From 98b9ac3f4c4aae26d230ba4ce841cecfb99e3999 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Tue, 27 Apr 2021 12:36:33 +0200
Subject: [PATCH 001/164] Bump BASE-VER

2021-05-27  Jakub Jelinek  <jakub@redhat.com>

	* BASE-VER: Set to 11.1.1.
---
 gcc/BASE-VER | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/BASE-VER b/gcc/BASE-VER
index 68d8f15e23cf5..668182d21a480 100644
--- a/gcc/BASE-VER
+++ b/gcc/BASE-VER
@@ -1 +1 @@
-11.1.0
+11.1.1

From 12333b7e7636d7337054b85d37cb2def3b2e4ca4 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Wed, 21 Apr 2021 12:31:45 +0200
Subject: [PATCH 002/164] cprop: Fix -fcompare-debug bug in constprop_register
 [PR100148]

The following testcase shows different behavior between -g and -g0
in constprop_register, if a flags register setter is separated
from a conditional jump using those flags with -g by a DEBUG_INSN.
As it uses just NEXT_INSN, for -g it will look at the DEBUG_INSN which is
not a conditional jump, while otherwise it would look at the conditional
jump and call cprop_jump.

2021-04-21  Jakub Jelinek  <jakub@redhat.com>

	PR rtl-optimization/100148
	* cprop.c (constprop_register): Use next_nondebug_insn instead of
	NEXT_INSN.

	* g++.dg/opt/pr100148.C: New test.

(cherry picked from commit 022f6ee3ad67ee30f62c8c2aeeb4156494f3284e)
---
 gcc/cprop.c                         |  8 +++++---
 gcc/testsuite/g++.dg/opt/pr100148.C | 27 +++++++++++++++++++++++++++
 2 files changed, 32 insertions(+), 3 deletions(-)
 create mode 100644 gcc/testsuite/g++.dg/opt/pr100148.C

diff --git a/gcc/cprop.c b/gcc/cprop.c
index 73034ce72d098..6f34f6b2418b9 100644
--- a/gcc/cprop.c
+++ b/gcc/cprop.c
@@ -1007,16 +1007,18 @@ static int
 constprop_register (rtx from, rtx src, rtx_insn *insn)
 {
   rtx sset;
+  rtx_insn *next_insn;
 
   /* Check for reg or cc0 setting instructions followed by
      conditional branch instructions first.  */
   if ((sset = single_set (insn)) != NULL
-      && NEXT_INSN (insn)
-      && any_condjump_p (NEXT_INSN (insn)) && onlyjump_p (NEXT_INSN (insn)))
+      && (next_insn = next_nondebug_insn (insn)) != NULL
+      && any_condjump_p (next_insn)
+      && onlyjump_p (next_insn))
     {
       rtx dest = SET_DEST (sset);
       if ((REG_P (dest) || CC0_P (dest))
-	  && cprop_jump (BLOCK_FOR_INSN (insn), insn, NEXT_INSN (insn),
+	  && cprop_jump (BLOCK_FOR_INSN (insn), insn, next_insn,
 			 from, src))
 	return 1;
     }
diff --git a/gcc/testsuite/g++.dg/opt/pr100148.C b/gcc/testsuite/g++.dg/opt/pr100148.C
new file mode 100644
index 0000000000000..d038879b6b847
--- /dev/null
+++ b/gcc/testsuite/g++.dg/opt/pr100148.C
@@ -0,0 +1,27 @@
+// PR rtl-optimization/100148
+// { dg-do compile }
+// { dg-options "-O2 -fno-dce -fno-tree-dce -fno-tree-dominator-opts -fno-tree-sink -fcompare-debug" }
+
+int i;
+enum E { } e, ee;
+
+bool
+baz (int)
+{
+  return ee;
+}
+
+bool bar ();
+bool a, b;
+
+void
+foo ()
+{
+  switch (ee)
+    {
+    case 0:
+      e = E (a ? : i);
+    case 1:
+      !(b || baz (0) && bar ());
+    }
+}

From c7421c7dd2ce1e27cf704fa444984a2628a1587f Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Wed, 21 Apr 2021 15:17:10 +0200
Subject: [PATCH 003/164] testsuite: Add -fchecking to dg-ice tests

In --enable-checking=release builds (which is the default on release
branches), I'm getting various extra FAILs that don't appear in
--enable-checking=yes builds.

XPASS: g++.dg/cpp0x/constexpr-52830.C  -std=c++14 (internal compiler error)
FAIL: g++.dg/cpp0x/constexpr-52830.C  -std=c++14 (test for excess errors)
XPASS: g++.dg/cpp0x/constexpr-52830.C  -std=c++17 (internal compiler error)
FAIL: g++.dg/cpp0x/constexpr-52830.C  -std=c++17 (test for excess errors)
XPASS: g++.dg/cpp0x/constexpr-52830.C  -std=c++2a (internal compiler error)
FAIL: g++.dg/cpp0x/constexpr-52830.C  -std=c++2a (test for excess errors)
FAIL: g++.dg/cpp0x/vt-88982.C  -std=c++14 (test for excess errors)
FAIL: g++.dg/cpp0x/vt-88982.C  -std=c++17 (test for excess errors)
FAIL: g++.dg/cpp0x/vt-88982.C  -std=c++2a (test for excess errors)
FAIL: g++.dg/cpp1y/auto-fn61.C  -std=c++14 (test for excess errors)
FAIL: g++.dg/cpp1y/auto-fn61.C  -std=c++17 (test for excess errors)
FAIL: g++.dg/cpp1y/auto-fn61.C  -std=c++2a (test for excess errors)
FAIL: g++.dg/cpp1z/constexpr-lambda26.C  -std=c++17 (test for excess errors)
FAIL: g++.dg/cpp1z/constexpr-lambda26.C  -std=c++2a (test for excess errors)
FAIL: g++.dg/cpp2a/nontype-class39.C  -std=c++2a (test for excess errors)
FAIL: c-c++-common/goacc/kernels-decompose-ice-1.c  -std=c++14 (test for excess errors)
FAIL: c-c++-common/goacc/kernels-decompose-ice-1.c  -std=c++17 (test for excess errors)
FAIL: c-c++-common/goacc/kernels-decompose-ice-1.c  -std=c++2a (test for excess errors)
FAIL: c-c++-common/goacc/kernels-decompose-ice-1.c  -std=c++98 (test for excess errors)
FAIL: c-c++-common/goacc/kernels-decompose-ice-2.c  -std=c++14 (test for excess errors)
FAIL: c-c++-common/goacc/kernels-decompose-ice-2.c  -std=c++17 (test for excess errors)
FAIL: c-c++-common/goacc/kernels-decompose-ice-2.c  -std=c++2a (test for excess errors)
FAIL: c-c++-common/goacc/kernels-decompose-ice-2.c  -std=c++98 (test for excess errors)

These are tests that have dg-ice and most of those ICEs are checking ICEs
which go away in release checking when -fno-checking is the default.

The following patch adds -fchecking option to those.

2021-04-21  Jakub Jelinek  <jakub@redhat.com>

	* g++.dg/cpp1z/constexpr-lambda26.C: Add dg-additional-options
	-fchecking.
	* g++.dg/cpp1y/auto-fn61.C: Likewise.
	* g++.dg/cpp2a/nontype-class39.C: Likewise.
	* g++.dg/cpp0x/constexpr-52830.C: Likewise.
	* g++.dg/cpp0x/vt-88982.C: Likewise.
	* c-c++-common/goacc/kernels-decompose-ice-1.c: Add -fchecking to
	dg-additional-options.
	* c-c++-common/goacc/kernels-decompose-ice-2.c: Likewise.

(cherry picked from commit ca4bf1dd4398dc65d8fff8b9f5c67733729cee95)
---
 gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-1.c | 2 +-
 gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-2.c | 2 +-
 gcc/testsuite/g++.dg/cpp0x/constexpr-52830.C               | 1 +
 gcc/testsuite/g++.dg/cpp0x/vt-88982.C                      | 1 +
 gcc/testsuite/g++.dg/cpp1y/auto-fn61.C                     | 1 +
 gcc/testsuite/g++.dg/cpp1z/constexpr-lambda26.C            | 1 +
 gcc/testsuite/g++.dg/cpp2a/nontype-class39.C               | 1 +
 7 files changed, 7 insertions(+), 2 deletions(-)

diff --git a/gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-1.c b/gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-1.c
index d770b91dd097a..8c3884bdc00ed 100644
--- a/gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-1.c
+++ b/gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-1.c
@@ -1,7 +1,7 @@
 /* Test OpenACC 'kernels' construct decomposition.  */
 
 /* { dg-additional-options "-fopt-info-omp-all" } */
-/* { dg-additional-options "--param=openacc-kernels=decompose" } */
+/* { dg-additional-options "-fchecking --param=openacc-kernels=decompose" } */
 /* { dg-ice "TODO" }
    { dg-prune-output "during GIMPLE pass: omplower" } */
 
diff --git a/gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-2.c b/gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-2.c
index ae059eb354bce..8bf60a9a50999 100644
--- a/gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-2.c
+++ b/gcc/testsuite/c-c++-common/goacc/kernels-decompose-ice-2.c
@@ -1,6 +1,6 @@
 /* Test OpenACC 'kernels' construct decomposition.  */
 
-/* { dg-additional-options "--param=openacc-kernels=decompose" } */
+/* { dg-additional-options "-fchecking --param=openacc-kernels=decompose" } */
 /* { dg-ice "TODO" }
    { dg-prune-output "during GIMPLE pass: omplower" } */
 
diff --git a/gcc/testsuite/g++.dg/cpp0x/constexpr-52830.C b/gcc/testsuite/g++.dg/cpp0x/constexpr-52830.C
index 2c9d2f9b329ea..eae0d8c377b8e 100644
--- a/gcc/testsuite/g++.dg/cpp0x/constexpr-52830.C
+++ b/gcc/testsuite/g++.dg/cpp0x/constexpr-52830.C
@@ -1,5 +1,6 @@
 // PR c++/52830
 // { dg-do compile { target c++11 } }
+// { dg-additional-options "-fchecking" }
 // { dg-ice "comptypes" }
 
 template<bool b> struct eif { typedef void type; };
diff --git a/gcc/testsuite/g++.dg/cpp0x/vt-88982.C b/gcc/testsuite/g++.dg/cpp0x/vt-88982.C
index cb9530dcee122..7a868233d73c5 100644
--- a/gcc/testsuite/g++.dg/cpp0x/vt-88982.C
+++ b/gcc/testsuite/g++.dg/cpp0x/vt-88982.C
@@ -1,5 +1,6 @@
 // PR c++/88982
 // { dg-do compile { target c++11 } }
+// { dg-additional-options "-fchecking" }
 // { dg-ice "tsubst_pack_expansion" }
 
 template<typename...Ts> struct A {
diff --git a/gcc/testsuite/g++.dg/cpp1y/auto-fn61.C b/gcc/testsuite/g++.dg/cpp1y/auto-fn61.C
index c24c3b85d782b..bed5ea0cfc037 100644
--- a/gcc/testsuite/g++.dg/cpp1y/auto-fn61.C
+++ b/gcc/testsuite/g++.dg/cpp1y/auto-fn61.C
@@ -1,5 +1,6 @@
 // PR c++/88003
 // { dg-do compile { target c++14 } }
+// { dg-additional-options "-fchecking" }
 // { dg-ice "poplevel_class" }
 
 auto test() {
diff --git a/gcc/testsuite/g++.dg/cpp1z/constexpr-lambda26.C b/gcc/testsuite/g++.dg/cpp1z/constexpr-lambda26.C
index d6c8bae525fa5..0cdb400d21c4f 100644
--- a/gcc/testsuite/g++.dg/cpp1z/constexpr-lambda26.C
+++ b/gcc/testsuite/g++.dg/cpp1z/constexpr-lambda26.C
@@ -1,5 +1,6 @@
 // PR c++/87765
 // { dg-do compile { target c++17 } }
+// { dg-additional-options "-fchecking" }
 // { dg-ice "cxx_eval_constant_expression" }
 
 template <int N>
diff --git a/gcc/testsuite/g++.dg/cpp2a/nontype-class39.C b/gcc/testsuite/g++.dg/cpp2a/nontype-class39.C
index f5f79a71ec2c3..512afad8e4faa 100644
--- a/gcc/testsuite/g++.dg/cpp2a/nontype-class39.C
+++ b/gcc/testsuite/g++.dg/cpp2a/nontype-class39.C
@@ -1,5 +1,6 @@
 // PR c++/89565
 // { dg-do compile { target c++20 } }
+// { dg-additional-options "-fchecking" }
 // { dg-ice "resolve_args" }
 
 template <auto>

From b363daf1321bec59b96908ddfb674312732173ad Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Mon, 26 Apr 2021 09:59:15 +0200
Subject: [PATCH 004/164] vmsdbgout: Remove useless register keywords

register keyword was removed in C++17, and in vmsdbgout.c it served no
useful purpose.

2021-04-26  Jakub Jelinek  <jakub@redhat.com>

	PR debug/100255
	* vmsdbgout.c (ASM_OUTPUT_DEBUG_STRING, vmsdbgout_begin_block,
	vmsdbgout_end_block, lookup_filename, vmsdbgout_source_line): Remove
	register keywords.

(cherry picked from commit 297bfacdb448c0d29b8dfac2818350b90902bc75)
---
 gcc/vmsdbgout.c | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/gcc/vmsdbgout.c b/gcc/vmsdbgout.c
index a7640004b87fb..c226bc69c8559 100644
--- a/gcc/vmsdbgout.c
+++ b/gcc/vmsdbgout.c
@@ -365,13 +365,13 @@ static char text_end_label[MAX_ARTIFICIAL_LABEL_BYTES];
 #define ASM_OUTPUT_DEBUG_STRING(FILE,P)		\
   do						\
     {						\
-      register int slen = strlen (P);		\
-      register const char *p = (P);		\
-      register int i;				\
+      int slen = strlen (P);			\
+      const char *p = (P);			\
+      int i;					\
       fprintf (FILE, "\t.ascii \"");		\
       for (i = 0; i < slen; i++)		\
 	{					\
-	  register int c = p[i];		\
+	  int c = p[i];				\
 	  if (c == '\"' || c == '\\')		\
 	    putc ('\\', FILE);			\
 	  if (c >= ' ' && c < 0177)		\
@@ -1229,7 +1229,7 @@ vmsdbgout_end_epilogue (unsigned int line, const char *file)
    a lexical block.  */
 
 static void
-vmsdbgout_begin_block (register unsigned line, register unsigned blocknum)
+vmsdbgout_begin_block (unsigned line, unsigned blocknum)
 {
   if (write_symbols == VMS_AND_DWARF2_DEBUG)
     (*dwarf2_debug_hooks.begin_block) (line, blocknum);
@@ -1242,7 +1242,7 @@ vmsdbgout_begin_block (register unsigned line, register unsigned blocknum)
    lexical block.  */
 
 static void
-vmsdbgout_end_block (register unsigned line, register unsigned blocknum)
+vmsdbgout_end_block (unsigned line, unsigned blocknum)
 {
   if (write_symbols == VMS_AND_DWARF2_DEBUG)
     (*dwarf2_debug_hooks.end_block) (line, blocknum);
@@ -1315,8 +1315,8 @@ static unsigned int
 lookup_filename (const char *file_name)
 {
   static unsigned int last_file_lookup_index = 0;
-  register char *fn;
-  register unsigned i;
+  char *fn;
+  unsigned i;
   const char *fnam;
   long long cdt = 0;
   long ebk = 0;
@@ -1405,8 +1405,8 @@ vmsdbgout_write_source_line (unsigned line, const char *filename,
 }
 
 static void
-vmsdbgout_source_line (register unsigned line, unsigned int column,
-		       register const char *filename,
+vmsdbgout_source_line (unsigned line, unsigned int column,
+		       const char *filename,
                        int discriminator, bool is_stmt)
 {
   if (write_symbols == VMS_AND_DWARF2_DEBUG)

From 7f8eea0b16494554d623113c8138879b3f31d67a Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Tue, 27 Apr 2021 15:26:24 +0200
Subject: [PATCH 005/164] cfgcleanup: Fix -fcompare-debug issue in
 outgoing_edges_match [PR100254]

The following testcase fails with -fcompare-debug.  The problem is that
outgoing_edges_match behaves differently between -g0 and -g, if
some load/store with REG_EH_REGION is followed by DEBUG_INSNs, the
REG_EH_REGION check is not done, while when there are no DEBUG_INSNs, it is
done.

We already compute last1 and last2 as BB_END (bb{1,2}) with skipped debug
insns and notes, so this patch just uses those.

2021-04-27  Jakub Jelinek  <jakub@redhat.com>

	PR rtl-optimization/100254
	* cfgcleanup.c (outgoing_edges_match): Check REG_EH_REGION on
	last1 and last2 insns rather than BB_END (bb1) and BB_END (bb2) insns.

	* g++.dg/opt/pr100254.C: New test.

(cherry picked from commit e600df51a15b2ec7a72731921a2464ffe59cf5ab)
---
 gcc/cfgcleanup.c                    |   4 +-
 gcc/testsuite/g++.dg/opt/pr100254.C | 101 ++++++++++++++++++++++++++++
 2 files changed, 103 insertions(+), 2 deletions(-)
 create mode 100644 gcc/testsuite/g++.dg/opt/pr100254.C

diff --git a/gcc/cfgcleanup.c b/gcc/cfgcleanup.c
index 8650fb7f2648c..260a896ac4863 100644
--- a/gcc/cfgcleanup.c
+++ b/gcc/cfgcleanup.c
@@ -1885,8 +1885,8 @@ outgoing_edges_match (int mode, basic_block bb1, basic_block bb2)
 
   /* Ensure the same EH region.  */
   {
-    rtx n1 = find_reg_note (BB_END (bb1), REG_EH_REGION, 0);
-    rtx n2 = find_reg_note (BB_END (bb2), REG_EH_REGION, 0);
+    rtx n1 = find_reg_note (last1, REG_EH_REGION, 0);
+    rtx n2 = find_reg_note (last2, REG_EH_REGION, 0);
 
     if (!n1 && n2)
       return false;
diff --git a/gcc/testsuite/g++.dg/opt/pr100254.C b/gcc/testsuite/g++.dg/opt/pr100254.C
new file mode 100644
index 0000000000000..dbdac1638c7fd
--- /dev/null
+++ b/gcc/testsuite/g++.dg/opt/pr100254.C
@@ -0,0 +1,101 @@
+// PR rtl-optimization/100254
+// { dg-do compile }
+// { dg-options "-O2 -fno-guess-branch-probability -fipa-pta -fnon-call-exceptions -fcompare-debug" }
+// { dg-additional-options "-mtune=goldmont" { target i?86-*-* x86_64-*-* } }
+
+struct _Rb_tree_node_base {
+  typedef _Rb_tree_node_base *_Base_ptr;
+  typedef _Rb_tree_node_base *_Const_Base_ptr;
+  _Base_ptr _M_left;
+};
+template <typename _Key_compare> struct _Rb_tree_key_compare {
+  _Key_compare _M_key_compare;
+};
+struct _Rb_tree_header {
+  _Rb_tree_node_base _M_header;
+};
+struct _Rb_tree_iterator {
+  _Rb_tree_iterator(_Rb_tree_node_base::_Base_ptr);
+  friend bool operator==(_Rb_tree_iterator, _Rb_tree_iterator);
+};
+template <typename _Tp> struct _Rb_tree_const_iterator {
+  typedef _Rb_tree_const_iterator _Self;
+  _Rb_tree_const_iterator(_Rb_tree_node_base::_Const_Base_ptr) {}
+  _Tp operator*();
+  template <typename _Up>
+  friend bool operator!=(_Rb_tree_const_iterator<_Up>, _Rb_tree_const_iterator<_Up>);
+};
+template <typename _Key, typename _Val, typename _Compare> struct _Rb_tree {
+  template <typename _Key_compare>
+  struct _Rb_tree_impl : _Rb_tree_key_compare<_Key_compare>, _Rb_tree_header {};
+  _Rb_tree_impl<_Compare> _M_impl;
+  _Key _S_key();
+  typedef _Rb_tree_const_iterator<_Val> const_iterator;
+  const_iterator begin() { return _M_impl._M_header._M_left; }
+  _Rb_tree_iterator find(const _Key &);
+};
+template <typename _Key, typename _Val, typename _Compare>
+_Rb_tree_iterator _Rb_tree<_Key, _Val, _Compare>::find(const _Key &__k) {
+  _Rb_tree_iterator __j = 0;
+  return __j == 0 || _M_impl._M_key_compare(__k, _S_key()) ? 0 : __j;
+}
+template <typename _Key, typename _Compare = _Key> struct set {
+  typedef _Key key_type;
+  typedef _Rb_tree<key_type, _Key, _Compare> _Rep_type;
+  _Rep_type _M_t;
+  typedef typename _Rep_type::const_iterator iterator;
+  iterator begin() { return _M_t.begin(); }
+  iterator end();
+  void find(key_type __x) { _M_t.find(__x); }
+};
+struct WindowDesc {
+  WindowDesc(short);
+} _station_view_desc(0);
+struct Window {
+  void IsWidgetLowered();
+  virtual void OnClick(int, int, int);
+};
+int AllocateWindowDescFront_window_number;
+template <typename Wcls> void AllocateWindowDescFront(WindowDesc *desc, bool) {
+  Wcls(desc, AllocateWindowDescFront_window_number);
+}
+class CargoDataEntry;
+struct CargoSorter {
+  bool operator()(const CargoDataEntry *, const CargoDataEntry *) const;
+};
+struct CargoDataEntry {
+  ~CargoDataEntry();
+  char Retrieve_cargo;
+  void Retrieve() {
+    CargoDataEntry t(Retrieve_cargo);
+    children->find(&t);
+  }
+  CargoDataEntry(char);
+  set<CargoDataEntry *, CargoSorter> *children;
+};
+CargoDataEntry::CargoDataEntry(char) : children() {}
+CargoDataEntry::~CargoDataEntry() {
+  if (children)
+    for (set<CargoDataEntry *>::iterator i = children->begin();
+         i != children->end();)
+      delete *i;
+}
+bool CargoSorter::operator()(const CargoDataEntry *,
+                             const CargoDataEntry *) const { return false; }
+struct StationViewWindow : Window {
+  StationViewWindow(WindowDesc *, int);
+  CargoDataEntry HandleCargoWaitingClick_filter;
+  void OnClick(int, int widget, int) {
+    switch (widget) {
+    case 0:
+      HandleCargoWaitingClick_filter.Retrieve();
+      HandleCargoWaitingClick_filter.Retrieve();
+    case 1:
+      IsWidgetLowered();
+    }
+  }
+};
+void ShowStationViewWindow_station() {
+  AllocateWindowDescFront<StationViewWindow>(&_station_view_desc,
+                                             ShowStationViewWindow_station);
+}

From 80dc24f813a9d8951d75eea7324f6d713b872bca Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Tue, 27 Apr 2021 15:42:47 +0200
Subject: [PATCH 006/164] veclower: Fix up vec_shl matching of VEC_PERM_EXPR
 [PR100239]

The following testcase ICEs at -O0, because lower_vec_perm sees the
  _1 = { 0, 0, 0, 0, 0, 0, 0, 0 };
  _2 = VEC_COND_EXPR <_1, { -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 0, 0, 0, 0, 0, 0, 0 }>;
  _3 = { 6, 0, 0, 0, 0, 0, 0, 0 };
  _4 = VEC_PERM_EXPR <{ 0, 0, 0, 0, 0, 0, 0, 0 }, _2, _3>;
and as the ISA is SSE2, there is no support for the particular permutation
nor for variable mask permutation.  But, the code to match vec_shl matches
it, because the permutation has the first operand a zero vector and the
mask picks all elements randomly from that vector.
So, in the end that isn't a vec_shl, but the permutation could be in theory
optimized into the first argument.  As we keep it as is, it will fail
during expansion though, because that for vec_shl correctly requires that
it actually is a shift:
      unsigned firstidx = 0;
      for (unsigned int i = 0; i < nelt; i++)
        {
          if (known_eq (sel[i], nelt))
            {
              if (i == 0 || firstidx)
                return NULL_RTX;
              firstidx = i;
            }
          else if (firstidx
                   ? maybe_ne (sel[i], nelt + i - firstidx)
                   : maybe_ge (sel[i], nelt))
            return NULL_RTX;
        }

      if (firstidx == 0)
        return NULL_RTX;
      first = firstidx;
The if (firstidx == 0) return NULL; is what is missing a counterpart
on the lower_vec_perm side.
As with optimize != 0 we fold it in other spots, I think it is not needed
to optimize this cornercase in lower_vec_perm (which would mean we'd need
to recurse on the newly created _4 = { 0, 0, 0, 0, 0, 0, 0, 0 };
whether it is supported or not).

2021-04-27  Jakub Jelinek  <jakub@redhat.com>

	PR tree-optimization/100239
	* tree-vect-generic.c (lower_vec_perm): Don't accept constant
	permutations with all indices from the first zero element as vec_shl.

	* gcc.dg/pr100239.c: New test.

(cherry picked from commit 83d26d0e1b3625ab6c2d83610a13976b52f63e0a)
---
 gcc/testsuite/gcc.dg/pr100239.c | 12 ++++++++++++
 gcc/tree-vect-generic.c         |  2 +-
 2 files changed, 13 insertions(+), 1 deletion(-)
 create mode 100644 gcc/testsuite/gcc.dg/pr100239.c

diff --git a/gcc/testsuite/gcc.dg/pr100239.c b/gcc/testsuite/gcc.dg/pr100239.c
new file mode 100644
index 0000000000000..1ade810c52b05
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr100239.c
@@ -0,0 +1,12 @@
+/* PR tree-optimization/100239 */
+/* { dg-do compile } */
+/* { dg-options "-O0" } */
+
+typedef short __attribute__((__vector_size__ (8 * sizeof (short)))) V;
+V v, w;
+
+void
+foo (void)
+{
+  w = __builtin_shuffle (v != v, 0 < (V) {}, (V) {192} >> 5);
+}
diff --git a/gcc/tree-vect-generic.c b/gcc/tree-vect-generic.c
index c8d8493e6eaef..3348545d18ba4 100644
--- a/gcc/tree-vect-generic.c
+++ b/gcc/tree-vect-generic.c
@@ -1515,7 +1515,7 @@ lower_vec_perm (gimple_stmt_iterator *gsi)
 					      elements + i - first)
 		     : maybe_ge (poly_uint64 (indices[i]), elements))
 	      break;
-	  if (i == elements)
+	  if (first && i == elements)
 	    {
 	      gimple_assign_set_rhs3 (stmt, mask);
 	      update_stmt (stmt);

From 3fe1c1fd0eb5e4bbc1af313b3e9dd4605ec5a134 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Tue, 27 Apr 2021 15:46:16 +0200
Subject: [PATCH 007/164] aarch64: Fix UB in the compiler [PR100200]

The following patch fixes UBs in the compiler when negativing
a CONST_INT containing HOST_WIDE_INT_MIN.  I've changed the spots where
there wasn't an obvious earlier condition check or predicate that
would fail for such CONST_INTs.

2021-04-27  Jakub Jelinek  <jakub@redhat.com>

	PR target/100200
	* config/aarch64/predicates.md (aarch64_sub_immediate,
	aarch64_plus_immediate): Use -UINTVAL instead of -INTVAL.
	* config/aarch64/aarch64.md (casesi, rotl<mode>3): Likewise.
	* config/aarch64/aarch64.c (aarch64_print_operand,
	aarch64_split_atomic_op, aarch64_expand_subvti): Likewise.

(cherry picked from commit 618ae596ebcd1de03857d20485d1324931852569)
---
 gcc/config/aarch64/aarch64.c     | 6 +++---
 gcc/config/aarch64/aarch64.md    | 5 +++--
 gcc/config/aarch64/predicates.md | 4 ++--
 3 files changed, 8 insertions(+), 7 deletions(-)

diff --git a/gcc/config/aarch64/aarch64.c b/gcc/config/aarch64/aarch64.c
index 12625a4bee399..7985940ba42e0 100644
--- a/gcc/config/aarch64/aarch64.c
+++ b/gcc/config/aarch64/aarch64.c
@@ -10778,7 +10778,7 @@ aarch64_print_operand (FILE *f, rtx x, int code)
 	}
 
       if (GET_MODE_CLASS (GET_MODE (x)) == MODE_VECTOR_INT)
-	asm_fprintf (f, "%wd", -INTVAL (elt));
+	asm_fprintf (f, "%wd", -UINTVAL (elt));
       else if (GET_MODE_CLASS (GET_MODE (x)) == MODE_VECTOR_FLOAT
 	       && aarch64_print_vector_float_operand (f, x, true))
 	;
@@ -21598,7 +21598,7 @@ aarch64_split_atomic_op (enum rtx_code code, rtx old_out, rtx new_out, rtx mem,
     case MINUS:
       if (CONST_INT_P (value))
 	{
-	  value = GEN_INT (-INTVAL (value));
+	  value = GEN_INT (-UINTVAL (value));
 	  code = PLUS;
 	}
       /* Fall through.  */
@@ -23514,7 +23514,7 @@ aarch64_expand_subvti (rtx op0, rtx low_dest, rtx low_in1,
     {
       if (aarch64_plus_immediate (low_in2, DImode))
 	emit_insn (gen_subdi3_compare1_imm (low_dest, low_in1, low_in2,
-					    GEN_INT (-INTVAL (low_in2))));
+					    GEN_INT (-UINTVAL (low_in2))));
       else
 	{
 	  low_in2 = force_reg (DImode, low_in2);
diff --git a/gcc/config/aarch64/aarch64.md b/gcc/config/aarch64/aarch64.md
index abfd84526745d..aef6da9732d45 100644
--- a/gcc/config/aarch64/aarch64.md
+++ b/gcc/config/aarch64/aarch64.md
@@ -747,7 +747,8 @@
 	   constant can be represented in SImode, this is important
 	   for the corner case where operand[1] is INT_MIN.  */
 
-	operands[1] = GEN_INT (trunc_int_for_mode (-INTVAL (operands[1]), SImode));
+	operands[1]
+	  = GEN_INT (trunc_int_for_mode (-UINTVAL (operands[1]), SImode));
 
 	if (!(*insn_data[CODE_FOR_addsi3].operand[2].predicate)
 	      (operands[1], SImode))
@@ -5008,7 +5009,7 @@
     /* (SZ - cnt) % SZ == -cnt % SZ */
     if (CONST_INT_P (operands[2]))
       {
-        operands[2] = GEN_INT ((-INTVAL (operands[2]))
+        operands[2] = GEN_INT ((-UINTVAL (operands[2]))
 			       & (GET_MODE_BITSIZE (<MODE>mode) - 1));
         if (operands[2] == const0_rtx)
           {
diff --git a/gcc/config/aarch64/predicates.md b/gcc/config/aarch64/predicates.md
index c55842b9c747b..49f02ae038135 100644
--- a/gcc/config/aarch64/predicates.md
+++ b/gcc/config/aarch64/predicates.md
@@ -121,12 +121,12 @@
 
 (define_predicate "aarch64_sub_immediate"
   (and (match_code "const_int")
-       (match_test "aarch64_uimm12_shift (-INTVAL (op))")))
+       (match_test "aarch64_uimm12_shift (-UINTVAL (op))")))
 
 (define_predicate "aarch64_plus_immediate"
   (and (match_code "const_int")
        (ior (match_test "aarch64_uimm12_shift (INTVAL (op))")
-	    (match_test "aarch64_uimm12_shift (-INTVAL (op))"))))
+	    (match_test "aarch64_uimm12_shift (-UINTVAL (op))"))))
 
 (define_predicate "aarch64_plus_operand"
   (ior (match_operand 0 "register_operand")

From 9e80a135fffa5c1b36b6007e7e57d303535fbe84 Mon Sep 17 00:00:00 2001
From: Michael Meissner <meissner@linux.ibm.com>
Date: Tue, 27 Apr 2021 10:52:57 -0400
Subject: [PATCH 008/164] [PATCH] Backport fix for PR target/98952

The test in the PowerPC 32-bit trampoline support is backwards.  It aborts
if the trampoline size is greater than the expected size.  It should abort
when the trampoline size is less than the expected size.  I fixed the test
so the operands are reversed.  I then folded the load immediate into the
compare instruction.

I verified this by creating a 32-bit trampoline program and manually
changing the size of the trampoline to be 48 instead of 40.  The program
aborted with the larger size.  I updated this code and ran the test again
and it passed.

I added a test case that runs on PowerPC 32-bit Linux systems and it calls
the __trampoline_setup function with a larger buffer size than the
compiler uses.  The test is not run on 64-bit systems, since the function
__trampoline_setup is not called.  I also limited the test to just Linux
systems, in case trampolines are handled differently in other systems.

libgcc/
2021-04-27  Michael Meissner  <meissner@linux.ibm.com>

	PR target/98952
	* config/rs6000/tramp.S (__trampoline_setup, elfv1 #ifdef): Fix
	trampoline size comparison in 32-bit by reversing test and
	combining load immediate with compare.  Fix backported from trunk
	change on 4/23, 886b6c1e8af502b69e3f318b9830b73b88215878.
	(__trampoline_setup, elfv2 #ifdef): Fix trampoline size comparison
	in 32-bit by reversing test and combining load immediate with
	compare.

gcc/testsuite/
2021-04-27  Michael Meissner  <meissner@linux.ibm.com>

	PR target/98952
	* gcc.target/powerpc/pr98952.c: New test.  Test backported from
	trunk change on 4/23, 886b6c1e8af502b69e3f318b9830b73b88215878.
---
 gcc/testsuite/gcc.target/powerpc/pr98952.c | 28 ++++++++++++++++++++++
 libgcc/config/rs6000/tramp.S               |  6 ++---
 2 files changed, 30 insertions(+), 4 deletions(-)
 create mode 100644 gcc/testsuite/gcc.target/powerpc/pr98952.c

diff --git a/gcc/testsuite/gcc.target/powerpc/pr98952.c b/gcc/testsuite/gcc.target/powerpc/pr98952.c
new file mode 100644
index 0000000000000..c487fbc403ef2
--- /dev/null
+++ b/gcc/testsuite/gcc.target/powerpc/pr98952.c
@@ -0,0 +1,28 @@
+/* { dg-do run { target { powerpc*-*-linux* && ilp32 } } } */
+/* { dg-options "-O2" } */
+
+/* PR 96983 reported that the test in libgcc's tramp.S was backwards and it
+   would abort if the trampoline size passed to the function was greater than
+   the size the runtime was expecting (40).  It should abort if the size is less
+   than 40, not greater than 40.  This test creates a call to __trampoline_setup
+   with a much larger buffer to make sure the function does not abort.
+
+   We do not run this test on 64-bit since __trampoline_setup is not present in
+   64-bit systems.
+
+   We only run the test under Linux in case the other systems have some
+   different variant for __trampoline_setup.  */
+
+#ifndef SIZE
+#define SIZE 100
+#endif
+
+extern void __trampoline_setup (int *, unsigned, void *, void *);
+
+int main (void)
+{
+  int tramp[SIZE / sizeof (int)];
+
+  __trampoline_setup (tramp, SIZE, 0, 0);
+  return 0;
+}
diff --git a/libgcc/config/rs6000/tramp.S b/libgcc/config/rs6000/tramp.S
index 4236a82b40265..68baf16de9f06 100644
--- a/libgcc/config/rs6000/tramp.S
+++ b/libgcc/config/rs6000/tramp.S
@@ -64,8 +64,7 @@ FUNC_START(__trampoline_setup)
         mflr	r11
         addi	r7,r11,trampoline_initial-4-.LCF0 /* trampoline address -4 */
 
-	li	r8,trampoline_size	/* verify that the trampoline is big enough */
-	cmpw	cr1,r8,r4
+	cmpwi	cr1,r4,trampoline_size	/* verify that the trampoline is big enough */
 	srwi	r4,r4,2		/* # words to move */
 	addi	r9,r3,-4	/* adjust pointer for lwzu */
 	mtctr	r4
@@ -156,8 +155,7 @@ FUNC_START(__trampoline_setup)
 	ld 7,.LC0@toc@l(7)	/* trampoline address -8 */
 #endif
 
-	li	r8,trampoline_size	/* verify that the trampoline is big enough */
-	cmpw	cr1,r8,r4
+	cmpwi	cr1,r4,trampoline_size	/* verify that the trampoline is big enough */
 	srwi	r4,r4,3		/* # doublewords to move */
 	addi	r9,r3,-8	/* adjust pointer for stdu */
 	mtctr	r4

From e89e883a450126d021874536ae102f60a1cacb78 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Tue, 27 Apr 2021 17:50:53 +0200
Subject: [PATCH 009/164] aarch64: Fix up last commit [PR100200]

Pedantically signed vs. unsigned mismatches in va_arg are only well defined
if the value can be represented in both signed and unsigned integer types.

2021-04-27  Jakub Jelinek  <jakub@redhat.com>

	PR target/100200
	* config/aarch64/aarch64.c (aarch64_print_operand): Cast -UINTVAL
	back to HOST_WIDE_INT.

(cherry picked from commit 1c0c371d0ea297af2e3180c64cd18f2bfce919b1)
---
 gcc/config/aarch64/aarch64.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/config/aarch64/aarch64.c b/gcc/config/aarch64/aarch64.c
index 7985940ba42e0..e979a51f3afd7 100644
--- a/gcc/config/aarch64/aarch64.c
+++ b/gcc/config/aarch64/aarch64.c
@@ -10778,7 +10778,7 @@ aarch64_print_operand (FILE *f, rtx x, int code)
 	}
 
       if (GET_MODE_CLASS (GET_MODE (x)) == MODE_VECTOR_INT)
-	asm_fprintf (f, "%wd", -UINTVAL (elt));
+	asm_fprintf (f, "%wd", (HOST_WIDE_INT) -UINTVAL (elt));
       else if (GET_MODE_CLASS (GET_MODE (x)) == MODE_VECTOR_FLOAT
 	       && aarch64_print_vector_float_operand (f, x, true))
 	;

From bb3316a6f10b95c8adef092678da2e161a8fd494 Mon Sep 17 00:00:00 2001
From: Tobias Burnus <tobias@codesourcery.com>
Date: Wed, 21 Apr 2021 20:07:19 +0200
Subject: [PATCH 010/164] libgomp/testsuite: Fix checks for dg-excess-errors

For the tests modified below, the effective target line has to be effective
when compiling for an offload target, except that variable-not-offloaded.c
would compile with unified-share memory and pr86416-*.c if long double/float128
is supported.
The previous check used a run-time device ability check. This new variant
now enables those dg- lines when _compiling_ for nvptx or gcn.

libgomp/ChangeLog:

	* testsuite/lib/libgomp.exp (offload_target_to_openacc_device_type):
	New, based on check_effective_target_offload_target_nvptx.
	(check_effective_target_offload_target_nvptx): Call it.
	(check_effective_target_offload_target_amdgcn): New.
	* testsuite/libgomp.c-c++-common/function-not-offloaded.c:
	Require target offload_target_nvptx || offload_target_amdgcn.
	* testsuite/libgomp.c-c++-common/variable-not-offloaded.c: Likewise.
	* testsuite/libgomp.c/pr86416-1.c: Likewise.
	* testsuite/libgomp.c/pr86416-2.c: Likewise.

(cherry picked from commit 95dfc3ac7baca19157bb976ee4c8c69753e1e178)
---
 libgomp/testsuite/lib/libgomp.exp             | 20 +++++++++++++++----
 .../function-not-offloaded.c                  |  2 +-
 .../variable-not-offloaded.c                  |  4 ++--
 libgomp/testsuite/libgomp.c/pr86416-1.c       |  4 ++--
 libgomp/testsuite/libgomp.c/pr86416-2.c       |  4 ++--
 5 files changed, 23 insertions(+), 11 deletions(-)

diff --git a/libgomp/testsuite/lib/libgomp.exp b/libgomp/testsuite/lib/libgomp.exp
index 14dcfdfd00a94..46cce9b8445e5 100644
--- a/libgomp/testsuite/lib/libgomp.exp
+++ b/libgomp/testsuite/lib/libgomp.exp
@@ -340,8 +340,10 @@ proc offload_target_to_openacc_device_type { offload_target } {
     }
 }
 
-# Return 1 if compiling for offload target nvptx.
-proc check_effective_target_offload_target_nvptx { } {
+# Return 1 if compiling for the specified offload target
+# Takes -foffload=... into account by checking OFFLOAD_TARGET_NAMES=
+# in the -v compiler output.
+proc libgomp_check_effective_target_offload_target { target_name } {
     # Consider all actual options, including the flags passed to
     # 'gcc-dg-runtest', or 'gfortran-dg-runtest' (see the 'libgomp.*/*.exp'
     # files; in particular, '-foffload', 'libgomp.oacc-*/*.exp'), which don't
@@ -354,13 +356,23 @@ proc check_effective_target_offload_target_nvptx { } {
     set gcc_output [libgomp_target_compile "" "" "none" $options]
     if [regexp "(?n)^OFFLOAD_TARGET_NAMES=(.*)" $gcc_output dummy offload_targets] {
 	verbose "compiling for offload targets: $offload_targets"
-	return [string match "*:nvptx*:*" ":$offload_targets:"]
+	return [string match "*:$target_name*:*" ":$offload_targets:"]
     }
 
-    verbose "not compiling for any offload targets"
+    verbose "not compiling for $target_name offload target"
     return 0
 }
 
+# Return 1 if compiling for offload target nvptx.
+proc check_effective_target_offload_target_nvptx { } {
+    return [libgomp_check_effective_target_offload_target "nvptx"]
+}
+
+# Return 1 if compiling for offload target amdgcn
+proc check_effective_target_offload_target_amdgcn { } {
+    return [libgomp_check_effective_target_offload_target "amdgcn"]
+}
+
 # Return 1 if offload device is available.
 proc check_effective_target_offload_device { } {
     return [check_runtime_nocache offload_device_available_ {
diff --git a/libgomp/testsuite/libgomp.c-c++-common/function-not-offloaded.c b/libgomp/testsuite/libgomp.c-c++-common/function-not-offloaded.c
index 9e59ef8864e77..bc1ae68941a03 100644
--- a/libgomp/testsuite/libgomp.c-c++-common/function-not-offloaded.c
+++ b/libgomp/testsuite/libgomp.c-c++-common/function-not-offloaded.c
@@ -1,5 +1,5 @@
 /* { dg-do link } */
-/* { dg-excess-errors "unresolved symbol foo, lto1, mkoffload and lto-wrapper fatal errors" { target offload_device_nonshared_as } } */
+/* { dg-excess-errors "unresolved symbol foo, lto1, mkoffload and lto-wrapper fatal errors" { target { offload_target_nvptx || offload_target_amdgcn } } } */
 /* { dg-additional-sources "function-not-offloaded-aux.c" } */
 
 #pragma omp declare target
diff --git a/libgomp/testsuite/libgomp.c-c++-common/variable-not-offloaded.c b/libgomp/testsuite/libgomp.c-c++-common/variable-not-offloaded.c
index bc4b916e9a457..fe2a8b2624270 100644
--- a/libgomp/testsuite/libgomp.c-c++-common/variable-not-offloaded.c
+++ b/libgomp/testsuite/libgomp.c-c++-common/variable-not-offloaded.c
@@ -1,7 +1,7 @@
 /* { dg-do link } */
-/* { dg-excess-errors "lto1, mkoffload and lto-wrapper fatal errors" { target offload_device_nonshared_as } } */
+/* { dg-excess-errors "lto1, mkoffload and lto-wrapper fatal errors" { target { offload_target_nvptx || offload_target_amdgcn } } } */
 
-int var; /* { dg-error "variable 'var' has been referenced in offloaded code but hasn't been marked to be included in the offloaded code" "" { target offload_device_nonshared_as } } */
+int var; /* { dg-error "variable 'var' has been referenced in offloaded code but hasn't been marked to be included in the offloaded code" "" { target { offload_target_nvptx || offload_target_amdgcn } } } */
 
 #pragma omp declare target
 void  __attribute__((noinline, noclone))
diff --git a/libgomp/testsuite/libgomp.c/pr86416-1.c b/libgomp/testsuite/libgomp.c/pr86416-1.c
index ad9370f78f3c0..6d3869264fdef 100644
--- a/libgomp/testsuite/libgomp.c/pr86416-1.c
+++ b/libgomp/testsuite/libgomp.c/pr86416-1.c
@@ -2,8 +2,8 @@
 /* { dg-require-effective-target large_long_double } */
 
 /* PR middle-end/86416  */
-/* { dg-error "bit-precision floating-point numbers unsupported .mode '.F'." "" { target offload_device } 0 }  */
-/* { dg-excess-errors "Follow-up errors from mkoffload and lto-wrapper" { target offload_device } }  */
+/* { dg-error "bit-precision floating-point numbers unsupported .mode '.F'." "" { target { offload_target_nvptx || offload_target_amdgcn } } 0 }  */
+/* { dg-excess-errors "Follow-up errors from mkoffload and lto-wrapper" { target { offload_target_nvptx || offload_target_amdgcn } } }  */
 
 #include <stdlib.h>  /* For abort. */
 
diff --git a/libgomp/testsuite/libgomp.c/pr86416-2.c b/libgomp/testsuite/libgomp.c/pr86416-2.c
index ec45e400f95f4..cffeb3f7107ce 100644
--- a/libgomp/testsuite/libgomp.c/pr86416-2.c
+++ b/libgomp/testsuite/libgomp.c/pr86416-2.c
@@ -2,8 +2,8 @@
 /* { dg-add-options __float128 } */
 
 /* PR middle-end/86416  */
-/* { dg-error "bit-precision floating-point numbers unsupported .mode '.F'." "" { target offload_device } 0 }  */
-/* { dg-excess-errors "Follow-up errors from mkoffload and lto-wrapper" { target offload_device } }  */
+/* { dg-error "bit-precision floating-point numbers unsupported .mode '.F'." "" { target { offload_target_nvptx || offload_target_amdgcn } } 0 }  */
+/* { dg-excess-errors "Follow-up errors from mkoffload and lto-wrapper" { target { offload_target_nvptx || offload_target_amdgcn } } }  */
 
 #include <stdlib.h>  /* For abort. */
 

From af53e450e5c61e36bd01aa2db1251483a60be007 Mon Sep 17 00:00:00 2001
From: Marek Polacek <polacek@redhat.com>
Date: Tue, 20 Apr 2021 12:16:04 -0400
Subject: [PATCH 011/164] c++: Don't allow defining types in enum-base
 [PR96380]

In r11-2064 I made cp_parser_enum_specifier commit to tentative parse
when seeing a '{'.  That still looks like the correct thing to do, but
it caused an ICE-on-invalid as well as accepts-invalid.

When we have something sneaky like this, which is broken in multiple
ways:

  template <class>
  enum struct c : union enum struct c { e = b, f = a };

we parse the "enum struct c" part (that's OK) and then we see that
we have an enum-base, so we consume ':' and then parse the type-specifier
that follows the :.  "union enum" is clearly invalid, but we're still
parsing tentatively and we parse everything up to the ;, and then
throw away the underlying type.  We parsed everything because we were
tricked into parsing an enum-specifier in an enum-base of another
enum-specifier!  Not good.

Since the grammar for enum-base doesn't allow a defining-type-specifier,
only a type-specifier, we should set type_definition_forbidden_message
which fixes all the problems in this PR.

gcc/cp/ChangeLog:

	PR c++/96380
	* parser.c (cp_parser_enum_specifier): Don't allow defining
	types in enum-base.

gcc/testsuite/ChangeLog:

	PR c++/96380
	* g++.dg/cpp0x/enum_base4.C: New test.
	* g++.dg/cpp0x/enum_base5.C: New test.

(cherry picked from commit 001c63d15e31bc0a1545426d889a0b9f671b4961)
---
 gcc/cp/parser.c                         | 4 ++++
 gcc/testsuite/g++.dg/cpp0x/enum_base4.C | 8 ++++++++
 gcc/testsuite/g++.dg/cpp0x/enum_base5.C | 7 +++++++
 3 files changed, 19 insertions(+)
 create mode 100644 gcc/testsuite/g++.dg/cpp0x/enum_base4.C
 create mode 100644 gcc/testsuite/g++.dg/cpp0x/enum_base5.C

diff --git a/gcc/cp/parser.c b/gcc/cp/parser.c
index 99eccf0c5e439..fba516efa23d5 100644
--- a/gcc/cp/parser.c
+++ b/gcc/cp/parser.c
@@ -19942,6 +19942,10 @@ cp_parser_enum_specifier (cp_parser* parser)
       /* Consume the `:'.  */
       cp_lexer_consume_token (parser->lexer);
 
+      auto tdf
+	= make_temp_override (parser->type_definition_forbidden_message,
+			      G_("types may not be defined in enum-base"));
+
       /* Parse the type-specifier-seq.  */
       cp_parser_type_specifier_seq (parser, CP_PARSER_FLAGS_NONE,
 				    /*is_declaration=*/false,
diff --git a/gcc/testsuite/g++.dg/cpp0x/enum_base4.C b/gcc/testsuite/g++.dg/cpp0x/enum_base4.C
new file mode 100644
index 0000000000000..b3015256386ab
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp0x/enum_base4.C
@@ -0,0 +1,8 @@
+// PR c++/96380
+// { dg-do compile { target c++11 } }
+
+extern const int a, b;
+enum struct c;
+template <class>
+enum struct c : union enum struct c { e = b, f = a };  // { dg-error "types may not be defined|expected|elaborated-type-specifier" }
+enum class c {};
diff --git a/gcc/testsuite/g++.dg/cpp0x/enum_base5.C b/gcc/testsuite/g++.dg/cpp0x/enum_base5.C
new file mode 100644
index 0000000000000..c01e857e612e2
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp0x/enum_base5.C
@@ -0,0 +1,7 @@
+// PR c++/96380
+// { dg-do compile { target c++11 } }
+
+extern const int a, b;
+enum struct c;
+template <class>
+enum struct c : union enum struct c { e = b, f = a }; // { dg-error "types may not be defined|expected|elaborated-type-specifier" }

From fb7c736c2f17ad054ee7815b688fa91135690f6d Mon Sep 17 00:00:00 2001
From: Marek Polacek <polacek@redhat.com>
Date: Tue, 20 Apr 2021 20:24:09 -0400
Subject: [PATCH 012/164] c++: Prevent bogus -Wtype-limits warning with NTTP
 [PR100161]

Recently, we made sure that we never call value_dependent_expression_p
on an expression that isn't potential_constant_expression.  That caused
this bogus warning with a non-type template parameter, something that
users don't want to see.

The problem is that in tsubst_copy_and_build/LE_EXPR 't' is "i < n",
which, due to 'i', is not p_c_e, therefore we call t_d_e_p.  But the
type of 'n' isn't dependent, so we think the whole 't' expression is
not dependent.  It seems we need to test both op0 and op1 separately
to suppress this warning.

gcc/cp/ChangeLog:

	PR c++/100161
	* pt.c (tsubst_copy_and_build) <case PLUS_EXPR>: Test op0 and
	op1 separately for value- or type-dependence.

gcc/testsuite/ChangeLog:

	PR c++/100161
	* g++.dg/warn/Wtype-limits6.C: New test.

(cherry picked from commit 244dfb95119106e9267f37583caac565c39eb0ec)
---
 gcc/cp/pt.c                               | 24 ++++++++++++++---------
 gcc/testsuite/g++.dg/warn/Wtype-limits6.C | 17 ++++++++++++++++
 2 files changed, 32 insertions(+), 9 deletions(-)
 create mode 100644 gcc/testsuite/g++.dg/warn/Wtype-limits6.C

diff --git a/gcc/cp/pt.c b/gcc/cp/pt.c
index 19fdafa4c43c8..ada2b63efb92b 100644
--- a/gcc/cp/pt.c
+++ b/gcc/cp/pt.c
@@ -19900,15 +19900,21 @@ tsubst_copy_and_build (tree t,
     case MEMBER_REF:
     case DOTSTAR_EXPR:
       {
-	/* If T was type-dependent, suppress warnings that depend on the range
-	   of the types involved.  */
-	++processing_template_decl;
-	const bool was_dep = (potential_constant_expression (t)
-			      ? value_dependent_expression_p (t)
-			      : type_dependent_expression_p (t));
-	--processing_template_decl;
-	tree op0 = RECUR (TREE_OPERAND (t, 0));
-	tree op1 = RECUR (TREE_OPERAND (t, 1));
+	/* If either OP0 or OP1 was value- or type-dependent, suppress
+	   warnings that depend on the range of the types involved.  */
+	tree op0 = TREE_OPERAND (t, 0);
+	tree op1 = TREE_OPERAND (t, 1);
+	auto dep_p = [](tree t) {
+	  ++processing_template_decl;
+	  bool r = (potential_constant_expression (t)
+		    ? value_dependent_expression_p (t)
+		    : type_dependent_expression_p (t));
+	  --processing_template_decl;
+	  return r;
+	};
+	const bool was_dep = dep_p (op0) || dep_p (op1);
+	op0 = RECUR (op0);
+	op1 = RECUR (op1);
 
 	warning_sentinel s1(warn_type_limits, was_dep);
 	warning_sentinel s2(warn_div_by_zero, was_dep);
diff --git a/gcc/testsuite/g++.dg/warn/Wtype-limits6.C b/gcc/testsuite/g++.dg/warn/Wtype-limits6.C
new file mode 100644
index 0000000000000..9d5886d532373
--- /dev/null
+++ b/gcc/testsuite/g++.dg/warn/Wtype-limits6.C
@@ -0,0 +1,17 @@
+// PR c++/100161
+// { dg-additional-options "-Wtype-limits" }
+
+void f(unsigned);
+
+template<unsigned n>
+void g()
+{
+    for (unsigned i = 0; i < n; i++) { // { dg-bogus "always false" }
+        f(i);
+    }
+}
+
+void h()
+{
+    g<0>();
+}

From 3efd52599ae47e8084f9485cd4c84b17419273ba Mon Sep 17 00:00:00 2001
From: Harald Anlauf <anlauf@gmx.de>
Date: Sat, 24 Apr 2021 20:51:41 +0200
Subject: [PATCH 013/164] PR fortran/100154 - ICE in gfc_conv_procedure_call,
 at fortran/trans-expr.c:6131

Add appropriate static checks for the character and status arguments to
the GNU Fortran intrinsic extensions fget[c], fput[c].  Extend variable
check to allow a function reference having a data pointer result.

gcc/fortran/ChangeLog:

	PR fortran/100154
	* check.c (variable_check): Allow function reference having a data
	pointer result.
	(arg_strlen_is_zero): New function.
	(gfc_check_fgetputc_sub): Add static check of character and status
	arguments.
	(gfc_check_fgetput_sub): Likewise.
	* intrinsic.c (add_subroutines): Fix argument name for the
	character argument to intrinsic subroutines fget[c], fput[c].

gcc/testsuite/ChangeLog:

	PR fortran/100154
	* gfortran.dg/pr100154.f90: New test.

(cherry picked from commit d0e7833b94953ba6b4a915150666969ad9fc66af)
---
 gcc/fortran/check.c                    | 36 ++++++++++++++++++++++++--
 gcc/fortran/intrinsic.c                | 10 +++----
 gcc/testsuite/gfortran.dg/pr100154.f90 | 26 +++++++++++++++++++
 3 files changed, 65 insertions(+), 7 deletions(-)
 create mode 100644 gcc/testsuite/gfortran.dg/pr100154.f90

diff --git a/gcc/fortran/check.c b/gcc/fortran/check.c
index 82db8e4e1b21a..27bf3a7eafefd 100644
--- a/gcc/fortran/check.c
+++ b/gcc/fortran/check.c
@@ -1055,6 +1055,13 @@ variable_check (gfc_expr *e, int n, bool allow_proc)
 	  return true;
     }
 
+  /* F2018:R902: function reference having a data pointer result.  */
+  if (e->expr_type == EXPR_FUNCTION
+      && e->symtree->n.sym->attr.flavor == FL_PROCEDURE
+      && e->symtree->n.sym->attr.function
+      && e->symtree->n.sym->attr.pointer)
+    return true;
+
   gfc_error ("%qs argument of %qs intrinsic at %L must be a variable",
 	     gfc_current_intrinsic_arg[n]->name, gfc_current_intrinsic, &e->where);
 
@@ -5689,6 +5696,19 @@ gfc_check_spread (gfc_expr *source, gfc_expr *dim, gfc_expr *ncopies)
 /* Functions for checking FGETC, FPUTC, FGET and FPUT (subroutines and
    functions).  */
 
+bool
+arg_strlen_is_zero (gfc_expr *c, int n)
+{
+  if (gfc_var_strlen (c) == 0)
+    {
+      gfc_error ("%qs argument of %qs intrinsic at %L must have "
+		 "length at least 1", gfc_current_intrinsic_arg[n]->name,
+		 gfc_current_intrinsic, &c->where);
+      return true;
+    }
+  return false;
+}
+
 bool
 gfc_check_fgetputc_sub (gfc_expr *unit, gfc_expr *c, gfc_expr *status)
 {
@@ -5702,13 +5722,19 @@ gfc_check_fgetputc_sub (gfc_expr *unit, gfc_expr *c, gfc_expr *status)
     return false;
   if (!kind_value_check (c, 1, gfc_default_character_kind))
     return false;
+  if (strcmp (gfc_current_intrinsic, "fgetc") == 0
+      && !variable_check (c, 1, false))
+    return false;
+  if (arg_strlen_is_zero (c, 1))
+    return false;
 
   if (status == NULL)
     return true;
 
   if (!type_check (status, 2, BT_INTEGER)
       || !kind_value_check (status, 2, gfc_default_integer_kind)
-      || !scalar_check (status, 2))
+      || !scalar_check (status, 2)
+      || !variable_check (status, 2, false))
     return false;
 
   return true;
@@ -5729,13 +5755,19 @@ gfc_check_fgetput_sub (gfc_expr *c, gfc_expr *status)
     return false;
   if (!kind_value_check (c, 0, gfc_default_character_kind))
     return false;
+  if (strcmp (gfc_current_intrinsic, "fget") == 0
+      && !variable_check (c, 0, false))
+    return false;
+  if (arg_strlen_is_zero (c, 0))
+    return false;
 
   if (status == NULL)
     return true;
 
   if (!type_check (status, 1, BT_INTEGER)
       || !kind_value_check (status, 1, gfc_default_integer_kind)
-      || !scalar_check (status, 1))
+      || !scalar_check (status, 1)
+      || !variable_check (status, 1, false))
     return false;
 
   return true;
diff --git a/gcc/fortran/intrinsic.c b/gcc/fortran/intrinsic.c
index 17fd92eb46297..219f04f231709 100644
--- a/gcc/fortran/intrinsic.c
+++ b/gcc/fortran/intrinsic.c
@@ -3460,7 +3460,7 @@ add_subroutines (void)
   /* Argument names.  These are used as argument keywords and so need to
      match the documentation.  Please keep this list in sorted order.  */
   static const char
-    *a = "a", *c = "count", *cm = "count_max", *com = "command",
+    *a = "a", *c_ = "c", *c = "count", *cm = "count_max", *com = "command",
     *cr = "count_rate", *dt = "date", *errmsg = "errmsg", *f = "from",
     *fp = "frompos", *gt = "get", *h = "harvest", *han = "handler",
     *length = "length", *ln = "len", *md = "mode", *msk = "mask",
@@ -3840,12 +3840,12 @@ add_subroutines (void)
   add_sym_3s ("fgetc", GFC_ISYM_FGETC, CLASS_IMPURE, BT_UNKNOWN, 0, GFC_STD_GNU,
 	      gfc_check_fgetputc_sub, NULL, gfc_resolve_fgetc_sub,
 	      ut, BT_INTEGER, di, REQUIRED, INTENT_IN,
-	      c, BT_CHARACTER, dc, REQUIRED, INTENT_OUT,
+	      c_, BT_CHARACTER, dc, REQUIRED, INTENT_OUT,
 	      st, BT_INTEGER, di, OPTIONAL, INTENT_OUT);
 
   add_sym_2s ("fget", GFC_ISYM_FGET, CLASS_IMPURE, BT_UNKNOWN, 0, GFC_STD_GNU,
 	      gfc_check_fgetput_sub, NULL, gfc_resolve_fget_sub,
-	      c, BT_CHARACTER, dc, REQUIRED, INTENT_OUT,
+	      c_, BT_CHARACTER, dc, REQUIRED, INTENT_OUT,
 	      st, BT_INTEGER, di, OPTIONAL, INTENT_OUT);
 
   add_sym_1s ("flush", GFC_ISYM_FLUSH, CLASS_IMPURE, BT_UNKNOWN, 0, GFC_STD_GNU,
@@ -3855,12 +3855,12 @@ add_subroutines (void)
   add_sym_3s ("fputc", GFC_ISYM_FPUTC, CLASS_IMPURE, BT_UNKNOWN, 0, GFC_STD_GNU,
 	      gfc_check_fgetputc_sub, NULL, gfc_resolve_fputc_sub,
 	      ut, BT_INTEGER, di, REQUIRED, INTENT_IN,
-	      c, BT_CHARACTER, dc, REQUIRED, INTENT_IN,
+	      c_, BT_CHARACTER, dc, REQUIRED, INTENT_IN,
 	      st, BT_INTEGER, di, OPTIONAL, INTENT_OUT);
 
   add_sym_2s ("fput", GFC_ISYM_FPUT, CLASS_IMPURE, BT_UNKNOWN, 0, GFC_STD_GNU,
 	      gfc_check_fgetput_sub, NULL, gfc_resolve_fput_sub,
-	      c, BT_CHARACTER, dc, REQUIRED, INTENT_IN,
+	      c_, BT_CHARACTER, dc, REQUIRED, INTENT_IN,
 	      st, BT_INTEGER, di, OPTIONAL, INTENT_OUT);
 
   add_sym_1s ("free", GFC_ISYM_FREE, CLASS_IMPURE, BT_UNKNOWN, 0, GFC_STD_GNU,
diff --git a/gcc/testsuite/gfortran.dg/pr100154.f90 b/gcc/testsuite/gfortran.dg/pr100154.f90
new file mode 100644
index 0000000000000..3a1489aaab8af
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/pr100154.f90
@@ -0,0 +1,26 @@
+! { dg-do compile }
+! { dg-options "-std=gnu" }
+! PR100154 - ICE in gfc_conv_procedure_call, at fortran/trans-expr.c:6131
+
+program p
+  implicit none
+  integer           :: n
+  character, target :: c
+  character(len=0)  :: c0
+  character(len=:), allocatable :: cc
+  n = fget(cc)
+  n = fget('a')       ! { dg-error "must be a variable" }
+  n = fget(c0)        ! { dg-error "must have length at least 1" }
+  call fget('x')      ! { dg-error "must be a variable" }
+  n = fgetc(5,'a')    ! { dg-error "must be a variable" }
+  call fgetc(5,c0)    ! { dg-error "must have length at least 1" }
+  call fgetc(5,c,1)   ! { dg-error "must be a variable" }
+  call fputc(5,'x',1) ! { dg-error "must be a variable" }
+  n = fget (ptr_returning_func())
+  print *, c
+contains
+  function ptr_returning_func () result (res)
+    character, pointer :: res
+    res => c
+  end
+end

From 5aee8c2a33ae0d3f375ed0ca6e03718b284d2574 Mon Sep 17 00:00:00 2001
From: Harald Anlauf <anlauf@gmx.de>
Date: Sat, 24 Apr 2021 20:38:06 +0200
Subject: [PATCH 014/164] Fortran - allow target of pointer from evaluation of
 function-reference

Fortran allows the target of a pointer from the evaluation of a
function-reference in a variable definition context (e.g. F2018:R902).

gcc/fortran/ChangeLog:

	PR fortran/100218
	* expr.c (gfc_check_vardef_context): Extend check to allow pointer
	from a function reference.

gcc/testsuite/ChangeLog:

	PR fortran/100218
	* gfortran.dg/ptr-func-4.f90: New test.

(cherry picked from commit 32c4d970ea3a9fc330d6aa8fd83f9dae0b9afc64)
---
 gcc/fortran/expr.c                       |  4 +++-
 gcc/testsuite/gfortran.dg/ptr-func-4.f90 | 19 +++++++++++++++++++
 2 files changed, 22 insertions(+), 1 deletion(-)
 create mode 100644 gcc/testsuite/gfortran.dg/ptr-func-4.f90

diff --git a/gcc/fortran/expr.c b/gcc/fortran/expr.c
index 92a6700568d6a..956003ec605e4 100644
--- a/gcc/fortran/expr.c
+++ b/gcc/fortran/expr.c
@@ -6121,7 +6121,9 @@ gfc_check_vardef_context (gfc_expr* e, bool pointer, bool alloc_obj,
     }
   if (!pointer && sym->attr.flavor != FL_VARIABLE
       && !(sym->attr.flavor == FL_PROCEDURE && sym == sym->result)
-      && !(sym->attr.flavor == FL_PROCEDURE && sym->attr.proc_pointer))
+      && !(sym->attr.flavor == FL_PROCEDURE && sym->attr.proc_pointer)
+      && !(sym->attr.flavor == FL_PROCEDURE
+	   && sym->attr.function && sym->attr.pointer))
     {
       if (context)
 	gfc_error ("%qs in variable definition context (%s) at %L is not"
diff --git a/gcc/testsuite/gfortran.dg/ptr-func-4.f90 b/gcc/testsuite/gfortran.dg/ptr-func-4.f90
new file mode 100644
index 0000000000000..62b18f6a93506
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/ptr-func-4.f90
@@ -0,0 +1,19 @@
+! { dg-do run }
+! { dg-options "-O2 -std=f2008" }
+! PR fortran/100218 - target of pointer from evaluation of function-reference
+
+program p
+  implicit none
+  integer, target :: z = 0
+  call g (f ())
+  if (z /= 1) stop 1
+contains
+  function f () result (r)
+    integer, pointer :: r
+    r => z
+  end function f
+  subroutine g (x)
+    integer, intent(out) :: x
+    x = 1
+  end subroutine g
+end program p

From 9532344edcf77c7c7b0fa5da31c1b9dd2850288e Mon Sep 17 00:00:00 2001
From: Patrick Palka <ppalka@redhat.com>
Date: Sat, 24 Apr 2021 00:14:29 -0400
Subject: [PATCH 015/164] c++: do_class_deduction and dependent init [PR93383]

Here we're crashing during CTAD with a dependent initializer (performed
from convert_template_argument) because one of the initializer's
elements has an empty TREE_TYPE, which ends up making resolve_args
unhappy.

Besides the case where we're initializing one template placeholder
from another, which is already specifically handled earlier in
do_class_deduction, it seems we can't in general correctly resolve a
template placeholder using a dependent initializer, so this patch makes
the function just punt until instantiation time instead.

gcc/cp/ChangeLog:

	PR c++/89565
	PR c++/93383
	PR c++/95291
	PR c++/99200
	PR c++/99683
	* pt.c (do_class_deduction): Punt if the initializer is
	type-dependent.

gcc/testsuite/ChangeLog:

	PR c++/89565
	PR c++/93383
	PR c++/95291
	PR c++/99200
	PR c++/99683
	* g++.dg/cpp2a/nontype-class39.C: Remove dg-ice directive.
	* g++.dg/cpp2a/nontype-class45.C: New test.
	* g++.dg/cpp2a/nontype-class46.C: New test.
	* g++.dg/cpp2a/nontype-class47.C: New test.
	* g++.dg/cpp2a/nontype-class48.C: New test.

(cherry picked from commit bcd77b7b9f35bd5b559ed593c3b3e346c1e6f364)
---
 gcc/cp/pt.c                                  |  4 +++
 gcc/testsuite/g++.dg/cpp2a/nontype-class39.C |  2 --
 gcc/testsuite/g++.dg/cpp2a/nontype-class45.C | 32 +++++++++++++++++
 gcc/testsuite/g++.dg/cpp2a/nontype-class46.C | 11 ++++++
 gcc/testsuite/g++.dg/cpp2a/nontype-class47.C | 11 ++++++
 gcc/testsuite/g++.dg/cpp2a/nontype-class48.C | 36 ++++++++++++++++++++
 6 files changed, 94 insertions(+), 2 deletions(-)
 create mode 100644 gcc/testsuite/g++.dg/cpp2a/nontype-class45.C
 create mode 100644 gcc/testsuite/g++.dg/cpp2a/nontype-class46.C
 create mode 100644 gcc/testsuite/g++.dg/cpp2a/nontype-class47.C
 create mode 100644 gcc/testsuite/g++.dg/cpp2a/nontype-class48.C

diff --git a/gcc/cp/pt.c b/gcc/cp/pt.c
index ada2b63efb92b..d30876ced9c59 100644
--- a/gcc/cp/pt.c
+++ b/gcc/cp/pt.c
@@ -29362,6 +29362,10 @@ do_class_deduction (tree ptype, tree tmpl, tree init,
       return error_mark_node;
     }
 
+  /* Wait until the initializer is non-dependent.  */
+  if (type_dependent_expression_p (init))
+    return ptype;
+
   tree type = TREE_TYPE (tmpl);
 
   bool try_list_ctor = false;
diff --git a/gcc/testsuite/g++.dg/cpp2a/nontype-class39.C b/gcc/testsuite/g++.dg/cpp2a/nontype-class39.C
index 512afad8e4faa..9b4da4f02ea02 100644
--- a/gcc/testsuite/g++.dg/cpp2a/nontype-class39.C
+++ b/gcc/testsuite/g++.dg/cpp2a/nontype-class39.C
@@ -1,7 +1,5 @@
 // PR c++/89565
 // { dg-do compile { target c++20 } }
-// { dg-additional-options "-fchecking" }
-// { dg-ice "resolve_args" }
 
 template <auto>
 struct N{};
diff --git a/gcc/testsuite/g++.dg/cpp2a/nontype-class45.C b/gcc/testsuite/g++.dg/cpp2a/nontype-class45.C
new file mode 100644
index 0000000000000..e7addf5f2912d
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/nontype-class45.C
@@ -0,0 +1,32 @@
+// PR c++/99200
+// { dg-do compile { target c++20 } }
+
+template <int N>
+struct A
+{
+  constexpr A (const char (&s)[N]) { for (int i = 0; i < N; i++) v[i] = s[i]; v[N] = 0; }
+  char v[N + 1];
+};
+
+template <A s>
+struct B
+{
+  constexpr operator const char *() { return s.v; }
+};
+
+template <typename T>
+const char *
+foo ()
+{ 
+  return B<__PRETTY_FUNCTION__>{};
+}
+
+template <typename T>
+const char *
+bar ()
+{ 
+  return B<__FUNCTION__>{};
+}
+
+auto a = foo <int> ();
+auto b = bar <double> ();
diff --git a/gcc/testsuite/g++.dg/cpp2a/nontype-class46.C b/gcc/testsuite/g++.dg/cpp2a/nontype-class46.C
new file mode 100644
index 0000000000000..d91e800424fcf
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/nontype-class46.C
@@ -0,0 +1,11 @@
+// PR c++/93383
+// { dg-do compile { target c++20 } }
+
+template <int> struct A {};
+
+template <A a> struct B {
+  void foo(B<+a>);
+  void bar(B<a.x>);
+  template <class T> using type = B<T{}>;
+  template <class> static inline auto y = A{0}; // { dg-error "deduction|no match" }
+};
diff --git a/gcc/testsuite/g++.dg/cpp2a/nontype-class47.C b/gcc/testsuite/g++.dg/cpp2a/nontype-class47.C
new file mode 100644
index 0000000000000..1f31b9bd53067
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/nontype-class47.C
@@ -0,0 +1,11 @@
+// PR c++/95291
+// { dg-do compile { target c++20 } }
+
+template <typename T = int>
+class xy { };
+
+template <xy _size>
+struct window_root { };
+
+template <typename minion>
+struct flip_horizontally : window_root<minion::size> { };
diff --git a/gcc/testsuite/g++.dg/cpp2a/nontype-class48.C b/gcc/testsuite/g++.dg/cpp2a/nontype-class48.C
new file mode 100644
index 0000000000000..9024436cad85e
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/nontype-class48.C
@@ -0,0 +1,36 @@
+// PR c++/99683
+// { dg-do compile { target c++20 } }
+
+template<auto V>
+struct nttp_tag {};
+
+template<typename T>
+struct type_tag {};
+
+
+/************************************************/
+template<bool is_type>
+struct use_ctad
+{
+    template<auto V> requires (!is_type)
+    constexpr use_ctad(nttp_tag<V>) {}
+};
+
+template<auto V>
+use_ctad(nttp_tag<V>) -> use_ctad<false>;
+
+/**********************************************/
+template<use_ctad t>
+struct wrapper 
+{
+    template<typename Tag>
+    wrapper(Tag);
+};
+
+template<typename Tag>
+wrapper(Tag) -> wrapper<use_ctad{Tag()}>;
+
+int main()
+{
+    wrapper t{nttp_tag<42>{}};
+}

From c6a94ee07e378632c4fcea2eead30a18ce15a6c3 Mon Sep 17 00:00:00 2001
From: Patrick Palka <ppalka@redhat.com>
Date: Tue, 27 Apr 2021 14:07:46 -0400
Subject: [PATCH 016/164] libstdc++: Fix up lambda in
 join_view::_Iterator::operator++ [PR100290]

Currently, the return type of this lambda is decltype(auto), so the
lambda ends up returning a copy of _M_parent->_M_inner rather than a
reference to it when _S_ref_glvalue is false.  This means _M_inner and
ranges::end(__inner_range) are respectively an iterator and sentinel for
different ranges, so comparing them is undefined.

libstdc++-v3/ChangeLog:

	PR libstdc++/100290
	* include/std/ranges (join_view::_Iterator::operator++): Correct
	the return type of the lambda to avoid returning a copy of
	_M_parent->_M_inner.
	* testsuite/std/ranges/adaptors/join.cc (test10): New test.

(cherry picked from commit 85ef4b8d4eb3313a48b79c7e752891f9646bb246)
---
 libstdc++-v3/include/std/ranges                    |  2 +-
 libstdc++-v3/testsuite/std/ranges/adaptors/join.cc | 11 +++++++++++
 2 files changed, 12 insertions(+), 1 deletion(-)

diff --git a/libstdc++-v3/include/std/ranges b/libstdc++-v3/include/std/ranges
index 74075a2d6d38a..09115e9b45f99 100644
--- a/libstdc++-v3/include/std/ranges
+++ b/libstdc++-v3/include/std/ranges
@@ -2389,7 +2389,7 @@ namespace views::__adaptor
 	  constexpr _Iterator&
 	  operator++()
 	  {
-	    auto&& __inner_range = [this] () -> decltype(auto) {
+	    auto&& __inner_range = [this] () -> auto&& {
 	      if constexpr (_S_ref_is_glvalue)
 		return *_M_outer;
 	      else
diff --git a/libstdc++-v3/testsuite/std/ranges/adaptors/join.cc b/libstdc++-v3/testsuite/std/ranges/adaptors/join.cc
index fb06a7698afc1..e6c71d771ded9 100644
--- a/libstdc++-v3/testsuite/std/ranges/adaptors/join.cc
+++ b/libstdc++-v3/testsuite/std/ranges/adaptors/join.cc
@@ -160,6 +160,16 @@ test09()
   static_assert(!requires { 0 | join; });
 }
 
+void
+test10()
+{
+  // PR libstdc++/100290
+  auto v = views::single(0)
+    | views::transform([](const auto& s) { return views::single(s); })
+    | views::join;
+  VERIFY( ranges::next(v.begin()) == v.end() );
+}
+
 int
 main()
 {
@@ -172,4 +182,5 @@ main()
   test07();
   test08();
   test09();
+  test10();
 }

From a8cc9bd2da9773a3d0230a132f6a7a309bb0ca2d Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Wed, 28 Apr 2021 00:18:15 +0000
Subject: [PATCH 017/164] Daily bump.

---
 contrib/ChangeLog       |  7 +++
 gcc/ChangeLog           | 58 +++++++++++++++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/cp/ChangeLog        | 35 +++++++++++++++
 gcc/fortran/ChangeLog   | 24 +++++++++++
 gcc/testsuite/ChangeLog | 94 +++++++++++++++++++++++++++++++++++++++++
 libgcc/ChangeLog        | 11 +++++
 libgomp/ChangeLog       | 15 +++++++
 libstdc++-v3/ChangeLog  | 11 +++++
 9 files changed, 256 insertions(+), 1 deletion(-)

diff --git a/contrib/ChangeLog b/contrib/ChangeLog
index 0a7104aea15ba..fe2e2763aa5cb 100644
--- a/contrib/ChangeLog
+++ b/contrib/ChangeLog
@@ -1,3 +1,10 @@
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	* gennews (files): Add files for GCC 10 and GCC 11.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 85d4f6d546b11..be1611a62d9aa 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,61 @@
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/100200
+	* config/aarch64/aarch64.c (aarch64_print_operand): Cast -UINTVAL
+	back to HOST_WIDE_INT.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/100200
+	* config/aarch64/predicates.md (aarch64_sub_immediate,
+	aarch64_plus_immediate): Use -UINTVAL instead of -INTVAL.
+	* config/aarch64/aarch64.md (casesi, rotl<mode>3): Likewise.
+	* config/aarch64/aarch64.c (aarch64_print_operand,
+	aarch64_split_atomic_op, aarch64_expand_subvti): Likewise.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/100239
+	* tree-vect-generic.c (lower_vec_perm): Don't accept constant
+	permutations with all indices from the first zero element as vec_shl.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR rtl-optimization/100254
+	* cfgcleanup.c (outgoing_edges_match): Check REG_EH_REGION on
+	last1 and last2 insns rather than BB_END (bb1) and BB_END (bb2) insns.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-26  Jakub Jelinek  <jakub@redhat.com>
+
+	PR debug/100255
+	* vmsdbgout.c (ASM_OUTPUT_DEBUG_STRING, vmsdbgout_begin_block,
+	vmsdbgout_end_block, lookup_filename, vmsdbgout_source_line): Remove
+	register keywords.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-21  Jakub Jelinek  <jakub@redhat.com>
+
+	PR rtl-optimization/100148
+	* cprop.c (constprop_register): Use next_nondebug_insn instead of
+	NEXT_INSN.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index f347a06c33428..5bc3f0e75f04b 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210427
+20210428
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 4b536fa4474c6..15b44f3585408 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,38 @@
+2021-04-27  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2021-04-24  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/89565
+	PR c++/93383
+	PR c++/95291
+	PR c++/99200
+	PR c++/99683
+	* pt.c (do_class_deduction): Punt if the initializer is
+	type-dependent.
+
+2021-04-27  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2021-04-22  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/100161
+	* pt.c (tsubst_copy_and_build) <case PLUS_EXPR>: Test op0 and
+	op1 separately for value- or type-dependence.
+
+2021-04-27  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2021-04-21  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/96380
+	* parser.c (cp_parser_enum_specifier): Don't allow defining
+	types in enum-base.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	* module.cc: Remove #error that triggers if DEV-PHASE is empty.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index 0e8580b40af38..1a552875160a3 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,27 @@
+2021-04-27  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2021-04-24  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/100218
+	* expr.c (gfc_check_vardef_context): Extend check to allow pointer
+	from a function reference.
+
+2021-04-27  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2021-04-24  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/100154
+	* check.c (variable_check): Allow function reference having a data
+	pointer result.
+	(arg_strlen_is_zero): New function.
+	(gfc_check_fgetputc_sub): Add static check of character and status
+	arguments.
+	(gfc_check_fgetput_sub): Likewise.
+	* intrinsic.c (add_subroutines): Fix argument name for the
+	character argument to intrinsic subroutines fget[c], fput[c].
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index c181744f655fe..aef2d12433222 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,97 @@
+2021-04-27  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2021-04-24  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/89565
+	PR c++/93383
+	PR c++/95291
+	PR c++/99200
+	PR c++/99683
+	* g++.dg/cpp2a/nontype-class39.C: Remove dg-ice directive.
+	* g++.dg/cpp2a/nontype-class45.C: New test.
+	* g++.dg/cpp2a/nontype-class46.C: New test.
+	* g++.dg/cpp2a/nontype-class47.C: New test.
+	* g++.dg/cpp2a/nontype-class48.C: New test.
+
+2021-04-27  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2021-04-24  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/100218
+	* gfortran.dg/ptr-func-4.f90: New test.
+
+2021-04-27  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2021-04-24  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/100154
+	* gfortran.dg/pr100154.f90: New test.
+
+2021-04-27  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2021-04-22  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/100161
+	* g++.dg/warn/Wtype-limits6.C: New test.
+
+2021-04-27  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2021-04-21  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/96380
+	* g++.dg/cpp0x/enum_base4.C: New test.
+	* g++.dg/cpp0x/enum_base5.C: New test.
+
+2021-04-27  Michael Meissner  <meissner@linux.ibm.com>
+
+	PR target/98952
+	* gcc.target/powerpc/pr98952.c: New test.  Test backported from
+	trunk change on 4/23, 886b6c1e8af502b69e3f318b9830b73b88215878.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/100239
+	* gcc.dg/pr100239.c: New test.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR rtl-optimization/100254
+	* g++.dg/opt/pr100254.C: New test.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-21  Jakub Jelinek  <jakub@redhat.com>
+
+	* g++.dg/cpp1z/constexpr-lambda26.C: Add dg-additional-options
+	-fchecking.
+	* g++.dg/cpp1y/auto-fn61.C: Likewise.
+	* g++.dg/cpp2a/nontype-class39.C: Likewise.
+	* g++.dg/cpp0x/constexpr-52830.C: Likewise.
+	* g++.dg/cpp0x/vt-88982.C: Likewise.
+	* c-c++-common/goacc/kernels-decompose-ice-1.c: Add -fchecking to
+	dg-additional-options.
+	* c-c++-common/goacc/kernels-decompose-ice-2.c: Likewise.
+
+2021-04-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-21  Jakub Jelinek  <jakub@redhat.com>
+
+	PR rtl-optimization/100148
+	* g++.dg/opt/pr100148.C: New test.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/libgcc/ChangeLog b/libgcc/ChangeLog
index b99bb2516af87..fae5149f07eba 100644
--- a/libgcc/ChangeLog
+++ b/libgcc/ChangeLog
@@ -1,3 +1,14 @@
+2021-04-27  Michael Meissner  <meissner@linux.ibm.com>
+
+	PR target/98952
+	* config/rs6000/tramp.S (__trampoline_setup, elfv1 #ifdef): Fix
+	trampoline size comparison in 32-bit by reversing test and
+	combining load immediate with compare.  Fix backported from trunk
+	change on 4/23, 886b6c1e8af502b69e3f318b9830b73b88215878.
+	(__trampoline_setup, elfv2 #ifdef): Fix trampoline size comparison
+	in 32-bit by reversing test and combining load immediate with
+	compare.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
index a58d590216d88..f987714219193 100644
--- a/libgomp/ChangeLog
+++ b/libgomp/ChangeLog
@@ -1,3 +1,18 @@
+2021-04-27  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-04-21  Tobias Burnus  <tobias@codesourcery.com>
+
+	* testsuite/lib/libgomp.exp (offload_target_to_openacc_device_type):
+	New, based on check_effective_target_offload_target_nvptx.
+	(check_effective_target_offload_target_nvptx): Call it.
+	(check_effective_target_offload_target_amdgcn): New.
+	* testsuite/libgomp.c-c++-common/function-not-offloaded.c:
+	Require target offload_target_nvptx || offload_target_amdgcn.
+	* testsuite/libgomp.c-c++-common/variable-not-offloaded.c: Likewise.
+	* testsuite/libgomp.c/pr86416-1.c: Likewise.
+	* testsuite/libgomp.c/pr86416-2.c: Likewise.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 4cf343403a110..a65b843c4a3be 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,14 @@
+2021-04-27  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2021-04-27  Patrick Palka  <ppalka@redhat.com>
+
+	PR libstdc++/100290
+	* include/std/ranges (join_view::_Iterator::operator++): Correct
+	the return type of the lambda to avoid returning a copy of
+	_M_parent->_M_inner.
+	* testsuite/std/ranges/adaptors/join.cc (test10): New test.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.

From 2b43cf037f5b62057c3b6f9eb36be57d2f7bab86 Mon Sep 17 00:00:00 2001
From: "Cui,Lili" <lili.cui@intel.com>
Date: Sat, 24 Apr 2021 11:52:17 +0800
Subject: [PATCH 018/164] Synchronize Rocket Lake's processor_names and
 processor_cost_table with processor_type

gcc/ChangeLog

	* common/config/i386/i386-common.c (processor_names):
	Sync processor_names with processor_type.
	* config/i386/i386-options.c (processor_cost_table):
	Sync processor_cost_table with processor_type.
---
 gcc/common/config/i386/i386-common.c | 2 +-
 gcc/config/i386/i386-options.c       | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/gcc/common/config/i386/i386-common.c b/gcc/common/config/i386/i386-common.c
index 1e6c1590ac4e0..6a7b5c8312fb0 100644
--- a/gcc/common/config/i386/i386-common.c
+++ b/gcc/common/config/i386/i386-common.c
@@ -1743,13 +1743,13 @@ const char *const processor_names[] =
   "skylake-avx512",
   "cannonlake",
   "icelake-client",
-  "rocketlake",
   "icelake-server",
   "cascadelake",
   "tigerlake",
   "cooperlake",
   "sapphirerapids",
   "alderlake",
+  "rocketlake",
   "intel",
   "geode",
   "k6",
diff --git a/gcc/config/i386/i386-options.c b/gcc/config/i386/i386-options.c
index 91da2849c4981..a58968790a30b 100644
--- a/gcc/config/i386/i386-options.c
+++ b/gcc/config/i386/i386-options.c
@@ -726,12 +726,12 @@ static const struct processor_costs *processor_cost_table[] =
   &icelake_cost,
   &icelake_cost,
   &icelake_cost,
-  &icelake_cost,
   &skylake_cost,
   &icelake_cost,
   &skylake_cost,
   &icelake_cost,
   &icelake_cost,
+  &icelake_cost,
   &intel_cost,
   &geode_cost,
   &k6_cost,

From c03f3077b1517a01c917f75179100f9d10b39156 Mon Sep 17 00:00:00 2001
From: Uros Bizjak <ubizjak@gmail.com>
Date: Wed, 28 Apr 2021 12:30:04 +0200
Subject: [PATCH 019/164] i386: Fix atomic FP peepholes [PR100182]
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

64bit loads to/stores from x87 and SSE registers are atomic also on 32-bit
targets, so there is no need for additional atomic moves to a temporary
register.

Introduced load peephole2 patterns assume that there won't be any additional
loads from the load location outside the peepholed sequence and wrongly
removed the source location initialization.

OTOH, introduced store peephole2 patterns assume there won't be any additional
loads from the stored location outside the peepholed sequence and wrongly
removed the destination location initialization.  Note that we can't use plain
x87 FST instruction to initialize destination location because FST converts
the value to the double-precision format, changing bits during move.

The patch restores removed initializations in load and store patterns.
Additionally, plain x87 FST in store peephole2 patterns is prevented by
limiting the store operand source to SSE registers.

2021-04-27  Uroš Bizjak  <ubizjak@gmail.com>

gcc/
	PR target/100182
	* config/i386/sync.md (FILD_ATOMIC/FIST_ATOMIC FP load peephole2):
	Copy operand 3 to operand 4.  Use sse_reg_operand
	as operand 3 predicate.
	(FILD_ATOMIC/FIST_ATOMIC FP load peephole2 with mem blockage): Ditto.
	(LDX_ATOMIC/STX_ATOMIC FP load peephole2): Ditto.
	(LDX_ATOMIC/LDX_ATOMIC FP load peephole2 with mem blockage): Ditto.
	(FILD_ATOMIC/FIST_ATOMIC FP store peephole2):
	Copy operand 1 to operand 0.
	(FILD_ATOMIC/FIST_ATOMIC FP store peephole2 with mem blockage): Ditto.
	(LDX_ATOMIC/STX_ATOMIC FP store peephole2): Ditto.
	(LDX_ATOMIC/LDX_ATOMIC FP store peephole2 with mem blockage): Ditto.

gcc/testsuite/
	PR target/100182
	* gcc.target/i386/pr100182.c: New test.
	* gcc.target/i386/pr71245-1.c (dg-final): Xfail scan-assembler-not.
	* gcc.target/i386/pr71245-2.c (dg-final): Ditto.
---
 gcc/config/i386/sync.md                   | 24 ++++++++++++------
 gcc/testsuite/gcc.target/i386/pr100182.c  | 30 +++++++++++++++++++++++
 gcc/testsuite/gcc.target/i386/pr71245-1.c |  2 +-
 gcc/testsuite/gcc.target/i386/pr71245-2.c |  2 +-
 4 files changed, 48 insertions(+), 10 deletions(-)
 create mode 100644 gcc/testsuite/gcc.target/i386/pr100182.c

diff --git a/gcc/config/i386/sync.md b/gcc/config/i386/sync.md
index c7c508c8de860..7913b918796ae 100644
--- a/gcc/config/i386/sync.md
+++ b/gcc/config/i386/sync.md
@@ -226,12 +226,13 @@
    (set (match_operand:DI 2 "memory_operand")
 	(unspec:DI [(match_dup 0)]
 		   UNSPEC_FIST_ATOMIC))
-   (set (match_operand:DF 3 "any_fp_register_operand")
+   (set (match_operand:DF 3 "sse_reg_operand")
 	(match_operand:DF 4 "memory_operand"))]
   "!TARGET_64BIT
    && peep2_reg_dead_p (2, operands[0])
    && rtx_equal_p (XEXP (operands[4], 0), XEXP (operands[2], 0))"
-  [(set (match_dup 3) (match_dup 5))]
+  [(set (match_dup 3) (match_dup 5))
+   (set (match_dup 4) (match_dup 3))]
   "operands[5] = gen_lowpart (DFmode, operands[1]);")
 
 (define_peephole2
@@ -243,7 +244,7 @@
 		   UNSPEC_FIST_ATOMIC))
    (set (mem:BLK (scratch:SI))
 	(unspec:BLK [(mem:BLK (scratch:SI))] UNSPEC_MEMORY_BLOCKAGE))
-   (set (match_operand:DF 3 "any_fp_register_operand")
+   (set (match_operand:DF 3 "sse_reg_operand")
 	(match_operand:DF 4 "memory_operand"))]
   "!TARGET_64BIT
    && peep2_reg_dead_p (2, operands[0])
@@ -251,6 +252,7 @@
   [(const_int 0)]
 {
   emit_move_insn (operands[3], gen_lowpart (DFmode, operands[1]));
+  emit_move_insn (operands[4], operands[3]);
   emit_insn (gen_memory_blockage ());
   DONE;
 })
@@ -262,12 +264,13 @@
    (set (match_operand:DI 2 "memory_operand")
 	(unspec:DI [(match_dup 0)]
 		   UNSPEC_STX_ATOMIC))
-   (set (match_operand:DF 3 "any_fp_register_operand")
+   (set (match_operand:DF 3 "sse_reg_operand")
 	(match_operand:DF 4 "memory_operand"))]
   "!TARGET_64BIT
    && peep2_reg_dead_p (2, operands[0])
    && rtx_equal_p (XEXP (operands[4], 0), XEXP (operands[2], 0))"
-  [(set (match_dup 3) (match_dup 5))]
+  [(set (match_dup 3) (match_dup 5))
+   (set (match_dup 4) (match_dup 3))]
   "operands[5] = gen_lowpart (DFmode, operands[1]);")
 
 (define_peephole2
@@ -279,7 +282,7 @@
 		   UNSPEC_STX_ATOMIC))
    (set (mem:BLK (scratch:SI))
 	(unspec:BLK [(mem:BLK (scratch:SI))] UNSPEC_MEMORY_BLOCKAGE))
-   (set (match_operand:DF 3 "any_fp_register_operand")
+   (set (match_operand:DF 3 "sse_reg_operand")
 	(match_operand:DF 4 "memory_operand"))]
   "!TARGET_64BIT
    && peep2_reg_dead_p (2, operands[0])
@@ -287,6 +290,7 @@
   [(const_int 0)]
 {
   emit_move_insn (operands[3], gen_lowpart (DFmode, operands[1]));
+  emit_move_insn (operands[4], operands[3]);
   emit_insn (gen_memory_blockage ());
   DONE;
 })
@@ -392,7 +396,8 @@
   "!TARGET_64BIT
    && peep2_reg_dead_p (3, operands[2])
    && rtx_equal_p (XEXP (operands[0], 0), XEXP (operands[3], 0))"
-  [(set (match_dup 5) (match_dup 1))]
+  [(set (match_dup 0) (match_dup 1))
+   (set (match_dup 5) (match_dup 1))]
   "operands[5] = gen_lowpart (DFmode, operands[4]);")
 
 (define_peephole2
@@ -411,6 +416,7 @@
    && rtx_equal_p (XEXP (operands[0], 0), XEXP (operands[3], 0))"
   [(const_int 0)]
 {
+  emit_move_insn (operands[0], operands[1]);
   emit_insn (gen_memory_blockage ());
   emit_move_insn (gen_lowpart (DFmode, operands[4]), operands[1]);
   DONE;
@@ -428,7 +434,8 @@
   "!TARGET_64BIT
    && peep2_reg_dead_p (3, operands[2])
    && rtx_equal_p (XEXP (operands[0], 0), XEXP (operands[3], 0))"
-  [(set (match_dup 5) (match_dup 1))]
+  [(set (match_dup 0) (match_dup 1))
+   (set (match_dup 5) (match_dup 1))]
   "operands[5] = gen_lowpart (DFmode, operands[4]);")
 
 (define_peephole2
@@ -447,6 +454,7 @@
    && rtx_equal_p (XEXP (operands[0], 0), XEXP (operands[3], 0))"
   [(const_int 0)]
 {
+  emit_move_insn (operands[0], operands[1]);
   emit_insn (gen_memory_blockage ());
   emit_move_insn (gen_lowpart (DFmode, operands[4]), operands[1]);
   DONE;
diff --git a/gcc/testsuite/gcc.target/i386/pr100182.c b/gcc/testsuite/gcc.target/i386/pr100182.c
new file mode 100644
index 0000000000000..2f92a04db7306
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/pr100182.c
@@ -0,0 +1,30 @@
+/* { dg-do run { target ia32 } } */
+/* { dg-options "-O2 -march=i686" } */
+
+struct S { double _M_fp; };
+union U { double d; unsigned long long int l; };
+
+void
+__attribute__((noipa))
+foo (void)
+{
+  struct S a0, a1;
+  union U u;
+  double d0, d1;
+  a0._M_fp = 0.0;
+  a1._M_fp = 1.0;
+  __atomic_store_8 (&a0._M_fp, __atomic_load_8 (&a1._M_fp, __ATOMIC_SEQ_CST), __ATOMIC_SEQ_CST);
+  u.l = __atomic_load_8 (&a0._M_fp, __ATOMIC_SEQ_CST);
+  d0 = u.d;
+  u.l = __atomic_load_8 (&a1._M_fp, __ATOMIC_SEQ_CST);
+  d1 = u.d;
+  if (d0 != d1)
+    __builtin_abort ();
+}
+
+int
+main ()
+{
+  foo ();
+  return 0;
+}
diff --git a/gcc/testsuite/gcc.target/i386/pr71245-1.c b/gcc/testsuite/gcc.target/i386/pr71245-1.c
index be0b7602a8cff..02c0dcb80b659 100644
--- a/gcc/testsuite/gcc.target/i386/pr71245-1.c
+++ b/gcc/testsuite/gcc.target/i386/pr71245-1.c
@@ -19,4 +19,4 @@ void foo_d (void)
   __atomic_store_n (&d.ll, tmp.ll, __ATOMIC_SEQ_CST);
 }
 
-/* { dg-final { scan-assembler-not "(fistp|fild)" } } */
+/* { dg-final { scan-assembler-not "(fistp|fild)" { xfail *-*-* } } } */
diff --git a/gcc/testsuite/gcc.target/i386/pr71245-2.c b/gcc/testsuite/gcc.target/i386/pr71245-2.c
index 65c139849d539..bf37a8cbb7138 100644
--- a/gcc/testsuite/gcc.target/i386/pr71245-2.c
+++ b/gcc/testsuite/gcc.target/i386/pr71245-2.c
@@ -19,4 +19,4 @@ void foo_d (void)
   __atomic_store_n (&d.ll, tmp.ll, __ATOMIC_SEQ_CST);
 }
 
-/* { dg-final { scan-assembler-not "movlps" } } */
+/* { dg-final { scan-assembler-not "movlps" { xfail *-*-* } } } */

From ac66ed554ade771ff0897f5c414ad303c9def1af Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Wed, 28 Apr 2021 13:06:06 +0200
Subject: [PATCH 020/164] Revert "libstdc++: Add workaround for ia32 floating
 atomics miscompilations [PR100184]"

This reverts commit a21f3b38c3b9a5c28c79be37b040e7d06d827d76.
---
 libstdc++-v3/testsuite/29_atomics/atomic_float/1.cc           | 1 -
 libstdc++-v3/testsuite/29_atomics/atomic_float/wait_notify.cc | 1 -
 2 files changed, 2 deletions(-)

diff --git a/libstdc++-v3/testsuite/29_atomics/atomic_float/1.cc b/libstdc++-v3/testsuite/29_atomics/atomic_float/1.cc
index 797d3b7ecbe81..b2008368a95a7 100644
--- a/libstdc++-v3/testsuite/29_atomics/atomic_float/1.cc
+++ b/libstdc++-v3/testsuite/29_atomics/atomic_float/1.cc
@@ -18,7 +18,6 @@
 // { dg-add-options ieee }
 // { dg-options "-std=gnu++2a" }
 // { dg-do run { target c++2a } }
-// { dg-xfail-run-if "PR100182" { ia32 } }
 
 #include <atomic>
 #include <testsuite_hooks.h>
diff --git a/libstdc++-v3/testsuite/29_atomics/atomic_float/wait_notify.cc b/libstdc++-v3/testsuite/29_atomics/atomic_float/wait_notify.cc
index e0ff34dbf24d9..01768da290b75 100644
--- a/libstdc++-v3/testsuite/29_atomics/atomic_float/wait_notify.cc
+++ b/libstdc++-v3/testsuite/29_atomics/atomic_float/wait_notify.cc
@@ -2,7 +2,6 @@
 // { dg-do run { target c++2a } }
 // { dg-require-gthreads "" }
 // { dg-additional-options "-pthread" { target pthread } }
-// { dg-skip-if "PR100182" { ia32 } }
 // { dg-add-options libatomic }
 
 // Copyright (C) 2020-2021 Free Software Foundation, Inc.

From 100cc845cda3843e87f152f845b11b70fee3d7bc Mon Sep 17 00:00:00 2001
From: Richard Earnshaw <rearnsha@arm.com>
Date: Tue, 27 Apr 2021 12:25:30 +0100
Subject: [PATCH 021/164] arm: fix UB when compiling thumb2 with PIC [PR100236]

arm_compute_save_core_reg_mask contains UB in that the saved PIC
register number is used to create a bit mask. However, for some target
options this register is undefined and we end up with a shift of ~0.

On native compilations this is benign since the shift will still be
large enough to move the bit outside of the range of the mask, but if
cross compiling from a system that truncates out-of-range shifts to
zero (or worse, raises a trap for such values) we'll get potentially
wrong code (or a fault).

gcc:
	PR target/100236
	* config/arm/arm.c (THUMB2_WORK_REGS): Check PIC_OFFSET_TABLE_REGNUM
	is valid before including it in the mask.
(cherry picked from commit 01d0bda8bdf3cd804e1e00915d432ad0cdc49399)
---
 gcc/config/arm/arm.c | 10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/gcc/config/arm/arm.c b/gcc/config/arm/arm.c
index 340f7c95d76b8..352b2cd6e8392 100644
--- a/gcc/config/arm/arm.c
+++ b/gcc/config/arm/arm.c
@@ -1051,9 +1051,13 @@ const char *fp_sysreg_names[NB_FP_SYSREGS] = {
 #define ARM_LSL_NAME "lsl"
 #define streq(string1, string2) (strcmp (string1, string2) == 0)
 
-#define THUMB2_WORK_REGS (0xff & ~(  (1 << THUMB_HARD_FRAME_POINTER_REGNUM) \
-				   | (1 << SP_REGNUM) | (1 << PC_REGNUM) \
-				   | (1 << PIC_OFFSET_TABLE_REGNUM)))
+#define THUMB2_WORK_REGS					\
+  (0xff & ~((1 << THUMB_HARD_FRAME_POINTER_REGNUM)		\
+	    | (1 << SP_REGNUM)					\
+	    | (1 << PC_REGNUM)					\
+	    | (PIC_OFFSET_TABLE_REGNUM != INVALID_REGNUM	\
+	       ? (1 << PIC_OFFSET_TABLE_REGNUM)			\
+	       : 0)))
 
 /* Initialization code.  */
 

From aae5106525d850c5f3ae8265374ead16c5e0a9b7 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Wed, 28 Apr 2021 12:45:49 +0100
Subject: [PATCH 022/164] libstdc++: Add missing noexcept on std::thread member
 function [PR 100298]

The new inline definition of std::thread::hardware_concurrency() for
non-gthreads targets is missing the noexcept-specifier that is on the
declaration.

libstdc++-v3/ChangeLog:

	PR libstdc++/100298
	* include/bits/std_thread.h (thread::hardware_concurrency): Add
	missing noexcept to inline definition for non-gthreads targets.

(cherry picked from commit 5cc28000cfcc219fb4c45dbc5388ec05109049af)
---
 libstdc++-v3/include/bits/std_thread.h | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/libstdc++-v3/include/bits/std_thread.h b/libstdc++-v3/include/bits/std_thread.h
index 70cb31a533153..2a500bf177728 100644
--- a/libstdc++-v3/include/bits/std_thread.h
+++ b/libstdc++-v3/include/bits/std_thread.h
@@ -270,7 +270,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 #ifndef _GLIBCXX_HAS_GTHREADS
   inline void thread::join() { std::__throw_system_error(EINVAL); }
   inline void thread::detach() { std::__throw_system_error(EINVAL); }
-  inline unsigned int thread::hardware_concurrency() { return 0; }
+  inline unsigned int thread::hardware_concurrency() noexcept { return 0; }
 #endif
 
   inline void

From 76c6c7261c62ff36570412f61cea7d68ff946184 Mon Sep 17 00:00:00 2001
From: YiFei Zhu <zhuyifei1999@gmail.com>
Date: Thu, 22 Apr 2021 05:05:56 -0500
Subject: [PATCH 023/164] bpf: align function entry point to 64 bits

Libbpf does not treat paddings after functions well. If function
symbols does not cover a whole text section, it will emit error
similar to:

  libbpf: sec '.text': failed to find program symbol at offset 56

Each instruction in BPF is a multiple of 8 bytes, so align the
functions to 8 bytes, similar to how clang does it.

2021-04-22  YiFei Zhu  <zhuyifei1999@gmail.com>

gcc/

	* config/bpf/bpf.h (FUNCTION_BOUNDARY): Set to 64.

(cherry picked from commit 0a662e103e911af935aa5c601051c135986ce3de)
---
 gcc/config/bpf/bpf.h | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gcc/config/bpf/bpf.h b/gcc/config/bpf/bpf.h
index 9e2f5260900ec..6a3907fb61816 100644
--- a/gcc/config/bpf/bpf.h
+++ b/gcc/config/bpf/bpf.h
@@ -57,8 +57,8 @@
    64-bit at any time.  */
 #define STACK_BOUNDARY 64
 
-/* Function entry points are aligned to 128 bits.  */
-#define FUNCTION_BOUNDARY 128
+/* Function entry points are aligned to 64 bits.  */
+#define FUNCTION_BOUNDARY 64
 
 /* Maximum alignment required by data of any type.  */
 #define BIGGEST_ALIGNMENT 64

From 6f60fd21fd4adfd76e637178f639ee7a9e8e8fd5 Mon Sep 17 00:00:00 2001
From: YiFei Zhu <zhuyifei1999@gmail.com>
Date: Thu, 22 Apr 2021 05:05:57 -0500
Subject: [PATCH 024/164] bpf: allow BSS symbols to be global symbols

Prior to this, a BSS declaration such as:

  int foo;
  static int bar;

Generates:

  .global foo
  .local  foo
  .comm   foo,4,4
  .local  bar
  .comm	  bar,4,4

Creating symbols:

  0000000000000000 b foo
  0000000000000004 b bar

Both symbols are local. However, libbpf bpf_object__variable_offset
rquires symbols to be STB_GLOBAL & STT_OBJECT for data section lookup.
This patch makes the same declaration generate:

  .global foo
  .type   foo, @object
  .lcomm  foo,4,4
  .local  bar
  .comm   bar,4,4

Creating symbols:

  0000000000000000 B foo
  0000000000000004 b bar

And libbpf will be okay with looking up the global symbol "foo".

2021-04-22  YiFei Zhu  <zhuyifei1999@gmail.com>

gcc/

	* config/bpf/bpf.h (ASM_OUTPUT_ALIGNED_BSS): Use .type and .lcomm.

(cherry picked from commit 886b6c1e8af502b69e3f318b9830b73b88215878)
---
 gcc/config/bpf/bpf.h | 12 +++++++++---
 1 file changed, 9 insertions(+), 3 deletions(-)

diff --git a/gcc/config/bpf/bpf.h b/gcc/config/bpf/bpf.h
index 6a3907fb61816..4c5b19e262b98 100644
--- a/gcc/config/bpf/bpf.h
+++ b/gcc/config/bpf/bpf.h
@@ -422,9 +422,15 @@ enum reg_class
    Try to use asm_output_aligned_bss to implement this macro.  */
 
 #define ASM_OUTPUT_ALIGNED_BSS(FILE, DECL, NAME, SIZE, ALIGN)	\
-  do {								\
-    ASM_OUTPUT_ALIGNED_LOCAL (FILE, NAME, SIZE, ALIGN);		\
-  } while (0)
+  do									\
+    {									\
+      ASM_OUTPUT_TYPE_DIRECTIVE (FILE, NAME, "object");			\
+      fprintf ((FILE), "%s", "\t.lcomm\t");				\
+      assemble_name ((FILE), (NAME));					\
+      fprintf ((FILE), "," HOST_WIDE_INT_PRINT_UNSIGNED ",%u\n",	\
+	       (SIZE), (ALIGN) / BITS_PER_UNIT);			\
+    }									\
+  while (0)
 
 /*** Output and Generation of Labels.  */
 

From 6590e4ae7c8192db53d9d4b85524948d88609ddb Mon Sep 17 00:00:00 2001
From: Joseph Myers <joseph@codesourcery.com>
Date: Wed, 28 Apr 2021 19:57:18 +0000
Subject: [PATCH 025/164] Update gcc .po files.

	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
	ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
	zh_TW.po: Update.
---
 gcc/po/be.po    | 11208 +++++++++++++++++++++--------------------
 gcc/po/da.po    | 11243 ++++++++++++++++++++---------------------
 gcc/po/de.po    | 11232 ++++++++++++++++++++---------------------
 gcc/po/el.po    | 11209 +++++++++++++++++++++--------------------
 gcc/po/es.po    | 11242 ++++++++++++++++++++---------------------
 gcc/po/fi.po    | 11222 ++++++++++++++++++++---------------------
 gcc/po/fr.po    | 11257 ++++++++++++++++++++---------------------
 gcc/po/hr.po    | 11207 +++++++++++++++++++++--------------------
 gcc/po/id.po    | 11235 ++++++++++++++++++++---------------------
 gcc/po/ja.po    | 11227 +++++++++++++++++++++--------------------
 gcc/po/nl.po    | 11218 +++++++++++++++++++++--------------------
 gcc/po/ru.po    | 11238 ++++++++++++++++++++---------------------
 gcc/po/sr.po    | 11235 ++++++++++++++++++++---------------------
 gcc/po/sv.po    | 11251 ++++++++++++++++++++---------------------
 gcc/po/tr.po    | 11238 ++++++++++++++++++++---------------------
 gcc/po/uk.po    | 12559 +++++++++++++++++++++++-----------------------
 gcc/po/vi.po    | 11228 +++++++++++++++++++++--------------------
 gcc/po/zh_CN.po | 11249 ++++++++++++++++++++---------------------
 gcc/po/zh_TW.po | 11237 ++++++++++++++++++++---------------------
 19 files changed, 107860 insertions(+), 106875 deletions(-)

diff --git a/gcc/po/be.po b/gcc/po/be.po
index 1bfc81302cbcf..ab13314e6d663 100644
--- a/gcc/po/be.po
+++ b/gcc/po/be.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 3.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2002-05-17 15:54+0200\n"
 "Last-Translator: Ales Nyakhaychyk <nyakhaychyk@i18n.linux.by>\n"
 "Language-Team: Belarusian <i18n@tut.by>\n"
@@ -1261,11 +1261,11 @@ msgstr "У файле уключаным з %s:%d"
 msgid "this is the insn:"
 msgstr ""
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 msgid "unable to generate reloads for impossible constraints:"
 msgstr ""
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr ""
 
@@ -1437,16 +1437,16 @@ msgstr "нераспазнаны выбар \"-%s\""
 msgid "insn does not satisfy its constraints:"
 msgstr ""
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr ""
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 msgid "created and used with different settings of %<-fpic%>"
 msgstr ""
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 msgid "created and used with different settings of %<-fpie%>"
 msgstr ""
 
@@ -1490,7 +1490,7 @@ msgstr ""
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr ""
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1981,87 +1981,87 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 #| msgid "invalid string constant `%E'"
 msgid "invalid vector constant"
 msgstr "`%E' - нерэчаісная нязьменная тыпу string"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 #| msgid "invalid register name for `%s'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "прапушчан ініцыялізатар"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "нерэчаісны %%d аперанд"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "нерэчаісны адрас"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2077,18 +2077,18 @@ msgid "invalid %%r value"
 msgstr "нерэчаіснае значэньне %%r"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "нерэчаіснае значэньне %%R"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "нерэчаіснае значэньне %%N"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "нерэчаіснае значэньне %%P"
@@ -2118,7 +2118,7 @@ msgstr "нерэчаіснае значэньне %%M"
 msgid "invalid %%U value"
 msgstr "нерэчаіснае значэньне %%U"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "нерэчаіснае значэньне %%v"
@@ -2128,7 +2128,7 @@ msgstr "нерэчаіснае значэньне %%v"
 msgid "invalid %%C value"
 msgstr "нерэчаіснае значэньне %%C"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "нерэчаіснае значэньне %%E"
@@ -2141,7 +2141,7 @@ msgstr ""
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "нерэчаіснае значэньне %%xn"
@@ -2225,36 +2225,36 @@ msgstr "нерэчаісны %%-код"
 msgid "unrecognized supposed constant"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "нерэчаісны %%f аперанд"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2262,13 +2262,13 @@ msgstr "Нерэчаісны выбар \"%s\""
 msgid "invalid operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2401,8 +2401,8 @@ msgstr "непадтрымліваемая версія"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2777,7 +2777,7 @@ msgstr "нерэчаісны %%-код"
 msgid "invalid %%P operand"
 msgstr "нерэчаісны %%-код"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -2833,7 +2833,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "дрэнны адрас"
 
@@ -2889,8 +2889,8 @@ msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, fuzzy, c-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of '%%%c'"
@@ -3036,297 +3036,297 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Выкарыстоўваць апаратную \"плаваючую кропку\""
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%A value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%e value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "нерэчаіснае значэньне %%O"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%t value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, c-format
 msgid "invalid %%V value"
 msgstr "нерэчаіснае значэньне %%V"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, fuzzy, c-format
 #| msgid "invalid %%x/X value"
 msgid "invalid %%x value"
 msgstr "нерэчаіснае значэньне %%x/X"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, c-format
 msgid "invalid %%z value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Стварыць код для DLL"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr ""
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, fuzzy, c-format
 msgid "cannot decompose address"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "vector argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3594,8 +3594,8 @@ msgstr ""
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr ""
@@ -3615,7 +3615,7 @@ msgstr ""
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr ""
@@ -3623,7 +3623,7 @@ msgstr ""
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr ""
@@ -3641,21 +3641,21 @@ msgstr ""
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr ""
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr ""
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr ""
@@ -3666,13 +3666,13 @@ msgstr ""
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr ""
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr ""
@@ -3681,7 +3681,7 @@ msgstr ""
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr ""
@@ -3690,18 +3690,18 @@ msgstr ""
 msgid "expected %<.%>"
 msgstr ""
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr ""
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr ""
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -3709,28 +3709,28 @@ msgstr ""
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr ""
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr ""
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -3745,30 +3745,30 @@ msgstr ""
 msgid "candidate:"
 msgstr ""
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr ""
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 #, fuzzy
 msgid "jump to label %qD"
 msgstr "паўтарэнне \"%s\""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr ""
 
@@ -4007,28 +4007,28 @@ msgstr "\"%s\" не абвешчан (першае выкарыстанне ў 
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 msgid "%<using enum%> of dependent type %qT"
 msgstr ""
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr ""
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr ""
 
@@ -4077,50 +4077,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 #, fuzzy
 #| msgid "too many arguments to function"
 msgid "in argument to unary !"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4221,7 +4221,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "увага:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4353,7 +4353,7 @@ msgstr "нерэчаісны абвяшчальнік"
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr ""
 
@@ -4387,11 +4387,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr ""
 
@@ -4497,154 +4497,154 @@ msgstr ""
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4769,26 +4769,26 @@ msgstr ""
 msgid "Incorrect function return value"
 msgstr ""
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, c-format
 msgid "Error allocating %lu bytes"
 msgstr ""
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr ""
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr ""
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, fuzzy, c-format
 #| msgid "error writing to %s"
 msgid "Error reallocating to %lu bytes"
@@ -5004,15 +5004,15 @@ msgstr ""
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr ""
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr ""
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr ""
 
@@ -5030,8 +5030,8 @@ msgstr ""
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr ""
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr ""
 
@@ -5199,10 +5199,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "немагчыма стварыць часовы файл"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5678,160 +5678,160 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr ""
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr ""
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr ""
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr ""
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr ""
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr ""
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr ""
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr ""
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr ""
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr ""
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr ""
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr ""
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr ""
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr ""
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr ""
@@ -6516,7 +6516,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7140,8 +7140,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, fuzzy, no-c-format
 msgid "No longer supported."
 msgstr "-pipe не падтрымліваецца."
@@ -7500,466 +7500,461 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr ""
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr ""
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr ""
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr ""
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr ""
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr ""
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr ""
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr ""
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr ""
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr ""
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr ""
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr ""
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr ""
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr ""
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr ""
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr ""
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr ""
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr ""
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr ""
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr ""
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr ""
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr ""
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr ""
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr ""
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr ""
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr ""
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr ""
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr ""
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr ""
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr ""
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr ""
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr ""
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr ""
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr ""
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr ""
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr ""
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr ""
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr ""
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr ""
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr ""
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr ""
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr ""
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr ""
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr ""
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr ""
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr ""
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr ""
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr ""
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr ""
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr ""
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr ""
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr ""
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr ""
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr ""
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr ""
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr ""
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr ""
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr ""
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr ""
@@ -8209,6 +8204,11 @@ msgstr ""
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr ""
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9464,143 +9464,155 @@ msgstr ""
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr ""
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr ""
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr ""
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr ""
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr ""
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr ""
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr ""
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr ""
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr ""
@@ -9735,12 +9747,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 #| msgid "Generate code without GP reg"
@@ -9762,12 +9768,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -17144,2183 +17144,2183 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 msgid "Align the start of functions."
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, no-c-format
 msgid "Enable static analysis pass."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 #| msgid "Do not generate char instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr ""
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1111
+#: common.opt:1115
 #, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr ""
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr ""
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr ""
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr ""
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable code hoisting."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr ""
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 #| msgid "for each function it appears in.)"
 msgid "Place each function into its own section."
 msgstr "адзін раз для кожнай функцыі, дзе ён з'яўляецца.)"
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr ""
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr ""
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 msgid "Process #ident directives."
 msgstr "нерэчаісны ініцыялізатар"
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 #| msgid "Do not generate char instructions"
 msgid "Do not generate .size directives."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, no-c-format
 msgid "Discover pure and const functions."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr ""
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1945
+#: common.opt:1949
 #, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr ""
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr ""
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable link-time optimization."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr ""
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2305
+#: common.opt:2309
 #, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, fuzzy, no-c-format
 msgid "Return small aggregates in registers."
 msgstr "Не выкарыстоўваць рэгістра sb"
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2449
+#: common.opt:2453
 #, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr ""
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Уключаць код правэркі стэку ў праграму"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Уключаць код правэркі стэку ў праграму"
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr ""
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr ""
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable dead store elimination."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable string length optimizations on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr ""
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable loop optimizations on tree level."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable loop vectorization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr ""
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3191
+#: common.opt:3195
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3223
+#: common.opt:3227
 #, fuzzy, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Стварыць код для DLL"
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, fuzzy, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Стварыць код для DLL"
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 #| msgid "  -o <file>                Place the output into <file>\n"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <файл>                Памясціць вывад у <файл>\n"
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable function profiling."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr ""
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr ""
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr ""
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19462,1105 +19462,1115 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr ""
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr ""
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr ""
 
-#: params.opt:210
+#: params.opt:215
 #, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr ""
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr ""
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr ""
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr ""
 
-#: params.opt:242
+#: params.opt:247
 #, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr ""
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr ""
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr ""
 
-#: params.opt:274
+#: params.opt:279
 #, no-c-format
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr ""
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr ""
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr ""
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr ""
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr ""
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr ""
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr ""
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr ""
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr ""
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr ""
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr ""
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr ""
 
-#: params.opt:366
+#: params.opt:371
 #, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr ""
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr ""
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr ""
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr ""
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr ""
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr ""
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr ""
 
-#: params.opt:414
+#: params.opt:419
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr ""
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr ""
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr ""
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr ""
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr ""
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr ""
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr ""
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr ""
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr ""
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr ""
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr ""
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr ""
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr ""
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr ""
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr ""
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr ""
 
-#: params.opt:518
+#: params.opt:523
 #, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr ""
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr ""
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr ""
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr ""
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr ""
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr ""
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr ""
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr ""
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr ""
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr ""
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr ""
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr ""
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr ""
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr ""
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr ""
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr ""
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr ""
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr ""
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr ""
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr ""
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr ""
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr ""
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr ""
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr ""
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr ""
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr ""
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr ""
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr ""
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr ""
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr ""
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr ""
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr ""
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr ""
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr ""
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr ""
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr ""
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr ""
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr ""
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr ""
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr ""
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr ""
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr ""
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr ""
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr ""
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr ""
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr ""
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr ""
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr ""
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr ""
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr ""
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr ""
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr ""
 
-#: params.opt:952
+#: params.opt:970
 #, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr ""
 
-#: params.opt:956
+#: params.opt:974
 #, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr ""
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr ""
 
-#: params.opt:964
+#: params.opt:982
 #, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr ""
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr ""
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr ""
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr ""
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr ""
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr ""
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr ""
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr ""
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20593,7 +20603,7 @@ msgid "expected boolean type"
 msgstr ""
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, gcc-internal-format
 msgid "expected integer"
 msgstr ""
@@ -20662,7 +20672,7 @@ msgstr "няма аргументаў"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments"
@@ -21048,7 +21058,7 @@ msgstr ""
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -21105,7 +21115,7 @@ msgstr ""
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -21134,20 +21144,20 @@ msgstr ""
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
@@ -21159,8 +21169,8 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %qD"
@@ -21171,59 +21181,59 @@ msgstr "папярэдняе абвяшчэньне `%D'"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr ""
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr ""
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr ""
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr ""
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr ""
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr ""
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr ""
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr ""
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr ""
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, gcc-internal-format
 msgid "%qD target declared here"
 msgstr ""
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -21327,7 +21337,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr ""
@@ -21352,633 +21362,633 @@ msgstr "аргумент `__builtin_args_info' павінен быць канс
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, gcc-internal-format
 msgid "source object declared here"
 msgstr ""
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, gcc-internal-format
 msgid "destination object declared here"
 msgstr ""
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, gcc-internal-format
 msgid "destination object allocated here"
 msgstr ""
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "too few arguments to function %<va_start%>"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid argument to %qD"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_args_info' must be constant"
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr ""
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 1 to %qs"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr "-pipe не падтрымліваецца"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr "аргумент для \"%s\" прапушчан"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, fuzzy, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "`va_start' used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
@@ -21986,99 +21996,99 @@ msgstr ""
 "`va_start' выкарыстоўвываецца ў функцыі з нязьменнай\n"
 "           колькасьцю аргументаў"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "\"__buitin_next_arg\" выклікаецца без аргумента"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared here"
 msgstr "выклікана адсюль"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, gcc-internal-format
 msgid "returned from %qD"
 msgstr ""
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, gcc-internal-format
 msgid "returned from %qT"
 msgstr ""
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, gcc-internal-format
 msgid "obtained here"
 msgstr ""
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, gcc-internal-format
 msgid "assigned here"
 msgstr ""
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -22864,303 +22874,303 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr ""
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "local symbols must be defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr ""
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to `-%s' is missing"
 msgid "%s: section %s.%d is missing"
@@ -23242,13 +23252,13 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "%q+F used but never defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -23322,7 +23332,7 @@ msgstr "памер вяртаемага значэння \"%s\" %u байт"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "памер вяртаемага значэння \"%s\" больш чым %d байт"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr ""
@@ -23738,12 +23748,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -23763,7 +23773,7 @@ msgstr ""
 msgid "internal consistency failure"
 msgstr "унутраная памылка"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -23896,42 +23906,42 @@ msgstr "не магу знайсці крыніцу %s\n"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23946,7 +23956,7 @@ msgstr ""
 msgid "total size of local objects exceeds maximum %wu"
 msgstr ""
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "impossible operator '%s'"
 msgid "impossible constraint in %<asm%>"
@@ -24586,7 +24596,7 @@ msgstr ""
 msgid "function may return address of local variable"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr ""
@@ -24952,53 +24962,53 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 msgid "%Guse of %<alloca%>"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 msgid "%Gargument to variable-length array may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 msgid "%Gargument to variable-length array is too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 msgid "%Gargument to %<alloca%> is too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 msgid "%Gunbounded use of variable-length array"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 msgid "%Gunbounded use of %<alloca%>"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 msgid "%Gargument to variable-length array is zero"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 msgid "%Gargument to %<alloca%> is zero"
 msgstr ""
 
@@ -25112,7 +25122,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
@@ -25138,11 +25148,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -25217,308 +25227,308 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr ""
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr ""
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, gcc-internal-format
 msgid "enclosing region"
 msgstr ""
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr ""
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -25969,22 +25979,22 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr "\"%s\" звычайна функцыя"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr ""
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr ""
@@ -26004,12 +26014,12 @@ msgstr ""
 msgid "unable to find a register to spill"
 msgstr "Не выкарыстоўваць рэгістра sb"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr ""
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
@@ -26726,12 +26736,12 @@ msgstr "памер \"%s\" больш чам %d байт"
 msgid "unrecognized argument in option %qs"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -26859,7 +26869,7 @@ msgstr ""
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
@@ -27371,22 +27381,22 @@ msgstr ""
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr ""
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr ""
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr ""
@@ -27448,12 +27458,12 @@ msgstr ""
 msgid "impossible register constraint in %<asm%>"
 msgstr ""
 
-#: reload.c:2687
+#: reload.c:2692
 #, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr ""
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr ""
@@ -27483,52 +27493,52 @@ msgstr ""
 msgid "output operand is constant in %<asm%>"
 msgstr ""
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:900
+#: rtl.c:910
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr ""
@@ -27574,22 +27584,22 @@ msgstr ""
 msgid "invalid punctuation %qc in constraint"
 msgstr "`%E' - нерэчаісная нязьменная тыпу string"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr ""
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr ""
 
-#: stmt.c:650
+#: stmt.c:651
 #, fuzzy, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "нераспазнаны аператар %s"
@@ -28279,9 +28289,9 @@ msgstr "нерэчаісны %%-код"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr ""
@@ -28319,7 +28329,7 @@ msgstr "нерэчаісны %%f аперанд"
 msgid "invalid clique in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
@@ -28525,367 +28535,367 @@ msgstr "нерэчаісны %%-код"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr ""
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr ""
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr ""
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr ""
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for `%s'"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr ""
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr ""
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%Q value"
 msgid "invalid %<PHI%> result"
 msgstr "дрэннае %%Q значэнне"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%Q value"
 msgid "invalid %<PHI%> argument"
 msgstr "дрэннае %%Q значэнне"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr ""
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr ""
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "case labels not sorted: "
 msgstr "-pipe не падтрымліваецца"
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing field '%s' in '%s'"
 msgid "missing edge %i->%i"
 msgstr "прапушчана поле '%s' у '%s'"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr ""
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr ""
@@ -29978,7 +29988,7 @@ msgstr ""
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
@@ -30139,7 +30149,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported record layout"
@@ -30755,7 +30765,7 @@ msgstr ""
 msgid "type was previously declared %qE"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -30776,7 +30786,7 @@ msgstr ""
 msgid "%qE argument is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -31205,12 +31215,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<restrict%>"
@@ -31373,14 +31383,14 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %qE"
 msgstr "не хапае аргументаў у функцыі"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %qE"
@@ -32335,7 +32345,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -32385,7 +32395,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -32401,17 +32411,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr "прапушчан ініцыялізатар"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -32421,7 +32431,7 @@ msgstr "аргумент для \"%s\" прапушчан"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "нерэчаісны ініцыялізатар"
@@ -32486,7 +32496,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -33061,8 +33071,8 @@ msgstr "вяртанне"
 msgid "wrong type argument to %s"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -33554,17 +33564,17 @@ msgstr "нехапае аргументаў у функцыі \"%s\""
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr ""
@@ -33747,8 +33757,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -33827,162 +33837,162 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr ""
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previously declared as a pointer %s"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "no previous declaration for `%s'"
 msgid "previously declared as an ordinary array %s"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr ""
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr ""
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "няма папярэдняга аб'яўлення для \"%s\""
 msgstr[1] "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr ""
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previously declared as %s with bound %qs"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -33997,7 +34007,7 @@ msgstr ""
 msgid "too many input files"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr ""
@@ -34029,14 +34039,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -34190,62 +34200,62 @@ msgstr ""
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
@@ -34408,89 +34418,89 @@ msgstr ""
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr ""
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr ""
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr ""
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr ""
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr ""
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr ""
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr ""
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr ""
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, fuzzy, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr ""
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr ""
 
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr ""
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34626,366 +34636,366 @@ msgstr ""
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid format for sve_width"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "нерэчаіснае значэньне %%h"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Нераспазнаны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s не падтрымлівае %s"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %wd"
 msgstr "непадтрымліваемая версія"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr ""
@@ -35046,7 +35056,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr ""
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -35168,18 +35178,18 @@ msgstr "аргумент `__builtin_args_info' павінен быць канс
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -35615,223 +35625,228 @@ msgstr "ISO C не падтрымлівае комлексныя цэлалік
 msgid "target CPU does not support unaligned accesses"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr ""
+
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr ""
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -35839,23 +35854,23 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "-pipe не падтрымліваецца"
@@ -35938,18 +35953,18 @@ msgstr "-pipe не падтрымліваецца"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "%qs function cannot have arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "%qs function cannot return a value"
@@ -36704,132 +36719,132 @@ msgstr "аргумент `__builtin_args_info' павінен быць канс
 msgid "parameter to builtin not valid: %s"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr ""
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
@@ -36850,517 +36865,517 @@ msgstr "віртуальныя функцыі не могуць быць сяб
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s does not support %s"
 msgid "code model %s does not support PIC mode"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "wrong argument %qs to option %qs"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -37820,7 +37835,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -38888,58 +38903,58 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for `%s'"
 msgid "%qs is not a valid base register in %qs"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -39449,242 +39464,242 @@ msgstr "Не выкарыстоўваць рэгістра sb"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s не падтрымлівае %s"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20055
+#: config/rs6000/rs6000.c:20172
 #, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 #| msgid "%s=%s is too large"
 msgid "%s%qs%s is not allowed"
 msgstr "%s=%s вельмі вялікі"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -39863,7 +39878,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -39934,202 +39949,207 @@ msgstr ""
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "параметр \"%s\" ініцыялізаваны"
+
+#: config/s390/s390.c:766
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr ""
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr ""
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "памер \"%s\" - %d байт"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
@@ -40473,17 +40493,22 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr ""
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr ""
@@ -40551,8 +40576,8 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "could not read the BRIG file"
 msgstr "не магу знайсці крыніцу %s\n"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -40615,7 +40640,7 @@ msgstr "адмеціна `%D' вызначана, але не выкарысто
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
@@ -40840,7 +40865,7 @@ msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэк
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -40850,7 +40875,7 @@ msgstr ""
 msgid "declaration of %qD shadows a previous local"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -40860,220 +40885,220 @@ msgstr "няма папярэдняга аб'яўлення для \"%s\""
 msgid "nested extern declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, fuzzy, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, fuzzy, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, fuzzy, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr ""
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "(Each undeclared identifier is reported only once"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Аб кожным неабвешчаным ідэнтыфікатары паведамляецца"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, fuzzy, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "label %qD defined here"
 msgstr "адмеціна `%D' вызначана, але не выкарыстоўваецца"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "duplicate label declaration %qE"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "паўтарэнне \"%s\""
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr ""
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr ""
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr ""
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, fuzzy, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "%<inline%> in empty declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, fuzzy, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, fuzzy, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C89 не падтрымлівае \"long long\""
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C89 не падтрымлівае \"long long\""
@@ -41081,29 +41106,29 @@ msgstr "ISO C89 не падтрымлівае \"long long\""
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is usually a function"
 msgid "%q+D is usually a function"
 msgstr "`%s' - звычайна функцыя"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr ""
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' is initialized"
 msgid "parameter %qD is initialized"
@@ -41113,274 +41138,274 @@ msgstr "параметр \"%s\" ініцыялізаваны"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr ""
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %q+D"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero or negative size array %q+D"
 msgstr "нулявы памер масіва `%D'"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr ""
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qs has invalid type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr ""
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr ""
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr ""
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `const'"
 msgid "duplicate %<const%>"
 msgstr "паўтарэнне \"const\""
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<restrict%>"
 msgstr "паўтарэнне \"restrict\""
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<volatile%>"
 msgstr "паўтарэнне \"volatile\""
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<_Atomic%>"
 msgstr "паўтарэнне \"restrict\""
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -41388,736 +41413,736 @@ msgstr ""
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of array %qE is negative"
 msgstr "адмоўны памер масіва "
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "адмоўны памер масіва "
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qE is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of unnamed array is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function definition has qualified void return type"
 msgstr "функцыя не вяртае тып string"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field has atomic type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, fuzzy, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, fuzzy, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr ""
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "struct defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "union defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "паўтарэнне \"%s\""
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr ""
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s - вельмі вялікі"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "перанакіраванне stdout: %s"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type defaults to %<int%>"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for `%s'"
 msgid "no previous prototype for %qD"
 msgstr "няма папярэдняга прататыпа для \"%s\""
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for `%s'"
 msgid "no previous declaration for %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type of %qD is not %<int%>"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is usually a function"
 msgid "%qD is normally a non-static function"
 msgstr "`%s' - звычайна функцыя"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr ""
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "number of arguments doesn%'t match prototype"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "prototype declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -42126,272 +42151,272 @@ msgstr "адмеціна `%D' вызначана, але не выкарысто
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C89 не падтрымлівае \"long long\""
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "duplicate %qE declaration specifier"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "`long long long' - вельмі доўга для GCC"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C89 не падтрымлівае `long long'"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "паўтарэньне `%s'"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C90 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -42411,7 +42436,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -42422,7 +42447,7 @@ msgstr ""
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr ""
@@ -42459,7 +42484,7 @@ msgid "unknown type name %qE"
 msgstr "невядомая назва рэгістра: %s"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration specifiers"
@@ -42481,7 +42506,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -42497,7 +42522,7 @@ msgstr "атрыбуты секцыі не падтрымліваюцца для
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -42535,7 +42560,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -42596,7 +42621,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -42643,14 +42668,14 @@ msgstr "параметр \"%s\" ініцыялізаваны"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -42737,7 +42762,7 @@ msgstr ""
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr ""
@@ -42798,7 +42823,7 @@ msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -42813,7 +42838,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
@@ -42838,19 +42863,19 @@ msgstr ""
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr ""
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -42870,12 +42895,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -42890,8 +42915,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "паўтарэнне \"volatile\""
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -42918,12 +42943,12 @@ msgstr "ISO C не дазваляе пусты ізыходны файл"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -43322,12 +43347,12 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "прапушчан ініцыялізатар"
@@ -43337,51 +43362,51 @@ msgstr "прапушчан ініцыялізатар"
 msgid "unknown property attribute %<%s%s%>"
 msgstr ""
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr ""
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -43391,18 +43416,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
@@ -43423,54 +43448,54 @@ msgstr ""
 msgid "%qD is not a variable"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr ""
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -43492,109 +43517,109 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr ""
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr ""
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many %<static%> arguments"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "unexpected argument"
 msgstr "няма аргументаў"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr ""
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%-code"
 msgid "invalid schedule kind"
@@ -43605,17 +43630,17 @@ msgstr "нерэчаісны %%-код"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -43635,24 +43660,24 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "нерэчаісны %%d аперанд"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "нерэчаісная маска"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -43667,83 +43692,83 @@ msgstr "Нерэчаісны выбар %s"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr ""
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%qs is not valid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -43758,7 +43783,7 @@ msgstr ""
 msgid "expected function name"
 msgstr ""
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD does not refer to a function"
@@ -43769,27 +43794,27 @@ msgstr "`%D' - гэта ня функцыя,"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, gcc-internal-format
 msgid "expected %<allocator%>"
 msgstr ""
@@ -43799,83 +43824,83 @@ msgstr ""
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr ""
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many atomic clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr ""
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr ""
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr ""
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr ""
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr ""
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -43885,32 +43910,32 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr ""
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr ""
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -43920,72 +43945,72 @@ msgstr ""
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr ""
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -44000,57 +44025,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr ""
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr ""
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr ""
@@ -44061,12 +44086,12 @@ msgstr ""
 msgid "variant %qD is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -44076,32 +44101,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr ""
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr ""
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -44156,42 +44181,42 @@ msgstr ""
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr ""
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr ""
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -44206,27 +44231,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -44236,7 +44261,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -44252,7 +44277,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -44293,127 +44318,127 @@ msgstr ""
 msgid "function types not truly compatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr ""
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr ""
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr ""
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr ""
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr ""
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr ""
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr ""
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr ""
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr ""
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr ""
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr ""
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr ""
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr ""
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr ""
@@ -44421,1603 +44446,1603 @@ msgstr ""
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr ""
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr ""
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr ""
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "too many arguments to method %qE"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr ""
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to absu"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support `++' and `--' on complex types"
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C не падтрымлівае \"++\" і \"--\" для тыпу complex"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr ""
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr ""
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, gcc-internal-format
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr ""
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr ""
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr ""
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr ""
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr ""
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr ""
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr ""
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, fuzzy, gcc-internal-format
 #| msgid "initialization"
 msgid "(near initialization for %qs)"
 msgstr "ініцыялізацыя"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr ""
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr ""
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "implicit conversion from %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr ""
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr ""
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr ""
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr ""
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr ""
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr ""
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr ""
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "прапушчан ініцыялізатар"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr ""
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr ""
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr ""
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, gcc-internal-format
 msgid "excess elements in %<char%> array initializer"
 msgstr ""
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr ""
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr ""
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr ""
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr ""
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids `goto *expr;'"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C не падтрымлівае \"goto *expr;\""
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функцыя не вяртае тып string"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr ""
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 msgid "function returns address of label"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, fuzzy, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "Не магу знайсці файл для класа %s."
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr ""
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr ""
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr ""
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -46230,7 +46255,7 @@ msgstr "пераўтварэньне з `%T' у `%T'"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -46339,670 +46364,674 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "Унутраная памылка: %s"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "%s\n"
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr ""
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr ""
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type of %qD is not %qs"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, fuzzy, gcc-internal-format
 #| msgid "impossible operator '%s'"
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "немагчымы апэратар '%s'"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared protected here"
 msgstr "выклікана адсюль"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "  from here"
 msgid "  declared here"
 msgstr " адсюль"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "invalid conversion from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr ""
+
+#: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "  for conversion from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -47026,1137 +47055,1137 @@ msgstr ""
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr ""
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr ""
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q#D"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr ""
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr ""
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is larger than %d bytes"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "in the definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, fuzzy, gcc-internal-format
 #| msgid "language %s not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "мова %s не распазнана"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr ""
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr ""
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr ""
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr ""
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr ""
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function `%s'"
 msgid "call to internal function %qE"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr ""
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' is initialized"
 msgid "virtual table pointer is used uninitialized"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr ""
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, gcc-internal-format
 msgid "allocation performed here"
 msgstr ""
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr ""
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr ""
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr ""
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "allocated here"
 msgstr "выклікана адсюль"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "%qD used in its own initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr ""
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -48166,52 +48195,52 @@ msgstr ""
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr ""
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr ""
@@ -48253,7 +48282,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -48641,7 +48670,7 @@ msgstr "папярэдняе абвяшчэньне `%D'"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -48775,8 +48804,8 @@ msgstr "няма папярэдняга аб'яўлення для \"%s\""
 msgid "%q#D previously defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -48812,54 +48841,54 @@ msgstr "нехапае аргументаў у функцыі \"%s\""
 msgid "previous specification in %q#D here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "conflicting exporting declaration %qD"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "previous definition of %qD here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr ""
@@ -48872,50 +48901,50 @@ msgstr ""
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#D"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr ""
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48923,2334 +48952,2349 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %q#D"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr " адсюль"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr ""
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr ""
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+msgid "%qD is a function, not a type"
+msgstr "\"%s\" звычайна функцыя"
+
+#: cp/decl.c:4072
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qD"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qD"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "Не магу знайсці дэкларацыю інтэрфейса для \"%s\""
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr ""
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' павінна вяртаць `int'"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr ""
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a variable concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "size of array %qD has non-integral type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as array of void"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr ""
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qE as non-member"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr ""
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr ""
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr ""
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr ""
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr ""
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qs declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Не магу знайсці файл для класа %s."
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "%<explicit%> outside class declaration"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "Не магу знайсці дэкларацыю пратакола для \"%s\""
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "нерэчаіснае выкарыстаньне `::'"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %qD as member of %qT"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "%qD cannot be %qs"
 msgstr "[нельга знайсці %s]"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr ""
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "%qD must have no arguments"
 msgstr "няма аргументаў"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qD has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qT has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -51262,106 +51306,106 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "redeclaration of %qT as a non-template"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr ""
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "паўтарэнне \"restrict\""
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -51370,78 +51414,78 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr ""
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "не знойдзен клас \"%s\""
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -51481,7 +51525,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "метка \"%s\" ужываецца, але не вызначана"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "пустое абвяшчэнне"
@@ -51491,7 +51535,7 @@ msgstr "пустое абвяшчэнне"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -51820,22 +51864,22 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr ""
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -51941,7 +51985,7 @@ msgstr "памер \"%s\" - %d байт"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
@@ -51951,7 +51995,7 @@ msgstr ""
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
@@ -52137,410 +52181,410 @@ msgstr ""
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "Клас \"%s\" ужо існуе"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "  when initialized here"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "ініцыялізацыя"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr ""
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr ""
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr ""
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "field '%s' not found in class"
 msgid "no suitable %qD found in class %qT"
 msgstr "поле \"%s\" не знойдзена ў класе"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -52596,62 +52640,62 @@ msgstr ""
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -52832,307 +52876,307 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr ""
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "YYDEBUG не вызначан."
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr ""
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr ""
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr ""
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr ""
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "%s: Not a directory"
 msgid "%qT is not a direct base of %qT"
 msgstr "%s: не дырэкторыя"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "using-declaration may not name namespace %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qD attribute directive ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "YYDEBUG не вызначан."
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr ""
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -53157,7 +53201,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -53182,7 +53226,7 @@ msgstr ""
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -53262,7 +53306,7 @@ msgstr "Нерэчаісны выбар %s"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -53399,7 +53443,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -53524,7 +53568,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -53576,7 +53620,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -53606,7 +53650,7 @@ msgstr ""
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr ""
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
@@ -53626,12 +53670,12 @@ msgstr ""
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "\"%s\" мае незавершаны тып"
@@ -53666,7 +53710,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
@@ -53682,7 +53726,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -53698,1126 +53742,1131 @@ msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr ""
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr ""
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr ""
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr ""
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "default argument specified for lambda parameter"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "паўтарэнне \"%s\""
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected labeled-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr ""
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "condition declares a function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "expected initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr ""
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected iteration-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, gcc-internal-format
 msgid "expected module-name"
 msgstr ""
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, gcc-internal-format
 msgid "private module fragment"
 msgstr ""
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr ""
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr ""
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr ""
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "неаднолькавае абвяшчэньне `%T' і `%T'"
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr ""
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected operator"
 msgstr "нераспазнаны аператар %s"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr ""
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr ""
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr ""
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "%qE does not constrain a type"
 msgstr "функцыя не вяртае тып string"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr ""
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr ""
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a namespace-name"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr ""
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr ""
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, gcc-internal-format
 msgid "parentheses were disambiguated as a function declaration"
 msgstr ""
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "\"%s\" мае незавершаны тып"
@@ -54826,437 +54875,437 @@ msgstr "\"%s\" мае незавершаны тып"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "нерэчаісны абвяшчальнік"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate cv-qualifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate virt-specifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr ""
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "нерэчаіснае выкарыстаньне `%T'"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "немагчыма знайсьці файл для кляса %s"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr ""
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr ""
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr ""
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr ""
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "невыкарыстаемы параметр \"%s\""
@@ -55265,623 +55314,623 @@ msgstr "невыкарыстаемы параметр \"%s\""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "пустое абвяшчэнне"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qD"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qs"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected %<operator%>"
 msgstr "нераспазнаны аператар %s"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr ""
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr ""
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr ""
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr ""
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr ""
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid type for instance variable"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid type for property"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr ""
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr ""
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "  from definition of %q#D"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of alias template %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "from definition of %q#D"
@@ -55889,143 +55938,143 @@ msgstr "папярэдняе вызначэньне `%#T'"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a template function"
@@ -56039,162 +56088,162 @@ msgstr "`%D' - гэта ня функцыя,"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "у функцыі \"%s\":"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "friend declaration here"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr ""
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "too many arguments for partial specialization %qT"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -56203,47 +56252,47 @@ msgstr "нехапае аргументаў у функцыі \"%s\""
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -56253,497 +56302,497 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "нявернае выкарыстанне \"restict\""
 msgstr[1] "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "няма папярэдняга аб'яўлення для \"%s\""
 msgstr[1] "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "original definition appeared here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "in template argument for type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr ""
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 msgid "provided for %qD"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
@@ -56761,296 +56810,296 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function returning an array"
 msgstr "функцыя не вяртае тып string"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -57062,154 +57111,154 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -57346,531 +57395,531 @@ msgstr "віртуальныя функцыі не могуць быць сяб
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr ""
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr ""
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr ""
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "\"%s\" мае незавершаны тып"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr ""
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -57878,22 +57927,22 @@ msgstr ""
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -57903,1063 +57952,1063 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid " declared here"
 msgstr "выклікана адсюль"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "Клас \"%s\" ужо існуе"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not public"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr ""
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr ""
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "сімвальная канстанта вельмі доўгая"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr ""
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a member template function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr ""
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr ""
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr ""
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/typeck.c:7956
+#: cp/typeck.c:7963
 #, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Нерэчаісны выбар %s"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr ""
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -59231,108 +59280,103 @@ msgstr ""
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck2.c:2213
-#, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr ""
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
@@ -59352,270 +59396,276 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 msgid "cannot be declared to be a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "перанакіраванне stdout: %s"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot be %s"
 msgstr "[нельга знайсці %s]"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
 msgstr "не магу прачытаць з %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is negative"
 msgid "size of type %s is invalid"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, gcc-internal-format
 msgid "string expected for library name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "няма аргументаў"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 msgid "can only apply to a single declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "pragma is missing closing `;`"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
 msgstr "пустое абвяшчэнне"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, gcc-internal-format
 msgid "circular reference to enum member"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, gcc-internal-format
 msgid "recursive mixin instantiation"
 msgstr ""
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, gcc-internal-format
 msgid "recursive expansion"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, gcc-internal-format
 msgid "error instantiating"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "functions cannot be scope"
@@ -59624,43 +59674,53 @@ msgstr "віртуальныя функцыі не могуць быць сяб
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "%s functions cannot be abstract"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, gcc-internal-format
 msgid "cannot be both final and abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -59668,174 +59728,174 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 msgid "does not override any function"
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "structs, unions cannot be abstract"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, gcc-internal-format
 msgid "circular inheritance"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, gcc-internal-format, gfc-internal-format
 msgid "inherits from duplicate interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot inherit from final class %s"
 msgstr "немагчыма знайсьці файл для кляса %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, fuzzy, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr "Не магу знайсці дэкларацыю інтэрфейса для \"%s\""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, gcc-internal-format
 msgid "cannot resolve"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find source %s"
 msgid "cannot alias an expression %s"
@@ -59851,22 +59911,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, gcc-internal-format
 msgid "has forward references"
 msgstr ""
@@ -59926,22 +59986,22 @@ msgstr ""
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
+#: d/dmd/semantic3.c:864
 #, gcc-internal-format
-msgid "no return exp; or assert(0); at end of function"
+msgid "no `return exp;` or `assert(0);` at end of function"
 msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr ""
@@ -60478,7 +60538,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -61575,12 +61635,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -61761,7 +61821,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -64251,7 +64311,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -64333,7 +64393,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -64468,12 +64528,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -64583,543 +64643,543 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "Unable to find symbol %qs"
 msgstr "не знойдзен клас \"%s\""
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr ""
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr ""
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
@@ -65264,33 +65324,33 @@ msgstr ""
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "Conversion from %s to %s at %L"
@@ -65299,22 +65359,22 @@ msgstr "пераўтварэньне з `%T' у `%T'"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -65852,7 +65912,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -67028,12 +67088,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -67190,152 +67250,152 @@ msgstr ""
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Cannot delete module file %qs: %s"
 msgstr "%s: немагчыма знішчыць файл \"%s\": %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create temporary file"
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "немагчыма стварыць часовы файл"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -67872,8 +67932,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -69900,7 +69960,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -70015,7 +70075,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -70172,213 +70232,213 @@ msgstr ""
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "Substring end index at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -70387,12 +70447,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -70401,293 +70461,293 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -70696,284 +70756,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -70981,192 +71041,192 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -71174,967 +71234,967 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "String length at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -73005,17 +73065,17 @@ msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -73107,109 +73167,109 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 #| msgid "unused variable `%s'"
 msgid "Unused variable %qs declared at %L"
 msgstr "невыкарыстоўваемая пераменная \"%s\""
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument list function at %L"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -73360,7 +73420,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr ""
@@ -73493,7 +73553,7 @@ msgstr ""
 
 #: lto/lto-lang.c:898
 #, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr ""
 
 #: lto/lto-object.c:107
@@ -74622,7 +74682,7 @@ msgstr "нераспазнаная назва сэкцыі \"%s\""
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr ""
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "нераспазнаны выбар \"-%s\""
@@ -74640,16 +74700,16 @@ msgstr "аргумент для \"%s\" прапушчан"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, fuzzy, gcc-internal-format
 #| msgid "missing white space after number '%.*s'"
 msgid "missing filename after %qs"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, fuzzy, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -74705,7 +74765,7 @@ msgstr "Прапушчана назва"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "нераспазнаная назва сэкцыі \"%s\""
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized section name \"%s\""
 msgid "unrecognized scalar storage order value %qs"
@@ -74791,100 +74851,100 @@ msgstr ""
 msgid "unknown linker output %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA algorithm %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown LTO partitioning model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: common.opt:2090
+#: common.opt:2094
 #, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 #, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr ""
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown profile update method %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown Live-Patching Level %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2690
+#: common.opt:2694
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown TLS model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown vectorizer cost model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:3067
+#: common.opt:3071
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized section name \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "нераспазнаная назва сэкцыі \"%s\""
 
-#: common.opt:3086
+#: common.opt:3090
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
diff --git a/gcc/po/da.po b/gcc/po/da.po
index fdd5f4d04f578..5d30bffbfa085 100644
--- a/gcc/po/da.po
+++ b/gcc/po/da.po
@@ -137,7 +137,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc-9.1-b20190203\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2019-02-14 11:00+0200\n"
 "Last-Translator: Joe Hansen <joedalton2@yahoo.dk>\n"
 "Language-Team: Danish <dansk@dansk-gruppen.dk>\n"
@@ -1401,11 +1401,11 @@ msgstr "    indlejret fra %qs"
 msgid "this is the insn:"
 msgstr "dette er instruktionen:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "kunne ikke generere genindlæsninger for umulige begræsninger:"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "kunne ikke generere genindlæsninger for:"
 
@@ -1581,18 +1581,18 @@ msgstr "ukendt instruktion:"
 msgid "insn does not satisfy its constraints:"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "oprettet og brugt med en anden indstilling for »%s«"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "oprettet og brugt med forskellige indstillinger for -fpic"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1632,7 +1632,7 @@ msgstr "%s%sadvarsel: %s teksthovedversion %s svarer ikke til biblioteksversion
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC-heuristikker: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2081,93 +2081,93 @@ msgstr "længdemodifikation i strfmon-formatering"
 msgid "<command-line>"
 msgstr "<kommandolinje>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "Ikke understøttet operand for koden »%c«"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ugyldig operand for »%%%c«"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "ugyldig konstant:"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 #| msgid "invalid operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "ugyldig operand for »%%%c«"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "manglende operand"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "ugyldig konstant:"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "ugyldig operand"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ugyldig operandpræfiks »%%%c«"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "ugyldig adresseringstilstand"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 #| msgid "invalid operands to binary %s"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ugyldige operander til binær %s"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« brugt uden nogle lokale dynamiske TLS-referencer"
@@ -2183,18 +2183,18 @@ msgid "invalid %%r value"
 msgstr "ugyldig %%r-værdi"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "ugyldig %%R-værdi"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "ugyldig %%N-værdi"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "ugyldig %%P-værdi"
@@ -2224,7 +2224,7 @@ msgstr "ugyldig %%M-værdi"
 msgid "invalid %%U value"
 msgstr "ugyldig %%U-værdi"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "ugyldig %%s-værdi"
@@ -2234,7 +2234,7 @@ msgstr "ugyldig %%s-værdi"
 msgid "invalid %%C value"
 msgstr "ugyldig %%C-værdi"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "ugyldig %%E-værdi"
@@ -2247,7 +2247,7 @@ msgstr "ukendt relokaliserings-unspec"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ugyldig %%xn-kode"
@@ -2330,37 +2330,37 @@ msgstr "ugyldig UNSPEC som operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "ukendt formodet konstant"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "ugyldig skift-operand"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, fuzzy, c-format
 #| msgid "Generate char instructions"
 msgid "predicated Thumb instruction"
 msgstr "Generér char-instruktioner"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, fuzzy, c-format
 #| msgid "ret instruction not implemented"
 msgid "predicated instruction in conditional sequence"
 msgstr "ret-instruktion ikke implementeret"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ikke understøttet operand for koden »%c«"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2368,13 +2368,13 @@ msgstr "Ikke understøttet operand for koden »%c«"
 msgid "invalid operand for code '%c'"
 msgstr "ugyldig operand for koden »%c«"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktion aldrig udført"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "forældet Maverick-formatkode »%c«"
@@ -2508,8 +2508,8 @@ msgstr "uventet operand"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2879,7 +2879,7 @@ msgstr "ugyldig operation på %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ugyldig %%P-operand"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "ugyldig %%p-værdi"
@@ -2933,7 +2933,7 @@ msgid "post-increment address is not a register"
 msgstr "postfiks forøgelsesadresse er ikke et register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "ugyldig adresse"
 
@@ -2986,8 +2986,8 @@ msgstr "»%%%c« er ikke et gyldigt operandpræfiks"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ugyldig brug af »%%%c«"
@@ -3133,323 +3133,323 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 #| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx kræver udstyrskommatal"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 #| msgid "-mvsx needs indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "-mvsx kræver indekseret adressering"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx og -mno-altivec er indbyrdes uforenelige"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 #, fuzzy
 #| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec deaktiverer vsx"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "-mquad-memory kræver 64-bit tilstand"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 #, fuzzy
 #| msgid "-mquad-memory-atomic requires 64-bit mode"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "-mquad-memory-atomic kræver 64-bit tilstand"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 #, fuzzy
 #| msgid "-mquad-memory is not available in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "-mquad-memory er ikke tilgængelig i lilleendet tilstand"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 #, fuzzy
 #| msgid "bad operand"
 msgid "bad move"
 msgstr "ugyldig operand"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "ugyldig %%D-værdi"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, c-format
 msgid "invalid %%e value"
 msgstr "ugyldig %%e-værdi"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "ugyldig %%f-værdi"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "ugyldig %%F-værdi"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "ugyldig %%G-værdi"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "ugyldig %%j-kode"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "ugyldig %%J-kode"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "ugyldig %%k-værdi"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "ugyldig %%K-værdi"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "ugyldig %%O-værdi"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "ugyldig %%q-værdi"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "ugyldig %%T-værdi"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "ugyldig %%u-værdi"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "ugyldig %%v-værdi"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "ugyldig %%x-værdi"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, c-format
 msgid "invalid %%z value"
 msgstr "ugyldig %%z-værdi"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ugyldig %%y-værdi, prøv at brug »Z«-begrænsningen"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 msgid "Could not generate addis value for fusion"
 msgstr "Kunne ikke generere addis-værdi for fusion"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kunne ikke generere indlæsning/lagring af forskydning for fusion"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr "Ugyldig GPR-fusion"
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ugyldig konvertering til %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ugyldig konvertering til %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "ugyldig konvertering til %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "ugyldig konvertering til %<__fpreg%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "symbolske hukommelsesreferencer er kun understøttet på z10 eller senere"
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "Kan ikke nedbryde adresse"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ugyldig sammenligningsoperator til »E«-ændring"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ugyldig reference til »J«-uddataændring"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ugyldig adresse til »O«-uddataændring"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ugyldig adresse til »R«-uddataændring"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "hukommelsesreference forventet til »S«-uddataændring"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ugyldig adresse for »S«-uddatamodifikation"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "register eller hukommelsesudtryk forventet til »N«-uddataændring"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "register eller hukommelsesudtryk forventet til »M«-uddataændring"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ugyldig konstant til uddataændringen »%c«"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ugyldig konstant - prøv at bruge en uddataændring"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ugyldig konstantvektor for uddataændringen »%c«"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ugyldigt udtryk - prøv at brug en uddataændring"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ugyldig udtryk til uddataændringen »%c«"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 msgid "vector argument passed to unprototyped function"
 msgstr "vektorparameter sendt til funktion uden prototype"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr "typer er forskellige i signedness"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr "binær operator understøtter ikke tovektor bool-operand"
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr "binær operator understøtter ikke vektor bool-operand"
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binær operator understøtter ikke at blande vektor bool med kommatals vektor-operand"
 
@@ -3712,8 +3712,8 @@ msgstr "({anonym})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> forventet"
@@ -3733,7 +3733,7 @@ msgstr "%<;%> forventet"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> forventet"
@@ -3741,7 +3741,7 @@ msgstr "%<)%> forventet"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> forventet"
@@ -3759,21 +3759,21 @@ msgstr "%<;%>, %<,%> eller %<)%> forventet"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> forventet"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> forventet"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> forventet"
@@ -3784,13 +3784,13 @@ msgstr "%<{%> forventet"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> forventet"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> forventet"
@@ -3799,7 +3799,7 @@ msgstr "%<while%> forventet"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> forventet"
@@ -3808,18 +3808,18 @@ msgstr "%<,%> forventet"
 msgid "expected %<.%>"
 msgstr "%<.%> forventet"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> forventet"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> forventet"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> forventet"
@@ -3827,28 +3827,28 @@ msgstr "%<,%> eller %<)%> forventet"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> forventet"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> forventet"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> forventet"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> forventet"
@@ -3865,32 +3865,32 @@ msgstr "forventet etiket"
 msgid "candidate:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 #| msgid "Enable use of DB instruction"
 msgid "  after user-defined conversion:"
 msgstr "Aktivér brug af DB-instruktioner"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "candidate%s: %+#D"
 msgstr[1] "candidate%s: %+#D"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "spring til etiketten %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "spring til case-etiket"
 
@@ -4139,35 +4139,35 @@ msgstr "'%D' blev ikke erklæret i dette virkefelt"
 msgid "local variable %qD may not appear in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 #, fuzzy
 #| msgid "template argument %d is invalid"
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 #| msgid "invalid use of undefined type `%#T'"
 msgid "%<using enum%> of dependent type %qT"
 msgstr "ugyldig brug af en ikke-defineret type '%#T'"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 #| msgid "`%T' is not a template type"
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "'%T' er ikke en skabelonstype"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 #| msgid "invalid use of incomplete typedef `%s'"
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "ugyldig brug af ufuldstændig typedef '%s'"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 #, fuzzy
 msgid "candidates are:"
 msgstr "candidate%s: %+#D"
@@ -4228,50 +4228,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "forkert parametertype til unært minus"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "forkert parametertype til bitkomplement"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "forkert parametertype til abs"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "forkert parametertype til konjugation"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4377,7 +4377,7 @@ msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 msgid "Driving:"
 msgstr "advarsel: "
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4531,7 +4531,7 @@ msgstr "ugyldig operand"
 msgid "Bad type in constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 #, fuzzy
 #| msgid "unexpected PIC symbol"
 msgid "Unexpected end of module"
@@ -4567,11 +4567,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "tildeling"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 #, fuzzy
 #| msgid "assignment"
 msgid "pointer assignment"
@@ -4687,160 +4687,160 @@ msgstr ""
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 #, fuzzy
 #| msgid "`%V' qualifiers cannot be applied to `%T'"
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "modifikationerne '%V' kan ikke anvendes på '%T'"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ugyldigt udtryk som operand"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4976,27 +4976,27 @@ msgstr "danner reference til void"
 msgid "Incorrect function return value"
 msgstr "en funktion uden returtype returnerer en ikke-tom værdi"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 #| msgid "Memory allocation failed"
 msgid "Error allocating %lu bytes"
 msgstr "Hukommelsesallokering mislykkedes"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr ""
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr ""
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -5210,17 +5210,17 @@ msgstr "-membedded-pic og -mabicalls er indbyrdes uforenelige"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "kan ikke bruge både -EB og -EL"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 #, fuzzy
 #| msgid "-msoft-float and -mhard_float may not be used together"
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-msoft-float og -mhard_float kan ikke bruges på samme tid"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian og -mlittle-endian kan ikke bruges på samme tid"
 
@@ -5242,8 +5242,8 @@ msgstr "specifikationsfil har ingen specifikation til sammenkædning"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "-C og -o er indbyrdes uforenelige"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared og mdll er indbyrdes uforenelige"
 
@@ -5427,10 +5427,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Advar om beregninger på funktionshenvisninger"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5928,163 +5928,163 @@ msgstr "Overbring alle parametre på stakken"
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr ""
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr ""
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 #| msgid "unexpected address expression"
 msgid "Protect parentheses in expressions."
 msgstr "uventet adresseudtryk"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable range checking during compilation."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, fuzzy, no-c-format
 #| msgid "invalid lvalue in assignment"
 msgid "Reallocate the LHS in assignments."
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr ""
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr ""
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, fuzzy, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr "Tilføj aldrig en anden understreg til eksterne variable"
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr ""
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr ""
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr ""
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr ""
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr ""
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr ""
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr ""
@@ -6813,7 +6813,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7476,8 +7476,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, fuzzy, no-c-format
 #| msgid "--driver no longer supported"
 msgid "No longer supported."
@@ -7847,472 +7847,467 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr ""
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr ""
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr ""
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, fuzzy, no-c-format
 #| msgid "Downgrade conformance errors to warnings"
 msgid "Downgrade conformance errors to warnings."
 msgstr "Nedgradér standardoverholdelsesfejl til advarsler"
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, fuzzy, no-c-format
 #| msgid "Enable Transmeta picoJava extensions"
 msgid "Enable Plan 9 language extensions."
 msgstr "Aktivér Transmeta picoJava-udvidelser"
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr ""
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr ""
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "%s har ingen %s"
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, fuzzy, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr "Generér ikke typebeskrivelsesoplysninger til kørselstidspunktet"
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, fuzzy, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, fuzzy, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "Overskriv den underliggende type af wchar_t til 'unsigned short'"
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr ""
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, fuzzy, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr "Lad 'char' være med fortegn som standard"
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, fuzzy, no-c-format
 #| msgid "hexadecimal floating constants require an exponent"
 msgid "Enable C++14 sized deallocation support."
 msgstr "hexadecimal kommatalskonstant skal have en eksponent"
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, fuzzy, no-c-format
 #| msgid "Display statistics accumulated during compilation"
 msgid "Display statistics accumulated during compilation."
 msgstr "Vis statistik som indsamles under oversættelsen"
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, fuzzy, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "Det maksimale antal faser der skal gennemgås ved udførsel af GCSE"
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, fuzzy, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "Angiv maksimal skabelonsinstantieringsdybde"
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr ""
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr ""
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, fuzzy, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "Lad 'char' være uden fortegn som standard"
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, fuzzy, no-c-format
 #| msgid "Use __cxa_atexit to register destructors"
 msgid "Use __cxa_atexit to register destructors."
 msgstr "Benyt __cxa_atexit til at registrere destruktionsfunktioner"
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr ""
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr ""
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Emit common-like symbols as weak symbols"
 msgid "Emit common-like symbols as weak symbols."
 msgstr "Udsend almindelige symboler som svage symboler"
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr ""
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr ""
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr ""
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, fuzzy, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr "Udskriv erklæringer i en .decl-fil"
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, fuzzy, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "  -aux-info <fil>         Udskriv erklæringsoplysninger til <fil>\n"
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr ""
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr ""
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr ""
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr ""
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr ""
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr ""
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr ""
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr ""
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, fuzzy, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr "Generér C-inkluderingsfil med platformspecifikke faciliteter"
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, fuzzy, no-c-format
 msgid "Remap file names when including files."
 msgstr "tomt filnavn i #%s"
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr ""
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr ""
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr ""
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr ""
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr ""
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr ""
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr ""
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr ""
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr ""
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr ""
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr ""
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr ""
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr ""
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr ""
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr ""
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr ""
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr ""
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, fuzzy, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "Aktivér stakprøvning"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr ""
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr ""
@@ -8572,6 +8567,11 @@ msgstr "Oversæt med 16 bit-heltalstilstand"
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr "Udsend kun eksplicitte instatieringer af indlejrede skabeloner"
+
 #: d/lang.opt:346
 #, fuzzy, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9895,152 +9895,166 @@ msgstr ""
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as big endian"
+msgid "Assume target CPU is configured as big endian."
+msgstr "Antag at målprocessoren er konfigureret som storendet"
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as little endian"
+msgid "Assume target CPU is configured as little endian."
+msgstr "Antag at målprocessoren er konfigureret som lilleendet"
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "Angiv kaldkonventione for heltal og kommatal."
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Forsøg at holde stakken justeret til denne potens af 2."
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, fuzzy, no-c-format
 #| msgid "Known ABIs (for use with the -mabi= option):"
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "Kendte ABI'er (for brug med tilvalget -mabi=):"
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Brug hardware-kommatalsdivision og kvadratrodsinstruktioner."
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 #| msgid "Don't trap on integer divide by zero"
 msgid "Use hardware instructions for integer division."
 msgstr "Forårsag ikke undtagelse ved heltalsdivision med nul"
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 #| msgid "Use features of and schedule code for given CPU"
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "Benyt faciliteter fra og planlæg koden til en given processor"
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, fuzzy, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "  -G <str>                Anbring globale og statiske data mindre end <tal> byte i en specialsektion (på nogle målarkitekturer)\n"
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologue/epilogue"
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "Benyt subrutiner for funktionsindledning/-afslutninger"
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, fuzzy, no-c-format
 #| msgid "Specify the MCU name"
 msgid "Specify the code model."
 msgstr "Angiv MCU-navnet"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 #| msgid "Do not permit unaligned accesses"
 msgid "Do not generate unaligned memory accesses."
 msgstr "Tillad ikke ikke-justeret adgang"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, fuzzy, no-c-format
 #| msgid "Do not tune writable data alignment"
 msgid "Use the given data alignment."
 msgstr "Finjustér ikke justering af skrivbare data"
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, fuzzy, no-c-format
 #| msgid "Pass all arguments on stack"
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Overbring alle parametre på stakken"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, fuzzy, no-c-format
 #| msgid "Known ABIs (for use with the -mabi= option):"
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "Kendte ABI'er (for brug med tilvalget -mabi=):"
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, fuzzy, no-c-format
 #| msgid "Specify the version of the ptx ISA to use."
 msgid "Set the version of RISC-V ISA spec."
@@ -10179,13 +10193,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as big endian"
-msgid "Assume target CPU is configured as big endian."
-msgstr "Antag at målprocessoren er konfigureret som storendet"
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 #| msgid "Generate code which uses the FPU"
@@ -10208,13 +10215,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as little endian"
-msgid "Assume target CPU is configured as little endian."
-msgstr "Antag at målprocessoren er konfigureret som lilleendet"
-
 #: config/aarch64/aarch64.opt:96
 #, fuzzy, no-c-format
 #| msgid "Don't assume that unaligned accesses are handled by the system"
@@ -18241,2336 +18241,2336 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "  -dumpbase <fil>         Basisnavn til brug for dump fra specifikke faser\n"
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "Justér begyndelsen af funktioner"
 
-#: common.opt:988
+#: common.opt:992
 #, fuzzy, no-c-format
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "Justér etiketter som kun nås ved spring"
 
-#: common.opt:995
+#: common.opt:999
 #, fuzzy, no-c-format
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "Justér alle etiketter"
 
-#: common.opt:1002
+#: common.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "Justér begyndelsen af løkker"
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 msgid "Enable static analysis pass."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, fuzzy, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, fuzzy, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Generér afvindingstabeller eksakt for hver instruktionsgrænse"
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 #| msgid "Generate char instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "Generér char-instruktioner"
 
-#: common.opt:1073
+#: common.opt:1077
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Benyt profileringsoplysninger til forgreningssandsynligheder"
 
-#: common.opt:1078
+#: common.opt:1082
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Benyt profileringsoplysninger til forgreningssandsynligheder"
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Generér kode til at kontrollere grænserne før tabeller indekseres"
 
 # RETMIG: rigtig?
-#: common.opt:1091
+#: common.opt:1095
 #, fuzzy, no-c-format
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Erstat tilføj, sammenlign, forgrening med forgrening på tælleregister"
 
-#: common.opt:1095
+#: common.opt:1099
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "Benyt profileringsoplysninger til forgreningssandsynligheder"
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output callgraph information on a per-file basis."
 msgstr "Genbrug r30 på et pr. funktionsgrundlag"
 
-#: common.opt:1115
+#: common.opt:1119
 #, fuzzy, no-c-format
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "Genbrug r30 på et pr. funktionsgrundlag"
 
-#: common.opt:1119
+#: common.opt:1123
 #, fuzzy, no-c-format
 #| msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<register>\tMarker <register> som værende bevaret over funktioner"
 
-#: common.opt:1123
+#: common.opt:1127
 #, fuzzy, no-c-format
 #| msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<register>\tMarker <register> som værende benyttet af funktionskald"
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "Gem registre omkring funktionskald"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy, no-c-format
 #| msgid "Check the return value of new in C++"
 msgid "Check the return value of new in C++."
 msgstr "Kontroller returværdien for new i C++"
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, fuzzy, no-c-format
 #| msgid "internal gcc abort"
 msgid "Perform internal consistency checkings."
 msgstr "intern GCC-afbrydelse"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable code hoisting."
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Put uninitialized globals in the common section."
 msgstr "Anbring ikke uklargjorte globale variabler i den fælles sektion"
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions after register allocation"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Omplanlæg instruktioner efter registerallokering"
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy, no-c-format
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "Udfør krydsspringsoptimering"
 
 # RETMIG: hvad er CSE?
-#: common.opt:1190
+#: common.opt:1194
 #, fuzzy, no-c-format
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Ved kørsel af CSE følg spring til deres mål"
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, fuzzy, no-c-format
 msgid "Place data items into their own section."
 msgstr "placér dataelementer i deres egen sektion"
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, fuzzy, no-c-format
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "Vent med fjernelse af funktionsparametre fra stakken til senere"
 
-#: common.opt:1236
+#: common.opt:1240
 #, fuzzy, no-c-format
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Forsøg at udfylde ventepladser med forgreningsinstruktioner"
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, fuzzy, no-c-format
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "Fjern ubrugelige nul-henvisningstjek"
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, fuzzy, no-c-format
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization."
 msgstr "Udfør superbloksformering vha. haleduplikering"
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, fuzzy, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "  -fdiagnostics-show-location=[once | every-line] Indikerer hvor ofte kildeplaceringsoplysninger skal udsendes som præfiks til begyndelsen af meddelelserne ved linjeombrydning\n"
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr ""
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, fuzzy, no-c-format
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Undtryk udskrift af instruktionstal og linjenummernoter i fejlfindingsdump"
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, fuzzy, no-c-format
 msgid "Dump optimization passes."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1455
+#: common.opt:1459
 #, fuzzy, no-c-format
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Undtryk udskrift af instruktionstal og linjenummernoter i fejlfindingsdump"
 
-#: common.opt:1459
+#: common.opt:1463
 #, fuzzy, no-c-format
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Undtryk udskrift af instruktionstal og linjenummernoter i fejlfindingsdump"
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1471
 #, fuzzy, no-c-format
 msgid "Perform early inlining."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1475
+#: common.opt:1479
 #, fuzzy, no-c-format
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Aktivér undtagelseshåndtering"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy, no-c-format
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Udfør et antal mindre, dyre optimeringer"
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, fuzzy, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Antag at ingen NaN eller +-Inf bliver genereret"
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, fuzzy, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "  -ffixed-<register>      Markér <register> som værende utilgængeligt for oversætteren\n"
 
-#: common.opt:1546
+#: common.opt:1550
 #, fuzzy, no-c-format
 #| msgid "Control allocation order of integer registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Kontrollér tildelingsordenen for heltalsregistrene"
 
-#: common.opt:1554
+#: common.opt:1558
 #, fuzzy, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, fuzzy, no-c-format
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "Tillad funktionsadresser at blive opbevaret i registre"
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 msgid "Place each function into its own section."
 msgstr "placér hver funktion i dens egen sektion"
 
-#: common.opt:1590
+#: common.opt:1594
 #, fuzzy, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr "Udfør global eliminering af fælles underudtryk"
 
-#: common.opt:1594
+#: common.opt:1598
 #, fuzzy, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Udfør forbedret indlæsningsbevægelse under eliminering af fælles underudtryk"
 
-#: common.opt:1598
+#: common.opt:1602
 #, fuzzy, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Udfør lagringsbevægelse efter eliminering af fælles underudtryk"
 
-#: common.opt:1602
+#: common.opt:1606
 #, fuzzy, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Udfør forbedret indlæsningsbevægelse under eliminering af fælles underudtryk"
 
-#: common.opt:1607
+#: common.opt:1611
 #, fuzzy, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Udfør global eliminering af fælles underudtryk"
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, fuzzy, no-c-format
 #| msgid "Enable automatic template instantiation"
 msgid "Enable in and out of Graphite representation."
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: common.opt:1633
+#: common.opt:1637
 #, fuzzy, no-c-format
 #| msgid "Emit call graph information"
 msgid "Enable Graphite Identity transformation."
 msgstr "Udsend kaldegrafinfo"
 
-#: common.opt:1637
+#: common.opt:1641
 #, fuzzy, no-c-format
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Aktivér brug af betingede flytteinstruktioner"
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable loop interchange on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:1667
+#: common.opt:1671
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, fuzzy, no-c-format
 #| msgid "Run the loop optimizer twice"
 msgid "Enable the loop nest optimizer."
 msgstr "Kør løkkeoptimeringen to gange"
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, fuzzy, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr "Aktivér gæt af forgreningssandsynligheder"
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "Behandl #ident-direktiver"
 
-#: common.opt:1707
+#: common.opt:1711
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Udfør konvertering af betingede spring til forgreningsløse ækvivalenter"
 
-#: common.opt:1711
+#: common.opt:1715
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Udfør konvertering af betingede spring til betinget udførsel"
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Udfør konvertering af betingede spring til forgreningsløse ækvivalenter"
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "Generér ikke .size-direktiver"
 
-#: common.opt:1747
+#: common.opt:1751
 #, fuzzy, no-c-format
 msgid "Perform indirect inlining."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, fuzzy, no-c-format
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Integrér simple funktioner i deres kaldere"
 
-#: common.opt:1761
+#: common.opt:1765
 #, fuzzy, no-c-format
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Integrér simple funktioner i deres kaldere"
 
-#: common.opt:1765
+#: common.opt:1769
 #, fuzzy, no-c-format
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "Integrér simple funktioner i deres kaldere"
 
-#: common.opt:1772
+#: common.opt:1776
 #, fuzzy, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "  -finline-limit=<str>    Begræns størrelsen af inlie funktion til <str>\n"
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, fuzzy, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Instrumentér funktionsindgange/-afslutninger med profileringskald"
 
-#: common.opt:1810
+#: common.opt:1814
 #, fuzzy, no-c-format
 #| msgid "Instrument function exit in instrumented functions with __fentry__."
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "Instrumentér funktionsafslutninger i instrumenteret funktioner med __fentry__."
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, no-c-format
 #| msgid "Instrument function exit in instrumented functions with __fentry__."
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "Instrumentér funktionsafslutninger i instrumenteret funktioner med __fentry__."
 
-#: common.opt:1818
+#: common.opt:1822
 #, fuzzy, no-c-format
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1822
+#: common.opt:1826
 #, fuzzy, no-c-format
 #| msgid "how much can given compilation unit grow because of the inlining (in percent)"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Hvor meget en oversættelsesenhed kan vokse pga. indlejring (i procent)"
 
-#: common.opt:1830
+#: common.opt:1834
 #, fuzzy, no-c-format
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1834
+#: common.opt:1838
 #, fuzzy, no-c-format
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural modref analysis."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1838
+#: common.opt:1842
 #, fuzzy, no-c-format
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural profile propagation."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1842
+#: common.opt:1846
 #, fuzzy, no-c-format
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural points-to analysis."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 #| msgid "Discard unused virtual functions"
 msgid "Discover pure and const functions."
 msgstr "Kassér ubrugte virtuelle funktioner"
 
-#: common.opt:1850
+#: common.opt:1854
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for functions."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:1858
+#: common.opt:1862
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr ""
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, fuzzy, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, fuzzy, no-c-format
 #| msgid "Store locals in argument registers"
 msgid "Share slots for saving different hard registers."
 msgstr "Gem lokale variable i parameterregistre"
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, fuzzy, no-c-format
 #| msgid "Strength reduce all loop general induction variables"
 msgid "Optimize induction variables on trees."
 msgstr "Styrkereducér alle generelle løkkeinduktionsvariabler"
 
-#: common.opt:1941
+#: common.opt:1945
 #, fuzzy, no-c-format
 #| msgid "case label not within a switch statement"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 #| msgid "case label not within a switch statement"
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: common.opt:1949
+#: common.opt:1953
 #, fuzzy, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Generér kode for funktioner selv hvis de indlejres helt"
 
-#: common.opt:1953
+#: common.opt:1957
 #, fuzzy, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "Generér kode for funktioner selv hvis de indlejres helt"
 
-#: common.opt:1957
+#: common.opt:1961
 #, fuzzy, no-c-format
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "Konstruér statiske, konstante variabler selv hvis de ikke bruges"
 
-#: common.opt:1961
+#: common.opt:1965
 #, fuzzy, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr "Eksterne symboler har indledende understreg"
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2016
+#: common.opt:2020
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "Sæt errno efter indbyggede matematikfunktioner"
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:2028
+#: common.opt:2032
 #, fuzzy, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr "Rapportér om permanente hukommelsesallokering ved afslutningen af kørslen"
 
-#: common.opt:2032
+#: common.opt:2036
 #, fuzzy, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Rapportér om permanente hukommelsesallokering ved afslutningen af kørslen"
 
-#: common.opt:2039
+#: common.opt:2043
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Forsøg at forene identiske konstanter og konstante variabler"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Forsøg at forene identiske konstanter over forskellige oversættelsesenheder"
 
-#: common.opt:2047
+#: common.opt:2051
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Forsøg at forene identiske konstanter over forskellige oversættelsesenheder"
 
-#: common.opt:2051
+#: common.opt:2055
 #, fuzzy, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "  -fmessage-length=<antal>  Begræns længden af diagnosticeringmeddelelser til længden <antal> tegn/linje. 0 undertrykker linjeombrydning\n"
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy, no-c-format
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "Tving alle løkkeinvariansberegninger ud af løkker"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy, no-c-format
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Use the RTL dead code elimination pass."
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "Foretag en komplet registerflytningsoptimering"
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "Understøt synkrone ikke-kaldende undtagelser"
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, fuzzy, no-c-format
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "Generér ikke stakrammer når det kan undgås"
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, fuzzy, no-c-format
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimér søskende- og halerekursive kald"
 
-#: common.opt:2124
+#: common.opt:2128
 #, fuzzy, no-c-format
 msgid "Perform partial inlining."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy, no-c-format
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "Pak strukturmedlemmer sammen uden mellemrum"
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 #, fuzzy, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr "Returnér små sammensatte værdier i hukommelsen, ikke i registre"
 
-#: common.opt:2148
+#: common.opt:2152
 #, fuzzy, no-c-format
 msgid "Perform loop peeling."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2152
+#: common.opt:2156
 #, fuzzy, no-c-format
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "Aktivér maskinspecifikke kighulsoptimeringer"
 
-#: common.opt:2156
+#: common.opt:2160
 #, fuzzy, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Aktivér en RTL-kikhulsfase før sched2"
 
-#: common.opt:2160
+#: common.opt:2164
 #, fuzzy, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:2164
+#: common.opt:2168
 #, fuzzy, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:2168
+#: common.opt:2172
 #, fuzzy, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:2172
+#: common.opt:2176
 #, fuzzy, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, fuzzy, no-c-format
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Aktivér en registerflytningsoptimering"
 
-#: common.opt:2192
+#: common.opt:2196
 #, fuzzy, no-c-format
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Generér præhentningsinstruktioner, hvis tilgængelige, for tabeller i løkker"
 
-#: common.opt:2196
+#: common.opt:2200
 #, fuzzy, no-c-format
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "Aktivér basal programprofileringskode"
 
-#: common.opt:2200
+#: common.opt:2204
 #, fuzzy, no-c-format
 #| msgid "Generate code for near calls"
 msgid "Generate absolute source path names for gcov."
 msgstr "Generér kode til nære kald"
 
-#: common.opt:2204
+#: common.opt:2208
 #, fuzzy, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr "Indsæt buebaseret programprofileringskode"
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, fuzzy, no-c-format
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2297
+#: common.opt:2301
 #, fuzzy, no-c-format
 #| msgid "internal gcc abort"
 msgid "Report on consistency of profile."
 msgstr "intern GCC-afbrydelse"
 
-#: common.opt:2301
+#: common.opt:2305
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "Omordn funktioner for at forbedre kodeplacering"
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 #| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "Opret cld-instruktion i en funktions begyndelse."
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, fuzzy, no-c-format
 msgid "Return small aggregates in registers."
 msgstr "Returnér små sammensatte værdier i registre"
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, fuzzy, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2372
+#: common.opt:2376
 #, fuzzy, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2376
+#: common.opt:2380
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Omordn basisblokke for at forbedre kodeplacering"
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Omordn basisblokke for at forbedre kodeplacering"
 
-#: common.opt:2397
+#: common.opt:2401
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "Omordn funktioner for at forbedre kodeplacering"
 
-#: common.opt:2401
+#: common.opt:2405
 #, fuzzy, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Kør CSE-fase efter løkkeoptimeringer"
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2413
+#: common.opt:2417
 #, fuzzy, no-c-format
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "Aktivér planlægning over basisblokke"
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "Tillad spekulativ bevægelse af ikke-indlæsninger"
 
-#: common.opt:2425
+#: common.opt:2429
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "Tillad spekulativ bevægelse af nogle indlæsninger"
 
-#: common.opt:2429
+#: common.opt:2433
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "Tillad spekulativ bevægelse af flere indlæsninger"
 
-#: common.opt:2433
+#: common.opt:2437
 #, fuzzy, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "  -fsched-verbose=<tal>    Angiv hvor meget planlæggeren skal fortælle\n"
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2445
+#: common.opt:2449
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "Omplanlæg instruktioner før registerallokering"
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "Omplanlæg instruktioner efter registerallokering"
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2506
+#: common.opt:2510
 #, fuzzy, no-c-format
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy, no-c-format
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2514
+#: common.opt:2518
 #, fuzzy, no-c-format
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy, no-c-format
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2522
+#: common.opt:2526
 #, fuzzy, no-c-format
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy, no-c-format
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Deaktivér optimeringer som kan opdages ved IEEE-signalerende NaN'er"
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, fuzzy, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr "Konvertér kommatalskonstanter til enkeltpræcisionskonstanter"
 
-#: common.opt:2571
+#: common.opt:2575
 #, fuzzy, no-c-format
 #| msgid "Strength reduce all loop general induction variables"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Styrkereducér alle generelle løkkeinduktionsvariabler"
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy, no-c-format
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "Generér APCS-overholdende stakrammer"
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy, no-c-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Antallet af registre der skal bruges til at overbringe heltalsparametre"
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Indsæt stakkontrolleringskode i programmet"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Indsæt stakkontrolleringskode i programmet"
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy, no-c-format
 #| msgid "Enable stack probing"
 msgid "Use propolice as a stack protection method."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy, no-c-format
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "Genbrug r30 på et pr. funktionsgrundlag"
 
-#: common.opt:2655
+#: common.opt:2659
 #, fuzzy, no-c-format
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "Antag at strenge aliasregler skal anvendes"
 
-#: common.opt:2659
+#: common.opt:2663
 #, fuzzy, no-c-format
 #| msgid "Set Windows defines"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Angiv Windows-definitioner"
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, fuzzy, no-c-format
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "Kontroller for syntaksfejl og stop derefter"
 
-#: common.opt:2671
+#: common.opt:2675
 #, fuzzy, no-c-format
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "Opret datafiler som »gcov« har brug for"
 
-#: common.opt:2675
+#: common.opt:2679
 #, fuzzy, no-c-format
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "Udfør springtrådningsoptimeringer"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy, no-c-format
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "Rapporter den tid det tager for hvert kompilergennemløb"
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, fuzzy, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "  -ftls-model=[global-dynamic | local-dynamic | initial-exec | local-exec] Indikerer den forvalgte tråd-lokale lagringsmodel for kodegenerering\n"
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2710
+#: common.opt:2714
 #, fuzzy, no-c-format
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "Udfør superbloksformering vha. haleduplikering"
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "Kommatalsoperationer kan fange"
 
-#: common.opt:2726
+#: common.opt:2730
 #, fuzzy, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Opsæt fælde for overløb med fortegn i addition/subtraktion/multiplikation"
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Aktivér SSA-optimeringer"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-BIT-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Aktiver SSA-BIT-CCP-optimering på træer"
 
-#: common.opt:2742
+#: common.opt:2746
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable loop header copying on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2750
+#: common.opt:2754
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA coalescing of user variables."
 msgstr "Aktiver SSA-kodesinking på træer"
 
-#: common.opt:2758
+#: common.opt:2762
 #, fuzzy, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:2766
+#: common.opt:2770
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones."
 msgstr "Udfør konvertering af betingede spring til betinget udførsel"
 
-#: common.opt:2770
+#: common.opt:2774
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Udfør konvertering af betingede spring til betinget udførsel"
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2782
+#: common.opt:2786
 #, fuzzy, no-c-format
 #| msgid "Enable most warning messages"
 msgid "Enable tail merging on trees."
 msgstr "Aktivér de fleste advarselsbeskeder"
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable dead store elimination."
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:2790
+#: common.opt:2794
 #, fuzzy, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:2794
+#: common.opt:2798
 #, fuzzy, no-c-format
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Tving alle løkkeinvariansberegninger ud af løkker"
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable string length optimizations on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 #| msgid "Enable parallel instructions"
 msgid "Enable loop distribution on trees."
 msgstr "Aktivér parallelle instruktioner"
 
-#: common.opt:2819
+#: common.opt:2823
 #, fuzzy, no-c-format
 #| msgid "Enable parallel instructions"
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Aktivér parallelle instruktioner"
 
-#: common.opt:2823
+#: common.opt:2827
 #, fuzzy, no-c-format
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Enable loop invariant motion on trees."
 msgstr "Tving alle løkkeinvariansberegninger ud af løkker"
 
-#: common.opt:2831
+#: common.opt:2835
 #, fuzzy, no-c-format
 #| msgid "Strength reduce all loop general induction variables"
 msgid "Create canonical induction variables in loops."
 msgstr "Styrkereducér alle generelle løkkeinduktionsvariabler"
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable loop optimizations on tree level."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2839
+#: common.opt:2843
 #, fuzzy, no-c-format
 #| msgid "Enable automatic template instantiation"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: common.opt:2843
+#: common.opt:2847
 #, fuzzy, no-c-format
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Aktivér brug af betingede flytteinstruktioner"
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Aktivér SSA-optimeringer"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2859
+#: common.opt:2863
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable reassociation on tree level."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2867
+#: common.opt:2871
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "Aktiver SSA-kodesinking på træer"
 
-#: common.opt:2871
+#: common.opt:2875
 #, fuzzy, no-c-format
 #| msgid "Perform strength reduction optimizations"
 msgid "Perform straight-line strength reduction."
 msgstr "Udfør styrkereduceringsoptimeringer"
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2887
+#: common.opt:2891
 #, fuzzy, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr "Anbring hele oversættelsesenheden i en fil"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Udfør løkkeudrulning når iterationsantallet er kendt"
 
-#: common.opt:2908
+#: common.opt:2912
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, fuzzy, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Tillad matematikoptimeringer der kan overtræde IEEE- eller ANSI-standarderne"
 
-#: common.opt:2940
+#: common.opt:2944
 #, fuzzy, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2944
+#: common.opt:2948
 #, fuzzy, no-c-format
 msgid "Perform loop splitting."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Generér blot afvindingstabeller for undtagelseshåndtering"
 
-#: common.opt:2956
+#: common.opt:2960
 #, fuzzy, no-c-format
 #| msgid "Use hardware quad fp instructions"
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Benyt hardware quad-kommatalsinstruktioner"
 
-#: common.opt:2960
+#: common.opt:2964
 #, fuzzy, no-c-format
 #| msgid "Use hardware quad fp instructions"
 msgid "Use the gold linker instead of the default linker."
 msgstr "Benyt hardware quad-kommatalsinstruktioner"
 
-#: common.opt:2964
+#: common.opt:2968
 #, fuzzy, no-c-format
 #| msgid "Use hardware quad fp instructions"
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Benyt hardware quad-kommatalsinstruktioner"
 
-#: common.opt:2976
+#: common.opt:2980
 #, fuzzy, no-c-format
 #| msgid "Perform tail call optimization"
 msgid "Perform variable tracking."
 msgstr "Udfør halekaldsoptimering"
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, fuzzy, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:3003
+#: common.opt:3007
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable loop vectorization on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:3015
+#: common.opt:3019
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:3019
+#: common.opt:3023
 #, fuzzy, no-c-format
 #| msgid "Specify alternate name for bss section"
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr "Angiv alternativt navn til bss-sektionen"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, no-c-format
 #| msgid "Specify alternate name for bss section"
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "Angiv alternativt navn til bss-sektionen"
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Tilføj ekstra kommentarer til menneskeligt læsbar maskinkodeuddata"
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, fuzzy, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3115
+#: common.opt:3119
 #, fuzzy, no-c-format
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Aktivér brug af betingede flytteinstruktioner"
 
-#: common.opt:3119
+#: common.opt:3123
 #, fuzzy, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:3123
+#: common.opt:3127
 #, fuzzy, no-c-format
 #| msgid "Set Windows defines"
 msgid "Assume pointer overflow wraps around."
 msgstr "Angiv Windows-definitioner"
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3131
+#: common.opt:3135
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "Anbring nul-klargjorte data i bss-sektionen"
 
-#: common.opt:3135
+#: common.opt:3139
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Clear call-used registers upon function return."
 msgstr "Gem registre omkring funktionskald"
 
-#: common.opt:3139
+#: common.opt:3143
 #, fuzzy, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, fuzzy, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3175
+#: common.opt:3179
 #, fuzzy, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Generér fejlfindingsinfo i udvidet standardformat"
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Generér et enkelt afslutningspunkt for hver funktion"
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, fuzzy, no-c-format
 #| msgid "Don't generate fused multiply/add instructions"
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Generér ikke sammensatte gang/addér-instruktioner"
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Opret sektioner for DWARF-pubnavne og pubtyper."
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Opret sektioner for DWARF-pubnavne og pubtyper med GNU-udvidelser."
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in separate .dwo files"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Opret fejlsøgningsinformation i separate .dwo-filer"
 
-#: common.opt:3223
+#: common.opt:3227
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "Opret fejlsøgningsinformation i STABS-format"
 
-#: common.opt:3227
+#: common.opt:3231
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Opret fejlsøgningsinformation i udvidet STABS-format"
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, fuzzy, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "Opret fejlsøgningsinformation i VMS-format"
 
-#: common.opt:3258
+#: common.opt:3262
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "Opret fejlsøgningsinformation i XCOFF-format"
 
-#: common.opt:3262
+#: common.opt:3266
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Opret fejlsøgningsinformation i udvidet XCOFF-format"
 
-#: common.opt:3280
+#: common.opt:3284
 #, fuzzy, no-c-format
 #| msgid "Generate compressed debug sections"
 msgid "Generate compressed debug sections."
 msgstr "Opret komprimeret fejlsøgningssektioner"
 
-#: common.opt:3284
+#: common.opt:3288
 #, fuzzy, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <fil>                Anbring uddata i <fil>\n"
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 msgid "Enable function profiling."
 msgstr "MIPS16-funktionsprofilering"
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3374
+#: common.opt:3378
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Vis ikke funktioner der oversættes eller forløbet tid"
 
-#: common.opt:3406
+#: common.opt:3410
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Aktiver uddybende uddata"
 
-#: common.opt:3410
+#: common.opt:3414
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Vis oversætterens version"
 
-#: common.opt:3414
+#: common.opt:3418
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Undertryk advarsler"
 
-#: common.opt:3424
+#: common.opt:3428
 #, fuzzy, no-c-format
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "Opret et delt bibliotek"
 
-#: common.opt:3472
+#: common.opt:3476
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:3476
+#: common.opt:3480
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:3480
+#: common.opt:3484
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -20717,1142 +20717,1152 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "Tærskelforholdet for udførsel af delvis redundanseleminering efter genindlæsning."
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "Minimal heap-udvidelse for at udløse affaldsindsamling, som en procentdel af den samlede størrelse på heap'en."
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "Minimal heap-størrelse før vi starter affaldsindsamling, i kilobyte."
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr "Om codegen-fejl skal være ICE'er når -fckhcking."
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 #| msgid "Maximum number of arrays per scop."
 msgid "Maximum number of arrays per SCoP."
 msgstr "Maksimalt antal tabeller per scop."
 
-#: params.opt:210
+#: params.opt:215
 #, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr "Maksimalt antal parametre i en SCoP."
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal count of repetitions of basic block in program given basic block needs to have to be considered hot (used in non-LTO mode)."
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "Vælg den andel af det maksimale antal gentagelser af basisblokke i et program en given basisblok skal have for at blive betragtet som »varm« (brugt i ikke-LTO-tilstand)."
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot."
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "Vælg den andel af den maksimale frekvens af udførsler af basisblokke i et program en given basisblok skal have for at blive betragtet som »varm«."
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr "Den mindste estimeret speedup der tillader indbyggeren at ignorere inline-insns-single og inline-insns-auto."
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "Hvor meget en oversættelsesenhed kan vokse pga. indlejring (i procent)."
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "The upper bound for sharing integer constants."
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions."
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "Den maksimale dybde for rekursiv indbygning af indbyggede funktioner."
 
-#: params.opt:258
+#: params.opt:263
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Indbyg rekursivt kun når sandsynligheden for kald under kørsel er højere end parameteren."
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "Hvor meget en oversættelsesenhed kan vokse pga. den interprocedurale konstantformering (i procent)."
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large."
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "Størrelsen af en oversættelsesenhed som anses for stor."
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "Det maksimale antal instruktioner i »ready«-listen som anses for klar til omdøbning."
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr "Maks. størrelse på konfliktabel i MB."
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr "Maks. løkkeantal for regional RA."
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr ""
 
-#: params.opt:330
+#: params.opt:335
 #, fuzzy, no-c-format
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "Udfør et antal mindre, dyre optimeringer"
 
-#: params.opt:334
+#: params.opt:339
 #, fuzzy, no-c-format
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "Udfør et antal mindre, dyre optimeringer"
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr "Størrelsen på L1-mellemlagerlinje."
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr "Størrelsen på L1-mellemlageret."
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr "Størrelsen på L2-mellemlageret."
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Maksimal kodevækst forårsaget af indlejring af stor funktion (i procent)."
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr "Størrelsen af en funktionskrop som anses for stor."
 
-#: params.opt:366
+#: params.opt:371
 #, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "Størrelsen af en stakramme som anses for stor."
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Maksimal stakrammevækst forårsaget af indlejring (i procent)."
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr "Størrelsen af en oversættelsesenhed som anses for stor."
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "Den minimale omkostning for et dyrt udtryk i løkkeinvariant-bevægelsen."
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "Det maksimale antal instruktioner der overvejes at udrulle i en løkke i gennemsnit."
 
-#: params.opt:398
+#: params.opt:403
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically."
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "Det maksimale antal løkkegennemløb vi forudser statistisk."
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr "Maksimalt antal datareferencer i loop for bygning af loop-dataafhængigheder."
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in basic block to be considered for SLP vectorization."
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "Maksimalt antal instruktioner i basisblokke som skal overvejes i SLP-vektorisering."
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop."
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "Det maksimale antal instruktioner der overvejes at udrulle i en løkke."
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "Det maksimale antal instruktioner der overvejes at udrulle i en løkke i gennemsnit."
 
-#: params.opt:446
+#: params.opt:451
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of insns combine tries to combine."
 msgstr "Det maksimale antal indadgående kanter der overvejes til krydsspring"
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "Den maksimale dybde for en løkkerede vi skrædder fuldstændig."
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Det maksimale antal skrælninger i en enkelt løkke, som skrælles fuldstændig."
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "Det maksimale antal instruktioner for en fuldstændig skrællet løkke."
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "Det maksimale antal indadgående kanter der overvejes til krydsspring."
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr "Det maksimale antal instruktioner CSE behandler før tømning."
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr "Den maksimale længde af stien som bruges i cse."
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Det maksimale antal hukommelseslokationer registreret af cselib."
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "Det maksimale antal instruktioner det overvejes at udfylde ventepladser med."
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "Det maksimale antal instruktioner der overvejes under søgning efter præcis registerinfo."
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "Det maksimale antal af indlejret indirekte indbygning udført af tidlig indbygger."
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr ""
 
-#: params.opt:502
+#: params.opt:507
 #, fuzzy, no-c-format
 #| msgid "maximum number of basic blocks per function to be analyzed by Graphite"
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr "Det maksimale antal grundlæggende blokke per funktion, der skal analyseres af Graphite"
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to fill a delay slot"
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "Det maksimale antal instruktioner det overvejes at udfylde ventepladser med"
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "Det maksimale forhold for indsættelser af sletninger for udtryk i GCSE."
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE."
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "Den maksimale mængde hukommelse som skal allokeres af GCSE."
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "Det maksimale antal instruktioner at duplikere når der fjernes faktorering af beregneder goto'er."
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "Den maksimale udvidelsesfaktor når basisblokke kopieres."
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "Det maksimale antal instruktioner ved automatisk indbygning."
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "Det maksimale antal instruktioner en indbygget funktion kan vokse via rekursiv indbygning."
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "Det maksimale antal instruktioner en ikke-indbygget funktion kan vokse via rekursiv indbygning."
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "Det maksimale antal instruktioner i en enkelt funktion der må indbygges."
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr "Det maksimale antal instruktioner ved automatisk indbygning for størrelse."
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "Det maksimale antal instruktioner ved automatisk indbygning af små funktioner."
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "Den maksimale dybde for rekursiv indbygning af indbyggede funktioner."
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "Den maksimale dybde for rekursiv indbygning for ikke-indbyggede funktioner."
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Maksimalt antal isl-operationer, 0 betyder ubegrænset"
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr ""
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr ""
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr ""
 
-#: params.opt:582
+#: params.opt:587
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "Det maksimale antal indadgående kanter der overvejes til krydsspring"
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "Det maksimale antal instruktioner i løkketeksthoveder duplikeret af kopiløkkehoveders gennemløb."
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "Det maksimale antal tilbagesporingsforsøg planlæggeren skal udføre når et loop moduloplanlægges."
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "Det maksimale antal grene på stien via den skrællede sekvens."
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "Det maksimale antal skrælninger for en enkel løkke."
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr "Det maksimale antal instruktioner for en skrællet løkke."
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "Den maksimale længde af planlæggerens liste over ventende operationer."
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "Det maksimale antal blokke i en region der overvejes til mellemblokplanlægning."
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "Det maksimale antal instruktioner i en region der overvejes til mellemblokplanlægning."
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr "Den maksimale dybde for sqrt-kæder at bruge når der syntetiseres eksponentiation af en rigtig konstant."
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "Det maksimale antal løkkegennemløb vi forudser statistisk."
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "Det maksimale antal instruktioner til at søge baglæns når der kigges efter tilsvarende genindlæsning."
 
-#: params.opt:634
+#: params.opt:639
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in basic block to be considered for SLP vectorization"
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Det maksimale antal instruktioner i basisblokke som skal overvejes i SLP-vektorisering"
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "Det maksimale antal instruktioner der overvejes at udrulle i en løkke"
 
-#: params.opt:650
+#: params.opt:655
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "Det maksimale antal indadgående kanter der overvejes til krydsspring"
 
-#: params.opt:654
+#: params.opt:659
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "Det maksimale antal instruktioner der overvejes at udrulle i en løkke"
 
-#: params.opt:666
+#: params.opt:671
 #, fuzzy, no-c-format
 #| msgid "Perform strength reduction optimizations"
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr "Udfør styrkereduceringsoptimeringer"
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "Maksimalt antal konstante lagre at sammenføje i gennemløbet for lagersammenføjelse."
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr ""
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 #| msgid "Maximum number of constant stores to merge in the store merging pass."
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "Maksimalt antal konstante lagre at sammenføje i gennemløbet for lagersammenføjelse."
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Det maksimale antal af udrulninger for en enkel løkke."
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "Det maksimale antal instruktioner der overvejes at udrulle i en løkke."
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "Det maksimale antal instruktioner for en ikke løkke uden afbryder."
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Det maksimale antal afbrydelser i en enkel løkke."
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "Hvis -fvariable-expansion-in-unroller bruges, det maksimale antal gange som en individuel variabel vil blive udvidet under loopudrulning."
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, fuzzy, no-c-format
 #| msgid "Maximum number of constant stores to merge in the store merging pass."
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr "Maksimalt antal konstante lagre at sammenføje i gennemløbet for lagersammenføjelse."
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "Det maksimale antal indadgående kanter der overvejes til krydsspring."
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Indbyg rekursivt kun når sandsynligheden for kald under kørsel er højere end parameteren."
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "Det maksimale antal indadgående kanter der overvejes til krydsspring"
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "Hvis -ftree-vectorize bruges, den minimale loopgrænse for et loop der overvejes for vektorisering."
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop."
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Det maksimale antal instruktioner der overvejes at udrulle i en løkke."
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr "Maksimal sandsynlighed for at indgangs-BB'en for split-region (i procent relativ til indgangs-BB for funktioner) for at delvis indbygning opstår."
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "Maksimalt estimeret resultat for gren anses for at være forudsigeligt."
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "Antallet af instruktioner før prefetch er færdig."
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr "Brug intern funktions-id i profilopslag."
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "Den maksimale dybde for en løkkerede til fuld værdi-nummer optimistisk."
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr ""
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "Det maksimale antal instruktioner i »ready«-listen som anses for klar til omdøbning."
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr ""
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr "Antallet af prefetch'er som kan afvikles på samme tidspunkt."
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr ""
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr ""
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr ""
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr "Den mindstre værdi for trinoptælling som swing modulo-planlæggeren vil oprette."
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "Det maksimale antal instruktioner der overvejes at udrulle i en løkke i gennemsnit."
 
-#: params.opt:928
+#: params.opt:946
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "Det maksimale antal indadgående kanter der overvejes til krydsspring"
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr ""
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 #| msgid "Maximum number of parameters in a SCoP."
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "Maksimalt antal parametre i en SCoP."
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 #| msgid "Maximum number of parameters in a SCoP."
 msgid "Maximum number of references stored in each modref base."
 msgstr "Maksimalt antal parametre i en SCoP."
 
-#: params.opt:960
+#: params.opt:978
 #, fuzzy, no-c-format
 #| msgid "Maximum number of constant stores to merge in the store merging pass."
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "Maksimalt antal konstante lagre at sammenføje i gennemløbet for lagersammenføjelse."
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 #| msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgid "Maximum number of tests performed by modref query."
 msgstr "Det maksimale antal af indlejret indirekte indbygning udført af tidlig indbygger."
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, fuzzy, no-c-format
 #| msgid "Maximum number of constant stores to merge in the store merging pass."
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "Maksimalt antal konstante lagre at sammenføje i gennemløbet for lagersammenføjelse."
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "Den procendel af funktioner vægtet efter udførselsfrekvens som skal dækkes af sporingsformering; benyttes når profileringstilbagemelding ikke er tilgængeligt"
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "Den procendel af funktioner vægtet efter udførselsfrekvens som skal dækkes af sporingsformering; benyttes når profileringstilbagemelding er tilgængeligt."
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Maksimal kodevækst forårsaget af haleduplikering (i procent)."
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "Stop fremadrettet vækst hvis sandsynligheden for den bedste kant er mindre end denne tærskel (i procent). Benyttes når profileringstilbagemelding ikke er tilgængelig"
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "Stop fremadrettet vækst hvis sandsynligheden for den bedste kant er mindre end denne tærskel (i procent). Benyttes når profileringstilbagemelding er tilgængelig."
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "Stop omvendt vækst hvis den omvendte sandsynlighed for den bedste kant er mindre end denne tærskel (i procent)."
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "Udsend kun eksplicitte instatieringer af indlejrede skabeloner"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "Instruktion medtaget forfunktionsindledning/-afslutning og andre systembyrder."
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "Tid medtaget for funktionsindledning/-afslutninger og andre systembyrder"
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr "Instruktion medtaget for funktion thunk-systembyrde."
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr "Tid medtaget for funktion thunk-systembyrde."
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr "Om der skal bruges kanoniske typer."
 
-#: params.opt:1056
+#: params.opt:1074
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: params.opt:1060
+#: params.opt:1078
 #, fuzzy, no-c-format
 #| msgid "Maximum number of namespaces to search for alternatives when name lookup fails."
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr "Det maksimale antal navnerum der søges i efter alternativer, når navneopslag mislykkes."
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr ""
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -21885,7 +21895,7 @@ msgid "expected boolean type"
 msgstr "forventet boolesk type"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "uventet operand"
@@ -21959,7 +21969,7 @@ msgstr "ikke nok parametre"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "for mange parametre"
@@ -22362,7 +22372,7 @@ msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration here"
@@ -22424,7 +22434,7 @@ msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -22453,20 +22463,20 @@ msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
@@ -22479,8 +22489,8 @@ msgstr "egenskaben '%s' ignoreret"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "tidligere erklæring af %qD"
@@ -22491,59 +22501,59 @@ msgstr "tidligere erklæring af %qD"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr ""
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr ""
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr ""
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, fuzzy, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "statisk variabel '%s' er markeret dllimport"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr ""
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr ""
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "%qD-mål erklæret her"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -22660,7 +22670,7 @@ msgstr "  '%#D' erklæret her"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "forskydning udenfor grænserne af konstant streng"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qE declared here"
@@ -22690,557 +22700,557 @@ msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "ugyldig tredje parameter til '__builtin_prefetch'; benytter nul"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "source object declared here"
 msgstr "  '%#D' erklæret her"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "destination object declared here"
 msgstr "  '%#D' erklæret her"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 #| msgid "a function-definition is not allowed here"
 msgid "destination object allocated here"
 msgstr "en funktionsdefinition er ikke tilladt her"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `va_start'"
 msgid "too few arguments to function %<va_start%>"
 msgstr "for mange parametre til funktionen 'va_start'"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid argument to %qD"
 msgstr "ugyldig typeparameter"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument to %qD"
@@ -23248,97 +23258,97 @@ msgstr "ubenyttede parametre i formatering med $"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_eh_return_regno' must be constant"
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "parameteren til '__builtin_eh_return_regno' skal være konstant"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-member function `%D'"
 msgid "trampoline generated for nested function %qD"
 msgstr "startværdi angivet for ikke-medlemsfunktion '%D'"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, fuzzy, gcc-internal-format
 #| msgid "Tune alignment for the specified chip or CPU version"
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "Finjustér justering til en given chip- eller processorversion"
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type `%T' for default argument to `%T'"
 msgid "invalid memory model argument to builtin"
 msgstr "ugyldig type '%T' for standardparameter til '%T'"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ugyldig tilstand for gen_tst_reg"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "non-constant argument 1 to %qs"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "non-integer argument 1 to %qs"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return understøttes ikke på målarkitekturen"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return understøttes ikke på målarkitekturen"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr "-g er kun understøttet ved brug af GAS på denne processor,"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "non-constant argument 0 to %qs"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "illegal argument 0 to %qs"
@@ -23346,135 +23356,135 @@ msgstr "ugyldig typeparameter"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_longjmp second argument must be 1"
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "den anden paramter til '__builtin_longjmp' skal være 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "målprocessoren understøtter ikke uendelig"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "`va_start' used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "`va_start' benyttet i en funktion med fast antal parametre"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `va_start'"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "for mange parametre til funktionen 'va_start'"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "`__builtin_next_arg' kaldt uden en parameter"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "forkert antal parametre angivet til egenskaben '%s'"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of `va_start' not last named argument"
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "den anden parameter til 'va_start' er ikke den sidste navngivne parameter"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared here"
 msgstr "  '%#D' erklæret her"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "returned from %qD"
 msgstr "kaldt herfra"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "returned from %qT"
 msgstr "kaldt herfra"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "obtained here"
 msgstr "'%s' tidligere defineret her"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "assigned here"
 msgstr "'%s' tidligere defineret her"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -24320,317 +24330,317 @@ msgstr "basisblokkene er ikke nummeret i rækkefølge"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "antallet af basisbloknoter i instruktionskæden (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "caller edge count invalid"
 msgstr "venstreskiftsantal er negativ"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing counts for called function %s/%i"
 msgid "missing direct call for speculation %i"
 msgstr "Manglende antal for kaldt funktion %s/%i"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "manglende barriere efter blok %i"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "startværdielement er ikke en konstant"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "tp_first_run must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "no symbol table found"
 msgid "local symbols must be defined"
 msgstr "ingen symboltabel fundet"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 #| msgid "`return' with no value, in function returning non-void"
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "edge count is not compatible with function count"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, fuzzy, gcc-internal-format
 #| msgid "section pointer missing"
 msgid "inlined_to pointer is wrong"
 msgstr "sektionshenvisning mangler"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple inline callers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "caller edge count does not match BB count"
 msgstr "venstreskiftsantal er negativ"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer to bit-field `%D'"
 msgid "inlined_to pointer refers to itself"
 msgstr "ugyldig henvisning til bitfeltet '%D'"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' used prior to declaration"
 msgid "edge points to wrong declaration:"
 msgstr "'%s' benyttes før erklæringen"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "origin points to a different parent"
 msgstr "typeomtvingelse fra henvisning til heltal af en anden størrelse"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, fuzzy, gcc-internal-format
 #| msgid "verify_flow_info failed"
 msgid "verify_cgraph_node failed"
 msgstr "verify_flow_info mislykkedes"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "string section missing"
 msgid "%s: section %s.%d is missing"
@@ -24722,12 +24732,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F brugt, men aldrig defineret"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F erklæret %<static%>, men aldrig defineret"
@@ -24805,7 +24815,7 @@ msgstr "%Jstørrelsen af returtypen til '%D' er %u byte"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "%Jstørrelsen af returtypen til '%D' er større end %wd byte"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr ""
@@ -25242,12 +25252,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -25268,7 +25278,7 @@ msgstr ""
 msgid "internal consistency failure"
 msgstr "intern GCC-afbrydelse"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn brugt hvor emit_jump_insn behøves:\n"
@@ -25410,45 +25420,45 @@ msgstr "kunne ikke åbne dumpningsfilen '%s'"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "stort heltal forkortes underforstået til type uden fortegn"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "sammenligning er altid %d på grund af den begrænsede rækkevidde af bitfeltet"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "sammenligning er altid %d"
 
 # RETMIG: det giver ikke mening
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, fuzzy, gcc-internal-format
 #| msgid "`or' of unmatched not-equal tests is always 1"
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "'or' af uafbalancerede sammenligninger med forskellig fra er altid 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "`and' of mutually exclusive equal-tests is always 0"
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "'and' af udtryk der hver for sig udelukker hinanden, er altid 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -25465,7 +25475,7 @@ msgstr "størrelsen af tabellen '%s' er for stor"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "impossible constraint in `asm'"
 msgid "impossible constraint in %<asm%>"
@@ -26127,7 +26137,7 @@ msgstr "henvisning"
 msgid "function may return address of local variable"
 msgstr "funktion kan returnere adressen på en lokal variabel"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "funktion returnerer adressen på en lokal variabel"
@@ -26503,71 +26513,71 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "formateringsstreng er nul"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 #| msgid "invalid use of `%D'"
 msgid "%Guse of %<alloca%>"
 msgstr "ugyldig brug af '%D"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 #| msgid "Warn when a variable is unused"
 msgid "%Gargument to variable-length array may be too large"
 msgstr "Advar når en variabel ikke benyttes"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 #| msgid "Warn when a variable is unused"
 msgid "%Gargument to variable-length array is too large"
 msgstr "Advar når en variabel ikke benyttes"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 #| msgid "ISO C++ forbids variable-size array"
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 #| msgid "invalid use of `%D'"
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "ugyldig brug af '%D"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 #, fuzzy
 #| msgid "invalid use of `%D'"
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "ugyldig brug af '%D"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 #| msgid "Warn when a variable is unused"
 msgid "%Gargument to variable-length array is zero"
 msgstr "Advar når en variabel ikke benyttes"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%Gargument to %<alloca%> is zero"
@@ -26687,7 +26697,7 @@ msgstr "højreskiftsantal er negativ"
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "array %qD declared here"
@@ -26716,11 +26726,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qD declared here"
@@ -26807,333 +26817,333 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "ugyldig venstreværdi i asm-sætning"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "output number %d not directly addressable"
 msgid "memory input %d is not directly addressable"
 msgstr "uddata nr. %d kan ikke adresseres direkte"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing region"
 msgstr "fejl ved lukning af %s: %m"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qE not specified in enclosing %qs"
 msgstr "'%D' ikke erklæret"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "fejl ved lukning af %s: %m"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, fuzzy, gcc-internal-format
 #| msgid "In construct"
 msgid "enclosing OpenACC %qs construct"
 msgstr "I konstruktionen"
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "'%s' er ikke erklæret (først benyttet i denne funktion)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "'%D' ikke erklæret"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %<target%>"
 msgstr "fejl ved lukning af %s: %m"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should be private"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qE should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be linear"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid private reduction on %qE"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, fuzzy, gcc-internal-format
 #| msgid "directives may not be used inside a macro argument"
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "direktiver må ikke optræde inden i en makroparameter"
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, fuzzy, gcc-internal-format
 #| msgid "directives may not be used inside a macro argument"
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "direktiver må ikke optræde inden i en makroparameter"
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "antallet af resultater matcher ikke antallet af værdier"
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is promoted to `%s' when passed through `...'"
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "'%s' forfremmes til '%s' ved overbringelse gennem '...'"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, fuzzy, gcc-internal-format
 #| msgid "(so you should pass `%s' not `%s' to `va_arg')"
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(så du skal overbring '%s' ikke '%s' til 'va_arg')"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -27616,23 +27626,23 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s kan ikke bruges i asm her"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr ""
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "rammestørrelse for stor til pålidelig stakkontrol"
@@ -27654,13 +27664,13 @@ msgstr "'asm'-operand %d passer sandsynligvis ikke til begrænsninger"
 msgid "unable to find a register to spill"
 msgstr "kan ikke finde et register at bortødsle i klassen '%s'"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent operand constraints in an `asm'"
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "inkonsistente operandbegræsninger i 'asm'"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
@@ -28412,13 +28422,13 @@ msgstr "-malign-functions=%d er ikke mellem 1 og %d"
 msgid "unrecognized argument in option %qs"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s"
@@ -28552,7 +28562,7 @@ msgstr "-traditional understøttes ikke i C++"
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
@@ -29107,25 +29117,25 @@ msgstr "implicit aflæste registre skal grupperes i toppen af stakken"
 msgid "output operand %d must use %<&%> constraint"
 msgstr "uddataoperand %d skal bruge %<&%>-begrænsningen"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "validate_value_data: [%u] Ugyldig next_regno til tom kæde (%u)"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: Loop in regno chain (%u)"
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "validate_value_data: Løkke i registertalskæde (%u)"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "validate_value_data: [%u] Ugyldig oldest_regno (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
@@ -29191,13 +29201,13 @@ msgstr "kan ikke genindlæse heltalskonstantoperand i %<asm%>"
 msgid "impossible register constraint in %<asm%>"
 msgstr "umulig registerbegrænsing i %<asm%>"
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "denne målarkitektur understøtter ikke %qs"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "%<&%>-begrænsning brugt uden registerklasse"
@@ -29228,53 +29238,53 @@ msgstr "%<asm%>-operandbegrænsning er ikke forenelig med operandstørrelse"
 msgid "output operand is constant in %<asm%>"
 msgstr "uddataoperand er konstant i %<asm%>"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "RTL-kontrol: tilgang til udtrykstræ %d fra »%s« med sidste udtrykstræ %d i %s, ved %s:%d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL-kontrol: forventede udtrykstræ %d type »%c«, har »%c« (registeroverførselsudtryk %s) i %s, ved %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL-kontrol: forventede udtrykstræ %d type »%c« eller »%c«, har »%c« (registeroverførselsudtryk %s) i %s, ved %s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL-kontrol: forventede koden »%s«, har »%s« i %s, ved %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL-kontrol: forventede koden »%s« eller »%s«, har »%s« i %s, ved %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL-kontrol: forventede koden »%s« eller »%s«, har »%s« i %s, ved %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "RTL-kontrol: forsøg på at opfatte ikke-blok symbol som et bloksymbol i %s, ved %s:%d"
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL-kontrol: tilgang til hwi-udtrykstræ %d af vektor hvis sidste udtrykstræ er %d i %s, ved %s:%d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL-kontrol: tilgang til udtrykstræ %d af vektor hvis sidste udtrykstræ er %d i %s, ved %s:%d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "RTL-flagkontrol: %s benyttet med uventet rtx-kode »%s« i %s, ved %s:%d"
@@ -29319,23 +29329,23 @@ msgstr "begrænsning refererer til et ugyldigt operandtal"
 msgid "invalid punctuation %qc in constraint"
 msgstr "ugyldig punktuering %qc i begrænsning"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "matchbegrænsningen tillader ikke et register"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate asm operand name %qs"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "asm-operandnavnet %qs optræder mere end en gang"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "manglende afsluttende krøllet parantes til navngiven operand"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "ikkedefineret navngiven operand %qs"
@@ -30066,9 +30076,9 @@ msgstr "ugyldig operand til %%R"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in %qs"
@@ -30110,7 +30120,7 @@ msgstr "ugyldig %%f-operand"
 msgid "invalid clique in %qs"
 msgstr "ugyldig brug af '%D"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 #| msgid "INDIRECT_REF in gimple IL"
 msgid "%qs in gimple IL"
@@ -30342,408 +30352,408 @@ msgstr "ugyldig operand i instruktionen"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "vector types expected in %qs"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "vectors with different element number found in %qs"
 msgstr "operander til ?: har forskellige typer"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid mask type in %qs"
 msgstr "ugyldig roteringsinstruktion"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "ikke-understøttet kombination: %s"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size in %qs"
 msgstr "ugyldig position eller størrelsesoperant for BIT_FIELD_REF"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 #| msgid "`sigof' applied to non-aggregate expression"
 msgid "%qs into non-mode-precision operand"
 msgstr "'sigof' benyttet på et udtryk der ikke er af en sammensat type"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "insertion out of range in %qs"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a directory"
 msgid "%qs not at element boundary"
 msgstr "%qs er ikke en mappe"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "%qs LHS in clobber statement"
 msgstr "Ugyldig klargøringssætning"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "ugyldig operand til %%R"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid indirect memory address"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "ugyldig indirekte hukommelsesadresse"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "incorrect type of vector %qs elements"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "incorrect number of vector %qs elements"
 msgstr "for få parametre til funktionen '%s'"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "non-vector %qs with elements"
 msgstr "operander til ?: har forskellige typer"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR med en altid-falsk betingelse"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in return statement"
 msgstr "ugyldig operand i instruktionen"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "invalid conversion in return statement"
 msgstr "Ugyldig klargøringssætning"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "goto destination is neither a label nor a pointer"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to switch statement"
 msgstr "ugyldig operand til %%s-koden"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code for huge switch statements"
 msgid "non-integral type switch statement"
 msgstr "Generér kode til store switch-sætninger"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "invalid case label in switch statement"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid case range in switch statement"
 msgstr "ugyldig venstreværdi i asm-sætning"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "parameternavne (uden typer) i funktionserklæringen"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, fuzzy, gcc-internal-format
 #| msgid "format string has invalid operand number"
 msgid "incorrect setting of landing pad number"
 msgstr "formateringsstrengen har et ugyldigt operandtal"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%p code"
 msgid "invalid comparison code in gimple cond"
 msgstr "ugyldig operand til %%p-koden"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in increment"
 msgid "invalid labels in gimple cond"
 msgstr "ugyldig venstreværdi i forøgelse"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid address"
 msgid "invalid %<PHI%> result"
 msgstr "ugyldig adresse"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "missing %<PHI%> def"
 msgstr "manglende tal"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid %<PHI%> argument"
 msgstr "ugyldig typeparameter"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in %s"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "uforenelige typer i %s"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 #| msgid "verify_flow_info failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_flow_info mislykkedes"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "local declaration from a different function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, fuzzy, gcc-internal-format
 #| msgid "verify_flow_info failed"
 msgid "verify_gimple failed"
 msgstr "verify_flow_info mislykkedes"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "flow control insn inside a basic block"
 msgid "control flow in the middle of basic block %d"
 msgstr "strømkontrolinstruktion inden i en basisblok"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fallthru edge after unconditional jump %i"
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "Fald gennem-kant efter ubetinget spring %i"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit goto at end of bb %d"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "case labels not sorted: "
 msgstr "trampoliner understøttes ikke"
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing field '%s' in '%s'"
 msgid "missing edge %i->%i"
 msgstr "manglende felt '%s' i '%s'"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "`noreturn' function does return"
 msgid "%<noreturn%> function does return"
 msgstr "funktion med egenskaben 'noreturn' returnerer"
 
 # RETMIG: dette må kunne gøres bedre
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "kontrol når til slutningen af ikke-void funktion"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -31893,7 +31903,7 @@ msgstr "tråd-lokal COMMON-data er ikke implementeret"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%Jforespurgt justering for '%D' er større end den implementerede justering på %d"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't known"
 msgid "storage size of %q+D isn%'t known"
@@ -32067,7 +32077,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported record layout"
@@ -32747,7 +32757,7 @@ msgstr ""
 msgid "type was previously declared %qE"
 msgstr "'%s' tidligere erklæret her"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -32769,7 +32779,7 @@ msgstr "-march=%s er ikke forenelig med den valgte ABI"
 msgid "%qE argument is not a function"
 msgstr "ingen parametre til specifikationsfunktion"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "second token after #line is not a string"
 msgid "deprecated message is not a string"
@@ -33242,12 +33252,12 @@ msgstr "heltalskonstanten er for stor for dens type"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "foreslår paranteser omkring tildeling der er benyttet som boolsk værdi"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<restrict%>"
@@ -33430,14 +33440,14 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %qE"
 msgstr "for få parametre til funktionen"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %qE"
@@ -34487,7 +34497,7 @@ msgstr "muligvis begyndelsen af uafsluttet strengkonstant"
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionel C tillader ikke strengsammensætning"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -34539,7 +34549,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid type for iteration variable %qE"
@@ -34557,19 +34567,19 @@ msgstr "ugyldig vektortype for egenskaben '%s'"
 msgid "%qE is not initialized"
 msgstr "manglende startværdi"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, fuzzy, gcc-internal-format
 #| msgid "missing '(' after predicate"
 msgid "missing controlling predicate"
 msgstr "manglende '(' efter udsagn"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid controlling predicate"
 msgstr "Ugyldigt kontroludtryk"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, fuzzy, gcc-internal-format
 #| msgid "missing ')' in expression"
 msgid "missing increment expression"
@@ -34580,7 +34590,7 @@ msgstr "manglende ')' i udtryk"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid increment expression"
@@ -34650,7 +34660,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -35279,8 +35289,8 @@ msgstr "returnering"
 msgid "wrong type argument to %s"
 msgstr "forkert parametertype til %s"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overløb i konstant udtryk"
@@ -35824,19 +35834,19 @@ msgstr "for få parametre til funktionen '%s'"
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only location"
 msgid "assignment of read-only location %qE"
 msgstr "%s af placering der kun må læses"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only location"
 msgid "increment of read-only location %qE"
 msgstr "%s af placering der kun må læses"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only location"
 msgid "decrement of read-only location %qE"
@@ -36042,8 +36052,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "comparison between types %qT and %qT"
@@ -36128,39 +36138,39 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 msgstr[1] "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, fuzzy, gcc-internal-format
 #| msgid "the conditional began here"
 msgid "this condition has identical branches"
 msgstr "betingelsen begyndte her"
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 #| msgid "in passing argument %P of `%+D'"
 msgid "mismatch in bound %Z of argument %u declared as %s"
@@ -36168,54 +36178,54 @@ msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "i overbringelse af parameter %P af '%+D'"
 msgstr[1] "i overbringelse af parameter %P af '%+D'"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "previously declared as %s"
 msgstr "'%s' tidligere erklæret her"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn when a variable is unused"
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "Advar når en variabel ikke benyttes"
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "previously declared as a pointer %s"
 msgstr "'%s' tidligere erklæret her"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "previously declared as an ordinary array %s"
 msgstr "'%s' tidligere erklæret her"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument %u of type %s declared as a pointer"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "previously declared as a variable length array %s"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "previously declared as an array %s"
 msgstr "'%s' tidligere erklæret her"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "argument %u of type %s declared with %u variable bound"
@@ -36223,81 +36233,81 @@ msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 msgstr[1] "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "tidligere erklæring af funktionen '%s' med egenskaben noinline"
 msgstr[1] "tidligere erklæring af funktionen '%s' med egenskaben noinline"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type `%T' does not match `%T'"
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "parameter af typen '%T' passer ikke til '%T'"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "previously declared as %s with bound argument %E"
 msgstr "'%s' tidligere erklæret her"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%s'"
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "'%s' er tidligere erklæret"
 
 # hænger sammen med næste tekst
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previously declared as %s with bound %qs"
 msgstr "tidligere erklæring '%D'"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type `%T' does not match `%T'"
 msgid "argument %u of type %s with mismatched bound"
 msgstr "parameter af typen '%T' passer ikke til '%T'"
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -36312,7 +36322,7 @@ msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 msgid "too many input files"
 msgstr "for mange inddatafiler"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -36347,15 +36357,15 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s"
@@ -36522,64 +36532,64 @@ msgstr "-mregparm=%d er ikke mellem 0 og %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "type of `%E' is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
@@ -36759,84 +36769,84 @@ msgstr "-mcpu=%s er i konflikt med tilvalget -march=%s"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr ""
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr ""
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr ""
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "visibility attribute not supported in this configuration; ignored"
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "synlighedsegenskab er ikke understøttet i denne konfiguration; ignoreret"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr ""
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "egenskaben '%s' er ikke understøttet på denne platform"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr ""
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr ""
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, fuzzy, gcc-internal-format
 #| msgid "string section missing"
 msgid "CFString literal is missing"
 msgstr "strengsektion mangler"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, fuzzy, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr ""
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "embedded NUL in CFString literal"
@@ -36844,7 +36854,7 @@ msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr ""
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -36998,414 +37008,414 @@ msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "ragelse i slutningen af #pragma GCC java_exceptions"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new kan ikke bruges på en funktionstype"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "%<,%> eller %<)%> forventet"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the Xtensa NSA option"
 msgid "this operation requires the SVE ISA extension"
 msgstr "Benyt ikke Xtensa-NSA-indstillingen"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the Xtensa NSA option"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Benyt ikke Xtensa-NSA-indstillingen"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "invalid format for sve_width"
 msgstr "ugyldigt tilvalg %s"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %h value"
 msgid "invalid sve_width value: %d"
 msgstr "ugyldig %h-værdi"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid range %s in option %s"
 msgid "tuning string missing in option (%s)"
 msgstr "ugyldigt interval %s i tilvalg %s"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function `%s'"
 msgid "unknown tuning option (%s)"
 msgstr "ukendt specifikationsfunktion '%s'"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Angiv registerallokeringsordnen"
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s understøtter ikke %s"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s;"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "ukendt maskintilstand '%s'"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arg to `__builtin_frame_address'"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "ugyldig parameter til '__builtin_frame_address'"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, fuzzy, gcc-internal-format
 #| msgid "may not use both -mfp64 and -msingle-float"
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr "-mfp64 og -msingle-float er indbyrdes uforenelige"
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing arch name in %<-march=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "unknown value %qs for %<-march%>"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "et filnavn mangler efter '-%s'"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "tilvalget -mcpu=%s er i konflikt med tilvalget -march="
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s understøtter ikke %s"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 #| msgid "malformed spec function name"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "forkert udformet specifikationsfunktionsnavn"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, fuzzy, gcc-internal-format
 #| msgid "target system does not support the %qs debug format"
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "målarkitektursystem understøtter ikke %qs-fejlsøgningsformatet"
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument not a string"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "lane %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %wd"
 msgstr "versionen er ikke understøttet"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 #| msgid "The -shared option is not currently supported for VAX ELF."
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -37475,7 +37485,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "ugyldig værdi '%s' for -mmemory-latency"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -37605,18 +37615,18 @@ msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -38083,243 +38093,249 @@ msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "switch -mcpu=%s conflicts with -march= switch"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "tilvalget -mcpu=%s er i konflikt med tilvalget -march="
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic og -mapcs-reent er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS-genindtrædelig kode er ikke understøttet - ignoreret"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to 8 or 32"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "strukturstørrelsesgrænse kan kun sættes til 8 eller 32"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "strukturstørrelsesgrænse kan kun sættes til 8 eller 32"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= er ubrugelig uden -fpic"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "kan ikke bruge '%s' til PIC-register"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable og -msdata=%s er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%s %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan ikke beregne virkelig placering af stakkede parametre"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "ingen lave registre er tilgængelige til at modtage værdier fra høje registre"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -38328,24 +38344,24 @@ msgstr "ugyldig vektortype for egenskaben '%s'"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "ukendt registernavn: %s"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -38437,19 +38453,19 @@ msgstr "-pipe understøttes ikke"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe understøttes ikke"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional and -ansi are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-traditional og -ansi er indbyrdes uforenelige"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs function cannot have arguments"
 msgstr "tilvalget '-%c' skal have en parameter"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "%qs function cannot return a value"
@@ -39263,154 +39279,154 @@ msgstr "parameter til dss skal være en 2 bit-konstant uden fortegn"
 msgid "parameter to builtin not valid: %s"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "skifteværdi skal være en umiddelbar værdi"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "%qE needs isa option %s"
 msgstr "ugyldigt tilvalg %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -39433,564 +39449,564 @@ msgstr "stakgrænseudtryk understøttes ikke"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodemodellen %s understøtter ikke PIC-tilstand"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %qs argument is not a string"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "forkert parameter %qs for tilvalget %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "forkert strateginavn %qs er angivet for tilvalget %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "ukendt justering %qs angivet for tilvalget %qs"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "intet klassenavn angivet med '-%s'"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= understøttes ikke på 32 bit-systemer"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressetilstanden %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodemodellen %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel understøttes ikke af denne konfiguration"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bit-tilstand er ikke oversat med ind"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "den valgte processor understøtter ikke x86-64-instruktionssættet"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d er ikke mellem 0 og %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-fprefetch-loop-arrays understøttes ikke på målarkitekturen"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "profilering understøttes ikke endnu"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-instruktionssæt deaktiveret, bruger 387-beregninger"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-instruktionssæt deaktiveret, bruger SSE-beregninger"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall og regparm er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-egenskaben kræver en heltalskonstant som parameter"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "parameter til %qE-egenskaben er større end %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall og fastcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-egenskaben bruges til ikke-klasse metode"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -40479,7 +40495,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -41625,61 +41641,61 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "--resource påkræver -o"
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s understøtter ikke %s"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs function cannot have different interrupt type"
@@ -42256,260 +42272,261 @@ msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma GCC-målarkitektur er ikke understøttet på denne maskine"
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid reference type"
 msgid "%qs requires %qs or %qs"
 msgstr "Ugyldig referencetype"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, fuzzy, gcc-internal-format
 #| msgid "-maix64 requires PowerPC64 architecture remain enabled"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-maix64 kræver at PowerPC64-arkitekturen forbliver aktiveret"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-maix64 kræver at PowerPC64-arkitekturen forbliver aktiveret"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "Udsend kode der er kompatibel med TI-værktøjer"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%qs unsupported for this ABI"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
 msgstr "stakgrænser understøttes ikke på målarkitekturen"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring er ikke understøttet på lilleendede systemer"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "Udsend kode der er kompatibel med TI-værktøjer"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qs requires %qs"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "ukendt registernavn: %s"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%s understøtter ikke %s"
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s understøtter ikke %s"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t use %qs as a call-used register"
 msgid "%qs needs a valid base register"
 msgstr "kan ikke bruge %qs som et kald-brugt register"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for %<%s=%s%>"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%s har ingen %s"
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering af 64 bit-kode for denne ABI"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
-msgstr ""
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "complex invalid for `%s'"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
+msgstr "complex ugyldig for '%s'"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ugyldig parametertype '%T'"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%s%qs%s is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -42700,7 +42717,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument `%s'"
 msgid "constant value required for builtin %qF argument %d"
@@ -42781,216 +42798,222 @@ msgstr "'%s' er forældet"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "constant argument out of range for `%s'"
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "konstant parameter uden for det gyldige interval for '%s'"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "Builtin %qF requires z15 or higher."
 msgstr "--resource påkræver -o"
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "Builtin %qF requires arch14 or higher."
 msgstr "--resource påkræver -o"
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "unresolved overloaded builtin"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
 msgid "bad builtin icode"
 msgstr "ugyldig indbygget fcode"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "for mange parametre til funktionen"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "Total size of local variables exceeds architecture limit."
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Total størrelse af lokale variable overstiger arkitekturgrænsen."
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsize of '%D' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "%Jstørrelsen af '%D' er %d byte"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware vector support not available on %s"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "-f%s er ikke understøttet: ignoreret"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -43367,18 +43390,24 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "insn contains an invalid address !"
+msgid "%s contains too many lines"
+msgstr "instruktion indeholder en ugyldig adresse!"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "parent subprogram cannot be inlined"
 msgstr "funktion kan ikke indbygges"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "subprogram %q+F not marked %<Inline%>"
@@ -43456,8 +43485,8 @@ msgstr "egenskaben '%s' kan kun anvendes på variabler"
 msgid "could not read the BRIG file"
 msgstr "kunne ikke finde specifikationsfilen %s\n"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tom værdi er ikke ignoreret som den burde være"
@@ -43521,7 +43550,7 @@ msgstr "etiketten '%D' er defineret, men ikke benyttet"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "  oprindelig definition er her"
@@ -43757,7 +43786,7 @@ msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 msgid "declaration of %qD shadows a parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "declaration of %qD shadows a global declaration"
@@ -43769,7 +43798,7 @@ msgstr "erklæring af '%s' skygger for en global erklæring"
 msgid "declaration of %qD shadows a previous local"
 msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -43781,235 +43810,235 @@ msgstr "%Jskygget erklæring er her"
 msgid "nested extern declaration of %qD"
 msgstr "indlejret extern-erklæring af '%s'"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%s'"
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "underforstået erklæring af funktionen '%s'"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%s'"
 msgid "implicit declaration of function %qE"
 msgstr "underforstået erklæring af funktionen '%s'"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "include %qs or provide a declaration of %qE"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "incompatible implicit declaration of function %qD"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function)"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "'%s' er ikke erklæret (først benyttet i denne funktion)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "'%s' er ikke erklæret (først benyttet i denne funktion)"
 
 # dækkende, og pænere end original i praktisk brug
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "(Each undeclared identifier is reported only once for each function it appears in.)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(et kaldenavn der ikke er erklæret, rapporteres kun én gang per funktion)"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, fuzzy, gcc-internal-format
 #| msgid "label %s referenced outside of any function"
 msgid "label %qE referenced outside of any function"
 msgstr "der er blevet henvist til etiketten '%s' uden for en funktion"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, fuzzy, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "Missing variable initializer"
 msgid "jump skips variable initialization"
 msgstr "Manglende variabelstartværdi"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "label %qD defined here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "jump into statement expression"
 msgstr "overløb i konstant udtryk"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "duplicate label declaration %qE"
 msgstr "etiketten '%s' er blevet erklæret mere end én gang"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "duplicate label %qD"
 msgstr "etiketten '%D' optræder mere end én gang"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, fuzzy, gcc-internal-format
 #| msgid "Missing variable initializer"
 msgid "switch jumps over variable initialization"
 msgstr "Manglende variabelstartværdi"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "switch jumps into statement expression"
 msgstr "overløb i konstant udtryk"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE defineret som forkert slags mærke"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "unavngiven struct/union som ikke definerer nogen instanser"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "tom erklæring med lagringsklasseanvisning erklærer ikke mærke igen"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "tom erklæring med typemodifikation erklærer ikke mærke igen"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "tom erklæring med %<_Alignas%> erklærer ikke mærke igen"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "ubrugeligt typenavn i tom erklæring"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%>i tom erklæring"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> i tom erklæring"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> i file-scope tom erklæring"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> i file-scope tom erklæring"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "ubrugelig lagringsklasseanvisning i tom erklæring"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "ubrugelig %qs i tom erklæring"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "ubrugelig typemodifikationer i tom erklæring"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "ubrugelig %<_Alignas%> i tom erklæring"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of attributes in empty declaration"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "tom erklæring"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 understøtter ikke %<static%> eller typemodifikationer i parameterarrayerklæringer"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 understøtter ikke %<[*]%> arrayerklæringer"
@@ -44017,30 +44046,30 @@ msgstr "ISO C90 understøtter ikke %<[*]%> arrayerklæringer"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D er normalt en funktion"
 
 # init dækker over værditildeling her - samme for de næste mange
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD bliver tildelt en værdi (benyt __typeof__ i stedet)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "funktionen %qD bliver tildelt en startværdi som en variabel"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parameteren %qD bliver tildelt en startværdi"
@@ -44049,304 +44078,304 @@ msgstr "parameteren %qD bliver tildelt en startværdi"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "variablen %qD bliver tildelt en startværdi, men er af en ufuldstændig type"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %q+D given attribute %qs"
 msgstr "inline funktion %q+D givet egenskaben noinline"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member `%D'"
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "konstant medlem '%D' uden startværdi"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD skal tildeles en startværdi"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %q+D"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %q+D"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, fuzzy, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "nul eller negativ størrelse for tabellen '%s'"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %q+D isn%'t constant"
 msgstr "lagringsstørrelsen af '%D' er ikke konstant"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "ignorerer asm-anvisning til den ikke-statiske, lokale variabel '%s'"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "kan ikke anbringe et objekt med et volatile-felt i et register"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "konstant '%D' uden startværdi"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' width not an integer constant"
 msgid "bit-field %qs width not an integer constant"
 msgstr "bredden af bitfeltet '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bredden af bitfeltet '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, fuzzy, gcc-internal-format
 #| msgid "negative width in bit-field `%s'"
 msgid "negative width in bit-field %qs"
 msgstr "negativ bredde i bitfeltet '%s'"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, fuzzy, gcc-internal-format
 #| msgid "zero width for bit-field `%s'"
 msgid "zero width for bit-field %qs"
 msgstr "en bredde på nul for bitfeltet '%s'"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qs has invalid type"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, fuzzy, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "linjestilsdirektiv er en GCC-udvidelse"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, fuzzy, gcc-internal-format
 #| msgid "width of `%s' exceeds its type"
 msgid "width of %qs exceeds its type"
 msgstr "bredden af '%s' overstiger typen"
 
 # RETMIG: find på et eller andet med præcisionen
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is narrower than values of its type"
 msgid "%qs is narrower than values of its type"
 msgstr "'%s' er smallere end værdier af dens type"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array `%s' whose size can't be evaluated"
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 forbyder tabellen '%s' hvis størrelse ikke kan bestemmes"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array `%s' whose size can't be evaluated"
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 forbyder tabellen '%s' hvis størrelse ikke kan bestemmes"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "type defaults to %<int%> in type name"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `const'"
 msgid "duplicate %<const%>"
 msgstr "'const' optræder mere end én gang"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<restrict%>"
 msgstr "'restrict' optræder mere end én gang"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<volatile%>"
 msgstr "'volatile' optræder mere end én gang"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<_Atomic%>"
 msgstr "'restrict' optræder mere end én gang"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name `%s'"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "modstridende superklassenavn '%s'"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `auto'"
 msgid "function definition declared %<auto%>"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition declared %<register%>"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `typedef'"
 msgid "function definition declared %<typedef%>"
 msgstr "'typedef' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `auto'"
 msgid "function definition declared %qs"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "storage class specified for structure field %qE"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "storage class specified for structure field"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qE"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qE declared %<extern%>"
 msgstr "indlejret funktion '%s' er erklæret 'extern'"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -44355,783 +44384,783 @@ msgstr "'%s' i funktionsvirkefelt underforstået auto og erklæret '__thread'"
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static eller typemodifikationer i ikke-parametertabelerklæring"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ugyldig brug af struktur med fleksibelt tabelmedlem"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of array %qE has incomplete type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of unnamed array has incomplete type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array `%s'"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C forbyder tabellen '%s' med størrelsen nul"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ forbyder tabel med størrelsen nul"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of array %qE is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qE is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of unnamed array is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "tabeltypen er af en ufuldstændig type"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE er erklæret som en funktion, der returnerer en funktion"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "'typenavn er erklæret som en funktion, der returnerer en funktion"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE er erklæret som en funktion, der returnerer en array"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "typenavn er erklæret som en funktion, der returnerer en array"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "funktiondefinition har kvalificeret void-returtype"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "ignorerer asm-anvisning til den ikke-statiske, lokale variabel '%s'"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier omitted for parameter `%E'"
 msgid "%qs specified for parameter %qE"
 msgstr "typeangivelse udeladt for parameteren '%E'"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier omitted for parameter"
 msgid "%qs specified for unnamed parameter"
 msgstr "typeangivelsen er ikke angivet for parameteren"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%qs specified for structure field %qE"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%qs specified for structure field"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field has atomic type"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "justering må ikke angives for '%s'"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "alignment specified for parameter %qE"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "alignment specified for unnamed parameter"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "justering må ikke angives for '%s'"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, fuzzy, gcc-internal-format
 #| msgid "`__alignof' applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "'__alignof' benyttet på et bitfelt"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "operator `%T' declared to return `%T'"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "operator '%T' erklæret til at returnere '%T'"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C forbyder const eller volatile funktionstyper"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable or field %qE declared void"
 msgstr "variabel eller felt erklæret void"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "field %qE declared as a function"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "feltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function `%s'"
 msgid "invalid storage class for function %qE"
 msgstr "ugyldig lagringsklasse for funktion '%s'"
 
 # at oversætte inline med et udsagnsord her bliver vist for tvetydigt
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, fuzzy, gcc-internal-format
 #| msgid "cannot inline function `main'"
 msgid "cannot inline function %<main%>"
 msgstr "funktionen 'main' kan ikke være inline"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, fuzzy, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variabel eller felt '%s' erklæret void"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, fuzzy, gcc-internal-format
 #| msgid "function declaration isn't a prototype"
 msgid "function declaration isn%'t a prototype"
 msgstr "funktionserklæringen er ikke en prototype"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parameternavne (uden typer) i funktionserklæringen"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "parameter %u has void type"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, fuzzy, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, fuzzy, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parameteren '%s' har kun en forhåndserklæring"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "enum type defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "struct defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "union defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `union %s'"
 msgid "redefinition of %<union %E%>"
 msgstr "omdefinering af 'union %s'"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `struct %s'"
 msgid "redefinition of %<struct %E%>"
 msgstr "omdefinering af 'struct %s'"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<union %E%>"
 msgstr "indlejret omdefinering af '%s'"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "indlejret omdefinering af '%s'"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "erklæring erklærer ikke noget"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn't support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C understøtter ikke unavngivne struct/union-konstruktioner"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn't support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C understøtter ikke unavngivne struct/union-konstruktioner"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate member `%D'"
 msgid "duplicate member %q+D"
 msgstr "medlemmet '%D' optræder mere end én gang"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "union has no named members"
 msgstr "navngivne medlemmer"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, fuzzy, gcc-internal-format
 msgid "union has no members"
 msgstr "anonym sammensat type uden medlemmer"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "struct has no named members"
 msgstr "navngivne medlemmer"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, fuzzy, gcc-internal-format
 #| msgid "%s has no member named `%s'"
 msgid "struct has no members"
 msgstr "%s har intet medlem ved navn '%s'"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s er for stor"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kan ikke ikke gøres gennemsigtig"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<enum %E%>"
 msgstr "indlejret omdefinering af '%s'"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `enum %s'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "omerklæring af 'enum %s'"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "enum-værdier overstige rækkevidden af det største heltal"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "enum-værdier for store"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "inline funktion '%s' givet egenskaben noinline"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "returtypen er en ufuldstændig type"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, fuzzy, gcc-internal-format
 #| msgid "return type defaults to `int'"
 msgid "return type defaults to %<int%>"
 msgstr "returtypen antages at være 'int'"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "ingen tidligere prototype for '%s'"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "'%s' blev brugt uden en prototype før dens definition"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidligere erklæring af '%s'"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "'%s' blev brugt uden en erklæring før dens definition"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "returtypen til '%s' er ikke 'int'"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "'%s' er normalt en ikke-statisk funktion"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionel C tillader ikke ISO C-functionsdefinitioner"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, fuzzy, gcc-internal-format
 #| msgid "traditional C rejects ISO C style function definitions"
 msgid "old-style function definition"
 msgstr "traditionel C tillader ikke ISO C-functionsdefinitioner"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parameternavn mangler fra parameterliste"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "'%D' er erklæret som en ven"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "flere parametre ved navn '%s'"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %qD declared with void type"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "typen til '%s' antages at være 'int'"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, fuzzy, gcc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "erklæring af parameteren '%s', men ingen sådan parameter"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match prototype"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "tom erklæring"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "den forfremmede parameter '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "den forfremmede parameter '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -45140,283 +45169,283 @@ msgstr "etiketten '%D' er defineret, men ikke benyttet"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "begyndelseserklæring i 'for'-løkke benyttet uden for C99-tilstand"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 understøtter ikke %<[*]%> arrayerklæringer"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en statisk variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "'struct %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "'union %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "'enum %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der ikke er en variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "duplicate %qE declaration specifier"
 msgstr "gentaget erklæring af enheden '%s'"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration specifiers"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "'long long long' er for langt for GCC"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "'%s' optræder mere end én gang"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<__int%d%> is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' fails to be a typedef or built in type"
 msgid "%qE fails to be a typedef or built in type"
 msgstr "'%s' er hverken en typedef eller en indbygget type"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `extern'"
 msgid "%<__thread%> before %<extern%>"
 msgstr "'__thread' før 'extern'"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `static'"
 msgid "%<__thread%> before %<static%>"
 msgstr "'__thread' før 'static'"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs used with %qE"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "højreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -45438,7 +45467,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "  anden type her"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, fuzzy, gcc-internal-format
 #| msgid "garbage at end of #line"
 msgid "expected end of line"
@@ -45450,7 +45479,7 @@ msgstr "ragelse i slutningen af #line"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C forbyder en tom kildefil"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr ""
@@ -45489,7 +45518,7 @@ msgid "unknown type name %qE"
 msgstr "ukendt registernavn: %s"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "expected declaration specifiers"
@@ -45511,7 +45540,7 @@ msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored for methods"
@@ -45528,7 +45557,7 @@ msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 msgid "unexpected attribute"
 msgstr "uventet operand"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
@@ -45566,7 +45595,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -45631,7 +45660,7 @@ msgstr "startværdien for den statiske variabel er ikke en konstant"
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "verification error at PC=%d"
 msgid "static assertion failed"
@@ -45681,14 +45710,14 @@ msgstr "skabelonsparameter %d er ugyldig"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "uventet operand"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutningen af enum-liste"
@@ -45778,7 +45807,7 @@ msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute does not take any arguments"
@@ -45845,7 +45874,7 @@ msgstr "ISO C89 forbyder blandede erklæringer og kode"
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -45860,7 +45889,7 @@ msgstr "forældet brug af etiket i slutningen af sammensat sætning"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "uventet operand"
@@ -45886,18 +45915,18 @@ msgstr ""
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous `else'"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -45920,12 +45949,12 @@ msgstr "flere erklærerer i skabelonserklæring"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ugyldigt register i instruktionen"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -45941,8 +45970,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "case-værdi optræder mere end én gang"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, fuzzy, gcc-internal-format
 msgid "first seen here"
 msgstr "  første type her"
@@ -45973,12 +46002,12 @@ msgstr "ISO C forbyder udeladelse af den midterste del af et '?:'-udtryk"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -46408,13 +46437,13 @@ msgstr "Klasse- eller grænsefladeerklæring forventet"
 msgid "no type or storage class may be specified here,"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, fuzzy, gcc-internal-format
 #| msgid "readonly property can not be set"
 msgid "empty property attribute list"
 msgstr "skrivebeskyttet egenskab kan ikke angives"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -46426,54 +46455,54 @@ msgstr "manglende Code-egenskab"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "%<,%> eller %<)%> forventet"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected %qE selector name"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "'#pragma once' i hovedfil"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -46484,18 +46513,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "'#pragma once' i hovedfil"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
@@ -46519,60 +46548,60 @@ msgstr "%<,%> eller %<)%> forventet"
 msgid "%qD is not a variable"
 msgstr "'%D' er ikke et navnerum"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qD is not a pointer variable"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "forventede %<catch%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -46595,122 +46624,122 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%qs expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%qs value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "for mange parametre"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected argument"
 msgstr "uventet operand"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<concurrent%>"
 msgstr "forventede %<new%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "chunk size value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -46720,17 +46749,17 @@ msgstr "ugyldig roteringsinstruktion"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -46750,25 +46779,25 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "ugyldig %%d-operand"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "ugyldig maske"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -46785,84 +46814,84 @@ msgstr "ugyldig roteringsinstruktion"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc %s data%> has no data movement clause"
@@ -46879,7 +46908,7 @@ msgstr "'%#D' kan ikke erklæres"
 msgid "expected function name"
 msgstr "forventet funktion"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a function"
@@ -46890,29 +46919,29 @@ msgstr "'%D' er ikke en medlemsskabelonfunktion"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<allocator%>"
@@ -46923,91 +46952,91 @@ msgstr "forventede %<operator%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "'#pragma vtable' understøttes ikke længere"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many atomic clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many memory order clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'p' modifier"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ugyldig operand til 'p'-ændring"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -47017,35 +47046,35 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "forventede %<:%> or %<::%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp section%> eller %<}%> forventet"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "for statement expected"
 msgstr "')' eller term forventet"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of automaton `%s'"
 msgid "expected iteration declaration or initialization"
@@ -47056,73 +47085,73 @@ msgstr "gentaget erklæring af automaten '%s'"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<point%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -47137,65 +47166,65 @@ msgstr "en global registervariabel følger en funktionsdefinition"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected trait selector name"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifier `%s' not allowed after struct or class"
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "typemodifikationen '%s' er ikke tilladt efter struct eller class"
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type `%T' does not have member `%D'"
 msgid "selector %qs does not accept any properties"
 msgstr "ufuldstændig type '%T' har ikke medlemmet '%D'"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "score argument must be constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "score argument must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "expected identifier or string literal"
 msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "property must be constant integer expression"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -47207,13 +47236,13 @@ msgstr "forventede %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "'%s' er ikke en funktion,"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s og -msdata=%s er indbyrdes uforenelige"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -47223,32 +47252,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -47304,45 +47333,45 @@ msgstr "uventet operand"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 #| msgid "code model `large' not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "kodemodellen 'large' er ikke understøttet endnu"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -47359,27 +47388,27 @@ msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -47390,7 +47419,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> funktionskald er ikke inden for ydre transaktion eller %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -47407,7 +47436,7 @@ msgstr "fejl ved lukning af %s: %m"
 msgid "%qD has an incomplete type %qT"
 msgstr "'%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ugyldig brug af void-udtryk"
@@ -47451,138 +47480,138 @@ msgstr "'%D' skal tage mod én eller to parametre"
 msgid "function types not truly compatible in ISO C"
 msgstr "funktionstyper ikke er fuldt ud forenelige i ISO C"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr ""
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr ""
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr ""
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "typer er ikke helt forenelige"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, fuzzy, gcc-internal-format
 #| msgid "types are not quite compatible"
 msgid "pointer target types incompatible in C++"
 msgstr "typer er ikke helt forenelige"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, fuzzy, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "en funktions returtype kan ikke være en funktion"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%qT has no member named %qE"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%s' in something not a structure or union"
 msgid "request for member %qE in something not a structure or union"
 msgstr "forespørgsel efter medlemmet '%s' i noget der hverken er en union eller en struktur"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing %<void *%> pointer"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "tabelindeks er ikke et heltal"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg of pointer to function"
 msgid "subscripted value is pointer to function"
 msgstr "videregiver parameter af henvisning til funktion"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids subscripting `register' array"
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C forbyder opslag i 'register'-tabel"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C90 forbyder opslag i tabel der ikke er venstreværdi"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 #| msgid "called object is not a function"
 msgid "called object %qE is not a function or function pointer"
 msgstr "det kaldte objekt er ikke en funktion"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "called object is not a function"
 msgid "called object %qD is not a function or function pointer"
 msgstr "det kaldte objekt er ikke en funktion"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "called object is not a function"
 msgid "called object is not a function or function pointer"
@@ -47591,210 +47620,210 @@ msgstr "det kaldte objekt er ikke en funktion"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, fuzzy, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "sizeof benyttet på en ufuldstændig type"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified void function return type"
 msgid "function with qualified void return type called"
 msgstr "ISO C forbyder void funktionsreturtype med modifikationer"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "typen af den formelle parameter %d er ufuldstændig"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "%s som heltal i stedet for kommatal på grund af prototypen"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than complex due to prototype"
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "%s som heltal i stedet for complex på grund af prototypen"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, fuzzy, gcc-internal-format
 #| msgid "%s as complex rather than floating due to prototype"
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "%s som complex i stedet for kommatal på grund af prototypen"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "%s as floating rather than integer due to prototype"
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "%s som kommatal i stedet for heltal på grund af prototypen"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, fuzzy, gcc-internal-format
 #| msgid "%s as complex rather than integer due to prototype"
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "%s som complex i stedet for heltal på grund af prototypen"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "%s as floating rather than complex due to prototype"
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "%s som kommatal i stedet for complex på grund af prototypen"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, fuzzy, gcc-internal-format
 #| msgid "%s as `float' rather than `double' due to prototype"
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "%s som float i stedet for double på grund af prototypen"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than complex due to prototype"
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "%s som heltal i stedet for complex på grund af prototypen"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, fuzzy, gcc-internal-format
 #| msgid "%s with different width due to prototype"
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "%s med anderledes bredde på grund af prototypen"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, fuzzy, gcc-internal-format
 #| msgid "%s as unsigned due to prototype"
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "%s som unsigned på grund af prototypen"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, fuzzy, gcc-internal-format
 #| msgid "%s as signed due to prototype"
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "%s som signed på grund af prototypen"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "too many arguments to method %qE"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "for mange parametre til funktionen"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "for få parametre til funktionen"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "%Jsvag erklæring af '%D' efter første brug resulterer i ikke-defineret opførsel"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "sammenligning mellem henvisningsvariabel og heltal"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
 msgstr "typeomtvingning af '%T' til '%T' følger ikke henvisning"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between `%#T' and `%#T'"
 msgid "comparison between %qT and %qT"
 msgstr "sammenligning mellem '%#T' og '%#T'"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, fuzzy, gcc-internal-format
 #| msgid "pointer of type `void *' used in subtraction"
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "henvisning af typen 'void *' benyttet i subtraktion"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "henvisning til en funktion benyttet i subtraktion"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "%<~%> on a boolean expression"
 msgstr "uventet adresseudtryk"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support `~' for complex conjugation"
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C understøtter ikke '~' til compleks-konjugering"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "forkert parametertype til abs"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "forkert parametertype til unært udråbstegn"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration value `%s' not handled in switch"
 msgid "increment of enumeration value is invalid in C++"
 msgstr "enum-værdien '%s' håndteres ikke i switch-sætning"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration value `%s' not handled in switch"
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "enum-værdien '%s' håndteres ikke i switch-sætning"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "increment of a boolean expression"
 msgstr "uventet adresseudtryk"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "decrement of a boolean expression"
 msgstr "uventet adresseudtryk"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support `++' and `--' on complex types"
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
@@ -47802,1575 +47831,1575 @@ msgstr "ISO C understøtter ikke '++' og '--' for complex-typer"
 
 # man kan ikke stikke en forøgelse (++) en type som parameter, 'type
 # argument' skal opfattes på en anden måde
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "forkert parametertype til forøgelse"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "forkert parametertype til formindskelse"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of expression of type %<void%>"
 msgstr "tager adressen på midlertidig variabel"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field `%s'"
 msgid "cannot take address of bit-field %qD"
 msgstr "kan ikke finde adressen af bitfeltet '%s'"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of an unaligned member"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "kan ikke tage adressen af et ikke-justeret medlem"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "forespørgsel efter adressen af registervariablen '%s'"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "global register variable `%s' used in nested function"
 msgid "global register variable %qD used in nested function"
 msgstr "global registervariabel '%s' benyttet i indlejret funktion"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "register variable %qD used in nested function"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, fuzzy, gcc-internal-format
 #| msgid "address of global register variable `%s' requested"
 msgid "address of global register variable %qD requested"
 msgstr "forespørgsel efter adressen af den globale registervariabel '%s'"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of register variable %qD requested"
 msgstr "forespørgsel efter adressen af registervariablen '%s'"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "non-lvalue array in conditional expression"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C forbyder betingede udtryk med kun én tom side"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids conditional expr between `void *' and function pointer"
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C++ forbyder betinget udtryk mellem 'void *' og funktionshenvisning"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "henvisnings- og heltalstype i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "in call to %qD, declared here"
 msgstr "  '%#D' erklæret her"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 #, fuzzy
 #| msgid "cast adds new qualifiers to function type"
 msgid "cast adds %q#v qualifier to function type"
 msgstr "typeomtvingning tilføjer modifikationer til en funktionstype"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "typeomtvingelse kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "typetildelingen angiver en tabeltype"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "typetildelingen angiver en funktionstype"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C forbyder omtvingelse af ikke-skalar til den samme type"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C forbyder omtvingelse til uniontype"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "typetildeling til en uniontype fra en type der ikke findes i union'en"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "typeomtvingelse forøger den påkrævne justering af måltypen"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "typeomtvingelse fra henvisning til heltal af en anden størrelse"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typeomtvingelse fra heltal til henvisning af en anden størrelse"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C forbyder sammenligning af 'void *' med funktionshenvisning"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C forbyder sammenligning af 'void *' med funktionshenvisning"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "kan ikke konvertere fra ufuldstændig type %qT til %qT"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "tildelingsundertrykkelse"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for `%s')"
 msgid "(near initialization for %qs)"
 msgstr "(i nærheden af klargøringen af '%s')"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, fuzzy, gcc-internal-format
 #| msgid "char-array initialized from wide string"
 msgid "array initialized from parenthesized string constant"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "built-in %qD declared here"
 msgstr "  '%#D' erklæret her"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%#T' to `%#T'"
 msgid "implicit conversion from %qT to %qT"
 msgstr "konvertering fra '%#T' til '%#T'"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 #, fuzzy
 #| msgid "%s makes qualified function pointer from unqualified"
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "%s opretter en funktionshenvisning med modifikationer fra én uden"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 #, fuzzy
 #| msgid "%s makes qualified function pointer from unqualified"
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "%s opretter en funktionshenvisning med modifikationer fra én uden"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 #, fuzzy
 #| msgid "%s makes qualified function pointer from unqualified"
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "%s opretter en funktionshenvisning med modifikationer fra én uden"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 #, fuzzy
 #| msgid "%s makes qualified function pointer from unqualified"
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "%s opretter en funktionshenvisning med modifikationer fra én uden"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 #, fuzzy
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "typeomtvingelse kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "typeomtvingelse kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "typeomtvingelse kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C forbyder parameterkonvertering til uniontype"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, fuzzy, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of pointer to function"
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "videregiver den %d. parameter af henvisning til funktion"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "typeomtvingelse fra henvisning til heltal af en anden størrelse"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "return type might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function declared with a void return type"
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "return-sætning med en værdi i en funktion der er erklæret med en void returtype"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids %s between function pointer and `void *'"
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C forbyder %s mellem funktionshenvisning og 'void *'"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids %s between function pointer and `void *'"
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C forbyder %s mellem funktionshenvisning og 'void *'"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids %s between function pointer and `void *'"
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C forbyder %s mellem funktionshenvisning og 'void *'"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids %s between function pointer and `void *'"
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C forbyder %s mellem funktionshenvisning og 'void *'"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in %s differ in signedness"
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "fortegnene i henvisningsmål i %s er forskellige"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in %s differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "fortegnene i henvisningsmål i %s er forskellige"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in %s differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "fortegnene i henvisningsmål i %s er forskellige"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in %s differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "fortegnene i henvisningsmål i %s er forskellige"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function declared with a void return type"
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "return-sætning med en værdi i en funktion der er erklæret med en void returtype"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function declared with a void return type"
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "return-sætning med en værdi i en funktion der er erklæret med en void returtype"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes pointer from integer without a cast"
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes integer from pointer without a cast"
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "%s opretter et heltal ud fra en henvisningsvariabel uden en typeomtvingning"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "%s opretter et heltal ud fra en henvisningsvariabel uden en typeomtvingning"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "%s opretter et heltal ud fra en henvisningsvariabel uden en typeomtvingning"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "%s opretter et heltal ud fra en henvisningsvariabel uden en typeomtvingning"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "incompatible type for argument %d of %qE"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
 # 'automatic aggregate' betyder automatisk allokerede variabler, dvs.
 # ganske almindelige lokale variabler (kan evt. erklæres med 'auto')
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "traditionel C forbyder klargøring af auto-variabler af sammensatte typer"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, fuzzy, gcc-internal-format
 #| msgid "char-array initialized from wide string"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ugyldig brug af en tabel der ikke kan optræde som en venstreværdi"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "startværdielement er ikke en konstant"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "tabel får tildelt en startværdi fra et tabeludtryk der ikke er konstant"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer element is not a constant expression"
 msgstr "startværdielement er ikke en konstant"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "startværdielement kan ikke beregnes ved indlæsningstidspunktet"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "ugyldig startværdi"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "overskydende krøllede paranteser ved slutningen af startværdien"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "krøllede paranteser omkring skalarstartværdi"
 
 # RETMIG: eller er det fleksibel tabel-medlem
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "klargøring af fleksibelt tabelmedlem i en indlejret kontekst"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for field %qD of %qT"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "tom skalarstartværdi"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "overskydende elementer i skalarstarværdi"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "tabelindeks i en startværdi der ikke er en tabel"
 
 # RETMIG: record?
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "feltnavn ikke i struktur- eller union-startværdi"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer exceeds array bounds"
 msgid "array index in initializer not of integer type"
 msgstr "tabelindeks i startværdi overskrider tabelgrænser"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "array index in initializer is not an integer constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "tabelindeks i startværdi overskrider tabelgrænser"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "tomt indeksinterval i startværdi"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "tabelindeksinterval i startværdi overskrider tabelgrænser"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "klargjort felt med bivirkninger overskrevet"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, fuzzy, gcc-internal-format
 #| msgid "initialized field with side-effects overwritten"
 msgid "initialized field overwritten"
 msgstr "klargjort felt med bivirkninger overskrevet"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "for mange elementer i char-tabelstartværdien"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "for mange elementer i struct-startværdi"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "ikke-statisk klargøring af fleksibelt tabelmedlem"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "traditionel C forbyder tildeling af startværdi til unioner"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "for mange elementer i tabelstartværdi"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "for mange elementer i vektorstartværdi"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "for mange elementer i skalarstartværdi"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids `goto *expr;'"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C forbyder 'goto *udtryk;'"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, fuzzy, gcc-internal-format
 #| msgid "function declared `noreturn' has a `return' statement"
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "funktion der er erklæret 'noreturn' har en 'return'-sætning"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, fuzzy, gcc-internal-format
 #| msgid "`return' with no value, in function returning non-void"
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, fuzzy, gcc-internal-format
 #| msgid "`return' with a value, in function returning void"
 msgid "%<return%> with a value, in function returning void"
 msgstr "'return' med en værdi i en funktion der returnerer void"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, fuzzy, gcc-internal-format
 #| msgid "`return' with a value, in function returning void"
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "'return' med en værdi i en funktion der returnerer void"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "funktion returnerer adressen på en lokal variabel"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-størrelsen er ikke et heltal"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, fuzzy, gcc-internal-format
 #| msgid "`long' switch expression not converted to `int' in ISO C"
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "'long'-udtryk i switch konverteres ikke til 'int' i ISO C"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "case label is not an integer constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, fuzzy, gcc-internal-format
 #| msgid "`default' label not within a switch statement"
 msgid "%<default%> label not within a switch statement"
 msgstr "'default'-etiket befinder sig ikke inden i en switch-sætning"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sætning befinder sig ikke i en løkke"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, fuzzy, gcc-internal-format
 #| msgid "%Hstatement with no effect"
 msgid "statement with no effect"
 msgstr "%Hsætning uden nogen virkning"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "operander til ?: har forskellige typer"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, fuzzy, gcc-internal-format
 #| msgid "operand constraints for `asm' differ in number of alternatives"
 msgid "comparing vectors with different number of elements"
 msgstr "operandbegrænsninger til 'asm' har forskellige antal alternativer"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "sammenligning af kommatal med == eller != er ikke sikkert"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of distinct pointer types lacks a cast"
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "sammenligning med forskellige henvisningstyper mangler en typeomtvingelse"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids comparison of `void *' with function pointer"
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C forbyder sammenligning af 'void *' med funktionshenvisning"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "sammenligning med forskellige henvisningstyper mangler en typeomtvingelse"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "sammenligning mellem henvisningsvariabel og heltal"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "sammenligning mellem en fuldstændig og ufuldstændig henvisning"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C forbyder ordnede sammenligninger af henvisninger til funktioner"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with null pointer"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, fuzzy, gcc-internal-format
 #| msgid "array type value used where scalar is required"
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "værdi af tabeltype angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, fuzzy, gcc-internal-format
 #| msgid "struct type value used where scalar is required"
 msgid "used struct type value where scalar is required"
 msgstr "værdi af struct-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, fuzzy, gcc-internal-format
 #| msgid "union type value used where scalar is required"
 msgid "used union type value where scalar is required"
 msgstr "værdi af union-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, fuzzy, gcc-internal-format
 #| msgid "struct type value used where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "værdi af struct-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "for mange inddatafiler"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected EOF while reading source file %s.\n"
 msgid "expected single pointer in %qs clause"
 msgstr "Stødt på slutningen af kildefilen %s tidligere end forventet.\n"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Intern oversætterfejl i %s ved %s:%d."
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "for array function parameter length expression must be specified"
 msgstr "udsagn skal være et kaldenavn"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "kaster NULL som har en heltals-, ikke en henvisningstype"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%#D' with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "end expression refers to outer iterator %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "step expression refers to outer iterator %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected pointer in %qs clause"
 msgstr "uventet operand"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "zero sized type %qT in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "variable sized type %qT in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "brug af '%D' er tvetydigt"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%<_Atomic%> %qD i %<aligned%>-klausul"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE er ikke en variable i %<depend%>-klausul"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in map clauses"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in map clauses"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE er ikke en variable i %<depend%>-klausul"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD fremgår mere end en gang i motion-klausuller"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE er hverken en variabel eller et funktionsnavn i klausul %qs"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "grundoperanden til '->' er ikke en henvisning"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses on a task construct"
 msgstr "for mange inddatafiler"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to `va_arg' not of type `va_list'"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "den første parameter til 'va_arg' er ikke af typen 'va_list'"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -49608,7 +49637,7 @@ msgstr "  for konvertering fra '%T' til '%T'"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -49728,13 +49757,13 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "call of overloaded `%D(%A)' is ambiguous"
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
@@ -49742,725 +49771,730 @@ msgstr "kald af flertydig '%D(%A)' er tvetydigt"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "henvisning til medlemsfunktionen %E kan ikke kaldes uden et objekt; overvej at benytte .* eller ->*"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to `(%T) (%A)'"
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "ingen passende fundet for kald til '(%T) (%A)'"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "tvetydig konvertering af tabelindeks"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "operand is r0"
 msgid " (operand type is %qT)"
 msgstr "operanden er r0"
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: %s"
 msgid "ternary %<operator?:%>"
 msgstr "intern fejl: %s"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ forbyder udeladelse af den mellemste del af et ?:-udtryk"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: `%T' vs `%T'"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "enum-typer passer ikke sammen i betinget udtryk: '%T' og '%T'"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "returtypen til '%s' er ikke 'int'"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between `%#T' and `%#T'"
 msgid "comparison between %q#T and %q#T"
 msgstr "sammenligning mellem '%#T' og '%#T'"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passende 'operator delete' for '%T'"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared private here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared protected here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "'%+#D' er ikke tilgængelig"
 
 # %s bliver til returnering eller tildeling eller noget i den retning
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, fuzzy, gcc-internal-format
 #| msgid "passing NULL used for non-pointer %s %P of `%D'"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "overbringelse af NULL benyttet for ikke-henvisnings%s %P af '%D'"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "  declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "%s to non-pointer type `%T' from NULL"
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "%s til ikke-henvisningstypen '%T' fra NULL"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of `%D'"
 msgid "  initializing argument %P of %qD"
 msgstr "  ved klargøring af parameteren %P til '%D'"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around initializer for %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid conversion from %qH to %qI"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
+
+#: cp/call.c:7911
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "kan ikke erklære feltet '%D' til at være af typen '%T'"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type `%#T' through `...'"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan ikke modtage objekter af en ikke-POD type '%#T' gennem '...'"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to `%D'"
 msgid "  in call to %qD"
 msgstr "  i kald af '%D'"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "'%T' er en utilgængelig stamklasse til '%T'"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "; use assignment instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "; use value-initialization instead"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "; use copy-assignment instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "; use copy-initialization instead"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%#qT declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call destructor `%T::~%T' without object"
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan ikke kalde destruktionsfunktion '%T::~%T' uden objekt"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "kald af flertydig '%D(%A)' er tvetydigt"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function `%D' without object"
 msgid "cannot call member function %qD without object"
 msgstr "kan ikke kalde medlemsfunktionen '%D' uden et objekt"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' chooses `%T' over `%T'"
 msgid "passing %qT chooses %qT over %qT"
 msgstr "videregivelse af '%T' vælger '%T' frem for '%T'"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, fuzzy, gcc-internal-format
 #| msgid "choosing `%D' over `%D'"
 msgid "choosing %qD over %qD"
 msgstr "vælger '%D' frem for '%D'"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  for conversion from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  fordi konverteringssekvensen for parameteren er bedre"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ifølge ISO C++ er '%D' og '%D' tvetydigt selvom den værste konvertering for førstnævnte er bedre end den værste konvertering for den sidstnævnte"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
@@ -50488,1270 +50522,1270 @@ msgstr "kan ikke konvertere fra stamklassen '%T' til den nedarvede type '%T' via
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "kan ikke konvertere fra stamklassen '%T' til den nedarvede type '%T' via den virtuelle stamklasse '%T'"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base `%T' to derived type `%T' via virtual base `%T'"
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "kan ikke konvertere fra stamklassen '%T' til den nedarvede type '%T' via den virtuelle stamklasse '%T'"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "strider mod tidligere erklæring '%#D'"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "version inherited from %qT declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' and `%#D' cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "'%#D' og '%#D' kan ikke flertydiggøres"
 
 # hænger sammen med næste tekst
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q#D"
 msgstr "tidligere erklæring '%D'"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting access specifications for method `%D', ignored"
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "modstridende tilgangsanvisninger til metoden '%D', ignoreret"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting access specifications for field `%s', ignored"
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "modstridende tilgangsanvisninger til feltet '%s', ignoreret"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method `%#D' with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  på grund af den lokale metode '%#D' med det samme navn"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "local method %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member `%#D' with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  på grund af det lokale medlem '%#D' med det samme navn"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "local member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qT declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base `%T' to derived type `%T' via virtual base `%T'"
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "kan ikke konvertere fra stamklassen '%T' til den nedarvede type '%T' via den virtuelle stamklasse '%T'"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "all member functions in class `%T' are private"
 msgid "all member functions in class %qT are private"
 msgstr "alle medlemsfunktioner i klassen '%T' er private"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' only defines a private destructor and has no friends"
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "'%#T' definerer kun en privat destruktionsfunktion og har ingen venner"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' only defines private constructors and has no friends"
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "'%#T' definerer kun private konstruktionsfunktioner og har ingen venner"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
 # %D er en funktion
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, fuzzy, gcc-internal-format
 #| msgid "no unique final overrider for `%D' in `%T'"
 msgid "no unique final overrider for %qD in %qT"
 msgstr "ingen unik endelig overskrivning af '%D' i '%T'"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' and `%#D' cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "'%#D' og '%#D' kan ikke flertydiggøres"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was hidden"
 msgid "%qD was hidden"
 msgstr "'%D' var skjult"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "  by `%D'"
 msgid "  by %qD"
 msgstr "  af '%D'"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is deprecated and may be removed"
 msgid "this flexibility is deprecated and will be removed"
 msgstr "-traditional er forældet og kan blive fjernet"
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%#D' with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%D' width not an integer constant"
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bredden af bitfeltet '%D' er ikke en heltalskonstant"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, fuzzy, gcc-internal-format
 #| msgid "negative width in bit-field `%D'"
 msgid "negative width in bit-field %q+D"
 msgstr "negativ bredde i bitfeltet '%D'"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "zero width for bit-field `%D'"
 msgid "zero width for bit-field %q+D"
 msgstr "en bredde på nul for bitfeltet '%D'"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "width of `%D' exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "bredden af '%D' overstiger typen"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is too small to hold all values of `%#T'"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "'%D' er for lille til at indeholde alle værdierne af '%#T'"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with constructor not allowed in union"
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "medlemmet '%#D' med en konstruktionsfunktion er ikke tilladt i en union"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with destructor not allowed in union"
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "medlemmet '%#D' med en destruktionsfunktion er ikke tilladt i en union"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with copy assignment operator not allowed in union"
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "medlemmet '%#D' med en kopitildelingsoperator er ikke tilladt i en union"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "feltet '%D' er på ugyldig vis erklæret som en funktionstype"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "multiple fields in union `%T' initialized"
 msgid "multiple fields in union %qT initialized"
 msgstr "flere felter i union '%T' tildeles startværdi"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 #| msgid "field `%#D' with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "felt '%#D' med samme navn som klassen"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has pointer data members"
 msgid "%q#T has pointer data members"
 msgstr "'%#T' har henvisningsdatamedlemmer"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override `%T(const %T&)'"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  men overskriver ikke '%T(const %T&)'"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, fuzzy, gcc-internal-format
 #| msgid "  or `operator=(const %T&)'"
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eller 'operator=(const %T&)'"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override `operator=(const %T&)'"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  men overskriver ikke 'operator=(const %T&)'"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method `%D'"
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "startværdi angivet for ikke-virtuel medlemsfunktion '%D'"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%q+T is not literal because:"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "  non-static data member %qD has volatile type"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference `%#D' in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "ikke-statisk reference '%#D' i klasse uden en konstruktionsfunktion"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member `%#D' in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "ikke-statisk konstant medlem '%#D' i klasse uden en konstruktionsfunktion"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, fuzzy, gcc-internal-format
 #| msgid "direct base `%T' inaccessible in `%T' due to ambiguity"
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, fuzzy, gcc-internal-format
 #| msgid "virtual base `%T' inaccessible in `%T' due to ambiguity"
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuel stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, fuzzy, gcc-internal-format
 #| msgid "offset of `%D' is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "afsættet for '%D' følger ikke ABI'en og kan ændre sig i en fremtidig version af GCC"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ugyldig brug af %<...%> med ikke-skive"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ugyldig brug af struktur med fleksibelt tabelmedlem"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "array member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "in the definition of %q#T"
 msgstr "omdefinering af '%#T'"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "next member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "omdefinering af '%#T'"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "'%#T' har virtuelle funktioner, men ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "type transparent %q#T does not have any fields"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "  eftersom typen '%T' har abstrakte virtuelle funktioner"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "forsøgte at afslutte struct, men blev stoppet af tidligere fortolkningsfejl"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, fuzzy, gcc-internal-format
 #| msgid "language string `\"%s\"' not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "sprogstrengen '\"%s\"' ikke genkendt"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, fuzzy, gcc-internal-format
 #| msgid "cannot resolve overloaded function `%D' based on conversion to type `%T'"
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "kan ikke benytte den flertydiggjorte funktion '%D' baseret på konvertering til typen '%T'"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "no matches converting function `%D' to type `%#T'"
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen passende ved konvertering af funktionen '%D' til typen '%#T'"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, fuzzy, gcc-internal-format
 #| msgid "converting overloaded function `%D' to type `%#T' is ambiguous"
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering af den flertydiggjorte funktion '%D' til typen '%T' er tvetydig"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, fuzzy, gcc-internal-format
 #| msgid "assuming pointer to member `%D'"
 msgid "assuming pointer to member %qD"
 msgstr "antager henvisning til medlemmet '%D'"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with `&%E')"
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en henvisning til medlem kan kun dannes med '&%E')"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%E' from type `%T' to type `%T'"
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "kan ikke konvertere '%E' fra typen '%T' til typen '%T'"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as `%#D'"
 msgid "%qD declared here as %q#D"
 msgstr "omerklæret her som '%#D'"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type `%T'"
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "parameter må ikke have variabelt ændret type '%T'"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 #| msgid "Only constructors can invoke constructors"
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "Kun konstruktionsfunktioner kan kalde konstruktionsfunktioner"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for member function `%#D'"
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "ugyldig returtype for medlemsfunktionen '%#D'"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "tom erklæring"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%q+E is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to internal function %qE"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr "  oprindelig definition er her"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not a base type for type `%T'"
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "typen '%T' er ikke en grundtype for typen '%T'"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object of type `%T' may not be initialized"
 msgid "virtual table pointer is used uninitialized"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an ambiguous base of `%T'"
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "'%T' er en tvetydig stamklasse til '%T'"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr "-client_name er ikke tilladt med -dynamiclib"
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 msgid "allocation performed here"
 msgstr "  oprindelig definition er her"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr "-client_name er ikke tilladt med -dynamiclib"
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a previous local"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' implicitly declared before its definition"
 msgid "%qD used before its definition"
 msgstr "'%s' er underforstået erklæret efter dens definition"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, fuzzy, gcc-internal-format
 #| msgid "protocol `%s' has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokollen '%s' har cirkulær afhængighed"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "højreskiftsantal er negativ"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized array element"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "-indlejrede funktioner er ikke understøttet på denne målarkitektur"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing a null pointer"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "allocated here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "%qD used in its own initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "'%s' er ikke en funktion,"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is private"
 msgid "%q#D is volatile"
 msgstr "'%+#D' er privat"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline assembly is not a constant expression"
 msgstr "startværdielement er ikke en konstant"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "cast from %qT is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "uventet operand"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "uventet adresseudtryk"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "ugyldig reinterpret_cast af et højreværdiudtryk fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "ugyldig reinterpret_cast fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected type for `id' (%s)"
 msgid "unexpected AST of kind %s"
@@ -51762,57 +51796,57 @@ msgstr "uventet type for 'id' (%s)"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a type"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "%qD is not a class type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -51862,7 +51896,7 @@ msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konvertering fra '%T' til '%T' forkaster modifikationer"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "casting %qT to %qT does not dereference pointer"
@@ -52298,7 +52332,7 @@ msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "erklæring af '%D' som %s"
 
 # hænger sammen med næste tekst
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -52450,8 +52484,8 @@ msgstr "tidligere ikke-funktionserklæring '%#D'"
 msgid "%q#D previously defined here"
 msgstr "'%#D' tidligere defineret her"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously declared here"
 msgid "%q#D previously declared here"
@@ -52493,57 +52527,57 @@ msgstr "standardparameter givet til %d. parameter for '%#D'"
 msgid "previous specification in %q#D here"
 msgstr "efter tidligere specifikation i '%#D'"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration `%#D'"
 msgid "declaration %qD conflicts with builtin"
 msgstr "strider mod indbygget erklæring '%#D'"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration `%#D'"
 msgid "declaration %qD conflicts with import"
 msgstr "strider mod indbygget erklæring '%#D'"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 #| msgid "  first declared as `%#D' here"
 msgid "import declared %q#D here"
 msgstr "  først erklæret som '%#D' her"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "tidligere definition her"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%D' in same scope"
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "overflødig omerklæring af '%D' i samme virkefelt"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "deleted definition of %qD is not first declaration"
@@ -52557,53 +52591,53 @@ msgstr "indlejret omdefinering af '%s'"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization of %qD after first use"
 msgstr "eksplicit specialisering af %D efter første brug"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#D"
 msgstr "omdefinering af '%#T'"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' conflicts with previous using declaration `%#D'"
 msgid "%qD conflicts with used function"
 msgstr "'%#D' strider mod tidligere using-erklæring '%#D'"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%q#D not declared in class"
 msgstr "'%D' ikke erklæret"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "deduction guide %q+D redeclared"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -52611,742 +52645,748 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "trådlokal erklæring af '%s' følger ikke-trådlokal erklæring"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "ikke-trådlokal erklæring af '%s' følger trådlokal erklæring"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %q#D"
 msgstr "omerklæring af '%#D'"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%s' in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "overflødig omerklæring af '%s' i samme virkefelt"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "a previous local"
 msgid "previous label"
 msgstr "en tidligere lokal variabel"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  herfra"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of `%#D'"
 msgid "  crosses initialization of %q#D"
 msgstr "  krydser klargøring af '%#D'"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  går ind i try-blok"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  går ind i catch-blok"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters OpenMP structured block"
 msgstr "  går ind i try-blok"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "uventet operand"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of `%#D'"
 msgid "  skips initialization of %q#D"
 msgstr "  springer over klargøring af '%#D'"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "'%D' benyttet uden skabelonsparametre"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "`%D' is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "'%D' er ikke en funktionsskabelon"
+
+#: cp/decl.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a template"
 msgid "%q#T is not a class"
 msgstr "'%#T' er ikke en skabelon"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named `%#T' in `%#T'"
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klasseskabelon ved navn '%#T' i '%#T'"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, fuzzy, gcc-internal-format
 #| msgid "no type named `%#T' in `%#T'"
 msgid "no type named %q#T in %q#T"
 msgstr "ingen type ved navn '%#T' i '%#T'"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameters do not match template %qD"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-falign-labels=%d understøttes ikke"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with constructor not allowed in anonymous aggregate"
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med konstruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with destructor not allowed in anonymous aggregate"
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med destruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with copy assignment operator not allowed in anonymous aggregate"
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med kopitildelingsoperator er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flere typer i én erklæring"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type `%T'"
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omerklæring af indbygget type i C++ '%T'"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "manglende typenavn i typedef-erklæring"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ forbyder anonyme strukturer"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified inside a class"
 msgid "%<friend%> can only be specified inside a class"
 msgstr "'%D' kan kun angives inden i en klasse"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for constructors"
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "'%D' kan kun angives for konstruktionsfunktioner"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "a storage class can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "tom erklæring"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter list used in explicit instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
 # init dækker over værditildeling her - samme for de næste mange
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 #| msgid "typedef `%D' is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef '%D' bliver tildelt en værdi (benyt __typeof__ i stedet)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "non-member-template declaration of %qD"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "does not match member template declaration here"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not permit `%T::%D' to be defined as `%T::%D'"
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillader ikke '%T::%D' at blive defineret som '%T::%D'"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "duplicate initialization of %qD"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, fuzzy, gcc-internal-format
 #| msgid "variable `%#D' has initializer but incomplete type"
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variablen '%#D' bliver tildelt en startværdi, men er af en ufuldstændig type"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate `%#D' has incomplete type and cannot be defined"
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "den sammensatte type '%#D' er af en ufuldstændig type og kan ikke defineres"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as reference but not initialized"
 msgid "%qD declared as reference but not initialized"
 msgstr "'%D' erklæret som en reference, men bliver ikke tildelt en startværdi"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ikke-trivielle udpegede startværdier er ikke understøttet"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "startværdien giver ikke størrelsen af %qD"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "tabelstørrelsen mangler i %qD"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nulstørrelsestabel %qD"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstørrelsen af %qD er ikke kendt"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstørrelsen af '%D' er ikke konstant"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  du kan arbejde dig rundt om dette ved at fjerne startværdien"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized %<const %D%>"
 msgstr "konstant '%D' uden startværdi"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "typen '%T' har ingen destruktionsfunktion"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for `%T' must be brace-enclosed"
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "startværdi for '%T' skal være indesluttet i krøllede paranteser"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "%qT has no non-static data member named %qD"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "ugyldig startværdi"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in aggregate initializer"
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "for mange elementer i startværdi til sammensat type"
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "for mange startværdier for %qT"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing braces around initializer for %qT"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C89 forbyder sammensatte konstanter"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "'%D' er af en ufuldstændig type"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be initialized by constructor, not by `{...}'"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "'%D' skal klargøres af en konstruktionsfunktion, ikke af '{...}'"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "tildeling af startværdi er ugyldig for statisk medlem med konstruktionsfunktion"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en klargøring uden for klassens erklæring er nødvendig)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' with uninitialized const fields"
 msgid "reference %qD is initialized with itself"
 msgstr "medlem '%D' med konstante felter uden startværdi"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "could not find variant declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillader ikke %<register%>-lagerklasseangivelse"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "%<register%> storage class specifier used"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member (did you forget the `&' ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "ugyldig brug af medlem (glemte du en '&'?)"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing previous type declaration of `%#D'"
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skygger for tidligere typeerklæring af '%#D'"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, fuzzy, gcc-internal-format
 #| msgid "function `%#D' is initialized like a variable"
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen '%#D' bliver tildelt en startværdi som en variabel"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%u name provided for structured binding"
@@ -53354,1898 +53394,1909 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "lagringsklasse angivet for strukturfelt '%s'"
 msgstr[1] "lagringsklasse angivet for strukturfelt '%s'"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "in initialization of structured binding variable %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose union type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qT"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "nulstørrelsestabel '%D'"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, fuzzy, gcc-internal-format
 #| msgid "destructor for alien class `%T' cannot be a member"
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, fuzzy, gcc-internal-format
 #| msgid "constructor for alien class `%T' cannot be a member"
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "'%D' erklæret som 'virtual' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "'%D' er erklæret som en ven"
 
 # %s bliver omsat til typen
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%q+D declared as a friend"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared with an exception specification"
 msgid "%q+D declared with an exception specification"
 msgstr "'%D' erklæret med en undtagelsesspecifikation"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, fuzzy, gcc-internal-format
 #| msgid "static member function `%#D' declared with type qualifiers"
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion '%#D' erklæret med typemodifikationer"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, fuzzy, gcc-internal-format
 #| msgid "Java method '%D' has non-Java return type `%T'"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java-metoden '%D' har har en returtype '%T' som ikke er fra Java"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 #| msgid "node is alias but not definition"
 msgid "concept %qD has no definition"
 msgstr "node er alias men ikke definition"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "a function concept cannot be constrained"
 msgstr "funktion kan ikke indbygges"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "constraints on a non-templated function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-id `%D' in declaration of primary template"
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ugyldig brug af skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' is not allowed in declaration of friend template specialization `%D'"
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "'inline' er ikke tilladt i erklæring venneskabelonsspecialisering '%D'"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "kan ikke erklære %<::main%> som en skabelon"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "kan ikke erklære %<::main%> som indlejret"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "kan ikke erklære '::main' som statisk"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be static"
 msgstr "kan ikke erklære '::main' som statisk"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "%qD has invalid argument list"
 msgstr "#%s med ugyldig parameter"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "'main' skal returnere typen 'int'"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of implicitly-declared %qD"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "'%#D' tidligere defineret her"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, fuzzy, gcc-internal-format
 #| msgid "no `%#D' member function declared in class `%T'"
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion '%#D' erklæret i klassen '%T'"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "kan ikke erklære '::main' som en skabelon"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+#| msgid "specialization of %D after instantiation"
+msgid "concept must be defined at namespace scope"
+msgstr "specialisering af '%D' efter instantiering"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids initialization of member constant `%D' of non-integral type `%T'"
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ forbyder tildeling af startværdi til medlemskonstant '%D' af en ikke-heltallig type"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "størrelsen af tabellen '%D' er ikke af en heltalstype"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array `%D'"
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med størrelsen nul"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ forbyder tabel med størrelsen nul"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array `%D'"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med variabel størrelse"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tabeldimension for stor"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of %qT"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of void"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of references"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "angivelse af returneringstypen til konstruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, fuzzy, gcc-internal-format
 #| msgid "return type specified for `operator %T'"
 msgid "return type specified for %<operator %T%>"
 msgstr "returtype angivet for 'operator %T'"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unavngiven variabel eller felt erklæret void"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qE as non-member"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "declarator-id missing; using reserved word `%D'"
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "erklærer-id mangler; bruger reserveret ord '%D'"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition does not declare parameters"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, fuzzy, gcc-internal-format
 #| msgid "both long and short specified for `%s'"
 msgid "both %qs and %qs specified"
 msgstr "både long og short er angivet for '%s'"
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration of %qs"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids declaration of `%s' with no type"
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ forbyder erklæring af '%s' uden en type"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_trap understøttes ikke på denne målarkitektur"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ understøtter ikke 'long long'"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for `%s'"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "signed og unsigned er begge angivet for '%s'"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for `%s'"
 msgid "%<long%> and %<short%> specified together"
 msgstr "long og short er begge angivet for '%s'"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs specified with %qT"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs specified with %<typeof%>"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-erklæringer er ugyldig i parametererklæringer"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "structured binding declaration cannot be %qs"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "Ugyldig erklæring"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "storage class specified for %qs"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qs declared %<extern%>"
 msgstr "indlejret funktion '%s' er erklæret 'extern'"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, fuzzy, gcc-internal-format
 #| msgid "top-level declaration of `%s' specifies `auto'"
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "'%s' i funktionsvirkefelt underforstået auto og erklæret '__thread'"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "egenskaben '%s' ignoreret"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses"
 msgstr "uventet operand"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "requires-clause on return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ugyldig brug af '%D"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "%qs declared as function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "%qs declared as function returning an array"
 msgstr "'%s' er erklæret som en funktion der returnerer en tabel"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%s som heltal i stedet for kommatal på grund af prototypen"
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be `%s'"
 msgid "constructors may not be cv-qualified"
 msgstr "konstruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "constructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function `%s' in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "kan ikke definere vennefunktion '%s' i en lokal klassedefinition"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktionsfunktioner må ikke have parametre"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T'"
 msgid "cannot declare pointer to %q#T"
 msgstr "kan ikke erklære henvisning til '%#T'"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "cannot declare reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T' member"
 msgid "cannot declare pointer to %q#T member"
 msgstr "kan ikke erklære henvisning til medlemmet '%#T'"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan ikke erklære referencer til referencer"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' used as a declarator"
 msgid "template-id %qD used as a declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner er underforstået venner af deres klasse"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification `%T::' on member `%s' ignored"
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra modifikation '%T::' af medlemmet '%s' ignoreret"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member `%T::%s' within `%T'"
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlem '%T::%s' inde i '%T'"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type `%T'"
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be `explicit'"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "kun erklæringer af konstruktionsfunktioner kan være 'explicit'"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member `%s' cannot be declared `mutable'"
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er objektmedlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 #| msgid "static `%s' cannot be declared `mutable'"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referencen %qs kan ikke erklæres %<mutable%>"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef erklæret %<auto%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-navn kan ikke være en indlejret-navn-specifikation"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ forbyder indlejret type %qD med samme navn som den omgivende klasse"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet for friend class-erklæring"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "forsøg på at gøre klassen %qT til ven af det globale virkningsfelt"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, fuzzy, gcc-internal-format
 #| msgid "abstract declarator `%T' used as declaration"
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt erklærer '%T' benyttet som erklæring"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use `::' in parameter declaration"
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter `%D' to be of type `%T'"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "kan ikke erklære parameteren '%D' til at være af typen '%T'"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter declared %<auto%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "ugyldig brug af '::'"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function `%#D' conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "erklæring af C-funktionen '%#D' strider mod"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "'%D' kan ikke erklæres virtual eftersom den altid er statisk"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD as member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %qs"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a constructor cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "kan ikke åbne %s"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "feltet '%D' er af en ufuldstændig type"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "name %qT has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static data member %qE declared %qs"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %qs"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `auto' invalid for function `%s'"
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen 'auto' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `register' invalid for function `%s'"
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen 'register' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier `%s' not allowed after struct or class"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "typeangivelsen '%s' er ikke tilladt efter struct eller class"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, fuzzy, gcc-internal-format
 #| msgid "virtual non-class function `%s'"
 msgid "virtual non-class function %qs"
 msgstr "virtuel funktion '%s' tilhører ikke en klasse"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, fuzzy, gcc-internal-format
 #| msgid "method definition not in class context"
 msgid "%qs defined in a non-class scope"
 msgstr "metodedefinitionen optræder ikke i en klassekontekst"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "kan ikke erklære medlemsfunktion '%D' til at have statisk kædning"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan ikke erklære en funktion for static inden i en anden funktion"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, fuzzy, gcc-internal-format
 #| msgid "`static' may not be used when defining (as opposed to declaring) a static data member"
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "'static' må ikke bruges ved definering (i modsætning til erklæring) af et statisk datamedlem"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, fuzzy, gcc-internal-format
 #| msgid "cannot explicitly declare member `%#D' to have extern linkage"
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "kan ikke eksplicit erklære medlemmet '%#D' til at have extern-kædning"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qs initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qs has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `virtual' in template declaration of `%#D'"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ugyldig brug af 'virtual' i skabelonserklæring af '%#D'"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constructor; you probably meant `%T (const %T&)'"
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ugyldig konstruktionsfunktion; du mente sandsynligvis '%T (const %T&)'"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD may not be declared within a namespace"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be either a non-static member function or a non-member function"
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "'%D' skal enten være en ikke-statisk medlemsfunktion eller ikke en medlemsfunktion"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must have an argument of class or enumerated type"
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "'%D' skal have en parameter af en klasse- eller enum-type"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ forbyder flertydiggørelse af operatoren ?:"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must not have variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "'%D' skal tage mod nul eller én parameter"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfiks '%D' skal tage mod 'int' som parameter"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfiks '%D' skal tage mod 'int' som den anden parameter"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "%qD cannot have default arguments"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, fuzzy, gcc-internal-format
 #| msgid "prefix `%D' should return `%T'"
 msgid "prefix %qD should return %qT"
 msgstr "præfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' should return `%T'"
 msgid "postfix %qD should return %qT"
 msgstr "postfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should return by value"
 msgid "%qD should return by value"
 msgstr "'%D' skal returnere pr. værdi (ikke reference)"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter `%T' after `%s'"
 msgid "using template type parameter %qT after %qs"
 msgstr "bruger skabelonstypeparameter '%D' efter '%s'"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "using alias template specialization %qT after %qs"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, fuzzy, gcc-internal-format
 #| msgid "using typedef-name `%D' after `%s'"
 msgid "using typedef-name %qD after %qs"
 msgstr "bruger typedef-navn '%D' efter '%s'"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "tidligere erklæring som '%#D'"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "'%#D' omerklæret som %C"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dette er en tidligere erklæring"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "'%#D' omerklæret som %C"
@@ -55257,116 +55308,116 @@ msgstr "'%#D' omerklæret som %C"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qT is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, fuzzy, gcc-internal-format
 #| msgid "use of enum `%#D' without previous declaration"
 msgid "use of enum %q#D without previous declaration"
 msgstr "brug af enum '%#D' uden tidligere erklæring"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration `%#D' declares a non-template function"
 msgid "redeclaration of %qT as a non-template"
 msgstr "friend-erklæring '%#D' erklærer en ikke-skabelonsfunktion"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `%D' to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "kan ikke erklære '%D' til at være en bitfeltstype"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, fuzzy, gcc-internal-format
 #| msgid "derived union `%T' invalid"
 msgid "derived union %qT invalid"
 msgstr "nedarvet union '%T' ugyldig"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in the class %T"
 msgid "%qT defined with multiple direct bases"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "%qT defined with direct virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, fuzzy, gcc-internal-format
 #| msgid "base type `%T' fails to be a struct or class type"
 msgid "base type %qT fails to be a struct or class type"
 msgstr "stamklassetype '%T' er hverken en struct- eller class-type"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, fuzzy, gcc-internal-format
 #| msgid "recursive type `%T' undefined"
 msgid "recursive type %qT undefined"
 msgstr "rekursiv type '%T' ikke defineret"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate base type `%T' invalid"
 msgid "duplicate base type %qT invalid"
 msgstr "stamklassetype '%T' optræder mere end én gang"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidligere definition her"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "specialisering af %qD i andet navnerum"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -55376,87 +55427,87 @@ msgstr "parameter til '%s' skal være en 2 bit-konstant"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in enumeration values at `%D'"
 msgid "overflow in enumeration values at %qD"
 msgstr "enum-værdier for store ved '%D'"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "flere definitioner af %q#T"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "return type %q#T is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, fuzzy, gcc-internal-format
 #| msgid "`operator=' should return a reference to `*this'"
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "'operator=' bør returnere en reference til '*this'"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in class `%T'"
 msgid "%qD is already defined in class %qT"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -55501,7 +55552,7 @@ msgstr "kan ikke udføre delete på en funktion; kun henvisninger til objekter e
 msgid "deleting %qT is undefined"
 msgstr "benyttelse af delete på '%T' er ikke defineret"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %q#D"
@@ -55513,7 +55564,7 @@ msgstr "skabelonserklæring af '%#D'"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
@@ -55880,24 +55931,24 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "use of deleted function %qD"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, fuzzy, gcc-internal-format
 #| msgid "use of template qualifier outside template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -56020,7 +56071,7 @@ msgstr "brug af '%D' er tvetydigt"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "%qD is not a member of %qT"
@@ -56032,7 +56083,7 @@ msgstr "'%D' er ikke et medlem af '%T'"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "'%D' er ikke et medlem af '%T'"
@@ -56243,443 +56294,443 @@ msgstr "standardklargøring af '%#D' som er af en referencetype"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "'%D' bør blive klargjort i medlemsklargøringslisten"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "klassen '%T' er underforstået ven med sig selv"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid initializer for array member %q#D"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member `%D'"
 msgid "uninitialized const member in %q#T"
 msgstr "konstant medlem '%D' uden startværdi"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member `%D'"
 msgid "uninitialized reference member in %q#T"
 msgstr "referencemedlem '%D' uden startværdi"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, fuzzy, gcc-internal-format
 #| msgid "base `%T' will be initialized after"
 msgid "base %qT will be initialized after"
 msgstr "stamklasse '%T' vil blive klargjort efter"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 #| msgid "  base `%T'"
 msgid "  base %qT"
 msgstr "  stamklasse '%T'"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 #| msgid "multiple initializations given for `%D'"
 msgid "multiple initializations given for %qD"
 msgstr "flere startværdier angivet for '%D'"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "multiple initializations given for base `%T'"
 msgid "multiple initializations given for base %qT"
 msgstr "flere startværdier angivet for stamklassen '%T'"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, fuzzy, gcc-internal-format
 #| msgid "initializations for multiple members of `%T'"
 msgid "initializations for multiple members of %qT"
 msgstr "startværdier for flere medlemmer af '%T'"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "stamklassen '%#T' bør eksplicit blive klargjort i kopikonstruktionsfunktionen"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "class %qT does not have any field named %qD"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "feltet '%#D' er statisk; det eneste sted det kan klargøres er ved dets definition"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, fuzzy, gcc-internal-format
 #| msgid "unnamed initializer for `%T', which has no base classes"
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, fuzzy, gcc-internal-format
 #| msgid "unnamed initializer for `%T', which uses multiple inheritance"
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "unavngiven klargøring af '%T' som benytter multipel nedarvning"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, fuzzy, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct base of `%T'"
 msgid "type %qT is not a direct base of %qT"
 msgstr "typen '%D' er ikke en direkte stamklasse til '%T'"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "%qT is not a class type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type `%T' does not have member `%D'"
 msgid "incomplete type %qT does not have member %qD"
 msgstr "ufuldstændig type '%T' har ikke medlemmet '%D'"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer to bit-field `%D'"
 msgid "invalid pointer to bit-field %qD"
 msgstr "ugyldig henvisning til bitfeltet '%D'"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member `%D'"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "referencemedlem '%D' uden startværdi"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in `new' of `%#T'"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "konstant uden startværdi i 'new' af '%#T'"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "at offset %wi from %qD declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "heltalsoverløb i udtryk"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "double quoted strings not allowed in #if expressions"
 msgid "variably modified type not allowed in new-expression"
 msgstr "strenge med dobbelte anførselstegn er ikke tilladte i #if-udtryk"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type `void' for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "ugyldig type 'void' til new"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in `new' of `%#T'"
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "konstant uden startværdi i 'new' af '%#T'"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "field '%s' not found in class"
 msgid "no suitable %qD found in class %qT"
 msgstr "feltet '%s' blev ikke fundet i klassen"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous"
 msgid "request for member %qD is ambiguous"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new kan ikke bruges på en funktionstype"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "startværdien slutter for tidligt"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukendt tabelstørrelse i delete"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to references"
 msgid "cannot capture %qE by reference"
 msgstr "kan ikke erklære %s til referencer"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "capture by copy of incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -56740,66 +56791,66 @@ msgstr ""
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
@@ -56997,334 +57048,334 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "cast does not match function type"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "cast does not match function type"
 msgid "expected signature: %qD"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a template cannot be defaulted"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' cannot be declared"
 msgid "%qD cannot be defaulted"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "strider mod tidligere erklæring '%#D'"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' hides constructor for `%#T'"
 msgid "%q#D hides constructor for %q#D"
 msgstr "'%#D' skjuler konstruktionsfunktion for '%#T'"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "Generér ikke kode til at kontrollere undtagelsesspecifikationer"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' names constructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "'%D' navngiver en konstruktionsfunktion"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct base of `%T'"
 msgid "%qT is not a direct base of %qT"
 msgstr "typen '%D' er ikke en direkte stamklasse til '%T'"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' names constructor"
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "'%D' navngiver en konstruktionsfunktion"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate type qualifiers in %s declaration"
 msgid "explicit qualification in declaration of %qD"
 msgstr "dobbelte typemodifikationer i %s-erklæring"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should have been declared inside `%D'"
 msgid "%qD should have been declared inside %qD"
 msgstr "'%D' skulle have været erklæret inden i '%D'"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "egenskabsdirektivet '%s' ignoreret"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' cannot be declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "it was later defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 #| msgid "switch \"%s\" is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "tilvalget '%s' understøttes ikke længere"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, fuzzy, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "cannot nest more than %d namespaces"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, fuzzy, gcc-internal-format
 #| msgid "namespace alias `%D' not allowed here, assuming `%D'"
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "navnerumsalias '%D' er ikke tilladt her, antager '%D'"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "%qD defined here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' conflicts with previous using declaration `%#D'"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "'%#D' strider mod tidligere using-erklæring '%#D'"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "tidligere definition her"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -57350,7 +57401,7 @@ msgstr "kaldenavnet '%s' er i modstrid med den interne navngivningsstrategi i GN
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
@@ -57377,7 +57428,7 @@ msgstr "'%#D' kan ikke erklæres"
 msgid "request for member %qE in non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "'%#D' kan ikke erklæres"
@@ -57469,7 +57520,7 @@ msgstr "ugyldig roteringsinstruktion"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -57614,7 +57665,7 @@ msgstr "skabelonsparameter %d er ugyldig"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -57746,7 +57797,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -57803,7 +57854,7 @@ msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected primary-expression"
@@ -57835,7 +57886,7 @@ msgstr ""
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
@@ -57857,12 +57908,12 @@ msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a template"
@@ -57899,7 +57950,7 @@ msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 msgid "expected nested-name-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "new kan ikke bruges på en referencetype"
@@ -57915,7 +57966,7 @@ msgstr "new kan ikke bruges på en referencetype"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -57931,1214 +57982,1220 @@ msgstr "ISO C++ forbyder sammensatte konstanter"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
 msgstr "ugyldig brug af '%D"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a member of `%T'"
 msgid "%<%D::%D%> is not a class member"
 msgstr "'%D::%D' er ikke et medlem af '%T'"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tillader ikke %<alignof%> med en ikke-type"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-expression"
 msgid "types may not be defined in %qs expressions"
 msgstr "typer kan ikke defineres i et nyt udtryk"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "typer kan ikke defineres i et nyt udtryk"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected expression-list or type-id"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "brug af ældre type typeomtvingning"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "foreslår paranteser omkring && inden i ||"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ tillader ikke ?: med udeladt midter operand"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, fuzzy, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "ISO C forbyder brug af typeomtvingningsudtryk som venstreværdier"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+#| msgid "Invalid expression statement"
+msgid "lambda-expression in template parameter type"
+msgstr "Ugyldig udtrykssætning"
+
+#: cp/parser.c:10819
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to references"
 msgid "%<this%> cannot be captured by reference"
 msgstr "kan ikke erklære %s til referencer"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer for lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only variable `%s'"
 msgid "capture of non-variable %qE"
 msgstr "%s af variablen '%s' der kun må læses"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<...%> in lambda capture"
 msgstr "for mange inddatafiler"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "default argument specified for lambda parameter"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<mutable%>"
 msgstr "'volatile' optræder mere end én gang"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected labeled-statement"
 msgstr "tom krop i en else-sætning"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, fuzzy, gcc-internal-format
 #| msgid "case label `%E' not within a switch statement"
 msgid "case label %qE not within a switch statement"
 msgstr "case-etiket '%E' befinder sig ikke inden i en switch-sætning"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "In statement function"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "I sætningsfunktion"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
 msgstr "tom krop i en else-sætning"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "condition declares an array"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "condition declares a function"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "new kan ikke bruges på en referencetype"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, fuzzy, gcc-internal-format
 #| msgid "empty scalar initializer"
 msgid "expected initializer"
 msgstr "tom skalarstartværdi"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ forbyder beregnede goto'er"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 msgid "expected module-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "method definition not in class context"
 msgid "module-declaration not permitted in header-unit"
 msgstr "metodedefinitionen optræder ikke i en klassekontekst"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "private module fragment"
 msgstr "ingen parametre"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "import-declaration must be at global scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attributes may be inserted here"
 msgstr "egenskaben '%s' ignoreret"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flere erklæringer '%T' og '%T'"
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "tom erklæring"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "invalid initializer for structured binding declaration"
 msgstr "ugyldig startværdi til bitstreng"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in friend function declarations"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' invalid in `%#T'"
 msgid "%qD invalid in lambda"
 msgstr "'%D' ugyldig i '%#T'"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in friend function declarations"
 msgid "type-specifier invalid in lambda"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "kun konstruktionsfunktioner har stamklasseklargøringer"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "cannot expand initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "forældet stamklasseklargøring"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "expected suffix identifier"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type modifier within pointer declarator"
 msgid "invalid encoding prefix in literal operator"
 msgstr "ugyldig typemodifikation i erklæring af henvisning"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
 msgstr "uventet operand"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, fuzzy, gcc-internal-format
 #| msgid "keyword `export' not implemented, and will be ignored"
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "det reserverede ord 'export' er ikke implementeret og vil blive ignoreret"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 #| msgid "keyword `export' not implemented, and will be ignored"
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "det reserverede ord 'export' er ikke implementeret og vil blive ignoreret"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "uventet operand"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "uventet operand"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "uventet operand"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "uventet operand"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "skabelonsspecialisering med C-kædning"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, fuzzy, gcc-internal-format
 #| msgid "sigof type specifier"
 msgid "expected type specifier"
 msgstr "sigof-typeangivelse"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "forventet skabelon-id for typen"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "forventet type-navn"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "concept defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "uventet operand"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 #| msgid "typedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "typedef-navn kan ikke være en indlejret-navn-specifikation"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on uninstantiated type"
 msgid "attributes ignored on uninstantiated type"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ekstra kvalifikation er ikke tilladt"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ forbyder tomme unavngivet enum"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD er ikke et navnerum-navn"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "forventet navnerum-navn"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "uventet operand"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "navnerumnavn krævet"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 #| msgid "function with nested functions cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "funktion med indlejrede funktioner kan ikke indbygges"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, fuzzy, gcc-internal-format
 #| msgid "namespace `%T' undeclared"
 msgid "namespace %qD entered"
 msgstr "navnerummet '%T' er ikke erklæret"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "opaque-enum-declaration here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate case value"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "case-værdi optræder mere end én gang"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%D' is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%J'%D' er ikke defineret uden for funktionsvirkefelt"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "'%T' er ikke et navnerum"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "parameternavne (uden typer) i funktionserklæringen"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "parameternavne (uden typer) i funktionserklæringen"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr "funktionen '%s' omerklæret som inline"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "en funktionsdefinition er ikke tilladt her"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-member function `%D'"
 msgid "initializer provided for function"
 msgstr "startværdi angivet for ikke-medlemsfunktion '%D'"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "funktionen '%s' omerklæret som inline"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array bound is not an integer constant"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a template"
 msgid "%<%T::%E%> is not a type"
@@ -59148,461 +59205,461 @@ msgstr "'%D::%D' er ikke en skabelon"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ugyldig erklærer"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Ugyldig erklæring"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "tom erklæring"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is a namespace"
 msgid "%qD is a namespace"
 msgstr "'%D' er et navnerum"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "uventet operand"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate case value"
 msgid "duplicate cv-qualifier"
 msgstr "case-værdi optræder mere end én gang"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "--resource påkræver -o"
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "duplicate virt-specifier"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "ugyldig brug af '%T'"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "forventede %<,%> eller %<...%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tillader ikke GNU-udpegede startværdier"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillader ikke C99-udpegede startværdier"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> er ikke tilladt i udpegede startværdiliste"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "forventet klasse-navn"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "forventede %<{%> eller %<:%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "kan ikke finde filen for klassen %s"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid class name in declaration of %qD"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "tidligere definition af '%#T'"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "uventet operand"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, fuzzy, gcc-internal-format
 #| msgid "`__alignof' applied to a bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "'__alignof' benyttet på et bitfelt"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%#D' with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "Generér ikke kode til at kontrollere undtagelsesspecifikationer"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ugyldig brug af %<auto%> i undtagelsesspecifikation"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected attribute before %<...%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "expression must be enclosed in parentheses"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "asm template is not a string constant"
 msgid "result type is not a plain type-constraint"
 msgstr "asm-sætning er ikke en strengkonstant"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "angivet justering er ikke en konstant"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
@@ -59611,653 +59668,653 @@ msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver understøttes ikke længere"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching concept for template-introduction"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template `%#D' in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "ugyldig erklæring af medlemsskabelon '%#D' i lokal klasse"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "invalid explicit specialization"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %<typedef%>"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> før %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 understøtter ikke %<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "duplikere %qD"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "duplikere %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "forventede %<new%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "forventede %<delete%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "forventede %<return%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "forventede %<extern%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "forventede %<static_assert%>"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "forventede %<operator%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "forventede %<class%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "forventede %<template%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "forventede %<namespace%>"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "forventede %<using%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "forventede %<asm%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "forventede %<try%>"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "forventede %<throw%>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<auto%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "forventede %<__label__%>"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "forventede %<@try%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "forventede %<@synchronized%>"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "forventede %<@throw%>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "forventede %<__transaction_atomic%>"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "forventede %<__transaction_relaxed%>"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "%<@end%> forventet"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "forventede %<::%>"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "forventede %<...%>"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "forventede %<*%>"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "forventede %<~%>"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' tag used in naming `%#T'"
 msgid "%qs tag used in naming %q#T"
 msgstr "'%s'-mærke benyttet i navngivning af '%#T'"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T var tidligere erklæret her"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "'%D' ikke erklæret"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "uventet operand"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "%qT defined as %qs here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 #| msgid "  first declared as `%#D' here"
 msgid "%qT first declared as %qs here"
 msgstr "  først erklæret som '%#D' her"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omerklæret med anden adgang"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Klasse- eller grænsefladeerklæring forventet"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name `%s' for register variable"
 msgid "invalid type for instance variable"
 msgstr "ugyldigt registernavn '%s' for registervariabel"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, fuzzy, gcc-internal-format
 #| msgid "Identifier expected"
 msgid "identifier expected after %<@protocol%>"
 msgstr "Kaldenavn forventet"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "ugyldig typeparameter"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown property attribute %qE"
 msgstr "ukendt registernavn: %s"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected integer expression list"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "invalid identifier `%s'"
 msgid "invalid reduction-identifier"
 msgstr "ugyldigt kaldenavn '%s'"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "ugyldig startværdi"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "expected id-expression (arguments)"
 msgstr "uventede bivirkninger i adresse"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma map, ignored"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "forkert udformet '#pragma map' - ignoreret"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "profilering understøttes ikke endnu"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "data member %qD cannot be a member template"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid member template declaration %qD"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope `%D'"
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "eksplicit specialisering i virkefeltet '%D' der ikke er et navnerum"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "specialisering af %qD skal fremstå ved navnerumsanvendelsesområde"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "specialisering af %qD i andet navnerum"
 
 # hænger sammen med foregående tekst, derfor ikke 'fra'
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  i forhold til definition af %q#D"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of alias template %qD"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization of non-template %qT"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of `%T' after instantiation"
 msgid "specialization of %qT after instantiation"
 msgstr "specialisering af '%T' efter instantiering"
 
 # hænger sammen med foregående tekst, derfor ikke 'fra'
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q#D"
 msgid "from definition of %q#D"
@@ -60265,162 +60322,162 @@ msgstr "  i forhold til definition af %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, fuzzy, gcc-internal-format
 #| msgid "specialization `%T' after instantiation `%T'"
 msgid "specialization %qT after instantiation %qT"
 msgstr "specialisering af '%T' efter instantiering '%T'"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "template specialization with C linkage"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "skabelonsspecialisering med C-kædning"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a variable template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "eksplicit specialisering af %D efter første brug"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "eksplicit specialisering af %D efter første brug"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definition angivet for eksplicit instantiering"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of `%D'"
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization declared %<concept%>"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%D' of function template"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "partiel specialisering '%D' af funktionsskabelon"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%D' of function template"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "partiel specialisering '%D' af funktionsskabelon"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD is not a template function"
@@ -60434,164 +60491,164 @@ msgstr "'%D' er ikke en medlemsskabelonfunktion"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, fuzzy, gcc-internal-format
 #| msgid "no member function `%D' declared in `%T'"
 msgid "no member function %qD declared in %qT"
 msgstr "ingen medlemsfunktion '%D' erklæret i '%T'"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "friend declaration here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization of function concept %qD"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, fuzzy, gcc-internal-format
 #| msgid "        `%D'"
 msgid "        %qD"
 msgstr "        '%D'"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "        `%D'"
 msgid "        %s"
 msgstr "        '%D'"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type `%T' declared `friend'"
 msgid "template parameter %qD declared here"
 msgstr "skabelonsparametertypen '%T' erklæret 'friend'"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of variable concept %q#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments for partial specialization %qT"
 msgstr "for mange parametre til funktionen"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "primary template %qD"
 msgstr "etiketten '%D' optræder mere end én gang"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "template argument %qE involves template parameter(s)"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
 # flertalsform unødvendig
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' of template argument `%E' depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -60599,19 +60656,19 @@ msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 msgstr[1] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for `%D'"
 msgid "no default argument for %qD"
@@ -60621,53 +60678,53 @@ msgstr "ingen standardparameter til '%D'"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "template %qD declared"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "skabelonsklasse uden et navn"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -60677,66 +60734,66 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid template declaration of %qD"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "template definition of non-template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "skabelonsdefinition af ikke-skabelon '%#D'"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, fuzzy, gcc-internal-format
 #| msgid "expected %d levels of template parms for `%#D', got %d"
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "forvented %d niveauer af skabelonsparametre for '%#D', modtog %d"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "got %d template parameters for %q#D"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#T'"
 msgid "got %d template parameters for %q#T"
 msgstr "modtog %d skabelonsparametre for '%#T'"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d påkrævet"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not a template type"
 msgstr "'%T' er ikke en skabelonstype"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -60744,7 +60801,7 @@ msgid_plural "redeclared with %d template parameters"
 msgstr[0] "'%D' benyttet uden skabelonsparametre"
 msgstr[1] "'%D' benyttet uden skabelonsparametre"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration %qD used %d template parameter"
@@ -60752,485 +60809,485 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "tidligere erklæring af '%#D' her"
 msgstr[1] "tidligere erklæring af '%#D' her"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter `%#D'"
 msgid "template parameter %q+#D"
 msgstr "skabelonsparameter '%#D'"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as `%#D'"
 msgid "redeclared here as %q#D"
 msgstr "omerklæret her som '%#D'"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, fuzzy, gcc-internal-format
 #| msgid "it must be a pointer-to-member of the form `&X::Y'"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "den skal være en henvisning til medlem på formen '&X::Y'"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "because it is a member of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "  mismatched types %qT and %qT"
 msgstr "sammenligning mellem typerne '%#T' og '%#T'"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type `%T' to type `%T'"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an ambiguous base of `%T'"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "'%T' er en tvetydig stamklasse til '%T'"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not derived from type `%T'"
 msgid "  %qT is not derived from %qT"
 msgstr "typen '%T' er ikke nedarvet fra typen '%T'"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument %qE does not match %qE"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring attributes in template argument %qE"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "ugyldig brug af 'restrict'"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, fuzzy, gcc-internal-format
 #| msgid "to refer to a type member of a template parameter, use `typename %E'"
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "benyt 'typename %E' for at referere til et typemedlem af en skabelonsparameter"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a constant of type `%T', got `%T'"
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  forventede en konstant af typen '%T', modtog '%T'"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected a type, got %qE"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%T'"
 msgid "  expected a type, got %qT"
 msgstr "  forventede en type, modtog '%T'"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got `%T'"
 msgid "  expected a class template, got %qT"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected %qD but got %qD"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 #| msgid "provided for `%D'"
 msgid "provided for %qD"
 msgstr "angivet for '%D'"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%q#D is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, fuzzy, gcc-internal-format
 #| msgid "non-template type `%T' used as a template"
 msgid "non-template type %qT used as a template"
 msgstr "ikke-skabelonstype '%T' benyttet som skabelon"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration `%D'"
 msgid "for template declaration %q+D"
 msgstr "til skabelonserklæring '%D'"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 #| msgid "internal gcc abort"
 msgid "template constraint failure for %qD"
 msgstr "intern GCC-afbrydelse"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member function of non-class type `%T'"
 msgid "creating pointer to member function of non-class type %qT"
@@ -61249,334 +61306,334 @@ msgstr "opretter henvisning til medlemsfunktion af typen '%T' der ikke er en kla
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "variable %qD has function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "i erklæringen '%D'"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "function returning an array"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "danner reference til void"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming pointer to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming reference to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming pointer to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming reference to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "creating pointer to member of non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member of type void"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class, struct, or union type"
 msgid "%qT is not a class, struct, or union type"
 msgstr "'%T' er ikke en class-, struct- eller union-type"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use of %qs in template"
 msgstr "brug af '%s' i skabelon"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, fuzzy, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "'%D' benyttes som en type, men er ikke defineret som en type"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, fuzzy, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "  (benyt 'typename %T::%D' hvis det er hvad du mener)"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "startværdielement er ikke en konstant"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, fuzzy, gcc-internal-format
 #| msgid "missing static field `%s'"
 msgid "using invalid field %qD"
 msgstr "manglende statisk felt '%s'"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to __builtin_choose_expr not a constant"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "første parameter til '__builtin_choose_expr' skal være en konstant"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qD is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "skabelonsparameter '%T' benytter anonym type"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "standardparameter for '%#D' har typen '%T'"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, fuzzy, gcc-internal-format
 #| msgid "  trying to instantiate `%D'"
 msgid "  trying to instantiate %qD"
 msgstr "  ved forsøg på at instantiere '%D'"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-template %q#D"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching template for %qD found"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit instantiation of %q#D"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#D'"
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "'%#D' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `extern' on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af 'extern' ved eksplicitte instantieringer"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#T' before definition of template"
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplicit instantiering af '%T' før definering af skabelonen"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `%s' on explicit instantiations"
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af '%s ved eksplicitte instantieringer"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#T'"
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "'%#T' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "exception specification of %qD depends on itself"
@@ -61589,172 +61646,172 @@ msgstr "eksplicit specialisering af %D efter første brug"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%D' but no definition available"
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplicit instantiering af '%D', men ingen definition tilgængelig"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "'%T' er ikke et navnerum"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "funktion overvejes ikke for indbygning"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "Ugyldig erklæring"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Ugyldig metodeerklæring, returtype påkrævet"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ugyldig standardparameter i skabelon"
@@ -61909,587 +61966,587 @@ msgstr "'%#D' kan ikke erklæres"
 msgid "  since %q+#D declared in base class"
 msgstr "  eftersom '%#D' er erklæret i stamklassen"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous `else'"
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "%Hforeslår eksplicitte krøllede paranteser for at undgå tvetydig 'else'"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "catching non-reference type %q#T"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 #| msgid "type of asm operand `%E' could not be determined"
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "typen af asm-operanden '%E' kunne ikke afgøres"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "begyndelseserklæring i 'for'-løkke benyttet uden for C99-tilstand"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D' in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "ugyldig brug af medlemmet '%D' i statisk medlemsfunktion"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "`this' is unavailable for static member functions"
 msgid "%<this%> is unavailable for static member functions"
 msgstr "'this' er ikke tilgængelig for statiske medlemsfunktioner"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' in non-member function"
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ugyldig brug af 'this' i ikke-medlemsfunktion"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' at top level"
 msgid "invalid use of %<this%> at top level"
 msgstr "ugyldig brug af 'this' ved øverste niveau"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not of type `%T'"
 msgid "%qE is not of type %qT"
 msgstr "'%E' er ikke af typen '%T'"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword `class' or `typename'"
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "skabelonstypeparametre skal begynde med 'class' eller 'typename'"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, fuzzy, gcc-internal-format
 #| msgid "definition of `%#T' inside template parameter list"
 msgid "definition of %q#T inside template parameter list"
 msgstr "definition af '%#T' inden i skabelonsparameterliste"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid definition of qualified type %qT"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not captured"
 msgstr "'%D' ikke erklæret"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter outside function body"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "use of class template %qT as expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous in multiple inheritance lattice"
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt i det multiple nedarvningsnet"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "type of `%E' is unknown"
 msgid "type of %qE is unknown"
 msgstr "typen af '%E' er ukendt"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not an enumeration type"
 msgstr "'%T' er ikke en skabelonstype"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "lagringsklasseanvisninger er ugyldige i parametererklæringer"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "%qE has const type for %<reduction%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> static expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<gang%> static value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<vector%> length expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<worker%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "angivet justering er ikke en potens af 2"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "%<worker%> num value must be positive"
 msgstr "venstre parameter skal være en skive"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in map clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in map clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "for mange inddatafiler"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<grainsize%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<priority%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<hint%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<tile%> argument needs integral type"
 msgstr "skive-slutning skal være heltal"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "%qE evaluates to false"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "erklæring uden static af '%s' følger static-erklæring"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
 # flertalsform unødvendig
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported arg to `__builtin_return_address'"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -62498,22 +62555,22 @@ msgstr "ikke-understøttet parameter til '__builtin_return_address'"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -62524,1198 +62581,1198 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "modifikationerne '%V' kan ikke anvendes på '%T'"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid " declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%T' has incomplete type"
 msgid "base class %qT is not public"
 msgstr "stamklasse '%T' er af en ufuldstændig type"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not public"
 msgstr "'%D' ikke erklæret"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is mutable"
 msgstr "'%D' er ikke et navnerum"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD has a non-structural type"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to Java class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "egenskaben '%s' kan kun anvendes med Java-klassedefinitioner"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute takes no arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "den udbedte init_priority er ikke en heltalskonstant"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, fuzzy, gcc-internal-format
 #| msgid "can only use `%s' attribute on file-scope definitions of objects of class type"
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "kan kun bruge egenskaben '%s' på filvirkefeltsdefinitioner af objekter af klassetype"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "den udbedte init_priority er uden for det gyldige interval"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "den udbedte init_priority er reserveret til intern brug"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute is not supported on this platform"
 msgid "%qE attribute is not supported on this platform"
 msgstr "egenskaben '%s' er ikke understøttet på denne platform"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "the %qE attribute requires arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "'%T::%D' er ikke en gyldig erklærer"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a valid expression"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%T' er ikke et gyldigt udtryk"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "zero as null pointer constant"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_*-kontrol: mislykkedes i %s, ved %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type `void *' and pointer-to-function"
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ forbyder %s mellem henvisning af typen 'void *' og henvisning til funktion"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type `void *' and pointer-to-function"
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ forbyder %s mellem henvisning af typen 'void *' og henvisning til funktion"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type `void *' and pointer-to-function"
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ forbyder %s mellem henvisning af typen 'void *' og henvisning til funktion"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of `%s' to a member function"
 msgid "invalid application of %qs to a member function"
 msgstr "ugyldig brug af '%s' på en medlemsfunktion"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ugyldig anvendelse af '%s' på en void-type"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ forbyder anvendelse af 'sizeof' på et udtryk af en funktionstype"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ugyldig anvendelse af '%s' på en void-type"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ forbyder anvendelse af 'sizeof' på et udtryk af en funktionstype"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to `%T'"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "forældet konvertering fra strengkonstant til '%T'"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to `%T'"
 msgid "deprecated conversion from string constant to %qT"
 msgstr "forældet konvertering fra strengkonstant til '%T'"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' in `%E', which is of non-aggregate type `%T'"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-sammensat type '%T'"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' in `%E', which is of non-class type `%T'"
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member `%D' of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ugyldig tilgang til ikke-statisk datamedlem '%D' af NULL-objekt"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a member of `%T'"
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "'%D::%D' er ikke et medlem af '%T'"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD is not a member template function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qT is not a pointer-to-object type"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared `register'"
 msgid "subscripting array declared %<register%>"
 msgstr "indeksering af tabel som er erklæret 'register'"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, fuzzy, gcc-internal-format
 #| msgid "object missing in use of `%E'"
 msgid "object missing in use of %qE"
 msgstr "objekt mangler i brug af '%E'"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids calling `::main' from within program"
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ forbyder kald af '::main' inde fra programmet"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "must use .* or ->* to call pointer-to-member function in `%E (...)'"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "brug .* eller ->* i kald af henvisning til medlemsfunktion i '%E (...)'"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qE cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to constructor %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to constructor %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to method %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to method %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "overløb i konstant udtryk"
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "assuming cast to type `%T' from overloaded function"
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antager typeomtvingning til typen '%T' fra flertydig funktion"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL benyttet i udregning"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ forbyder sammenligning mellem henvisningsvariabel og heltal"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "uordnet sammenligning af ikke-kommatalsparameter"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types `%T' and `%T' to binary `%O'"
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ugyldige operander af typerne '%T' og '%T' til binær '%O'"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids using pointer of type `void *' in subtraction"
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning af typen 'void *' i fratrækning"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til funktion i fratrækning"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til medlemsfunktion i fratrækning"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ugyldig brug af en henvisning til en ufuldstændig type i henvisningsberegning"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of constructor %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of destructor %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' to form a pointer-to-member-function.  Use a qualified-id."
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ugyldig brug af '%E' til at danne en henvisning til medlemsfunktion; benyt et kaldenavn med klassepræfiks"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around '%E' cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "paranteser omkring '%E' kan ikke bruges til at danne en henvisning til medlemsfunktion"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ forbyder at tage adressen på en ikke-modificeret, ikke-statisk medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say `&%T::%D'"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ forbyder at tage adressen på en bundet medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking address of function `::main'"
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ forbyder at tage adressen på funktionen '::main'"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member `%D'"
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan ikke oprette henvisning til reference medlemmet '%D'"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field `%s'"
 msgid "attempt to take address of bit-field"
 msgstr "kan ikke finde adressen af bitfeltet '%s'"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of an immediate function %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, fuzzy, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "ISO C forbyder brug af typeomtvingningsudtryk som venstreværdier"
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of explicit register variable %qD requested"
 msgstr "forespørgsel efter adressen af registervariablen '%s'"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, fuzzy, gcc-internal-format
 #| msgid "address requested for `%D', which is declared `register'"
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse forespurgt for '%D' som er erklæret 'register'"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from `%T' to `%T' casts away const (or volatile)"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast fra '%T' til '%T' fjerner const (eller volatile)"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "skabelonsparameter '%T' benytter lokal type '%T'"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type `%T' to type `%T'"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ugyldig static_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qH to %qI"
 msgstr "konvertering fra '%T' til '%T'"
 
-#: cp/typeck.c:7956
+#: cp/typeck.c:7963
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "ugyldig reinterpret_cast af et højreværdiudtryk fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 #| msgid "reinterpret_cast from `%T' to `%T' loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "reinterpret_cast fra '%T' til '%T' mister præcision"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 #| msgid "cast from `%T' to `%T' increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "typeomtvingning fra '%T' til '%T' forøger den påkrævede justering af målets type"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ forbyder sammenligninger mellem henvisning til funktion og henvisning til objekt"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ugyldig brug af const_cast med typen '%T' som ikke er en henvisnings-, reference- eller en henvisning til datamedlem-type"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "ugyldig brug af const_cast med typen '%T' som er en henvisning eller reference til funktion"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type `%T' to type `%T'"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type `%T'"
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ forbyder omtvingelse af typen til en tabeltype '%T'"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "invalid cast to function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, fuzzy, gcc-internal-format
 #| msgid "  in evaluation of `%Q(%#T, %#T)'"
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i evaluering af '%Q(%#T, %#T)'"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "ugyldig tildeling af startværdi til tabel"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i henvisning til medlemsfunktion-omdannelse"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "henvisning til medlem-omdannelse via den virtuelle stamklasse '%T' af '%T'"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i henvisning til medlem-omdannelse"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "in passing argument %P of %qD"
 msgstr "i overbringelse af parameter %P af '%+D'"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerer reference til midlertidig variabel"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable `%D' returned"
 msgid "reference to local variable %qD returned"
 msgstr "reference til den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of label %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of local variable %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "too many 'l' suffixes in integer constant"
 msgid "redundant move in return statement"
 msgstr "for mange 'l'-endelser i heltalskonstant"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "kan ikke returnere fra en håndtering af en funktions-try-blok i en konstruktionsfunktion"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "manglende startværdi"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must not return NULL unless it is declared `throw()' (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "'operator new' må ikke returnere NULL medmindre den er erklæret 'throw()' (eller -fcheck-new er benyttet)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -64024,124 +64081,119 @@ msgstr "krøllede paranteser omkring skalarstartværdi"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD is uninitialized reference"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "no field `%D' in union being initialized"
 msgid "no field %qD found in union being initialized"
 msgstr "intet felt '%D' i union der tildeles startværdi"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indeksværdi i stedet for feltnavn i union-startværdi"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "fundet en henvisningsefterfølgelse der går i ring"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' has non-pointer type `%T'"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grundoperanden til '->' har en ikke-henvisningstype '%T'"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, fuzzy, gcc-internal-format
 #| msgid "result of `operator->()' yields non-pointer result"
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet af 'operator->()' er ikke en henvisning"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grundoperanden til '->' er ikke en henvisning"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a member pointer, since it is of type `%T'"
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "'%E' kan ikke bruges som en medlemshenvisning eftersom udtrykkets type er '%T'"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer `%E' to `%E', which is of non-aggregate type `%T'"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "kan ikke anvende medlemshenvisning '%E' på '%E' som er af den ikke-sammensatte type '%T'"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, fuzzy, gcc-internal-format
 #| msgid "member type `%T::' incompatible with object type `%T'"
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "medlemstypen '%T::' uforenelige med objekttypen '%T'"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "functional cast to array type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "skabelonsparameter er påkrævet for '%T'"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 #| msgid "default-initialization of `%#D', which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "standardklargøring af '%#D' som er af en referencetype"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, fuzzy, gcc-internal-format
 #| msgid "call to function `%D' which throws incomplete type `%#T'"
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "kald af en funktion '%D' som kaster en ufuldstændig type '%#T'"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, fuzzy, gcc-internal-format
 #| msgid "call to function which throws incomplete type `%#T'"
 msgid "call to function which throws incomplete type %q#T"
@@ -64162,295 +64214,301 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "variables cannot be of type void"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "cannot be declared to be a function"
 msgstr "new kan ikke bruges på en funktionstype"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of `struct %s'"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "omdefinering af 'struct %s'"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot be %s"
 msgstr "kan ikke åbne %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
 msgstr "kan ikke åbne %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, fuzzy, gcc-internal-format
 #| msgid "\"defined\" cannot be used as a macro name"
 msgid "field cannot be `scope`"
 msgstr "\"defined\" kan ikke bruges som makronavn"
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "asm not allowed in atomic transaction"
 msgid "field not allowed in interface"
 msgstr "asm er ikke tilladt i atomar transaktion"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "variable-size type declared outside of any function"
 msgid "inout variables can only be declared inside inout functions"
 msgstr "en type med en variabel størrelse er erklæret uden for en funktion"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer list construction invalid for `%D'"
 msgid "default construction is disabled for type %s"
 msgstr "klargøringslistekonstruktion er ugyldig for '%D'"
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "manifest constants must have initializers"
 msgstr "kun konstruktionsfunktioner har stamklasseklargøringer"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" is not a valid filename"
 msgid "size of type %s is invalid"
 msgstr "\"%s\" er ikke et ugyldigt filnavn"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 msgid "string expected for library name"
 msgstr "uventet operand"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, fuzzy, gcc-internal-format
 #| msgid "type name expected before `&'"
 msgid "function name expected for start address"
 msgstr "der forventedes et typenavn før '&'"
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type name expected before `&'"
 msgid "function name expected for start address, not `%s`"
 msgstr "der forventedes et typenavn før '&'"
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 #| msgid "expected function"
 msgid "string expected for mangled name"
 msgstr "forventet funktion"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 #, fuzzy
 #| msgid "Statement at %0 invalid in this context"
 msgid "char 0x%02x not allowed in mangled name"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 #, fuzzy
 #| msgid "Statement at %0 invalid in this context"
 msgid "char 0x%04x not allowed in mangled name"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "ingen parametre"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration `%D'"
 msgid "can only apply to a single declaration"
 msgstr "til skabelonserklæring '%D'"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%s'"
 msgid "pragma is missing closing `;`"
 msgstr "tabelstørrelsen mangler i '%s'"
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in binary expression"
 msgid "incomplete mixin declaration (%s)"
 msgstr "uforenelige typer i binæret udtryk"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "must have at least one catch per try block"
 msgid "enum %s must have at least one member"
 msgstr "skal have mindst én catch pr. try-blok"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "circular reference to enum member"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, fuzzy, gcc-internal-format
 #| msgid "%s: partial loss of precision"
 msgid "has inexact value, due to loss of precision"
 msgstr "%s: delvist tab af præcision"
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword `class' or `typename'"
 msgid "template tuple parameter must be last one"
 msgstr "skabelonstypeparametre skal begynde med 'class' eller 'typename'"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "rekursiv indbygning"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "rekursiv indbygning"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 msgid "error instantiating"
 msgstr "fejl ved skrivning til %s"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%s must be a function instead of %s"
 msgstr "-frepo skal bruges med -c"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "functions cannot be scope"
@@ -64459,45 +64517,55 @@ msgstr "funktion kan ikke indbygges"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "function cannot be inline"
 msgid "%s functions cannot be abstract"
 msgstr "funktion kan ikke indbygges"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot override a non-virtual function"
 msgstr "Advar om flertydige virtuelle funktionsnavne"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify both -C and -o"
 msgid "cannot be both final and abstract"
 msgstr "-C og -o er indbyrdes uforenelige"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -64505,191 +64573,191 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot disable built-in function `%s'"
 msgid "cannot override final function %s"
 msgstr "kan ikke deaktivere den indbyggede funktion '%s'"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "cannot set interrupt attribute: no current function"
 msgid "multiple overrides of same function"
 msgstr "kan ikke sætte afbrydelsesegenskaben: ingen aktuel funktion"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "incompatible covariant types %s and %s"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "does not override any function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "cannot override final function %s.%s"
 msgstr "for få parametre til funktionen '%s'"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "ugyldig brug af medlemmet '%D' i statisk medlemsfunktion"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "Advar om flertydige virtuelle funktionsnavne"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "left argument must be a slice"
 msgid "first argument must be type size_t, not %s"
 msgstr "venstre parameter skal være en skive"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "one argument of type void* expected, not %s"
 msgstr "%s-udtryk forventet ved %L"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "structs, unions cannot be abstract"
 msgstr "funktion kan ikke indbygges"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `static' invalid for function `%s' declared out of global scope"
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr "lagringsklassen 'static' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "base type must be class or interface, not %s"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "circular pointer delegation detected"
 msgid "circular inheritance"
 msgstr "fundet en henvisningsefterfølgelse der går i ring"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "base type must be interface, not %s"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "ignorerer mere end en angivelse af mappen »%s«\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot read LTO mode table from %s"
 msgid "cannot inherit from final class %s"
 msgstr "kan ikke læse LTO-tilstandstabel fra %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "  eftersom typen '%T' har abstrakte virtuelle funktioner"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, fuzzy, gcc-internal-format
 #| msgid "circular inheritance in interface declaration for `%s'"
 msgid "circular inheritance of interface"
 msgstr "cirkulær nedarvning i interface-erklæringen af '%s'"
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "non-template used as template"
 msgid "mixin templates are not regular templates"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot read %s"
 msgid "cannot resolve"
 msgstr "Kan ikke læse %s"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot take address of bit-field `%s'"
 msgid "cannot alias an expression %s"
@@ -64705,22 +64773,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "forming reference to void"
 msgid "has forward references"
@@ -64789,23 +64857,22 @@ msgstr "tildeling af startværdi er ugyldig for statisk medlem med konstruktions
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "en funktions returtype kan ikke være en funktion"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "naked assembly functions with contracts are not supported"
@@ -65371,7 +65438,7 @@ msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid suffix on integer constant"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -66510,12 +66577,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -66708,7 +66775,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -69315,7 +69382,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of `%T'"
@@ -69401,7 +69468,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -69540,12 +69607,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -69658,564 +69725,564 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "Invalid procedure argument at %L"
 msgstr "ugyldig typeparameter '%s'"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return specifier at %0 invalid within a function"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Alternativ returangivelse ved %0 er ugyldig inden i en funktion"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return specifier at %0 invalid within a function"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Alternativ returangivelse ved %0 er ugyldig inden i en funktion"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 #| msgid "Missing value at %1 for real-number exponent at %0"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Manglende værdi ved %1 for reel eksponent ved %0"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid option argument `%s'"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "ugyldig tilvalgsparameter '%s'"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "Unable to find symbol %qs"
 msgstr "kunne ikke finde klassen '%s'"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - too many interface type"
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "intern fejl - for mange grænsefladetyper"
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator number is out of bounds"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "akkumulatortal er uden for det gyldig interval"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "complex arguments must have identical types"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "komplekse parametre skal have identiske typer"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement or attribute at %1 cannot be specified along with SAVE statement or attribute at %0"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "SAVE-sætning eller -egenskab ved %1 kan ikke angives sammen med SAVE-sætning eller -egenskab ved %0"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -70368,36 +70435,36 @@ msgstr "tildeling af startværdi til new-udtryk med '='"
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conversion from NaN to int"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "konvertering fra NaN til int"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conversion from NaN to int"
 msgid "Conversion from %s to %s at %L"
@@ -70406,22 +70473,22 @@ msgstr "konvertering fra NaN til int"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -71003,7 +71070,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -72256,12 +72323,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -72426,156 +72493,156 @@ msgstr ""
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s for writing: %m"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "kan ikke åbne %s til skrivning: %m"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "%s: error writing file `%s': %s\n"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: fejl ved skrivning til filen '%s': %s\n"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Cannot delete module file %qs: %s"
 msgstr "%s: kan ikke slette filen '%s': %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "%s: warning: can't rename file `%s' to `%s': %s\n"
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "%s: advarsel: kan ikke omdøbe filen '%s' til '%s': %s\n"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file `%s': %s\n"
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "%s: kan ikke slette hjælpeinformationsfilen '%s': %s\n"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs at %C already declared"
 msgstr "Symboler har en indledende understreg"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs already declared"
 msgstr "Symboler har en indledende understreg"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "%s: kan ikke åbne filen '%s' til at læse fra: %s\n"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -73130,8 +73197,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -75223,7 +75290,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Label %d referenced at %L is never defined"
@@ -75345,7 +75412,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -75510,219 +75577,219 @@ msgstr "Returnér værdier fra funktioner i fpu-registre"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Advar når en inline funktion ikke kan indbygges"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Equality comparison for %s at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Inequality comparison for %s at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Argument dim at %L must be scalar"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array `%A' at %0 is too large to handle"
 msgid "Array index at %L is an array of rank %d"
 msgstr "Tabellen '%A' ved %0 er for stor til at håndtere"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring begin/end point at %0 out of defined range"
 msgid "Substring end index at %L must be scalar"
 msgstr "Understrengs begyndelses-/slutpunkt ved %0 er uden for det definerede interval"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "Substring end index at %L is too large"
 msgstr "angivet justering er for stor"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75731,12 +75798,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -75745,301 +75812,301 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is deprecated"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "'%s' er forældet"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Error in typebound call at %L"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" after # is not a positive integer"
 msgid "%s at %L must be integer"
 msgstr "\"%s\" efter # er ikke et positivt heltal"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -76048,291 +76115,291 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" cannot be used as a macro name as it is an operator in C++"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "\"%s\" kan ikke bruges som et makronavn da det er en operator i C++"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Selector at %L cannot be NULL()"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "Selector at %L has no type"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -76340,198 +76407,198 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "FORALL construct at %L"
 msgstr "I konstruktionen"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Pointer procedure assignment at %L"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid NULL at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' declared void"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "parameteren '%s' erklæret void"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -76539,981 +76606,981 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "String length at %L is too large"
 msgstr "Heltal ved %0 for stort"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fejl ved egenskabsundersøgelse af filen %s"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "funktion kan ikke indbygges"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object of type `%T' may not be initialized"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "'%#D' kan ikke erklæres"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "uforenelig afledt type i PARAMETER ved %L"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No specification for implied-DO iterator `%A' at %0"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Ingen angivelse af underforstået DO-iterator '%A' ved %0"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expecting definable entity near %L"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in method specification"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -78411,17 +78478,17 @@ msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -78515,115 +78582,115 @@ msgstr "tildeling af startværdi til new-udtryk med '='"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value of function %qs at %L not set"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared %s"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "instansvariablen '%s' er erklæret '%s'"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared %s"
 msgid "Unused variable %qs declared at %L"
 msgstr "instansvariablen '%s' er erklæret '%s'"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' declared void"
 msgid "Unused parameter %qs declared at %L"
 msgstr "parameteren '%s' erklæret void"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, fuzzy, gcc-internal-format
 #| msgid "unknown insn mode"
 msgid "Unknown intrinsic op"
 msgstr "ukendt instruktionstilstand"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument list function at %L"
 msgstr "for få parametre til funktionen '%s'"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -78780,7 +78847,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr ""
@@ -78913,7 +78980,7 @@ msgstr "-fwpa og -fltrans er indbyrdes uforenelige"
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
 #| msgid "-fwpa and -fltrans are mutually exclusive"
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-fwpa og -fltrans er indbyrdes uforenelige"
 
 #: lto/lto-object.c:107
@@ -80097,7 +80164,7 @@ msgstr "ukendt sektionsnavn \"%s\""
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "Tilvalg til kommatals opstartsværdi blev ikke genkendt: %qs"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized option `%s'"
 msgid "Unrecognized option: %qs"
@@ -80116,15 +80183,15 @@ msgstr "et makronavn mangler efter %s"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, fuzzy, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "et filnavn mangler efter '-%s'"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, fuzzy, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "et mål mangler efter '-%s'"
@@ -80179,7 +80246,7 @@ msgstr "Manglende navn"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "ukendt registernavn '%s'"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "ukendt registernavn '%s'"
@@ -80264,101 +80331,101 @@ msgstr "'%s' er forældet"
 msgid "unknown linker output %qs"
 msgstr "'%s': ukendt tls-model-tilvalg"
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown string token %s\n"
 msgid "unknown excess precision style %qs"
 msgstr "ukendt strengsymbol %s\n"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "unknown floating point contraction style %qs"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA algorithm %qs"
 msgstr "ukendt registernavn: %s"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "ukendt registernavn: %s"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown LTO partitioning model %qs"
 msgstr "ukendt maskintilstand '%s'"
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 #| msgid "target missing after %s"
 msgid "options or targets missing after %qs"
 msgstr "et mål mangler efter %s"
 
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "'%s': ukendt tls-model-tilvalg"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "'%s': ukendt tls-model-tilvalg"
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "'%s': ukendt tls-model-tilvalg"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown Live-Patching Level %qs"
 msgstr "ukendt maskintilstand '%s'"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "ukendt registernavn: %s"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "ukendt tls-model %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown vectorizer cost model %qs"
 msgstr "ukendt maskintilstand '%s'"
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "ikke genkendt synlighedsværdi %qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for `%s')"
 msgid "unknown vtable verify initialization priority %qs"
@@ -81029,11 +81096,6 @@ msgstr "ukendt tls-model %qs"
 #~ msgid "builtin function %qs not supported in this compiler configuration"
 #~ msgstr "%s understøttes ikke af denne konfiguration"
 
-#, fuzzy
-#~| msgid "constant argument out of range for `%s'"
-#~ msgid "constant argument %d for builtin %qF is out of range ("
-#~ msgstr "konstant parameter uden for det gyldige interval for '%s'"
-
 #~ msgid "bad value (%s) for -mcmodel= switch"
 #~ msgstr "ugyldig værdi (%s) til tilvalget -mcmodel="
 
@@ -81309,6 +81371,10 @@ msgstr "ukendt tls-model %qs"
 #~ msgid "narrowing conversion of %qE from %qH to %qI "
 #~ msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
+#, fuzzy
+#~ msgid "cannot deduce template arguments for %qT from ()"
+#~ msgstr "skabelonsparameter er påkrævet for '%T'"
+
 #, fuzzy
 #~| msgid "cannot take address of bit-field `%s'"
 #~ msgid "cannot take address of scope %s %s in @safe function %s"
@@ -82535,11 +82601,6 @@ msgstr "ukendt tls-model %qs"
 #~ msgid "using obsolete binding %qD"
 #~ msgstr "  bruger forældet binding til '%D'"
 
-#, fuzzy
-#~| msgid "Invalid expression statement"
-#~ msgid "lambda-expression in template-argument"
-#~ msgstr "Ugyldig udtrykssætning"
-
 #, fuzzy
 #~| msgid "Enable multiply instructions"
 #~ msgid "empty introduction-list"
diff --git a/gcc/po/de.po b/gcc/po/de.po
index c1821664521fd..fa7e842e10aab 100644
--- a/gcc/po/de.po
+++ b/gcc/po/de.po
@@ -8,10 +8,10 @@
 # Roland Illig <roland.illig@gmx.de>, 2015, 2017-2021.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 11.1-b20210321\n"
+"Project-Id-Version: gcc 11.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
-"PO-Revision-Date: 2021-04-03 16:17+0200\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
+"PO-Revision-Date: 2021-04-28 15:04+0200\n"
 "Last-Translator: Roland Illig <roland.illig@gmx.de>\n"
 "Language-Team: German <translation-team-de@lists.sourceforge.net>\n"
 "Language: de\n"
@@ -20,7 +20,7 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Poedit 2.4.2\n"
+"X-Generator: Poedit 2.4.3\n"
 "X-Poedit-Bookmarks: -1,-1,-1,6017,-1,-1,-1,-1,-1,-1\n"
 
 #: cfgrtl.c:2797
@@ -1279,11 +1279,11 @@ msgstr "    eingefügt von %qs"
 msgid "this is the insn:"
 msgstr "dies ist der Befehl:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "Neuladungen für unmögliche Einschränkungen konnten nicht generiert werden:"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "Neuladungen konnten nicht generiert werden für:"
 
@@ -1454,16 +1454,16 @@ msgstr "unerkennbarer Befehl:"
 msgid "insn does not satisfy its constraints:"
 msgstr "Befehl erfüllt nicht seine Bedingungen:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "erzeugt und mit anderen Einstellungen von »%s« verwendet"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "erzeugt und mit anderen Einstellungen von %<-fpic%> verwendet"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "erzeugt und mit anderen Einstellungen von %<-fpie%> verwendet"
 
@@ -1501,7 +1501,7 @@ msgstr "%s%sWarnung: %s-Header-Version %s unterscheidet sich von Bibliotheksvers
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC-Heuristik: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1945,83 +1945,83 @@ msgstr "Längenmodifizierer im strfmon-Format"
 msgid "<command-line>"
 msgstr "<Kommandozeile>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ungültiger Operand für »%%%c«"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, c-format
 msgid "invalid vector constant"
 msgstr "ungültige Vektorkonstante"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "unverträglicher Gleitkomma- / Vektorregisteroperand für »%%%c«"
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "unverträglicher Registeroperand für »%%%c«"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "fehlender Operand"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "ungültige Konstante"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "ungültiger Operand"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ungültiger Operandenpräfix »%%%c«"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, c-format
 msgid "invalid address mode"
 msgstr "ungültiger Adressierungsmodus"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ungültige Umwandlung von Typ %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ungültige Umwandlung in Typ %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "Operation nicht erlaubt auf Typ %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "GNU- und SVE-Vektoren können nicht in einer binären Operation kombiniert werden"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« ohne lokale dynamische TLS-Referenzen verwendet"
@@ -2037,18 +2037,18 @@ msgid "invalid %%r value"
 msgstr "ungültiger %%r-Wert"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "ungültiger %%R-Wert"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "ungültiger %%N-Wert"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "ungültiger %%P-Wert"
@@ -2078,7 +2078,7 @@ msgstr "ungültiger %%M-Wert"
 msgid "invalid %%U value"
 msgstr "ungültiger %%U-Wert"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "ungültiger %%s-Wert"
@@ -2088,7 +2088,7 @@ msgstr "ungültiger %%s-Wert"
 msgid "invalid %%C value"
 msgstr "ungültiger %%C-Wert"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "ungültiger %%E-Wert"
@@ -2101,7 +2101,7 @@ msgstr "unbekannte Adressverschiebungs-Unspec"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ungültiger %%xn-Code"
@@ -2183,35 +2183,35 @@ msgstr "ungültiges UNSPEC als Operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "unerkannte vermutete Konstante"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "ungültiger Schiebeoperand"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "bedingter Thumb-Befehl"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "bedingter Befehl in bedingter Sequenz"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2219,13 +2219,13 @@ msgstr "Operand für Code »%c« nicht unterstützt"
 msgid "invalid operand for code '%c'"
 msgstr "ungültiger Operand für Code »%c«"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "Befehl wird niemals ausgeführt"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "veralteter Maverick-Formatcode »%c«"
@@ -2347,8 +2347,8 @@ msgstr "nicht unterstützter Operand"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2711,7 +2711,7 @@ msgstr "ungültige Operation auf %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ungültiger %%P-Operand"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "ungültiger %%p-Wert"
@@ -2765,7 +2765,7 @@ msgid "post-increment address is not a register"
 msgstr "Post-Increment-Adresse ist kein Register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "Falsche Adresse"
 
@@ -2817,8 +2817,8 @@ msgstr "»%%%c« ist kein gültiger Operandenpräfix"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ungültige Verwendung von »%%%c«"
@@ -2954,286 +2954,286 @@ msgstr "Stapelspeicher aufgebraucht.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "»%s« in der Shell könnte diese Beschränkung erhöhen.\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "%<-mvsx%> benötigt Hardware-Gleitkommabefehle"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> benötigt indizierte Adressierung"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "%<-mvsx%> und %<-mno-altivec%> sind unverträglich"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "%<-mno-altivec%> schaltet vsx aus"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<-mquad-memory%> benötigt 64-Bit-Modus"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> benötigt 64-Bit-Modus"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> ist im Little-Endian-Modus nicht verfügbar"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr "ungültige Bewegung"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr "Falsche 128-Bit-Verschiebung"
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, c-format
 msgid "invalid %%A value"
 msgstr "ungültiger %%A-Wert"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "ungültiger %%D-Wert"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, c-format
 msgid "invalid %%e value"
 msgstr "ungültiger %%e-Wert"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "ungültiger %%f-Wert"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "ungültiger %%F-Wert"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "ungültiger %%G-Wert"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "ungültiger %%j-Code"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "ungültiger %%J-Code"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "ungültiger %%k-Wert"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "ungültiger %%K-Wert"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "ungültiger %%O-Wert"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "ungültiger %%q-Wert"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, c-format
 msgid "invalid %%t value"
 msgstr "ungültiger %%t-Wert"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "ungültiger %%T-Wert"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "ungültiger %%u-Wert"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "ungültiger %%v-Wert"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, c-format
 msgid "invalid %%V value"
 msgstr "ungültiger %%V-Wert"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "ungültiger %%x-Wert"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, c-format
 msgid "invalid %%z value"
 msgstr "ungültiger %%z-Wert"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ungültiger %%y-Wert, bitte »Z«-Bedingung probieren"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Unerlaubtes Mischen von IEEE-128-Bit- und IBM-128-Bit-Gleitkommatypen"
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 msgid "Could not generate addis value for fusion"
 msgstr "Addis-Wert für Fusion kann nicht erzeugt werden"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Lade-/Speicheroffset für Fusion kann nicht generiert werden"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr "Falsche GPR-Fusion"
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ungültige Umwandlung von Typ %<__vector_quad%>"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ungültige Umwandlung in Typ %<__vector_quad%>"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ungültige Umwandlung von %<__vector_pair%>"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ungültige Umwandlung in %<__vector_pair%>"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "ungültige Umwandlung von Typ %<* __vector_quad%>"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "ungültige Umwandlung in Typ %<* __vector_quad%>"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "ungültige Umwandlung von %<* __vector_pair%>"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "ungültige Umwandlung in %<* __vector_pair%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "symbolische Speicherreferenzen werden nur auf z10 oder neuer unterstützt"
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "Adresse kann nicht zerlegt werden"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ungültiger Vergleichsoperator für Ausgabemodifizierer »E«"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ungültige Referenz für Ausgabemodifizierer »J«"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »O«"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »R«"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "Speicherreferenz für Ausgabemodifizierer »S« erwartet"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »S«"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "Register oder Speicherausdruck für Ausgabemodifizierer »N« erwartet"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "Register oder Speicherausdruck für Ausgabemodifizierer »M« erwartet"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ungültige Konstante für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "Ungültige Konstante – anderen Ausgabemodifizierer probieren"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ungültiger konstanter Vektor für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ungültiger Ausdruck – anderen Ausgabemodifizierer probieren"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ungültiger Ausdruck für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 msgid "vector argument passed to unprototyped function"
 msgstr "Vektor-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr "Typen unterscheiden sich im Vorzeichenbesitz"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr "binärer Operator unterstützt keine zwei bool-Vektor-Operanden"
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr "Binärer Operator unterstützt Boolean-Vektor-Argument nicht"
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binärer Operator unterstützt nicht, dass bool-Vektor mit Gleitkommavektor vermischt wird"
 
@@ -3496,8 +3496,8 @@ msgstr "({anonym})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> erwartet"
@@ -3517,7 +3517,7 @@ msgstr "%<;%> erwartet"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> erwartet"
@@ -3525,7 +3525,7 @@ msgstr "%<)%> erwartet"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> erwartet"
@@ -3543,21 +3543,21 @@ msgstr "%<;%>, %<,%> oder %<)%> erwartet"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> erwartet"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> erwartet"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> erwartet"
@@ -3568,13 +3568,13 @@ msgstr "%<{%> erwartet"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> erwartet"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> erwartet"
@@ -3583,7 +3583,7 @@ msgstr "%<while%> erwartet"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> erwartet"
@@ -3592,18 +3592,18 @@ msgstr "%<,%> erwartet"
 msgid "expected %<.%>"
 msgstr "%<.%> erwartet"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> erwartet"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> erwartet"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> oder %<)%> erwartet"
@@ -3611,28 +3611,28 @@ msgstr "%<,%> oder %<)%> erwartet"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> erwartet"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> erwartet"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> oder %<}%> erwartet"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> erwartet"
@@ -3647,29 +3647,29 @@ msgstr "Sprungmarke erwartet"
 msgid "candidate:"
 msgstr "Kandidat:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 msgid "  after user-defined conversion:"
 msgstr "  nach benutzerdefinierter Umwandlung:"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "Kandidat ist:"
 msgstr[1] "Kandidaten sind:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "Kandidat 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "Kandidat 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "Sprung zur Marke %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "Sprung zur case-Marke"
 
@@ -3888,27 +3888,27 @@ msgstr "Parameter %qD darf in diesem Kontext nicht auftauchen"
 msgid "local variable %qD may not appear in this context"
 msgstr "lokale Variable %qD darf in diesem Kontext nicht auftauchen"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using enum%> ist nur mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 msgid "%<using enum%> of dependent type %qT"
 msgstr "%<using enum%> des abhängigen Typen %qT"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%<using enum%> an Nicht-Aufzählungstyp %q#T"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "%<using enum%> an unvollständigem Typ %qT"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr "%<using enum%> von %qT vor seinem enum-specifier"
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "Kandidaten sind:"
 
@@ -3952,48 +3952,48 @@ msgstr "Umformung verwirft Konstantheit"
 msgid "source type is not polymorphic"
 msgstr "Quellentyp ist nicht polymorph"
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "Argument falschen Typs für unäres Minus"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "Argument falschen Typs für unäres Plus"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "Argument falschen Typs für Bit-Komplement"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "Argument falschen Typs für abs"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "Argument falschen Typs für Konjugation"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr "in Argument für unäres !"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr "kein Präinkrementoperator für Typ"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr "kein Postinkrementoperator für Typ"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr "kein Prädekrementoperator für Typ"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr "kein Postdekrementoperator für Typ"
 
@@ -4101,7 +4101,7 @@ msgstr "Unstimmige Arraygrenzen für Dimension 2 des Arrays (%ld/%ld)"
 msgid "Driving:"
 msgstr "Angesteuert:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "effektives Argument für INTENT = OUT/INOUT"
 
@@ -4231,7 +4231,7 @@ msgstr "Falscher Operator"
 msgid "Bad type in constant expression"
 msgstr "Falscher Typ in Konstanten-Ausdruck"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "Unerwartetes Modulende"
 
@@ -4259,11 +4259,11 @@ msgstr "Block-IF"
 msgid "implied END DO"
 msgstr "impliziertes END DO"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "Zuweisung"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "Zeigerzuweisung"
 
@@ -4349,154 +4349,154 @@ msgstr "Resultat mit nicht konstanter Zeichenlänge"
 msgid "bind(c) procedure"
 msgstr "bind(c)-Prozedur"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %%L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operand des unären numerischen Operators %%<%s%%> bei %%L ist %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Unerwartete Entitäten mit abgeleitetem Typ im binären intrinsischen numerischen Operator %%<%s%%> bei %%L"
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des binären numerischen Operators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanden des Zeichenkettenverkettungsoperators bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des logischen Operators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand des Operators .not. bei %%L ist %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-Größen können nicht bei %L verglichen werden"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logische Werte bei %%L müssen mit %s statt mit %s verglichen werden"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des Vergleichsoperators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Unbekannter Operator %%<%s%%> bei %%L; meinten Sie »%s«?"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Unbekannter Operator %%<%s%%> bei %%L"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operand des Benutzeroperators %%<%s%%> bei %%L ist %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des Benutzeroperators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Ränge für Operator bei %%L und %%L stimmen nicht überein"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr "Schleifenvariable"
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr "Iteratorvariable"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr "Anfangs-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr "End-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr "Schrittausdruck in DO-Schleife"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE Objekt"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr "ALLOCATE Objekt"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr "STAT-Variable"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr "ERRMSG-Variable"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr "Element in READ"
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr "Variable ACQUIRED_LOCK"
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Unterschiedliche CHARACTER-Längen (%ld/%ld) in Feldkonstruktor"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Ganzzahlüberlauf bei der Berechnung des zu reservierenden Speichers"
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "Der Wert des Parameters PDT LEN »%s« stimmt nicht mit dem in der Dummy-Deklaration überein"
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Effektive Zeichenkettenlänge passt nicht zur deklarierten für Scheinargument »%s« (%ld/%ld)"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Effektive Zeichenkettenlänge ist kürzer als die deklarierte für Scheinargument »%s« (%ld/%ld)"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Ziel für neue Rangabbildung ist zu klein (%ld < %ld)"
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr "Zuweisung von Skalar zu unalloziertem Array"
 
@@ -4621,26 +4621,26 @@ msgstr "Feldreferenz außerhalb des Wertebereichs"
 msgid "Incorrect function return value"
 msgstr "Falscher Funktions-Rückgabewert"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, c-format
 msgid "Error allocating %lu bytes"
 msgstr "Fehler beim Reservieren von %lu Bytes"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "Versuch, bereits reservierte Variable »%s« zu reservieren"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr "Versuch, bereits reservierte Variable zu reservieren"
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "Versuch, nicht reserviertes »%s« freizugeben"
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr "Fehler beim Vergrößern des Speicherblocks auf %lu Bytes"
@@ -4835,15 +4835,15 @@ msgstr "»-Xbind-now« und »-Xbind-lazy« sind unverträglich"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr "evtl. »-pg« statt »-p« mit gprof(1) verwenden"
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "»-EB« und »-EL« dürfen nicht gleichzeitig verwendet werden"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "»-mfloat-abi=soft« und »-mfloat-abi=hard« dürfen nicht zusammen verwendet werden"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "»-mbig-endian« und »-mlittle-endian« dürfen nicht zusammen verwendet werden"
 
@@ -4859,8 +4859,8 @@ msgstr "kein Prozessortyp zum Binden angegeben"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "»-march=…« und »-mcpu=…« dürfen nicht zusammen angegeben werden"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared und mdll sind unverträglich"
 
@@ -5020,10 +5020,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Bei Erzeugung temporärer Felder warnen."
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
@@ -5498,160 +5498,160 @@ msgstr "Alle lokalen Felder über Stapel übergeben."
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "Standardzugriff von Modulentitäten auf PRIVATE setzen."
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "Versuchen, abgeleitete Typen so kompakt wie möglich anzuordnen."
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "Klammern in Ausdrücken schützen."
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr "Pfad zu Headerdatei, die vor jeder Übersetzungseinheit eingebunden wird."
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr "Bereichsprüfung während Kompilierung einschalten."
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr "Jeden REAL(4) als REAL(8) interpretieren."
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr "Jeden REAL(4) als REAL(10) interpretieren."
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr "Jeden REAL(4) als REAL(16) interpretieren."
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr "Jeden REAL(8) als REAL(4) interpretieren."
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr "Jeden REAL(8) als REAL(10) interpretieren."
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr "Jeden REAL(8) als REAL(16) interpretieren."
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr "LHS in Zuweisungen neu reservieren."
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Eine 4-Byte-Datensatzmarkierung für unformatierte Dateien verwenden."
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Eine 8-Byte-Datensatzmarkierung für unformatierte Dateien verwenden."
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr "Lokale Variablen auf Stapel anlegen, um indirekte Rekursion zu ermöglichen."
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "Feldabschnitte bei Prozedureintritt in einen zusammenhängenden Block kopieren."
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr "-fcoarray=<none|single|lib>\tAngeben, welche Koarray-Parallelisierung verwendet wird."
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr "-fcheck=[...]\tDurchgeführte Laufzeitprüfungen."
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "Einen zweiten Unterstrich anhängen, wenn der Name bereits einen Unterstrich enthält."
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr "Negatives Vorzeichen auf Null-Werte anwenden."
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr "Optimierung der Endrekursion verbieten, wenn die aufrufende Routine die Zeichenlänge weggelassen haben könnte."
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr "Unterstriche an extern sichtbare Namen anhängen."
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr "GNU Fortran Hilfsbibliothek (libgfortran) statisch binden."
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Mit dem Standard ISO Fortran 2003 übereinstimmen."
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Mit dem Standard ISO Fortran 2008 übereinstimmen."
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Mit dem Standard ISO Fortran 2008 inkl. TS 29113 übereinstimmen."
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Mit dem Standard ISO Fortran 2018 übereinstimmen."
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Mit dem Standard ISO Fortran 95 übereinstimmen."
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr "Mit nichts besonderem übereinstimmen."
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr "Erweiterungen akzeptieren, um alten Code zu unterstützen."
@@ -6330,8 +6330,8 @@ msgstr "Warnen bei Deallokationsaufrufen mit Argumenten, die von nicht übereins
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
-msgstr "Warnen bei Nichtübereinstimmung zwischen Aufrufen der Operatoren %<new%> oder %<delete%> und dem entsprechenden Aufruf der Allokations- oder Deallokationsfunktion."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
+msgstr "Warnen bei Nichtübereinstimmung zwischen Aufrufen der Operatoren »new« oder »delete« und dem entsprechenden Aufruf der Allokations- oder Deallokationsfunktion."
 
 #: c-family/c.opt:808
 #, no-c-format
@@ -6954,8 +6954,8 @@ msgstr "-faligned-new=<N>\tÜberausgerichtete Typallozierung aus C++17 für Type
 msgid "Allow variadic functions without named parameter."
 msgstr "Variadische Funktionen ohne benannte Parameter erlauben."
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr "Wird nicht mehr unterstützt."
@@ -7312,466 +7312,461 @@ msgstr "Standard-OpenACC-Berechnungsdimensionen angeben."
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr "-fopenacc-kernels=[decompose|parloops]\tModus, in dem OpenACC-»kernels«-Konstrukte verarbeitet werden."
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "OpenMP einschalten (bringt »-frecursive« in Fortran mit sich)."
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "SIMD-Direktiven von OpenMP einschalten."
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "C++-Schlüsselworte wie »compl« und »xor« erkennen."
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "PCH-Dateien suchen und verwenden, sogar bei Vorverarbeitung."
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr "Übereinstimmungsfehler zu Warnungen degradieren."
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr "Plan-9-Spracherweiterungen einschalten."
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr "Die Eingabedatei als bereits vorverarbeitet behandeln."
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr "-ftrack-macro-expansion=<0|1|2>\tOrte der aus der Makroersetzung entstehenden Token verfolgen und sie in Fehlermeldungen anzeigen."
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr "Template-Spezialisierungen für die Ausgabe nicht als Template-Signatur gefolgt von den Argumenten umformatieren."
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr "Bekannte sprintf-Rückgabewerte als Konstanten behandeln."
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "Im Fix-and-Continue-Modus verwendet, um anzuzeigen, dass Objektdateien zur Laufzeit eingetauscht werden können (»swap«)."
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "In GCC 10 entfernt. Dieser Schalter hat keine Auswirkung."
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr "Informationen zur Typbeschreibung zur Laufzeit erzeugen."
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "Den schmalstmöglichen Ganzzahltyp für Aufzählungstypen verwenden."
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "Den für »wchar_t« zugrundeliegenden Typen auf »unsigned short« zwingen."
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "Wenn weder »signed« noch »unsigned« angegeben wurden, das Bitfeld vorzeichenbehaftet machen."
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr "Macht »char« standardmäßig vorzeichenbehaftet."
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "Unterstützung für Deallozierung mit Größenangabe aus C++14 einschalten."
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr "-fsso-struct=[big-endian|little-endian|native]\tStandardspeicherreihenfolge für Skalare festlegen."
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr "Während der Übersetzung angesammelte Statistik anzeigen."
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "Annehmen, dass die Werte einer Aufzählung immer im kleinsten Bereich des Typs liegen."
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr "Die C++17-Anforderungen für die Auswertungsreihenfolge von Zuweisungsausdrücken, Bitverschiebungen, Elementfunktionsaufrufe, etc. befolgen."
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "Höchstzahl der Template-Instanziierungshinweise für einzelne Warnung oder Fehler festlegen."
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "-ftemplate-depth=<Zahl>\tGrößte Template-Instanziierungstiefe angeben."
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "-fno-threadsafe-statics\tKeinen threadsicheren Code für Initialisierung lokaler statischer Objekte erzeugen."
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "Wenn weder »signed« noch »unsigned« angegeben ist, das Bitfeld vorzeichenlos machen."
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "»char« standardmäßig vorzeichenlos machen."
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr "__cxa_atexit verwenden, um Destruktoren zu registrieren."
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "__cxa_get_exception_ptr in Ausnahmebehandlung verwenden."
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "Alle inline-Funktionen und -Methoden mit versteckter Sichtbarkeit markieren."
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "Sichtbarkeit wird geändert, um standardmäßig zu Microsoft Visual Studio zu passen."
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr "Common-ähnliche Symbole als schwache Symbole ausgeben."
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-fwide-exec-charset=<Zeichensatz>\tAlle Wide-Zeichenketten und -konstanten in Zeichensatz <Zeichensatz> umwandeln."
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "Eine auf das aktuelle Verzeichnis verweisende #line-Anweisung erzeugen."
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "Lockeres Nachschlagen von Klassen (mit objc_getClass()) für Verwendung im Null-Verknüpfungs-Modus erzeugen."
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr "Deklaration in .decl-Datei ausgeben."
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "-femit-struct-debug-baseonly\tAggressiv reduzierte Debuginfo für Strukturen."
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "-femit-struct-debug-reduced\tKonservativ reduzierte Debuginfo für Strukturen."
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "-femit-struct-debug-detailed=<spec-list>Ausführliche reduzierte Debuginfo für Strukturen."
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr "Imaginäre, Festkomma, oder andere GNU-Zahlenauffixe als das korrespondieren Zahlenliteral statt eines benutzerdefinierten Zahlenliterals interpretieren."
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <Verzeichnis>\t<Verzeichnis> an das Ende des System-Einfügepfades anfügen."
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "-imacros <Datei>\tDefinition von Makros in <Datei> akzeptieren."
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-imultilib <Verzeichnis>\t<Verzeichnis> als Multilib-include-Verzeichnis setzen."
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "-include <Datei>\tInhalt von <Datei> vor anderen Dateien einfügen."
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "-iprefix <Pfad>\t<Pfad> als ein Präfix für die nächsten zwei Optionen angeben."
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <Verzeichnis>\t<Verzeichnis> als System-Wurzelverzeichnis setzen."
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <Verzeichnis>\t<Verzeichnis> an den Anfang des System-Einfügepfades anfügen."
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-iquote <Verzeichnis>\t<Verzeichnis> am Ende des Einfügepfades für »#include \"…\"« anfügen."
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <Verzeichnis>\t<Verzeichnis> an das Ende des System-Einfügepfades anfügen."
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <Verz>\t<Verz> an das Ende des Haupt-Einfügepfades anfügen."
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "Standard-System-Einfügepfade nicht durchsuchen (die mit -isystem angegebenen werden trotzdem noch verwendet)."
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr "Standard-System-Einfügeverzeichnisse nicht für C++ durchsuchen."
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr "C-Header mit Plattform-spezifischen Merkmalen erzeugen."
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr "Dateinamen beim Einfügen von Dateien neu abbilden."
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Mit dem ISO-C++-Standard von 1998 (inclusive technischer Korrekturen von 2003) übereinstimmen."
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Mit dem ISO-C++-Standard von 2011 übereinstimmen."
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Veraltet zugunsten von -std=c++11."
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Veraltet zugunsten von -std=c++14."
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Mit dem ISO-C++-Standard von 2014 übereinstimmen."
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr "Veraltet zugunsten von -std=c++17."
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "Mit dem ISO-C++-Standard von 2017 übereinstimmen."
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Mit dem ISO-C++-Standard 2020 übereinstimmen (experimentelle und unvollständige Unterstützung)."
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Mit dem ISO-C++-Standardentwurf 2023 übereinstimmen (experimentelle und unvollständige Unterstützung)."
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Mit dem ISO-C-Standard von 2011 übereinstimmen."
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "Veraltet zugunsten von -std=c11."
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Mit dem ISO-C-Standard von 2017 (2018 veröffentlicht) übereinstimmen."
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Mit dem ISO-C-Standardentwurf 202X übereinstimmen (experimentelle und unvollständige Unterstützung)."
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Mit dem ISO-C-Standard von 1990 übereinstimmen."
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Mit dem ISO-C-Standard von 1999 übereinstimmen."
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr "Veraltet zugunsten von -std=c99."
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Mit dem ISO-C++-Standard von 1998 (inclusive technischer Korrekturen von 2003 sowie GNU-Erweiterungen) übereinstimmen."
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Mit dem ISO-C++-Standard von 2011 mit GNU-Erweiterungen übereinstimmen."
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Veraltet zugunsten von -std=gnu++11."
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Veraltet zugunsten von -std=gnu++14."
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Mit dem ISO-C++-Standard von 2014 mit GNU-Erweiterungen übereinstimmen."
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "Veraltet zugunsten von -std=gnu++17."
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "Mit dem ISO-C++-Standard von 2017 mit GNU-Erweiterungen übereinstimmen."
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Mit dem ISO-C++-Standard für 2020 mit GNU-Erweiterungen (experimentelle und unvollständige Unterstützung) übereinstimmen."
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Mit dem ISO-C++-Standardentwurf für 2023 mit GNU-Erweiterungen (experimentelle und unvollständige Unterstützung) übereinstimmen."
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Mit dem ISO-C-Standard von von 2011 mit GNU-Erweiterungen übereinstimmen."
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Veraltet zugunsten von -std=gnu11."
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Mit dem ISO-C-Standard von 2017 (veröffentlicht 2018) mit GNU-Erweiterungen übereinstimmen."
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Mit dem ISO-C-Standardentwurf für 202X mit GNU-Erweiterungen (experimentelle und unvollständige Unterstützung) übereinstimmen."
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Mit dem ISO-C-Standard von von 1990 mit GNU-Erweiterungen übereinstimmen."
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Mit dem ISO-C-Standard von von 1999 mit GNU-Erweiterungen übereinstimmen."
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Veraltet zugunsten von -std=gnu99."
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Mit dem ISO-C-Standard von 1990, wie 1994 ergänzt, übereinstimmen."
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Veraltet zugunsten von -std=iso9899:1999."
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr "-stdlib=[libstdc++|libc++]\tDie Standardbibliothek, die für C++-Header und Laufzeit verwendet wird."
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "Traditionelle Vorverarbeitung einschalten."
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\tTrigraphen nach ISO C unterstützen."
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr "Keine system- oder GCC-spezifischen Makros vordefinieren."
@@ -8016,6 +8011,11 @@ msgstr "Unittest-Code eincompilieren."
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr "-fversion=<Stufe|Ident>\tVersionscode >= <Stufe> oder durch <Ident> gekennzeichneten Code mitcompilieren."
 
+#: d/lang.opt:326
+#, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr "Template-Instanziierungen als schwache Symbole ausgeben."
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9253,143 +9253,155 @@ msgstr "Mehr als 8192 GOT-Einträge auf ColdFire unterstützen."
 msgid "Support TLS segment larger than 64K."
 msgstr "TLS-Segment größer als 64K unterstützen."
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr "Ziel-CPU als »big endian«-konfiguriert annehmen."
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr "Ziel-CPU als »little endian«-konfiguriert annehmen."
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "-mbranch-cost=N\tSprungkosten auf ungefähr N Befehle setzen."
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr "Bei Erzeugung von »-fpic«-Code den ausführbaren Dateien erlauben, PLTs zu verwenden. Ignoriert für »-fno-pic«."
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "Aufrufkonventionen für Ganzzahl und Gleitkomma angeben."
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Versuch, den Stapel an dieser Potenz von 2 auszurichten."
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "Unterstützte ABIs (für Verwendung mit Option »-mabi=«):"
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Hardware-Gleitkommabefehle für Division und Quadratwurzel verwenden."
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr "Hardwarebefehle für Ganzzahldivision verwenden."
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr "-march=\tCode für die angegebene RISC-V-ISA (z.B. RV64IM) erzeugen. ISA-Zeichenketten müssen in Kleinbuchstaben angegeben werden."
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=PROZESSOR\tAusgabe für PROZESSOR optimieren."
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "-mcpu=PROZESSOR\tArchitektur von PROZESSOR verwenden und die Ausgabe dafür optimieren."
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "-msmall-data-limit=N\tGlobale und statische Daten kleiner als <N> Bytes in einen gesonderten Abschnitt legen (bei manchen Zielarchitekturen)."
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "Kleineren, aber langsameren Code für Funktionsprologe und -epiloge verwenden."
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr "Adressen der Form BASE + LARGE_OFFSET in NEW_BASE + SMALL_OFFSET konvertieren, damit mehr Speicherzugriffe als komprimierte Anweisungen generiert werden können. Zielt derzeit auf 32-Bit-Integer-Laden/Speichern ab."
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr "Codemodell angeben."
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr "Keine unausgerichteten Speicherzugriffe erzeugen."
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr "Bekannte Codemodelle (für Verwendung mit Option -mcmodel=):"
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr "%reloc()-Operatoren statt Assemblermakros verwenden, um Adressen zu laden."
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr "Linker-Lockerungen ausnutzen, um die Anzahl der Befehle zu reduzieren, die für das Materialisieren von Symboladressen verwendet werden."
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr "ELF-Attribut für RISC-V generieren."
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr "Die angegebene Datenausrichtung verwenden."
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr "Bekannte Datenausrichtungen (für Verwendung mit Option -malign-data=):"
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr "Angegebenen Stapelschutz-Wächter verwenden."
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Gültige Argumente für -mstack-protector-guart=:"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Angegebenes Basisregister zur Adressierung des Stapelschutz-Wächters verwenden."
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Angegebenen Offset zur Addressierung des Stapelschutz-Wächters verwenden."
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "Unterstützte ISA-Spezifikationen (für Verwendung mit Option »-misa-spec=«):"
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr "Die Version der RISC-V-ISA-Spezifikation festlegen."
@@ -9524,12 +9536,6 @@ msgstr "Mögliche TLS-Dialekte:"
 msgid "The code model option names for -mcmodel:"
 msgstr "Codemodell-Optionsnamen für -mcmodel:"
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr "Ziel-CPU als »big endian«-konfiguriert annehmen."
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9550,12 +9556,6 @@ msgstr "Umgehung von Erratum 835769 für ARM-Cortex-A53."
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr "Umgehung von Erratum 843419 für ARM-Cortex-A53."
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr "Ziel-CPU als »little endian«-konfiguriert annehmen."
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -16773,2162 +16773,2162 @@ msgstr "-dumpbase-ext .<Erw>    Die Dateinamenserweiterung .<Erw> weglassen, bei
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <Verzeichnis>\tDen Basis-Verzeichnisnamen für Ausgaben setzen."
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr "Die Version der C++-ABI, die verwendet wird."
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr "Schleifen aggressiv optimieren, dabei sprachspezifische Einschränkungen einbeziehen."
 
-#: common.opt:978
+#: common.opt:982
 #, no-c-format
 msgid "Align the start of functions."
 msgstr "Funktionsanfänge ausrichten."
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr "Marken ausrichten, die nur mit Sprüngen erreicht werden können."
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr "Alle Marken ausrichten."
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr "Schleifenanfänge ausrichten."
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr "Dem Compiler erlauben, neue Datenwettläufe bei Speichervorgängen einzuführen."
 
-#: common.opt:1013
+#: common.opt:1017
 #, no-c-format
 msgid "Enable static analysis pass."
 msgstr "Durchgang für statische Analyse einschalten."
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr "Auswählen, was bereinigt werden soll."
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr "Art der Abdeckungs-Bereinigung auswählen."
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr "-fasan-shadow-offset=<Zahl>\tSpezifischen Offset für Schattenspeicher verwenden."
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr "-fsanitize-sections=<sec1,sec2,...>\tGlobale Variablen in benutzerdefinierten Abschnitten bereinigen."
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr "Nach dem Erkennen von undefiniertem Verhalten versuchen, die Ausführung fortzusetzen."
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Dieser Schalter ist veraltet; stattdessen -fsanitize-recover= verwenden."
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr "Für das Bereinigen von undefiniertem Verhalten eine Trap statt einer Bibliotheksfunktion verwenden."
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Abwicklungstabellen erzeugen, die genau an jeder Befehlsgrenze liegen."
 
-#: common.opt:1069
+#: common.opt:1073
 #, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "Auto-inc/dec-Befehle erzeugen."
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Profilierungsinformationen für Aufrufgraph-Knotengewichtungen verwenden. Vorgabe ist die Datei fbdata.afdo im aktuellen Arbeitsverzeichnis."
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Profilierungsinformationen für Aufrufgraph-Knotengewichtungen verwenden. Die Profilierungsdatei ist im Argument angegeben."
 
-#: common.opt:1087
+#: common.opt:1091
 #, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Code zur Überprüfung der Grenzen vor Arrayindizierung erzeugen."
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Addieren, Vergleichen, Verzweigen mit Verzweigung anhand des Zählregisters ersetzen."
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr "Profilierungsinformationen für Verzweigungswahrscheinlichkeiten verwenden."
 
-#: common.opt:1111
+#: common.opt:1115
 #, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr "Information über Aufrufgraphen auf Dateibasis ausgeben."
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "Information über Aufrufgraphen auf Dateibasis mit Dekoration ausgeben."
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<Register>\t<Register> als über Funktionsgrenzen hinweg reserviert markieren."
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<Register>\t<Register> als durch Funktionsaufrufe beschädigt markieren."
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr "Register bei Funktionsaufrufen sichern."
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "Dieser Schalter ist veraltet; nicht verwenden."
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "Rückgabewert des C++-Operators new prüfen."
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr "Interne Konsistenzprüfungen durchführen."
 
-#: common.opt:1150
+#: common.opt:1154
 #, no-c-format
 msgid "Enable code hoisting."
 msgstr "Codeanhebung einschalten."
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Sucht Möglichkeiten, Stapel-Anpassungen und Stapel-Referenzen zu reduzieren."
 
-#: common.opt:1158
+#: common.opt:1162
 #, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr "Uninitialisierte globale Symbole in gemeinsamen Abschnitt legen."
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<Optionen>]\tMit und ohne z.B. -gtoggle kompilieren, und den Dump der »final-insns« vergleichen."
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "Nur die zweite Kompilierung von -fcompare-debug laufen lassen."
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Beseitigung von Vergleichen nach Registerreservierung durchführen."
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "Keine Optimierungen durchführen, die die Stapelverwendung deutlich erhöhen."
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Optimierungsdurchlauf zur Kopierübertragung von Registern durchführen."
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr "Optimierung zum Kreuzsprung durchführen."
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Beim Durchlaufen von CSE: Sprüngen zu ihren Zielen folgen."
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr "Schritt zur Bereichsverkleinerung auslassen, wenn komplexe Division durchgeführt wird."
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Komplexe Multiplikation und Division befolgen Fortran-Regeln."
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr "Datenstücke in ihren eigenen Abschnitt legen."
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Alle verfügbaren Fehleranalysezähler mit ihren Grenzen und Werten auflisten."
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<Zähler>[:<Untere Grenze 1>-]<Obere Grenze 1>[:<Untere Grenze 2>-<Obere Grenze 2>:...][,<Zähler>:...]\tObergrenze für Debug-Zähler festlegen."
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr "-fdebug-prefix-map=<alt>=<neu>\tIn Fehlersuchinfo einen Verzeichnisnamen auf einen anderen abbilden."
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr "-ffile-prefix-map=<alt>=<neu>\tIn Übersetzungsergebnis einen Verzeichnisnamen auf einen anderen abbilden."
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ".debug_types-Abschnitt ausgeben, wenn DWARF v4-Debuginfo verwendet wird."
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr "Zurückholen der Funktionsargumente vom Stapel bis auf weiteres hinauszögern."
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Versuchen, die Verzögerungsschlitze der Sprungbefehle auszufüllen."
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr "Unerreichbare Befehle löschen, die Ausnahmen werfen können."
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr "Unnötige Nullzeigerprüfungen löschen."
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr "Zusätzliche Daten verarbeiten, um in LTO-lokalem Umwandlungsmodus aggressiver zu devirtualisieren."
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr "Spekulative Devirtualisierung durchführen."
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Versuchen, virtuelle Sprünge in direkte umzuwandeln."
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\tWie oft die Quelltext-Position am Zeilenanfang ausgegeben wird, wenn die Diagnose über mehrere Zeilen geht."
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr "Quellzeile mit Einschaltungszeichen anzeigen, um die Spalte zu kennzeichnen."
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr "Beim Anzeigen von Quellcode Marker verwenden, um Bereiche des Quellcodes zu markieren."
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr "Beim Anzeigen von Quellcode Zeilennummern im linken Rand anzeigen."
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tDiagnosemeldungen einfärben."
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr "-fdiagnostics-urls=[never|always|auto]\tURLs in Diagnosemeldungen einbetten."
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr "-fdiagnostics-column-unit=[display|byte]\tFestlegen, ob Spaltennummern als Anzeigespalten (Standard) ausgegeben werden oder in rohen Bytes gemessen werden."
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr "-fdiagnostics-column-origin=<Nummer>\tLegt die Nummer der ersten Spalte fest. Die Vorgabe ist gemäß GNU-Stil 1-basiert, aber einige Dienstprogramme erwarten 0-basierte Spaltennummern."
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr "-fdiagnostics-format=[text|json]\tAusgabeformat auswählen."
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr "Behebungshinweise in maschinenlesbarer Form ausgeben."
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr "Behebungshinweise in vereinheitlichtem Diff-Format auf stderr ausgeben."
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Die geeignete Diagnosemeldung mit der Kommandozeilenoption anreichern, die sie steuert."
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr "CWE-Identifikatoren für Diagnosemeldungen ausgeben, sofern verfügbar."
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr "Angeben, wie jeder Kontrollflusspfad, der mit einer Diagnose verbunden ist, ausgegeben werden soll."
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr "Alle Diagnosefunktionen deaktivieren, die die Ausgabe verkomplizieren, wie Zeilennummern, Farbe und Warn-URLs."
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "-ftabstop=<Zahl>        Abstand zwischen Tabstopps für Spaltenmeldungen."
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr "Stapeltiefe der Ereignisse in Pfaden anzeigen."
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr "Mindestbreite des linken Randes des Quellcodes angeben, für das Ausgeben des Quellcodes."
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<Durchgang>=range1+range2\tEinen Optimierungsdurchgang ausschalten."
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<Durchgang>=range1+range2\tEinen Optimierungsdurchgang einschalten."
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\tVerschiedene compilerinterne Informationen in eine Datei abziehen."
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=<Datei>\tDie Befehle am Ende der Übersetzung in Datei abziehen."
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=<Datei>\tAlle Deklarationen als Go-Code in <Datei> schreiben."
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Ausgabe von Adressen in Fehlersuch-Auszügen unterdrücken."
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr "Im Falle eines internen Fehlers im C/C++-Compiler die Debuginformationen sammeln und in temporäre Datei ausgeben."
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr "Detaillierte Informationen über die GCC-interne Repräsentation von Quellcode-Stellen ausgeben."
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr "Optimierungsdurchläufe ausgeben."
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Ausgabe von Befehlszahlen, Zeilennummernangaben und Adressen in Fehlersuch-Auszügen unterdrücken."
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Ausgabe der vorigen und nächsten Befehlsnummern in Fehlersuch-Auszügen unterdrücken."
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "CFI-Tabellen über GAS-Assembler-Direktiven einschalten."
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr "Frühes Inlining durchführen."
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Zwischenprozedurale Reduktion von Aggregaten durchführen."
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Ungenutzte Symbole aus Info zur Fehlersuche entfernen."
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr "Ungenutzte Typen aus Info zur Fehlersuche entfernen."
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "Keine Fehlersuchinformationen für C++-Klassen unterdrücken."
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr "Ausnahmebehandlung einschalten."
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Eine Reihe kleiner, aber teurer, Optimierungen durchführen."
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tBehandlung überschüssiger Gleitkommagenauigkeit bestimmen."
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tAngeben, welche Werte von FLT_EVAL_METHOD erlaubt sind."
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "LTO-Objekte ausgeben, die sowohl Zwischensprache als auch Binärausgabe enthalten."
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Annehmen, dass keine NaNs oder Unendlichkeiten erzeugt werden."
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr "Annehmen, dass Schleifen mit einem Ausgang keine Endlosschleifen sind."
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<Register>\t<Register> als für den Compiler nicht verfügbar markieren."
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Keine floats und doubles in Registern erweiterter Genauigkeit reservieren."
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Schritt zur Vorwärts-Übertragung auf RTL durchführen."
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast]\tSchrumpfung von Gleitkommaausdrücken durchführen."
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr "Den eingebauten Funktionen ceil, floor, round, trunc erlauben, »inexact«-Exceptions zu werfen."
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr "Vorhalten von Funktionsadressen in Registern erlauben."
 
-#: common.opt:1586
+#: common.opt:1590
 #, no-c-format
 msgid "Place each function into its own section."
 msgstr "Jede Funktion in ihren eigenen Abschnitt platzieren."
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr "Beseitigung globaler gemeinsamer Teilausdrücke durchführen."
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Erweiterte Ladebewegung während Beseitigung globaler gemeinsamer Teilausdrücke durchführen."
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Speicherbewegung nach Beseitigung globaler gemeinsamer Teilausdrücke durchführen."
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Beseitigung überflüssigen Ladens nach dem Abspeichern in globalem gemeinsamem Teilausdruck durchführen."
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Beseitigung globaler gemeinsamer Teilausdrücke nach Registerreservierung durchführen."
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr "-fgnat-encodings=[all|gdb|minimal]\tGleichgewicht zwischen GNAT-Encodings und Standard-DWARF auswählen, die in den Debuginformationen landen."
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr "Ein- und Ausgabe der Graphite-Repräsentierung einschalten."
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr "Transformation der Graphite-Identität einschalten."
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Herausziehen aufeinanderfolgender Ladeoperationen einschalten, um Erzeugung bedingter Kopieroperationen zu fördern."
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr "Verbesserung der Fähigkeit des GCC, Spaltennummern in großen Quelldateien zu verfolgen, auf Kosten einer langsameren Kompilierung."
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr "Alle Schleifen als parallel markieren."
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "Schleifenschachtelungs-Umwandlungen einschalten. Entspricht -floop-next-optimize."
 
-#: common.opt:1659
+#: common.opt:1663
 #, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr "Umordnen der Schleifen auf Bäumen einschalten."
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr "Schleifenabwicklung (unroll-and-jam) für Schleifen durchführen."
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr "Unterstützung für GNU-Transaktionsspeicher einschalten."
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "STB_GNU_UNIQUE verwenden, sofern der Assembler es unterstützt."
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr "Optimierer für geschachtelte Schleifen einschalten."
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr "Bitfeld-Zugriffe zwingen, zu ihrer Typbreite zu passen."
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr "Nebeneinanderliegende Speicheroperationen zusammenfassen."
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr "Erraten der Sprungwahrscheinlichkeiten einschalten."
 
-#: common.opt:1703
+#: common.opt:1707
 #, no-c-format
 msgid "Process #ident directives."
 msgstr "#ident-Direktiven verarbeiten."
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Umwandlung bedingter Sprünge in zweiglose Äquivalente durchführen."
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Umwandlung bedingter Sprünge in bedingte Ausführung durchführen."
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none]\tStufe der Stapel-Wiederverwendung für lokale Variablen festlegen."
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Umwandlung bedingter Sprünge in innersten Schleifen in zweiglose Äquivalente durchführen."
 
-#: common.opt:1743
+#: common.opt:1747
 #, no-c-format
 msgid "Do not generate .size directives."
 msgstr "Keine .size-Direktiven erzeugen."
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr "Indirektes Inlining durchführen."
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "Einschalten des Inlining von »inline«-Funktionen, ansonsten wird jegliches Inlining ausgeschaltet."
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Funktionen in ihre Aufrufer einfügen, wenn Codegröße als nicht wachsend bekannt ist."
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Nicht als »inline« deklarierte Funktionen in ihre Aufrufer einfügen, wenn gewinnbringend."
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "Nur an einer Stelle aufgerufene Funktionen in ihre Aufrufer einfügen."
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<Zahl>\tGröße von »inline«-Funktionen auf <Zahl> beschränken."
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "__atomic-Operationen »inline« erzeugen, wenn Lock-freie Befehlssequenz verfügbar ist."
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr "-fcf-protection=[full|branch|return|none|check]\tFunktionen mit zusätzlichen Prüfungen versehen, dass die Sprungziele von jump/call/return gültig sind."
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Ein- und Austritte von Funktionen beim Profilieren von Aufrufen verwenden."
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=name,…\tAufgezählte Funktionen nicht instrumentieren."
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=filename,…\tIn den Dateien aufgezählte Funktionen nicht instrumentieren."
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr "Zwischenprozedurale Konstantenweitergabe durchführen."
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Kopien erzeugen, um zwischenprozedurale Konstantenweitergabe zu verstärken."
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Zwischenprozedurale bitweise Konstantenweitergabe durchführen."
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr "Prozedurübergreifende modref-Analyse durchführen."
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr "Zwischenprozedurale Profilweitergabe durchführen."
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr "Zwischenprozedurale Zeigt-auf-Analyse durchführen."
 
-#: common.opt:1846
+#: common.opt:1850
 #, no-c-format
 msgid "Discover pure and const functions."
 msgstr "Reine und konstante Funktionen entdecken."
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Identischen Code für Funktionen und schreibgeschützte Variablen zusammenfassen."
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr "Identischen Code für Funktionen zusammenfassen."
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr "Identischen Code für Variablen zusammenfassen."
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr "Nur-lese und nicht-adressierbare statische Variablen entdecken."
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "Nur-lese-, nur-schreib- und nicht-adressierbare statische Variablen entdecken."
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr "Stapelausrichtung im Aufrufer reduzieren, wenn möglich."
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr "Informationen über IPA-Wertebereiche weitergeben."
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority]\tVerwendeten IRA-Algorithmus festlegen."
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed]\tRegionen für IRA festlegen."
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "IRA-basierte Registerdruckberechnungen in RTL-Optimierungen zum Anheben verwenden."
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "IRA-basierte Registerdruckberechnungen in RTL-Schleifenoptimierungen verwenden."
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr "Schlitze gemeinsam verwenden, um verschiedene harte Register zu sichern."
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Stapel-Schlitze für übergelaufene Pseudo-Register gemeinsam verwenden."
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<Zahl<\tStufe der IRA Diagnosemeldungen steuern."
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr "Induktionsvariablen auf Bäumen optimieren."
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Sprungtabellen für hinreichend große switch-Anweisungen verwenden."
 
-#: common.opt:1945
+#: common.opt:1949
 #, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "Bittests für hinreichend große switch-Anweisungen verwenden."
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Code für Funktionen erzeugen, auch wenn sie vollständig »inline« sind."
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "Code für static-Funktionen erzeugen, auch wenn sie nie aufgerufen werden."
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr "static-const-Variablen erzeugen, auch wenn sie nicht verwendet werden."
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr "Externen Symbolen einen führenden Unterstrich geben."
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr "In LRA die ablaufsensitive Rematerialisierung durchführen."
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr "Optimierungen zur Bindezeit einschalten."
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Optimierungen zur Bindezeit mit Anzahl paralleler Jobs oder Jobserver."
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr "Algorithmus, mit dem Symbole und Variablen zur Linkzeit partitioniert werden."
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr "-flto-compression-level=<Stufe>\tzlib/zstd-Kompressionsstufe <Stufe> für IL verwenden."
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "Verschiedene Statistiken über Linkzeit-Optimierung ausgeben."
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Nur in WPA verschiedene Statistiken über Linkzeit-Optimierung ausgeben."
 
-#: common.opt:2020
+#: common.opt:2024
 #, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "Nach eingebauten Mathematikfunktionen errno setzen."
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<Anzahl>\tHöchstzahl der zu meldenden Fehler."
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr "Über dauerhafte Speicherreservierung berichten."
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Nur in WPA über dauerhafte Speicherreservierung berichten."
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Versuchen, identische Konstanten und konstante Variablen zu verschmelzen."
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Versuchen, identische Konstanten über Übersetzungseinheiten hinweg zu verschmelzen."
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Versuchen, identische Zeichenketten zur Fehlersuche über Übersetzungseinheiten hinweg zu verschmelzen."
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<Anzahl>\tDiagnosemeldungen auf <Anzahl> Zeichen pro Zeile beschränken. 0 unterdrückt Zeilenumbruch."
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "SMS-basierte modulo-Planung vor erstem Planungsdurchlauf durchführen."
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "SMS-basierte modulo-Planung mit erlaubten Register-Verschiebungen durchführen."
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr "Berechnung der Schleifeninvarianten außerhalb der Schleifen legen."
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr "Den RTL-Durchlauf zur Entfernung toten Codes verwenden."
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "Den RTL-Durchlauf zur Entfernung toter Speicherungen verwenden."
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Traditionelle Planung in Schleifen, die bereits Modulo-Planung unterzogen wurden, einschalten/ausschalten."
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr "Synchrone Nicht-Aufruf-Ausnahmen unterstützen."
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr "-foffload=<Ziele>=<Optionen>\tOffloading-Ziele und deren Optionen angeben."
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr "-foffload-abi=[lp64|ilp32]\tFestlegen, welche ABI in einem Offload-Compiler verwendet wird."
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr "Wenn möglich, keine Stapelrahmen erzeugen."
 
-#: common.opt:2104
+#: common.opt:2108
 #, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Alle Informationen über Optimierungen auf stderr einschalten."
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<Typ>=Dateiname]\tOptimierungsdetails des Compilers ausgeben."
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr "Eine QUELLDATEI.opt-record.json schreiben mit Details, welche Optimierungen durchgeführt wurden."
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Geschwister- und endrekursive Aufrufe optimieren."
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr "Teilweises Inlining durchführen."
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Über Speicherbelegung vor zwischenprozeduraler Optimierung berichten."
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr "Strukturelemente ohne Lücken zusammenpacken."
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<Zahl>\tAnfängliche größte Ausrichtung für Strukturelemente festlegen."
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr "Kleine Aggregate über Speicher, nicht Register, zurückgeben."
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr "Schleifen-Schälung durchführen."
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr "Maschinenspezifische Guckloch-Optimierungen einschalten."
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Einen RTL-Guckloch-Durchlauf vor sched2 einschalten."
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Wenn möglich, lageunabhängigen Code erzeugen (large mode)."
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Wenn möglich, lageunabhängigen Code für ausführbare Dateien erzeugen (large mode)."
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Wenn möglich, positionsunabhängigen Code erzeugen (small mode)."
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Wenn möglich, positionsunabhängigen Code für ausführbare Dateien erzeugen (small mode)."
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr "PLT für PIC-Aufrufe verwenden (-fno-plt: die Adresse beim Aufrufer aus der GOT laden)."
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr "Zu ladendes Plugin angeben."
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<Name>-<Schlüssel>[=<Wert>]\tArgument <Schlüssel>=<Wert> für Plugin <Name> angeben."
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr "Vorhersehende vereinheitlichende Optimierung durchlaufen."
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Wenn verfügbar, Prefetch-Befehle für Arrays in Schleifen erzeugen."
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr "Einfachen Programm-Profilierungscode einschalten."
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr "Absolute Quellpfade für gcov erzeugen."
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr "Arc-basierten Programm-Profilierungscode einfügen."
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Basisverzeichnis zum Speichern der Profildaten setzen. Vorgabe ist das aktuelle Verzeichnis."
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr "Name zum Speichern der Profilingnotizen festlegen."
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Korrektur fluss-unstimmiger Profildateneingabe einschalten."
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tMethode für Profilupdates festlegen."
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr "Funktionen nur aus Dateien instrumentieren, deren Namen zu einem der regulären Ausdrücke passen (durch Semikolon getrennt)."
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr "Funktionen nur aus Dateien instrumentieren, deren Namen zu keinem der regulären Ausdrücke passen (durch Semikolon getrennt)."
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tStufe für die Reproduzierbarkeit des mit »-fprofile-generate« generierten Profils festlegen."
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr "Präfix von absolutem Pfad abschneiden, bevor dieser Name für »-fprofile-generate=« und »-fprofile-use=« gemangelt wird."
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Allgemeine Optionen zum Erzeugen von Profil-Info für Profil-Feedback-gerichtete Optimierungen einschalten."
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Allgemeine Optionen zum Erzeugen von Profil-Info für Profil-Feedback-gerichtete Optimierungen einschalten, und -fprofile-dir= setzen."
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr "Profilinformation im Abschnitt .gcov_info registrieren, statt einen Konstruktor/Destruktor zu verwenden."
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr "Profilinformation im angegebenen Abschnitt registrieren, statt einen Konstruktor/Destruktor zu verwenden."
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr "Nicht annehmen, dass Funktionen, die im Trainingslauf nie ausgeführt wurden, kalt sind."
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Allgemeine Optionen zum Durchführen von Profil-Feedback-gerichteten Optimierungen einschalten."
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Allgemeine Optionen zum Durchführen von Profil-Feedback-gerichteten Optimierungen einschalten, und -fprofile-dir= setzen."
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr "Code einfügen, um Ausdrücke zu profilen."
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr "Über Konsistenz des Profils berichten."
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr "Funktionen umsortieren, um Codeplatzierung zu verbessern."
 
-#: common.opt:2305
+#: common.opt:2309
 #, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr "In jedem Funktionsprolog NOP-Befehle erzeugen."
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<Zeichenkette>\tÜbersetzung mit <Zeichenkette> reproduzierbar machen."
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr "GCC-Kommandozeilenschalter in Objektdateien aufzeichnen."
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr "Kleine Aggregate über Register zurückgeben."
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr "DSE mitteilen, dass der Speicher für ein C++-Objekt tot ist, wenn der Konstruktor anfängt und wenn der Destruktor aufhört."
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr "-flive-patching=[inline-only-static|inline-clone]\tFunktionsübergreifende Optimierung steuern, um für Live-Patching geeigneten Code zu erzeugen. Bietet gleichzeitig mehrstufige Kontrolle bezüglich der ausgewählten funktionsübergreifenden Optimierungen."
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr "DCE mitteilen, dass ungenutzte C++-Allokationen entfernt werden."
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Entlastung des Registerdrucks durch Live-Bereichs-Schrumpfung."
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr "Einen Optimierungsdurchgang zur Registerumbenennung durchführen."
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Einen zielabhängigen Optimierungsdurchgang zur Befehlsfusion durchführen."
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Basisblöcke umsortieren, um Codeplatzierung zu verbessern."
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr "-freorder-blocks-algorithm=[simple|stc]\tAlgorithmus zum Umordnen der Basisblöcke festlegen."
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Basisblöcke und in heiße und kalte Abschnitte umordnen und partitionieren."
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr "Funktionen umsortieren, um Codeplatzierung zu verbessern."
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Einen Durchlauf zur Entfernung von Teilausdrücken nach Schleifenoptimierungen hinzufügen."
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Optimierungen, die Standard-Rundungsverhalten für Gleitkomma annehmen, ausschalten."
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr "Planung über Basisblöcke hinaus einschalten."
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Registerdruckempfindliche Befehlsplanung einschalten."
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr "Spekulative Bewegung von Nicht-Lade-Befehlen erlauben."
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr "Spekulative Bewegung bei einigen Ladebefehlen erlauben."
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr "Spekulative Bewegung bei mehr Ladebefehlen erlauben."
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<Stufe>\tStufe der Wortfülle des Planers angeben."
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Wenn Planung nach dem Neuladen, dann Superblock-Planung."
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr "Befehle vor Registerbelegung neu planen."
 
-#: common.opt:2449
+#: common.opt:2453
 #, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr "Befehle nach Registerbelegung neu planen."
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Befehle mit selektivem Planungs-Algorithmus einplanen."
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr "Ausgewählte Planung nach Neuladen durchführen."
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr "Selbsttests durchführen, mit dem angegebenen Pfad, um die Testdateien zu finden."
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Während selektiver Planung Software-Pipelining innerer Schleifen durchführen."
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Während selektiver Planung Software-Pipelining äußerer Schleifen durchführen."
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Regionen mit Pipelining ohne Pipelining neu planen."
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr "Erlauben, dass der dynamische Linker Funktionen und Variablen mit solchen unterschiedlicher Semantik (oder Initialisierungen) gemischt platzieren darf."
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr "Nicht ausgereifte Planung von eingereihten Befehlen erlauben."
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<Anzahl>\tAnzahl der eingereihten Befehle festlegen, die unausgereift geplant werden können."
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Prüfung der Abhängigkeitsentfernung in nicht ausgereifter Planung von eingereihten Befehlen festlegen."
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<Zahl>\tAbhängigkeitsentfernung für Prüfung in nicht ausgereifter Planung von eingereihten Befehlen festlegen."
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Gruppenheuristik im Planer einschalten."
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Critical-Path-Heuristik im Planer einschalten."
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Heuristik für spekulative Befehle im Planer einschalten."
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Rang-Heuristik im Planer einschalten."
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Heuristik für letzte Befehle im Planer einschalten."
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Heuristik für Abhängigkeits-Zähler bei Planung einschalten."
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr "Auf Daten im gleichen Abschnitt von gemeinsam verwendeten Ankerpunkten zugreifen."
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Durchlauf für Redundante Erweiterungsentfernung (REE) einschalten."
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Spaltenzahlen in Diagnose zeigen, wenn verfügbar. Standard: Ein."
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Funktionsprologe nur vor Teilen der Funktion erzeugen, die diese benötigt, statt am Anfang der Funktion."
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "Teile des Prologs und Epilogs separat an den nötigen Stellen erzeugen."
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Von IEEE-Signalisierungs-NaNs wahrnehmbare Optimierungen ausschalten."
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Gleitkommaoptimierungen ausschalten, die die IEEE-Vorzeichenbehaftung von Null nicht beachten."
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr "Gleitkommakonstanten in Konstanten einfacher Genauigkeit umwandeln."
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Lebensdauer von Induktionsvariablen aufteilen, wenn Schleifen abgerollt werden."
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "Nicht zusammenhängende Stapelrahmen erzeugen."
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr "Breite Typen in unabhängige Register aufteilen."
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr "Breite Typen bereits früher in unabhängige Register aufteilen."
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Rückwärtsübermittlung von Nutzungseigenschaften auf SSA-Ebene einschalten."
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr "Bedingte Ausdrücke mittels SSA-PHI-Knoten optimieren."
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Anzahl der stdarg-Register optimieren, die am Anfang einer Funktion auf dem Stapel gespeichert werden."
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Variablenerweiterung anwenden, wenn Schleifen abgerollt werden."
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tCode zur Stapelprüfung in das Programm einfügen."
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Code zur Stapelprüfung in das Programm einfügen. Dasselbe wie -fstack-check=specific."
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr "Code einfügen, der jede Speicherseite des Stapels bei der Allokation antestet, um vor Angriffen basierend auf Überschneidungen zu schützen."
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<Register>\tWenn der Stapel über <Register> hinausgeht, abfangen (»trap«)."
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<Name>\tWenn der Stapel über das Symbol <Name> hinausgeht, abfangen (»trap«)."
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "Propolice als Stapelschutzmethode verwenden."
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr "Eine Stapelschutzmethode für jede Funktion verwenden."
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Eine schlaue Stapelschutzmethode für gewisse Funktionen verwenden."
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Stapelschutzmethode nur für Funktionen mit dem Attribut »stack_protect« verwenden."
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr "Information über Stapelverwendung auf Funktionsbasis ausgeben."
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr "Annehmen, dass strenge Alias-Regeln gelten."
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Vorzeichenbehafteten Überlauf als undefiniertes Verhalten behandeln. Wird mit -fwrapv -fwrapv-pointer negiert."
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr "__atomic-Operationen über Bibliotheksaufrufe alter __sync-Funktionen durchführen."
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr "Auf Syntaxfehler prüfen, dann anhalten."
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr "Von »gcov« benötigte Dateien anlegen."
 
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr "Sprung-Threading-Optimierungen durchführen."
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr "Benötigte Zeit für jeden Compilerdurchlauf ausgeben."
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr "Dauer der Teilphasen separat aufzeichnen."
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tDas standardmäßige Codeerzeugungsmodell für Thread-lokalen Speicher angeben."
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Funktionen, Variablen und asms höchster Ebene umordnen."
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr "Superblockerzeugung über Ende-Vervielfältigung durchführen."
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr "Für Ziele, die normalerweise Trampoline für geschachtelte Funktionen benötigen, diese stets generieren, statt Deskriptoren zu verwenden."
 
-#: common.opt:2722
+#: common.opt:2726
 #, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "Annehmen, dass Gleitkommaoperationen abgefangen werden können (»trap«)."
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Vorzeichenbehafteten Überlauf in Addition, Subtraktion und Multiplikation abfangen (»trap«)."
 
-#: common.opt:2730
+#: common.opt:2734
 #, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "SSA-CCP-Optimierungen auf Bäumen einschalten."
 
-#: common.opt:2734
+#: common.opt:2738
 #, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "SSA-BIT-CCP-Optimierungen auf Bäumen einschalten."
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr "Kopieren des Schleifenkopfes auf Bäumen einschalten."
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "Zusammenfassen von nutzersichtbaren Variablen während des SSA-Durchlaufs einschalten."
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr "Kopieweitergabe auf Bäumen einschalten."
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr "Bedingte Speicherbefehle in unbedingte umwandeln."
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr "Umwandlungen von »switch«-Initialisierungen durchführen."
 
-#: common.opt:2774
+#: common.opt:2778
 #, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Beseitigungsoptimierung für toten SSA-Code auf Bäumen einschalten."
 
-#: common.opt:2778
+#: common.opt:2782
 #, no-c-format
 msgid "Enable dominator optimizations."
 msgstr "Dominator-Optimierungen einschalten."
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "Enden-Zusammenfassung auf Bäumen einschalten."
 
-#: common.opt:2786
+#: common.opt:2790
 #, no-c-format
 msgid "Enable dead store elimination."
 msgstr "Entfernung toter Speicherungen einschalten."
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "Vorwärts-Übertragung auf Bäumen einschalten."
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Vollständige Redundanzentfernung (FRE) auf Bäumen einschalten."
 
-#: common.opt:2798
+#: common.opt:2802
 #, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "Zeichenkettenlängen-Optimierungen auf Bäumen einschalten."
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Ausführungspfade erkennen, die durch Dereferenzieren eines Nullzeigers fehlerhaftes oder undefiniertes Verhalten auslösen. Solche Pfade werden aus dem Hauptablauf herausgenommen und durch eine Trap ersetzt."
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Ausführungspfade erkennen, die ausgelöst werden, indem ein Nullwert auf eine Weise verwendet wird, die durch ein »returns_nonnull«- oder »nonnull«-Attribut verboten ist. Solche Pfade werden aus dem Hauptablauf herausgenommen und durch eine Trap ersetzt."
 
-#: common.opt:2815
+#: common.opt:2819
 #, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "Schleifenverteilung auf Bäumen einschalten."
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Schleifenverteilung für in Bibliotheksaufruf umgewandelte Muster einschalten."
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr "Bewegung der Schleifeninvariante auf Bäumen einschalten."
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr "Kanonische Induktionsvariablen in Schleifen erzeugen."
 
-#: common.opt:2835
+#: common.opt:2839
 #, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr "Schleifenoptimierungen auf Baumebene einschalten."
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "-ftree-parallelize-loops=<Anzahl>\tAutomatische Parallelisierung von Schleifen einschalten."
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Herausziehen von Ladeoperationen aus bedingten Zeigern einschalten."
 
-#: common.opt:2847
+#: common.opt:2851
 #, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "SSA-PRE-Optimierungen auf Bäumen einschalten."
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr "In SSA-PRE-Optimierungen auf Bäumen Teils-Teils-Redundanz eliminieren."
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Funktionslokale Analyse von Zeigerzielen auf Bäumen durchführen."
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr "Neuverbindung auf Baumebene einschalten."
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr "SSA-Codeversenkung auf Bäumen einschalten."
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr "Geradlinige Stärkereduktion durchführen."
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr "Skalarersetzung von Aggregaten durchführen."
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Vorübergehende Ausdrücke im SSA->Normal-Durchlauf ersetzen."
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Lebensdaueraufteilung während des »SSA -> Normal«-Durchlaufs durchführen."
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr "Wertebereichsweitergabe auf Bäumen durchführen."
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr "Pfade aufteilen, die zu Schleifen-Rückkanten führen."
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr "Annehmen, dass gemeinsame Deklarationen durch solche übersteuert werden dürfen, die ein längeres hintangestelltes Array haben."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr "Ganze Übersetzungseinheit auf einmal übersetzen."
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Schleifenabwicklung durchführen, wenn Anzahl der Wiederholungen bekannt ist."
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr "Schleifenabwicklung für alle Schleifen durchführen."
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Optimierung für Gleitkommaarithmetik erlauben, auch wenn durch Runden ein anderes Ergebnis herauskommen kann."
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Das gleiche wie -fassociative-math für Ausdrücke, die Division enthalten."
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Mathematische Optimierungen erlauben, die IEEE- oder ISO-Standards verletzen könnten."
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Schleifenausschaltung durchführen."
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Schleifen-Aufteilung durchführen."
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr "Schleifen versionieren, je nachdem, ob sie eine Schrittweite von eins haben."
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Einfach Abwicklungstabellen für Ausnahmebehandlung erzeugen."
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "BFD-Linker statt Standardlinker verwenden."
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Gold-Linker statt Standardlinker verwenden."
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Den LLVM-lld-Linker statt des Standardlinkers verwenden."
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Variablenverfolgung durchführen."
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Variablenverfolgung durch Zuweisungsanmerkungen durchführen."
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "-fvar-tracking-assignments umschalten."
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Variablenverfolgung durchführen und auch Variablen markieren, die uninitialisiert sind."
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Vektorisierung auf Bäumen einschalten."
 
-#: common.opt:3011
+#: common.opt:3015
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Schleifenvektorisierung auf Bäumen einschalten."
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Vektorisierung von Basisblöcken (SLP) auf Bäumen einschalten."
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tKostenmodell für Vektorisierung angeben."
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tVektorisierungs-Kostenmodell angeben, das für mit einer SIMD-Direktive markierten Code verwendet wird."
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Schaltet das dynamische Vektorisierer-Kostenmodell ein. Für Rückwärtskompatibilität erhalten."
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Kopieweitergabe von Informationen über Skalar-Evolution einschalten."
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Zusätzliche Anmerkungen an Assemblerausgabe anfügen."
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tStandard-Symbolsichtbarkeit festlegen."
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "VTable-Zeiger validieren, bevor sie verwendet werden."
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Verifikationszähler für VTables ausgeben."
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Informationen über Zeigermengen der VTable-Verifikation ausgeben."
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Profile von Ausdruckswerten in Optimierungen verwenden."
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Netze konstruieren und nicht zusammenhängende Verwendungen einzelner Variablen aufteilen."
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Beseitigung von bedingt totem Code für Aufrufe eingebauter Funktionen einschalten."
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Gesamtprogrammoptimierung durchführen."
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Annehmen, dass Zeigerüberläufe überschlagen (Wraparound)."
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Annehmen, dass vorzeichenbehaftete arithmetische Überläufe regulär überschlagen (Wraparound)."
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Null-initialisierte Daten in den bss-Abschnitt legen."
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr "Register, die beim Funktionsaufruf verwendet wurden, am Ende auf 0 zurücksetzen."
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Fehlersuchinformationen im Standardformat erzeugen."
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "Assembler-Unterstützung für (DWARF2+-).loc-Direktiven annehmen."
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "Assembler-Unterstützung für Ansicht in (DWARF2+-).loc-Direktiven annehmen."
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "DW_AT_decl_column und DW_AT_call_column in DWARF aufzeichnen."
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Fehlersuchinformationen im Standardversion des DWARF-Formats erzeugen."
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Fehlersuchinformationen im DWARF-v2-Format (oder neuer) erzeugen."
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr "Wenn DWARF-Debuginformationen erzeugt werden, dann im 32-Bit-Format."
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr "Wenn DWARF-Debuginformationen erzeugt werden, dann im 64-Bit-Format."
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Fehlersuchinformationen im erweiterten Standardformat erzeugen."
 
-#: common.opt:3191
+#: common.opt:3195
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Erweiterte Informationen für Einsprungpunkt für inline-Funktionen erzeugen."
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr "Locview-Rücksetzpunkte auf Basis der geschätzten Befehlslängen berechnen."
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Keine DWARF-Abschnitte für Pubnames und Pubtypes erzeugen."
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "DWARF-Abschnitte für Pubnames und Pubtypes erzeugen."
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "DWARF-Abschnitte für Pubnames und Pubtypes mit GNU-Erweiterungen erzeugen."
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "GCC-Kommandozeilenschalter in DWARF DW_AT_producer aufzeichnen."
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Fehlersuchinformationen in separaten .dwo-Dateien erzeugen."
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Fehlersuchinformationen im STABS-Format erzeugen."
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Fehlersuchinformationen im erweiterten STABS-Format erzeugen."
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr "Progressive empfohlene Breakpoint-Stellen ausgeben."
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Keine DWARF-Ergänzungen über gewählte Version hinaus erzeugen."
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr "Beschreibungsattribute zu einigen DWARF-DIEs hinzufügen, die kein Namensattribut haben."
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Erzeugung von Fehlersuchinformationen umschalten."
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr "Adresslisten der Variablen mit progressiven Sichten anreichern."
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Fehlersuchinformationen im VMS-Format erzeugen."
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Fehlersuchinformationen im XCOFF-Format erzeugen."
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Fehlersuchinformationen im erweiterten XCOFF-Format erzeugen."
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Komprimierte Fehlersuchinformationen erzeugen."
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<Format>\tKomprimierte Debugabschnitte im Format <Format> erzeugen."
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<Verz>\t<Verz> als Standard-Plugin-Verzeichnis festlegen."
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <Verzeichnis>\t<Verzeichnis> als Multiarch-include-Verzeichnis festlegen."
 
-#: common.opt:3320
+#: common.opt:3324
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <Datei>\tAusgabe in <Datei> schreiben."
 
-#: common.opt:3324
+#: common.opt:3328
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Funktionsprofilierung einschalten."
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Wie -pedantic, aber als Fehler ausgeben."
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Übersetzte Funktionen oder verstrichene Zeit nicht ausgeben."
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Wortreiche Ausgabe einschalten."
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Compiler-Version anzeigen."
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Warnungen unterdrücken."
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Shared Library erzeugen."
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Keine dynamisch gebundene, lageunabhängige ausführbare Datei erzeugen."
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Dynamisch gebundene, lageunabhängige ausführbare Datei erzeugen."
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Statische, lageunabhängige ausführbare Datei erzeugen."
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Vom Aufrufer zu sichernde Register über Aufrufe hinweg verwenden, wenn möglich."
@@ -19070,1106 +19070,1116 @@ msgstr "--param=evrp-mode=[legacy|ranger|legacy-first|ranger-first|ranger-trace|
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr "Maximale Tiefe der logischen Ausdrücke, die von der Bereichsanalyse erfasst werden, um ausgehende Bereiche zu evaluieren."
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr "Anzahl der Argumente für ein PHI, bis zu der der FSM-Threader versucht, durch dessen Block zu laufen."
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr "Skalierungsfaktor für die Anzahl der Blöcke in einem Threadingpfad, verglichen mit der Anzahl der (skalierten) Anweisungen."
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr "Skalierungsfaktor für die Anzahl der Anweisungen pro Threadingpfad, verglichen mit der Anzahl der (skalierten) Blöcke."
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "Der Schwellwert-Anteil des Ausführungszählers kritischer Kanten, die Redundanzbeseitigung nach dem Neuladen erlauben."
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "Der Schwellwert-Anteil für die Ausführung partieller Redundanzbeseitigung nach dem Neuladen."
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr "Skalierungsfaktor bei Berechnung der größten Entfernung, um die ein Ausdruck durch GCSE-Optimierungen verschoben werden kann."
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr "Kosten, zu denen GCSE-Optimierungen nicht die Entfernung beeinträchtigen werden, um die ein Ausdruck verschoben werden kann."
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "Minimale Heaperweiterung, die Speicherbereinigung anstößt, als Prozentsatz der Gesamtgröße des Heap."
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "Kleinste Heapgröße vor Speicherbereinigungsbeginn, in Kilobytes."
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr "Die Anzahl der Ausführungen eines Basisblocks, der als heiß angesehen wird. Dieser Parameter wird nur im GIMPLE-Frontend verwendet."
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr "Ob bei -fchecking Fehler im Codegenerator als interne Compilerfehler behandelt werden sollen."
 
-#: params.opt:206
+#: params.opt:211
 #, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr "Höchstzahl der Arrays in einem SCoP."
 
-#: params.opt:210
+#: params.opt:215
 #, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr "Höchstzahl der Parameter in einem SCoP."
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr "Die Anzahl der Elemente, für die die Überprüfung der Hash-Tabelle für jedes gesuchte Element durchgeführt wird."
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "Der Nenner n des Bruchteils 1/n der maximalen Ausführungsanzahl eines Basisblocks im gesamten Programm, den ein Basisblock mindestens haben muss, um als heiß zu gelten (im Nicht-LTO-Modus verwendet)."
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr "Die Anzahl der am häufigsten ausgeführten Promille der profilierten Ausführung des gesamten Programms, zu der die Ausführungszahl eines Basisblocks gehören muss, um als heiß zu gelten (im LTO-Modus verwendet)."
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "Der Nenner n des Bruchteils 1/n der Ausführungshäufigkeit des Eingangsblocks einer Funktion, den ein Basisblock dieser Funktion mindestens haben muss, um als heiß zu gelten."
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr "Die Skalierung (in Prozent), die auf inline-insns-single und Auto-Limits angewendet wird, wenn die Heuristik darauf hinweist, dass Inlining sehr profitabel ist."
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr "Kleinste voraussichtliche Beschleunigung, die dem Inliner erlaubt, inline-insns-single und inline-isnsns-auto zu ignorieren."
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "Wie viel die gegebene Übersetzungseinheit durch das »inline« wachsen kann (in Prozent)."
 
-#: params.opt:242
+#: params.opt:247
 #, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "Obere Schranke zum gemeinsamen Verwenden von Ganzzahlkonstanten."
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr "Schwellwert für Auswertung der Möglichkeit von IPA-CP, der noch als vorteilhaft zum Kopieren betrachtet wird."
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr "Übersetzungszeit-Bonus, den IPA-CP an Kandidaten vergibt, die Schleifengrenzen oder Schrittweiten bekannt machen."
 
-#: params.opt:254
+#: params.opt:259
 #, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "Maximale Tiefe des rekursiven Klonens für selbstrekursive Funktionen."
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Rekursives Klonen nur dann, wenn die Wahrscheinlichkeit, dass der Aufruf ausgeführt wird, den Parameter überschreitet."
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr "Prozentuale Strafe für rekursive Funktionen, wenn sie zum Klonen evaluiert werden."
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr "Prozentuale Strafe für Funktionen, die nur einen einzigen Aufruf einer anderen Funktion enthalten, wenn sie zum Klonen evaluiert werden."
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "Wie viel die gegebene Übersetzungseinheit durch die interprozedurale Konstantenweitergabe wachsen kann (in Prozent)."
 
-#: params.opt:274
+#: params.opt:279
 #, no-c-format
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "Die Größe einer Übersetzungseinheit, ab der der IPA-CP-Durchlauf sie als groß ansieht."
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr "Maximale Größe einer jedem Parameter zugeordneten Liste von Werten für interprozedurale Konstantenweitergabe."
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr "Höchstzahl der betrachteten Anweisungen für das Entdecken von Sprungfunktionsoffsets."
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr "Höchstzahl der Anweisungen, die von der Analyse der formalen Parameter für IPA besucht werden, basierend auf der Aliasanalyse in einer gegebenen Funktion."
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr "Höchstzahl der zusammengesetzten Elemente für einen Parameter in Sprungfunktionen und Gittern."
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "Maximale Anzahl von Operationen in einem Parameterausdruck, die von der IPA-Analyse behandelt werden können."
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr "Maximale Anzahl verschiedener Prädikate, die zur Verfolgung der Eigenschaften von Schleifen in der interprozeduralen Analyse verwendet werden."
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr "Maximale Anzahl der Grenzendpunkte der Fallbereiche der Switch-Anweisung, die bei der Generierung der IPA-Funktionszusammenfassung verwendet werden."
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr "Maximale Stücke, die IPA-SRA pro Formalparameter verfolgt, folglich auch die maximale Anzahl von Ersetzungen eines Formalparameters."
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr "Maximal erlaubte Größenzunahme und Gesamtgröße der neuen Parameter, bis zu der IPA-RSA Zeiger auf Aggregate ersetzt."
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr "Die Anzahl der Register in jeder Klasse, die von Schleifeninvariantenbewegung freigehalten werden."
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr "Maximale Größe der Konflikttabelle in MB."
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr "Maximale Schleifenanzahl für regionale Registerzuweisung (RA)."
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "Wenn die Anzahl der Kandidaten in der Menge kleiner ist, wird immer versucht, ungenutzte IVs während ihrer Optimierung zu entfernen."
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "Schranke für Anzahl der Kandidaten, unter der alle Kandidaten in IV-Optimierungen betrachtet werden."
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "Schranke für Anzahl der IV-Verwendungen in bei IV-Optimierungen optimierter Schleife."
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr "Die maximale Wachstumsrate der Codegröße bei der Erweiterung in eine Sprungtabelle (in Prozent). Der Parameter wird bei der Optimierung auf Größe verwendet."
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr "Die maximale Wachstumsrate der Codegröße bei der Erweiterung in eine Sprungtabelle (in Prozent). Der Parameter wird bei der Optimierung auf Geschwindigkeit verwendet."
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr "Die Größe einer L1-Cacheline."
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr "Die Größe des L1-Caches."
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr "Die Größe des L2-Caches."
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Maximales Wachstum durch »inline« einer großen Funktion (in Prozent)."
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr "Die Größe eines als groß angesehenen Funktionskörpers."
 
-#: params.opt:366
+#: params.opt:371
 #, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "Die Größe eines als groß angesehenen Stapelrahmens."
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Maximales Stapelrahmen-Wachstum durch »inline« (in Prozent)."
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr "Die Größe einer als groß angesehenen Übersetzungseinheit."
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr "Höchstzahl der gleichzeitig offenen C++-Moduldateien beim verzögerten Laden."
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "Die Mindestkosten eines teuren Ausdrucks in der Schleifeninvariantenbewegung."
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr "Bei den booleschen Kurzschluss-Operatoren && und || beide Seiten auswerten, wenn das nebenwirkungsfrei zu besserem Code führt."
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr "Größe der Kacheln für Schleifenblockierung."
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "Die Höchstzahl der Anweisungen in geschachtelten Schleifen zum Schleifenaustausch."
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "Das Mindestverhältnis der Schrittweiten, damit Schleifenaustausch profitabel ist."
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr "Höchstzahl der Basis-Blöcke in Schleife für Schleifeninvariantenbewegung."
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr "Höchstzahl der Datenreferenzen in Schleife zum Aufbau der Abhängigkeiten der Schleifendaten."
 
-#: params.opt:410
+#: params.opt:415
 #, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "Die Höchstzahl der in einer inneren Schleife zu betrachtenden Befehle für Versionierung."
 
-#: params.opt:414
+#: params.opt:419
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "Die Höchstzahl der in einer äußeren Schleife zu betrachtenden Befehle für Versionierung, zusätzlich zu den Befehlen in inneren Schleifen."
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr "Mindestwahrscheinlichkeit in Prozent für Durchfall-Kanten, damit der BB zu geerbten EBB in LRA hinzugefügt wird."
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr "Die Höchstzahl Reload-Pseudos, die beim Auslagern eines Nicht-Reload-Pseudos berücksichtigt werden."
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr "Kleinste Größe einer Partition für LTO (in geschätzten Befehlen)"
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr "Höchstzahl der LTO-Partitionen, die parallel gestreamt werden."
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr "Kleinste Größe einer Partition für Linkzeitoptimierung (in geschätzten Befehlen)."
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr "Anzahl der Partitionen, in die das Programm aufgeteilt werden soll."
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "Die Höchstzahl der zum Abrollen von Schleifen im Mittel zu betrachtenden Befehle."
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr "Höchstzahl von Befehlen, die »combine« zu kombinieren versucht."
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "Die maximale Tiefe einer Schleifenschachtelung, die vollständig geschält wird."
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Die Höchstzahl der Schälvorgänge einer einzelnen Schleife, die vollständig geschält wird."
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "Die Höchstzahl der Befehle einer vollständig geschälten Schleife."
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "Höchstzahl der zu betrachtenden eingehenden Kanten für Kreuzsprung."
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr "Die Höchstzahl der von CSE verarbeiteten Befehle vor dem Rücksetzen."
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr "Größte Länge des betrachteten Pfades in CSE."
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Höchstzahl der Speicherstellen, die von cselib aufgezeichnet werden."
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr "Maximalzahl der Debugmarkierungen, die expandiert oder eingereiht werden."
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "Die Höchstzahl der zu betrachtenden Befehle, um einen Verzögerungsschlitz zu füllen."
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "Die Höchstzahl der zu betrachtenden Befehle, um richtige aktive Registerinformationen zu finden."
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr "Höchstzahl der aktiven lokalen Speicherungen bei RTL-Eliminierung toter Speicherungen."
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "Die Höchstzahl von geschachteltem indirektem inlinen wurde bereits durch den frühen Inliner durchgeführt."
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "Die Höchstzahl der Felder in einer Struktur, bevor Zeigeranalyse sie als einzelne Variable behandelt."
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr "Höchstzahl der Basis-Blöcke in einem Mehrfachsprung in einem endlichen Automaten."
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr "Höchstzahl der zu kopierenden Befehle, wenn Blöcke auf einem Mehrsprungpfad des Zustandsautomaten dupliziert werden."
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "Höchstzahl der neuen Sprungpfade, die für einen endlichen Automaten erzeugt werden."
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "Das maximale Verhältnis von Einfügungen zu Löschungen von Ausdrücken in GCSE."
 
-#: params.opt:518
+#: params.opt:523
 #, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "Höchstmenge des von GCSE zu belegenden Speichers, in Kilobyte."
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "Die Höchstzahl der zu vervielfältigenden Befehle, wenn berechnete Gotos expandiert werden."
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "Der höchste Erweiterungsfaktor beim Kopieren von Basisblöcken."
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr "Größte Tiefe der Suche im Dominator-Baum für anzuhebende Ausdrücke."
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "Die Höchstzahl der Befehle für automatisches Inlinen."
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "Die Höchstzahl der Befehle, bis zu der eine Inline-Funktion per Rekursion wachsen kann."
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "Die Höchstzahl der Befehle, bis zu der eine Nicht-Inline-Funktion per Rekursion wachsen kann."
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "Die Höchstzahl der Befehle in einer einzelnen für »inline« geeigneten Funktion."
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr "Die Höchstzahl der Befehle für automatisches Inlinen beim Optimieren auf Codegröße."
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "Die Höchstzahl der Befehle für automatisches Inlinen von kleinen Funktionen."
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "Größte Tiefe mit rekursivem Inline für Inline-Funktionen."
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "Größte Tiefe rekursiven Inlinens für Nicht-Inline-Funktionen."
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Höchstzahl der ISL-Operationen, 0 bedeutet unbegrenzt."
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "Schranke für die Kosten eines Ausdrucks, um die Anzahl der Durchläufe zu berechnen."
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "Schranke für die Anzahl der Iterationen, die der Brute-Force-Algorithmus zur Auswertung der Anzahl von Iterationen auswertet."
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "Höchstzahl der in einem Block erlaubten Anweisungen, die für Sprungbehandlung vervielfältigt werden müssen."
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "Höchstzahl der RTL-Knoten, die als letzte Werte des Kombinierers aufgezeichnet werden können."
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "Die Höchstzahl der Befehle im Schleifenkopf, die während der Schleifenkopfkopier-Phase dupliziert werden."
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "Die Höchstzahl der Versuche zur Rückverfolgung bei Modulo-Planung von Schleifen."
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr "Maximalgröße der partiellen Aufwandsmenge, wenn Baumvoroptimierung ausgeführt wird."
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "Höchstzahl der Zweige auf dem Pfad durch die geschälte Sequenz."
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "Die Höchstzahl der Schälvorgänge einer einzelnen Schleife."
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr "Die Höchstzahl der Befehle einer geschälten Schleife."
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "Die Maximallänge der Liste der anhängigen geplanten Operationen."
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "Höchstzahl der für Zwischen-Block-Scheduling zu betrachtenden Blöcke in einer Region."
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "Höchstzahl der für Zwischen-Block-Scheduling zu betrachtenden Befehle in einer Region."
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr "Maximale Verschachtelung von Quadratwurzeln, um Potenzierung mit Gleitkommakonstanten abzubilden."
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "Die Höchstzahl der Schleifendurchläufe, die statisch vorhergesagt werden."
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "Höchstzahl der rückwärts zu suchenden Befehle, wenn nach äquivalentem Neuladen gesucht wird."
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Höchstzahl der in Basis-Block zu betrachtenden Befehle für RTL-if-Umwandlung."
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr "Maximal erlaubte Kosten für die Befehlsfolge, die vom RTL-if-Umwandlungs-Durchlauf für eine vorhersagbare Verzweigung erzeugt wird."
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr "Maximal erlaubte Kosten für die Befehlsfolge, die vom RTL-if-Umwandlungs-Durchlauf für eine unvorhersagbare Verzweigung erzeugt wird."
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "Höchstzahl der Iterationen durch CFG zur Regionserweiterung."
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "Höchste Verzögerung bei Konflikt, sodass Befehl für spekulative Bewegung in Betracht kommt."
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "Höchstzahl der vom Scheduler während der ersten Planphase fertig zur Ausführung zu betrachtenden Befehle."
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr "Maximallänge von Kandidatenprüfungen für geradlinige Stärkereduktion."
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr "Höchstzahl der beim spekulativen Devirtualisieren besuchten may-defs."
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr "Maximal erlaubte Rekursionstiefe beim Abfragen von Eigenschaften eines SSA-Namens."
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "Höchstzahl der konstanten Speicherungen, die im Speicherzusammenfassungs-Durchgang zusammengefasst werden."
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "Höchstzahl von bedingten Speicherpaaren, die ausgegeben werden können."
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "Höchstzahl der Speicherungsketten, die im Speicherzusammenfassungs-Durchgang gleichzeitig berücksichtigt werden."
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr "Höchstzahl der ähnlichen Basisblöcke, mit denen ein Basisblock verglichen wird."
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr "Höchstzahl der Iterationen des Durchgangs über eine Funktion."
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr "Höchstzahl der Zeichenketten, für die der strlen-Optimierungsdurchgang Zeichenkettenlängen aufzeichnet."
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr "Höchstzahl der Argumente in einem PHI, die einer TREE-if-Umwandlung unterstützt werden, außer wenn die Schleife mit einem SIMD-Pragma markiert ist."
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Die Höchstzahl der Iterationen zum Abrollen in einzelner Schleife."
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "Die Höchstzahl der zum Abrollen von Schleifen zu betrachtenden Befehle."
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "Die Höchstzahl der Befehle einer ungeschalteten Schleife."
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Die Höchstzahl der Abschaltungen in einer einzelnen Schleife."
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "Wenn »-fvariable-expansion-in-unroller« verwendet wird, die Höchstzahl der Fälle, dass eine einzelne Variable während Loop-Unrolling expandiert wird."
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr "Größte Rekursionstiefe für das Expandieren von variablenverfolgenden Ausdrücken."
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr "Maximalgröße der Speicherort-Liste, bei der Umkehrungsoperationen hinzugefügt werden sollen."
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr "Maximale Größe variablenverfolgender Hash-Tabellen."
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr "Maximale Anzahl der VALUEs, die während eines einzelnen Aufrufs von »find_base_term« verarbeitet werden."
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr "Höchstzahl der Assertions, die während der VRP entlang der Standardkante einer switch-Anweisung hinzugefügt werden."
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "Mindestanzahl der passenden zu betrachtenden Befehle für Kreuzsprung."
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Rekursives inlinen nur, wenn die Wahrscheinlichkeit des Aufrufs den Parameter überschreitet."
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr "Kleinstes Verhältnis von Befehlen zu Prefetches, um Prefetching für eine Schleife mit unbekannter Frequentierung einzuschalten."
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr "Der minimale Schwellwert für die Wahrscheinlichkeit, dass eine halbinvariante Bedingungsanweisung eine Schleifenteilung auslöst."
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr "Kleinste UID für Nicht-Debug-Befehl."
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr "Mindestgröße von Variablen, die sich Stapelspeicher teilen, wenn nicht optimiert wird."
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "Die Mindestwahrscheinlichkeit für das Erreichen eines Quellblockes für spekulatives Zwischen-Block-Scheduling."
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "Wenn »-ftree-vectorize« verwendet wird, die minimale Schleifengrenze einer für Vektorisierung zu betrachtenden Schleife."
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr "--param=openacc-kernels=[decompose|parloops]\tModus, in dem OpenACC-»kernels«-Konstrukte verarbeitet werden."
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr "Häppchengröße des OMP-Schedulers für Schleifen, die durch parloops parallelisiert wurden."
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Die Mindestzahl der Iterationen pro Thread in einer innersten parallelisierten Schleife."
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tArt des OMP-Zeitplans für Schleifen, die durch parloops parallelisiert werden."
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr "Größte Wahrscheinlichkeit des Einsprung-BB der geteilten Region (in Prozent relativ zum Einsprung-BB der Funktion), um teilweises »inline« durchzuführen."
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "Größtes geschätztes Ergebnis eines als vorhersagbar betrachteten Sprunges."
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr "Ob Software-Prefetch-Tipps für nicht-konstante Schrittweiten produziert werden."
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "Die Anzahl der ausgeführten Befehle, bevor Prefetch abgeschlossen ist."
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr "Kleinstes Verhältnis von Befehlen zu Speicheroperationen, um Prefetching in einer Schleife einzuschalten."
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr "Die kleinste Schrittweite, ab der Software-Prefetch-Tipps produziert werden."
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr "Interne Funktions-ID bei Profilnachschlagen verwenden."
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "Maximale Verschachtelungstiefe von Schleifen für optimistisches value-number."
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr "Höchstzahl der Auflösungen von Mehrdeutigkeiten pro Speicherzugriff."
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "Schranke für die Komplexität von Ausdrücken im skalaren Evolutions-Analysierer."
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "Schranke für Größe von Ausdrücken, die im skalaren Evolutions-Analysierer verwendet werden."
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr "Hardware-Autoprefetcher-Scheduler-Modellsteuerung: Anzahl der Vorausschauzyklen, die das Modell untersucht, bei '0' ist nur die heuristische Sortierung von Befehlen aktiviert. Standardmäßig deaktiviert."
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr "Kleinster Abstand zwischen möglicherweise in Konflikt stehendem Speichern und Laden."
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr "Anzuwendender Algorithmus für »-fsched-pressure«."
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "Die Mindestwahrscheinlichkeit für spekulativen Erfolg (in Prozent), sodass spekulativer Befehl eingeplant wird."
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr "Kleinste Wahrscheinlichkeit einer Kante, sodass bei der Planung ihr Zustand gesichert wird."
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "Die Höchstzahl der Befehle in der ausführungsbereiten Liste, die zur Umbenennung in Frage kommen."
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr "Maximale Größe des Vorgriffsfensters der wählbaren Planung."
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "Höchstzahl, wie oft ein Befehl geplant werden könnte."
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr "Die Anzahl der Prefetches, die gleichzeitig laufen können."
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr "Zum Absenken einer Anweisung nötige relative Ausführungsfrequenz des Ziel-Blocks (in Prozent)."
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "Anzahl der Zyklen, die der Swing-Modulo-Scheduler bei Konfliktprüfung mit DFA betrachtet."
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "Schwellwert für vom Swing-Modulo-Scheduler betrachteten Durchschnitts-Schleifen-Zähler."
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "Ein Faktor, um die obere Schranke des Swing-Modulo-Schedulers für Schleifenplanung einzustellen."
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr "Kleinster Wert der Stufenzahl, den der Swing-Modulo-Scheduler erzeugen wird."
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr "Maximale Größe (in Speichereinheiten) von Aggregaten, die für Skalarisierung erwägt werden, wenn auf Codegröße optimiert wird."
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr "Maximale Größe (in Speichereinheiten) von Aggregaten, die für Skalarisierung erwägt werden, wenn auf Geschwindigkeit optimiert wird."
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr "Maximale Anzahl von künstlichen Zugriffen, um eine Vorwärtsausbreitung zu ermöglichen, die die Skalare Ersetzung von Aggregaten für eine lokale Variable beibehält."
 
-#: params.opt:924
+#: params.opt:942
 #, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "Die maximale Anzahl von SSA_NAME-Zuweisungen, die verfolgt werden, um einen Wert zu bestimmen."
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "Untere Schranke für einen für Stack-Smashing-Protection betrachteten Puffer."
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr "Größe des Stapelschutzes, als Zweierpotenz von Bytes ausgedrückt."
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr "Intervall, in dem der Stack geprüft wird, als Zweierpotenz in Bytes ausgedrückt."
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr "Im Durchlauf, der Speicheroperationen zusammenfasst, unausgerichtete Speicherungen zulassen, sofern es erlaubt ist."
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr "Maximale Größe eines einzelnen Bereichs einer Speicherzusammenführung in Bytes."
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "Maximales Verhältnis zwischen Arraygröße und Switch-Zweigen, bei dem eine Switch-Umwandlung erfolgt."
 
-#: params.opt:952
+#: params.opt:970
 #, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "Höchstzahl der Basen, die pro modref-Baum gespeichert werden."
 
-#: params.opt:956
+#: params.opt:974
 #, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr "Höchstzahl der Verweise, die pro modref-Basis gespeichert werden."
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99167
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "Höchstzahl der Zugriffe, die pro modref-Verweis gespeichert werden."
 
-#: params.opt:964
+#: params.opt:982
 #, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr "Höchstzahl der Tests, die von modref-Anfragen durchgeführt werden."
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr "Höchsttiefe beim Durchlaufen des DFS durch die modref-Escapeanalyse."
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "Höchstzahl der Ausstiegspunkte, die von modref pro SSA-Name aufgezeichnet werden."
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr "Größe in Bytes, über der thread-lokale Zusammenfassungen mit Logging-Funktionen statt mit Save/Restore-Paaren instrumentiert werden sollten."
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "Prozentsatz der Funktion, gewichtet nach Ausführungshäufigkeit, die bei Verfolgungsentwurf abgedeckt werden muss. Verwendet, wenn Profil-Rückmeldung nicht verfügbar ist."
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "Prozentsatz der Funktion, gewichtet nach Ausführungshäufigkeit, die bei Verfolgungsentwurf abgedeckt werden muss. Verwendet, wenn Profil-Rückmeldung verfügbar ist."
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Maximaler Code-Zuwachs durch Ende-Vervielfältigung (in Prozent)."
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "Vorwärtswachstum anhalten, wenn die Wahrscheinlichkeit der besten Kante weniger als dieser Schwellwert ist. Verwendet, wenn Profil-Rückmeldung nicht verfügbar ist."
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "Vorwärtswachstum anhalten, wenn die Wahrscheinlichkeit der besten Kante weniger als dieser Schwellwert ist. Verwendet, wenn Profil-Rückmeldung verfügbar ist."
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "Umgekehrtes Wachstum anhalten, wenn die umgekehrte Wahrscheinlichkeit der besten Kante weniger als dieser Schwellwert ist (in Prozent)."
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr "Höchstzahl der parallel ausgeführten Befehle im neuverbundenen Baum festlegen. Bei 0 die zielabhängige Heuristik verwenden."
 
-#: params.opt:1008
+#: params.opt:1026
 #, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "Spezielle Instrumentierung für Zugriff auf volatile-Objekte erzeugen."
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr "Instrumentierungsaufrufe für Aufrufe von __tsan_func_entry() und __tsan_func_exit() erzeugen."
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr "Höchstzahl der geschachtelten Aufrufe, die bei der Analyse für uninitialisierte Variablen auf Abhängigkeiten in der Ablaufsteuerung untersucht werden."
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "Anzahl der Maschinenbefehle, die für Funktionsprolog, -Epilog und sonstigen Overhead veranschlagt werden."
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "Zeit, die für Funktionsprolog, -Epilog und sonstigen Overhead veranschlagt wird."
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr "Anzahl der Maschinenbefehle, die für Thunk-Overhead in Funktionen veranschlagt werden."
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr "Zeit, die für Thunk-Overhead in Funktionen veranschlagt wird."
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr "Der Nenner n des Bruchteils 1/n der Anzahl der profilierten Durchläufe des gesamten Programms, unter dem die Ausführungszahl eines Grundblocks liegen muss, damit der Grundblock als unwahrscheinlich angesehen wird."
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr "Maximaler Entrollfaktor für die »unroll-and-jam«-Transformation."
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr "Mindestprozentsatz der Memrefs, die für unroll-and-jam verschwinden müssen, damit es profitabel ist."
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr "Direkt vergiftende/entgiftende Befehle für Variablen verwenden, die maximal die angegebene Größe haben."
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr "Ob kanonische Typen zu verwenden sind."
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "Vektorisierung des Schleifen-Epilogs mit kleinerer Vektorgröße einschalten."
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr "Höchstzahl der Schleifenschälungen, um Ausrichtung von Datenreferenzen in einer Schleife zu verbessern."
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "Schranke für Anzahl der Laufzeitprüfungen, die von Schleifenversionierung des Vektorisierers für Aliasprüfung eingefügt werden."
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Schranke für Anzahl der Laufzeitprüfungen, die von Schleifenversionierung des Vektorisierers für Ausrichtungsprüfung eingefügt werden."
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr "Steuert, wie der Schleifenvektorisierer partielle Vektoren verwendet. 0 bedeutet nie, 1 bedeutet nur für Schleifen, die nicht unbedingt vektorisiert werden müssen, 2 bedeutet für alle Schleifen. Voreinstellung ist 2."
@@ -20200,7 +20210,7 @@ msgid "expected boolean type"
 msgstr "boolescher Typ erwartet"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Ganzzahl erwartet"
@@ -20264,7 +20274,7 @@ msgstr "Nicht genug Argumente"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "zu viele Argumente"
@@ -20618,7 +20628,7 @@ msgstr "Attribut %qE steht mit Attribut %qs in Konflikt; wird ignoriert"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "vorherige Deklaration hier"
@@ -20673,7 +20683,7 @@ msgstr "Typattribute ignoriert, nachdem Typ bereits definiert ist"
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -20702,20 +20712,20 @@ msgstr "Typattribute ignoriert, nachdem Typ bereits definiert ist"
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -20726,8 +20736,8 @@ msgstr "Attribut %qE wird ignoriert"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "Attribut %<target%> fehlt für multiversioniertes %qD"
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "vorherige Deklaration von %qD"
@@ -20737,59 +20747,59 @@ msgstr "vorherige Deklaration von %qD"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "auf %qT nach einer Definition angewandte Attribute werden ignoriert"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D bereits mit Attribut »dllimport« deklariert: »dllimport« ignoriert"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D ohne Attribut »dllimport« redeklariert, nachdem es mit dll-Bindung referenziert wurde"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%qD ohne Attribut »dllimport« redeklariert: vorheriges »dllimport« ignoriert"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "»inline«-Funktion %q+D ist als »dllimport« deklariert: Attribut wird ignoriert"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "Funktionsdefinition von %q+D ist als »dllimport« markiert"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "Variablendefinition von %q+D ist als dllimport markiert"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "für Symbol %q+D wird wegen des Attributes %qE externe Bindung benötigt"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qE bringt Standardsichtbarkeit mit sich, aber %qD wurde bereits mit anderer Sichtbarkeit deklariert"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] "%qD legt eingeschränkteres Attribut als sein Ziel %qD fest: %s"
 msgstr[1] "%qD legt eingeschränktere Attribute als sein Ziel %qD fest: %s"
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "Ziel %qD wurde hier deklariert"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -20891,7 +20901,7 @@ msgstr "das referenzierte Argument wird hier deklariert"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "Offset %qwi ist außerhalb der Grenzen der konstanten Zeichenkette"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE ist hier deklariert"
@@ -20916,720 +20926,720 @@ msgstr "Drittes Argument für %<__builtin_prefetch%> muss eine Konstante sein"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "Ungültiges drittes Argument für %<__builtin_prefetch%>; es wird 0 verwendet"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "%Kdurch %qD angegebene Grenze %E überschreitet möglicherweise die maximale Objektgröße %E"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "%Kdurch %qD angegebene Grenze %E überschreitet die maximale Objektgröße %E"
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "%Kangegebene Grenze %E überschreitet möglicherweise die maximale Objektgröße %E"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr "%Kangegebene Grenze %E überschreitet die maximale Objektgröße %E"
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "%Kdurch %qD angegebene Grenze [%E, %E] überschreitet möglicherweise die maximale Objektgröße %E"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr "%Kdurch %qD angegebene Grenze [%E, %E] überschreitet die maximale Objektgröße %E"
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "%Kangegebene Grenze [%E, %E] überschreitet möglicherweise die maximale Objektgröße %E"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "%Kangegebene Grenze [%E, %E] überschreitet die maximale Objektgröße %E"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr "%Kdurch %qD angegebene Grenze %E überschreitet möglicherweise die Größe %E des Quellobjekts"
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr "%Kdurch %qD angegebene Grenze %E überschreitet die Größe %E des Quellobjekts"
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr "%Kangegebene Grenze %E überschreitet möglicherweise die Größe %E des Quellobjekts"
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr "%Kangegebene Grenze %E überschreitet die Größe %E des Quellobjekts"
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr "%Kdurch %qD angegebene Grenze [%E, %E] überschreitet möglicherweise die Größe %E des Quellobjekts"
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr "%Kdurch %qD angegebene Grenze [%E, %E] überschreitet die Größe %E des Quellobjekts"
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr "%Kangegebene Grenze [%E, %E] überschreitet möglicherweise die Größe %E des Quellobjekts"
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr "%Kangegebene Grenze [%E, %E] überschreitet die Größe %E des Quellobjekts"
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, gcc-internal-format
 msgid "source object declared here"
 msgstr "Quellobjekt ist hier deklariert"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr "Quellobjekt wird hier alloziert"
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "%Kdurch %qD angegebene Größe %E überschreitet möglicherweise die maximale Objektgröße %E"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr "%Kdurch %qD angegebene Größe %E überschreitet die maximale Objektgröße %E"
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "%Kangegebene Größe %E überschreitet möglicherweise die maximale Objektgröße %E"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr "%Kangegebene Größe %E überschreitet die maximale Objektgröße %E"
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "%Kdurch %qD angegebene Größe zwischen %E und %E überschreitet möglicherweise die maximale Objektgröße %E"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "%Kdurch %qD angegebene Größe zwischen %E und %E überschreitet die maximale Objektgröße %E"
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "%Kangegebene Größe zwischen %E und %E überschreitet möglicherweise die maximale Objektgröße %E"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr "%Kangegebene Größe zwischen %E und %E überschreitet die maximale Objektgröße %E"
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr "%Kdurch %qD angegebene Grenze %E überschreitet möglicherweise die Größe %E des Zielobjekts"
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr "%Kdurch %qD angegebene Grenze %E überschreitet die Größe %E des Zielobjekts"
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr "%Kangegebene Grenze %E überschreitet möglicherweise die Größe %E des Zielobjekts"
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr "%Kangegebene Grenze %E überschreitet die Größe %E des Zielobjekts"
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr "%Kdurch %qD angegebene Grenze [%E, %E] überschreitet möglicherweise die Größe %E des Zielobjekts"
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr "%Kdurch %qD angegebene Grenze [%E, %E] überschreitet die Größe %E des Zielobjekts"
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr "%Kangegebene Grenze [%E, %E] überschreitet die Größe %E des Zielobjekts"
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, gcc-internal-format
 msgid "destination object declared here"
 msgstr "Zielobjekt ist hier deklariert"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, gcc-internal-format
 msgid "destination object allocated here"
 msgstr "Zielobjekt wird hier alloziert"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr "%K%qD greift möglicherweise auf %E Byte in einer Region der Größe %E zu"
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr "%K%qD greift auf %E Byte in einer Region der Größe %E zu"
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr "%K%qD greift möglicherweise auf %E Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr "%K%qD greift auf %E Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr "%KCode greift möglicherweise auf %E Byte in einer Region der Größe %E zu"
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr "%KCode greift auf %E Byte in einer Region der Größe %E zu"
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr "%KCode greift möglicherweise auf %E Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr "%KCode greift auf %E Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr "%K%qD greift möglicherweise auf %E oder mehr Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr "%K%qD greift auf %E oder mehr Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr "%KCode greift möglicherweise auf %E oder mehr Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr "%KCode greift auf %E oder mehr Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr "%K%qD greift möglicherweise auf zwischen %E und %E Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr "%K%qD greift auf zwischen %E und %E Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr "%Kgreift möglicherweise auf zwischen %E und %E Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr "%KCode greift auf zwischen %E und %E Bytes in einer Region der Größe %E zu"
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr "%K%qD schreibt möglicherweise %E Byte in eine Region der Größe %E"
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr "%K%qD schreibt %E Byte in eine Region der Größe %E und bringt dadurch das Zielobjekt zum Überlaufen"
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr "%K%qD schreibt möglicherweise %E Bytes in eine Region der Größe %E"
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD schreibt %E Bytes in eine Region der Größe %E und bringt dadurch das Zielobjekt zum Überlaufen"
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr "%KCode schreibt möglicherweise %E Byte in eine Region der Größe %E"
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr "%KCode schreibt %E Byte in eine Region der Größe %E und bringt dadurch das Zielobjekt zum Überlaufen"
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr "%KCode schreibt %E Bytes in eine Region der Größe %E"
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr "%KCode schreibt %E Bytes in eine Region der Größe %E und bringt dadurch das Zielobjekt zum Überlaufen"
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr "%K%qD schreibt möglicherweise %E oder mehr Bytes in eine Region der Größe %E"
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr "%K%qD schreibt %E oder mehr Bytes in eine Region der Größe %E und bringt dadurch das Zielobjekt zum Überlaufen"
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr "%KCode schreibt %E oder mehr Bytes in eine Region der Größe %E"
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr "%KCode schreibt %E oder mehr Bytes in eine Region der Größe %E und bringt dadurch die Zielregion zum Überlaufen"
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr "%K%qD schreibt möglicherweise zwischen %E und %E Bytes in eine Region der Größe %E"
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD schreibt zwischen %E und %E Bytes in eine Region der Größe %E und bringt dadurch das Zielobjekt zum Überlaufen"
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr "%KCode schreibt möglicherweise zwischen %E und %E Bytes in eine Region der Größe %E"
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%KCode schreibt zwischen %E und %E Bytes in eine Region der Größe %E und bringt dadurch das Zielobjekt zum Überlaufen"
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr "%K%qD liest möglicherweise %E Byte aus einer Region der Größe %E"
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr "%K%qD liest %E Byte aus einer Region der Größe %E"
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr "%K%qD liest möglicherweise %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr "%K%qD liest %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr "%KCode liest möglicherweise %E Byte aus einer Region der Größe %E"
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr "%KCode liest %E Byte aus einer Region der Größe %E"
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr "%KCode liest möglicherweise %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr "%KCode liest %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr "%K%qD liest möglicherweise %E oder mehr Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr "%K%qD liest %E oder mehr Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr "%KCode liest möglicherweise %E oder mehr Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr "%KCode liest %E oder mehr Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr "%K%qD liest möglicherweise zwischen %E und %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr "%K%qD liest zwischen %E und %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr "%KCode liest möglicherweise zwischen %E und %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr "%KCode liest zwischen %E und %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] "%K%qD erwartet %E Byte in einer Region der Größe %E"
 msgstr[1] "%K%qD erwartet %E Bytes in einer Region der Größe %E"
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] "%KCode erwartet %E Byte in einer Region der Größe %E"
 msgstr[1] "%KCode erwartet %E Bytes in einer Region der Größe %E"
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr "%K%qD erwartet %E oder mehr Bytes in einer Region der Größe %E"
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr "%KCode erwartet %E oder mehr Bytes in einer Region der Größe %E"
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr "%K%qD erwartet zwischen %E und %E Bytes in einer Region der Größe %E"
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr "%KCode erwartet zwischen %E und %E Bytes in einer Region der Größe %E"
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr "an Offset %s des Zielobjekts %qE der Größe %s"
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr "Zielobjekt %qE der Größe %s"
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr "an Offset %s des Zielobjekts der Größe %s, alloziert durch %qE"
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr "Zielobjekt der Größe %s, alloziert durch %qE"
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr "an Offset %s des Quellobjekts %qE der Größe %s"
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr "Quellobjekt %qE der Größe %s"
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr "an Offset %s des Quellobjekts der Größe %s, alloziert durch %qE"
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr "Quellobjekt der Größe %s, alloziert durch %qE"
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr "%Kdurch %qD angegebene Grenze %E ist genau die Größe des Zielobjekts"
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "Zu wenige Argumente für %<va_start%>"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "ungültiges Argument für %qD"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "nicht unterstütztes Argument für %qD"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr "das Aufrufen von %qD mit einem nicht-null-Argument ist unsicher"
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "beide Argumente für %<__builtin___clear_cache%> müssen Zeiger sein"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "Trampolin für geschachtelte Funktion %qD erzeugt"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD hat neue Semantik in GCC 4.4"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "Unbekannte Architekturspezifikation in Speichermodell für eingebaute Funktion"
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "ungültiges Speichermodell-Argument für eingebaute Funktion"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "Fehler-Speichermodell kann nicht stärker als Erfolgs-Speichermodell für %<__atomic_compare_exchange%> sein"
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "ungültiges Fehler-Speichermodell für %<__atomic_compare_exchange%>"
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "ungültiges Speichermodell für %<__atomic_load%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ungültiges Speichermodell für %<__atomic_store%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr "Nicht konstantes Argument 1 für %qs"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, gcc-internal-format
 msgid "non-integer argument 1 to %qs"
 msgstr "Nicht ganzzahliges Argument 1 für %qs"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "%<__builtin_thread_pointer%> wird für dieses Ziel nicht unterstützt"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "%<__builtin_set_thread_pointer%> wird für dieses Ziel nicht unterstützt"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr "%qs wird nur in OpenACC-Code unterstützt"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr "Nicht konstantes Argument 0 für %qs"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr "ungültiges Argument 0 für %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kungültige Verwendung von %<__builtin_va_arg_pack ()%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kungültige Verwendung von %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "Zweites Argument für %<__builtin_longjmp%> muss 1 sein"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "Zielformat unterstützt nicht »unendlich«"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> in Funktion mit fester Parameteranzahl verwendet"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "falsche Anzahl der Argumente für Funktion %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> ohne Argument gerufen"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "falsche Anzahl der Argumente für Funktion %<__builtin_next_arg%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "Zweiter Parameter von %<va_start%> ist nicht letztgenanntes Argument"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "undefiniertes Verhalten, wenn zweiter Parameter von %<va_start%> mit %<register%>-Speicherklasse deklariert wird"
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kerstes Argument von %qD muss ein Zeiger, das zweite eine Ganzzahlkonstante sein"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Kletztes Argument von %qD ist keine Ganzzahlkonstante zwischen 0 und 3"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr "%K%qD wird mit Zeiger %qE mit Offset%s ungleich 0 aufgerufen"
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "hier deklariert"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, gcc-internal-format
 msgid "returned from %qD"
 msgstr "zurückgegeben von %qD"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, gcc-internal-format
 msgid "returned from %qT"
 msgstr "zurückgegeben von %qT"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, gcc-internal-format
 msgid "obtained here"
 msgstr "von hier erhalten"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr "%K%qD wird auf nicht alloziertem Objekt %qD aufgerufen"
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr "%K%qD wird mit Zeiger auf nicht alloziertes Objekt %qE aufgerufen"
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, gcc-internal-format
 msgid "assigned here"
 msgstr "hier zugewiesen"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr "%K%qD wird mit Zeiger aufgerufen, der aus einer unpassenden Allozierungsfunktion stammt"
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr "%K%qD wird mit nicht alloziertem Zeiger aufgerufen"
@@ -22393,302 +22403,302 @@ msgstr "Interner Fehler: basic blocks not laid down consecutively"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "Interner Fehler: number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "Interner Fehler: caller edge count invalid"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr "fehlender indirekter Aufruf in der Folge der spekulativen Aufrufe"
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr "indirekter Aufruf in der Folge der spekulativen Aufrufe hat kein Spekulationsflag"
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr "spekulative Kanten sind nicht benachbart"
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr "der direkte Aufruf von %s in der Folge der spekulativen Aufrufe hat kein Spekulationsflag"
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr "der direkte Aufruf von %s in der Folge der spekulativen Aufrufe hat speculative_id %i außerhalb des Bereichs"
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr "doppelter direkter Aufruf von %s in der Folge der spekulativen Aufrufe mit speculative_id %i"
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr "der Hash der Aufrufanweisung zeigt nicht auf die erste direkte Kante der Folge von spekulativen Aufrufen"
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr "doppelter Verweis %s in der Folge der spekulativen Aufrufe mit speculative_id %i"
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "missing direct call for speculation %i"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "missing ref for speculation %i"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr "Anzahl der spekulativen Ziele %i stimmt nicht mit num_speculative_call_targets %i überein"
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "Interner Fehler: aux field set for edge %s->%s"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "Interner Fehler: cgraph count invalid"
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "Interner Fehler: inline clone in same comdat group list"
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "inline clone count is not compatible"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "tp_first_run must be non-negative"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "Interner Fehler: local symbols must be defined"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "Interner Fehler: externally visible inline clone"
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "Interner Fehler: inline clone with address taken"
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "Interner Fehler: inline clone is forced to output"
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr "calls_comdat_local wird außerhalb einer comdat-Gruppe gesetzt"
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr "ungültiger Schalter »calls_comdat_local«"
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "Attribut %<malloc%> ist nur an Funktionen sinnvoll, die einen Zeiger zurückgeben"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "Interner Fehler: aux field set for indirect edge from %s"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "edge count is not compatible with function count"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Interner Fehler: An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr "Kante hat sowohl call_stmt als auch lto_stmt_uid gesetzt"
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "Interner Fehler: comdat-local function called by %s outside its comdat"
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "Interner Fehler: inlined_to pointer is wrong"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "Interner Fehler: multiple inline callers"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "Interner Fehler: inlined_to pointer set for noninline callers"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "Interner Fehler: caller edge count does not match BB count"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "Interner Fehler: indirect call count does not match BB count"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr "Verweis hat sowohl stmt als auch lto_stmt_uid gesetzt"
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "Interner Fehler: inlined_to pointer is set but no predecessors found"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Interner Fehler: inlined_to pointer refers to itself"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "Interner Fehler: cgraph_node has wrong clone_of"
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "Interner Fehler: cgraph_node has wrong clone list"
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "Interner Fehler: cgraph_node is in clone list but it is not clone"
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "Interner Fehler: cgraph_node has wrong prev_clone pointer"
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "Interner Fehler: double linked list of clones corrupted"
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Interner Fehler: Alias has call edges"
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Interner Fehler: Alias has non-alias reference"
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Interner Fehler: Alias has more than one alias reference"
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Interner Fehler: Analyzed alias has no reference"
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Interner Fehler: No edge out of thunk node"
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Interner Fehler: More than one edge out of thunk node"
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Interner Fehler: Thunk is not supposed to have body"
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "Interner Fehler: shared call_stmt:"
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "Interner Fehler: edge points to wrong declaration:"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "Interner Fehler: an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "Interner Fehler: missing callgraph edge for call stmt:"
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "Interner Fehler: reference to dead statement"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "Interner Fehler: edge %s->%s has no corresponding call_stmt"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "Interner Fehler: an indirect edge from %s has no corresponding call_stmt"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr "fehlender Ursprung für einen Knoten in einer verschachtelten Liste"
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "origin points to a different parent"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "Interner Fehler: verify_cgraph_node failed"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s: section %s.%d is missing"
@@ -22769,12 +22779,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "Attribut %<weakref%> ignoriert, da Variable bereits initialisiert ist"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F verwendet, aber nirgendwo definiert"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F als %<static%> deklariert, aber nirgendwo definiert"
@@ -22844,7 +22854,7 @@ msgstr "Größe des Rückgabewertes von %q+D ist %u Bytes"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "Größe des Rückgabewertes von %q+D ist größer als %wu Bytes"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "Knoten mit nicht freigegebenem Speicher gefunden"
@@ -23248,12 +23258,12 @@ msgstr "möglicherweise in Konflikt stehende Option %<-fopt-info-%s%> wird ignor
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr "Mehrere EH-Persönlichkeiten werden nur mit Assemblern unterstützt, die die Direktive %<.cfi_personality%> unterstützen"
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr "%<-gdwarf-6%> wird als Version 5 ausgegeben, mit Inkompatibilitäten"
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "Nicht-Delegitimiertes UNSPEC %s (%d) am Variablenort gefunden"
@@ -23273,7 +23283,7 @@ msgstr "Gemeinsames rtx"
 msgid "internal consistency failure"
 msgstr "internes Konsistenzproblem"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn verwendet, wo emit_jump_insn erforderlich:\n"
@@ -23404,42 +23414,42 @@ msgstr "endgültige Abzugsdatei %qs der Befehle konnte nicht geschlossen werden:
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "große Festkommakonstante implizit auf Festkommatypen abgeschnitten"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "Vergleich ist immer %d wegen Breite des Bitfeldes"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Bereichsprüfung vereinfacht wird"
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "Vergleich ist immer %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<oder%> bei nicht passenden Ungleichheits-Tests ist immer 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<und%> bei sich gegenseitig ausschließenden Gleichheits-Tests ist immer 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Konstante in Vergleich verringert wird"
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Konstanten um einen Vergleich kombiniert werden"
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "Faltungstest: ursprünglicher Baum durch Faltung geändert"
@@ -23454,7 +23464,7 @@ msgstr "Gesamtgröße der lokalen Objekte %wu überschreitet das Maximum %wu"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "Gesamtgröße der lokalen Objekte überschreitet das Maximum %wu"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "unmögliche Bedingung in %<asm%>"
@@ -24070,7 +24080,7 @@ msgstr "Dereferenzierung eines Nullzeigers"
 msgid "function may return address of local variable"
 msgstr "Funktion liefert möglicherweise Adresse einer lokalen Variablen zurück"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "Funktion liefert Adresse einer lokalen Variablen zurück"
@@ -24436,53 +24446,53 @@ msgstr "angegebene Grenze %wu überschreitet die Größe %wu des Zielobjekts"
 msgid "%Gnull format string"
 msgstr "%GNULL-Formatzeichenkette"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 msgid "%Guse of %<alloca%>"
 msgstr "%GVerwendung von %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 msgid "%Gargument to variable-length array may be too large"
 msgstr "%GArgument für Array mit variabler Länge könnte zu groß sein"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "%GArgument für %<alloca%> könnte zu groß sein"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr "Grenze ist %wu Bytes, Argument hat jedoch bis zu %s Bytes"
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 msgid "%Gargument to variable-length array is too large"
 msgstr "%GArgument für Array mit variabler Länge ist zu groß"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "%GArgument für %<alloca%> ist zu groß"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr "Grenze ist %wu Bytes, Argument hat jedoch %s Bytes"
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 msgid "%Gunbounded use of variable-length array"
 msgstr "%Gunbegrenzte Verwendung von Array mit variabler Länge"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "%Gunbegrenzte Verwendung von %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "%GVerwendung von %<alloca%> innerhalb einer Schleife"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 msgid "%Gargument to variable-length array is zero"
 msgstr "%GArgument für Array variabler Länge ist 0"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 msgid "%Gargument to %<alloca%> is zero"
 msgstr "%GArgument für %<alloca%> ist 0"
 
@@ -24596,7 +24606,7 @@ msgstr "%Gdurch %qD angegebene Grenze zwischen %wu und %wu überschreitet maxima
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr "%G%qD Zeigerüberlauf zwischen Offset %s und Größe %s beim Zugriff auf Array %qD mit Typ %qT"
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "Array %qD ist hier deklariert"
@@ -24622,11 +24632,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "%G%qD Offset %s ist außerhalb der Grenzen von Objekt %qD mit Typ %qT"
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD ist hier deklariert"
@@ -24701,309 +24711,309 @@ msgstr "%<fallthrough%>-Attribut ist nicht direkt vor einer case-Marke oder eine
 msgid "using result of function returning %<void%>"
 msgstr "Ergebnis einer %<void%> zurückgebenden Funktion verwendet"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr "Nicht-Speicher-Ausgabe %d muss im Speicher bleiben"
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "ungültiger L-Wert in %<asm%>-Ausgabe %d"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "Eingabe von Nicht-Speicher %d muss im Speicher bleiben"
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "Speichereingabe %d ist nicht direkt adressierbar"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "threadprivate Variable %qE in Zielregion mit %<order(concurrent)%>-Klausel verwendet"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, gcc-internal-format
 msgid "enclosing region"
 msgstr "umgebende Region"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "threadprivate Variable %qE in Zielregion verwendet"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "umgebende Zielregion"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "threadprivate Variable %qE in unverknüpfter Task verwendet"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "umgebende Task"
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE in umgebendem %qs nicht angegeben"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "umgebendes %qs"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE in umgebendem OpenACC-%qs-Konstrukt nicht angegeben"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "umgebendes OpenACC-%qs-Konstrukt"
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE mit %<link%>-Klausel wird in %<routine%>-Funktion verwendet"
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE erfordert eine %<declare%>-Direktive, um in einer %<routine%>-Funktion verwendet zu werden"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "%qE in umgebendem %<target%> nicht angegeben"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr "umgebendes %<target%>"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "Variable %qE in umgebender %<host_data%>-Region deklariert"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "Zielregion verweist auf %qD, aber der Ausdruck hat keinen zuordenbaren Typ"
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "Iterationsvariable %qE ist vorbestimmt linear"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "Schleifenvariable %qE sollte »private« sein"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "Schleifenvariable %qE sollte nicht »firstprivate« sein"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "Schleifenvariable %qE sollte nicht Reduktion sein"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "Iterationsvariable %qE sollte nicht »linear« sein"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr "bedingte %<lastprivate%>-Klausel im %qs-Konstrukt"
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "nichtskalare Variable %qD in bedingter %<lastprivate%>-Klausel"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr "%<task%>-Reduktionsmodifizierer bei einem Konstrukt mit %<nowait%>-Klausel"
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr "ungültiger %<task%>-Reduktionsmodifizierer bei Konstrukt außer %<parallel%>, %qs oder %<sections%>"
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "%<inscan%>-%<reduction%>-Klausel am %qs-Konstrukt"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%>-Klausel für Variable, die keine Schleifeniterationsvariable ist, wurde für ein mit %<distribute%> kombiniertes Konstrukt angegeben"
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "Feld %qE der Struktur variabler Länger wird zugeordnet"
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE tritt in Mapklauseln mehrfach auf"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "»copyprivate«-Variable %qE ist im äußeren Kontext weder »threadprivate« noch »private«"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "»%s«-Variable %qE ist im äußeren Kontext »private«"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%qs %<if%>-Klausel-Modifizierer anstelle %qs erwartet"
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr "%qD wurde in %qs-Klausel angegeben, aber nicht in %<inscan%>-%<reduction%>-Klausel am enthaltenden Konstrukt"
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD in implizier %<map%>-Klausel"
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD in impliziter %<firstprivate%>-Klausel am %<target%>-Konstrukt"
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD in %<firstprivate%>-Klausel am %<target%>-Konstrukt"
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "selbe Variable wird in %<firstprivate%>- und %<lastprivate%>-Klauseln am %<distribute%>-Konstrukt"
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "inkompatible Datenklausel mit Reduktion an %qE; wird zu %<present_or_copy%> befördert"
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr "%qD ist in %<inscan%>-%<reduction%>-Klausel angegeben, aber nicht in %<scan%>-Direktivenklausel"
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "ungültige »private«-Reduktion auf %qE"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "%<inscan%>-%<reduction%>-Klausel wird zusammen mit %<linear%>-Klausel an einer Variable verwendet, die kein Schleifeniterator ist"
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "%<mutexinoutset%>-Art in %<depend%>-Klausel bei einem %<taskwait%>-Konstrukt"
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr "%qs-Klausel darf nur bei rechteckigen %qs vorkommen"
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "bedingte %<lastprivate%>-Klausel an Schleifeniterator %qD wird ignoriert"
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "%<bind%>-Klausel nicht auf einem %<loop%>-Konstrukt, das nicht in einem anderen OpenMP-Konstrukt geschachtelt ist"
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "%<bind(parallel)%> an einem %<loop%>-Konstrukt, das in einem %<simd%>-Konstrukt geschachtelt ist"
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "%<bind(teams)%> an einer %<loop%>-Region, die nicht streng innerhalb einer %<teams%>-Region geschachtelt ist"
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "%<lastprivate%>-Klausel an einem %<loop%>-Konstrukt bezieht sich auf eine Variable %qD, die nicht der Schleifeniterator ist"
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%>-Konstrukt mit %<depend%>-Klausel muss innerhalb einer Schleife mit %<ordered%>-Klausel und Parameter eng geschachtelt sein"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "Variable %qE ist keine Iteration der äußersten Schleife %d, jedoch %qE erwartet"
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "Anzahl der Variablen in %<depend%>-Klausel mit %<sink%>-Modifizierer passt nicht zur Anzahl der Iterationsvariablen"
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "mehr als eine %<depend%>-Klausel mit %<source%>-Modifizierer an einem %<ordered%>-Konstrukt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79999
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "%<depend%>-Klausel mit %<source%>-Modifizierer zusammen mit %<depend%>-Klauseln mit %<sink%>-Modifizierer an demselben Konstrukt"
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "Gimplifikation gescheitert"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT auf %qT erweitert beim Durchlaufen von %<...%>"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(Es sollte also %qT statt %qT an %<va_arg%> übergeben werden)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Wenn dieser Code erreicht wird, wird das Programm abgebrochen"
@@ -25452,22 +25462,22 @@ msgstr "Die Funktion %qs, Parameter %u, hat IPA-SRA-Zugriffe, die sich überlapp
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr "Funktion %s, Parameter %u, wird verwendet, hat aber keinen bestimmten IPA-SRA-Zugriff"
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr "»%s« kann nicht hier in %<asm%> verwendet werden"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr "Rahmenzeiger benötigt, aber reserviert"
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr "für %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "Rahmengröße zu groß für zuverlässige Stapelüberprüfung"
@@ -25487,12 +25497,12 @@ msgstr "%<asm%>-Operand hat unmögliche Nebenbedingungen"
 msgid "unable to find a register to spill"
 msgstr "Kein Register zum Auslagern gefunden"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "inkonsistente Operandenbedingungen in einem %<asm%>"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "Höchstzahl der erzeugten Neuladebefehle pro Befehl ist erreicht (%d)"
@@ -26200,12 +26210,12 @@ msgstr "Argument von %qs ist nicht zwischen %d und %d"
 msgid "unrecognized argument in option %qs"
 msgstr "nicht erkanntes Kommandozeilenargument in Option %qs"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %qs sind: %s; meinten Sie %qs?"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "gültige Argumente für %qs sind: %s"
@@ -26330,7 +26340,7 @@ msgstr "transaktionsbasierter Speicher wird von Nicht-Aufruf-Ausnahmen nicht unt
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr "Abschnittsanker müssen ausgeschaltet sein, wenn Toplevel-Neuordnung ausgeschaltet ist"
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> funktioniert auf dieser Architektur nicht mit Ausnahmen"
@@ -26839,25 +26849,25 @@ msgid "output operand %d must use %<&%> constraint"
 msgstr "Ausgabeoperand %d muss %<&%>-Bedingung verwenden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93748
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "%s: [%u] Falsches %<next_regno%> für leere Kette (%u)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93748
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "%s: Zyklus in %<next_regno%>-Kette (%u)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93748
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "%s: [%u] Falsches %<oldest_regno%> (%u)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93748
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr "%s: [%u] Nicht leeres Register in Kette (%s %u %i)"
@@ -26919,12 +26929,12 @@ msgstr "Ganzzahlkonstantenoperand kann in %<asm%> nicht neu geladen werden"
 msgid "impossible register constraint in %<asm%>"
 msgstr "unmögliche Registerbedingung in %<asm%>"
 
-#: reload.c:2687
+#: reload.c:2692
 #, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "dieses Ziel unterstützt nicht %<asm goto%> mit Ausgaben in %<asm%>"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "%<&%>-Bedingung ohne Registerklasse verwendet"
@@ -26954,53 +26964,53 @@ msgstr "%<asm%>-Operandenbedingung inkompatibel mit Operandengröße"
 msgid "output operand is constant in %<asm%>"
 msgstr "Ausgabeoperand ist in %<asm%> konstant"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "Interner Fehler: RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "Interner Fehler: RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "Interner Fehler: RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "Interner Fehler: RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "Interner Fehler: RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "Interner Fehler: RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "Interner Fehler: RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "Interner Fehler: RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "Interner Fehler: RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "Interner Fehler: RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
@@ -27045,22 +27055,22 @@ msgstr "dazu passende Bedingung referenziert ungültige Operandennummer"
 msgid "invalid punctuation %qc in constraint"
 msgstr "ungültiges Zeichen %qc in Bedingung"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "dazu passende Bedingung erlaubt kein Register"
 
-#: stmt.c:524
+#: stmt.c:525
 #, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "doppelter %<asm%>-Operandenname %qs"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "schließende geschweifte Klammer für benannten Operanden fehlt"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "benannter Operand %qs ist nicht definiert"
@@ -27765,9 +27775,9 @@ msgstr "ungültiger Operand für %qs"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "unverträgliche Typen in %qs"
@@ -27802,7 +27812,7 @@ msgstr "ungültiger Offset-Operand in %qs"
 msgid "invalid clique in %qs"
 msgstr "ungültige Clique in %qs"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr "%qs in GIMPLE-IL"
@@ -28008,385 +28018,385 @@ msgstr "ungültige Operanden in ternärer Operation"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "das erste Argument eines %qs muss von booleschem Vektortyp sein und gleich viele Elemente wie das Ergebnis haben"
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "Vektortypen erwartet in %qs"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "Vektoren unterschiedlicher Elementanzahl in %qs gefunden"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "ungültiger Maskentyp in %qs"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "unerlaubte Typkombination in %qs"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "ungültige Position oder Größe in %qs"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "%qs in non-mode-precision Operanden"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "Einschub außerhalb des gültigen Bereichs in %qs"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qs nicht an Elementgrenze"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "nicht-triviale Umwandlung in %qs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "%s auf der linken Seite einer Clobber-Anweisung"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "ungültiger Operand in %qs"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "ungültige rechte Seite für GIMPLE-Speicherung: %qs"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "ungültiger Typ der Vektor-%qs-Elemente"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "falsche Anzahl der Vektor-%qs-Elemente"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "falscher Typ der Elemente eines Vektorkonstruktors"
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr "Vektor-%qs mit Elementindex, der nicht NULL ist"
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "%qs-Element des Vektors ist kein GIMPLE-Wert"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "%qs mit Elementen ist kein Vektor"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr "%qs mit immer falscher Bedingung"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "ungültiger Operand in »return«-Anweisung"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "ungültige Umwandlung in »return«-Anweisung"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "Goto-Ziel ist weder eine Marke noch ein Zeiger"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "ungültiger Operand für switch-Anweisung"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "switch-Anweisung ohne eingebauten Typ"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "ungültige %<default%>-Sprungmarke in switch-Anweisung"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "ungültiges %<CASE_CHAIN%>"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "ungültige »case«-Marke in switch-Anweisung"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "ungültiger »case«-Bereich in switch-Anweisung"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "unpassende Präzision für Typ in switch-Anweisung"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "unpassender Typ für »case«-Marke in switch-Anweisung"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "unsortierte case-Marken in switch-Anweisung"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "der Label-Kontext ist nicht die aktuelle Funktionsdeklaration"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "falscher Eintrag in %<label_to_block_map%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "incorrect setting of landing pad number"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "invalid comparison code in gimple cond"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "Ungültiger Marken in GIMPLE-Bedingung"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "ungültiges %<PHI%>-Ergebnis"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93852
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "fehlende %<PHI%>-Definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "ungültiges %<PHI%>-Argument"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "inkompatible Typen in %<PHI%>-Argument %u"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "%<verify_gimple%> failed"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "unerreichbare Anweisung in EH-Tabelle"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "location references block not in block tree"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "local declaration from a different function"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) is set to a wrong basic block"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "PHI node with location"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "incorrect sharing of tree nodes"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "virtual PHI with argument locations"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) is set to a wrong basic block"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "Anweisung für throw markiert, wirft jedoch nichts"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "Anweisung inmitten eines Blocks für throw markiert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple failed"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK has IL associated with it"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK has IL associated with it"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fallthru to exit from bb %d"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "nichtlokale Marke "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH Landefeld-Marke "
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "Marke "
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "control flow in the middle of basic block %d"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "Fallthru-Kante hinter einer Kontrollanweisung in bb %d"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "Wahr/Falsch-Kante hinter einer Nicht-GIMPLE_COND in bb %d"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "Falsche ausgehende Kantenmarken am Ende des bb %d"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "Explizites Goto am Ende von bb %d"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "Return-Kante zeigt nicht auf Ausgang in bb %d"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "Standard-Fall nicht am Anfang des case-Vektors gefunden"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "Case-Marken nicht sortiert: "
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "Zusätzliche ausgehende Kante %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "Fehlende Kante %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>-Funktion kehrt zurück"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "Kontrollfluss erreicht Ende von Nicht-void-Funktion"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "Der Rückgabewert von %qD, der mit dem Attribut %<warn_unused_result%> deklariert wurde, wird ignoriert"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "Rückgabewert der mit dem Attribut %<warn_unused_result%> definierten Funktion wird ignoriert"
@@ -29487,7 +29497,7 @@ msgstr "Thread-lokale COMMON-Daten nicht implementiert"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "angeforderte Ausrichtung für %q+D ist größer als die implementierte Ausrichtung von %wu"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "Speichergröße von %q+D ist unbekannt"
@@ -29648,7 +29658,7 @@ msgstr "Bytecode-Strom: Marke %s statt %s erwartet"
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "bytecode stream: tag %s is not in the expected range [%s, %s]"
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, gcc-internal-format
 msgid "unsupported record layout"
 msgstr "nicht unterstütztes Record-Layout"
@@ -30252,7 +30262,7 @@ msgstr "Attribut %qE folgt auf %qE"
 msgid "type was previously declared %qE"
 msgstr "Typ war vorher als %qE deklariert"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> kann nur für virtuelle Funktionen angegeben werden"
@@ -30272,7 +30282,7 @@ msgstr "%qD ist mit %qD unverträglich"
 msgid "%qE argument is not a function"
 msgstr "Argument %qE ist keine Funktion"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "Veraltete Meldung ist keine Zeichenkette"
@@ -30700,12 +30710,12 @@ msgstr "%<?:%> mit Ganzzahlkonstanten in booleschem Kontext"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "der Compiler kann davon ausgehen, dass die Adresse von %qD immer zu %<true%> evaluiert"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "Um Zuweisung, die als Wahrheitswert verwendet wird, werden Klammern empfohlen"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "Ungültige Verwendung von %<restrict%>"
@@ -30866,13 +30876,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "%<fallthrough%>-Attribut mit einem Parameter angegeben"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "Zu wenige Argumente für Funktion %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "zu viele Argumente für Funktion %qE"
@@ -31807,7 +31817,7 @@ msgstr "nicht unterstützte Nicht-Standard-Verkettung von Zeichenkettenliteralen
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionelles C weist Zeichenkettenkonstantenverkettung zurück"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> mit %<hint%>-Klausel erfordert einen Namen, außer wenn %<omp_sync_hint_none%> verwendet wird"
@@ -31858,7 +31868,7 @@ msgstr "%<depobj%>-Abhängigkeitstyp in %<depend%>-Klausel von %<depobj%> angege
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<iterator%>-Modifizierer darf nicht bei einem %<depobj%>-Konstrukt angegeben sein"
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ungültiger Typ für Schleifenvariable %qE"
@@ -31873,17 +31883,17 @@ msgstr "%<_Atomic%>-Iterationsvariable %qE"
 msgid "%qE is not initialized"
 msgstr "%qE ist nicht initialisiert"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Steuerprädikat fehlt"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Steuerprädikat ungültig"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "Erhöhungsausdruck fehlt"
@@ -31893,7 +31903,7 @@ msgstr "Erhöhungsausdruck fehlt"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "Erhöhung ist weder konstant 1 noch konstant -1 für die %<!=%>-Bedingung"
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Erhöhungsausdruck ungültig"
@@ -31958,7 +31968,7 @@ msgstr "ungültiger %<task%>-Reduktionsmodifizierer in Konstrukt, das nicht mit
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr "%<inscan%>-%<reduction%>-Klausel bei Konstruktion außer %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr "%qD ist in %<allocate%>-Klausel angegeben, aber nicht in einer expliziten Privatisierungs-Klausel"
@@ -32523,8 +32533,8 @@ msgstr "<Rückgabewert>"
 msgid "wrong type argument to %s"
 msgstr "Argument falschen Typs für %s"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "Überlauf in Konstanten-Ausdruck"
@@ -33010,17 +33020,17 @@ msgstr "Verringerung der Funktion %qD"
 msgid "function %qD used as %<asm%> output"
 msgstr "Funktion %qD als %<asm%>-Ausgabe verwendet"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "Zuweisung der schreibgeschützten Speicherstelle %qE"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "Erhöhung der schreibgeschützten Speicherstelle %qE"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "Verringerung der schreibgeschützten Speicherstelle %qE"
@@ -33200,8 +33210,8 @@ msgstr "%<memset%> mit konstanter Länge 0 verwendet; das könnte heißen, dass
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr "im Aufruf von %<memset%> ist die Länge gleich der Anzahl der Elemente angegeben, ohne sie mit der Elementgröße zu multiplizieren"
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "Vergleich zwischen den Typen %qT und %qT"
@@ -33277,158 +33287,158 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "Argument %i wird an den mit %qs qualifizierten Parameter übergeben, dadurch wird es zum Alias für Argument %Z"
 msgstr[1] "Argument %i wird an den mit %qs qualifizierten Parameter übergeben, dadurch wird es zum Alias für die Argumente %Z"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "diese Bedingung hat identische Zweige"
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr "Makro expandiert zu mehreren Anweisungen"
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr "Einige Teile des expandierten Makros sind nicht von diesem %qs-Konstrukt erfasst"
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr "die Umwandlung eines gepackten Zeigers auf %qT (Ausrichtung %d) in einen Zeiger auf %qT (Ausrichtung %d) führt möglicherweise zu einem nicht ausgerichteten Zeiger"
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, gcc-internal-format
 msgid "defined here"
 msgstr "hier definiert"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr "Zugriff auf die Adresse des gepackten Elements von %qT führt möglicherweise zu einem nicht ausgerichteten Zeigerwert"
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "Abweichung in Grenze %Z von Argument %u, deklariert als %s"
 msgstr[1] "Abweichung in Grenzen %Z von Argument %u, deklariert als %s"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr "vorher als %s deklariert"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "Argument %u vom Typ %s ist als Array variabler Länge deklariert"
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
 msgstr "war vorher als Zeiger %s deklariert"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
 msgstr "war vorher als gewöhnliches Array %s deklariert"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr "Argument %u vom Typ %s ist als Zeiger deklariert"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr "war vorher als Array variabler Länge %s deklariert"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr "war vorher als Array %s deklariert"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr "Argument %u vom Typ %s ist als gewöhnliches Array deklariert"
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] "Argument %u vom Typ %s ist mit %u Variablengrenze deklariert"
 msgstr[1] "Argument %u vom Typ %s ist mit %u Variablengrenzen deklariert"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "war vorher als %s mit %u Variablengrenze deklariert"
 msgstr[1] "war vorher als %s mit %u Variablengrenzen deklariert"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] "Argument %u vom Typ %s ist mit %u unspezifizierten Variablengrenze deklariert"
 msgstr[1] "Argument %u vom Typ %s ist mit %u unspezifizierten Variablengrenzen deklariert"
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] "war vorher als %s mit %u unspezifizierten Variablengrenze deklariert"
 msgstr[1] "war vorher als %s mit %u unspezifizierten Variablengrenzen deklariert"
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] "war später als %s mit %u unspezifizierten Variablengrenze deklariert"
 msgstr[1] "war später als %s mit %u unspezifizierten Variablengrenze deklariert"
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr "Argument %u vom Typ %s ist mit abweichendem Grenzargument %E deklariert"
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "Argument %u vom Typ %s ist mit abweichender Grenze %<%s%> deklariert"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr "war vorher als %s deklariert, mit Grenzargument %E"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "war vorher als %s deklariert, mit Grenze %qs"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr "war vorher als %s deklariert, mit Grenze %qs"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr "Argument %u vom Typ %s mit abweichender Grenze"
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr "Ausdruck berechnet nicht die Anzahl der Elemente in diesem Array; der Elementtyp ist %qT, nicht %qT"
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr "klammern Sie den Ausdruck %qE, um diese Warnung zu unterdrücken"
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr "klammern Sie den zweiten %<sizeof%>-Ausdruck, um diese Warnung zu unterdrücken"
@@ -33443,7 +33453,7 @@ msgstr "%qs ist keine gültige Präprozessoroption"
 msgid "too many input files"
 msgstr "zu viele Eingabedateien"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "unbekannter Wert %qs für %<-mcpu%>"
@@ -33474,14 +33484,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "unbekannte Option an %%:target_mode_check weitergegeben"
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "gültige Argumente sind: %s; meinten Sie %qs?"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "gültige Argumente sind: %s"
@@ -33633,62 +33643,62 @@ msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 3
 msgstr "für die Option %<-mcache-block-size=X%> sind nur die Werte 4, 8, 16, 32, 64, 128, 256 oder 512 gültig"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99291
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr "%<-march=%s%>: Erweiterung %qs kommt mehr als einmal vor."
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "%<-march=%s%> erfordert eine Zahl nach %<%dp%>."
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "%<-march=%s%>: rv%de ist keine gültige Basis-ISA"
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr "Version von %<g%> wird weggelassen, bitte geben Sie die Version für die individuelle Erweiterung an."
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr "%<-march=%s%>: erste ISA-Teilmenge muss %<e%>, %<i%> oder %<g%> sein"
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr "%<-march=%s%>: nicht unterstützte ISA-Teilmenge %<%c%>"
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr "%<-march=%s%>: ISA-Zeichenkette ist nicht in kanonischer Reihenfolge. %<%c%>"
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>: Name von %s muss mehr als 1 Buchstabe sein"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%>: %s müssen durch _ getrennt sein"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "%<-march=%s%>: ISA-Zeichenkette muss mit %<rv32%> oder %<rv64%> anfangen"
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr "%<-march=%s%>: unerwartete ISA-Zeichenkette am Ende: %qs"
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<-mcpu=%s%>: unbekannte CPU"
@@ -33850,91 +33860,90 @@ msgstr "%s steht in Konflikt mit ppc (arch-Flags werden ignoriert)"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr "%s steht in Konflikt mit ppc64 (arch-Flags werden ignoriert)"
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "temporäre Datei %s konnte nicht für LTO-Ausgaben geöffnet werden"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "%qE 2.95 vtable-Kompatibilitätsattribut trifft nur zu, wenn ein »kext« kompiliert wird"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "%qE 2.95 vtable-Kompatibilitätsattribut trifft nur für C++-Klassen zu"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "geschützte Sichtbarkeitsattribute werden in dieser Konfiguration nicht unterstützt; ignoriert"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "temporäre Datei %s konnte nicht mit LTO-Ausgabe geöffnet werden"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> 2 muss für 64-Bit-Ziele mit %<-fnext-runtime%> verwendet werden"
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> %d wird für 32-Bit-Ziele mit %<-fnext-runtime%> nicht unterstützt"
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "%<-gsplit-dwarf%> wird für dieses Ziel nicht unterstützt, wird ignoriert"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "%<-mdynamic-no-pic%> übersteuert %<-fpic%>, %<-fPIC%>, %<-fpie%> oder %<-fPIE%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93831
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr "%<-mpic-symbol-stubs%> ist für 64-Bit-Code nicht erforderlich (ignoriert)"
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "eingebaute Funktion %qD erfordert das Kennzeichen %<-mconstant-cfstrings%>"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "eingebaute Funktion %qD nimmt nur ein Argument"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "CFString-Literal fehlt"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "CFString-Literalausdruck ist keine Zeichenkettenkonstante"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr "Nicht-ASCII-Zeichen in CFString-Literal"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr "eingebettetes NUL in CFString-Literal"
 
-# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99733
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "%<munmap%> von %<pch_address_space%> fehlgeschlagen: %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34070,373 +34079,373 @@ msgstr "%<#pragma GCC aarch64%> erfordert eine Zeichenkette als Parameter"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "unbekannte Option %qs für %<#pragma GCC aarch64%>"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "das Attribut %qE kann nicht auf einen SVE-Funktionstyp angewendet werden"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "unerwartetes %<%s%> nach %<%s%>"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs verträgt sich nicht mit der Verwendung von Gleitkommatypen"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs verträgt sich nicht mit der Verwendung von Vektortypen"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "Feature-Modifizierer %qs verträgt sich nicht mit der Verwendung von Gleitkommatypen"
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "Feature-Modifizierer %qs verträgt sich nicht mit der Verwendung von Vektortypen"
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "diese Operation erfordert die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "Sie können SVE mit der Befehlszeilenoption %<-march%>, oder mit dem Attribut %<target%> oder Pragma aktivieren"
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "Argumente vom Typ %qT erfordern die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "der SVE-Typ %qT kann nur an prototypisierte Funktionen übergeben werden"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 9.1 geändert"
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "%qE benötigt die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "Aufrufe von Funktionen vom Typ %qT erfordern die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "Stapelsonde für SVE-Rahmen"
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "unbekanntes Flag wurde in %<-moverride=%s%> übergeben (%s)"
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "Zeichenkette für %s falsch geformt\n"
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "ungültiges Format für sve_width"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "ungültiger Wert für sve_width: %d"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Tuning-Zeichenkette fehlt in Option »%s«"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "unbekannte Tuning-Option »%s«"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "die Optionen %<-mstack-protector-guard=global%> und %<-mstack-protector-guard-offset=%s%> sind unverträglich"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90153
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "wenn %<-mstack-protector-guard=sysreg%> angegeben ist, müssen sowohl %<-mstack-protector-guard-offset%> als auch %<-mstack-protector-guard-reg%> angegeben werden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90154
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr "Systemregister mit einem kurzem Namen (weniger als 100 Zeichen) angeben."
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs ist in %qs kein gültiger Offset"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr "nur die Werte 12 (4 kB) und 16 (64 kB) werden für die Wächtergröße unterstützt. Der angegebene Wert %d (%llu kB) liegt außerhalb des gültigen Bereichs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90155
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr "Größe des Stapelkollisionswächters %d muss gleich dem Sondierungsintervall %d sein"
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "gültige Argumente sind: %s;"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "fehlender CPU-Name in %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "unbekannter Feature-Modifizierer %qs in %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "ungültiges Argument für %<-mharden-sls=%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99291
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr "%<%s%> muss für sich allein stehen, für %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "ungültiges Argument %qs für %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "ungültiges Argument %qs für %<-mbranch-protection=%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90157
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "fehlendes Argument für %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "fehlender Architekturname in %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "unbekannter Wert %qs für %<-march%>"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "unbekannter Feature-Modifizierer %qs in %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "fehlender CPU-Name in %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "unbekannter Wert %qs für %<-mtune%>"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "Schalter %<-mcpu=%s%> steht mit dem Schalter %<-march=%s%> in Konflikt"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "Assembler unterstützt %<-mabi=ilp32%> nicht"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr "Signieren der Rückgabeadresse wird nur für %<-mabi=lp64%> unterstützt"
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "Codemodell %qs mit %<-f%s%>"
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "Codemodell %qs wird im ilp32-Modus nicht unterstützt"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "fehlender Name für Pragma oder Attribut %<target(\"arch=\")%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90158
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ungültiger Name (%qs) für Pragma oder Attribut %<target(\"arch=\")%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90158
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "ungültiger Featuremodifizierer %qs mit Wert %qs in Pragma oder Attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "fehlender Name für Pragma oder Attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ungültiger Name (%qs) für Pragma oder Attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "fehlendes Argument für Pragma oder Attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "ungültiger Schutztyp %qs in Pragma oder Attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "ungültiger Name (%qs) für Pragma oder Attribut %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "fehlender Wert für Pragma oder Attribut %<target()%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "falsch geformtes Pragma oder Attribut %<target()%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> akzeptiert keine Argumente"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> erlaubt keine negierte Form"
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "Pragma oder Attribut %<target(\"%s=%s\")%> ist nicht gültig"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "Argument für Attribut %<target%> ist keine Zeichenkette"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> ist nicht gültig"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "falsch geformtes Pragma oder Attribut %<target(\"%s\")%>"
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT mit %<[[no_unique_address]]%>-Elementen hat sich %{in GCC 10.1%} geändert"
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich, sofern C++17 aktiviert ist, so geändert, dass es C++14 %{in GCC 10.1%} entspricht"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79872
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%KSpur %wd außerhalb des Wertebereiches %wd bis %wd"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "Spur %wd ist außerhalb des Wertebereiches %wd bis %wd"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "nicht unterstützte simdlen %wd"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "GCC unterstützt derzeit keine Typen gemischter Größe für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "GCC bietet derzeit keine Unterstützung für Rückgabetyp %qT für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "nicht unterstützter Rückgabetyp %qT für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "GCC bietet derzeit keine Unterstützung für Parametertyp %qT für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "GCC unterstützt derzeit %<simdlen %wd%> für Typ %qT nicht"
@@ -34497,7 +34506,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "falscher Wert %qs für %<-mmemory-latency%>"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -34617,18 +34626,18 @@ msgstr "Argument des Attributes %qE ist weder »ilink1« oder »ilink2«"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "Argument des Attributes %qE ist weder »ilink« oder »firq«"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -35060,225 +35069,230 @@ msgstr "Ziel-CPU unterstützt keine THUMB-Befehle"
 msgid "target CPU does not support unaligned accesses"
 msgstr "Ziel-CPU unterstützt keine unausgerichteten Zugriffe"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "Schalter %<-mcpu=%s%> steht mit dem Schalter %<-march=%s%> in Konflikt"
+
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "%<-mapcs-stack-check%> verträgt sich nicht mit %<-mno-apcs-frame%>"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "%<-fpic%> und %<-mapcs-reent%> sind inkompatibel"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "wiedereinsprungsfähiger APCS-Code nicht unterstützt. Ignoriert"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr "option %<-mstructure-size-boundary%> ist veraltet"
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "Grenze für Strukturgröße kann nur auf 8, 32 oder 64 gesetzt werden"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "Grenze für Strukturgröße kann nur auf 8 oder 32 gesetzt werden"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC ist mit %<-msingle-pic-base%> unverträglich"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "Der FDPIC-Modus wird im Thumb-1-Modus nicht unterstützt"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "%<-mpic-register=%> ist ohne %<-fpic%> nutzlos"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "%qs kann nicht als PIC-Register verwendet werden"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> wird auf dieser Architektur nicht unterstützt"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "die ausgewählten fp16-Optionen sind inkompatibel"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt erfordert ein AAPCS-kompatibles ABI für den richtigen Einsatz"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt ABI erfordert eine iwmmxt-fähige CPU"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "Ziel-CPU unterstützt keine Zusammenarbeit"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS unterstützt nicht %<-mcaller-super-interworking%>"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS unterstützt nicht %<-mcallee-super-interworking%>"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 ohne ldrh"
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "Ziel-CPU unterstützt keine ARMv8-M-Security-Erweiterungen"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr "ARMv8-M Security Extensions sind mit der gewählten FPU inkompatibel"
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
-msgstr "%<-mfloat-abi=hard%>: ausgewählter Prozessor hat keine FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
+msgstr "%<-mfloat-abi=hard%>: ausgewählte Architektur hat keine FPU"
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "%<-mfloat-abi=hard%> und VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "von nicht-AAPCS abgeleitete PCS-Variante"
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "variadische Funktionen müssen die AAPCS-Basisvariante verwenden"
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS-Variante"
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 Hardware-Gleitkomma VFP ABI"
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr "Argument vom Typ %qT ist zusammen mit »-mgeneral-regs-only« nicht erlaubt"
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 7.1 geändert"
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr "Gleitkomma-Register könnten trotz Attribut %qE überschrieben werden: compilieren Sie mit %<-mgeneral-regs-only%>"
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar, die Argumente auf dem Stack übergeben"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar, die variable Anzahl von Argumenten haben"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar, die Argumente auf dem Stack zurückgeben"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "Attribut %qE ignoriert, da die Option %<-mcmse%> nicht angegeben ist."
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "Attribut %qE wirkt sich nicht auf Funktionen mit »static«-Bindung aus"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "Attribut %qE kann nur auf Basistypen von Funktionszeiger angewandt werden"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "Zugriff auf threadlokalen Speicher wird derzeit mit %<-mpure-code%> oder %<-mslow-flash-data%> nicht unterstützt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79871
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K»%s« %wd ist außerhalb des gültigen Bereichs von %wd bis %wd"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79871
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "»%s« %wd ist außerhalb des gültigen Bereichs von %wd bis %wd"
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "Wirkliche Stelle des gestapelten Parameters kann nicht berechnet werden"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Unexpected thumb1 far jump"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "keine unteren Register für das Hervorholen der hohen Register verfügbar"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Interrupt-Dienst-Routinen können nicht im »Thumb-1«-Modus codiert werden"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> für Thumb-1"
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ungültige FPU für Zielattribut oder -pragma %qs"
@@ -35286,22 +35300,22 @@ msgstr "ungültige FPU für Zielattribut oder -pragma %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatische FPU-Auswahl ist hier momentan nicht erlaubt"
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "Ungültige Architektur für Zielattribut oder -pragma %qs"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "Unbekanntes Zielattribut oder -pragma %qs"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "%<asm%>-Schalter werden im Thumb1-Modus nicht unterstützt"
@@ -35380,17 +35394,17 @@ msgstr "%<-fpie%> wird nicht unterstützt"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> wird nicht unterstützt"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "Funktionsattribute %qs und %qs schließen sich gegenseitig aus"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Funktion %qs kann keine Argumente haben"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "Funktion %qs kann keinen Wert zurückgeben"
@@ -36133,132 +36147,132 @@ msgstr "Parameter für eingebaute Funktion muss Zeichenkettenkonstante oder Lite
 msgid "parameter to builtin not valid: %s"
 msgstr "Parameter für eingebaute Funktion ist ungültig: %s"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "Interrupt-Dienst-Routinen können nicht direkt aufgerufen werden"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Das letzte Argument muss ein 2-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fünftes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "drittes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "das letzte Argument muss ein 3-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Das letzte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Das letzte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Das vorletzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Das letzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "das dritte Argument muss eine Vergleichskonstante sein"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "Falscher Vergleichsmodus"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "Falscher Rundungsoperand"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Der direkte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Das direkte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Das direkte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "Selektor muss eine Ganzzahlkonstante im Bereich [0, %wi] sein"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE erfordert unbekannte ISA-Option"
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE erfordert ISA-Option %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Das letzte Argument muss ein 32-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "das letzte Argument muss ein Immediate sein"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "Das letzte muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "Das vierte Argument muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "Falscher Hinweis-Operand"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "Das Argument zum eingebauten %<xabort%> ein 8-Bit-Direktwert sein"
@@ -36278,514 +36292,514 @@ msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "Multiversionierung erfordert %<ifunc%>, was auf diesem Ziel nicht unterstützt wird"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "Codemodell %s unterstützt keinen PIC-Modus"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "Argument von Attribut %qs muss eine Zeichenkette sein"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "beim Attribut %qs ist das Argument %qs unbekannt"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "der Wert %qs wurde bereits im Attribut %qs angegeben"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "Attributwert %qs ist im %qs-Attribut unbekannt"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "falsches Argument %qs für Option %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "Größenbereiche der Option %qs sollten aufsteigend sein"
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "falscher Strategiename %qs für Option %qs angegeben"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "Strategiename %qs für Option %qs angegeben, wird jedoch für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "unbekannte Ausrichtung %qs für Option %qs angegeben"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "der Maximalwert für den letzten Größenbereich sollte für Option %qs -1 sein"
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "zu viele Größenbereiche in Option %qs angegeben"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Unbekannter Parameter für Option %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel-MCU-psABI wird im %s-Modus nicht unterstützt"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> ist veraltet; stattdessen entsprechend %<-mtune=k8%> oder %<-mtune=generic%> verwenden"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> ist veraltet; stattdessen entsprechend %<target(\"tune=k8\")%> oder %<target(\"tune=generic\")%> verwenden"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "Adressmodus %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> wird in der X32-ABI nicht unterstützt"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> wird nicht zusammen mit %<-fsanitize=address%> unterstützt"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> wird nicht zusammen mit %<-fsanitize=kernel-address%> unterstützt"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> wird nicht zusammen mit %<-fsanitize=thread%> unterstützt"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "Codemodell %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "Codemodell %qs wird im x32-Modus nicht unterstützt"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> wird in dieser Konfiguration nicht unterstützt"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-Bit-Modus nicht einkompiliert"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<generic%>-CPU kann nur für %<-mtune=%>-Schalter verwendet werden"
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<generic%>-CPU kann nur für %<target(\"tune=\")%>-Schalter verwendet werden"
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "die CPU %<intel%> kann nur für den Schalter %<-mtune=%> verwendet werden"
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "die CPU %<intel%> kann nur für das Attribut %<target(\"tune=\")%> verwendet werden"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Die ausgewählte CPU unterstützt nicht den x86-64-Befehlssatz"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "falscher Wert (%qs) für Schalter %<-march=%>"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "unbekannter Wert (%qs) für %<target(\"arch=\")%>-Attribut"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-march=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "gültige Argumente für %<-march=%> sind: %s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "falscher Wert (%qs) für Schalter %<-mtune=%>"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "unbekannter Wert %qs für %<target(\"tune=\")%>-Attribut"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"tune=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"tune=\")%> sind: %s"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> wird für Intel-MCU-psABI ignoriert"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> liegt nicht zwischen 0 und %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> wird für dieses Ziel nicht unterstützt"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> liegt nicht zwischen %d und %d"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> liegt nicht zwischen %d und 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> ist für %<-fPIC%> nicht implementiert"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-Befehlssatz ausgeschaltet, es wird 387-Arithmetik verwendet"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-Befehlssatz ausgeschaltet, es wird SSE-Arithmetik verwendet"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<-maccumulate-outgoing-args%> für Korrektheit"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<target(\"accumulate-outgoing-args\")%> für Korrektheit"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "feststehendes ebp-Register erfordert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "feststehendes ebp-Register erfordert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> wird für 32 Bit in Kombination mit %<-fpic%> nicht unterstützt"
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> ist nicht mit SEH verträglich"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> wird derzeit nicht zusammen mit SEH unterstützt"
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "unbekannte Option für %<-mrecip=%s%>"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs ist keine gültige Zahl in %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs ist kein gültiger Offset in %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs ist kein gültiges Basisregister in %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "die Attribute %<interrupt%> und %<naked%> sind nicht kompatibel"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "Nur das DWARF-Debugformat ist für Interrupt-Service-Routinen unterstützt"
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> und %<-fcf-protection%> sind nicht kompatibel"
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> und %<-fcf-protection%> sind nicht kompatibel"
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-Befehle sind in Exception-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-Befehle sind in Interrupt-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-Befehle sind in Funktionen mit %<no_caller_saved_registers%>-Attribut nicht erlaubt"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "Attribute fastcall und regparm sind nicht verträglich"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "Attribute regparam und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "Attribut %qE benötigt eine Ganzzahlkonstante als Argument"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "Argument für Attribut %qE ist größer als %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "Attribute fastcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "Attribute fastcall und stdcall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "Attribute fastcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "Attribute stdcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "Attribute stdcall und fastcall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "Attribute stdcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "Attribute cdecl und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "Attribut %qE wird für Nicht-Klassen-Methode verwendet"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibles Attribut wird ignoriert"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Attribut %qE nur für 32 Bit verfügbar"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Argument des Attributes %qE ist weder Null noch Eins"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "Attribute %qs und %qs sind nicht verträglich"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Argument des Attributes %qE ist nicht (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "in Interrupt-Service-Routinen sollte das erste Argument ein Zeiger sein"
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "in Interrupt-Service-Routinen sollte das zweite Argument vom Typ %qs sein"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "Interrupt-Service-Routine darf nur ein Zeiger- und ein optionales Ganzzahl-Argument haben"
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "Interrupt-Service-Routine muss den Rückgabetyp %<void%> haben"
@@ -37241,7 +37255,7 @@ msgstr "%qE kann nicht gleichzeitig die Attribute %qs und %qs haben"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE mit in Konflikt stehenden Attributen %qs redeklariert"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
@@ -38305,57 +38319,57 @@ msgstr "%<__delay_cycles%> ist auf 32-Bit-Schleifendurchläufe beschränkt"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "unbekannte CPU %qs für %<-mtune%>"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI für abgeflachte Struktur mit Bit-Feldern der Länge 0 hat wurde mit GCC 10 geändert"
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "Argument des Attributs %qE ist weder »user«, noch »supervisor« noch »machine«"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> erfordert %<-march%>, um die %<M%>-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "die angeforderte ABI erfordert %<-march%>, um die %qc-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e erfordert die ilp32e-ABI"
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI erfordert %<-march=rv%d%>"
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> muss zwischen %d und %d liegen"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "%<-mriscv-attribute%> RISC-V-ELF-Attribut erfordert GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs ist in %qs kein gültiges Basisregister"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs ist in %qs keine gültige Zahl"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs-Funktion kann keine andere Interrupt-Art haben"
@@ -38858,240 +38872,240 @@ msgstr "%qs verwendet Register r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Stapelrahmen größer als 2G wird für %<-fsplit-stack%> nicht unterstützt"
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs erfordert %qs oder %qs"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs erfordert PowerPC64-Architektur, wird eingeschaltet"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "%<-mcall-aixdesc%> ist unverträglich mit %<-mabi=elfv2%>"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "%<-m64%> benötigt eine PowerPC64-CPU"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90148
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "%<-mcmodel%> unverträglich mit anderen TOC-Optionen"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "%qs wird in dieser ABI nicht unterstützt"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "%qs wird für 64-Bit-Darwin nicht unterstützt; es ist mit den installierten C- und C++-Bibliotheken unverträglich"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec wird für dieses Ziel nicht unterstützt"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "%qs wird auf »little endian«-Systemen nicht unterstützt"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "power9-Zieloption ist mit %<%s=<xxx>%> für <xxx> kleiner als power9 inkompatibel"
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs inkompatibel mit explizit ausgeschalteten Optionen"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs erfordert %qs"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "Ziel-Attribut oder Pragma ändert Größe von %<long double%>"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%qs erfordert vollständige Unterstützung von ISA 2.06"
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "IEEE %<long double%> mit erweiterter Genauigkeit wird verwendet"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr "IBM %<long double%> mit erweiterter Genauigkeit wird verwendet"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs erfordert VSX-Unterstützung"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr "Die Option %<-mfloat128%> wird möglicherweise nicht vollständig unterstützt"
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs erfordert vollständige Unterstützung von ISA 3.0"
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "unbekannter ABI-Typ (%qs) für Vektorisierungsbibliothek für Schalter %qs"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "Ziel-Attribut oder Pragma ändert AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "Ziel-Attribut oder Pragma ändert darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs erfordert ein gültiges Basisregister"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "unbekannte Option für %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs ist veraltet und wird unter keinen Umständen empfohlen"
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "das Layout von Aggregaten, die Vektoren mit %d-Byte-Ausrichtung enthalten, hat sich in GCC 5 geändert"
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs ist ein undurchsichtiger Typ, und Sie können ihn nicht auf andere Werte setzen."
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "kein Profiling von 64-bit-Code für dieses ABI"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Bei Verwendung der Option %qs kann die Adresse von geschachtelten Funktionen nicht verwendet werden"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "Verwendung von %<long double%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "Verwendung boolescher Typen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "Verwendung von %<complex%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:20055
+#: config/rs6000/rs6000.c:20172
 #, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "Verwendung dezimaler Gleitkommatypen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist veraltet; %<int%> verwenden"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<long long%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<double%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ungültige CPU %qs für %s%qs%s"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ist nicht erlaubt"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s ist ungültig"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> schaltet %<-m%s%> aus"
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "das Attribut %<target_clones%> erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Multiversionierung erfordert »ifunc«, was in dieser Konfiguration nicht unterstützt wird"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "das Ergebnis des Befehls xxspltidp ist für denormalisierte Eingabewerte undefiniert"
@@ -39272,7 +39286,7 @@ msgstr "RX-FPU-Befehle unterstützen keine NaNs und Unendlichkeiten"
 msgid "builtin vec_step can only be used on vector types."
 msgstr "das eingebaute vec_step kann nur mit Vektortypen verwendet werden."
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "Konstanter Wert erwartet für Argument %2$d der eingebauten Funktion %1$qF"
@@ -39342,202 +39356,207 @@ msgstr "%qs-Matchingvariante ist veraltet"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "Konstantes Argument %d für eingebaute %qF liegt außerhalb des Wertebereiches für Zieltyp"
 
+#: config/s390/s390.c:762
+#, gcc-internal-format
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "konstantes Argument %d für eingebautes %qF ist ungültig (%s)"
+
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90180
-#: config/s390/s390.c:743
+#: config/s390/s390.c:766
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "konstantes Argument %d für eingebaute %qF liegt außerhalb des Bereichs 0..%wu"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79846
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "konstantes Argument %d für eingebaute %qF liegt außerhalb des Bereichs %wd..%wd"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr "eingebaute %qF wird nur mit %<-mhtm%> unterstützt (standardmäßig für %<-march=zEC12%> und höher eingeschaltet)"
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr "eingebaute %qF wird nur mit %<-mvx%> unterstützt (standardmäßig für %<-march=z13%> und höher eingeschaltet)"
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr "Eingebaute %qF erfordert z14 oder höher."
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr "Eingebaute %qF erfordert z15 oder höher."
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr "Eingebaute %qF erfordert arch14 oder höher."
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "unaufgelöste überladene eingebaute Funktion"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "Falscher eingebauter ICode"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "Ungültiges Argument %d für eingebaute Funktion %qF"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "das angeforderte %qE-Attribut ist kein kommaseparierter Paar von nichtnegativen ganzzahligen Konstanten, oder es ist zu groß (maximal %d)"
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "Argument für %qE ist nicht (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Gesamtgröße der lokalen Variablen übersteigt Grenze der Architektur"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, größer als benutzerdefinierte Stapelgrenze von %d Bytes. Eine unbedingte Falle wird gesetzt."
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, mehr als die Hälfte der Stapelgröße. Dynamische Prüfung wäre nicht zuverlässig. Für diese Funktion wird keine Prüfung ausgegeben."
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Rahmengröße von %qs ist %wd Bytes"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs verwendet dynamische Stapelanforderung"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "auf s390 können geschachtelte Funktionen mit %<-mfentry%> nicht im Profiling verwendet werden"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-Bit-ABI nicht unterstützt im ESA/390-Modus"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline wird nur mit %<-mindirect-branch-jump%> unterstützt"
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "Hardware-Vektorunterstützung ist auf %s nicht verfügbar"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "Hardware-Vektorunterstützung ist mit %<-msoft-float%> nicht verfügbar"
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Dezimale Hardware-Gleitkommabefehle sind auf %s nicht verfügbar"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Dezimale Hardware-Gleitkommabefehle sind im ESA/390-Modus nicht verfügbar"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> kann nicht in Verbindung mit %<-msoft-float%> verwendet werden"
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "die Kombination aus %<-mbackchain%>, %<-mpacked-stack%> und %<-mhard-float%> wird nicht unterstützt"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "Stapelgröße muss größer als der Stapel-Überwachungswert sein"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "Stapelgröße darf nicht größer als 64k sein"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> bringt %<-mstack-size%> mit sich"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr "»-mtpf-trace-hook-prologue-check« erfordert eine Ganzzahl im Bereich 0..4095"
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr "»-mtpf-trace-hook-prologue-target« erfordert eine Ganzzahl im Bereich 0..4095"
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr "»-mtpf-trace-hook-epilogue-check« erfordert eine Ganzzahl im Bereich 0..4095"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr "»-mtpf-trace-hook-epilogue-target« erfordert eine Ganzzahl im Bereich 0..4095"
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> wird nur auf 64-Bit-CPUs unterstützt"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "Argumente von %qs sollten nicht-negative Ganzzahlen sein"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "Argument für %qs ist zu groß (max. %d)"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> kann nur zusammen mit %<-fpic%>/%<-fPIC%> verwendet werden"
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) ist unbekannt"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "Wert %qs wird von Attribut %<target%> nicht unterstützt"
@@ -39879,17 +39898,22 @@ msgstr "%<-fexcess-precision=standard%> für Ada"
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr "STABS-Debuginfos für Ada ist abgelaufen und wird nicht mehr unterstützt"
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr "%s enthält zu viele Zeilen"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr "Unterprogramm %q+F nicht als %<Inline_Always%> markiert"
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "Eltern-Unterprogramm kann nicht geinlinet werden"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr "Unterprogramm %q+F nicht als %<Inline%> markiert"
@@ -39955,8 +39979,8 @@ msgstr "Attribut %qs bezieht sich nur auf Arraytypen"
 msgid "could not read the BRIG file"
 msgstr "BRIG-Datei konnte nicht gelesen werden"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-Wert nicht ignoriert wie es sein sollte"
@@ -40016,7 +40040,7 @@ msgstr "Variable %qD gesetzt, aber nicht verwendet"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "Typ des Arrays %q+D vervollständigt Unverträglichkeit mit impliziter Initialisierung"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "ursprünglich hier definiert"
@@ -40238,7 +40262,7 @@ msgstr "Deklaration von %q+D überdeckt eine vorhergehende Nicht-Variable"
 msgid "declaration of %qD shadows a parameter"
 msgstr "Deklaration von %qD überdeckt einen Parameter"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "Deklaration von %qD überdeckt eine globale Deklaration"
@@ -40248,7 +40272,7 @@ msgstr "Deklaration von %qD überdeckt eine globale Deklaration"
 msgid "declaration of %qD shadows a previous local"
 msgstr "Deklaration von %qD überdeckt einen vorhergehenden lokalen Bezeichner"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "verdeckte Deklaration ist hier"
@@ -40258,212 +40282,212 @@ msgstr "verdeckte Deklaration ist hier"
 msgid "nested extern declaration of %qD"
 msgstr "Geschachtelte extern-Deklaration von %qD"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "Implizite Deklaration der Funktion %qE; meinten Sie %qs?"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "Implizite Deklaration der Funktion %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr "binden Sie %qs ein oder stellen Sie eine Deklaration von %qE bereit"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "Unverträgliche implizite Deklaration der eingebauten Funktion %qD"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "binden Sie %qs ein oder stellen Sie eine Deklaration von %qD bereit"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "Unverträgliche implizite Deklaration der Funktion %qD"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE ist hier (außerhalb einer Funktion) nicht deklariert; meinten Sie %qs?"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE ist hier nicht deklariert (nicht in einer Funktion)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE nicht deklariert (erstmalige Verwendung in dieser Funktion); meinten Sie %qs?"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE nicht deklariert (erste Verwendung in dieser Funktion)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "jeder nicht deklarierte Bezeichner wird nur einmal für jede Funktion, in der er vorkommt, gemeldet"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "Marke %qE außerhalb einer Funktion referenziert"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "in Gültigkeitsbereich des Bezeichners mit variabel modifiziertem Typen springen"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "Sprung lässt Variableninitialisierung aus"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "Marke %qD hier definiert"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "Sprung in Anweisungs-Ausdruck"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "Doppelte Markendeklaration %qE"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "doppelte Marke %qD"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "traditionelles C bietet keinen separaten Namensraum für Marken an, Bezeichner %qE steht in Konflikt"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "switch springt über Variableninitialisierung"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch beginnt hier"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "switch springt in Anweisungs-Ausdruck"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE als falsche Symbolart definiert"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "Attribut %qE auf %qD mit Rückgabetyp »void« angewendet"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "Attribut %qE kann nur auf Funktionen oder auf struct-, union- oder enum-Typen angewendet werden"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "Unbenannte struct/union, die keine Instanzen definiert"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "Leere Deklaration mit Speicherklassenangabe redeklariert nicht Symbol"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "Leere Deklaration mit Typqualifizierer redeklariert nicht Symbol"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "Leere Deklaration mit %<_Alignas%> redeklariert nicht Symbol"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "Nutzloser Typname in leerer Deklaration"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> in leerer Deklaration"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> in leerer Deklaration"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> in leerer Deklaration im Datei-Gültigkeitsbereich"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> in leerer Deklaration im Datei-Gültigkeitsbereich"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "Nutzlose Speicherklassenangabe in leerer Deklaration"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "nutzloses %qs in leerer Deklaration"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "Nutzloser Typqualifizierer in leerer Deklaration"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "nutzloses %<_Alignas%> in leerer Deklaration"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr "ungültige Verwendung von Attributen in leerer Deklaration"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "Leere Deklaration"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO-C90 unterstützt kein %<static%> oder Typkennzeichner in Parameterarraydeklaratoren"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO-C90 unterstützt %<[*]%>-Arraydeklaratoren nicht"
@@ -40471,28 +40495,28 @@ msgstr "ISO-C90 unterstützt %<[*]%>-Arraydeklaratoren nicht"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> außerhalb des Bereichs des Funktionsprototypen nicht erlaubt"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D ist üblicherweise eine Funktion"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD ist initialisiert (verwenden Sie stattdessen lieber %<__typeof__%>)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "Funktion %qD ist wie eine Variable initialisiert"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "Parameter %qD ist initialisiert"
@@ -40501,267 +40525,267 @@ msgstr "Parameter %qD ist initialisiert"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "Objekt variabler Größe darf nicht initialisiert werden"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "Variable %qD hat Initialisierung, aber unvollständigen Typ"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr "der inline-Funktion %q+D wurde das Attribut %qs gegeben"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "nicht initialisiertes konstantes Element %qT ist in C++ ungültig"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD sollte initialisiert werden"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "Initialisierung gibt nicht die Größe von %q+D an"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "Arraygröße fehlt in %q+D"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "Arraygröße von %q+D ist null oder negativ"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "Speichergröße von %q+D ist nicht konstant"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "%<asm%>-Angabe für nicht-statische lokale Variable %q+D wird ignoriert"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "Objekt mit volatile-Feld kann nicht in Register geladen werden"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, gcc-internal-format
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "nicht initialisiertes %<const %qD%> ist in C++ ungültig"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D in »declare target«-Direktive hat keinen zuordenbaren Typ"
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO-C verbietet Vorwärtsdeklaration für Parameter"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "Definition eines Typs in einem zusammengesetzten Literal ist in C++ ungültig"
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "Breite des Bitfeldes %qs ist keine Ganzzahlkonstante"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "Breite des Bitfeldes %qs ist kein Ganzzahlkonstantenausdruck"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "Negative Breite in Bitfeld %qs"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "Breite Null für Bitfeld %qs"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "Bitfeld %qs hat ungültigen Typen"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "Bitfeld %qs kann nicht mit %<warn_if_not_aligned%>-Typ deklariert werden"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "Typ des Bitfeldes %qs ist eine Erweiterung des GCC"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "Breite von %qs überschreitet dessen Typen"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs ist schmaler als die Werte seines Typs"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO-C90 verbietet Array %qE, dessen Größe nicht ausgewertet werden kann"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO-C90 verbietet Array, dessen Größe nicht ausgewertet werden kann"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO-C90 verbietet Array %qE variabler Größe"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO-C90 verbietet Array variabler Größe"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "variabel modifiziertes %qE im Dateibereich"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "variabel modifiziertes Feld im Dateibereich"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "%<int%> ist Standardtyp in Deklaration von %qE"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "%<int%> ist Standardtyp in Typ-Deklaration"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "doppeltes %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "doppeltes %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "doppeltes %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "doppeltes %<_Atomic%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "in Konflikt stehende benannte Adressräume (%s und %s)"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "%<_Atomic%>-qualifizierter Arraytyp"
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "Funktionsdefinition deklarierte %<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "Funktionsdefinition deklarierte %<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "Funktionsdefinition deklarierte %<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "Funktionsdefinition deklarierte %qs"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "Speicherklasse für Strukturfeld %qE angegeben"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "Speicherklasse für Strukturfeld angegeben"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "Speicherklasse für Parameter %qE angegeben"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "Speicherklasse für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "Speicherklasse für Typnamen angegeben"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE initialisiert und als %<extern%> deklariert"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE hat sowohl %<extern%> als auch Initialisierung"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "Deklaration von %qE in Datei-Sichtbarkeitsbereich spezifiziert %<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "Deklaration von %qE in Datei-Sichtbarkeitsbereich spezifiziert %<register%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "geschachtelte Funktion %qE als %<extern%> deklariert"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "Funktions-Gültigkeitsbereich %qE ist implizit auto, jedoch als %qs deklariert"
@@ -40769,711 +40793,711 @@ msgstr "Funktions-Gültigkeitsbereich %qE ist implizit auto, jedoch als %qs dekl
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "»static« oder Typkennzeichner in Nicht-Parameter-Arraydeklarator"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "Deklaration von %qE als Array von voids"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "Deklaration eines Typnamen als Array von voids"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "Deklaration von %qE als Array von Funktionen"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "Deklaration eines Typnamen als Array von Funktionen"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ungültige Verwendung einer Struktur mit flexiblem Arrayelement"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "Arraygröße von %qE hat Nicht-Ganzzahltyp"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "Größe eines unbenannten Arrays hat Nicht-Ganzzahltyp"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "Arraygröße von %qE hat unvollständigen Typ"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "Größe eines unbenannten Arrays hat unvollständigen Typ"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO-C verbietet Array %qE der Größe null"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO-C verbietet Array der Größe null"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "Größe des Arrays %qE ist negativ"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "Größe des unbenannten Arrays ist negativ"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "Arraygröße von %qE ist zu groß"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "Größe des unbenannten Arrays ist zu groß"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO-C90 unterstützt keine flexiblen Arrays als Elemente"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> nicht in einer Deklaration"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "Arraytyp hat unvollständigen Elementtypen %qT"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von %qE als multidimensionales Array muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von multidimensionalem Array muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "Typname als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE als Funktion, die ein Array zurückgibt, deklariert"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "Typname als Funktion, die ein Array zurückgibt, deklariert"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "Funktionsdefinition hat qualifizierten void-Rückgabetypen"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "Typkennzeichner an Funktions-Rückgabewert ignoriert"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "%<_Atomic%>-qualifizierter Funktionstyp"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO-C verbietet qualifizierte Funktionstypen"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs mit Qualifizierer %<auto%> für %qE kombiniert"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs mit Qualifizierer %<register%> für %qE kombiniert"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs für »auto«-Variable %qE angegeben"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs für Parameter %qE angegeben"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs für Strukturfeld %qE angegeben"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs für Strukturfeld angegeben"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "Bitfeld %qE hat atomaren Typen"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "Bitfeld hat atomaren Typen"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "Ausrichtung für typedef %qE angegeben"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "Ausrichtung für %<register%>-Objekt %qE angegeben"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "Ausrichtung für Parameter %qE angegeben"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "Ausrichtung für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "Ausrichtung für Bitfeld %qE angegeben"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "Ausrichtung für unbenanntes Bitfeld angegeben"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "Ausrichtung für Funktion %qE angegeben"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<_Alignas%>-Spezifizierer können nicht die Ausrichtung von %qE reduzieren"
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<_Alignas%>-Spezifizierer können nicht die Ausrichtung eines unbenannten Feldes reduzieren"
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D als %<inline%> deklariert"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO-C verbietet const- oder volatile-Funktionstypen"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "Ein Element einer Struktur oder Union kann nicht variabel modifizierten Typ haben"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "Variable oder Feld %qE als »void« deklariert"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "Attribute in Parameterarraydeklarator ignoriert"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "Parameter %q+D als %<inline%> deklariert"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "Parameter %q+D als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "Feld %qE als Funktion deklariert"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "Feld %qE hat unvollständigen Typen"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "unbenanntes Feld hat unvollständigen Typen"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "ungültige Speicherklasse für Funktion %qE"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "%<main%> ist nicht als »inline« möglich"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO-C99 unterstützt nicht %<_Noreturn%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO-C90 unterstützt nicht %<_Noreturn%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "als %<extern%> redeklarierte Variable war bereits als %<static%> deklariert"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "Variable %q+D als %<inline%> deklariert"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "Variable %q+D als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "nicht geschachtelte Funktion mit variabel modifiziertem Typen"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "Objekt mit variabel geändertem Typ darf keine Bindung haben"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "Funktionsdeklaration ist kein Prototyp"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "Parameternamen (ohne Typen) in Funktionsdeklaration"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "Parameter %u (%q+D) hat unvollständigen Typen"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "Parameter %u hat unvollständigen Typen"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "Parameter %u (%q+D) hat void-Typen"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "Parameter %u hat void-Typen"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> kann nicht als einzelner Parameter qualifiziert werden"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> muss der einzige Parameter sein"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "Parameter %q+D hat nur eine Vorwärtsdeklaration"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "das innerhalb der Parameterliste deklarierte %<%s %E%> ist außerhalb dieser Definition oder Deklaration nicht sichtbar"
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "das innerhalb der Parameterliste deklarierte anonyme »%s« ist außerhalb dieser Definition oder Deklaration nicht sichtbar"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "»enum«-Typ hier definiert"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "»struct« wurde hier definiert"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "»union« wurde hier definiert"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "Redefinition von %<union %E%>"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "Redefinition von %<struct %E%>"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "Verschachtelte Redefinition von %<union %E%>"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "Verschachtelte Redefinition von %<struct %E%>"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "Typdefinition in Ausdruck %qs ist in C++ ungültig"
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "Deklaration deklariert nichts"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO-C99 unterstützt keine namenlosen structs/unions"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO-C90 unterstützt keine namenlosen structs/unions"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "doppeltes Element %q+D"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr "leere Struktur hat Größe 0 in C, aber 1 in C++"
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "leere Union hat Größe 0 in C, aber 1 in C++"
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "Union hat keine benannten Elemente"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "Union hat keine Elemente"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct hat keine benannten Elemente"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct hat keine Elemente"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibles Arrayelement in Union"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexibles Arrayelement nicht am Ende von struct"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "flexibles Arrayelement in einer Struktur ohne benannte Elemente"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "Typ %qT ist zu groß"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kann nicht transparent gemacht werden"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "Verschachtelte Redefinition von %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "Redeklaration von %<enum %E%>"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "angegebener Modus zu klein für Aufzählungswerte"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "Aufzählungswerte überschreiten Wertebereich des größten Ganzzahltypen"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "Aufzählungswert für %qE ist keine Ganzzahlkonstante"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "Aufzählungswert für %qE ist kein Ganzzahlkonstantenausdruck"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "Überlauf in Aufzählungswerten"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO-C beschränkt Aufzählungswerte auf Bereich von %<int%>"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "der inline-Funktion %qD wurde das Attribut %qs gegeben"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "Rückgabetyp ist unvollständig"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "Rückgabetyp ist auf %<int%> voreingestellt"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D ist als variadische Funktion ohne Prototyp definiert"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "kein vorheriger Prototyp für %qD"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Prototyp verwendet"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "keine vorherige Deklaration für %qD"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Deklaration verwendet"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "Rückgabetyp von %qD ist nicht %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%>-qualifizierter Rückgabetyp von %qD"
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD ist normalerweise eine nicht-statische Funktion"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "Parameterdeklarationen alten Stils in Prototyp-Funktionsdeklaration"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionelles C weist Funktionsdefinitionen im ISO-C-Stil zurück"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "ISO-C unterstützt das Weglassen von Parameternamen in Funktionsdefinitionen erst ab C2X"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "Funktionsdefinition im alten Stil"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "Parametername fehlt in Parameterliste"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD als Nicht-Parameter deklariert"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "mehrere Parameter wurden %qD genannt"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "Parameter %qD als void deklariert"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "Typ von %qD ist auf %<int%> voreingestellt"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "Parameter %qD hat unvollständigen Typen"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "Deklaration für nicht vorhandenen Parameter %qD"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "Anzahl der Argumente passt nicht zum eingebauten Prototypen"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "Anzahl der Argumente passt nicht zum Prototypen"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "Prototyp-Deklaration"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "weitergegebenes Argument %qD passt nicht zu eingebautem Prototypen"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "weitergegebenes Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "Argument %qD passt nicht zu eingebautem Prototypen"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "keine return-Anweisung in nicht void zurückgebender Funktion"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "Parameter %qD gesetzt, jedoch nicht verwendet"
@@ -41481,257 +41505,257 @@ msgstr "Parameter %qD gesetzt, jedoch nicht verwendet"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Anfangsdeklarationen in %<for%>-Schleifen sind nur im C99- oder C11-Modus erlaubt"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "die Option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> oder %<-std=gnu11%> verwenden, um den Code zu übersetzen"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "Deklarationen im Initialisierungsteil einer %<for%>-Schleife werden von ISO C90 nicht unterstützt; ab ISO C99 geht es"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der »static«-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der %<extern%>-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der Nicht-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "Inkompatible Adressraumkennzeichen %qs und %qs"
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "Doppelter Deklarationsspezifizierer %qE"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "zwei oder mehr Datentypen in Deklaration"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> ist für GCC zu lang"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO-C90 unterstützt nicht %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO-C90 unterstützt keine komplexen Typen"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO-C unterstützt keine sättigenden Typen"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "doppeltes %qE"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO-C unterstützt die Typen %<__int%d%> nicht"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> wird für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO-C90 unterstützt keine booleschen Typen"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO-C unterstützt den Typen %<_Float%d%s%> nicht"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> wird für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO-C unterstützt dezimale Gleitkommazahlen erst ab C2X"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "Festkommatypen werden für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO-C unterstützt keine Ganzzahltypen"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "Nachschlagen von %qD würde in C++ ein Feld, keinen Typen zurückgeben"
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ist kein typedef oder eingebauter Typ"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ist nicht am Anfang einer Deklaration"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE mit %<auto%> verwendet"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE mit %<register%> verwendet"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE mit %<typedef%> verwendet"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO-C99 unterstützt nicht %qE"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO-C90 unterstützt nicht %qE"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vor %<extern%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vor %<static%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "doppeltes %<_Thread_local%> oder %<__thread%>"
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "mehrere Speicherklassen in Deklaration"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs mit %qE verwendet"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> ohne %<_Fract%> oder %<_Accum%> verwendet"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C unterstützt nicht %<double complex%> bedeutendes einfaches %<complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%> gefolgt von %<[[]]%>-Attributen"
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO-C unterstützt keine komplexen Ganzzahltypen"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-Kombinierer verweist auf Variable %qD, die weder %<omp_out%> noch %<omp_in%> ist"
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-Initialisierung verweist auf Variable %qD, die weder %<omp_priv%> noch %<omp_orig%> ist"
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "left shift of negative value"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "Links-Schiebe-Weite ist negativ"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "Rechts-Schiebe-Weite ist negativ"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "Links-Schiebe-Weite >= Breite des Typs"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "Rechts-Schiebe-Weite >= Breite des Typs"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "Links-Schiebe-Weite >= Breite des Vektorelements"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "Rechts-Schiebe-Weite >= Breite des Vektorelements"
@@ -41751,7 +41775,7 @@ msgstr "Konfliktmarker für Versionskontrolle in Datei"
 msgid "to match this %qs"
 msgstr "andere Fundstelle von %qs ist hier"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "Zeilenende erwartet"
@@ -41761,7 +41785,7 @@ msgstr "Zeilenende erwartet"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO-C verbietet eine leere Quelldatei"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> ohne zugehöriges %<#pragma omp end declare target%>"
@@ -41797,7 +41821,7 @@ msgid "unknown type name %qE"
 msgstr "unbekannter Typname: %qE"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "Deklarationsspezifizierer erwartet"
@@ -41817,7 +41841,7 @@ msgstr "%<fallthrough%>-Attribut auf höchster Ebene"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, Bezeichner oder %<(%> erwartet"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "Präfixattribute werden für Methoden ignoriert"
@@ -41832,7 +41856,7 @@ msgstr "Präfixattribute werden für Implementierungen ignoriert"
 msgid "unexpected attribute"
 msgstr "unerwartetes Attribut"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "%<fallthrough%>-Attribut ohne darauffolgendes %<;%>"
@@ -41870,7 +41894,7 @@ msgstr "%<__auto_type%> benötigt eine initialisierte Datendeklaration"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kann nur mit einem einzelnen Deklarator verwendet werden"
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> oder %<;%> erwartet"
@@ -41928,7 +41952,7 @@ msgstr "Ausdruck in statischer Behauptung ist nicht konstant"
 msgid "static assertion failed: %E"
 msgstr "statische Behauptung gescheitert: %E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statische Behauptung gescheitert"
@@ -41973,14 +41997,14 @@ msgstr "Leeres Enum ist ungültig"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "Bezeichner erwartet"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "Komma am Ende der Aufzählungsliste"
@@ -42065,7 +42089,7 @@ msgstr "Deklarationsspezifizierer oder %<...%> erwartet"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "Klammern müssen weggelassen werden, wenn die Argumentenliste des Attributs leer ist"
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "Attribut %qE akzeptiert keine Argumente"
@@ -42125,7 +42149,7 @@ msgstr "ISO-C90 verbietet gemischte Deklarationen und Code"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> vor %<else%> erwartet"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> ohne vorheriges %<if%>"
@@ -42140,7 +42164,7 @@ msgstr "Marke am Ende einer Verbundanweisung"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "Anweisung erwartet"
@@ -42165,17 +42189,17 @@ msgstr "Bezeichner oder %<*%> erwartet"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "Nur das Attribut %<fallthrough%> kann auf eine leere Anweisung angewendet werden"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<if%>-Anweisung empfohlen"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<else%>-Anweisung empfohlen"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "es wird empfohlen, explizite geschweifte Klammern zu setzen, um mehrdeutiges %<else%> zu vermeiden"
@@ -42195,12 +42219,12 @@ msgstr "mehrere Schleifenvariablen in schneller Aufzählung"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ungültiges Schleifenvariable in schneller Aufzählung"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "fehlende Schleifenbedingung in Schleife mit %<GCC ivdep%>-Pragma"
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "fehlende Schleifenbedingung in Schleife mit %<GCC unroll%>-Pragma"
@@ -42215,8 +42239,8 @@ msgstr "die Sammlung in schneller Aufzählung fehlt"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "doppelter %<asm%>-Qualifizierer %qE"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr "erstmals hier gesehen"
@@ -42243,12 +42267,12 @@ msgstr "ISO-C verbietet das Weglassen des mittleren Terms eines %<?:%>-Ausdrucke
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "Division %<sizeof (%T) / sizeof (%T)%> berechnet nicht die Anzahl der Feldelemente"
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "der Operand des ersten %<sizeof%> wurde hier deklariert"
@@ -42639,12 +42663,12 @@ msgstr "Methodendeklaration in Objective-C erwartet"
 msgid "no type or storage class may be specified here,"
 msgstr "hier darf kein Typ oder Speicherklasse angegeben werden,"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "leere Liste von Eigenschaftsattributen"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, gcc-internal-format
 msgid "missing property attribute"
 msgstr "Eigenschaftsattribut fehlt"
@@ -42654,51 +42678,51 @@ msgstr "Eigenschaftsattribut fehlt"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "unbekanntes Eigenschaftsattribut %<%s%s%>"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "unbekanntes Eigenschaftsattribut"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "nach dem Objective-C-Attribut %qE wird ein %<=%> erwartet"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "Selektorname für %qE erwartet"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "Methodennamen von Settern müssen mit %<:%> aufhören"
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> erfordert einen Zuweisungsausdruck, der zu einer nichtnegativen Ganzzahlkonstante kleiner als %u evaluiert"
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> darf nur im Datei-Gültigkeitsbereich auftreten"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> darf nur in einem Schleifenkonstrukt mit %<inscan%>-%<reduction%>-Klausel verwendet werden"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt verwendet werden"
@@ -42708,18 +42732,18 @@ msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt v
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp requires%> darf nur im Gültigkeitsbereich einer Datei verwendet werden"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- oder do-Anweisung erwartet"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> muss zuerst kommen"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "zu viele %qs-Klauseln"
@@ -42739,53 +42763,53 @@ msgstr "%<)%> oder %<,%> erwartet"
 msgid "%qD is not a variable"
 msgstr "%qD ist keine Variable"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ist keine Zeigervariable"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "Collapse-Argument erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> oder %<present%> erwartet"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> oder %<shared%> erwartet"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> oder %<exit%> erwartet"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> erwartet"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "zu viele %<if%>-Klauseln mit %qs-Modifizierer"
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "zu viele %<if%>-Klauseln"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "zu viele %<if%>-Klauseln ohne Modifizierer"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "wenn eine der %<if%>-Klauseln einen Modifizierer verwendet, müssen alle %<if%>-Klauseln Modifizierer verwenden"
@@ -42807,107 +42831,107 @@ msgstr "Wert von %<num_threads%> muss positiv sein"
 msgid "%<num_tasks%> value must be positive"
 msgstr "Wert von %<num_tasks%> muss positiv sein"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "Wert von %<grainsize%> muss positiv sein"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "Wert von %<priority%> muss positiv sein"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "konstanter Ganzzahlausdruck mit gültigem sync-hint-Wert erwartet"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> oder %<default%> erwartet"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<scalar%>, %<aggregate%> oder %<pointer%> erwartet"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "zu viele %<defaultmap%>-Klauseln mit %qs-Kategorie"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "zu viele %<defaultmap%>-Klauseln mit nicht angegebener Kategorie"
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-Ausdruck muss ganzzahlig sein"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "Wert %qs muss positiv sein"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "zu viele %<static%>-Argumente"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "unerwartetes Argument"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%<tile%>-Argument muss eine positive, ganzzahlige Konstante sein"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<concurrent%> erwartet"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<teams%>, %<parallel%> oder %<thread%> erwartet"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "Argument für %<ordered%> muss ein positiver, ganzzahliger Ausdruck sein"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> oder Bezeichner erwartet"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "widersprüchliche Modifizierer %<monotonic%> und %<nonmonotonic%> angegeben"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<runtime%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<auto%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "Wert der Chunkgröße muss positiv sein"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ungültige Ablaufart"
@@ -42917,17 +42941,17 @@ msgstr "ungültige Ablaufart"
 msgid "%<num_teams%> value must be positive"
 msgstr "Wert von %<num_teams%> muss positiv sein"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "Wert von %<thread_limit%> muss positiv sein"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "Ausdruck für %<aligned%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "Allokationsausdruck in %<allocate%>-Klausel ist vom Typ %qT statt des erwarteten %<omp_allocator_handle_t%>"
@@ -42948,22 +42972,22 @@ msgid "%<simdlen%> clause expression must be positive constant integer expressio
 msgstr "Ausdruck der %<simdlen%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79924
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "Modifizierer %<iterator%> ist unverträglich mit %qs"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ungültige Abhängigkeitsart"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ungültige Zuordnungsart"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ungültige »dist_schedule«-Art"
@@ -42978,82 +43002,82 @@ msgstr "ungültige »proc_bind«-Art"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<host%>, %<nohost%> oder %<any%> erwartet"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr "Ereignishandle in %<detach%>-Klausel ist vom Typ %qT statt des erwarteten %<omp_event_handle_t%>"
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "Klausel %<#pragma acc%> erwartet"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs ist für %qs ungültig"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "Klauseln in %<simd%>-Eigenschaft sollten durch %<,%> getrennt werden"
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs muss die erste Klausel von %qs sein"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "Klausel %<#pragma omp%> erwartet"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "keine gültigen Klauseln in %<#pragma acc declare%> angegeben"
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "Arrayabschnitt in %<#pragma acc declare%>"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "In %<#pragma acc declare link%> muss %qD eine globale Variable sein"
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ungültige OpenACC-Klausel im Datei-Gültigkeitsbereich"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<extern%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<global%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD muss eine Variable sein, die im selben Gültigkeitsbereich wie %<#pragma acc declare%> deklariert ist"
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Variable %qD wird in %<#pragma acc declare%> mehr als einmal verwendet"
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "hinter %<#pragma acc %s%> wird %<data%> erwartet"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> hat keine Datenverschiebeklausel"
@@ -43068,7 +43092,7 @@ msgstr "%qE wurde nicht deklariert"
 msgid "expected function name"
 msgstr "Funktionsname erwartet"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD bezeichnet keine Funktion"
@@ -43078,27 +43102,27 @@ msgstr "%qD bezeichnet keine Funktion"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Funktionsdeklaration oder -definition auftreten"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Deklaration oder Definition einer einzelnen Funktion auftreten"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> muss vor Verwendung angewendet werden"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> muss vor Definition angewendet werden"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> muss mindestens eine %<device%>- oder %<host%>- or %<self%>-Klausel enthalten"
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, gcc-internal-format
 msgid "expected %<allocator%>"
 msgstr "%<allocator%> erwartet"
@@ -43108,82 +43132,82 @@ msgstr "%<allocator%> erwartet"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "Allokationsausdruck in %<allocator%>-Klausel ist vom Typ %qT statt des erwarteten %<omp_allocator_handle_t%>"
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "%<#pragma omp allocate%> wird nicht mehr unterstützt"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "eine der Klauseln %<read%>, %<write%>, %<update%> oder %<capture%> erwartet"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "eine der Klauseln %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> oder %<hint%> erwartet"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "zu viele atomare Klauseln"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "zu viele Speicherreihenfolge-Klauseln"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp atomic read%> ist unverträglich mit den Klauseln %<acq_rel%> und %<release%>"
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic write%> ist unverträglich mit den Klauseln %<acq_rel%> und %<acquire%>"
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic update%> ist unverträglich mit den Klauseln %<acq_rel%> und %<acquire%>"
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ungültige Form von %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ungültiger Operator für %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "Ausdruck %<depobj%> ist kein lvalue-Ausdruck"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<in%>, %<out%>, %<inout%> oder %<mutexinoutset%> erwartet"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "eine der Klauseln %<depend%>, %<destroy%> oder %<update%> erwartet"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<acq_rel%>, %<release%> oder %<acquire%> erwartet"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<flush%>-Liste wurde zusammen mit Speicherreihenfolge-Klausel angegeben"
@@ -43193,32 +43217,32 @@ msgstr "%<flush%>-Liste wurde zusammen mit Speicherreihenfolge-Klausel angegeben
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> oder Zeilenende erwartet"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<inclusive%>- oder %<exclusive%>-Klausel erwartet"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp scan%> erwartet"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-Klauselparameter ist weniger als %<collapse%>"
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "%<linear%>-Klausel darf nicht zusammen mit %<ordered%>-Klausel mit einem Parameter angegeben werden"
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "für Anweisung erwartet"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "Schleifendeklaration oder Initialisierung erwartet"
@@ -43228,72 +43252,72 @@ msgstr "Schleifendeklaration oder Initialisierung erwartet"
 msgid "not enough perfectly nested loops"
 msgstr "nicht genügend perfekt geschachtelte Schleifen"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "zusammengelegte Schleifen sind nicht perfekt geschachtelt"
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "Schleifenvariable %qD sollte nicht »firstprivate« sein"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<ordered%>-Klausel mit Parameter darf nicht beim %qs-Konstruk angegeben werden"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> mit %<depend%>-Klausel darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> hinter %qs erwartet"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> erwartet"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> muss mindestens eine %<map%>-, %<use_device_ptr%>- oder %<use_device_addr%>-Klausel enthalten"
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> muss mindestens eine %<from%>- oder %<to%>-Klausel enthalten"
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> mit Zuordnungstyp außer %<to%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> mit Zuordnungstyp außer %<from%>, %<release%> oder %<delete%> an %<map%>-Klausel"
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
@@ -43308,57 +43332,57 @@ msgstr "%<#pragma omp declare %s%> muss von einer Funktionsdeklaration oder -def
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> muss vor der Deklaration oder Definition einer Funktion auftreten"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "Name des Merkmalsselektors erwartet"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "Selektor %qs nicht erlaubt für Kontext-Selektorsatz %qs"
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "Selektor %qs akzeptiert keine Eigenschaften"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "das Score-Argument muss ein konstanter ganzzahliger Ausdruck sein"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "das Score-Argument darf nicht negativ sein"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "Eigenschaft muss ein konstanter ganzzahliger Ausdruck oder ein Zeichenkettenliteral sein"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "Bezeichner oder Zeichenkettenliteral erwartet"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "Eigenschaft muss ein konstanter ganzzahliger Ausdruck sein"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "Eigenschaften für %<simd%>-Selektor dürfen nicht in %<metadirective%> angegeben werden"
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<construct%>, %<device%>, %<implementation%> oder %<user%> erwartet"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<match%> erwartet"
@@ -43368,12 +43392,12 @@ msgstr "%<match%> erwartet"
 msgid "variant %qD is not a function"
 msgstr "Variante %qD ist keine Funktion"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "Variante %qD und Basis %qD haben unverträgliche Typen"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "die Variante %qD ist eine eingebaute"
@@ -43383,32 +43407,32 @@ msgstr "die Variante %qD ist eine eingebaute"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "hinter %<#pragma omp declare %s%> muss direkt eine Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "hinter %<#pragma omp declare %s%> muss direkt eine einzelne Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD ist sowohl in %<link%>- als auch %<to%>-Klauseln des Deklarationsziels angegeben"
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr "Direktiven mit nur %<device_type%>-Klauseln werden ignoriert"
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> erwartet"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> erwartet"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> ohne zugehöriges %<#pragma omp declare target%>"
@@ -43463,42 +43487,42 @@ msgstr "Funktionsname und %<(%> erwartet"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "eins der Argumente für den Initialisierungsaufruf sollte %<&omp_priv%> sein"
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<simd%>, %<reduction%>, %<target%> oder %<variant%> erwartet"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<seq_cst%>, %<relaxed%> oder %<acq_rel%> erwartet"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "eine der Klauseln %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> oder %<atomic_default_mem_order%> erwartet"
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "die %qs-Klausel wird in der %<requires%>-Direktive noch nicht unterstützt"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "%qs-Klausel wird lexikalisch nach dem ersten Zielkonstrukt oder nach der ersten Auslagerungs-API verwendet"
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "mehr als eine %<atomic_default_mem_order%>-Klausel in einer einzigen Übersetzungseinheit"
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "%<atomic_default_mem_order%>-Klausel wird lexikalisch nach dem ersten %<atomic%>-Konstrukt ohne Speicherreihenfolge-Klausel verwendet"
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> erfordert mindestens eine Klausel"
@@ -43513,27 +43537,27 @@ msgstr "Typ %qT mit Größe 0 in %<reduction%>-Klausel"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "Typ %qT mit variabler Länge in %<reduction%>-Klausel"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE nach erster Verwendung als %<threadprivate%> deklariert"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatische Variable %qE kann nicht %<threadprivate%> sein"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE hat unvollständigen Typen"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> ohne eingeschaltete Unterstützung für transaktionsbasierten Speicher"
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> innerhalb eines %<__transaction_relaxed%>"
@@ -43543,7 +43567,7 @@ msgstr "%<__transaction_cancel%> innerhalb eines %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "Funktionsaufruf von %<__transaction_cancel%> nicht innerhalb von äußerer %<__transaction_atomic%>- oder %<transaction_may_cancel_outer%>-Funktion"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> nicht innerhalb von %<__transaction_atomic%>"
@@ -43558,7 +43582,7 @@ msgstr "fehlende schließende geschweifte Klammer"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD hat unvollständigen Typ %qT"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "falsche Verwendung eines void-Ausdruckes"
@@ -43600,127 +43624,127 @@ msgstr "Attribut %qs ist nur auf Funktionen anwendbar, die eine variable Anzahl
 msgid "function types not truly compatible in ISO C"
 msgstr "Funktionstypen nicht wirklich kompatibel in ISO-C"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "Operanden von dezimalen Gleitkomma- und Vektortypen können nicht gemischt werden"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "Operanden von dezimalen Gleitkomma- und komplexen Typen können nicht gemischt werden"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "Operanden von dezimalen und anderen Gleitkommatypen können nicht gemischt werden"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "Zeiger auf Arrays mit unterschiedlichen Qualifizierern sind in ISO-C inkompatibel"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "Typen nicht ganz kompatibel"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "Zeiger-Zieltypen sind in C++ inkompatibel"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "Funktionsrückgabetypen nicht kompatibel wegen %<volatile%>"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "Umwandlung eines zusammengesetzten Arrayliterals ist in C++ ungültig"
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT hat kein Element namens %qE; meinten Sie %qE?"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT hat kein Element namens %qE"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr "Zugriff auf ein Element %qE einer atomaren Struktur %qE"
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "Zugriff auf ein Element %qE einer atomaren Union %qE"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr "%qE ist ein Zeiger; meinten Sie %<->%>?"
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "Anfrage nach Element %qE in etwas, was keine Struktur oder Variante ist"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "Dereferenzierung eines %<void *%>-Zeigers"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indizierter Wert ist weder Array noch Zeiger noch Vektor"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "Arrayindex ist keine Ganzzahl"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "indizierter Wert ist Zeiger auf Funktion"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO-C verbietet, ein %<register%>-Array zu indizieren"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO-C90 verbietet, ein Nicht-L-Wert-Array zu indizieren"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr "enum-Konstante hier definiert"
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> auf Array-Funktionsparameter %qE gibt die Größe von %qT zurück"
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "gerufenes Objekt %qE ist keine Funktion oder Funktionszeiger"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "gerufenes Objekt %qD ist keine Funktion oder Funktionszeiger"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "gerufenes Objekt ist keine Funktion oder Funktionszeiger"
@@ -43728,1594 +43752,1594 @@ msgstr "gerufenes Objekt ist keine Funktion oder Funktionszeiger"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "Funktion über nicht kompatiblen Typen aufgerufen"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "Funktion mit qualifiziertem void-Rückgabetypen aufgerufen"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "Typ des formalen Parameters %d ist unvollständig"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als Ganzzahl statt Gleitkomma aufgrund des Prototyps"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als Ganzzahl statt komplex aufgrund des Prototyps"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als komplex statt Gleitkomma aufgrund des Prototyps"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als Gleitkomma statt Ganzzahl aufgrund des Prototyps"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als komplex statt Ganzzahl aufgrund des Prototyps"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als Gleitkomma statt komplex aufgrund des Prototyps"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als %<float%> statt %<double%> aufgrund des Prototyps"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als %qT statt %qT aufgrund des Prototyps"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "Übergabe des Arguments %d von %qE mit anderer Breite aufgrund des Prototyps"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als vorzeichenlos aufgrund des Prototyps"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "Übergabe des Arguments %d von %qE als vorzeichenbehaftet aufgrund des Prototyps"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "zu viele Argumente für Methode %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, gcc-internal-format
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "zu viele Argumente für eingebaute Funktion %qE, nur %d erwartet"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "implizite Umwandlung von %qT in %qT bei Übergabe von Argument an Funktion"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, gcc-internal-format
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "zu wenige Argumente für eingebaute Funktion %qE, %u erwartet"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "Vergleich mit Zeichenkettenliteral führt zu unspezifiziertem Verhalten"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "Vergleich zwischen Zeiger und '\\0'"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "wollten Sie vielleicht den Zeiger dereferenzieren?"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "Vergleich zwischen %qT und %qT"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "Zeiger des Typs %<void *%> in Subtraktion verwendet"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "Zeiger auf eine Funktion in Subtraktion verwendet"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "Arithmetik mit Zeiger auf unvollständigen Typen"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "Arithmetik mit Zeiger auf leeres Aggregat"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> auf booleschem Ausdruck"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "meinten Sie ein logisches Nicht (%<!%>)?"
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO-C unterstützt nicht %<~%> für komplexe Konjugation"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, gcc-internal-format
 msgid "wrong type argument to absu"
 msgstr "falsches Typargument für »absu«"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "Argument falschen Typs für unäres Ausrufungszeichen"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "Schrittweite von Aufzählungswerten (enum) ist in C++ ungültig"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "Verringerung von Aufzählungswerten (enum) ist in C++ ungültig"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "Inkrementieren eines booleschen Ausdrucks"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "Dekrementieren eines booleschen Ausdrucks"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO-C unterstützt kein %<++%> und %<--%> für komplexe Typen"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "Argument falschen Typs für Inkrementierung"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "Argument falschen Typs für Dekrementierung"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "Inkrementieren eines Zeigers auf unvollständigen Typ %qT"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "Dekrementieren eines Zeigers auf unvollständigen Typ %qT"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "Adresse des Ausdrucks des Typs %<void%> wird genommen"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "die Adresse des Bit-Feldes %qD kann nicht ermittelt werden"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "Adresse eines Skalars mit umgekehrter Speicherreihenfolge kann nicht ermittelt werden"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "Adresse eines Arrays mit umgekehrter Speicherreihenfolge angefordert"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "globale Register-Variable %qD in verschachtelter Funktion verwendet"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "Register-Variable %qD in verschachtelter Funktion verwendet"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "Adresse der globalen Variablen %qD angefordert"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "Adresse der Register-Variablen %qD angefordert"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "Nicht-L-Wert-Array in bedingtem Ausdruck"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "implizite Umwandlung von %qT in %qT um an anderes Ergebnis von Bedingung anzupassen"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr "Operand von %<?:%> wechselt das Vorzeichen von %qT nach %qT, aufgrund der Vorzeichenlosigkeit des anderen Operanden"
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO-C verbietet bedingten Ausdruck mit nur einer void-Seite"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "Zeiger auf disjunkte Adressräume in bedingtem Ausdruck verwendet"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "Zeiger auf Array verliert durch den Bedingungsausdruck Qualifizierer"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO-C verbietet bedingten Ausdruck zwischen %<void *%> und Funktionszeiger"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, gcc-internal-format
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "unverträgliche Zeigertypen %qT und %qT von %qD und %qD in bedingtem Ausdruck"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "Zeigertyp passt nicht in bedingtem Ausdruck"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "Zeiger-/Ganzzahltyp passt nicht in bedingtem Ausdruck"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "Typ passt nicht in bedingtem Ausdruck"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "der Rückgabewert von %qD (mit %<nodiscard%>-Attribut deklariert) wird ignoriert: %E"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "der Rückgabewert von %qD (mit %<nodiscard%>-Attribut deklariert) wird ignoriert"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "der Rückgabewert vom Typ %qT (mit %<nodiscard%>-Attribut deklariert) wird ignoriert: %E"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "der Rückgabewert vom Typ %qT (mit %<nodiscard%>-Attribut deklariert) wird ignoriert"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "im Aufruf von %qD, hier deklariert"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "linker Operand des Komma-Ausdrucks hat keinen Effekt"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "rechter Operand des Komma-Ausdrucks hat keinen Effekt"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr "Typumwandlung fügt Qualifizierer %q#v zu Funktionstyp hinzu"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "Typumwandlung streicht Qualifizierer %qv von Zeiger-Zieltyp"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "zur Sicherheit müssen alle vorübergehenden Zeiger in Umwandlung von %qT in %qT mit %<const%> qualifiziert sein"
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "Typkonvertierung gibt Arraytyp an"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "Typkonvertierung gibt Funktionstyp an"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO-C verbietet Typkonvertierung von Nicht-Skalar auf selben Typen"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO-C verbietet Typkonvertierung auf union-Typ"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "Typkonvertierung in union-Typ von nicht in union vorhandenem Typen"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "Umwandlung in %s-Adressraumzeiger aus getrenntem allgemeinen Adressraumzeiger"
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "Umwandlung in allgemeinen Adressraumzeiger von getrenntem %s-Adressraumzeiger"
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "Umwandlung in %s-Adressraumzeiger von getrenntem %s-Adressraumzeiger"
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "Typkonvertierung erfordert Ausrichtung des Zieltyps"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "Typkonvertierung von Zeiger auf Ganzzahl anderer Breite"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "Typumwandlung von Funktionsaufruf des Typs %qT in unpassenden Typen %qT"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "Typkonvertierung in Zeiger von Ganzzahl anderer Breite"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO-C verbietet Konvertierung von Funktionszeigern in Objektzeigertyp"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO-C verbietet Konvertierung von Objektzeigertypen in Funktionszeigertyp"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "unvollständiger Funktionstyp %qT kann nicht nach %qT umgewandelt werden"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "Definition eines Typs in einer Umwandlung ist in C++ ungültig"
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "Zuweisung an Ausdruck von Arraytyp"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "enum-Umwandlung in Zuweisung ist in C++ ungültig"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(nahe der Initialisierung für %qs)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "Array mit geklammerter Zeichenkettenkonstante initialisiert"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "%qT erwartet, aber Argument hat Typ %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr "der Typ von %qD Argument %d ist %qT, der Aufruf der eingebauten Funktion, die ohne Prototyp deklariert wurde, erwartet jedoch %qT"
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr "der Typ von %qD Argument %d wird zu %qT befördert, der Aufruf der eingebauten Funktion, die ohne Prototyp deklariert wurde, erwartet jedoch %qT"
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr "eingebaute %qD ist hier deklariert"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "Enum-Umwandlung bei Übergabe des Arguments %d von %qE ist in C++ ungültig"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "enum-Umwandlung von %qT nach %qT in Zuweisung ist in C++ ungültig"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "enum-Umwandlung von %qT nach %qT in Initialisierung ist in C++ ungültig"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "enum-Umwandlung von %qT nach %qT in Rückgabe ist in C++ ungültig"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT"
 msgstr "implizite Umwandlung von %qT nach %qT"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "Übergabe des Arguments %d von %qE erzeugt aus unqualifiziertem einen qualifizierten Funktionszeiger %q#v"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "Zuweisung erzeugt aus unqualifiziertem einen qualifizierten Funktionszeiger %q#v"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "Initialisierung erzeugt aus unqualifiziertem einen qualifizierten Funktionszeiger %q#v"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "return erzeugt aus unqualifiziertem einen qualifizierten Funktionszeiger %q#v"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "Übergabe des Arguments %d von %qE entfernt Kennzeichner %qv von Zeiger-Ziel-Typ"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "Zuweisung streicht Qualifizierer %qv von Zeiger-Zieltyp"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "Initialisierung streicht Qualifizierer %qv von Zeiger-Zieltyp"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "return streicht Qualifizierer %qv von Zeiger-Zieltyp"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO-C verbietet Argumentkonvertierung in union-Typ"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "Anfrage zur impliziten für Umwandlung von %qT in %qT ist in C++ nicht erlaubt"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "Übergabe des Arguments %d von %qE von Zeiger auf nicht eingeschlossenen Adressbereich"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "Zuweisung von Zeiger auf nicht eingeschlossenen Adressbereich"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "Initialisierung von Zeiger auf nicht enthaltenen Adressraum"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "Rückgabe von Pointer auf nicht enthaltenen Adressraum"
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "Argument %d von %qE könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "Links-Zuweisung könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "Linke-Initialisierung könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "Rückgabetyp könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "Übergabe des Arguments %d von %qE von inkompatibler Speicherreihenfolge für Skalare"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "Zuweisung an %qT von Zeigertyp %qT mit inkompatibler Speicherreihenfolge für Skalare"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "Initialisierung von %qT von Zeigertyp %qT mit inkompatibler Speicherreihenfolge für Skalare"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "Rückgabe von %qT von Zeigertyp %qT mit inkompatibler Speicherreihenfolge für Skalare"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO-C verbietet Übergabe des Arguments %d von %qE zwischen Funktionszeiger und %<void *%>"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO-C verbietet Zuweisung zwischen Funktionszeiger und %<void *%>"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO-C verbietet Initialisierung zwischen Funktionszeiger und %<void *%>"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO-C verbietet return zwischen Funktionszeiger und %<void *%>"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "Zeigerziele bei Übergabe des Arguments %d von %qE unterscheiden sich im Vorzeichenbesitz"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "Zeigerziele in Zuweisung von %qT nach %qT unterscheiden sich im Vorzeichenbesitz"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "Zeigerziele in Initialisierung von %qT nach %qT unterscheiden sich im Vorzeichenbesitz"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "Zeigerziele in Rückgabe von %qT aus einer Funktion mit Rückgabetyp %qT unterscheiden sich im Vorzeichenbesitz"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "Übergabe des Arguments %d von %qE von inkompatiblem Zeigertyp"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "Zuweisung an %qT von Zeiger auf %qD mit inkompatiblem Typ %qT"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "Zuweisung an %qT von inkompatiblem Zeigertyp %qT"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "Initialisierung von %qT von Zeiger auf %qD mit inkompatiblem Typ %qT"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "Initialisierung von %qT von inkompatiblem Zeigertyp %qT"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "Rückgabe von Zeiger auf %qD vom Typ %qT aus einer Funktion mit inkompatiblem Rückgabetyp %qT"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "Rückgabe von %qT aus einer Funktion mit inkompatiblem Rückgabetyp %qT"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "Übergabe des Arguments %d von %qE wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "Zuweisung an %qT von %qT wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "Initialisierung von %qT von %qT wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "Rückgabe von %qT aus einer Funktion mit Rückgabetyp %qT wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "Übergabe des Arguments %d von %qE wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "Zuweisung an %qT aus %qT wandelt einen Zeiger in eine Ganzzahl um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "Initialisierung eines %qT aus %qT wandelt einen Zeiger in eine Zahl um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "Rückgabe von %qT aus einer Funktion mit Rückgabetyp %qT wandelt einen Zeiger in eine Zahl um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "Inkompatibler Typ für Argument %d von %qE"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "unverträgliche Typen bei Zuweisung an Typ %qT von Typ %qT"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "inkompatible Typen bei Initialisierung von Typ %qT mit Typ %qT"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "unverträgliche Typen bei Rückgabe von Typ %qT, aber %qT wurde erwartet"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "traditionelles C lehnt automatische Gesamt-Initialisierung ab"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "Initialisierung eines flexiblen Array-Elements"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "Array von %qT kann nicht aus einem Zeichenkettenliteral mit Typ %<Array von %T%> initialisiert werden"
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "Array unpassenden Typs mit Zeichenkettenkonstante initialisiert"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ungültige Verwendung eines Nicht-L-Wert-Arrays"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "Initialisierungselement ist nicht konstant"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "Array mit nicht konstantem Arrayausdruck initialisiert"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "Initialisierungselement ist kein konstanter Ausdruck"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "Initialisierungs-Element ist zur Lade-Zeit nicht berechenbar"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "ungültige Initialisierung"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opake Vektortypen können nicht initialisiert werden"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "zusätzliche geschweifte Klammern am Ende der Initialisierung"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "geschweifte Klammern um Skalar-Initialisierung"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "Initialisierung eines flexiblen Array-Elements in geschachteltem Kontext"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "geschweifte Klammern fehlen um Initialisierung"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "fehlende Initialisierung für Feld %qD von %qT fehlt"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "leere Skalar-Initialisierung"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "zusätzliche Elemente in Skalar-Initialisierung"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "Arrayindex in Nicht-Array-Initialisierung"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "Feldname nicht in Datensatz- oder union-Initialisierung"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "Arrayindex in Initialisierung hat nicht Ganzzahltyp"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "Arrayindex in Initialisierung ist kein konstanter Ganzzahlausdruck"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "nichtkonstanter Arrayindex in Initialisierung"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "Arrayindex in Initialisierung überschreitet Arraygrenzen"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "leerer Indexbereich in Initialisierung"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "Arrayindexbereich in Initialisierung überschreitet Arraygrenzen"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "initialisiertes Feld mit Seiteneffekten überschrieben"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "initialisiertes Feld überschrieben"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "enum-Umwandlung in Initialisierung ist in C++ ungültig"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, gcc-internal-format
 msgid "excess elements in %<char%> array initializer"
 msgstr "überzählige Elemente in %<char%>-Array-Initialisierung"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "Elementüberschreitung in struct-Initialisierung"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "positionelle Initialisierung eines Feldes in %<struct%>, die mit dem %<designated_init%>-Attribut deklariert wurde"
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "nicht-statische Initialisierung eines flexiblen Arrayelements"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "Elementüberschreitung in union-Initialisierung"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "traditionelles C lehnt Initialisierung von unions ab"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "Elementüberschreitung in Arrayinitialisierung"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "Elementüberschreitung in Vektorinitialisierung"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "Elementüberschreitung in Skalarinitialisierung"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO-C verbietet %<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> deklarierte Funktion hat %<return%>-Anweisung"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> ohne Wert in nicht-void zurückgebender Funktion"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> mit Wert in void zurückgebender Funktion"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO-C verbietet %<return%> mit Ausdruck, in void zurückgebender Funktion"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "Funktion liefert Adresse einer Sprungmarke zurück"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-Größe ist keine Ganzzahl"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "%<long%> switch-Ausdruck nicht nach %<int%> konvertiert in ISO C"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "»case«-Marke ist kein konstanter Ganzzahlausdruck"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-Marke nicht innerhalb einer switch-Anweisung"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>-Marke nicht innerhalb einer switch-Anweisung"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-Anweisung nicht innerhalb einer Schleife oder »switch«"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ungültiger Ausgang von strukturiertem OpenMP-Block"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-Anweisung mit OpenMP für Schleife verwendet"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-Anweisung nicht innerhalb einer Schleife"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "Anweisung ohne Effekt"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "Ausdrucksanweisung hat unvollständigen Typ"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Vergleich von Vektoren mit verschiedenen Element-Typen"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "Vergleich von Vektoren mit unterschiedlicher Elementanzahl"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "kein ganzzahliger Typ mit derselben Größe wie %qT gefunden"
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "Vergleich von Gleitkomma mit %<==%> oder %<!=%> ist unsicher"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "Vergleich wird stets als %<false%> ausgewertet da die Adresse von %qD nie NULL wird"
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "Vergleich wird stets als %<true%> ausgewertet da die Adresse von %qD nie NULL wird"
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "Vergleich von Zeigern auf disjunkte Adressräume"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO-C verbietet Vergleich von %<void *%> mit Funktionszeiger"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "in Vergleich verschiedener Zeigertypen fehlt Typkonvertierung"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "Vergleich zwischen Zeiger und Ganzzahl"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "Vergleich von vollständigen und unvollständigen Zeigern"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO-C verbietet geordnete Vergleiche zwischen Zeigern auf Funktionen"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "geordneter Vergleich von Zeiger mit Null-Zeiger"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordneter Vergleich von Zeiger mit Ganzzahlnull"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "implizite Umwandlung von %qT in %qT zur Anpassung an anderen Operanden des Binärausdrucks"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "Array, das nicht in Zeiger umgewandelt werden kann, anstelle des geforderten Skalars verwendet"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "Wert eines struct-Typs anstelle des geforderten Skalars verwendet"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "Wert eines union-Typs anstelle des geforderten Skalars verwendet"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "Vektortyp verwendet, wo Skalars benötigt wird"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "Klauselmodifizierer %<cancel%> %<if%> erwartet"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%>-Ausdruck %qE in %qs-Klausel"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "Bitfeld %qE in %qs-Klausel"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE ist ein Element eines Union-Typs"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "%qE in %qs-Klausel kann nicht dereferenziert werden"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD in %qs-Klausel muss eine Variable sein"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE in %qs-Klausel muss eine Variable sein"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%>-Deklaration %qD in %qs-Klausel"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD in %qs-Klausel ist eine threadprivate Variable"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "Untere Grenze %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Länge %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "einelnen Zeiger in %qs-Klausel erwartet"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Arrayabschnitt der Länge 0 in %qs-Klausel"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "für Arraytyp mit unbekannten Grenzen muss ein Längenausdruck angegeben werden"
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negative untere Grenze in Arrayabschnitt in %qs-Klausel"
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "Arrayabschnitt mit negativer Länge in %qs-Klausel"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "untere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "Länge %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "obere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "für Funktionsparameter vom Typ Array muss die Länge angegeben sein"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "für Zeigertyp muss der Längenausdruck angegeben werden"
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "Arrayabschnitt ist in %qs-Klausel nicht zusammenhängend"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE hat weder Zeiger- noch Arraytyp"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "Typ des Iterators %qD ist weder ganzzahlig noch ein Zeiger"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "Iterator %qD hat %<_Atomic%>-qualifizierten Typ"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "Iterator %qD hat %<const%>-qualifizierten Typ"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "Iterator-Schrittweite mit nichtganzzahligem Typ"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr "Iterator %qD hat Schrittweite 0"
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr "Typ des Iterators %qD verweist auf äußeren Iterator %qD"
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "Anfangsausdruck verweist auf äußeren Iterator %qD"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "Endausdruck verweist auf äußeren Iterator %qD"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "Ausdruck für die Schrittweite verweist auf äußeren Iterator %qD"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "Zeiger in %qs-Klausel erwartet"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "die Klausel %<inscan%> darf nicht zusammen mit nicht-%<inscan%>-%<reduction%> am selben Konstrukt vorkommen"
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "%<inscan%>-%<reduction%>-Klausel mit Arrayabschnitt"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD in %<reduction%>-Klausel ist ein Array der Länge 0"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE in %<reduction%>-Klausel"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr "Typ %qT mit Größe 0 in %qs-Klausel"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr "Typ %qT mit variabler Größe in %qs-Klausel"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE hat ungültigen Typ für %<reduction(%s)%>"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "benutzerdefinierte Reduktion für %qE nicht gefunden"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "Elementtyp variabler Länge in %<reduction%>-Klausel eines Arrays"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<nowait%>-Klausel darf nicht zusammen mit %<copyprivate%> verwendet werden"
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE muss für %<copyin%> %<threadprivate%> sein"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "Modifizierer sollte an %<simd%>- oder %<for%>-Konstrukten nicht in %<linear%>-Klausel angegeben werden"
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "»linear«-Klausel auf Variable vom Typ %qT angewendet, die weder Ganzzahl noch Zeiger ist"
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD in %<linear%>-Klausel"
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "Schrittweite %qE der %<linear%>-Klausel muss konstant oder ein Parameter sein"
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD tritt in Reduktionsklauseln mehrfach auf"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE tritt in dieser Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD tritt in Daten- und Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE ist in Klausel %<firstprivate%> keine Variable"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE ist in Klausel %<lastprivate%> keine Variable"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE ist %<aligned%>-Klausel keine Variable"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "%qE in %<aligned%>-Klausel ist weder Zeiger noch Array"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%<_Atomic%> %qD in %<aligned%>-Klausel"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE ist in %<nontemporal%>-Klausel keine Variable"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE tritt in %<nontemporal%>-Klausel mehrfach auf"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE in %<allocate%>-Klausel ist keine Variable"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE kommt mehr als einmal in %<allocate%>-Klauseln vor"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr "%<depend%>-Klausel mit %<depobj%>-Abhängigkeitstyp auf Arrayabschnitt"
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE ist weder lvalue-Ausdruck noch Arrayabschnitt in %<depend%>-Klausel"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr "%qE hat nicht den Typ %<omp_depend_t%>, in der %<depend%>-Klausel mit %<depobj%>-Abhängigkeitstyp"
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr "%qE sollte einen anderen Typ haben als %<omp_depend_t%>, in der %<depend%>-Klausel mit von %<depobj%> verschiedenem Abhängigkeitstyp"
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "Arrayabschnitt in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD tritt in Bewegungsklausel mehrfach auf"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD tritt in Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE in %qs-Klausel ist weder Variablen- noch Funktionsname"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE tritt in derselben %<declare target%>-Direktive mehrfach auf"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD in %<uniform%>-Klausel ist kein Argument"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE in %<uniform%>-Klausel ist kein Argument"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "Variable %qs muss ein Zeiger sein"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "Variable %qs ist weder Zeiger noch Array"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "%<order%>-Klausel darf nicht zusammen mit %<ordered%> verwendet werden"
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "zu viele %qs-Klauseln an einem Task-Konstrukt"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<inbranch%>-Klausel ist inkompatibel mit %<notinbranch%>"
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE ist vorbestimmt %qs für %qs"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-qualifiziertes %qE darf nur in %<shared%>- oder %<firstprivate%>-Klauseln vorkommen"
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-Klauselwert ist größer als %<safelen%>-Klauselwert"
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-Planungsmodifizierer zusammen mit %<ordered%>-Klausel angegeben"
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%qs-Klausel darf nicht zusammen mit %<inscan%>-%<reduction%>-Klausel verwendet werden"
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-Klauselschritt ist ein Parameter %qD, der nicht in der %<uniform%>-Klausel angegeben ist"
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "%<nogroup%>-Klausel darf nicht zusammen mit %<reduction%>-Klausel verwendet werden"
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "%<detach%>-Klausel darf nicht zusammen mit %<mergeable%>-Klausel verwendet werden"
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr "das Ereignishandle einer %<detach%>-Klausel sollte nicht in einer data-sharing-Klausel sein"
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "%<va_arg%> kann nicht zusammen mit umgedreher Speicherreihenfolge verwendet werden"
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "zweites Argument für %<va_arg%> ist vom unvollständigen Typ %qT"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ erfordert weitergegebenen Typ, nicht Enum-Typ, in %<va_arg%>"
@@ -45521,7 +45545,7 @@ msgstr "  keine bekannte Umwandlung von %qH nach %qI"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  keine bekannte Umwandlung für Argument %d von %qH nach %qI"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -45631,661 +45655,665 @@ msgstr "das Initialisieren von %qH mit %qI in einem umgewandelten konstanten Aus
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "Umwandlung von %qH nach %qI in einem umgewandelten konstanten Ausdruck"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%D(%A)%>"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%D(%A)%> ist nicht eindeutig"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "Zeiger auf Elementfunktion %qE kann nicht ohne Objekt aufgerufen werden; verwenden Sie beispielsweise %<.*%> oder %<->*%>"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "keine Übereinstimmung für Aufruf von %<(%T) (%A)%>"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "Aufruf von %<(%T) (%A)%> ist nicht eindeutig"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "mehrdeutiges Überladen für "
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr "keine Übereinstimmung für "
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (Operandentypen sind %qT, %qT und %qT)"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (Operandentypen sind %qT und %qT)"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (Operandentyp ist %qT)"
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "ternärer %<operator?:%>"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "ternärer %<operator?:%> in %<%E ? %E : %E%>"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> in %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> in %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs in %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%<operator %s%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator %s%> in %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> in %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> in %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO-C++ verbietet das Auslassen des mittleren Terms eines %<?:%>-Ausdrucks"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "erschlossener skalarer Typ %qT muss ein Ganzzahl- oder Gleitkommatyp derselben Größe wie %qT sein"
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "Umwandlung von Skalar %qH in Vektor %qI führt zum Abschneiden"
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "unverträgliche Vektortypen in bedingtem Ausdruck: %qT, %qT und %qT"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "zweiter Operand für Bedingungsoperator ist vom Typ %<void%>, aber der dritte Operand ist weder ein Throw-Ausdruck noch vom Typ %<void%>"
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "dritter Operand für Bedingungsoperator ist vom Typ %<void%>, aber der zweite Operand ist weder ein Throw-Ausdruck noch vom Typ %<void%>"
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "Operanden für %<?:%> haben unterschiedliche Typen %qT und %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  und jeder Typ kann zu jedem anderen konvertiert werden"
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "implizite Umwandlung von %qH in %qI, um an das Ergebnis im anderen Zweig der Bedingung anzugleichen"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "bedingter Ausdruck enthält unverträgliche Aufzählungswerte der Typen %qT und %qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "Bedingungsausdruck zwischen Aufzählungstyp %qT und Gleitkommatyp %qT ist veraltet"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "Bedingungsausdruck zwischen Gleitkommatyp %qT und Aufzählungstyp %qT ist veraltet"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "Aufzählungs- und Nicht-Aufzählungstyp in bedingtem Ausdruck"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert, stattdessen wird Präfixoperator versucht"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "in C++20 ruft dieser Vergleich die aktuelle Funktion rekursiv mit vertauschten Argumenten auf"
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "Rückgabetyp von %qD ist nicht %qs"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "als umgeschriebener Kandidat für den Vergleich von %qT und %qT verwendet"
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "Vergleich zwischen %q#T und %q#T"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "Exceptionaufräumen für dieses Placement-New wählt delete-Operator für Nicht-Placement"
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD ist eine übliche (nicht-placement) Deallokationsfunktion in C++14 (oder mit %<-fsized-deallocation%>)"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD ist eine gewöhnliche (nicht-Platzierungs) Deallokationsfunktion"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "keine passende Freigabefunktion für %qD"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "kein geeignetes %<operator %s%> für %qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D ist in diesem Zusammenhang »private«"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "hier als »private« deklariert"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D ist in diesem Zusammenhang »protected«"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "hier als »protected« deklariert"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D ist in diesem Zusammenhang unzugänglich"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Übergabe von NULL an Nicht-Zeiger-Argument %P von %qD"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  hier deklariert"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "Konvertierung in Nicht-Zeiger-Typ %qT von NULL"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%<false%> wird für Argument %P von %qD in Zeigertyp umgewandelt"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "%<false%> wird in Zeigertyp %qT umgewandelt"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  Argument %P von %qD wird initialisiert"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Umwandlungen in Arrays mit unbekannten Grenzen sind erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "zu viele geschweifte Klammern um Initialisierung für %qT"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "Umwandlung von %qH nach %qI erfordert direkte Initialisierung"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ungültige benutzerdefinierte Umwandlung von %qH in %qI"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "ungültige Umwandlung von %qH in %qI"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "Umwandlung in %qT von Initialisierungsliste würde expliziten Konstruktor %qD verwenden"
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "in C++11 und neuer kann ein Defaultkonstruktor explizit sein"
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "rvalue-Referenz vom Typ %qH kann nicht an lvalue vom Typ %qI gebunden werden"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "nicht-konstante lvalue-Referenz vom Typ %qH kann nicht an Wert vom Typ %qI gebunden werden"
+
+#: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "nicht-konstante lvalue-Referenz vom Typ %qH kann nicht an rvalue vom Typ %qI gebunden werden"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "Referenz vom Typ %qH kann nicht an %qI gebunden werden, da die Arraygrenzen sich unterscheiden"
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "das Binden der Referenz vom Typ %qH an %qI streicht Qualifizierer"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "das Bitfeld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "das gepackte Feld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "der R-Wert %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "implizite Umwandlung von %qH in %qI bei Übergabe von Argument an Funktion"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "enum %qT mit eingeschränkter Sichtbarkeit wird vor %<-fabi-version=6%> als Typ %qT, später jedoch als %qT durch %<...%> übergeben"
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "Das Übergeben des nicht trivial-kopierbaren Typs %q#T über %<...%> ist »conditionally-supported« ([expr.call] 5.2.2/7)"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "Referenztyp %qT kann nicht über %<...%> empfangen werden"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "Das Übergeben des nicht trivial-kopierbaren Typs %q#T über %<...%> ist »conditionally-supported« ([expr.call] 5.2.2/7)"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursive Auswertung des Standardarguments für %q#D"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "Aufruf von %qD verwendet das Standardargument für Parameter %P, der noch nicht definiert wurde"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Argument des Funktionsaufrufs könnte Kandidat für Formatattribut sein"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "Verwendung einer multiversionierten Funktion ohne Standardargument"
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "Die Übergabe von %qT als %<this%>-Argument streicht Qualifizierer"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  in Aufruf von %qD"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT ist keine erreichbare Basis von %qT"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Argumente werden an Auslassungspunkte des geerbten Konstruktors %qD übergeben"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "Zuweisung von temporärer %<initializer_list%> führt nicht dazu, dass die Lebenszeit des zugrundeliegenden Arrays ausgeweitet wird"
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT ohne triviale Kopierzuweisung"
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD Schreiben in ein Objekt des nichttrivialen Typs %#qT%s"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT mit Element %qs %qD"
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT, das einen Zeiger auf Datenelement enthält%s"
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Zuweisung oder Wertinitialisierung"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; verwenden Sie stattdessen eine Zuweisung"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Wertinitialisierung"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD Säubern eines Objekts des Typs %#qT ohne triviale Kopierzuweisung%s"
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD Säubern eines Objekts von nichttrivialem Typ %#qT%s"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD Säubern eines Objekts des Typs %#qT, das einen Zeiger auf Datenelement enthält%s"
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Kopierzuweisung oder Kopierinitialisierung"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; verwenden Sie stattdessen eine Kopierzuweisung"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Kopierinitialisierung"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT ohne triviale Kopierzuweisung%s"
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD Schreiben in ein Objekt des nichttrivial kopierbaren Typs %#qT%s"
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD Schreibzugriff auf ein Objekt mit einem gelöschten Kopierkonstruktor"
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD Kopieren eines Objekts mit nichttrivialem Typ %#qT aus einem Array von %#qT"
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD Kopieren eines Objekts des Typs %#qT mit Element %qs %qD aus einem Array von %#qT; verwenden Sie eine Zuweisung oder Kopierinitialisierung stattdessen"
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD Schreiben in ein Objekt eines nichttrivialen Typen %#qT lässt %wu Bytes unverändert"
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD Schreiben in ein Objekt eines nichttrivialen Typen %#qT lässt %wu Byte unverändert"
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD Verschieben eines Objekts des nichttrivial kopierbaren Typs %#qT; verwenden Sie stattdessen %<new%> oder %<delete%>"
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD Verschieben eines Objekts des Typs %#qT mit gelöschtem Kopierkonstruktor; verwenden Sie stattdessen %<new%> und %<delete%>"
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD Verschieben eines Objekts des Typs %#qT mit gelöschtem Destruktor"
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD Verschieben eines Objekts des nichttrivialen Typs %#qT und Größe %E in eine Region der Größe %E"
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT wird hier deklariert"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "Konstruktor verweist auf sich selbst"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 msgid "cannot convert %qH to %qI"
 msgstr "%qH kann nicht nach %qI umgewandelt werden"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "Aufruf der Nicht-Funktion %qD"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "Konstruktor %<%T::%D%> kann nicht direkt aufgerufen werden"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "um eine funktionsartige Umwandlung zu erreichen, entfernen Sie das redundante %<::%D%>"
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%s(%A)%>"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%s(%A)%> ist mehrdeutig"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtuelle %q#D aus nichtstatischem Datenelement-Initialisierer heraus aufgerufen"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtuelle %q#D aus Konstruktor heraus aufgerufen"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtuelle %q#D aus Destruktor heraus aufgerufen"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "Elementfunktion %qD kann nicht ohne Objekt aufgerufen werden"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "Übergabe von %qT wählt %qT statt %qT"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "Wahl von %qD statt %qD"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 msgid "  for conversion from %qH to %qI"
 msgstr "  für Umwandlung von %qH in %qI"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  denn die Umwandlungsfolge für das Argument ist besser"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "Zuordnungsfehler der Standardargumente in Überladungsauflösung"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " Kandidat 1: %q#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " Kandidat 2: %q#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ besagt, dass diese mehrdeutig sind, auch wenn die schlechteste Umwandlung für das erste besser ist als die schlechteste Umwandlung für das zweite:"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "eine vorübergehende Bindung an %qD besteht nur, bis der Konstruktor beendet ist"
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ungültige Initialisierung einer nicht-konstanten Referenz des Typs %qH von rvalue des Typs %qI"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ungültige Initialisierung einer Referenz des Typs %qH von Ausdruck des Typs %qI"
 
@@ -46309,1126 +46337,1126 @@ msgstr "Umwandlung von Zeiger auf Basisklasse %qT in Zeiger auf abgeleitete Klas
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "Umwandlung von Basisklasse %qT in abgeleitete Klasse %qT nicht möglich, da die Basisklasse %qT virtuell ist"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "Umwandlung von %qT in Basisklasse %qT nicht möglich, da %qT unvollständig ist"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D steht in Konflikt mit von %qT geerbter Version"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "von %qT geerbte Version ist hier deklariert"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D kann nicht mit %q#D überladen werden"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "vorherige Deklaration von %q#D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "Zugriffsangaben für Methode %q+D stehen in Konflikt, ignoriert"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "Zugriffsangaben für Feld %qE stehen in Konflikt, ignoriert"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "%qD ist in %q#T ungültig wegen lokaler Methode %q#D mit gleichem Namen"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "lokale Methode %q#D ist hier deklariert"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "%qD ist ungültig in %q#T wegen lokalem Element %q#D mit gleichem Namen"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "lokales Element %q#D ist hier deklariert"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD erbt das %E-ABI-Tag, das %qT (im Rückgabetyp verwendet) hat"
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT hier deklariert"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD erbt das %E-ABI-Tag, das %qT (im Typ verwendet) hat"
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qT hat nicht das ABI-Tag %E, das die Basis %qT hat"
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qT hat nicht das ABI-Tag %E, das %qT (im Typ von %qD verwendet) hat"
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "Es kann nicht von %<final%>-Basis %qT in abgeleiteten Typ %qT abgeleitet werden"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "alle Elementfunktionen in Klasse %qT sind privat"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T definiert nur einen privaten Destruktor und hat keine »friends«"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T definiert nur private Konstruktoren und hat keine »friends«"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D ist %<public%>, benötigt jedoch ein existierendes Objekt vom Typ %q#T"
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD wurde nicht eindeutig und endgültig in %qT überschrieben"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD kann als »override« markiert werden"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D als %<override%> markiert, überschreibt aber nicht"
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D als %<final%> markiert, ist aber nicht »virtual«"
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD war versteckt"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  von %qD"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ungültig; eine anonyme Union kann nur nicht-statische Datenelemente haben"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "diese Flexibilität ist veraltet und wird demnächst entfernt"
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "die Auslassung in %qD wurde nicht vererbt"
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "Bitfeld %q#D mit Nicht-Ganzzahl-Typ %qT"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "Breite des Bitfeldes %q+D ist keine Ganzzahlkonstante"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "negative Breite in Bitfeld %q+D"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "Breite Null für Bitfeld %q+D"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "Breite von %qD übersteigt seinen Typen"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD ist zu klein, um alle Werte von %q#T aufzunehmen"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "Element %q+#D mit Konstruktor nicht erlaubt in Union"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "Element %q+#D mit Destruktor nicht erlaubt in Union"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "Element %q+#D mit Copy-Zuweisungsoperator ist nicht erlaubt in Union"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "uneingeschränkte »Unions« sind nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D kann in C++98 nicht static sein, da es ein Union-Element ist"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "nicht-statisches Datenelement %q+D in einer Union darf keinen Referenztypen %qT haben"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "Datenelement %q+D hat ungültigerweise einen Funktionstypen deklariert"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "Datenelement %q+D hat ungültigerweise einen Methodentyp deklariert"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "»packed«-Attribut für ungepacktes nicht-POD-Feld %q#D wird ignoriert"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "Element %q+D darf nicht als %<mutable%>-Referenz deklariert sein"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "Element %q+D darf nicht gleichzeitig als %<const%> und %<mutable%> deklariert sein"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "in Union %qT werden mehrere Felder initialisiert"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "das initialisierte Element %q+D wurde hier deklariert"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "Feld %q#D mit gleichem Namen wie Klasse"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T hat Zeigertypen als Elemente"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  aber deklariert %<%T(const %T&)%> nicht"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  oder %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  aber deklariert %<operator=(const %T&)%> nicht"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "das Zeigerelement %q+D wurde hier deklariert"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "Ausrichtung von %qD wurde in %<-fabi-version=9%> (GCC 5.2) erhöht"
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "Ausrichtung von %qD wird in %<-fabi-version=9%> ansteigen"
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Initialisierung für nicht-virtuelle Methode %q+D angegeben"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "Destruktor für %qT ist mehrdeutig"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "Methode überschreibt Methoden %<transaction_pure%> und %qE"
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "als %qE deklarierte Methode überschreibt Methode %qE"
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "umschließende Klasse der %<constexpr%> nicht-statischen Elementfunktion %q+#D ist kein Literaltyp"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T ist kein Literal, denn: "
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT is a Closure-Typ und ist erst ab C++17 literal"
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T hat einen nicht-trivialen Destruktor"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T hat keinen %<constexpr%>-Destruktor"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T ist kein Aggregat, hat keinen trivialen Standardkonstruktor und hat keinen %<constexpr%>-Konstruktor, der kein Kopier- oder Bewegungskonstruktor ist"
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  Basisklasse %qT von %q+T ist kein Literal"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  nicht-statisches Datenelement %qD hat nicht-literalen Typ"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  nicht-statisches Datenelement %qD hat nicht-literalen Typ"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Basisklasse %q#T hat einen zugänglichen nicht-virtuellen Destruktor"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "nicht-statische Referenz %q#D in Klasse ohne Konstruktor"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "nicht-statisches const-Element %q#D in Klasse ohne einen Konstruktor"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuelle Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "Offset von %qD ist ABI-unverträglich und kann sich in zukünftigen GCC-Versionen ändern"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "Größe des Typs %qT ist zu groß (%qE Bytes)"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ungültige Verwendung von %q#T mit Array der Größe 0 in %q#D"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ungültige Verwendung von %q#T mit flexiblem Arrayelement in %q#T"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "Arrayelement %q#D hier deklariert"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "Arrayelement %qD mit Länge 0 befindet sich nicht am Ende von %q#T"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "Arrayelement %qD mit Länge 0 in ansonsten leerem %q#T"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "in der Definition von %q#T"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexibles Arrayelement %qD nicht am Ende von %q#T"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexibles Arrayelement %qD in ansonsten leerem %q#T"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "nächstes Feld %q#D hier deklariert"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "Redefinition von %q#T"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T hat virtuelle Funktionen und erreichbaren nicht-virtuellen Destruktor"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typtransparentes %q#T hat keine Felder"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "typtransparente Klasse %qT hat Basisklassen"
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "typtransparente Klasse %qT hat virtuelle Funktionen"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparentes %q#T kann nicht transparent gemacht werden, weil der Typ des ersten Feldes anderes ABI als gesamte Klasse hat"
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "Definition von %qD entspricht nicht %<#include <initializer_list>%>"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "Lesen der struct konnte wegen Syntaxfehlern nicht beendet werden"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "Sprachen-Zeichenkette %<\"%E\"%> nicht erkannt"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "überladene Funktion %qD konnte nicht durch Umwandlung in Typ %qT aufgelöst werden"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "bei der Umwandlung der Funktion %qD in den Typ %q#T gab es keine Übereinstimmungen"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "Umwandung der überladenen Funktion %qD in den Typ %q#T ist mehrdeutig"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "Zeiger auf Element %qD wird angenommen"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(ein Zeiger auf ein Element kann nur mit %<»&%E%> erzeugt werden)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "zu wenig Typinformationen"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE kann nicht vom Typ %qT in den Typ %qT umgewandelt werden"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "Deklaration von %q#D ändert die Bedeutung von %qD"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%qD wurde hier als %q#D deklariert"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "der Typ %qT der %<constexpr%>-Variable %qD ist kein Literal"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "Variable %qD des nicht-literalen Typs %qT in %<constexpr%>-Funktion"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "%<constexpr%>-Variable %qD hat variabel modifizierten Typ %qT"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "geerbter Konstruktor %qD ist nicht %<constexpr%>"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "ungültiger Typ für Parameter %d der %<constexpr%>-Funktion %q+#D"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "Lambdas sind erst ab C++17 implizit %<constexpr%>"
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "ungültiger Rückgabetyp %qT der %<constexpr%>-Funktion %q+D"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T hat virtuelle Basisklassen"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr "%<constexpr%>-Konstruktor hat keinen leeren Körper"
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%>-Konstruktor für Union %qT muss genau ein nicht-statisches Datenelement initialisieren"
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "Element %qD in %<constexpr%> muss von »mem-initializer« initialisiert werden"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr "Körper der %<constexpr%>-Funktion %qD ist keine Rückgabeanweisung"
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD ist nicht als %<constexpr%>-Funktion verwendbar, denn:"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "Kontrollfluss für %<constexpr%>-Aufruf fällt hinten aus der Funktion"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "Aufruf für interne Funktion %qE"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "in einem konstanten Ausdruck ist es nicht erlaubt, das %<const%>-Objekt %qE zu verändern"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr "wurde ursprünglich hier als %<const%> deklariert"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr "%<dynamic_cast%> auf Referenz fehlgeschlagen"
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "dynamischer Typ %qT seines Operanden hat keine Basisklasse vom Typ %qT"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr "Zeiger auf Virtuelle Tabelle wird uninitialisiert verwendet"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr "der statische Typ %qT des Operanden ist eine nicht öffentliche Basisklasse des dynamischen Typs %qT"
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "%qT ist eine mehrdeutige Basisklasse des dynamischen Typen %qT seines Operanden"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "der dynamische Typ %qT des Operanden hat keine eindeutige öffentliche Basisklasse %qT"
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "Aufruf der nicht-%<constexpr%>-Funktion %qD"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "Ausdruck %qE bezeichnet keine %<constexpr%>-Funktion"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr "Array-Deallokation eines Objekts, das mit einer Nicht-Array-Allokation alloziert wurde"
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, gcc-internal-format
 msgid "allocation performed here"
 msgstr "die Allokation ist hier"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr "Nicht-Array-Deallokation eines Objekts, das mit Array-Allokation allokiert wurde"
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr "Versuch, bereits freigegebenen Speicher freizugeben"
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr "Speicher, der vorher nicht angefordert wurde, wird freigegeben"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD in konstantem Ausdruck aufgerufen, bevor die Definition vollständig war"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD in konstantem Ausdruck aufgerufen"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD vor seiner Definition verwendet"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "Aufruf hat ringförmige Abhängigkeit"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "Auswertungstiefe von %<constexpr%> überschreitet Höchstwert %d (%<-fconstexpr-depth=%> verwenden, um dies zu erhöhen)"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "rechter Operand des Schiebeausdrucks %q+E ist negativ"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "rechter Operand des Schiebeausdrucks %q+E ist mindestens so groß wie die Genauigkeit %wu des linken Operanden"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "linker Operand des Schiebeausdrucks %q+E ist negativ"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "Schiebeausdruck %q+E läuft über"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "Arithmetik mit Nullzeiger in %qE"
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "Arrayindexwert %qE ist außerhalb der Grenzen des Arrays %qD vom Typ %qT"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "Arrayindex %qE ist ungleich 0 und wird mit Array %qD vom Typ %qT mit unbekannten Grenzen verwendet"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "Arrayindexwert %qE ist außerhalb der Grenzen des Arraytyps %qT"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "Arrayindex %qE ist ungleich 0 und wird mit Array vom Typ %qT mit unbekannten Grenzen verwendet"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "Zugriff auf uninitialisiertes Arrayelement"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Dereferenzierung eines Nullzeigers in %qE"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "veränderliches %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "Zugriff auf uninitialisiertes Element %qD"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "Zugriff auf Element %qD statt auf initialisiertes Element %qD in Konstantenausdruck"
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein union-Typ ist"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT einen union-Typen enthält"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein Zeigertyp ist"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT einen Zeigertyp enthält"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein Referenztyp ist"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT einen Referenztypen enthält"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein Zeiger-auf-Element-Typ ist"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT einen Zeiger-auf-Element-Typen enthält"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT %<volatile%> ist"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein %<volatile%>-Teilobjekt enthält"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%qs kann auf diesem Ziel nicht als konstanter Ausdruck ausgewertet werden"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr "%qs kann nicht als konstanter Ausdruck ausgewertet werden, da der Typ zu groß ist"
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qs kann nicht als konstanter Ausdruck ausgewertet werden, da das Argument nicht codiert werden kann"
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "%qs greift auf das uninitialisierte Byte an Offset %d zu"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs kann nicht als konstanter Ausdruck ausgewertet werden, da das Argument nicht interpretiert werden kann"
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "Dereferenzierung eines Null-Zeigers"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "auf Wert von %qE wird über ein %qT GL-Wert in Konstantenausdruck zugegriffen"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "der Wert von uninitialisiertem Speicher ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "wurde hier deklariert"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "angeforderter Speicher wird in konstantem Ausdruck verwendet, nachdem er wieder freigegeben wurde"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "der Wert von %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD in seiner eigenen Initialisierung verwendet"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D ist nicht konstant"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D ist volatile"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD wurde nicht mit konstantem Ausdruck initialisiert"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD wurde nicht als %<constexpr%> definiert"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD hat keinen Ganzzahl- oder Aufzählungstyp"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "Modifikation von %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "Änderung des aktiven Elements einer union von %qD zu %qD"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Änderung des aktiven Elements einer union von %qD zu %qD während der Initialisierung"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "Anweisung ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "Anzahl der Schleifendurchläufe in %<constexpr%> überschreitet Höchstwert %d (%<-fconstexpr-loop-limit=%> verwenden, um diesen zu erhöhen)"
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "Inline-Assembler ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr "in einer %<constexpr%>-Funktion in C++20 darf Inline-Assemblercode nur vorkommen, wenn er nicht im Auswertungspfad liegt"
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Wert %qE vom Typ %qT ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "Anzahl der Evaluierungsoperationen in %<constexpr%> überschreitet Höchstwert %wd (%<-fconstexpr-ops-limit=%> verwenden, um diesen zu erhöhen)"
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "Zwischenergebnis des nicht-literalen Typs %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "Ein %<reinterpret_cast%> ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Umwandlung von Zeigertyp %qT in arithmetischen Typ %qT in Konstantenausdruck"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "Cast von %qT ist nicht erlaubt"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "Ausdruck %qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "unerwartete Template-ID %qE"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "Funktionskonzept muss aufgerufen werden"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "Adresse des Aufrufs von %qs ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "unexpected expression %qE of kind %s"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE ist kein Konstantenausdruck, da er auf veränderliche Teilobjekte von %qT verweist"
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE ist kein Konstantenausdruck, da er auf eine unvollständig initialisierte Variable verweist"
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE ist kein konstanter Ausdruck, da er auf das Ergebnis von %<operator new%> verweist"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE ist kein konstanter Ausdruck, da der angeforderte Speicher nicht vollständig freigegeben wurde"
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "unmittelbare Auswertung liefert die Adresse der unmittelbaren Funktion %qD"
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "Umwandlung lvalue-in-rvalue eines volatile-lvalue %qE mit Typ %qT"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Lambda-Einfangen von %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "da er als glvalue verwendet wird"
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> von Ganzzahl zu Zeiger"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "Adresse eines Objektes %qE mit thread-lokalem oder automatischem Speicher ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "Verwendung von %<this%> in Konstantenausdruck"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Lambda-Ausdruck ist erst ab C++17 ein konstanter Ausdruck"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "virtuelle Funktionen können erst mit C++20 %<constexpr%> sein"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<typeid%> ist kein konstanter Ausdruck, da %qE polymorphen Typ hat"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Umwandlung in Nicht-Ganzzahltyp %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<static%> deklariert"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<thread_local%> deklariert"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Division durch Null ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "nicht konstante Arrayinitialisierung"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "Definition einer Sprungmarke ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "unerwarteter AST der Art %s"
@@ -47438,52 +47466,52 @@ msgstr "unerwarteter AST der Art %s"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr "beide Zweige der %<if%>-Anweisung als %qs markiert"
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> wird immer %<terminate%> aufrufen"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "in C++11 sind Destruktoren standardmäßig %<noexcept%>"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "in C++11 ruft dieses %<throw%> %<terminate%> auf, da Destruktoren standardmäßig %<noexcept%> sind"
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "Attribut %qE wird nach dem früheren %qE ignoriert"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD ist kein Typ"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD ist kein Klassentyp"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD hat nicht den Typ %<const char *%>"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD hat keinen Ganzzahltyp"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> enthält nicht nur nicht-statische Datenelemente %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> und %<_M_column%>"
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "%qs wird ausgewertet"
@@ -47524,7 +47552,7 @@ msgstr "Umwandlung in nicht-konstanten Referenztyp %q#T von R-Wert des Typs %qT"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "Umwandlung von %qH in %qI löscht Qualifizierer"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Umwandlung von %qT in %qT dereferenziert nicht den Zeiger"
@@ -47908,7 +47936,7 @@ msgstr "von vorheriger Deklaration %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "Redeklaration %qD unterscheidet sich in %qs von vorheriger Deklaration"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "vorherige Deklaration %qD"
@@ -48038,8 +48066,8 @@ msgstr "vorherige Deklaration von %<pragma omp declare reduction%>"
 msgid "%q#D previously defined here"
 msgstr "%q#D wurde bereits hier definiert"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D wurde bereits hier deklariert"
@@ -48074,52 +48102,52 @@ msgstr "Standardargument für Parameter %d von %q#D angegeben"
 msgid "previous specification in %q#D here"
 msgstr "bisherige Spezifikation in %q+#D hier"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr "Deklaration %qD widerspricht der eingebauten Deklaration"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr "Deklaration %qD widerspricht dem Import"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr "der Import hat %q#D hier deklariert"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
 msgstr "in Konflikt stehende Export-Deklaration %qD"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr "vorherige Deklaration von %q#D ist hier"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "vorherige Definition von %qD war hier"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "vorherige Deklaration von %qD war hier"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "Funktion %qD wurde als %<[[noreturn]]%> deklariert, das weicht von der ersten Deklaration ab"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "redundante Redeklaration von %qD im selben Gültigkeitsbereich"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "gelöschte Definition von %qD ist nicht die erste Deklaration"
@@ -48132,48 +48160,48 @@ msgstr "gelöschte Definition von %qD ist nicht die erste Deklaration"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "explizite Spezialisierung von %qD nach erster Verwendung"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: Sichtbarkeitsattribut ignoriert, da es in Konflikt mit vorheriger Deklaration steht"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "Redefinition von %q#D"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD steht mit verwendeter Funktion in Konflikt"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D nicht in Klasse deklariert"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D mit Attribut %<gnu_inline%> »inline« redeklariert"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D ohne Attribut %<gnu_inline%> »inline« redeklariert"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr "Herleitungshinweis %q+D neudeklariert"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "Vergleichsoperator %q+D mit Standardimplementierung nach der ersten Deklaration [class.compare.default]"
@@ -48181,2301 +48209,2316 @@ msgstr "Vergleichsoperator %q+D mit Standardimplementierung nach der ersten Dekl
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "Redeklaration des »friend« %q#D kann keine Standardtemplateargumente haben"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "Thread-lokale Deklaration von %q#D folgt nicht-Thread-lokaler Deklaration"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "Nicht-Thread-lokale Deklaration von %q#D folgt Thread-lokaler Deklaration"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "Redeklaration von %q#D"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "redundante Redeklaration von %<constexpr%>static-Datenmember %qD"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "lokale Sprungmarke %qE steht in Konflikt mit bestehender Sprungmarke"
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr "vorherige Sprungmarke"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  von hier"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  beendet OpenMP-strukturierten Block"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  überschneidet Initialisierung von %q#D"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  Eintritt in Gültigkeitsbereich von %q#D mit nicht-trivialem Destruktor"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  betritt %<try%>-Block"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  betritt %<catch%>-Block"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  tritt in OpenMP-strukturierten Block ein"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  synchronisierte oder atomare Anweisung wird betreten"
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  betritt %<constexpr if%>-Anweisung"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  überspringt Initialisierung von %q#D"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  Eintritt in Gültigkeitsbereich von %q#D mit nicht-trivialem Destruktor"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD wird ohne Template-Argumente verwendet"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, gcc-internal-format
+msgid "%qD is a function, not a type"
+msgstr "%qD ist eine Funktion, kein Typ"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T ist keine Klasse"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "kein Klassentemplate namens %q#T in %q#T"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "kein Typ namens %q#T in %q#T"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "Nachschlagen von %qT in %qT ist nicht eindeutig"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> benennt %q#T, was kein Klassentemplate ist"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> benennt %q#T, was kein Typ ist"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "Template-Parameter passen nicht zum Template %qD"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> ist keine Zweierpotenz"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Konstruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Destruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Zuweisungsoperator ist in anonymem Aggregt nicht erlaubt"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "Attribut in Deklaration von %q#T ignoriert"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "Attribut für %q#T muss dem Schlüsselwort %qs folgen"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "mehrere Typen in einer Deklaration"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "Redeklaration des eingebauten C++-Typs %qT"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kann nur für Variablen oder Funktionsdeklarationen angegeben werden"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "fehlender Typname in typedef-Deklaration"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO-C++ verbietet anonyme structs"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kann nur innerhalb einer Klasse angegeben werden"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kann nur für Konstruktoren angegeben werden"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "eine Speicherklasse kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> wurde in dieser Deklaration ignoriert"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs kann nicht für Typdeklarationen verwendet werden"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "Attribut in expliter Instanziierung %q#T ignoriert"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "auf explizite Instanziierung kann kein Attribut angewendet werden"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "auf Klassentyp %qT angewandte Attribute außerhalb einer Definition werden ignoriert"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "auf abhängigen Typ %qT angewandte Attribute ohne zugehörige Deklaration werden ignoriert"
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD ist initialisiert (stattdessen %qs verwenden)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "Deklaration von %q#D hat %<extern%> und ist initialisiert"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "Definition von %q#D ist als %<dllimport%> markiert"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D ist kein static-Datenelement von %q#T"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "Nichtelement-Templatedeklaration von %qD"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "entspricht nicht der Element-Templatedeklaration hier"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO-C++ erlaubt nicht, %<%T::%D%> als %<%T::%D%> zu definieren"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "doppelte Initialisierung von %qD"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "Deklaration von %q#D außerhalb einer Klasse ist keine Definition"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr "extern-Deklaration %q#D mit Gültigkeitsbereich Block ist im Zuständigkeitsbereich des Moduls nicht erlaubt"
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qD in %qs-Funktion als %<thread_local%> deklariert"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qD in %qs-Funktion als %<static%> deklariert"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "Variable %q#D hat Initialisierung, aber unvollständigen Typ"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "Elemente des Arrays %q#D haben unvollständigen Typ"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "Aggregat %q#D hat unvollständigen Typ und kann nicht definiert werden"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD als Referenz deklariert, aber nicht initialisiert"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "Name in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "Name %qD in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "nicht-trivial markierte Initialisierungen nicht unterstützt"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-Designator %qE ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "Initialisierung gibt nicht die Größe von %qD an"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "Arraygröße fehlt in %qD"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "Array %qD der Größe null"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Speichergröße von %qD ist unbekannt"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Speichergröße von %qD ist nicht konstant"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik der Inline-Variable %q#D ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik von static-Variable %q#D in inline-Funktion ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "dies kann durch das Löschen der Initialisierung umgangen werden"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "nicht initialisiertes %<const %D%>"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Funktion"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Kontext"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T hat keinen benutzerdefinierten Default-Konstruktor"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "Konstruktor ist nicht benutzerdefiniert, da er im Klassenkörper ausdrücklich standardisiert ist"
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "und der implizit definierte Konstruktor initialisiert %q#D nicht"
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Ungültiger Typ %qT als Initialisierung für einen Vektor des Typs %qT"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "Initialisierung für %qT muss geklammert sein"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> in benannter Initialisierung im GNU-Stil für Klasse %qT verwendet"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT hat kein nicht-statisches Datenelement namens %qD"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ungültige Initialisierung für %q#D"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-Bezeichner %qE außerhalb von Aggregatinitialisierung"
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "zu viele Initialisierer für %qT"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90182
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "zu viele geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "geschweifte Klammern fehlen um Initialisierung für %qT"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "Strukturierte Bindung hat unvollständigen Typen %qT"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "Elemente des Arrays %q#T haben unvollständigen Typ"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "zusammengesetztes Literal variabler Größe"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D hat unvollständigen Typ"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalares Objekt %qD erfordert ein Element in Initialisierung"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "in C++98 muss %qD mit Konstruktor initialisiert werden, nicht mit %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "Array %qD mit geklammerter Zeichenkettenkonstante %qE initialisiert"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "Initialisierung ungültig für statisches Element mit Konstruktor"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(eine Initialisierung außerhalb der Klasse ist erforderlich)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "Referenz %qD wird mit sich selbst initialisiert"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "Variantendeklaration nicht gefunden"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> für Konstruktor %qD"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> für Destruktor %qD"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> an %qD mit Vorgabewert"
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> an gelöschter %qD"
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> an virtueller %qD"
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "Zuweisung (nicht Initialisierung) in Deklaration"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO-C++17 erlaubt Speicherklassenangabe %<register%> nicht"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-Speicherklassenangabe verwendet"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "Initialisierung für %<decltype(auto) %D%> hat Funktionstyp; %<()%> vergessen?"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "Variablenkonzept hat keine Initialisierung"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "vorherige Typdeklaration von %q#D wird überschattet"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "Attribut %<constinit%> kann nur für Variablen verwendet werden, die »static« oder threadlokel sind"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "Funktion %q#D ist wie eine Variable initialisiert"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Strukturelement hat"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Unionelement hat"
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "unzugreifbares Element %qD von %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da sowohl er als auch seine Basisklasse %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da seine Basisklassen %qT und %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Typen %qT"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "Array mit variabler Länge %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u Name für strukturelle Bindung angegeben"
 msgstr[1] "%u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "nur %u Name für strukturelle Bindung angegeben"
 msgstr[1] "nur %u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "während %qT in %wu Element zerlegt wird"
 msgstr[1] "während %qT in %wu Elemente zerlegt wird"
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "Vektor %qT variabler Länge kann nicht zerlegt werden"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "während %qT in %E Elemente zerlegt wird"
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr "%<std::tuple_element<%u, %T>::type%> ist %<void%>"
+
+#: cp/decl.c:8646
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "in Initialisierung der Variable %qD für strukturierte Bindung"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "Union-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "nicht-Array-nicht-Klassentyp %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Lambda-Abschluss-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Klassentypen %qT"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "Klassentyp %qT ohne nicht-static-Datenelemente kann nicht dekomponiert werden"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "nicht-lokale %<__thread%>-Variable %qD erfordert dynamische Initialisierung"
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "nicht-lokale %<__thread%>-Variable %qD hat einen nicht-trivialen Destruktor"
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> in C++11 erlaubt dynamische Initialisierung und Zerstörung"
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Initialisierung gibt nicht die Größe von %qT an"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "Arraygröße fehlt in %qT"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "Array %qT der Größe null"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Destruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Konstruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD als eine %<virtual%> Variable deklariert"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Variablendeklaration"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD als ein %<virtual%> Parameter deklariert"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD als ein %<inline%> Parameter deklariert"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Parameterdeklaration"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD als ein %<virtual%> Typ deklariert"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD als ein %<inline%> Typ deklariert"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Typdeklaration"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD als ein %<virtual%> Feld deklariert"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD als ein %<inline%> Feld deklariert"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Felddeklaration"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D als »friend« deklariert"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D mit einer Ausnahmespezifikation deklariert"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "Deklaration von %qD ist nicht in einem Namensbereich um %qT"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statische Elementfunktion %q#D mit Typqualifizierern deklariert"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "Konzept %q#D mit Funktionsparametern deklariert"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "Konzept %q#D mit hergeleitetem Rückgabetyp deklariert"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Konzept %q#D mit nicht-%<bool%>-Rückgabetyp %qT"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "Konzept %qD hat keine Definition"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "ein Funktionskonzept kann nicht eingeschränkt werden"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "Einschränkungen auf einer Funktion, die kein Template hat"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "Definition der expliziten Spezialisierung %qD in friend-Deklaration"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ungültige Verwendung der Template-ID %qD in Deklaration des ursprünglichen Templates"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "Standardargumente sind nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> ist nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "»friend«-Deklaration von %qD gibt Defaultargumente an und ist keine Definition"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> kann nicht als Template deklariert werden"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> kann nicht inline deklariert werden"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "%<::main%> kann nicht als %qs deklariert werden"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> kann nicht statisch deklariert werden"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statische Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statische Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "Herleitungshinweis %qD muss im Gültigkeitsbereich des Namensbereiches auftreten"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "Herleitungshinweis %qD muss im selben Gültigkeitsbereich wie %qT deklariert sein"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "Herleitungshinweis %qD darf keinen Funktionskörper haben"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "literaler Operator mit C-Bindung"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD hat ungültige Argumentliste"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "Ganzzahl-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "Gleitkomma-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "Literale Operator-Suffixe ohne vorangehendes %<_%> sind für zukünftige Standardisierungen reserviert"
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD muss eine Nicht-Elementfunktion sein"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> muss %<int%> zurückgeben"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "Definition des implizit deklarierten %qD"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "Definition des explizit standardisierten %q+D"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D wurde hat hier ausdrücklichen Standardwert bekommen"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "keine Elementfunktion %q#D in Klasse %qT deklariert"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> kann nicht als globale Variable deklariert werden"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "eine Nicht-Template-Variable kann nicht %<concept%> sein"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr "Konzept muss im Gültigkeitsbereich des Namensbereiches definiert werden"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "Konzept muss Typ %<bool%> haben"
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "ein Variablenkonzept kann nicht eingeschränkt werden"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit unvollständigem Typ"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> erforderlich für Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ungültige Initialisierung innerhalb der Klasse des statischen Datenelements vom nicht eingebauten Typen %qT"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO-C++ verbietet Initialisierung des nicht konstanten statischen Elements %qD in der Klasse"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO-C++ verbietet Initialisierung der Elementkonstante %qD vom nicht eingebauten Typen %qT"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "Arraygröße von %qD hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "Arraygröße hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "Größe des Arrays %qD ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "Größe des Arrays ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO-C++ verbietet Array %qD der Größe null"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO-C++ verbietet Array der Größe null"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO-C++ verbietet Array %qD variabler Länge"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO-C++ verbietet Array variabler Länge"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "Array %qD variabler Länge wird verwendet"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "Array variabler Größe wird verwendet"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "Überlauf in Arraygröße"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD als Array von %qT deklariert"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "Array von %qT wird erzeugt"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "Deklaration von %qD als Array von voids"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "Array von void wird erzeugt"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "Deklaration von %qD als Array von Funktionen"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "Array von Funktionen wird erzeugt"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "Deklaration von %qD als Array von Referenzen"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "Feld von Referenzen wird erzeugt"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "Deklaration von %qD als Feld von Funktionselementen"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "Feld von Funktionselementen wird erzeugt"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von %qD als multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "Angabe des Rückgabetyps für Konstruktor ist ungültig"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Qualifizierer sind bei Konstruktordeklarationen nicht erlaubt"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "Angabe des Rückgabetyps für Destruktor ist ungültig"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "Qualifizierer sind bei Destruktordeklarationen nicht erlaubt"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "Rückgabetyp für %<operator %T%> angegeben"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "Qualifizierer sind bei Deklaration von %<operator %T%> nicht erlaubt"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "Rückgabetyp für Herleitungshinweis angegeben"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "Qualifizierer sind bei Deklaration von Herleitungshinweis nicht erlaubt"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Template-Template-Parameter %qT in Deklaration von Ableitungshinweis"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> in Deklaration von Ableitungshinweis"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unbenannte Variable oder Feld als »void« deklariert"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "Variable oder Feld als »void« deklariert"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%>-Spezifizierer ungültig für Variable %qD mit Gültigkeitsbereich Block"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "»inline«-Variablen sind nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<::%D%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%T::%D%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%D::%D%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T ist weder Klasse noch Namensbereich"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "Deklaration von %qE als Nicht-Funktion"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "Deklaration von %qE als Nicht-Element"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "Deklarator-ID fehlt: reserviertes Wort %qD wird verwendet"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "Funktionsdefinition deklariert keine Parameter"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "Deklaration von %qD als Nicht-Funktion"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "Deklaration von %qD als %<typedef%>"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "Deklaration von %qD als Parameter"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "sowohl %qs als auch %qs angegeben"
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs kann nicht in einer typedef-Deklaration auftreten"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "höchstens einer der Spezifizierer %<constinit%> und %<constexpr%> kann verwendet werden"
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "zwei oder mehr Datentypen in Deklaration von %qs"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "in Konflikt stehende Spezifikationen für Deklaration von %qs"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C++ unterstützt nicht, dass einfaches %<complex%> %<double complex%> bedeutet"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO-C++ verbietet Deklaration von %qs ohne Typ"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> wird von diesem Ziel nicht unterstützt"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO-C++ unterstützt %<__int%d%> für %qs nicht"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> und %<unsigned%> gleichzeitig angegeben"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> und %<short%> gleichzeitig angegeben"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs mit %qT angegeben"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs mit %<decltype%> angegeben"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs mit %<typeof%> angegeben"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ungültig für %qs"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "Template-Platzhaltertyp %qT muss von einer einfachen declarator-id gefolgt sein"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Element %qD kann nicht gleichzeitig %<virtual%> und %<static%> sein"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Element %qD kann erst mit %<-std=c++20%> oder %<-std=gnu++20%> gleichzeitig %<virtual%> und %<constexpr%> sein"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "»typedef«-Deklaration in Parameterdeklaration ungültig"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Speicherklasse für Template-Parameter %qs angegeben"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "Speicherklasse für Parameter %qs angegeben"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "ein Parameter kann nicht als %qs deklariert sein"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %qs deklariert werden"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "strukturierte Bindungsdeklarationen können erst ab %<-std=c++20%> oder %<-std=gnu++20%> %qs sein"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "%<volatile%>-qualifizierte strukturierte Bindung ist veraltet"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<auto%> (C++98) deklariert werden"
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "Deklaration für strukturierte Bindung darf nicht vom Typen %qT sein"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "Typ muss cv-qualifizierter %<auto%> oder Referenz auf cv-qualifizierten %<auto%> sein"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "mehrere Speicherklassen in Deklaration von %qs"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Speicherklasse %qs angegeben"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geschachtelte Funktion %qs als %<extern%> deklariert"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "Deklaration höchster Ebene von %qs gibt %<auto%> an"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "Funktions-Gültigkeitsbereich %qs ist implizit auto und deklarierte %<__thread%>"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "Speicherklassenangaben sind in friend-Funktionsdeklarationen ungültig"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "Attribut wird ignoriert"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "ein Attribut, das sich auf eine Typspezifizierung bezieht, wird ignoriert"
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "unnötige Klammern in Deklaration von %qs"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "entfernen Sie die Klammern"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "»requires«-Klausel für Rückgabetyp"
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "Funktion %qs verwendet Typspezifikation %<auto%> ohne folgenden Rückgabetypen"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "hergeleiteter Rückgabetyp nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "virtuelle Funktionen kann keinen hergeleiteten Rückgabetyp haben"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit folgendem Rückgabetypen hat %qT als seinen Typ statt einfaches %<auto%>"
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit nachgestelltem Rückgabetyp hat %<decltype(auto)%> als Typ statt einfachem %<auto%>"
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ungültige Verwendung von %<decltype(auto)%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "hergeleiteter Klassentyp %qD in Rückgabetyp von Funktion"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "Herleitungshinweis für %qT muss angehängten Rückgabetyp haben"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "angehängter Rückgabetyp %qT den Ableitungshinweises ist keine Spezialisierung von %qT"
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "nachgestellter Rückgabetyp nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "Funktion %qs mit folgendem Rückgabetypen nicht mit Typspezifikation %<auto%> deklariert"
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<volatile%>-qualifizierter Rückgabetyp ist veraltet"
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs als Funktion, die ein Feld zurückgibt, deklariert"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<constinit%> ist am Rückgabetyp einer Funktion nicht erlaubt"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT als Typ statt als einfaches %<decltype(auto)%>"
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> darf nicht CV-qualifiziert sein"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "Destruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "Konstruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "Destruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "Konstruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "Destruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "Konstruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Konstruktoren dürfen nicht als %<virtual%> deklariert sein"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuelle Funktionen können keine friends sein"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-Deklaration nicht in Klassendefinition"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "%<friend%>-Funktion %qs kann nicht in einer lokalen Klassendefinition definiert werden"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "Definition der Freundfunktion %qs kann keinen Namen haben, der mit %<::%> qualifiziert ist"
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "Definition der Freundfunktion %qs kann keinen Namen haben, der mit %<%D::%> qualifiziert ist"
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "eine Umwandlungsfunktion darf keinen angehängten Rückgabetyp haben"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "Destruktoren dürfen keine Parameter haben"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "Zeiger auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Referenz auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "Zeiger auf Element %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Referenz auf %q#T kann nicht deklariert werden, da letzteres weder Typedef noch Templatetyp-Argument ist"
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "Template-ID %qD als Deklarator verwendet"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "Elementfunktionen sind implizite »friends« ihrer Klasse"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "zusätzliche Qualifizierung %<%T::%> an Element %qs"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT definiert werden"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT deklariert werden"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "Element %<%T::%s%> kann nicht in %qT deklariert werden"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Nicht-Parameter %qs kann kein Parameterpack sein"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "Datenelement darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "Parameter darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> in »friend«-Deklaration"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "nur Deklarationen von Konstruktoren und Umwandlungsoperatoren können %<explicit%> sein"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Objekt-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Funktion %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%qs ist %<static%> und darf daher nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%qs ist %<const%> und darf daher nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Referenz %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "mit %<typedef%> definierte Funktion darf keinen Rumpf %<{ … }%> haben"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "mit %<typedef%> definierte Elementfunktion darf keinen Rumpf %<{ … }%> haben"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> ist in Aliasdeklaration nicht erlaubt"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "»typedef« als %<auto%> deklariert"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-clause an Typedef"
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-Name darf kein Spezifizierer mit geschachteltem Namen sein"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO-C++ verbietet geschachtelten Typen %qD mit gleichem Namen wie umschließende Klasse"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> für friend-Klassen-Deklaration angegeben"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "Template-Parameter können keine »friends« sein"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "Versuch, die Klasse %qT zu einem »friend« des globalen Gültigkeitsbereiches zu machen"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ungültige Qualifizierer an Nicht-Element-Funktionstyp"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-clause an type-id"
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakter Deklarator %qT als Deklaration verwendet"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "»requires«-Klausel in Deklaration von Nichtfunktionstyp %qT"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "%<::%> kann nicht in Parameterdeklaration verwendet werden"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "Parameter kann nicht mit %<decltype(auto)%> deklariert werden"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "Platzhalter für Klassentemplate %qE ist in diesem Kontext nicht erlaubt"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "verwenden Sie %<auto%> für ein abgekürztes Funktionstemplate"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%>-Parameter darf in diesem Kontext nicht verwendet werden"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "Parameter als %<auto%> deklariert"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ungültige Verwendung des Template-Namens %qE ohne eine Argumentliste"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "nicht-statisches Datenelement mit Platzhalter %qT deklariert"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO-C++ verbietet flexibles Arrayelement %qs"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO-C++ verbietet flexible Arrayelemente"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ungültige Verwendung von %<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "Deklaration der Funktion %qD in ungültigem Kontext"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Funktion %qD wurde innerhalb einer Union als %<virtual%> deklariert"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kann nicht als %<virtual%> deklariert werden, da es immer statisch ist"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Destruktor %qD erwartet"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "Deklaration von %qD als Element %qT"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "ein Destruktor kann nicht %qs sein"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%>-Destruktoren sind erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Konstruktor %qD erwartet"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "ein Konstruktor kann nicht %<concept%> sein"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ein Konzept kann keine Elementfunktion sein"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD kann nicht %qs sein"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "Spezialisierung des Variablentemplates %qD als Funktion deklariert"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "Variablentemplate hier deklariert"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "Feld %qD hat unvollständigen Typen %qT"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "Name %qT hat unvollständigen Typen"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ist weder eine Funktion noch Elementfunktion; kann nicht als »friend« deklariert werden"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "unbenanntes Feld ist weder eine Funktion noch Elementfunktion; kann nicht als %<friend%> deklariert werden"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "statisches Datenelement %qE als %qs deklariert"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statisches Datenelement %qD (%<constexpr%>) muss Initialisierung haben"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "nicht-statisches Datenelement %qE als %qs deklariert"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "Speicherklasse %<auto%> ungültig für Funktion %qs"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "Speicherklasse %<register%> ungültig für Funktion %qs"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "Speicherklasse %<__thread%> ungültig für Funktion %qs"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "Speicherklasse %<thread_local%> ungültig für Funktion %qs"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-Spezifikation in %qs ist außerhalb einer Klassendefinition nicht erlaubt"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> ist für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs ungültig"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> ungültig für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuelle Nicht-Klassen-Funktion %qs"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs nicht in Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs in einem Nicht-Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "Elementfunktion %qD kann nicht deklariert werden, statische Bindung zu haben"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statische Funktion innerhalb anderer Funktion kann nicht deklariert werden"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> darf nicht bei der Definition (im Gegensatz zu Deklaration) eines statischen Datenelementes verwendet werden"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisches Element %qD als %<register%> deklariert"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "Element %q#D kann nicht explizit deklariert werden, externe Bindung zu haben"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "Deklaration der %<constexpr%>-Variable %qD ist keine Definition"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "eine Variable kann nicht als %<consteval%> deklariert sein"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "Deklaration von %q#D hat keine Initialisierung"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisiert und als %<extern%> deklariert"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hat sowohl %<extern%> als auch Initialisierung"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Standardargument %qE verwendet %qD"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Standardargument %qE verwendet lokale Variable %qD"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ungültige Verwendung von cv-qualifiziertem Typ %qT in Parameterdeklaration"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ungültige Verwendung von Typ %<void%> in Parameterdeklaration"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<volatile%>-qualifizierter Parameter ist veraltet"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "Parameter %qD deklariert ungültigerweise Methodentyp"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Zeiger auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Referenz auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ungültiger Konstruktor; wahrscheinlich war %<%T (const %T&)%> gemeint"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD darf nicht innerhalb eines Namensbereiches definiert werden"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD darf nicht als »static« deklariert werden"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD muss eine nichtstatische Elementfunktion sein"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD muss entweder eine nichtstatische Elementfunktion oder eine Nicht-Element-Funktion sein"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD muss ein Argument von einem Klassen- oder Aufzählungstyp haben"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO-C++ verbietet Überladen von %<operator ?:%>"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "»%qD« darf keine variable Argumentanzahl haben"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD muss entweder null oder ein Argument nehmen"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD muss entweder ein oder zwei Argumente nehmen"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Suffix-%qD muss %<int%> als sein Argument nehmen"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Suffix-%qD muss %<int%> als sein zweites Argument nehmen"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD darf keine Argumente nehmen"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD muss genau ein Argument nehmen"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD muss genau zwei Argumente nehmen"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kann keine Standardargumente haben"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "Umwandlung von %qT in %<void%> wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Referenz auf gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "Umwandlung von %qT in gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Referenz auf Basisklasse %qT wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Basisklasse %qT wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "benutzerdefiniertes %qD wertet immer beide Argumente aus"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "Präfix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "Suffix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD sollte Wert zurückgeben"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "Templatetyp-Parameter %qT wird nach %qs verwendet"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "Templatespezialisierung alias %qT hinter %qs wird verwendet"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-Name %qD wird nach %qs verwendet"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD hat eine vorherige Deklaration hier"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT als %qs verwendet"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT hat hier eine vorherige Deklaration"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT als enum verwendet"
@@ -50487,105 +50530,105 @@ msgstr "%qT als enum verwendet"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "Template-Argument für %<%s %T%> benötigt"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "Referenz auf %qD ist mehrdeutig"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD hat den gleichen Namen wie die Klasse, in der es deklariert wurde"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ist kein Template"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "Sie könnten ein explizites %<%T::%> hinzufügen"
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "Verwendung des enum %q#D ohne vorherige Deklaration"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Redeklaration von %qT als Nicht-Template"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "%qD kann nicht in einem anderen Modul deklariert sein"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "abgeleitete Union %qT ist ungültig"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT ist mit mehreren direkten Basisklassen definiert"
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT ist mit direkter virtueller Basisklasse definiert"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "Basistyp %qT ist kein struct- oder Klassentyp"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiver Typ %qT nicht definiert"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "doppelter Basistyp %qT ungültig"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "falsche Zuordnung zwischen innerhalb und außerhalb eines Gültigkeitsbereiches in enum %q#T"
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "vorherige Definition hier"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "falsche Zuordnung des zugrunde liegenden Typs in enum %q#T"
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "anderer zugrunde liegender Typ in enum %q#T"
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "%qD kann nicht in einem anderen Modul definiert sein"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
@@ -50594,77 +50637,77 @@ msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "kein Ganzzahltyp kann alle Aufzählungswerte für %qT darstellen"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Aufzählungswert für %qD muss ganzzahligen oder Aufzählungstyp ohne Gültigkeitsbereich haben"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Aufzählungswert für %qD ist keine Ganzzahlkonstante"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<unsigned long%>"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<long%>"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "Überlauf in Aufzählungswerten bei %qD"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Aufzählungswert %qE ist außerhalb des Gültigkeitsbereichs des zugrundeliegenden Typen %qT"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "mehrfache Definition von %q#T"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "Rückgabetyp %q#T ist unvollständig"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> sollte eine Referenz auf %<*this%> zurückgeben"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "keine return-Anweisungen in %qT zurückgebender Funktion"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "nur einfacher Rückgabetyp %<auto%> kann zu %<void%> hergeleitet werden"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "eine %<constexpr%>-Funktion, die etwas Anderes als %<void%> zurückgibt, muss eine return-Anweisung enthalten"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ist bereits in Klasse %qT definiert"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "Verwendung von %qD vor Herleitung von %<auto%>"
@@ -50704,7 +50747,7 @@ msgstr "Eine Funktion kann nicht gelöscht werden. Nur Zeiger auf Objekte sind g
 msgid "deleting %qT is undefined"
 msgstr "Löschen von %qT ist nicht definiert"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "Templatedeklaration von %q#D"
@@ -50714,7 +50757,7 @@ msgstr "Templatedeklaration von %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "angegebene Template-Parameterlisten passen nicht zu Templateparametern von %qD"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "Destruktor %qD als Element-Template deklariert"
@@ -51039,22 +51082,22 @@ msgstr "da %qT vom Benutzer bereitgestelltes %qD hat"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "Lambda, das %<...%> verwendendet, wird in Funktionszeiger umgewandelt"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "gelöschte Funktion %qD wird verwendet"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "Verwendung der Funktion %qD mit nicht erfüllten Einschränkungen"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "Verwendung von eingebautem Parameterpack %qD außerhalb eines Templates"
@@ -51159,7 +51202,7 @@ msgstr "Referenz auf %<%T::%D%> ist mehrdeutig"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD ist kein Element von %qT; meinten Sie %qs?"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD ist kein Element von %qT"
@@ -51169,7 +51212,7 @@ msgstr "%qD ist kein Element von %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD ist kein Element von %qD; meinten Sie %qs?"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD ist kein Element von %qD"
@@ -51355,408 +51398,408 @@ msgstr "Wertinitialisierung des Referenztypen %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "rekursive Instanziierung von Vorgabeinitialisierer für Element %qD"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "Vorgabeinitialisierer für Element %qD erforderlich vor dem Ende der umschließenden Klasse"
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "Initialisierung eines flexiblen Arrayelements %q#D"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr "dadurch, dass %qD mittels %qE initialisiert wird, verlängert sich die Lebenszeit des zugrundeliegenden Arrays nicht"
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD sollte in Elementinitialisierungsliste initialisiert werden"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD wird mit sich selbst initialisiert"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ungültige Initialisierung für Arrayelement %q#D"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "nicht initialisiertes konstantes Element in %q#T"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D sollte initialisiert werden"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "nicht initialisiertes Referenzelement in %q#T"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD wird initialisiert nach"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "Basis %qT wird initialisiert nach"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  Basis %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  während es hier initialisiert wurde"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "mehrere Initialisierungen für %qD angegeben"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "mehrere Initialisierungen für Basis %qT angegeben"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "Initialisierungen für mehrere Elemente von %qT"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "Basisklasse %q#T sollte explizit im Kopierkonstruktor initialisiert werden"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "Klasse %qT hat keinen Feldnamen %qD"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D« ist ein statisches Datenelement; es kann nur bei seiner Definition initialisiert werden"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D ist kein Nicht-static-Datenelement von %qT"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "unbenannte Initialisierung für %qT, das keine Basisklassen hat"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "unbenannte Initialisierung für %qT, das Mehrfachvererbung verwendet"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD ist sowohl eine direkte Basis als auch eine indirekte virtuelle Basis"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "Typ %qT ist keine direkte oder virtuelle Basis von %qT"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "Typ %qT ist keine direkte Basis von %qT"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "Array muss mit Initialisierung mit umgebenden geschweiften Klammern initialisiert werden"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ist kein Klassentyp"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "unvollständiger Typ %qT hat kein Element %qD"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ungültiger Zeiger auf Bitfeld %qD"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion %qD"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ungültige Verwendung des nicht-statischen Datenelementes %qD"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes Referenzelement in %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes Referenzelement in Basis %q#T von %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "nicht initialisiertes Referenzelement in Basis %q#T von %q#T"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes konstantes Element in %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes konstantes Element in Basis %q#T von %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "nicht initialisiertes konstantes Element in Basis %q#T von %q#T"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New erzeugt ein Objekt vom Typ %<%T [%wu]%> mit Größe %qwu in einer Region von Typ %qT mit Größe %qwi"
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "Placement-New erzeugt ein Objekt vom Typ %<%T [%wu]%> mit Größe %qwu in einer Region vom Typ %qT mit Maximalgröße %qwu"
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New erzeugt ein Array von Objekten vom Typ %qT mit Größe %qwu in einer Region von Typ %qT mit Größe %qwi"
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "Placement-New erzeugt ein Array von Objekten vom Typ %qT mit Größe %qwu in einer Region vom Typ %qT mit Maximalgröße %qwu"
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New erzeugt ein Objekt vom Typ %qT mit Größe %qwu in einer Region von Typ %qT mit Größe %qwi"
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "Placement-New erzeugt ein Objekt vom Typ %qT mit Größe %qwu in einer Region vom Typ %qT mit Maximalgröße %qwu"
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr "an Offset %wi von %qD, das hier deklariert ist"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "an Offset [%wi, %wi] von %qD, das hier deklariert ist"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "Ganzzahlüberlauf in Arraygröße"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "Arraygröße in »new«-Ausdruck muss konstant sein"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "im »new«-Ausdruck ist kein variabel modifizierter Typ erlaubt"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "nichtkonstante Länge für neues Array muss direkt angegeben werden, nicht über %<typedef%>"
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "Nichtkonstante Länge in Array-new muss ohne Klammern um die Typ-ID angegeben werden"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "ungültiger Typ %<void%> für %<new%>"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "%<new%> einer %<initializer_list%> führt nicht zu einer längeren Lebenszeit des zugrundeliegenden Arrays"
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "nicht initialisierte Konstante in %<new%> von %q#T"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "Kein passendes %qD in Klasse %qT gefunden"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "Abfrage des Elementes %qD ist mehrdeutig"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> für Typ %qT mit erweiterter Ausrichtung %d"
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "verwendet %qD, das jedoch keinen Ausrichtungsparameter hat"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "verwenden Sie %<-faligned-new%>, um die C++17-Unterstützung für überausgerichtetes New einzuschalten"
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "geklammerte Initialisierung in Array-»new«"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "Größe des Arrays bei »new« muss Ganzzahltyp haben"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "»new« kann nicht auf Referenztyp angewendet werden"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "»new« kann nicht auf Funktionstyp angewendet werden"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "mögliches Problem bei Aufruf von %<operator delete []%> erkannt"
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische %<operator delete []%> wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "Initialisierung endet vorzeitig"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "unbekannte Arraygröße in »delete«"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "mögliches Problem bei Aufruf von %<operator delete%> erkannt"
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische %<operator delete%> wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "Löschen des Objekts mit abstraktem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt undefiniertes Verhalten"
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "Löschen des Objekts mit polymorphem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt möglicherweise undefiniertes Verhalten"
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "Typ für Vektor-»delete« ist weder Zeiger- noch Arraytyp"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr "Array mit Laufzeitgrenzen kann nicht durch Kopie eingefangen werden, sondern nur über eine Referenz"
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "Einfangen des variabel geänderten Typs %qT, der kein N3639-Array mit Laufzeitgrenzen ist"
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "da der Arrayelementtyp %qT variable Größe hat"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "%qE kann nicht per Referenz aufgefangen werden"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "Einfangen per Kopie von unvollständigem Typ %qT"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr "Versuch, %qD in Instanziierung eines generischen Lambdas einzufangen"
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr "implizites Einfangen von %qE via %<[=]%> ist in C++20 veraltet"
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr "fangen Sie %<this%> oder %<*this%> explizit ein"
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> wurde für diese Lambda-Funktion nicht aufgefangen"
@@ -51811,62 +51854,62 @@ msgstr "es gibt keine Argumente für %qD, die von einem Templateparameter abhän
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(mit %<-fpermissive%> wird G++ den Code akzeptieren, aber die Verwendung eines nicht deklarierten Namens ist veraltet)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr "mangling %<typeof%>, verwenden Sie stattdessen %<decltype%>"
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr "mangling %<__unterliegender_Typ%>"
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "unbekannter Festkommatyp wird vernichtet"
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "Verwendung der eingebauten Eigenschaft %qE in Funktionssignatur; stattdessen sollten Bibliothekseigenschaften verwendet werden"
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "%C wird gemangelt"
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "ausgelassener mittlerer Operand für Operator %<?:%> kann nicht verarbeitet werden"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "gemangelter Name für %qD wird sich ich C++17 ändern, da die Exceptionangabe Teil des Funktionstyps ist"
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "der gemangelte Name von %qD hat sich zwischen %<%s=%d%> (%qD) und %<%s=%d%> (%qD) geändert"
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "der gemangelte Name von %qD ändert sich zwischen %<%s=%d%> (%qD) und %<%s=%d%> (%qD)"
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "der gemangelte Name eines Thunks für %qD ändert sich zwischen %<-fabi-version=%d%> und %<-fabi-version=%d%>"
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "der gemangelte Name von %qD ändert sich zwischen %<-fabi-version=%d%> und %<-fabi-version=%d%>"
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "der gemangelte Name der Initialisierungswächter-Variable für %qD ändert sich zwischen %<-fabi-version=%d%> und %<-fabi-version=%d%>"
@@ -52047,303 +52090,303 @@ msgstr "%q#D wird implizit gelöscht, da die Standarddefinition ungültig wäre:
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F wird implizit gelöscht, da ihre Ausnahme-Spezifikation nicht zur impliziten Ausnahme-Spezifikation %qX passt"
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "Default-Deklaration %q+D passt nicht zur erwarteten Signatur"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "erwartete Signatur: %qD"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "Explizite Standardfunktion %q+D kann nicht als %qs deklariert werden, da die implizite Deklaration nicht %qs ist:"
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "ein Template kann nicht vorbelegt werden"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD kann nicht vorgegeben werden"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "vorgegebene Funktion %q+D mit Standardargument"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "Neudeklaration von %q#D mit unterschiedlichen Templateparametern"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D steht mit vorheriger Deklaration in Konflikt"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D verdeckt Konstruktor für %q#D"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "in Konflikt stehende Deklaration %q#D mit Bindung für die Sprache \"C\""
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "durch andere Ausnahmespezifikationen"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "Lambdaparameter %qD war vorher als Einfänger deklariert"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "Deklaration von %q#D überdeckt einen Parameter"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "Deklaration von %qD überdeckt ein Element von %qT"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "Friend-Deklaration %qD in lokaler Klasse ohne vorherige Deklaration"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "%q#D hat keine externe Bindung"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D hier deklariert"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T%s%D%> benennt Destruktor"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "»using«-Deklaration für Nicht-Element im Gültigkeitsbereich der Klasse"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> mit Gültigkeitsbereich in enum-Typ %q#T ist erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT ist weder eine Klasse, noch ein Namensbereich oder eine Aufzählung"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "eine Using-Deklaration, die nicht-Member ist, benennt den Konstruktor von %qT"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "%<using%>-Deklaration für Element außerhalb des Gültigkeitsbereichs der Klasse"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%qT ist keine direkte Basis von %qT"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "meinten Sie %<using enum %T::%D%>?"
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD wurde nicht innerhalb von %qD deklariert"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "%<using%>-Deklaration darf den Namensraum %qD nicht benennen"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> benennt Konstruktor in %qT"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "Deklaration von %qD nicht in einem Namensbereich um %qD"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explizite Qualifizierung in Deklaration von %qD"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD sollte innerhalb von %qD deklariert werden"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD wurde nicht innerhalb von %qD deklariert"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "sondern nur hier als %<friend%>"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "Attribut %qD erfordert ein einzelnes NTBS-Argument"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "Attribut %qD ist bedeutungslos, da die Elemente des anonymen Namensraums lokale Symbole erhalten"
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "Attribut %qD an unbenanntem Namensraum wird ignoriert"
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "Attribut %qD an nicht-»inline«-Namensraum wird ignoriert"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "Attribut-Anweisung %qD wird ignoriert"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "obere Grenze von %d Namensräumen für %qE durchsucht"
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "empfohlene Alternative:"
 msgstr[1] "empfohlene Alternativen:"
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%<std::%s%> ist im Header %qs definiert; haben Sie vergessen, %<#include %s%> zu schreiben?"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79869
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> ist erst ab %s verfügbar"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "das Makro %qs war noch nicht definiert"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "es wurde später hier definiert"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "Deklaration von %<std::initializer_list%> entspricht nicht %<#include <initializer_list>%>, ist kein Template"
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "die Direktive %<strong%>-%<using%> wird nicht mehr unterstützt"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "Sie können stattdessen einen inline-Namensraum verwenden"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "es können maximal %d Namensräume geschachtelt werden"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> ist mehrdeutig"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "Namensbereich-Alias %qD ist hier nicht erlaubt, %qD angenommen"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "ein %<inline%>-Namensraum muss bei der ersten Definition angegeben werden"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD hier definiert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99298
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%s-Namensraum %qD widerspricht der Erreichbarkeits-Definition"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "Erreichbarkeitsdefinition %s ist hier"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX %<pop_everything%> wird betreten"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX %<pop_everything%> wird verlassen"
@@ -52368,7 +52411,7 @@ msgstr "Bezeichner %qE wird in C++20 zum Schlüsselwort"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> ist nicht auf true gesetzt"
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> muss direkt von einer Funktionsdeklaration oder -definition gefolgt sein"
@@ -52393,7 +52436,7 @@ msgstr "%<::%E%> wurde nicht deklariert"
 msgid "request for member %qE in non-class type %qT"
 msgstr "Abfrage des Elementes %qE in Nicht-Klassentyp %qT"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> wurde nicht deklariert"
@@ -52473,7 +52516,7 @@ msgstr "ungültige Template-ID"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO-C++ verbietet Gleitkommaliterale in Konstanten-Ausdrücken"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "Eine Typumwandlung, die weder zu ganzzahligen noch Aufzählungstypen führt, kann nicht in einem Konstantenausdruck auftreten"
@@ -52609,7 +52652,7 @@ msgstr "%<constinit%> aus C++20 ist erst ab %<-std=c++20%> oder %<-std=gnu++20%>
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> ist erst ab %<-std=c++20%> oder mit %<-fconcepts%> verfügbar"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<requires%> ist erst ab %<-std=c++20%> oder mit %<-fconcepts%> verfügbar"
@@ -52734,7 +52777,7 @@ msgstr "literaler Operator für Zeichenketten %qD mit Argumenten %qT, %qT konnte
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr "der Inhalt des %<global-module-fragment%> muss aus einer Präprozessor-Einbindung stammen"
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "Deklaration erwartet"
@@ -52784,7 +52827,7 @@ msgstr "Anweisungs-Ausdrücke sind weder außerhalb von Funktionen noch in Templ
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fold-expressions sind nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "übergeordneter Ausdruck erwartet"
@@ -52814,7 +52857,7 @@ msgstr "Bereich %qT vor %<~%> ist kein Klassenname"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "das Schlüsselwort %<template%> ist im Destruktornamen nicht erlaubt"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%<~auto%> ist nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
@@ -52834,12 +52877,12 @@ msgstr "Deklaration von %<~%T%> als Element von %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-Name %qD als Destruktor-Deklarator verwendet"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualifizierte ID erwartet"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ist kein Template"
@@ -52874,7 +52917,7 @@ msgstr "Bezeichner %qD für Variablentemplate ist geschachteltem Namens-Spezifiz
 msgid "expected nested-name-specifier"
 msgstr "Spezifikation mit geschachteltem Namen erwartet"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Typen dürfen nicht in Typumwandlungen definiert werden"
@@ -52889,7 +52932,7 @@ msgstr "Typen dürfen nicht in einem %<typeid%>-Ausdruck definiert werden"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_addressof%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_launder%>"
@@ -52904,1116 +52947,1121 @@ msgstr "ISO-C++ verbietet zusammengesetzte Literale"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "zwei aufeinander folgende %<[%> dürfen nur ein Attribut einführen"
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ungültige Verwendung von %qD"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> ist kein Klassenelement"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "nicht-skalarer Typ"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO-C++ erlaubt kein %<alignof%> mit einem Nicht-Typ"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "Typen dürfen nicht in %<noexcept%>-Ausdrücken definiert werden"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "Typen dürfen nicht in einem %qs-Ausdruck definiert werden"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr "%<__builtin_has_attribute%> mit abhängigem Argument wird noch nicht unterstützt"
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "Typen dürfen nicht in einem »new«-Ausdruck definiert werden"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "Arraygrenze hinter geklammerter type-id ist verboten"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "Klammern um die Type-ID sollten entfernt werden"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "Initialisierung des new-Ausdrucks für Typ %<auto%> erfordert genau ein Element"
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "»expression-list« oder »type-id« erwartet"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "Typen dürfen nicht in einem »new-type-id« definiert werden"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "Ausdruck in new-Deklarator muss Ganzzahl- oder Aufzählungstyp haben"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "Verwendung einer Typumwandlung nach %q#T im alten Stil"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "Operator %<>>%> wird in C++11 wie zwei spitze schließende Klammern behandelt"
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "Klammern um %<>>%>-Ausdruck empfohlen"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "in ISO-C++ darf der mittlere Operand von %<?:%> nicht weggelassen werden"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "ungeklammerte Komma-Ausdrücke in Arrayindex-Ausdrücken sind veraltet"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "Typen dürfen nicht innerhalb von %<__builtin_offsetof%> definiert werden"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr "Lambda-Ausdruck in Template-Parameter-Typ"
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Lambda-Ausdruck in nicht evaluiertem Kontext ist erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Lambda-Ausdruck in Template-Argument ist erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "nicht-lokaler Lambdaausdruck kann keinen »capture-default« haben"
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "unerwartetes Ende der Auffangliste"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "Explizite Erfassung (als Kopie) von %<this%> ist mit Standarderfassung (als Kopie) gedoppelt"
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "%qD bereits in Lambda-Ausdruck erfasst"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<*this%>-Capture ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "%<this%> kann nicht per Referenz eingefangen werden"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<pack init-capture%> ist erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr "%<&%> sollte vor %<...%> kommen"
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Initialisierungen für Lambda-Captures sind nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "nicht-leere Initialisierung »init-capture« eines Lambdas"
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "Erfassung von Nicht-Variable %qE"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "Erfassung der Variable %qD ohne automatische Speicherdauer"
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "zu viele %<...%> in Lambda-Capture"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "Explizite Erfassung (als Kopie) von %qD ist mit Standarderfassung (als Kopie) gedoppelt"
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "Explizite Erfassung (als Referenz) von %qD ist mit Standarderfassung (als Referenz) gedoppelt"
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Lambda-Templates sind nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Lambda-Templates sind erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "Standardargument für Lambda-Parameter angegeben"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "Parameterdeklaration vor Lambdadeklarationsangaben ist erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> optional"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "doppeltes %<mutable%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "Parameterdeklaration vor einem Lambda-Transaktions-Qualifizierer ist erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> optional"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90183
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "Parameterdeklaration vor einer Lambda-Exception-Angabe ist erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> optional"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "Parameterdeklaration vor einem abschließenden Rückgabetyp ist erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> optional"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<constexpr%>-Lambda ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "Attribute am Anfang der Anweisung werden ignoriert"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "benannte Anweisung erwartet"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-Marke %qE nicht innerhalb einer switch-Anweisung"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> vor %qE erforderlich, da %qT ein abhängiger Gültigkeitsbereich ist"
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> benennt Konstruktor, nicht den Typ"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "zusammengesetzte Anweisung in %<constexpr%>-Funktion"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<if constexpr%> ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "»init-statement in Auswahlanweisungen« ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "Auswahl-Anweisung erwartet"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr "Bedingung deklariert ein Array"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr "Bedingung deklariert eine Funktion"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "Typen dürfen nicht in Bedingungen definiert werden"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "Initialisierung erwartet"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr "Schleifenvariable %qD vom Typ %qT bindet an temporäres Objekt, das aus dem Typen %qT konstruiert wurde"
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr "verwenden Sie den Nicht-Referenz-Typ %qT, um das Kopieren explizit zu machen, oder %qT um das Kopieren zu sparen"
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "Schleifenvariable %qD erzeugt eine Kopie vom Typ %qT"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr "verwenden Sie einen Referenztyp, um das Kopieren zu sparen"
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat unvollständigen Typ"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "unvereinbare Anfang-/Ende-Typen in bereichsbasierter %<for%>-Anweisung: %qT und %qT"
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "Iterationsanweisung erwartet"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Bereichsbasierte %<for%>-Schleifen mit Initialisierer sind erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Bereichsbasierte %<for%>-Schleifen sind nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> in %<constexpr%>-Funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO-C++ verbietet berechnete Gotos"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "Sprunganweisung erwartet"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, gcc-internal-format
 msgid "expected module-name"
 msgstr "Modulname erwartet"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr "%<module-declaration%> ist innerhalb von %<header-unit%> nicht erlaubt"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr "%<private-module-fragment%> ist nur im Zuständigkeitsbereich eines Modulinterfaces oder einer Partition zulässig"
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, gcc-internal-format
 msgid "private module fragment"
 msgstr "private-module-fragment"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr "Modul-Deklaration ist nur als erste Deklaration erlaubt, oder wenn sie das global-module-fragment beendet"
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr "post-module-declarations müssen zusammenhängend sein"
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr "vielleicht hilft ein Zeilenumbruch oder eine andere Kenntlichmachung, damit dies nicht mehr als Modul-Steuerzeile angesehen wird"
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr "Import-Deklaration muss im globalen Gültigkeitsbereich sein"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "%<import%> kann nicht direkt in einer Bindungs-Angabe vorkommen"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr "%<post-module-declaration%>-Importe dürfen nicht %<include-translated%> sein"
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr "%<post-module-declaration%>-Importe dürfen nicht aus Header-Einbindung stammen"
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr "%qE darf erst nach einer Modul-Interface-Deklaration vorkommen"
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr "%qE darf nur einmal pro Export-Deklaration vorkommen"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr "%<export%> ist kein Teil der folgenden module-directive"
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "Attribute dürfen an dieser Stelle nicht verwendet werden"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr "Attribute dürfen hier eingesetzt werden"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "zusätzliches %<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> nicht am Anfang eines Blocks"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "Nicht-Variable %qD in Deklaration mit mehr als einem Deklarator mit Platzhaltertyp"
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für %qT: %qT und dann %qT"
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "Vermischung von Deklarationen und Funktionsdefinitionen ist verboten"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "in einer for-Bereichs-Deklaration dürfen keine Typen definiert werden"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "Initialisierung in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "mehrere Deklarationen in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "strukturierte Bindungen sind nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "leere Deklaration für strukturierte Bindung"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ungültige Initialisierung für strukturierte Bindungsdeklaration"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> außerhalb einer Klasse verwendet"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "das Schlüsselwort %<bool%> ist in einer Konzeptdefinition in C++20 nicht erlaubt"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr "Die Schreibweise der C++20-Konzeptdefinition ist %<concept <Name> = <Ausdruck>%>"
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "Bedeutung von %<auto%> ändert in C++11 die Bedeutung; Bitte entfernen"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%<decl-specifier%> ist in Bedingung ungültig"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD ungültig in Lambda"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "type-specifier ist in Lambda ungültig"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "Klassendefinition darf nicht als »friend« deklariert sein"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "Typen dürfen nicht in explicit-specifier definiert werden"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<explicit(bool)%> ist erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ungültige Bindungsspezifikation"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<static_assert%> ohne Text ist erst ab %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "die Typangabe %<decltype(auto)%> ist erst mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "Typen dürfen nicht in %<decltype%>-Ausdrücken definiert werden"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "Typen dürfen nicht in einem »conversion-type-id« definiert werden"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ungültige Verwendung von %<auto%> in Umwandlungsoperator"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "Verwendung von %<auto%> in Umwandlungsoperator von Elementtemplate kann niemals hergeleitet werden"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "nur Konstruktoren nehmen Elementinitialisierungen"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "Initialisierung für Element %qD kann nicht expandiert werden"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "Speicherinitialisierung für %qD folgt Konstruktordelegation"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "Konstruktordelegation folgt Speicherinitialisierung für %qD"
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "veraltete Basisklasseninitialisierung"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> in diesem Kontext nicht erlaubt (eine qualifizierte Elementinitialisierung ist implizit ein Typ)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "unerwartetes Schlüsselwort; entfernen Sie Leerzeichen zwischen Anführungszeichen und Suffixbezeichner"
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "Suffixbezeichner erwartet"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "hinter Schlüsselwort %<operator%> wird leere Zeichenkette erwartet"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ungültiges Encoding-Präfix in Literal-Operator"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "Operator erwartet"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Schlüsselwort %<export%> nicht implementiert, und wird ignoriert"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "das Schlüsselwort %<export%> ist veraltet und wird ignoriert"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr "das Schlüsselwort %<export%> wird mit %<-fmodules-ts%> eingeschaltet"
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ungültiger beschränkter Typparameter"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-qualifizierter Typparameter"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ungültige Verwendung von %<auto%> in Default-Templateargument"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Templateparameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "Template-Parameterpacks können keine Standardargumente haben"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "Template-ID erwartet"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kann keine Templateargumentliste einleiten"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ist eine andere Schreibweise für %<[%>. Leerraum zwischen %<<%> und %<::%> einfügen"
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(bei Verwendung von %<-fpermissive%>, %<-std=c++11%> oder %<-std=gnu++11%> wird G++ den Code akzeptieren)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "ungültige template-argument-list"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr "Funktionsname als linker Operand von %<<%> ist in C++20 verboten; klammern Sie den Funktionsnamen mit %<()%> ein"
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<(%> hinter template-argument-list erwartet"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "Syntaxfehler in Templateargumentliste"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "Templatename erwartet"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "Nicht-Template %qD als Template verwendet"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "%<%T::template %D%> verwenden, um dies als Template zu kennzeichnen"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "Parameterbündel vor %<...%> erwartet"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "Templateargument erwartet"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ungültiges Templateargument ohne Typ"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "explizite Instanziierung darf kein %<inline%> verwenden"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "explizite Instanziierung darf kein %<constexpr%> verwenden"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "explizite Instanziierung darf kein %<consteval%> verwenden"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "Templatespezialisierung mit C-Bindung angegeben"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Typspezifizierer erwartet"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Verwendung von %<auto%> in Lambda-Parameterdeklaration ist nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Verwendung von %<auto%> in Parameterdeklaration ist nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "Verwendung von %<auto%> in Parameterdeklaration ist nur mit %<-fconcepts-ts%> verfügbar"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "Template-ID für Typ erwartet"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "Typ-Name erwartet"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE schränkt keinen Typ ein"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr "das Konzept wurde hier definiert"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<auto%> oder %<decltype(auto)%> nach %qE erwartet"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr "unerwarteter Platzhalter in eingeschränktem Ergebnistyp"
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "ausführliche Typ-Spezifikation für einen enum mit Gültigkeitsbereich darf nicht das Schlüsselwort %qD verwenden"
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%<template%> muss auf einen nested-name-specifier folgen"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "Deklaration %qD deklariert nichts"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "Attribute an instanziiertem Typen ignoriert"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "Attribute an Templateinstanziierung ignoriert"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "Attribute an Spezifizierer ausführlichen Typs ignoriert, der keine Vorwärtsdeklaration ist"
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ist ein Aufzählungstemplate"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD benennt keinen Aufzählungstyp in %qT"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "unbenanntes »enum« mit Gültigkeitsbereich ist nicht erlaubt"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> oder %<{%> erwartet"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aufzählungsliste kann nicht zu Template-Instanziierung hinzugefügt werden"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "geschachtelter Namensgeber %qT für enum-Deklaration benennt weder Klasse noch Namensraum"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in Namensraum %qD, der nicht %qD einschließt"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in %qD, das nicht %qD einschließt"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "zusätzliche Qualifizierung nicht erlaubt"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO-C++ verbietet leere unbenannte Aufzählung"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "intransparente Enum-Spezifikation ohne Namen"
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "intransparente Enum-Spezifikation muss einfachen Bezeichner verwenden"
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD bezeichnet Namensraum-Namen; meinten Sie %qs?"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ist kein Namensbereichs-Name"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "Namensraumname erwartet"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90183
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "verschachtelte inline-Namensraumdefinitionen sind erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr "Standardattribute für Namensräume müssen vor dem Namen des Namensraums stehen"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90183
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "verschachtelte Namensraumdefinitionen sind nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "Name eines geschachtelten Namensraums erwartet"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "Name eines Namensraums erwartet"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "eine verschachtelte Namensraum-Definition darf keine Attribute haben"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "eine verschachtelte Namensraumdefinition darf nicht inline sein"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "Namensbereich %qD betreten"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-Definition ist hier nicht erlaubt"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "Pack-Expansion in using-Deklaration ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "eine Template-ID darf nicht in »using«-Deklaration auftreten"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "kommagetrennte Liste in using-Deklaration ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "Zugriffsdeklarationen sind zugunsten von %<using%>-Deklarationen veraltet; Vorschlag: %<using%> hinzufügen"
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "opaque-enum-declaration ist hier"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "Typen dürfen nicht in Alias-Templatedeklarationen definiert werden"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<asm%> innerhalb einer %<constexpr%>-Funktion ist erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "doppelter %<asm%>-Qualifizierer %qT"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%<asm%>-Qualifizierer %qT wird ignoriert, da außerhalb des Funktionsrumpfes"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT ist kein %<asm%>-Qualifizierer"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%<asm%>-Qualifizierer außerhalb des Funktionsrumpfes"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "leere Klammern sind mehrdeutig und werden als Funktionsdeklaration angesehen"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr "entfernen Sie die Klammern, um stattdessen eine Variable mit ihrem Vorgabewert zu initialisieren"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr "oder ersetzen Sie die Klammern durch geschweifte Klammern, um die Variable als Aggregat zu initialisieren"
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr "oder ersetzen Sie die Klammern durch geschweifte Klammern, um die Variable mit einem einzelnen Wert zu initialisieren"
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, gcc-internal-format
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "Klammern waren mehrdeutig und wurden als Funktionsdeklaration angesehen"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr "ersetzen Sie die Klammern durch geschweifte Klammern, um eine Variable zu deklarieren"
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr "fügen Sie Klammern hinzu, um eine Variable zu deklarieren"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "eine Funktionsdefinition ist hier nicht erlaubt"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "eine %<asm%>-Spezifikation ist bei Funktionsdefinition nicht erlaubt"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bei einer Funktionsdefinition sind keine Attribute erlaubt"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "Konstruktor, Destruktor oder Typumwandlung erwartet"
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Initialisierung für Funktion bereitgestellt"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "Attribute hinter geklammerter Initialisierung werden ignoriert"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Nicht-Funktion %qD als implizites Template deklariert"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "Arraygrenze ist keine Ganzzahlkonstante"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "Element des abhängigen Typedef %qT kann nicht definiert werden"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ist kein Typ"
@@ -54022,431 +54070,431 @@ msgstr "%<%T::%E%> ist kein Typ"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ungültiger Deklarator"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ungültige Verwendung des Konstruktors als Template"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "%<%T::%D%> statt %<%T::%D%> verwenden, um den Konstruktor mit qualifiziertem Namen zu benennen"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id in Deklaration"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "Deklarator erwartet"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD ist ein Namensbereich"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "Zeiger auf Element der Nicht-Klasse %q#T kann nicht erzeugt werden"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Ptr-Operator erwartet"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "doppelter CV-Qualifizierer"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "mehrere ref-qualifier"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE benötigt %<-fgnu-tm%>"
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "doppelter Virt-Spezifizierer"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "fehlende Templateargumente nach %qT"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr "%qT ist in einem Templateargument nicht erlaubt"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ungültige Verwendung von %qT"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "in Template-Argumenten dürfen keine Typen definiert werden"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ungültige Verwendung von %<auto%> in Templateargument"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Typspezifikation erwartet"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> oder %<...%> erwartet"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "Typen dürfen nicht in Parametertypen definiert werden"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "Standardargumente sind nur für Funktionsparameter zugelassen"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Parameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "Templateparameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Parameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Rumpf eines function-try-block in einem %<constexpr%>-Konstruktor ist erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Rumpf eines function-try-block in einer %<constexpr%>-Funktion ist erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "designierte Initialisierer für C++ sind erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen (GNU)"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen von C99"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "entweder sollten alle Initialisierer-Klauseln benannt sein oder gar keine"
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> ist in benannten Initialisierungen nicht erlaubt"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "%<.%s%>-Name wird mehrfach in derselben Initialisierungsliste verwendet"
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "Klassenname erwartet"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> hinter Klassendefinition erwartet"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> hinter Strukturdefinition erwartet"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> hinter Uniondefinition erwartet"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> oder %<:%> erwartet"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "für eine Klasse kann kein %<override%> angegeben werden"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globale Qualifizierung von Klassenname ist ungültig"
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "qualifizierter Name benennt keine Klasse"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "Schlüsselwort %<template%> nicht innerhalb des Klassenkopfnamens erlaubt"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ungültiger Klassenname in Deklaration von %qD"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "einer expliziten Spezialisierung muss %<template <>%> vorausgehen"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Funktions-Template %qD als Klassentemplate redeklariert"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "Typnamen-Typ kann nicht aufgelöst werden"
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "vorherige Definition von %q#T"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "Klassenschlüssel erwartet"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ISO-C++ verbietet typename-Schlüssel in Template-Template-Parameter; verwenden Sie %<-std=c++17%> oder %<-std=gnu++17%>"
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> oder %<typename%> erwartet"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "in C++03 muss bei Deklaration eines »friend« ein Klassenschlüssel verwendet werden"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "»friend«-Deklaration benennt keine Klasse oder Funktion"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "Speicherklasse an anonymem Aggregat im Klassenbereich ist nicht erlaubt"
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Defaultinitialisierer für Bitfeld-Elemente sind erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "Defaultinitialisierer für unbenanntes Bitfeld-Element"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ erlaubt Bitfeld-Attribute nur vor dem %<:%>-Token"
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "Bitfeld %qD mit Nicht-Ganzzahl-Typ %qT"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "reiner Spezifizierer bei Funktionsdefinition"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "zusätzliches %<;%> hinter Funktionsdefinition innerhalb einer Klasse"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "überflüssiges %<,%> am Ende der Elementdeklaration"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> am Ende von Elementdeklaration erwartet"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ungültige reine Spezifikation (nur %<= 0%> ist erlaubt)"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "eine geschweift geklammerte Initialisierung ist hier nicht erlaubt"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> mehr als einmal in Basisspezifikation angegeben"
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "mehr als ein Zugriff in Basisspezifikation angegeben"
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "Schlüsselwort %<typename%> nicht außerhalb von Templates erlaubt"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> nicht erlaubt in diesem Kontext (die Basisklasse ist implizit ein Typ)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "Typen dürfen nicht in einer Ausnahmespezifikation definiert werden"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 erlaubt keine dynamischen Ausnahmespezifikationen"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamische Ausnahmespezifikationen sind in C++11 veraltet"
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ungültige Verwendung von %<auto%> in Ausnahmespezifikation"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<try%> innerhalb einer %<constexpr%>-Funktion ist erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "Typen dürfen nicht in Ausnahmedeklarationen definiert werden"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Attribut, das Präfix verwendet, wird zusammen mit Gültigkeitsbereich-Attribut-Token verwendet"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "Bezeichner für den Attributnamen erwartet"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr "Klammern müssen weggelassen werden, wenn die Argumentliste des %qE-Attributs leer ist"
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr "Attribut %qs ist mehrfach angegeben"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Attribut vor %<...%> erwartet"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90184
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribute-using-prefix ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "Ausdruck muss in runden Klammern eingeschlossen sein"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "Fehlendes zusätzliches %<requries%>, um eine requires-expression zu beginnen"
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "Rückgabetyp ist keine einfache Typ-Einschränkung"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "%<return-type-requirement%> ist keine Typ-Einschränkung"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "spezialisierendes Element %<%T::%E%> erfordert Syntax %<template<>%>"
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ungültige Deklaration von %<%T::%E%>"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "zu wenige Templateparameterlisten"
@@ -54455,757 +54503,757 @@ msgstr "zu wenige Templateparameterlisten"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "zu viele Templateparameterlisten"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "benannte Rückgabewerte werden nicht mehr unterstützt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90185
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "ISO C++ unterstützt keine Operatortemplates in Zeichenkettenliteralen, die eine Argumentpackung von Zeichen bekommen"
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "literales Operatortemplate %qD hat ungültige Parameterliste; nicht-Typ Templateargumentpack %<<char…>%> oder einzelner Nicht-Typ-Parameter von Klassentyp erwartet"
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "literales Operatortemplate %qD hat ungültige Parameterliste; Template für Nicht-Typ Argumentpack %<<char…>%> erwartet"
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr "Template-Einführungen sind nicht Teil der C++20-Konzepte; verwenden Sie %qs, um sie zu aktivieren"
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "kein passendes Konzept für template-introduction"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ungültige Deklaration eines Elementtemplates in lokaler Klasse"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "Template mit C-Bindung"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ungültige explizite Spezialisierung"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "Templatedeklaration von %<typedef%>"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "eine Klassen-Templatedeklaration darf nichts anderes deklarieren"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explizite Template-Spezialisierung kann keine Speicherklasse haben"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> sollte innerhalb einer geschachtelten Templateargumentliste %<> >%> sein"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "falsches %<>>%>; %<>%> verwenden, um eine Templateargumentliste zu beenden"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "Argument von %<sizeof...%> muss mit Klammern umschlossen werden"
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ungültige Verwendung von %qD in Spezifizierung der Bindung"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vor %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO-C++ 1998 unterstützt nicht %<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sowohl %<__thread%> als auch %<thread_local%> angegeben"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "doppeltes %qD"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "doppeltes %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> erwartet"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> erwartet"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> erwartet"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> erwartet"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> erwartet"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> erwartet"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> erwartet"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> erwartet"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> erwartet"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> erwartet"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> erwartet"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> erwartet"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> erwartet"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> erwartet"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> erwartet"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<auto%> erwartet"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> erwartet"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> erwartet"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> erwartet"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> erwartet"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> erwartet"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> erwartet"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<co_yield%> erwartet"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> erwartet"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> erwartet"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> erwartet"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> erwartet"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> oder %<::%> erwartet"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> oder %<template%> erwartet"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "redundanter Aufzählungsschlüssel %<enum%s%> in Bezug auf %q#T"
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Markierung %qs bei Benennung von %q#T verwendet"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T wurde vorher hier deklariert"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "redundanter Klassenschlüssel %qs in Verweis auf %q#T"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT mit nicht zusammenpassendem Klassenschlüssel %qs deklariert"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "entfernen Sie den Klassenschlüssel oder ersetzen Sie ihn durch %qs"
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "Klassenschlüssel durch %qs ersetzen"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT wurde hier als %qs definiert"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT wurde erstmals hier als %qs deklariert"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD mit anderem Zugriff redeklariert"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "in C++98 ist %<template%> (zum eindeutig machen) nur innerhalb von Templates erlaubt"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "Datei endet in Standardargument"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "unpassendes Objective-C++-Konstrukt %<@%D%>"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "Objective-C++-Nachrichtenempfänger erwartet"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "Objective-C++ Nachrichtenargument(e) erwartet"
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> muss als Argument einen Typen angeben"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Ungültiger Objective-C++-Selektorname"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Objective-C++ Methodendeklaration erwartet"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "Methodenattribute müssen am Ende angegeben werden"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "überflüssiges %qs zwischen Objective-C++ Methoden"
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ungültiger Typ für Instanzvariable"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Bezeichner nach %<@protocol%> erwartet"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "Attribute dürfen nicht vor dem Objective-C++-Schlüsselwort %<@%D%> angegeben werden"
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "Präfix-Attribute vor %<@%D%> werden ignoriert"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ungültiger Typ für Eigenschaft"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "unbekanntes Eigenschaftsattribut %qE"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "Liste von Ganzzahlausdrücken erwartet"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ungültiger reduction-identifier"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "Typen dürfen nicht in Iteratortyp definiert werden"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "geklammerte Initialisierung ist in OpenMP-%<for%>-Schleife nicht erlaubt"
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<ordered%>-Klausel mit Parameter in %<for%>-Schleife über einen Bereich"
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "Schleifenvariable %qD sollte keine Reduktion sein"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "zu wenige for-Schleifen um sie einzuklappen"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> gefolgt von %<#pragma omp declare %s%>"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ungültige Initialisierungsklausel"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "»id-expression (arguments)« erwartet"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "eins der Aufrufargumente für die Initialisierung sollte %<omp_priv%> oder %<&omp_priv%> sein"
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "neue Typen dürfen nicht in einem Rückgabetyp definiert werden"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "vordeklarierter arithmetischer Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "Funktions- oder Arraytyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "Referenztyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "%<const%>-, %<volatile%>- oder %<__restrict%>-qualifizierter Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> benennt eine Menge von Überladungen"
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bezeichnet keine Funktion innerhalb eines Namensraum"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "äußeres %<__transaction_cancel%> nicht innerhalb des äußeren %<__transaction_atomic%>"
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  oder einer %<transaction_may_cancel_outer%>-Funktion"
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "falsch geformtes %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp requires%> darf nur im Gültigkeitsbereich einer Datei oder eines Namensraums verwendet werden"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "Compilieren von mehreren Quellen ist für C++ nicht implementiert"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "Platzhaltertyp ist in diesem Kontext nicht erlaubt"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "Implizite Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-Bindung beginnt hier"
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "Datenelement %qD kann kein Elementtemplate sein"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "ungültige Elementtemplatedeklaration %qD"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "explizite Spezialisierung in Gültigkeitsbereich des Nicht-Namensbereiches %qD"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "einschließende Klassentemplates werden nicht explizit spezialisiert"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "Spezialisierung von %qD muss im Gültigkeitsbereich des Namensbereiches auftreten"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "Spezialisierung von %qD in anderem Namensbereich"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  aus Definition von %q#D"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "explizite Instanziierung von %qD in Namensbereich %qD (das nicht Namensbereich %qD einschließt)"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "Name der Klasse verdeckt Template-Templateparameter %qD"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "Spezialisierung des Alias-Template %qD"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "explizite Spezialisierung des Nicht-Templates %qT"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "Spezialisierung von %qT hinter Instanziierung"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "aus der Definition von %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "Spezialisierung %qT hinter Instanziierung %qT"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "Templatespezialisierung von %qD durch ISO C++ nicht erlaubt"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "Spezialisierung von %qD nach Instanziierung"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD ist kein Funktionstemplate"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD ist kein variadisches Template"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "Template-ID %qD für %q+D passt zu keiner Templatedeklaration"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "%d %<template<>%> gefunden, %d werden für Spezialisierung eines Elementfunktionstemplates benötigt"
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "mehrdeutige Templatespezialisierung %qD für %q+D"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "variable Templates sind nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "zu viele Templateheader für %qD (sollten %d sein)"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "Elemente einer explizit spezialisierten Klasse sind ohne Templateheader definiert"
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explizite Spezialisierung von %qD außerhalb seines Namensraums muss einen nested-name-specifier verwenden"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explizite Instanziierung von %qD außerhalb seines Namensraums muss einen nested-name-specifier verwenden"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "der expliziten Spezialisierung %q#D fehlen möglicherweise Attribute"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "fehlende primäre Templateattribute %s"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "fehlendes primäres Templateattribut %s"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "Template-ID %qE in Deklaration des ersten Templates"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "Templateparameterliste in expliziter Instanziierung verwendet"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "Definition für explizite Instanziierung angegeben"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "zu viele Templateparameterlisten in Deklaration von %qD"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "zu wenige Templateparameterlisten in Deklaration von %qD"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "der expliziten Spezialisierung von %D muss %<template <>%> vorausgehen"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "explizite Spezialisierung als %<concept%> deklariert"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "Nichttyp-Teilspezialisierung %qE ist nicht erlaubt"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "Teilspezialisierung %qE ist nur für Klassen und Variablen erlaubt"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "Standardargument in expliziter Spezialisierung angegeben"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD ist keine Templatefunktion"
@@ -55218,159 +55266,159 @@ msgstr "%qD ist keine Templatefunktion"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "Spezialisierung der implizit deklarierten speziellen Elementfunktion"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "keine Elementfunktion %qD in %qT deklariert"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "»friend«-Deklaration %qD ist für explizite Spezialisierung nicht sichtbar"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "%<friend%>-Deklaration hier"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "explizite Spezialisierung des Funktionskonzepts %qD"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "Argument von %<__integer_pack%> muss zwischen 0 und %d liegen"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "Expansion der Basisinitialisierung %qT enthält keine Parameterpacks"
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "Expansionsmuster %qT enthält keine Parameterpacks"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "Expansionsmuster %qE enthält keine Parameterpacks"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "Parameterbündel nicht mit %<...%> aufgelöst:"
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "         %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "Deklaration des Templateparameters %q+D überdeckt einen Templateparameter"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "Deklaration von %q+#D überdeckt einen Templateparameter"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "Templateparameter %qD hier deklariert"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "Spezialisierung des Variablenkonzepts %q#D"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "Templateparameter nicht in partieller Spezialisierung herleitbar:"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente und ist nicht eingeschränkter als das primäre Template; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "ursprüngliches Template hier"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partielle Spezialisierung ist nicht näher spezialisiert als das ursprüngliche Template, da es mehrere Parameter mit einer »pack«-Erweiterung ersetzt"
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "zu viele Argumente für teilweise Spezialisierung %qT"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "Teilspezialisierung %qD ist nicht spezialisierter als"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "primäres Template %qD"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "Argument %qE für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "Argument %qT für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "Templateargument %qE betrifft Templateparameter"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "Typ %qT des Templatearguments %qE hängt von Templateparameter ab"
 msgstr[1] "Typ %qT des Templatearguments %qE hängt von Templateparametern ab"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "Deklaration von %qD macht vorherige Template-Instanziierung für %qD mehrdeutig"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "teilweise Spezialisierung von %qD nach Instanziierung von %qD"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "kein Standard-Argument für %qD"
@@ -55379,47 +55427,47 @@ msgstr "kein Standard-Argument für %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "Parameterpack %q+D muss am Ende der Templateparameterliste sein"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "Standardtemplateargumente dürfen in friend-Redeklaration eines Funktionstemplates nicht verwendet werden"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "Standardtemplateargumente dürfen in friend-Deklaration nicht verwendet werden"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Standardtemplateargumente dürfen in Funktionstemplates nur mit %<-std=c++11%> und %<-std=gnu++11%> verwendet werden"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "Standardtemplateargumente dürfen in teilweiser Spezialisierung nicht verwendet werden"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Standardargument für Template-Parameter für %qD umschließende Klasse"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "Template %qD deklariert"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "Templateklasse ohne Namen"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "Element-Template %qD darf keine virt-Spezifizierer haben"
@@ -55429,493 +55477,493 @@ msgstr "Element-Template %qD darf keine virt-Spezifizierer haben"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ungültige Templatedeklaration von %qD"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "Template-Definition eines Nicht-Templates %q#D"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d Ebenen von Template-Parametern für %q#D erwartet, %d erhalten"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d Template-Parameter für %q#D erhalten"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d Template-Parameter für %q#T erhalten"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  aber %d benötigt"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "Template-Argumente für %qD passen nicht zum ursprünglichen Template %qD"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "verwenden Sie %<template<>%> für eine explizite Spezialisierung"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ist kein Template-Typ"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "keine Templatespezifizierer in Deklaration von %qD angegeben"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "mit %d Template-Parameter redeklariert"
 msgstr[1] "mit %d Template-Parametern redeklariert"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 msgstr[1] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "Template-Parameter %q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "hier als %q#D redeklariert"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "Deklaration von Templateparameter %q+#D mit unterschiedlichen Einschränkungen"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprüngliche Deklaration trat hier auf"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Redefinition des Standardarguments für %q#D"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprüngliche Definition trat hier auf"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "Redeklaration %q#D mit unterschiedlichen Constraints"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "es muss die Adresse einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "es muss der Name einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "es muss ein Zeiger auf ein Element der Form %<&X::Y%> sein"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "da es ein Element von %qT ist"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  Template-Parameter %qD konnte nicht hergeleitet werden"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr " Typen %qT und %qT haben unverträgliche CV-Qualifizierer"
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr " unpassende Typen %qT und %qT"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr " Templateparameter %qD ist kein Parameterpack wie Argument %qD"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr " Templateargumente %qE passt nicht zum konstanten Zeiger auf Element %qE"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr " %qE entspricht nicht %qE"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr " unpassende Herleitung von Parameterpack mit %qT und %qT"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr " hergeleitete Typen für Parameter %qT stehen in Konflikt (%qT und %qT)"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr " hergeleitete Werte für Nicht-Typ-Parameter %qE stehen in Konflikt (%qE und %qE)"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr " Arraytyp %qT mit veränderlicher Größe ist kein gültiges Templateargument"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr " Typ %qT von Elementfunktion ist kein gültiges Templateargument"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  Kandidat erwartet mindestens %d Argument, %d angegeben"
 msgstr[1] "  Kandidat erwartet mindestens %d Argumente, %d angegeben"
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr " %qE (Typ %qT) kann nicht in den Typ %qT umgewandelt werden"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr " %qT ist mehrdeutige Basisklasse von %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr " %qT ist nicht vom Typ %qT abgeleitet"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr " Templateparameter eines Template-Templatearguments sind mit anderen hergeleiteten Templateargumenten unverträglich"
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  für %qT kann kein Template aus Nicht-Templatetyp %qT hergeleitet werden"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr " Template-Argument %qE passt nicht zu %qE"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qE keine Variable ist"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE ist in C++98 kein gültiges Templateargument des Typs %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "die Adresse des %qT-Teilobjekts von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument, weil sie keine statische Lebensdauer hat"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD ist kein gültiges Templateargument, weil %qD eine Variable und nicht die Adresse einer Variable ist"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ist kein gültiges Templateargument für %qT, da es keine Adresse einer Variable ist"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da Zeichenkettensymbole in diesem Zusammenhang nicht verwendet werden können"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "in Templateargument für Typ %qT"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "Templateargument %qE für Typ %qT ist keine Übersetzungszeit-Konstante"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da es in CV-Qualifikation in Konflikt steht"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein L-Wert ist"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D ist kein gültiges Templateargument für Typ %qT, weil eine Referenzvariable keine konstante Adresse hat"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es ein Zeiger ist"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "stattdessen %qE verwenden"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es vom Typ %qT ist"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "Attribute an Templateargument %qT werden ignoriert"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "Attribute an Templateargument %qE werden ignoriert"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "eingegebener Klassenname %qD als Template-Templateargument verwendet"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ungültige Verwendung des Destruktors %qE als Typ"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "um auf ein Typelement eines Templateparameters zu verweisen, %<typename %E%> verwenden"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "Typ/Wert des Arguments %d passt nicht in Template-Parameterliste für %qD"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  Konstante des Typs %qT erwartet, %qT erhalten"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  mehrdeutiges Templateargument für Nichttyp-Templateparameter wird wie ein Funktionstyp behandelt"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  Klassentemplate erwartet, %qE erhalten"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  einen Typ erwartet, %qE erhalten"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  einen Typ erwartet, %qT erhalten"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  Klassentemplate erwartet, %qT erhalten"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ein Template des Typs %qD erwartet, %qT erhalten"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "unpassende Beschränkungen für Argument %d in Template-Parameterliste für %qD"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD erwartet, %qD erhalten"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "Templateargument %qE konnte nicht von %qT in %qT umgewandelt werden"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "Templateargument %d ist ungültig"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte %d sein)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte mindestens %d sein)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "für %qD bereitgestellt"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Alias-Template %qD"
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Konzept %qD"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "jegliche Instanziierung mit nichtleerer Parameterpackung wäre unzulässig"
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D ist kein Funktionstemplate"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "Nicht-Template-Typ %qT als Template verwendet"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "Für Template-Deklaration %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "Template-Einschränkung für %qD fehlgeschlagen"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Verwendung des ungültigen Variablentemplates %qE"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (%<-ftemplate-depth=%> verwenden, um dies zu erhöhen)"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexibles Arrayelement %qD in Union"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "Falten einer leeren Expansion über %O"
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE ist nicht das vollständige Muster einer Packexpansion"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qT"
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qE"
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  bei Instanziierung des Standardarguments für Aufruf von %qD"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "Erzeugung eines Zeigers auf Elementfunktion des Nicht-Klassentyps %qT"
@@ -55933,291 +55981,291 @@ msgstr "Erzeugung eines Zeigers auf Elementfunktion des Nicht-Klassentyps %qT"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Variable %qD hat Funktionstyp"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ungültiger Parametertyp %qT"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "in Deklaration %q+D"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "Funktion gibt ein Array zurück"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "Funktion gibt eine Funktion"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "Referenz auf »void« wird gebildet"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "Zeiger auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "Referenz auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "Zeiger auf Element des Nicht-Klassentypen %qT wird erzeugt"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "Zeiger auf Elementreferenztyp %qT wird erzeugt"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "Zeiger auf Element mit Typ »void« wird erzeugt"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD wird für ein leeres Pack instanziiert"
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ist kein Klassen-, Struktur- oder Union-Typ"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT wird in %qT aufgelöst, was kein Aufzählungstyp ist"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT wird in %qT aufgelöst, aber das ist kein Klassentyp"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "Verwendung von %qs in Template"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "qualifizierender Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "Abhängigenname %qE wird als Nicht-Typ erkannt, aber die Instanziierung liefert einen Typ"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "%<typename %E%> sagen, wenn ein Typ gemeint ist"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "Initialisierer für %q#D expandiert zu einer leeren Ausdrucksliste"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ungültiges Feld %qD wird verwendet"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "falsche Verwendung eines Packauflösungs-Ausdruckes"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> verwenden, um Argumentpack aufzulösen"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "leere Initialisierung in »init-capture« für Lambda"
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD wurde in diesem Gültigkeitsbereich nicht deklariert, und bei argumentabhängiger Suche am Ort der Instanziierung wurden keine Deklarationen gefunden"
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "Deklarationen in abhängiger Basis %qT wurden bei unqualifizierter Suche nicht gefunden"
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "stattdessen %<this->%D%> verwenden"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "stattdessen %<%T::%D%> verwenden"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD hier deklariert, später in der Übersetzungseinheit"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_convertvector%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT ist/verwendet anonymen Typen"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Templateargument für %qD verwendet lokalen Typ %qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT ist ein variabel modifizierter Typ"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "Ganzzahlausdruck %qE ist nicht konstant"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  Versuch, %qD zu instanziieren"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "mehrdeutige Template-Instanziierung für %q#T"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "mehrdeutige Template-Instanziierung für %q#D"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explizite Instanziierung des Nicht-Templates %q#D"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "Explizite Instanziierung des Variablenkonzepts %q#D"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "Explizite Instanziierung des Funktionskonzepts %q#D"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD ist kein statisches Datenelement eines Klassentemplates"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "kein passendes Template für %qD gefunden"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "Typ %qT für explizite Instanziierung %qD passt nicht zum deklarierten Typ %qT"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explizite Instanziierung von %q#D"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "doppelte explizite Instanziierung von %q#D"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO-C++ 1998 verbietet die Verwendung von %<extern%> bei expliziten Instanziierungen"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "Speicherklasse %qD auf Templateinstanziierung angewendet"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explizite Instanziierung des Nicht-Klassen-Templates %qD"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explizite Instanziierung des Nicht-Templatetyps %qT"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explizite Instanziierung von %q#T vor Definition des Templates"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO-C++ verbietet die Verwendung von %qE bei expliziten Instanziierungen"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "doppelte explizite Instanziierung von %q#T"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
@@ -56229,153 +56277,153 @@ msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explizite Instanziierung von %qD, aber keine Definition verfügbar"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d beim Instanziieren von %q+D, möglicherweise wegen Generierung der virtuellen Tabelle (%<-ftemplate-depth=%> verwenden, um den Höchstwert zu erhöhen)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Nichttypen-Templateparameter von hergeleitetem Klassentyp sind erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT ist kein gültiger Typ für einen Nichttyp-Templateparameter, da er nicht strukturell ist"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Nichttypen-Templateparameter von Klassentyp sind nur mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ungültiger Nicht-Typ-Parameter für Template"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T ist kein gültiger Typ für einen Nicht-Typ-Parameter eines Templates"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "Schlüsselwort %<template%> nicht innerhalb der declarator-id erlaubt"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "ein Konzept kann nicht eingeschränkt werden"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "das Konzept %qE ist nicht im Gültigkeitsbereich des Namensraums"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "Ermittlung aus geschweift geklammerter Initialisierungsliste erfordert %<#include <initializer_list>%>"
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "nicht herleitbares Templates %qT wird ohne Template-Argumente verwendet"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Alias-Template-Herleitung ist erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "Templateargumente für die Kopierinitialisierung von %qT können nicht abgeleitet werden, da es keine expliziten Ableitungshinweise oder benutzerdeklarierten Konstruktoren gibt"
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "Templateargumente für %qT können nicht abgeleitet werden, da es keine Ableitungshinweise gibt"
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "Argumentherleitung für Klassentemplate gescheitert:"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Explizite Herleitungshinweise werden nicht für »copy-initialization« berücksichtigt"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "Argumentherleitung für Klassentemplate von %qT fehlgeschlagen: expliziter Herleitungshinweis in copy-list-initialization ausgewählt"
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "der explizite Herleitungshinweis ist hier deklariert"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT beabsichtigt möglicherweise nicht, Argumentherleitung für Klassentemplates zu unterstützen"
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "fügen Sie einen Herleitungshinweis hinzu, um diese Warnung zu unterdrücken"
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization von %<auto%> erfordert genau ein Element"
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "um %<std::initializer_list%> herzuleiten, verwenden Sie einen copy-list-initialization (also mit %<=%> vor dem %<{%>)"
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Lambda-Rückgabewert von %qE kann nicht hergeleitet werden"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qT kann nicht aus %qE hergeleitet werden"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "Platzhalter-Beschränkungen nicht erfüllt"
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "hergeleiteter Initialisierer erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Rückgabetyp erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Ausdruckstyp erfüllt die Platzhalterbeschränkungen nicht"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ungültige Verwendung von %qT in Templateargument"
@@ -56510,531 +56558,531 @@ msgstr "%q+#D kann nicht deklariert werden"
 msgid "  since %q+#D declared in base class"
 msgstr "  denn %q+#D ist in Basisklasse deklariert"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%qs wird in %<if constexpr%> stets zu %<true%> ausgewertet"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "es wird empfohlen, explizite geschweifte Klammern um leeren Körper in %<do%>-Anweisung zu setzen"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr "polymorpher Typ %q#T wird per Wertzuweisung gefangen"
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr "Typ %q#T wird per Wertzuweisung gefangen"
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr "Nichtreferenztyp %q#T wird gefangen"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "Typ des %<asm%>-Operanden %qE konnte nicht ermittelt werden"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "%<__label__%>-Deklarationen sind nur im Funktionsgültigkeitsbereich erlaubt"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "ungültige Verwendung des Elementes %qD in statischer Elementfunktion"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "fehlende Templateargumente für %qE"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "ein Anweisungsausdruck reicht nicht als Kontext für Überladungs-Auflösung nicht aus"
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "ein Konzept kann nicht wie eine Funktion aufgerufen werden"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "Argumente für Destruktor sind nicht erlaubt"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> ist für statische Elementfunktionen nicht verfügbar"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ungültige Verwendung von %<this%> in Nicht-Element-Funktion"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ungültige Verwendung von %<this%> auf höchster Ebene"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ungültiger angegebener Gültigkeitsbereich in Pseudodestruktor-Name"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "qualifizierter Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE ist nicht vom Typ %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "zusammengesetztes Literal vom Nicht-Objekt-Typ %qT"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "Templatetypparameter müssen das Schlüsselwort %<class%> oder %<typename%> verwenden"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ungültige Verwendung des Typs %qT als Standardwert für einen Template-Templateparameter"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ungültiges Standardargument für einen Template-Templateparameter"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "Definition von %q#T in Templateparameterliste"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ungültige Definition des qualifizierten Typen %qT"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ungültige Spezifizierung der Basisklasse"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "Element %qD von unbenannter Union kann nicht eingefangen werden"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD ist nicht eingefangen"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "das Lambda hat keinen »capture-default«"
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "Lambda in lokaler Klasse %q+T kann Variablen aus dem umschließenden Kontext nicht einfangen"
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "Verwendung lokaler Variable mit automatischer Speicherklasse aus enthaltender Funktion"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "Verwendung eines Parameters aus enthaltender Funktion"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "Verwendung eines Parameters außerhalb des Funktionskörpers"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "fehlende Templateargumente"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "Templateparameter %qD vom Typ %qT ist in ganzzahligem Konstantenausdruck nicht erlaubt, da er nicht Ganzzahl- oder Aufzählungstyp hat"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Verwendung des Klassentemplates %qT als Ausdruck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "Abfrage des Elementes %qD ist im Gitter der Mehrfachvererbung mehrdeutig"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD kann nicht in Konstanten-Ausdruck auftreten"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "Typ von %qE ist unbekannt"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT ist kein Aufzählungstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "Parameterpack %<__bases%> ist nur in Templatedeklaration gültig"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "%<offsetof%> kann nicht auf Destruktor %<~%T%> angewandt werden"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<offsetof%> kann nicht auf Elementfunktion %qD angewandt werden"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "%<offsetof%> kann nicht auf Elementfunktion angewandt werden"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "%<offsetof%> kann nicht auf Aufzähler %qD angewandt werden"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "%<offsetof%> innerhalb von Typ %qT (der kein Standardlayout hat) ist bedingt unterstützt"
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> ist in OpenMP nur innerhalb von %<declare simd%>-Klauseln erlaubt"
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "benutzerdefinierte Reduktionsauflösung ist mehrdeutig"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE in %<reduction%>-Klausel ist ein Array der Länge 0"
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE hat konstanten Typ für %<reduction%>"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "benutzerdefinierte Reduktion mit Konstruktorinitialisierung für Basisklasse %qT"
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "»linear«-Klausel mit Modifizierer %qs wird auf Nicht-Referenz-Variable mit Typ %qT angewandt"
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "»linear«-Klausel wird auf Variable vom Typ %qT angewandt, die weder ganzzahlig noch Zeiger ist"
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "Ausdruck für »linear«-Schrittweite muss ganzzahlig sein"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD ist in Klausel %<firstprivate%> keine Variable"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD ist in Klausel %<lastprivate%> keine Variable"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "statischer %<gang%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "statischer %<gang%>-Ausdruck muss positiv sein"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "Ausdruck für %<gang%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "Ausdruck für %<vector%>-Länge muss ganzzahlig sein"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "Ausdruck für %<worker%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "Wert von %<gang%> muss positiv sein"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "Wert der %<vector%>-Länge muss positiv sein"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "Wert der %<worker%>-Nummer muss positiv sein"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "Plan-Teilgrößenausdruck muss bestimmt sein"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig sein"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig, positiv und konstant sein"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-ID muss ganzzahlig sein"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "Ausdruck für %<dist_schedule%>-Chunkgröße muss ganzzahlig sein"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD ist in %<aligned%>-Klausel keine Variable"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE in %<aligned%>-Klausel ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "Ausdruck für Ausrichtung der %<aligned%>-Klausel muss ganzzahlig sein"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD ist in %<nontemporal%>-Klausel keine Variable"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD tritt in %<nontemporal%>-Klauseln mehrfach auf"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%<this%> ist in %<allocate%>-Klausel nicht erlaubt"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD ist in %<allocate%>-Klausel keine Variable"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD kommt in %<allocate%>-Klausel mehrfach vor"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD ist in %<depend%>-Klausel weder lvalue-Ausdruck noch Arrayabschnitt"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "Template %qE in Klausel %qs"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "überladener Funktionsname %qE in Klausel %qs"
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "Ausdruck für %<grainsize%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "Ausdruck für %<priority%> muss ganzzahlig sein"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "%<hint%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%<hint%>-Ausdruck muss ganzzahlig und konstant sein"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "Variable %qs ist weder Zeiger noch Referenz auf Zeiger"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "Variable %qs ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "Argument für %<tile%> erfordert ganzzahligen Typ"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-qualifiziertes %qE ohne %<mutable%>-Element darf nur in %<shared%>- oder %<firstprivate%>-Klauseln vorkommen"
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD ist weder Datei-, Namens- noch Blockbereichsvariable"
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> Direktive %qE nicht in Definition von %qT"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "Unterschied zwischen %qE und %qD hat keinen Ganzzahltyp"
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> zusammen mit Iterationsvariable %qE verwendet"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statische Erklärung gescheitert: %s"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr "%qE wird zu »false« ausgewertet"
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "Nicht-konstante Bedingung für statische Behauptung"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "Argument für %<decltype%> muss ein Ausdruck sein"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "Operand des Faltungsausdrucks hat keine unexpandierten Parameterpackungen"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "beide Argumente in binärer Faltung haben unexpandierte Parameterpackungen"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "keine unexpandierten Parameterpackungen in binärer Faltung"
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
@@ -57042,22 +57090,22 @@ msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "Zieltyp %qT von %<__builtin_bit_cast%> ist ein Arraytyp"
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "Zieltyp %qT von %<__builtin_bit_cast%> ist nicht trivial kopierbar"
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "Quelltyp %qT von %<__builtin_bit_cast%> ist nicht trivial kopierbar"
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "in %<__builtin_bit_cast%> ist die Quellgröße %qE ungleich der Zieltypgröße %qE"
@@ -57067,1053 +57115,1053 @@ msgstr "in %<__builtin_bit_cast%> ist die Quellgröße %qE ungleich der Zieltypg
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV-Qualifizierer können nicht auf %qT angewendet werden"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "Anweisungs-Ausdruck in konstantem Ausdruck"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr "%<-fabi-version=13%> (GCC 8.2) korrigiert die Aufrufkonvention für %qT, die in 8.1 versehentlich geändert wurde"
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr "%<-fabi-version=12%> (GCC 8.1) ändert versehentlich die Aufrufkonvention für %qT"
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, gcc-internal-format
 msgid " declared here"
 msgstr " hier deklariert"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "die Aufrufkonvention für %qT ändert sich mit %<-fabi-version=13%> (GCC 8.2)"
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " da alle seine Kopier- und Verschiebekonstruktoren gelöscht sind"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "Basisklasse %qT ist nicht %<public%>"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qD ist nicht %<public%>"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD ist veränderlich"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD ist kein nicht-struktureller Typ"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "Argument des Attributs %qE muss eine Zeichenkettenkonstante sein"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "Attribut %qE kann nur auf Funktionen oder auf Klasse- oder Aufzählungstypen angewendet werden"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "Attribut %qE kann nur auf nicht-statische Datenelemente angewendet werden"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "Attribut %qE kann nicht auf Bitfeld angewendet werden"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "Attribut %qE erwartet keine Argumente"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "Attribut %qE aus ISO C++ ist nicht auf Funktionen anwendbar; wird als %<[[gnu::%E]]%> behandelt"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "angeforderte %<init_priority%> muss ganzzahlig und konstant sein"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "nur Attribut %qE kann für Definitionen von Objekten eines Klassentyps im Datei-Gültigkeitsbereich verwendet werden"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "angeforderte %<init_priority%> %i liegt außerhalb des Bereichs [0, %i]"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "angeforderte %<init_priority%> %i ist für interne Verwendung reserviert"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "Attribut %qE wird auf dieser Plattform nicht unterstützt"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "Redeklaration von %qD fügt ABI-Marke %qE hinzu"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "Attribut %qE erfordert Argumente"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Argumente für Attribut %qE müssen enge Zeichenkettenliterale sein"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Argumente für Attribut %qE müssen gültige Bezeichner enthalten"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> ist kein gültiges Anfangszeichen für einen Bezeichner"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> ist kein gültiges Zeichen in einem Bezeichner"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "Attribut %qE auf Nicht-Klassen-, Nicht-Enum-Typ %qT angewendet"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "Attribut %qE auf %qT nach seiner Definition angewendet"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "%qE-Attribut wird für Templateinstanziierung %qT ignoriert"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "%qE-Attribut wird für Templatespezialisierung %qT ignoriert"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE-Attribut wird auf %qD angewendet, das weder Funktion noch Variable ist"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "Attribut %qE wird auf »extern \"C\"«-Deklaration %qD angewendet"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "Null als Nullzeigerkonstante"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "%<lang_*%> check: failed in %s, at %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "Vergleich zwischen den unterschiedlichen Zeigertypen %qT und %qT benötigt Umwandlung"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "Umwandlung zwischen den unterschiedlichen Zeigertypen %qT und %qT benötigt Umwandlung"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "Bedingungsausdruck mit den unterschiedlichen Zeigertypen %qT und %qT benötigt Umwandlung"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO-C++ verbietet Vergleich zwischen Zeiger des Typs %<void *%> und Zeiger auf Funktion"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO-C++ verbietet Umwandlung zwischen Zeiger des Typs %<void *%> und Zeiger auf Funktion"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO-C++ verbietet Bedingungsausdruck mit Zeiger des Typs %<void *%> und Zeiger auf Funktion"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "beim Vergleich zwischen unterschiedlichen Zeiger-auf-Element-Typen %qT und %qT fehlt eine Typkonvertierung"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "bei Umwandlung zwischen unterschiedlichen Zeiger-auf-Element-Typen %qT und %qT fehlt eine Typkonvertierung"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "im Bedingungsausdruck mit unterschiedlichen Zeiger-auf-Element-Typen %qT und %qT fehlt eine Typkonvertierung"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "kanonische Typen unterscheiden sich für identische Typen %qT und %qT"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "selber kanonischer Typknoten für die unterschiedlichen Typen %qT und %qT"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "ungültige Anwendung von %qs auf Elementfunktion"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ungültige Anwendung von %<sizeof%> auf ein Bitfeld"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO-C++ verbietet Anwendung von %<sizeof%> auf einen Ausdruck mit Funktionstyp"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ungültige Anwendung von %<__alignof%> auf ein Bitfeld"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO-C++ verbietet Anwendung von %<__alignof%> auf einen Ausdruck mit Funktionstyp"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "Argument für %<alignas%> hat nicht-ganzzahligen Typen %qT"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion vom Typ %qT"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "Adresse eines temporären Wertes wird verwendet"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ verbietet, eine Zeichenkettenkonstante in %qT zu konvertieren"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "veraltete Konvertierung von Zeichenkettenkonstante in %qT"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "Anforderung des Elements %qD in %qE, das vom Zeigertyp %qT ist (vielleicht war %<->%> gemeint?)"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "Abfrage des Elementes %qD in %qE, das vom Nicht-Klassentyp %qT ist"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "ungültige Verwendung des nicht-statischen Datenelements %qE"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ungültiger Zugriff auf nicht-statisches Datenelement %qD in virtueller Basis des NULL-Objektes"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "Objekttyp %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "der zerstörte Typ ist %qT, aber der Destruktor verweist auf %qT"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "auf Feld %q#D kann mittels %q#D zugegriffen werden"
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T hat kein Element namens %qE"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %q#D? (zugreifbar über %q#D)"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %q#D? (aus diesem Kontext nicht zugreifbar)"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %qE?"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> ist kein Element von %qT"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT ist keine Basis von %qT"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD ist keine Elementtemplatefunktion"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT ist kein Zeiger auf Objekt"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ungültige Verwendung von Arrayindizierung bei Zeiger auf Element"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ungültige Verwendung des unären %<*%> bei Zeiger auf Element"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ungültige Verwendung impliziter Umwandlung bei Zeiger auf Element"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "linker Operand von %<->*%> muss Zeiger auf Klasse sein, ist aber ein Zeiger auf Element des Typs %qT"
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "Index fehlt in Arrayreferenz"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "Indizierung eines als %<register%> deklarierten Arrays"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indizierter Wert ist weder ein Array noch ein Zeiger"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "bei Verwendung von %qE fehlt Objekt"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO-C++ verbietet den Aufruf von %<::main%> vom Programm aus"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<.*%> oder %<->*%> muss verwendet werden, um Zeiger auf Element als Funktion in %<%E (...)%> aufzurufen, z.B. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Ausdruck kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "zu viele Argumente für Konstruktor %q#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "zu wenige Argumente für Konstruktor %q#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "zu viele Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Zu wenige Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "zu viele Argumente für Funktion %q#D"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "zu wenige Argumente für Funktion %q#D"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "zu viele Argumente für Methode %q#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "zu wenige Argumente für Methode %q#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "zu viele Argumente für Funktion"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "zu wenige Argumente für Funktion"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "Parameter %P von %qD hat unvollständigen Typen %qT"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "Parameter %P hat unvollständigen Typen %qT"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "Die Adresse von %qD wird nie NULL sein"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "der Compiler kann annehmen, dass die Adresse von %qD niemals NULL ist"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "bitweise Operation zwischen den unterschiedlichen Aufzählungstypen %qT und %qT ist veraltet"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "Arithmetik zwischen den unterschiedlichen Aufzählungstypen %qT und %qT ist veraltet"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr "Vergleich zwischen Aufzählungstyp %qT und Gleitkommatyp %qT ist veraltet"
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "Vergleich zwischen Gleitkommatyp %qT und Aufzählungstyp %qT ist veraltet"
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "Arithmetik zwischen Aufzählungstyp %qT und Gleitkommatyp %qT ist veraltet"
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "Arithmetik zwischen Gleitkommatyp %qT und Aufzählungstyp %qT ist veraltet"
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "Umwandlung in Typ %qT von überladener Funktion wird angenommen"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL in Arithmetik verwendet"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO-C++ verbietet Vergleich zwischen Zeiger und Ganzzahl"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Operandentypen sind %qT und %qT"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "Drei-Wege-Vergleich von Vektoren"
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "geordneter Vergleich von Zeiger mit der Zahl 0 (%qT und %qT)"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "ungeordneter Vergleich mit Nicht-Gleitkomma-Argument"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "implizite Umwandlung von %qH in %qI zur Anpassung an anderen Operanden des Binärausdrucks"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ungültige Operanden der Typen %qT und %qT für binäres %qO"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers des Typs %<void *%> in Subtraktion"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf eine Funktion in Subtraktion"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf Methode in Subtraktion"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ungültige Verwendung eines Zeigers auf einen unvollständigen Typen in Zeigerarithmetik"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "Adresse des Konstruktors %qD wird genommen"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "Adresse des Destruktors %qD wird genommen"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ungültige Verwendung von %qE um Zeiger auf Elementfunktion zu erzeugen"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  eine qualifizierte ID ist erforderlich"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "Klammern um %qE können nicht verwendet werden, einen Zeiger auf Elementfunktion zu erzeugen"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer nicht qualifizierten oder geklammerten nicht-statischen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer gebundenen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "Adresse eines rvalues wird ermittelt"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse der Funktion %<::main%>"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "Zeiger auf Referenzelement %qD kann nicht erzeugt werden"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "Versuch, die Adresse eines Bitfelds zu bestimmen"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "Adresse der direkten Funktion %qD wird genommen"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> auf einem Ausdruck vom Typ %<bool%>"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "meinten Sie ein logisches Nicht (%<!%>)?"
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO-C++ verbietet erhöhen einer Aufzählung"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO-C++ verbietet verringern einer Aufzählung"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht erhöht werden"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht verringert werden"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Erhöhen eines Zeigers vom Typ %qT"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Verringern eines Zeigers vom Typ %qT"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "%qs-Ausdruck von %<volatile%>-qualifiziertem Typ ist veraltet"
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator--%> ist verboten"
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator++%> ist in C++17 verboten"
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator++%> ist veraltet"
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "Adresse von %<this%> kann nicht ermittelt werden, das ein R-Wert-Ausdruck ist"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "Adresse der Register-Variablen %qD angefordert"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "Adresse für %qD angefordert, was als %<register%> deklariert ist"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "Listeninitialisierung für Nicht-Klassentyp darf nicht geklammert sein"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Initialisierung behandelt"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Speicherinitialisierung behandelt"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in funktionaler Umwandlung behandelt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=80191
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "Ausdrucksliste für »%s« wird als zusammengesetzten Ausdruck behandelt"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "kein Kontext, um Typ von %qE aufzulösen"
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "Umwandlung des Typs %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<static_cast%> von Typ %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<reinterpret_cast%> von Typ %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "nutzlose Umwandlung in Typ %q#T"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "Typkennzeichner an Umwandlungs-Rückgabetyp ignoriert"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ungültiges %<static_cast%> von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "Klassentyp %qT ist unvollständig"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 msgid "converting from %qH to %qI"
 msgstr "Umwandlung von %qH nach %qI"
 
-#: cp/typeck.c:7956
+#: cp/typeck.c:7963
 #, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
-msgstr "ungültige Typumwandlung eines R-Wert-Ausdrucks des Typs %qT in Typ %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
+msgstr "ungültige Typumwandlung eines prvalue-Ausdrucks des Typs %qT in Typ %qT"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
 msgstr "Typumwandlung von %qH nach %qI verliert Genauigkeit"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "Umwandlung zwischen inkompatiblen Funktionstypen von %qH nach %qI"
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "Umwandlung zwischen inkompatiblen Elementzeigertypen von %qH nach %qI"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "Umwandlung von %qH in %qI erhöht erforderliche Ausrichtung des Zieltyps"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "Umwandlung zwischen Zeiger auf Funktion und Zeiger auf Objekt ist bedingt unterstützt"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ungültige Umwandlung von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ungültige Verwendung von %<const_cast%> mit Typ %qT, der weder Zeiger, Referenz, noch Zeiger auf ein Datenelement ist"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "ungültige Verwendung von %<const_cast%> mit Typ %qT, der ein Zeiger oder Referenz auf Funktionstyp ist"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ungültiges %<const_cast%> eines R-Wertes des Typs %qT in Typ %qT"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ungültiges %<const_cast%> von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO-C++ verbietet Umwandlung in Arraytyp %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ungültige Umwandlung in Funktionstyp %qT"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr "Verbundzuweisung mit %<volatile%>-qualifiziertem linken Operanden ist veraltet"
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  in Auswertung von %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "Zuweisung an Array von Initialisierungsliste"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "unverträgliche Typen in Zuweisung von %qT an %qT"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "Array als Initialisierung verwendet"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Ungültige Arrayzuweisung"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   in Umwandlung in Zeiger auf Elementfunktion"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "Umwandlung in Zeiger auf Element über virtuelle Basis %qT"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   in Umwandlung in Zeiger auf Element"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ungültige Umwandlung in Typ %qT von Typ %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%qH kann nicht nach %qI im Standardargument umgewandelt werden"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "%qH kann nicht nach %qI bei Argumentübergabe umgewandelt werden"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "%qH kann nicht nach %qI in Initialisierung umgewandelt werden"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 msgid "cannot convert %qH to %qI in return"
 msgstr "%qH kann nicht nach %qI in Rückgabe umgewandelt werden"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "%qH kann nicht nach %qI in Zuweisung umgewandelt werden"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Parameter %qP von %qD könnte Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "Parameter könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Ziel der Umwandlung könnte Kandidat ein für ein Formatattribut sein"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "Ziel der Initialisierung könnte ein Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "linke Seite der Zuweisung könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "bei Übergabe des Arguments %P von %qD"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "Referenz auf temporären Wert wird zurückgegeben"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "das Zurückgeben einer temporären %<initializer_list%> verlängert nicht die Lebenszeit des zugrundeliegenden Arrays"
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "Referenz auf lokale Variable %qD zurückgegeben"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "das Zurückgeben der lokalen %<initializer_list%>-Variable %qD verlängert nicht die Lebenszeit des zugrundeliegenden Arrays"
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "das Verschieben eines lokalen Objekts in einer return-Anweisung verhindert das Einsparen der Kopie"
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "entfernen Sie den Aufruf von %<std::move%>"
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "redundantes Verschieben in Rückgabeanweisung"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "Wert von Destruktor zurückgegeben"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "vom Behandler eines Funktions-try-Blocks eines Konstruktors kann nicht zurückgekehrt werden"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "Rückgabe eines Wertes von einem Konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "Return-Anweisung ohne Wert, in %qT zurückgebender Funktion"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "Initialisierungsliste wird zurückgegeben"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "widersprüchliche Typen %qT und %qT für Lambda-Rückgabetypen hergeleitet"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für automatischen Rückgabetyp: %qT und dann %qT"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "Return-Anweisung mit Wert, in Funktion mit Rückgabetyp %qT"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> darf nicht NULL zurückgeben, außer er ist mit %<throw%> deklariert (oder %<-fcheck-new%> ist eingeschaltet)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "rvalue wird als lvalue verwendet"
@@ -58377,107 +58425,102 @@ msgstr "entfernen Sie die %<{ }%> um den Initialisierer"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "Aggregat des Typs %qT kann nicht mit zusammengesetztem Literal initialisiert werden"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "Initialisierung für Element %qD fehlt"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "Element %qD ist nicht initialisierte Referenz"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Element %qD mit nicht initialisierten Feldern"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "Designator-Reihenfolge für Feld %qD passt nicht zur ursprünglichen Deklaration in %qT"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "kein Feld %qD in initialisierter Union gefunden"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "Indexwert statt Feldname in Union-Initialisierung"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "ringförmige Zeigerdelegation erkannt"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "Basisoperand von %<->%> hat Nicht-Zeiger-Typ %qT"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "Ergebnis von %<operator->()%> ergibt Nicht-Zeiger-Ergebnis"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "Basisoperand von %<->%> ist kein Zeiger"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kann nicht als Elementzeiger verwendet werden, da es vom Typ %qT ist"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "Elementzeiger %qE kann nicht auf %qE angewandt werden, da letzteres vom Nicht-Klassen-Typ %qT ist"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "Zeiger auf Elementtyp %qT mit Objekttyp %qT inkompatibel"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen rvalue"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen lvalue"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "Zeiger-auf-Element-Funktions-Typ %qT braucht vor C++20 einen lvalue"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionale Umwandlung in Arraytyp %qT"
 
-#: cp/typeck2.c:2213
-#, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "Templateargumente für %qT von %<()%> können nicht hergeleitet werden"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ungültige Wert-Initialisierung von Referenztyp"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "Aufruf der Funktion %qD, die unvollständigen Typen %q#T wirft"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "Aufruf einer Funktion, die unvollständigen Typen %q#T wirft"
@@ -58497,266 +58540,271 @@ msgstr "Logdatei %<vtv_set_ptr_data.log%> kann nicht geöffnet werden: %m"
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr "Logdatei %<vtv_count_data.log%> kann nicht geöffnet werden: %m"
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr "fehlende oder beschädigte object.d"
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr "%p hat keine semantische Routine"
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr "externe Symbole können keine Initialisierung haben"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "%<__gshared%> nicht innerhalb von sicheren Funktionen erlaubt; verwenden Sie stattdessen %<shared%>"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr "Typ %s wird aus dem Initialisierer %s hergeleitet, und Variablen können nicht vom Typ »void« sein"
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr "Variablen können nicht vom Typ %<void%> sein"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, gcc-internal-format
 msgid "cannot be declared to be a function"
 msgstr "kann nicht als Funktion deklariert werden"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, gcc-internal-format, gfc-internal-format
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "keine Definition von »struct %s«"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr "Speicherklasse %<auto%> hat nur dann einen Effekt, wenn der Typ hergeleitet ist; meinten Sie %<scope%>?"
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr "kann nicht %<final%> sein, meinten Sie %<const%>?"
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be %s"
 msgstr "kann nicht »%s« sein"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
 msgstr "kann nicht gleichzeitig »scope« und »%s« sein"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr "Feld kann nicht %<scope%> sein"
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr "Feld nicht in Interface erlaubt"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr "kann kein weiteres Feld sein, da es die festgelegte Größe %s ändert"
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr "Template kann nicht verwendet werden, um das Feld zum zusammengesetzten »%s« hinzuzufügen"
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr "nur Parameter oder foreach-Deklarationen können %<ref%> sein"
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr "nur Parameter oder Variablen auf dem Stapel können %<inout%> sein"
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr "inout-Variablen können nur innerhalb von inout-Funktionen deklariert werden"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr "Standardkonstruktion ist für den Typ »%s« deaktiviert"
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr "globale Variablen, statische Variablen, Felder, Manifest-Konstanten, ref- und out-Parameter können nicht %<scope%> sein"
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr "Referenz auf scope-Klasse muss selbst auch %<scope%> sein"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "void-Initialisierer für Zeiger ist in %<safe%>-Funktionen nicht erlaubt"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr "Manifest-Konstanten müssen Initialisierer haben"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr "Größe des Typs »%s« ist ungültig"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr "»%s« hat keinen Standardinitialisierer"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr "ist nicht %<static%> und kann daher keinen static-Initialisierer haben"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr "vom Typ »struct %s« verwendet »this(this)«, das ist jedoch in »static«-Initialisierung nicht erlaubt"
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr "Variablen im %<static%>-Speicher können keine Destruktoren haben"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, gcc-internal-format
 msgid "string expected for library name"
 msgstr "Zeichenkette für Bibliotheksnamen erwartet"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr "Funktionsname für die Startadresse erwartet"
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr "Funktionsname für die Startadresse erwartet, nicht »%s«"
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr "Zeichenkette für gemangelten Namen erwartet"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr "leere Zeichenkette ist für gemangelten Namen nicht erlaubt"
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr "die Zeichen in einem gemangelten Namen können nur vom Typ %<char%> sein"
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr "Zeichen 0x%02x ist in gemangeltem Namen nicht erlaubt"
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr "Zeichen 0x%04x ist in gemangeltem Namen nicht erlaubt"
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, gcc-internal-format
+msgid "takes no argument"
+msgstr "verarbeitet kein Argument"
+
+#: d/dmd/dsymbolsem.c:1526
 #, gcc-internal-format
 msgid "can only apply to a single declaration"
 msgstr "kann nur auf eine einzelne Deklaration angewendet werden"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr "dem Pragma fehlt das schließende %<;%>"
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
 msgstr "unvollständige Mixin-Deklaration (%s)"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr "der Basistyp kann nicht %<void%> sein"
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr "die Aufzählung »%s« muss mindestens eine Konstante enthalten"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, gcc-internal-format
 msgid "circular reference to enum member"
 msgstr "zirkulärer Verweis auf enum-Konstante"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr "Initialisierung mit »%s.%s + 1« erzeugt Überlauf für Typ »%s«"
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr "hat ungenauen Wert, wegen Verlust der Genauigkeit"
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr "Template-Tupelparameter muss der letzte sein"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, gcc-internal-format
 msgid "recursive mixin instantiation"
 msgstr "rekursive Mixin-Instanziierung"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, gcc-internal-format
 msgid "recursive expansion"
 msgstr "rekursive Expansion"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, gcc-internal-format
 msgid "error instantiating"
 msgstr "Fehler beim Instanziieren"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr "»%s« muss eine Funktion sein statt »%s«"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "without `this` cannot be %s"
 msgstr "ohne »this« kann »%s« nicht sein"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr "Speicherklasse %<auto%> hat nur dann einen Effekt, wenn der Rückgabetyp hergeleitet ist"
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, gcc-internal-format
 msgid "functions cannot be scope"
 msgstr "Funktionen können nicht %<scope%> sein"
@@ -58764,42 +58812,52 @@ msgstr "Funktionen können nicht %<scope%> sein"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr "statisches Element hat kein %<this%>, auf das sich das %<return%> beziehen könnte"
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr "»%s«-Funktionen können nicht abstrakt sein"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr "die Methode »%s« ist nicht virtuell und kann daher nicht »override« sein"
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr "eine Funktion, die nicht %<virtual%> ist, kann nicht übersteuert werden"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, gcc-internal-format
 msgid "cannot be both final and abstract"
 msgstr "kann nicht gleichzeitig %<final%> und %<abstract%> sein"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr "Funktionen mit »pragma(%s)« müssen »extern(C) %s %s([Parameter]..., const(char)*, ...)« sein, nicht »%s«"
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr "Funktionen mit »pragma(%s)« müssen »extern(C) %s %s([Parameter]..., const(char)*, va_list)« sein"
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr "Konstruktoren, Destruktoren, »postblit«, Invarianten, »new«- und »delete«-Funktionen sind im Interface »%s« nicht erlaubt"
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr "Funktionsrumpf ist innerhalb des Interface »%s« nur in final-Funktionen erlaubt"
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr "Destruktoren, »postblit« und Invarianten sind in »union %s« nicht erlaubt"
@@ -58807,172 +58865,172 @@ msgstr "Destruktoren, »postblit« und Invarianten sind in »union %s« nicht er
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr "Herleitung des Rückgabetypen wird nicht unterstützt, wenn die Funktion der Basisklasse übersteuert werden kann"
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr "»final«-Funktion »%s« kann nicht übersteuert werden"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr "mehrere Übersteuerungen derselben Funktion"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr "inkompatible kovariante Typen »%s« und »%s«"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr "übersteuert keine Funktion, wollten Sie »%s%s« übersteuern?"
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, gcc-internal-format
 msgid "does not override any function"
 msgstr "übersteuert keine Funktion"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "»final«-Funktion »%s.%s« kann nicht übersteuert werden"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "%<override%> ist nur auf Klassenelementfunktionen anwendbar"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr "in- und out-Verträge können nur ohne Rumpf vorkommen, wenn sie virtuelle Interface-Funktionen sind, oder %<abstract%>"
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "Template kann nicht verwendet werden, um virtuelle Funktion zu Klasse »%s« hinzuzufügen"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr "Standardkonstruktor für %<struct%> ist nur mit %<@disable%>, ohne Rumpf und ohne Parameter erlaubt"
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr "mindestens ein Argument vom Typ %<size_t%> erwartet"
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr "das erste Argument muss vom Typ »size_t« sein, nicht »%s«"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr "genau ein Argument vom Typ %<void*%> erwartet"
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr "genau ein Argument vom Typ »void« erwartet, nicht »%s«"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, gcc-internal-format
 msgid "structs, unions cannot be abstract"
 msgstr "%<struct%> und %<union%> können nicht %<abstract%> sein"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr "existiert bereits bei %s. Vielleicht in einer anderen Funktion desselben Namens?"
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr "Speicherklasse %<auto%> ist beim Deklarieren einer Klasse ungültig, meinten Sie %<scope%>?"
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr "der Basistyp muss eine Klasse oder ein Interface sein, nicht »%s«"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, gcc-internal-format
 msgid "circular inheritance"
 msgstr "zirkuläre Vererbung"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr "der Basistyp muss ein Interface sein, nicht »%s«"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, gcc-internal-format, gfc-internal-format
 msgid "inherits from duplicate interface %s"
 msgstr "erbt vom doppelten Interface »%s«"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot inherit from final class %s"
 msgstr "von der »final«-Klasse »%s« kann nicht geerbt werden"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "die C++-Basisklasse »%s« benötigt mindestens eine »virtual«-Funktion"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr "»static«-Klasse kann nicht von geschachtelter Klasse »%s« erben"
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr "ist in »%s« geschachtelt, aber die Oberklasse »%s« ist in »%s« geschachtelt"
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr "ist nicht geschachtelt, aber die Oberklasse »%s« ist in »%s« geschachtelt"
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr "ein impliziter Standardkonstruktor ist nicht möglich, da die Basisklasse »%s« keinen Standardkonstruktor hat"
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr "Felder einer »synchronized«-Klasse können nicht »%s« sein"
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr "zirkuläre Abhängigkeit eines Interfaces"
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr "Mixin-Templates sind keine regulären Templates"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "Template-Instanziierung »%s« verweist vorgreifend auf die Template-Deklaration »%s«"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, gcc-internal-format
 msgid "cannot resolve"
 msgstr "kann nicht aufgelöst werden"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr "kann keinen Alias für den Ausdruck »%s« bilden"
@@ -58987,22 +59045,22 @@ msgstr "\"%.*s\""
 msgid "(%s) is false"
 msgstr "(%s) ist falsch"
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr "Aufzählung kann nicht mit Klasse oder Zeiger auf »struct« initialisiert werden. Verwenden Sie eine »static const«-Variable stattdessen."
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr "ist veränderlich. Als threadlokale Variablen sind nur »const« oder »immutable class« erlaubt, nicht jedoch »%s«"
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr "ist ein Zeiger auf eine veränderliche »struct«. Nur Zeiger auf »const«, »immutable« oder »shared struct« sind als threadlokale Variablen erlaubt, nicht jedoch »%s«"
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, gcc-internal-format
 msgid "has forward references"
 msgstr "hat Vorwärtsreferenzen"
@@ -59062,22 +59120,22 @@ msgstr "die Basisklasse enthält keinen Standardkonstruktor, der vom impliziten
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr "der Standardkonstruktor der Basisklasse ist mit »@disabled« annotiert und kann daher nicht aufgerufen werden"
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
-msgstr "hat keine »return«-Anweisung, verspricht aber einen Rückgabewert vom Typ »%s«"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
+msgstr "hat keine »return«-Anweisung, soll aber Wert vom Typ »%s« zurückgeben"
 
-#: d/dmd/semantic3.c:862
+#: d/dmd/semantic3.c:864
 #, gcc-internal-format
-msgid "no return exp; or assert(0); at end of function"
+msgid "no `return exp;` or `assert(0);` at end of function"
 msgstr "weder »return Ausdruck;« noch »assert(0);« am Ende der Funktion"
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr "»synchronized«-Funktion »%s« muss ein Element der Klasse sein"
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr "nackte Assembler-Funktionen mit Verträgen werden nicht unterstützt"
@@ -59634,7 +59692,7 @@ msgstr "Die BOZ-Literalkonstante bei %L darf kein tatsächliches Argument für %
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Argumente von %qs bei %L und %L können nicht beide literale BOZ-Konstanten sein"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Ungültige Verwendung der BOZ-Literalkonstante bei %L"
@@ -60729,12 +60787,12 @@ msgstr "Unbenutzte Initialisierungszeichenkette bei %L, da die Variable die Län
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Initialisierungszeichenkette bei %L wurde abgeschnitten, um zur Variable zu passen (%ld/%ld)"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L ist kleiner als Eins"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "End-Index der Teilzeichenkette bei %L überschreitet Zeichenkettenlänge"
@@ -60915,7 +60973,7 @@ msgstr "Falsche INTENT-Spezifikation bei %C"
 msgid "deferred type parameter at %C"
 msgstr "Parameter mit zurückgestelltem Typ bei %C"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalarer INTEGER-Ausdruck bei %L erwartet"
@@ -63420,7 +63478,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Illegal id in copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63501,7 +63559,7 @@ msgstr "Variable %qs bei %L auf undefinierten Wert innerhalb der bei %L beginnen
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variable %qs bei %L kann nicht innerhalb der bei %L beginnenden Schleife als INTENT(INOUT)-Argument für Funktion %qs definiert werden"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Code zur Neu-Reservierung des reservierbaren Feldes bei %L wird hinzugefügt"
@@ -63637,12 +63695,12 @@ msgstr "Erstes Argument der definierten Zuweisung bei %L muss INTENT(OUT) oder I
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Zweites Argument der definierten Zuweisung bei %L muss INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
@@ -63752,547 +63810,547 @@ msgstr "Unverträgliche Ränge zwischen Argument bei %L und Argument bei %L (Ran
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Unverträgliche Ränge zwischen Argument bei %L und Argument bei %L (Rang-%d und Rang-%d)"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Ungültiges Argument für Prozedur bei %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Schnittstelle in Scheinprozedur %qs bei %L passt nicht: %s"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Effektives Argument für fortlaufenden Schein-Zeiger %qs bei %L muss einfach fortlaufend sein"
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Unverträgliche Typen zwischen Argument bei %L und Argument bei %L (%s/%s)."
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Unpassender Typ in Argument %qs bei %L; %s wurde an %s übergeben"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Feld mit vermutetem Rang bei %L erfordert Scheinargument %qs mit vermutetem Rang"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Effektives Argument für %qs bei %L muss polymorph sein"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Effektives Argument für %qs bei %L muss denselben deklarierten Typ haben"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Effektives Argument für %qs bei %L muss unbegrenzt polymorph sein, da das formale Argument ein Zeiger oder reservierbare unbegrenzt polymorphe Entität ist [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Effektives Argument für %qs bei %L sein muss Koarray sein"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Unpassender Korang in Argument %qs bei %L (%d und %d)"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "Effektives Argument für %qs bei %L muss einfach fortlaufend oder ein Element eines solchen Feldes sein"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Effektives Argument für Nicht-INTENT(INOUT)-Platzhalter %qs bei %L mit Typ LOCK_TYPE oder einer Komponente LOCK_TYPE"
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Effektives Argument für Nicht-INTENT(INOUT)-Platzhalter %qs bei %L mit Typ EVENT_TYPE oder einer EVENT_TYPE-Komponente"
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Scheinargument %qs muss Zeiger oder Feld mit angenommener Form ohne CONTIGUOUS-Attribut sein, da das effektive Argument bei %L nicht einfach fortlaufend ist und beide ASYNCHRONOUS oder VOLATILE sind"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Koarray bei %L wird an reservierbares, Nicht-Coarray, INTENT(OUT) Scheinargument %qs übergeben"
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Koarray bei %L wird an reservierbares, Nicht-Coarray-Scheinargument %qs übergeben, das ungültig wird, wenn der Reservierungsstatus geändert wird"
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorphes Skalar wird an Feld-Scheinargument %qs bei %L übergeben"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Element des Feldes mit vermuteter Form oder von Zeigern bei %L kann nicht zum Argument bei %L passen"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Element des Feldes mit vermuteter Form oder von Zeigern wird bei %2$L an ein Feld-Scheinargument %1$qs übergeben"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Erweiterung: Skalares effektives nicht-standardartiges, nicht-C_CHAR CHARACTER-Argument mit Feld-Scheinargument %qs bei %L"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalares effektives CHARACTER-Argument mit Feld-Scheinargument %qs bei %L"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Schlüsselwort-Argument %qs bei %L darf innerhalb einer Anweisungsfunktion nicht auftauchen"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Schlüsselwort-Argument %qs bei %L ist nicht in der Prozedur; meinen Sie %qs?"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Schlüsselwort-Argument %qs bei %L ist nicht in der Prozedur"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Schlüsselwort-Argument %qs bei %L ist bereits mit einem anderen effektiven Argument verbunden"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Mehr effektive als formale Argumente in Prozeduraufruf bei %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Fehlende alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Unerwartete alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Unerwartetes intrinsisches NULL() bei %L für Schein-%qs"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Nullzeiger bei %L an Nicht-Zeiger-Schein-%qs"
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "Effektives Argument bei %L für Scheinparameter vermuteten Typs hat abgeleiteten Typ mit typgebundenen oder FINAL-Prozeduren"
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Zeichenlänge passt nicht (%ld/%ld) zwischen effektivem Argument und Zeiger oder reservierbarem Scheinargument %qs bei %L"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Zeichenlänge passt nicht (%ld/%ld) zwischen effektivem Argument und Scheinargument %qs mit vermuteter Form bei %L"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Effektives Argument bei %L an reservierbares oder Zeiger-Scheinargument %qs muss Parameter mit Typ aufgeschobener Länge haben, genau dann, wenn das Scheinargument einen solchen hat"
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Zeichenlänge des effektiven Arguments kürzer als das des Scheinarguments %qs (%lu/%lu) bei %L"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Effektives Argument enthält zuwenige Elemente für Scheinargument %qs (%lu/%lu) bei %L"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Prozedurzeiger für Argument %qs bei %L erwartet"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Prozedur für Argument %qs bei %L erwartet"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Effektives Argument für %qs kann nicht Feld vermuteter Größe bei %L sein"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Effektives Argument für %qs muss ein Zeiger bei %L sein"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Effektives Nicht-Zeiger-Argument bei %L an Scheinzeiger %qs"
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Koindiziertes effektives Argument bei %L an Scheinzeiger %qs"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Koindiziertes effektives Argument bei %L an scheinreservierbares %qs erfordert INTENT(IN)"
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Koindiziertes effektives ASYNCHRONOUS- oder VOLATILE-Argument bei %L erfordert, dass Schein-%qs weder ASYNCHRONOUS noch VOLATILE hat"
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Koindiziertes effektives Argument bei %L mit reservierbarer endgültiger Komponente für Schein-%qs erfordert entweder VALUE oder INTENT(IN)"
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Effektives CLASS-Feldargument für %qs muss ein vollständiges Feld bei %L sein"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Effektives Argument für %qs muss ALLOCATABLE bei %L sein"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Feldbereich mit Vektorindex als effektives Argument bei %L ist unverträglich mit INTENT(OUT), INTENT(INOUT), VOLATILE- und ASYNCHRONOUS-Attribut des Scheinarguments %qs"
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Effektives Argument mit vermuteter Form bei %L ist wegen VOLATILE-Attribut unverträglich mit dem Scheinargument ohne vermutete Form %qs"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Feldbereich als effektives Argument bei %L ist wegen VOLATILE-Attribut unverträglich mit dem Scheinargument ohne vermutete Form %qs"
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Zeigerfeld als effektives Argument bei %L erfordert wegen VOLATILE-Attribut ein Scheinargument %qs mit vermuteter Form oder als Zeigerfeld"
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Fehlende alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Fehlendes effektives Argument für Argument %qs bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Bad component code"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): List mismatch"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): corrupted data"
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Gleiches effektives Argument mit INTENT(%s)-Argument %qs und INTENT(%s)-Argument %qs bei %L verbunden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): List mismatch"
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Prozedurargument bei %L ist lokal für PURE-Prozedur und hat das POINTER-Attribut"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Effektives koindiziertes Argument bei %L in PURE-Prozedur wird an INTENT(%s)-Argument übergeben"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Effektives koindiziertes Argument bei %L in PURE-Prozedur wird an POINTER-Scheinargument übergeben"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Koindiziertem polymorphen effektiven Argument bei %L wird polymorphes Scheinargument %qs übergeben"
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Prozedur %qs, die bei %L aufgerufen wird, ist nicht explizit deklariert; meinen Sie %qs?"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Prozedur %qs, die bei %L aufgerufen wird, ist nicht explizit deklariert"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Prozedur %qs mit einer impliziten Schnittstelle bei %L aufgerufen"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Das Zeigerobjekt %qs bei %L muss eine explizite Funktionsschnittstelle haben oder als Feld deklariert sein"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Das reservierbare Objekt %qs bei %L muss eine explizite Funktionsschnittstelle haben oder als Feld deklariert sein"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Reservierbare Funktion %qs bei %L muss eine explizite Funktionsschnittstelle haben"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Explizite Schnittstelle für polymorphes Argument bei %L erforderlich"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Schlüsselwort-Argument erfordert explizite Schnittstelle für Prozedur %qs bei %L"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Argument »%s« bei %L vermuteten Typs erfordert eine explizite Schnittstelle"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Effektives Argument mit LOCK_TYPE oder mit LOCK_TYPE-Komponente bei %L erfordert eine explizite Schnittstelle für Prozedur %qs"
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Effektives Argument mit EVENT_TYPE oder mit EVENT_TYPE-Komponente bei %L erfordert eine explizite Schnittstelle für Prozedur %qs"
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD-Argument an NULL bei %L erforderlich"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Argument vermuteten Ranges erfordert eine explizite Schnittstelle bei %L"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Prozedurzeiger-Komponente %qs mit einer impliziten Schnittstelle bei %L aufgerufen"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Schlüsselwortargument erfordert explizite Schnittstelle für Prozedurzeigerkomponente %qs bei %L"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "In NULL()-Argument bei %L wird MOLD= benötigt: Mehrdeutig zwischen spezifischen Funktionen %s und %s"
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Symbol %qs kann nicht gefunden werden"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entität %qs bei %L ist bereits in der Schnittstelle vorhanden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Bad interface type"
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "GENERIC %qs bei %L kann nicht überschrieben werden"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs bei %L überschreibt eine Prozedurbindung, die als NON_OVERRIDABLE deklariert ist"
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs bei %L darf nicht DEFERRED sein, da es eine Nicht-DEFERRED-Bindung überschreibt"
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs bei %L überschreibt eine PURE-Prozedur und muss auch PURE sein"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs bei %L überschreibt eine ELEMENTAL-Prozedur und muss auch ELEMENTAL sein"
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs bei %L überschreibt eine Nicht-ELEMENTAL-Prozedur und darf ebenfalls nicht ELEMENTAL sein"
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs bei %L überschreibt eine SUBROUTINE und muss auch eine SUBROUTINE sein"
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs bei %L überschreibt eine FUNCTION und muss auch eine FUNCTION sein"
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Unpassendes Ergebnis für die überschreibende Prozedur %qs bei %L: %s"
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs bei %L überschreibt eine PUBLIC-Prozedur und darf nicht PRIVATE sein"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Scheinargument %qs von %qs bei %L sollte %qs genannt werden, um zum zugehörigen Argument der überschriebenen Prozedur zu passen"
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Unpassende Argumente für die überschreibende Prozedur %qs bei %L: %s"
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs bei %L muss die gleiche Anzahl formaler Argumente wie die überschriebene Prozedur haben"
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs bei %L überschreibt eine NOPASS-Bindung und muss ebenfalls NOPASS sein"
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs bei %L überschreibt eine Bindung mit PASS und muss ebenfalls PASS sein"
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Scheinargument des übergebenen Objektes von %qs bei %L muss an der gleichen Stelle wie das Scheinargument des übergebenen Objektes der überschriebenen Prozedur stehen"
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "DTIO-Scheinargument bei %L muss vom Typ %s sein"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "DTIO-Scheinargument bei %L muss von KIND = %d sein"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "DTIO-Scheinargument bei %L muss ein Skalar sein"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "DTIO-Scheinargument bei %L muss ein ASSUMED SHAPE ARRAY sein"
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "DTIO-Zeichenargument bei %L muss angenommene Länge haben"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "DTIO-Scheinargument bei %L muss INTENT %s haben"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Alternativer Rücksprung bei %L ist in einer DTIO-Prozedur nicht erlaubt"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "DTIO-Prozedur %qs bei %L muss ein Unterprogramm sein"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Zu wenige Scheinargumente in DTIO-Prozedur %qs bei %L"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Zu viele Scheinargumente in DTIO-Prozedur %qs bei %L"
@@ -64444,33 +64502,33 @@ msgstr "Transformierende Funktion %qs bei %L darf nicht in einem Initialisierung
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Elementare Funktion als Initialisierungsausdruck mit Nicht-Ganzzahl-/Nicht-Zeichen-Argumenten bei %L"
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Unterprogrammaufruf von intrinsischem %qs in »DO CONCURRENT«-Block bei %L ist nicht PURE"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Unterprogrammaufruf des intrinsischen %qs bei %L ist nicht PURE"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Erweiterung: Umwandlung von %s in %s bei %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Nichtstandard-Umwandlung von %s in %s bei %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Mögliche Wertänderung bei Umwandlung von %s in %s bei %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Umwandlung von %s in %s bei %L"
@@ -64478,22 +64536,22 @@ msgstr "Umwandlung von %s in %s bei %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "%s kann nicht nach %s bei %L umgewandelt werden"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Interner Fehler: Cannot convert %qs to %qs at %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "Bei %2$L deklariertes %1$qs überdeckt intrinsische Funktion mit gleichem Namen. Um die aufzurufen, sind explizite INTRINSIC-Deklarationen erforderlich."
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "Bei %2$L deklariertes %1$qs ist auch der Name einer intrinsischen Funktion. Sie kann nur über eine explizite Schnittstelle oder als EXTERNAL deklariert aufgerufen werden."
@@ -65029,7 +65087,7 @@ msgstr "NAMELIST %qs in READ-Anweisung bei %L enthält Symbol %qs, das im Kontex
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L ist polymorph und erfordert eine definierte Ein-/Ausgabeprozedur"
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L mit ALLOCATABLE- oder POINTER-Komponenten"
@@ -66207,13 +66265,13 @@ msgid "gfc_basic_typename(): Undefined type"
 msgstr "gfc_basic_typename(): Undefined type"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "gfc_typename(): Undefined type"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "gfc_code2string(): Bad code"
@@ -66376,149 +66434,149 @@ msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): bad module symbol %qs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbol not written"
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, gcc-internal-format
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "Moduldatei %qs kann bei %C nicht zum Schreiben geöffnet werden: %s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Fehler beim Schreiben der Moduldatei %qs: %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "Moduldatei %qs kann nicht gelöscht werden: %s"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Moduldatei %qs kann nicht in %qs umbenannt werden: %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "Temporäre Moduldatei %qs kann nicht gelöscht werden: %s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Symbol %qs bei %C bereits deklariert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Unable to create symbol for %s"
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Das bei %2$L referenzierte Symbol %1$qs ist nicht im gewählten Standard vorhanden"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Bei %2$L referenziertes Symbol %1$qs nicht im Modul ISO_C_BINDING gefunden"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbol %qs bereits deklariert"
 
 # https://german.stackexchange.com/questions/35158/deklination-mehrerer-attributiver-adjektive
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Verwendung des intrinsischen Moduls %qs bei %C steht mit nicht-intrinsischem vorher verwendeten Modulnamen in Konflikt"
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Verwendung der Konstante NUMERIC_STORAGE_SIZE aus intrinsischem Modul ISO_FORTRAN_ENV bei %L ist mit Option %qs unverträglich"
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Verwendung der Konstante NUMERIC_STORAGE_SIZE aus intrinsischem Modul ISO_FORTRAN_ENV bei %C ist mit Option %s unverträglich"
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Bei %2$L referenziertes Symbol %1$qs nicht im intrinsischen Modul ISO_FORTRAN_ENV gefunden"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "USE-Anweisung bei %C hat keinen ONLY-Qualifizierer"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Intrinsisches Modul ISO_FORTRAN_ENV bei %C"
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Modul ISO_C_BINDING bei %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "Intrinsisches Modul namens %qs bei %C nicht gefunden"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "IEEE_FEATURES-Modul bei %C"
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "IEEE_EXCEPTIONS-Modul bei %C"
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "IEEE_ARITHMETIC-Modul bei %C"
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, gcc-internal-format
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Moduldatei %qs kann bei %C nicht zum Lesen geöffnet werden: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Moduldatei %qs wurde nicht generiert, entweder weil das Modul keine MODULE PROCEDURE enthält oder weil es einen Fehler in dem Modul gibt."
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Verwendung des nicht-intrinsischen Moduls %qs bei %C steht mit vorher verwendetem intrinsischen Modulnamen in Konflikt"
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Bei %2$C geöffnete Datei %1$qs ist keine GNU-Fortran-Moduldatei"
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Bei %2$C geöffnete Moduldatei %1$qs kann nicht gelesen werden, da sie von einer anderen Version von GNU Fortran erstellt wurde"
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr "Das Teilmodul, das gerade gebaut wird, kann nicht gleichzeitig mit USE verwendet werden"
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr "Das Modul, das gerade gebaut wird, kann nicht gleichzeitig mit USE verwendet werden"
@@ -67054,8 +67112,8 @@ msgstr "Implizit deklariertes Unterprogramm %s wird in !$OMP DECLARE REDUCTION b
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "ORDERED-Parameter der Klausel bei %L ist weniger als COLLAPSE"
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-Klausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
@@ -69089,7 +69147,7 @@ msgstr "Das bei %2$L deklarierte INTRINSIC %1$qs ist in den derzeitigen Standard
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Nicht-RECURSIVE Prozedur %qs bei %L ruft sich möglicherweise rekursiv selbst auf. Sollte als RECURSIVE oder mit %<-frecursive%> verwendet werden"
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Marke %d wird bei %L referenziert, aber nirgendwo definiert"
@@ -69204,7 +69262,7 @@ msgstr "Spezifische Funktion %qs bei %L kann nicht aufgelöst werden"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ; meinen Sie %qs?"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ"
@@ -69363,220 +69421,220 @@ msgstr "Unreine Funktion %qs bei %L wird möglicherweise nicht ausgewertet"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Unreine Funktion bei %L wird möglicherweise nicht ausgewertet"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "BOZ-Literalkonstante bei %L kann kein Operand des einstelligen Operators %qs sein"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr "Operanden bei %L und %L können nicht als Operanden des binären Operators %qs verwendet werden"
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "BOZ-Literalkonstante bei %L kann nicht als Operand eines Vergleichsoperators vorkommen"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "Vergleich auf Gleichheit für %s bei %L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "Vergleich auf Ungleichheit für %s bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Bad intrinsic"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Bad expression"
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld < %ld) in Kodimension %d"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld > %ld) in Kodimension %d"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Unzulässiger Schritt von Null bei %L"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Bad array reference"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rechte obere Schranke des Feldabschnitts angenommener Größe nicht angegeben bei %L"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge des Koindex in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Koindex der Kodimension %d muss bei %L ein Skalar sein"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Feldindex bei %L muss skalar sein"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Feldindex bei %L muss INTEGER-Typ haben, %s gefunden"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-Feld-Index bei %L"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argument dim bei %L muss skalar sein"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argument dim bei %L muss INTEGER-Typ haben"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Missing spec"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): unused as(1)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): unused as(2)"
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Feldindex bei %L ist ein Feld mit Rang %d"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "End-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "End-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "End-Index der Teilzeichenkette bei %L ist zu groß"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Bad array reference"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang größer Null darf kein POINTER-Attribut bei %L haben"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang ungleich Null darf bei %L kein Attribut ALLOCATABLE haben"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Zwei oder mehr Teilreferenzen mit Rang größer Null dürfen nicht bei %L angegeben werden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "gfc_expression_rank(): Two array specs"
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut kann nur als effektives Argument verwendet werden"
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Typs bei %L kann nur als effektives Argument verwendet werden"
@@ -69585,12 +69643,12 @@ msgstr "Variable %s vermuteten Typs bei %L kann nur als effektives Argument verw
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Typs bei %L als effektives Argument für Abfragefunktion muss das erste Argument sein"
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Ranges bei %L kann nur als effektives Argument verwendet werden"
@@ -69599,294 +69657,294 @@ msgstr "Variable %s vermuteten Ranges bei %L kann nur als effektives Argument ve
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Ranges bei %L als effektives Argument für Abfragefunktion muss das erste Argument sein"
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variable %s vermuteten Typs bei %L darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variable »%s« vermuteten Ranges bei %L darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "In Spezifikationsausdruck verwendete Variable %qs wird bei %L vor Anweisung ENTRY referenziert, in der sie ein Parameter ist"
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variable %qs wird bei %L vor Anweisung ENTRY verwendet, in der sie ein Parameter ist"
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphes Subobjekt des koindizierten Objektes bei %L"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Koindiziertes Objekt mit polymorpher reservierbarer Subkomponente bei %L"
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "Verwendung der Variable %qs bei %L ist veraltet"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs bei %L ist Host-verbunden bei %L in eine enthaltene Prozedur mit einer gleichnamigen internen Prozedur"
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Fehler in Typbeschränktem Aufruf bei %L"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Weitergegebenes Objekt bei %L muss Skalar sein"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der Prozedurzeigerkomponente bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der typgebundenen Prozedur bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basisobjekt für Aufruf der typgebundenen NOPASS-Prozedur bei %L muss skalar sein"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Keine passende spezifische Bindung für Aufruf des GENERIC %qs bei %L gefunden"
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs bei %L sollte eine SUBROUTINE sein"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs bei %L sollte eine FUNCTION sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Bad expression type"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s bei %L muss skalar sein"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s bei %L muss ganzzahlig sein"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s bei %L muss INTEGER sein"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Schrittausdruck in DO-Schleife bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-Schleife bei %L wird null mal ausgeführt"
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie überläuft"
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie unterläuft"
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Anfangsausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Endausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-Schrittausdruck bei %L muss skalares %s sein"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-Schrittausdruck bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-Index %qs kann nicht in Tripel-Spezifikation bei %L auftreten"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "ALLOCATE-Objekt bei %L muss ALLOCATABLE oder ein POINTER sein"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Koindiziertes reservierbares Objekt bei %L"
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Quell-Ausdruck bei %L muss skalar sein oder den selben Rang wie das ALLOCATE-Objekt bei %L haben"
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Quell-Ausdruck bei %L und ALLOCATE-Objekt bei %L müssen dieselbe Form haben"
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typ der Entität bei %L ist mit Quellausdruck bei %L typunverträglich"
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Das ALLOCATE-Objekt bei %L und der Quellausdruck bei %L müssen Typparameter der gleichen Art haben"
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ LOCK_TYPE sein noch eine LOCK_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ EVENT_TYPE sein noch eine EVENT_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Reservierung von %s mit ABSTRACT-Basistyp bei %L erfordert Typspezifikation oder Quellausdruck"
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Reservierung von %s bei %L mit Typspezifikation erfordert den selben Zeichenkettenlängenparameter wie in der Deklaration"
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "In ALLOCATE-Anweisung bei %L ist Feld-Spezifikation erforderlich"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Feldspezifikation oder feldwertiger SOURCE=-Ausdruck erforderlich in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Koarray-Spezifikation in ALLOCATE-Anweisung bei %L erforderlich"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Falsche Feldspezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "Obere Kogrenze ist kleiner als untere Kogrenze bei %L"
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "Obere Kogrenze ist kleiner als untere Kogrenze von 1 bei %L"
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs darf nicht bei %L in einer Feldspezifikation in der gleichen ALLOCATE-Anweisung auftreten, wo es selbst alloziert wird"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "In Koindex-Spezifikation in ALLOCATE-Anweisung bei %L wird »*« erwartet"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Falsche Koarray-Spezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-Variable bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-Variable bei %L darf nicht %s innerhalb der gleichen %s-Anweisung sein"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG bei %L ist ohne STAT-Marke nutzlos"
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "»ERRMSG=«-Variable bei %L muss skalare Default-CHARACTER-Variable sein"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "ERRMSG-Variable bei %L darf nicht »%s« innerhalb der selben »%s«-Anweisung sein"
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "ALLOCATE-Objekt bei %L tritt auch bei %L auf"
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
@@ -69895,284 +69953,284 @@ msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-Marke bei %L überschneidet sich mit CASE-Marke bei %L"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss Typ %s haben"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss von der Art %d sein"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss skalar sein"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Auswahlausdruck in berechneter GOTO-Anweisung bei %L muss ein skalarer Ganzzahlausdruck sein"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument der SELECT-Anweisung bei %L kann nicht %s sein"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argument der SELECT-Anweisung bei %L muss ein skalarer Ausdruck sein"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L ist nicht im Bereich von %s"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Der DEFAULT CASE bei %L kann nicht von zweitem DEFAULT CASE bei %L gefolgt werden"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logischer Bereich in CASE-Anweisung bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstanter logischer Wert in CASE-Anweisung wird bei %L wiederholt"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Bereichsspezifikation bei %L kann nie passen"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logischer SELECT CASE Block bei %L hat mehr als zwei Fälle"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Zugeordneter Name %qs bei %L ist ein Prozedurzeiger"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Abgeleiteter Typ %qs kann bei %L nicht als Variable verwendet werden"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Zugeordneter Name %qs bei %L ist ein Prozedurname"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "Der zuordnende Selektor-Ausdruck bei %L ergibt eine Prozedur"
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektor bei %L darf nicht NULL() sein"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektor bei %L hat keinen Typ"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Zugeordneter Name %qs bei %L wird als Feld verwendet"
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-Selektor bei %L erfordert Zwischenspeicher, was noch nicht implementiert ist"
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektor muss in SELECT TYPE-Anweisung bei %L polymorph sein"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektor bei %L darf nicht koindiziert sein"
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS bei %L überlappt sich mit TYPE IS bei %L"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Abgeleiteter Typ %qs bei %L muss erweiterbar sein"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Abgeleiteter Typ %qs bei %L muss eine Erweiterung von %qs sein"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Unerwarteter intrinsischer Typ %qs bei %L"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Die Typspezifikation bei %L muss angeben, dass jeder Parameter mit Längentyp vermutet ist"
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Doppelter CLASS IS-Block in SELECT TYPE-Anweisung bei %L"
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) bei %L kann nicht mit dem Zeiger oder dem allozierbaren Selektor bei %L verwendet werden"
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO-%s-Prozedur bei %L muss rekursiv sein"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Element zum Datenaustausch bei %L kann nicht polymorph sein, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine POINTER-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Datenübertragungselement bei %L kann keine Prozedurzeiger-Komponenten haben"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine ALLOCATABLE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Datenübertragungselement bei %L kann keine vollständige Referenz auf Feld vermuteter Größe sein"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock-Variable bei %L muss Skalar mit LOCK_TYPE sein"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Ereignis-Variable bei %L muss Skalar mit EVENT_TYPE sein"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray oder koindiziert sein"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray, aber nicht koindiziert sein"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "»STAT=«-Argument bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "»ERRMSG=«-Argument bei %L muss skalare CHARACTER-Variable sein"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "»ACQUIRED_LOCK=«-Argument bei %L muss skalare LOGICAL-Variable sein"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Argument UNTIL_COUNT= bei %L muss ein skalarer INTEGER-Ausdruck sein"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argument für Imageset bei %L muss Skalar oder Rang-1-INTEGER-Ausdruck sein"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argument für Imageset bei %L muss zwischen 1 und num_images() liegen"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Anweisung bei %L ist keine gültige Sprungzielanweisung für Sprungziel bei %L"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Sprung bei %L könnte Endlosschleife bewirken"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt CRITICAL-Konstrukt für Marke bei %L"
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke bei %L"
@@ -70180,195 +70238,195 @@ msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke be
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Marke bei %L ist nicht im gleichen Block wie GOTO-Anweisung bei %L"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-Maske bei %L hat ungültige Form"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-Zuweisungsziel bei %L hat ungültige Form"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Benutzerdefinierte Nicht-ELEMENTAL-Zuweisung in WHERE bei %L"
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Nicht unterstützte Anweisung in WHERE bei %L"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Zuweisung an FORALL-Indexvariable bei %L"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Das FORALL mit Index %qs wird nicht auf der linken Seite der Zuweisung bei %L verwendet und könnte somit mehrere Zuweisungen an dieses Objekt auslösen"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "FORALL-Konstrukt bei %L"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Ein äußeres FORALL-Konstrukt hat bereits einen Index mit Namen %L"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Klausel WHERE/ELSEWHERE bei %L erfordert ein LOGICAL-Feld"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Bad block type"
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-Ausdruck wird in Zuweisung (%ld/%ld) bei %L abgeschnitten"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Koindizierter Ausdruck bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "In einem reinen Unterprogramm darf ein INTENT(IN)-Dummy-Argument nicht als »expr« bei %L einer intrinsischen Zuweisungsanweisung verwendet werden, in der die Variable von einem abgeleiteten Typ ist, wenn der abgeleitete Typ eine Zeigerkomponente auf irgendeiner Ebene der Komponentenauswahl hat."
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Zuweisung an koindizierte Variable bei %L in einer PURE-Prozedur"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Zuweisung an polymorphes Koarray bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L erfordert %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Variable darf in intrinsischer Zuweisung bei %L nicht polymorph sein - bitte prüfen, ob es ein passendes spezifisches Unterprogramm für den »=«-Operator gibt"
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Koindizierte Variable darf keine reservierbare endgültige Komponente in Zuweisung bei %L haben"
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: als typgebunden definierte Zuweisung(en) bei %L nicht durchgeführt, da Feldreferenzen mit mehreren Teilen in Ausdrücken als Zwischenergebnisse auftreten würden."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Zuweisung eines Prozedurzeigers bei %L"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsergebnis auf der linken Seite der Zuweisung bei %L muss Zeiger-Attribut haben."
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "Anweisung ASSIGNED GOTO bei %L erfordert eine skalare INTEGER-Variable"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variable %qs bei %L wurde keine Zielmarke zugewiesen"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternative RETURN-Anweisung bei %L erfordert einen SCALAR-INTEGER-Spezifizierer als Rückgabe"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-Anweisung bei %L erfordert eine skalare Standard-INTEGER-Variable"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ungültiges NULL bei %L"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Arithmetische IF-Anweisung bei %L erfordert einen skalaren REAL- oder INTEGER-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): No expression on DO WHILE"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Abbruchbedingung der DO WHILE-Schleife bei %L muss ein skalarer LOGICAL-Ausdruck sein"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-Maskenklausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Bad statement code"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Verwendung von Parameter %qs, der bei %L deklariert wurde, ist veraltet"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variable %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet denselben globalen Bezeichner wie Entität bei %L aus Modul %qs"
@@ -70376,965 +70434,965 @@ msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet densel
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Prozedur %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Zeichenkettenlänge bei %L ist zu groß"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Reservierbares Feld %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalares Objekt %qs bei %L kann nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Feldzeiger %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Feld %qs bei %L kann keine aufgeschobene Form haben"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typ %qs der CLASS-Variable %qs bei %L ist nicht erweiterbar"
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-Variable %qs bei %L muss Attrappe, reservierbar oder Zeiger sein"
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Der Typ %qs bei %L darf nicht mit Wirt verbunden sein, da er von unverträglichem bei %L definierten Objekt mit gleichem Namen blockiert wird"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Einbezogenes SAVE für Modulvariable %qs bei %L, benötigt wegen Standardinitialisierung"
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Entität %qs bei %L hat Parameter mit aufgeschobenem Typ und benötigt entweder das POINTER- oder ALLOCATABLE-Attribut"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Das Feld %qs im Modul oder Hauptprogramm bei %L muss konstante Form haben"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entität mit vermuteter Zeichenlänge bei %L muss ein Scheinargument oder ein PARAMETER sein"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs bei %L muss in diesem Zusammenhang konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-Variable %qs bei %L muss konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Zuordnungsfähiges %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Externes %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Schein-%qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsisches %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsergebnis %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisches Feld %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s bei %L"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Zeichenwertige Anweisungsfunktion %qs bei %L muss konstante Länge haben"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs hat PRIVATE-Typ und kann kein Scheinargument von %qs bei %L sein, das PUBLIC ist"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Prozedur %qs in PUBLIC-Schnittstelle %qs bei %L nimmt Scheinargumente von %qs, das PRIVATE ist"
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externes Objekt %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-Funktion %qs bei %L muss ein skalares Ergebnis haben"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Anweisungsfunktion %qs bei %L darf weder POINTER- oder ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht feld-wertig sein"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht zeiger-wertig sein"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rein sein"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rekursiv sein"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-Funktion %qs bei %L"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prozedurzeiger %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Scheinprozedur %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionsergebnisvariable %qs bei %L von elementarer Funktion %qs darf nicht die Attribute ALLOCATABLE oder POINTER haben"
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut SAVE in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut INTENT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut RESULT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Attribut EXTERNAL steht mit Attribut FUNCTION in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Dem Ergebnis %qs als Prozedurzeiger bei %L fehlt das POINTER-Attribut"
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in ELEMENTAL-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in PURE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in RECURSIVE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s zwischen der MODULE-PROCEDURE-Deklaration in Modul %qs und der Deklaration bei %L in (SUB)MODULE %qs"
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-Prozedur %qs bei %L ist keine SUBROUTINE"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-Prozedur bei %L muss genau ein Argument haben"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument der FINAL-Prozedur bei %L muss Typ %qs haben"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument der FINAL-Prozedur bei %L darf kein POINTER sein"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht OPTIONAL sein"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Nicht-skalare FINAL-Prozedur bei %L sollte Argument mit vermuteter Form haben"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Bei %2$L deklarierte FINAL-Prozedur %1$qs hat denselben Rang (%3$d) wie %4$qs"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Bei %2$L wurde nur FINAL-Feldprozedur für abgeleiteten Typ %1$qs definiert, skalare wird ebenfalls empfohlen"
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs und %qs können nicht gemischte FUNCTION/SUBROUTINE für GENERIC %qs bei %L sein"
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs und %qs für GENERIC %qs bei %L sind mehrdeutig"
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Undefinierte spezifische Bindung %qs als Ziel des GENERIC %qs bei %L"
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs bei %L muss auf spezifische Bindung abzielen, %qs ist ebenfalls GENERIC"
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs bei %L kann nicht spezifische Bindung mit gleichem Namen überschreiben"
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Typgebundener Operator bei %L kann nicht NOPASS sein"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs bei %L muss eine Modulprozedur oder eine externe Prozedur mit expliziter Schnittstelle sein"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedur %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prozedur %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Nicht-polymorphes Scheinargument von %qs für weitergegebenes Objekt bei %L"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L muss ein Skalar sein"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht POINTER sein"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prozedur %qs bei %L hat den gleichen Namen wie eine Komponente von %qs"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prozedur %qs bei %L hat den selben Namen wie eine vererbte Komponente von %qs"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Bei %2$L deklarierter abgeleiteter Typ %1$qs muss ABSTRACT sein, da %3$qs DEFERRED und nicht überschrieben ist"
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Koarray-Komponente %qs bei %L muss reservierbar mit aufgeschobener Form sein"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponente %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponente %qs bei %L mit Koarray-Komponente darf ein Nicht-Zeiger und nicht-reservierbares Skalar sein"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Komponente %qs bei %L hat das CONTIGUOUS-Attribut, aber ist kein Feldzeiger"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponente %qs von BIND(C)-Typ bei %L muss Länge eins haben"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Parameter %qs von %qs mit PASS(%s) bei %L muss skalar sein"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf kein POINTER-Attribut haben"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponente %qs von %qs bei %L hat den gleichen Namen wie eine geerbte typgebundene Prozedur"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Zeichenlänge der Komponente %qs muss ein konstanter Spezifikationsausdruck bei %L sein"
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Zeichenkomponente %qs von %qs bei %L mit aufgeschobener Länge muss POINTER oder ALLOCATABLE sein"
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Die Komponente %qs ist ein PRIVATE-Typ und kann nicht Komponente von %qs sein, die PUBLIC bei %L ist"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphe Komponente %s bei %L in SEQUENCE oder BIND(C)-Typ %s"
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponente %s des bei %L deklarierten SEQUENCE-Typen hat kein SEQUENCE-Attribut"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "In Konflikt stehende Initialisierungen in Union bei %L und %L"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Da der erweiterte Typ %qs bei %L eine Koarray-Komponente hat, muss der Elterntyp %qs auch eine haben"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Nicht-erweiterbarer abgeleiteter Typ %qs bei %L darf nicht ABSTRACT sein"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parametrisierter Typ %1$qs hat bei %3$L keine Komponente, die zu Parameter %2$qs gehört"
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Allgemeiner Name %qs der Funktion %qs bei %L ist der gleiche wie der des abgeleiteten Typs bei %L"
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Abgeleiteter Typ %qs bei %L wurde nicht deklariert"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Feld %qs mit vermuteter Größe in Namensliste %qs bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs mit vermuteter Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs ohne konstante Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs ohne konstante Zeichenlänge in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs wurde als PRIVATE deklariert und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat Verwendungs-verbundene PRIVATE-Komponenten und kann kein Element der Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat PRIVATE-Komponenten und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut NAMELIST in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameterfeld %qs bei %L kann nicht automatische oder vermutete Form haben"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implizit angegebener PARAMETER %qs bei %L passt nicht zu früherem IMPLICIT-Typ"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Unverträglicher abgeleiteter Typ in PARAMETER bei %L"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "COMMON-Block %qs bei %L kann nicht das EXTERNAL-Attribut haben"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Das Objekt %qs bei %L hat aufgeschobenen LEN-Parameter %qs und ist weder allozierbar noch ein Zeiger"
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "Das AUTOMATIC-Objekt %qs bei %L darf kein SAVE-Attribut haben und dard auch keine Variable im main-Programm, einem Modul oder einem Teilmodus sein (F08/C513)"
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Das Objekt %qs bei %L mit ASSUMED-Typparametern muss ein Dummy oder ein SELECT-TYPE-Selektor sein (F08/4.2)"
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Sorry, allozierbare/Zeiger-Komponenten in polymorphen (CLASS-)getypten Koarrays bei %L werden nicht unterstützt"
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attribut PROTECTED steht mit Attribut EXTERNAL bei %L in Konflikt"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut PROTECTED bei %L in Konflikt"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs bei %L hat Attribut CONTIGUOUS, aber ist kein Feldzeiger oder Feld vermuteter Größe oder Rang"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Falsche Spezifikation für Feld bei %L mit angenommener Größe"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Größe bei %L muss ein Schein-Argument sein"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Form bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Feld mit vermutetem Rang bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Feld mit vermutetem Rang bei %L darf kein Attribut VALUE oder CODIMENSION haben"
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol bei %L ist keine Scheinvariable"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs bei %L kann nicht das VALUE-Attribut haben, da es kein Scheinargument ist"
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss konstante Länge haben"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-kompatible zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss Länge eins haben"
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Der abgeleitete Typ %qs bei %L hat Typ %qs, der nicht definiert wurde"
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss ein Scheinargument sein"
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss vom Typ TYPE(*) oder von einem numerischen intrinsischen Typ sein"
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss entweder skalar sein oder ein Feld vermuteter Größe"
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Vermuteter Typ der Variable %s bei %L ist nur für Scheinvariablen erlaubt"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variable %s vermuteten Typs bei %L darf kein Feld mit ausdrücklicher Form sein"
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variable %qs bei %L kann nicht BIND(C) sein, weil es weder ein COMMON-Block noch mit Sichtbarkeit auf Modulebene deklariert ist"
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-Variable %qs bei %L muss Länge eins haben"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs bei %L mit abgeleitetem PRIVATE-Typen %qs"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variable %s bei %L mit LOCK_TYPE oder mit Subkomponente mit LOCK_TYPE muss ein Koarray sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79866
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variable %s bei %L des Typs EVENT_TYPE oder mit Subkomponente des Typs EVENT_TYPE muss ein Koarray sein"
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Das INTENT(OUT)-Scheinargument %qs bei %L hat ASSUMED SIZE und kann damit keine Standardinitialisierung haben"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit LOCK_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit EVENT_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsergebnis %qs bei %L darf weder Koarray sein noch eine Koarray-Komponente haben"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variable %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variable %qs bei %L mit Koarraykomponente muss ein Nichtzeiger, nichtallozierbares Skalar und damit kein Koarray sein"
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variable %qs bei %L ist ein Koarray und ist weder ALLOCATABLE, SAVE, noch ein Scheinargument"
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Koarray-Variable %qs bei %L darf keine Kodimensionen mit aufgeschobener Form haben"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Zuordnungsfähige Koarray-Variable %qs bei %L muss aufgeschobene Form haben"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variable %qs bei %L ist INTENT(OUT) und kann daher kein reservierbares Coarray sein oder Coarray-Komponenten haben"
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray-Scheinvariable %qs bei %L in BIND(C)-Prozedur %qs nicht erlaubt"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Scheinargument %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Rückgabevariable %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Namensliste %qs kann bei %L nicht als Argument für Unterprogramm oder Funktion verwendet werden"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate bei %L ist nicht SAVEd"
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "»!$OMP DECLARE TARGET«-Variable %qs bei %L ist nicht gespeichert (SAVE)"
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Definierbare Entität bei %L erwartet"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA Element %qs bei %L muss in COMMON sein"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-Feld %qs bei %L muss in vorheriger Deklaration angegeben werden"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-Element %qs bei %L kann keinen Coindex haben"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-Element %qs bei %L ist ein Zeiger und muss daher ein vollständiges Feld sein"
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "Das DATA-Objekt in der Nähe von %L hat das Zeiger-Attribut und der entsprechende DATA-Wert ist kein gültiges initial-data-target"
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Das DATA-Element %qs bei %L kann kein ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Abschnitt eines nicht konstanten Feldes bei %L in DATA-Anweisung"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-Anweisung bei %L hat mehr Variablen als Werte"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Anfang der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Ende der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Schritt der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "Schrittweite der implied-do-Schleife bei %L darf nicht 0 sein"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-Anweisung bei %L hat mehr Werte als Variablen"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Marke %d bei %L definiert, aber nicht verwendet"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Marke %d bei %L definiert, kann aber nicht verwendet werden"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L muss SEQUENCE-Attribut haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L kann keine ALLOCATABLE-Komponenten haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Standardinitialisierung kann nicht in EQUIVALENCE mit einer Variablen in COMMON sein"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Zeigerkomponenten kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfehler in EQUIVALENCE-Anweisung bei %L"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Entweder alle oder keines der Objekte in bei %L gesetztem EQUIVALENCE muss das Attribut PROTECTED haben"
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-Blockelement %qs bei %L darf in der PURE-Prozedur %qs kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Benannte Konstante %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Feld %qs bei %L mit nicht-konstanten Grenzen kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Strukturkomponente %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Teilzeichenkette bei %L hat Länge Null"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Selbstreferenz im Zeichenlängenausdruck für %qs bei %L"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-Funktion %qs bei %L mit PRIVATE-Typ %qs"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss eine FUNCTION sein"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prozedur für Benutzeroperator %qs bei %L kann nicht vermutete Zeichenlänge haben"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorschnittstelle bei %L darf höchstens zwei Argumente haben"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Enthaltene Prozedur %qs bei %L einer PURE-Prozedur muss auch PURE sein"
@@ -72222,17 +72280,17 @@ msgstr "Überlappende ungleiche Initialisierungen in EQUIVALENCE bei %C"
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Die Anzahl der Elemente im Feldkonstruktor bei %L erfordert Erhöhung der erlaubten oberen Grenze %d. Siehe Option %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Bei %L wird ein vorübergehendes Feld für Argument %qs erzeugt"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Falscher Ausdruckstyp beim Durchlaufen (%d)"
@@ -72325,107 +72383,107 @@ msgstr "Nicht-konstanter Initialisierungsausdruck bei %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr "Das Feld %qs bei %L ist größer als der Grenzwert, der durch %<-fmax-stack-var-size=%> festgelegt wurde, daher wurde es vom Stapel in den statischen Speicher verschoben. Dies macht die Prozedur unsicher, wenn sie rekursiv oder gleichzeitig von mehreren Threads aus aufgerufen wird. Erwägen Sie die Verwendung von %<-frecursive%>, oder erhöhen Sie die Grenze %<-fmax-stack-var-size=%>, oder ändern Sie den Code, um ein ALLOCATABLE-Feld zu verwenden."
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "innere Variable, die keine Prozedur ist"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Rückgabewert der Funktion %qs bei %L nicht gesetzt"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Parameter aufgeschobenen Typs wird noch nicht unterstützt"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "Backend-Deklaration für Modulvariable %qs ist bereits vorhanden"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Ungenutzte PRIVATE-Variable %qs bei %L deklariert"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Scheinargument %qs bei %L war als INTENT(OUT) deklariert, aber nicht gesetzt"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Scheinargument %qs abgeleiteten Typs bei %L war als INTENT(OUT) deklariert, aber nicht gesetzt und hat keine Standardinitialisierung"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Ungenutztes Dummyargument %qs bei %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Ungenutzte Modulvariable »%qs«, die bei %L ausdrücklich importiert wurde"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Ungenutzte Variable %qs, bei %L deklariert"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Ungenutzter Parameter %qs, bei %L deklariert"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Ungenutzter Parameter %qs, der bei %L ausdrücklich importiert wurde"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Rückgabewert %1$qs der bei %3$L deklarierten Funktion %2$qs nicht gesetzt"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Entschuldigung, !$ACC DECLARE bei %L ist in einem BLOCK-Konstrukt nicht erlaubt"
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "Länge des Arrays bei %L kann nicht berechnet werden."
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Code zur Neu-Reservierung der reservierbaren Variable bei %L wird hinzugefügt"
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Sorry, der koindizierte Zugriff bei %L auf ein unbegrenzt polymorphes Objekt wird nicht unterstützt"
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Sorry, der koindizierte Zugriff bei %L auf eine unbegrenzt polymorphe Komponente wird nicht unterstützt"
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Unbekannte eingebauter Operator"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Unbekannte Argumentlistenfunktion bei %L"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Wenn die Neuzuordnung von Grenzen bei %L angegeben wird, darf das Zeigerziel nicht NULL sein"
@@ -72581,7 +72639,7 @@ msgid "gfc_validate_kind(): Got bad kind"
 msgstr "gfc_validate_kind(): Got bad kind"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code(): Bad statement code"
@@ -72708,7 +72766,7 @@ msgstr "%<-fwpa%> und %<-fltrans%> schließen sich gegenseitig aus"
 
 #: lto/lto-lang.c:898
 #, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "%<-flinker-output=rel%> und %<-fltrans%> schließen sich gegenseitig aus"
 
 #: lto/lto-object.c:107
@@ -73810,7 +73868,7 @@ msgstr "Unbekannte Option für Endianess-Wert: %qs"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "Unbekannte Option für Gleitkomma-Initialisierungswert: %qs"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "Unbekannte Option %qs"
@@ -73828,15 +73886,15 @@ msgstr "Makroname fehlt hinter %qs"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "fehlender Dateiname hinter %qs"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "fehlender Pfad hinter %qs"
@@ -73886,7 +73944,7 @@ msgstr "fehlender Modulname"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "unbekannter ivar-Sichtbarkeitswert %qs"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "unbekannter Wert %qs für Speicherreihenfolge von Skalaren"
@@ -73969,92 +74027,92 @@ msgstr "%qs ist veraltet"
 msgid "unknown linker output %qs"
 msgstr "unbekannte Linkerausgabe %qs"
 
-#: common.opt:1502
+#: common.opt:1506
 #, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "unbekannte Art überschüssiger Genauigkeit %qs"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr "unbekannte Spezifikation für die Menge der FLT_EVAL_METHOD-Werte, um %qs zu erlauben"
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "unbekannte Art der Gleitkomma-Kürzung %qs"
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "Unbekannte Stufe %qs für Stapel-Wiederverwendung"
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "Unbekannte Schutzstufe %qs für Kontrollfluss"
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "unbekannter IRA-Algorithmus %qs"
 
-#: common.opt:1902
+#: common.opt:1906
 #, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "unbekannte IRA-Region %qs"
 
-#: common.opt:1980
+#: common.opt:1984
 #, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "Unbekanntes LTO-Partitionierungs-Modell %qs"
 
-#: common.opt:2082
+#: common.opt:2086
 #, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "Optionen oder Zielarchitekturen fehlen hinter %qs"
 
-#: common.opt:2090
+#: common.opt:2094
 #, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "Unbekannte Offload-ABI %qs"
 
-#: common.opt:2232
+#: common.opt:2236
 #, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "Unbekannte Profil-Reproduzierbarkeitsstufe %qs"
 
-#: common.opt:2248
+#: common.opt:2252
 #, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "Unbekannte Profil-Aktualisierungs-Methode %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr "unbekannte Stufe %qs für Live-Patching"
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "unbekannter Basisblock-Umsortierungs-Algorithmus %qs"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "unbekanntes TLS-Modell %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "Unbekanntes Vektorisierer-Kostenmodell %qs"
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "unbekannter Sichtbarkeitswert %qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "Unbekannte Initialisierungspriorität %qs für VTable-Verifikation"
@@ -74064,6 +74122,9 @@ msgstr "Unbekannte Initialisierungspriorität %qs für VTable-Verifikation"
 msgid "unknown evrp mode %qs"
 msgstr "unbekannter evrp-Modus %qs"
 
+#~ msgid "cannot deduce template arguments for %qT from %<()%>"
+#~ msgstr "Templateargumente für %qT von %<()%> können nicht hergeleitet werden"
+
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99276
 #~ msgid "%K%qD may write %E or more bytes into a region of size %E the destination"
 #~ msgstr "%K%qD schreibt möglicherweise %E oder mehr Bytes in eine Region der Größe %E"
@@ -76408,10 +76469,6 @@ msgstr "unbekannter evrp-Modus %qs"
 #~ msgid "argument 1 of %s must be a constant"
 #~ msgstr "Argument 1 von %s muss eine Konstante sein"
 
-# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79846
-#~ msgid "constant argument %d for builtin %qF is out of range ("
-#~ msgstr "bla %d %qF"
-
 #~ msgid "CPUs older than z900 are not supported for -fsplit-stack"
 #~ msgstr "CPUs älter als z900 werden für -fsplit-stack nicht unterstützt"
 
@@ -76568,9 +76625,6 @@ msgstr "unbekannter evrp-Modus %qs"
 #~ msgid "lambda-expression in unevaluated context"
 #~ msgstr "Lambda-Ausdruck in ungeprüftem Kontext"
 
-#~ msgid "lambda-expression in template-argument"
-#~ msgstr "Lambda-Ausdruck in Templateargument"
-
 #~ msgid "%<try%> in %<constexpr%> function"
 #~ msgstr "%<try%> in %<constexpr%>-Funktion"
 
diff --git a/gcc/po/el.po b/gcc/po/el.po
index defc295277ddf..10bada81a97dc 100644
--- a/gcc/po/el.po
+++ b/gcc/po/el.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.0-b20041128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2004-12-15 18:53+0000\n"
 "Last-Translator: Simos Xenitellis <simos74@gmx.net>\n"
 "Language-Team: Greek <nls@tux.hellug.gr>\n"
@@ -1336,12 +1336,12 @@ msgstr "Μη έγκυρη προτεραιότητα `%s'"
 msgid "this is the insn:"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 #, fuzzy
 msgid "unable to generate reloads for:"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
@@ -1516,16 +1516,16 @@ msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 msgid "insn does not satisfy its constraints:"
 msgstr ""
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr ""
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 msgid "created and used with different settings of %<-fpic%>"
 msgstr ""
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 msgid "created and used with different settings of %<-fpie%>"
 msgstr ""
 
@@ -1561,7 +1561,7 @@ msgstr ""
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr ""
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, fuzzy, gcc-internal-format
 msgid "<anonymous>"
@@ -2023,85 +2023,85 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "RPC: Μη συμβατές εκδόσεις του RPC"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 msgid "invalid address mode"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2117,18 +2117,18 @@ msgid "invalid %%r value"
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, fuzzy, c-format
 msgid "invalid %%R value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, fuzzy, c-format
 msgid "invalid %%N value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, fuzzy, c-format
 msgid "invalid %%P value"
 msgstr "μη έγκυρος χρήστης"
@@ -2158,7 +2158,7 @@ msgstr "μη έγκυρος χρήστης"
 msgid "invalid %%U value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, fuzzy, c-format
 msgid "invalid %%s value"
 msgstr "μη έγκυρος χρήστης"
@@ -2168,7 +2168,7 @@ msgstr "μη έγκυρος χρήστης"
 msgid "invalid %%C value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, fuzzy, c-format
 msgid "invalid %%E value"
 msgstr "μη έγκυρος χρήστης"
@@ -2181,7 +2181,7 @@ msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, fuzzy, c-format
 msgid "invalid %%xn code"
 msgstr "μη έγκυρο δικαίωμα"
@@ -2264,35 +2264,35 @@ msgstr "μη έγκυρη μετατόπιση UTC"
 msgid "unrecognized supposed constant"
 msgstr "άγνωστο πρόθεμα: %s"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, fuzzy, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2300,13 +2300,13 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 msgid "invalid operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2437,8 +2437,8 @@ msgstr "Μη ορισμένο όνομα %s"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2840,7 +2840,7 @@ msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 msgid "invalid %%P operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, fuzzy, c-format
 msgid "invalid %%p value"
 msgstr "μη έγκυρος χρήστης"
@@ -2896,7 +2896,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 #, fuzzy
 msgid "bad address"
 msgstr "Εσφαλμένη διεύθυνση"
@@ -2952,8 +2952,8 @@ msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, fuzzy, c-format
 msgid "invalid use of '%%%c'"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -3089,300 +3089,300 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 #, fuzzy
 msgid "bad move"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 msgid "invalid %%A value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, fuzzy, c-format
 msgid "invalid %%f value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, fuzzy, c-format
 msgid "invalid %%F value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, fuzzy, c-format
 msgid "invalid %%G value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, fuzzy, c-format
 msgid "invalid %%j code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, fuzzy, c-format
 msgid "invalid %%J code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, fuzzy, c-format
 msgid "invalid %%k value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, fuzzy, c-format
 msgid "invalid %%K value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, fuzzy, c-format
 msgid "invalid %%O value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, fuzzy, c-format
 msgid "invalid %%q value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 msgid "invalid %%t value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, fuzzy, c-format
 msgid "invalid %%T value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, fuzzy, c-format
 msgid "invalid %%u value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, fuzzy, c-format
 msgid "invalid %%v value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 msgid "invalid %%V value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, fuzzy, c-format
 msgid "invalid %%x value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 msgid "invalid %%z value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 #, fuzzy
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, fuzzy, c-format
 msgid "cannot decompose address"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "Μη έγκυρος κώδικας αίτησης"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 msgid "vector argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3653,8 +3653,8 @@ msgstr "((ανώνυμο))"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3674,7 +3674,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3682,7 +3682,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3700,21 +3700,21 @@ msgstr ""
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3725,13 +3725,13 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3740,7 +3740,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3750,18 +3750,18 @@ msgstr "Μη ορισμένο όνομα %s"
 msgid "expected %<.%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -3769,29 +3769,29 @@ msgstr ""
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 #, fuzzy
 msgid "(anonymous)"
 msgstr "((ανώνυμο))"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3806,31 +3806,31 @@ msgstr "Μη ορισμένο όνομα %s"
 msgid "candidate:"
 msgstr ""
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr ""
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 #, fuzzy
 msgid "jump to label %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr ""
 
@@ -4067,29 +4067,29 @@ msgstr "το `%s' δεν είναι κανονικό αρχείο"
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 msgid "%<using enum%> of dependent type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr ""
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr ""
 
@@ -4140,49 +4140,49 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4283,7 +4283,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "προειδοποίηση: "
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4427,7 +4427,7 @@ msgstr "μη έγκυρος χρήστης"
 msgid "Bad type in constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4459,12 +4459,12 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 #, fuzzy
 msgid "assignment"
 msgstr "προσπέρασμα ορίσματος"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 #, fuzzy
 msgid "pointer assignment"
 msgstr "προσπέρασμα ορίσματος"
@@ -4574,156 +4574,156 @@ msgstr ""
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 #, fuzzy
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -4850,26 +4850,26 @@ msgstr ""
 msgid "Incorrect function return value"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, c-format
 msgid "Error allocating %lu bytes"
 msgstr ""
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr ""
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr ""
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -5092,18 +5092,18 @@ msgstr ""
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr ""
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 #, fuzzy
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr ""
 "Οι επιλογές για να εκτυπωθεί και να οριστεί η ώρα δεν μπορούν να\n"
 "χρησιμοποιηθούν παράλληλα."
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 #, fuzzy
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr ""
@@ -5125,8 +5125,8 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "δεν είναι δυνατό να παραληφθεί ο χρήστης και η ομάδα"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr ""
 
@@ -5299,10 +5299,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "ΣΦΑΛΜΑ: Αδυναμία δημιουργίας προσωρινού αρχείου για αλλαγή"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5777,160 +5777,160 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr ""
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr ""
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr ""
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, fuzzy, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr ""
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr ""
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr ""
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr ""
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr ""
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr ""
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr ""
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr ""
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr ""
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr ""
@@ -6610,7 +6610,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7233,8 +7233,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, fuzzy, no-c-format
 msgid "No longer supported."
 msgstr "αρχεία fifo δεν υποστηρίζονται"
@@ -7591,466 +7591,461 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr ""
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr ""
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr ""
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr ""
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr ""
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr ""
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr ""
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr ""
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr ""
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr ""
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr ""
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr ""
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr ""
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr ""
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr ""
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr ""
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr ""
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr ""
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr ""
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr ""
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr ""
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr ""
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr ""
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr ""
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr ""
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr ""
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr ""
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr ""
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr ""
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr ""
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr ""
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr ""
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr ""
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr ""
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr ""
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr ""
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr ""
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr ""
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, fuzzy, no-c-format
 msgid "Remap file names when including files."
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr ""
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr ""
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr ""
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr ""
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr ""
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr ""
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr ""
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr ""
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr ""
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr ""
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr ""
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr ""
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr ""
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr ""
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr ""
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr ""
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr ""
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, fuzzy, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr ""
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr ""
@@ -8295,6 +8290,11 @@ msgstr ""
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr "διπλός ορισμός συνόλου"
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9532,143 +9532,155 @@ msgstr ""
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr ""
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr ""
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr ""
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr ""
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, fuzzy, no-c-format
 msgid "Specify the code model."
 msgstr "Ορισμός ονόματος προγράμματος"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr "Μη έγκυρη πισω-παραπομπή"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr ""
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, fuzzy, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr ""
@@ -9803,12 +9815,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9829,12 +9835,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -17061,2163 +17061,2163 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 msgid "Align the start of functions."
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, no-c-format
 msgid "Enable static analysis pass."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr "εμφάνιση πληροφοριών προόδου"
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr ""
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr ""
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, fuzzy, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 msgid "Enable code hoisting."
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr ""
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy, no-c-format
 msgid "Enable exception handling."
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, fuzzy, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr "Δεν είναι δυνατό να δεσμευτεί μνήμη"
 
-#: common.opt:1586
+#: common.opt:1590
 #, no-c-format
 msgid "Place each function into its own section."
 msgstr ""
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr ""
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr ""
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 msgid "Process #ident directives."
 msgstr "%%%c: κατευθυντήριος γραμμή μη έγκυρη."
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 msgid "Do not generate .size directives."
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 msgid "Discover pure and const functions."
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr ""
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr ""
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr ""
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:2104
+#: common.opt:2108
 #, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr ""
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2196
+#: common.opt:2200
 #, fuzzy, no-c-format
 msgid "Enable basic program profiling code."
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2297
+#: common.opt:2301
 #, fuzzy, no-c-format
 msgid "Report on consistency of profile."
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2305
+#: common.opt:2309
 #, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2445
+#: common.opt:2449
 #, fuzzy, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, fuzzy, no-c-format
 #| msgid "syntax error at %qs token"
 msgid "Check for syntax errors, then stop."
 msgstr "συντακτικό σφάλμα στο σύμβολο %qs"
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2730
+#: common.opt:2734
 #, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2734
+#: common.opt:2738
 #, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2774
+#: common.opt:2778
 #, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr ""
 
-#: common.opt:2778
+#: common.opt:2782
 #, no-c-format
 msgid "Enable dominator optimizations."
 msgstr ""
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2786
+#: common.opt:2790
 #, no-c-format
 msgid "Enable dead store elimination."
 msgstr ""
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2798
+#: common.opt:2802
 #, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr ""
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2835
+#: common.opt:2839
 #, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr ""
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2847
+#: common.opt:2851
 #, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr ""
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:3011
+#: common.opt:3015
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, fuzzy, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr ""
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3191
+#: common.opt:3195
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <αρχείο>              Τοποθέτηση της εξόδου στο <αρχείο>\n"
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 msgid "Enable function profiling."
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr ""
 
-#: common.opt:3410
+#: common.opt:3414
 #, fuzzy, no-c-format
 msgid "Display the compiler's version."
 msgstr "  --help                   Εμφάνιση αυτών των πληροφοριών\n"
 
-#: common.opt:3414
+#: common.opt:3418
 #, fuzzy, no-c-format
 msgid "Suppress warnings."
 msgstr "%s: προειδοποίηση: "
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr ""
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19359,1106 +19359,1116 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr ""
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr ""
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr ""
 
-#: params.opt:210
+#: params.opt:215
 #, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr ""
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr ""
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr ""
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr ""
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr ""
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr ""
 
-#: params.opt:274
+#: params.opt:279
 #, no-c-format
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr ""
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr ""
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr ""
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr ""
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr ""
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr ""
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr ""
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr ""
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr ""
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr ""
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr ""
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr ""
 
 # src/shred.c:1134
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr ""
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr ""
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr ""
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr ""
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr ""
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr ""
 
-#: params.opt:414
+#: params.opt:419
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr ""
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr ""
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr ""
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr ""
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr ""
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr ""
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr ""
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr ""
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr ""
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr ""
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr ""
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr ""
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr ""
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr ""
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr ""
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr ""
 
-#: params.opt:518
+#: params.opt:523
 #, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr ""
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr ""
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr ""
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr ""
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr ""
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr ""
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr ""
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr ""
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr ""
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr ""
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr ""
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr ""
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr ""
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr ""
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr ""
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr ""
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr ""
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr ""
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr ""
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr ""
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr ""
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr ""
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr ""
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr ""
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr ""
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr ""
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr ""
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr ""
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr ""
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr ""
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr ""
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr ""
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr ""
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr ""
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr ""
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr ""
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr ""
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr ""
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr ""
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr ""
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr ""
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr ""
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr ""
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr ""
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr ""
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr ""
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr ""
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr ""
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr ""
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr ""
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr ""
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr ""
 
-#: params.opt:952
+#: params.opt:970
 #, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr ""
 
-#: params.opt:956
+#: params.opt:974
 #, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr ""
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr ""
 
-#: params.opt:964
+#: params.opt:982
 #, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr ""
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr ""
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr ""
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr ""
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "διπλός ορισμός συνόλου"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr ""
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr ""
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr ""
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20493,7 +20503,7 @@ msgid "expected boolean type"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "Μη ορισμένο όνομα %s"
@@ -20570,7 +20580,7 @@ msgstr "χωρίς ορίσματα"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, fuzzy, gcc-internal-format
 msgid "too many arguments"
 msgstr "πάρα πολλά ορίσματα"
@@ -20970,7 +20980,7 @@ msgstr ""
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -21025,7 +21035,7 @@ msgstr ""
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -21054,20 +21064,20 @@ msgstr ""
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21078,8 +21088,8 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -21089,59 +21099,59 @@ msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'
 msgid "ignoring attributes applied to %qT after definition"
 msgstr ""
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr ""
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr ""
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr ""
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, fuzzy, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr ""
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr ""
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr ""
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -21244,7 +21254,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -21269,720 +21279,720 @@ msgstr ""
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr ""
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 msgid "source object declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 msgid "destination object declared here"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, gcc-internal-format
 msgid "destination object allocated here"
 msgstr ""
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, fuzzy, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "μη έγκυρη κατάσταση για την dlopen()"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 1 to %qs"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr "Λείπει παράμετρος για `%s'"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr ""
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, gcc-internal-format
 msgid "returned from %qD"
 msgstr ""
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, gcc-internal-format
 msgid "returned from %qT"
 msgstr ""
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, gcc-internal-format
 msgid "obtained here"
 msgstr ""
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 msgid "assigned here"
 msgstr "προσπέρασμα ορίσματος"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -22748,304 +22758,304 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "δεν δώθηκε συμβολικό όνομα"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr ""
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -23126,12 +23136,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -23201,7 +23211,7 @@ msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να ε
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr ""
@@ -23614,12 +23624,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -23639,7 +23649,7 @@ msgstr ""
 msgid "internal consistency failure"
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -23769,42 +23779,42 @@ msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23819,7 +23829,7 @@ msgstr ""
 msgid "total size of local objects exceeds maximum %wu"
 msgstr ""
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -24441,7 +24451,7 @@ msgstr "Μη έγκυρη πισω-παραπομπή"
 msgid "function may return address of local variable"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr ""
@@ -24808,55 +24818,55 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 msgid "%Guse of %<alloca%>"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 msgid "%Gargument to variable-length array may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
 # src/shred.c:1134
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 msgid "%Gargument to variable-length array is too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 msgid "%Gargument to %<alloca%> is too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 msgid "%Gunbounded use of variable-length array"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 msgid "%Gunbounded use of %<alloca%>"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 msgid "%Gargument to variable-length array is zero"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 msgid "%Gargument to %<alloca%> is zero"
 msgstr ""
 
@@ -24970,7 +24980,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -24996,11 +25006,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -25075,310 +25085,310 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr ""
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, gcc-internal-format
 msgid "enclosing region"
 msgstr ""
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "σφάλμα ανάγνωσης %s"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη συνάρτηση αυτή)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
 # src/shred.c:1134
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr ""
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -25827,22 +25837,22 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr ""
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr ""
@@ -25862,12 +25872,12 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "unable to find a register to spill"
 msgstr "αδυναμία εύρεσης βρόχου"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr ""
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
@@ -26577,12 +26587,12 @@ msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να ε
 msgid "unrecognized argument in option %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -26709,7 +26719,7 @@ msgstr "Η λειτουργία δεν υποστηρίζεται"
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
@@ -27209,22 +27219,22 @@ msgstr ""
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr ""
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr ""
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr ""
@@ -27286,12 +27296,12 @@ msgstr ""
 msgid "impossible register constraint in %<asm%>"
 msgstr ""
 
-#: reload.c:2687
+#: reload.c:2692
 #, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr ""
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr ""
@@ -27321,52 +27331,52 @@ msgstr ""
 msgid "output operand is constant in %<asm%>"
 msgstr ""
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:900
+#: rtl.c:910
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr ""
@@ -27411,22 +27421,22 @@ msgstr ""
 msgid "invalid punctuation %qc in constraint"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: stmt.c:430
+#: stmt.c:431
 #, fuzzy, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr ""
 
-#: stmt.c:650
+#: stmt.c:651
 #, fuzzy, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "Μη ορισμένο όνομα %s"
@@ -28104,9 +28114,9 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr ""
@@ -28141,7 +28151,7 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 msgid "invalid clique in %qs"
 msgstr "μη έγκυρη επιλογή %s"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
@@ -28347,362 +28357,362 @@ msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατ
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "μη έγκυρη επιλογή %s"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, fuzzy, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr ""
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "διπλός ορισμός συνόλου"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, fuzzy, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, fuzzy, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "ο έλεγχος φθάνει στο τέλος μη-κενής συνάρτησης"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr ""
@@ -29788,7 +29798,7 @@ msgstr ""
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
@@ -29949,7 +29959,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 msgid "unsupported record layout"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
@@ -30553,7 +30563,7 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "type was previously declared %qE"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -30573,7 +30583,7 @@ msgstr "δεν είστε μέλος της ομάδας `%s'"
 msgid "%qE argument is not a function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -30999,12 +31009,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
@@ -31165,13 +31175,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "πολύ λίγα ορίσματα"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "πάρα πολλά ορίσματα"
@@ -32106,7 +32116,7 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -32156,7 +32166,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -32171,17 +32181,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Η λειτουργία δεν επιτρέπεται"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "παράληψη ορίσματος αρχείου"
@@ -32191,7 +32201,7 @@ msgstr "παράληψη ορίσματος αρχείου"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -32256,7 +32266,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -32826,8 +32836,8 @@ msgstr "επιστροφή"
 msgid "wrong type argument to %s"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -33320,17 +33330,17 @@ msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο ε
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
@@ -33510,8 +33520,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -33587,158 +33597,158 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr ""
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr ""
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr ""
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 msgstr[1] "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr ""
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -33753,7 +33763,7 @@ msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgid "too many input files"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
@@ -33784,14 +33794,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -33943,62 +33953,62 @@ msgstr ""
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
@@ -34159,89 +34169,89 @@ msgstr ""
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr ""
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr ""
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr ""
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr ""
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr ""
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr ""
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr ""
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, fuzzy, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, fuzzy, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, fuzzy, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr ""
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34381,364 +34391,364 @@ msgstr ""
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, fuzzy, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "πάρα πολλές δηλώσεις μετατροπής στην κατάληξη"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
 # src/dfa.c:569 src/dfa.c:583 src/dfa.c:587
 # src/dfa.c:577 src/dfa.c:591 src/dfa.c:595
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "κακοσχηματισμένος μετρητής επανάληψης"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "%s: αριθμός γραμμής έξω από τα όρια"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr ""
@@ -34799,7 +34809,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -34921,18 +34931,18 @@ msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένα
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -35362,225 +35372,230 @@ msgstr ""
 msgid "target CPU does not support unaligned accesses"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr ""
+
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr ""
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
 # src/getopt1.c:155
 # src/getopt1.c:155
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "επιλογή α\n"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr ""
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -35588,22 +35603,22 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -35684,17 +35699,17 @@ msgstr "το -pipe δεν υποστηρίζεται"
 msgid "%<-fPIE%> is not supported"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "οι επιλογές --string και --check είναι αμοιβαίως αποκλειόμενες"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
@@ -36439,132 +36454,132 @@ msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένα
 msgid "parameter to builtin not valid: %s"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
@@ -36584,514 +36599,514 @@ msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%s: η υποστήριξη εκσφαλμάτωσης δεν έχει συμπεριληφθεί στη μεταγλώττιση.\n"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "Άγνωστη επιλογή: %s %s %s"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -37550,7 +37565,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -38606,57 +38621,57 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "πάρα πολλές δηλώσεις μετατροπής στην κατάληξη"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -39160,239 +39175,239 @@ msgstr "Δεν είναι δυνατή η καταχώρηση της υπηρε
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "Δεν υποστηρίζεται"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "μη έγκυρο δικαίωμα"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20055
+#: config/rs6000/rs6000.c:20172
 #, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -39572,7 +39587,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -39643,200 +39658,205 @@ msgstr "το `%s' δεν είναι κανονικό αρχείο"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "έχουν παραληφθεί ορίσματα"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, fuzzy, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "%s: ο αριθμός γραμμής πρέπει να είναι μεγαλύτερος από το μηδέν"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "το πρώτο όρισμα της `%s' πρέπει να είναι `int'"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -40181,17 +40201,22 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr ""
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
@@ -40258,8 +40283,8 @@ msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζετ
 msgid "could not read the BRIG file"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -40319,7 +40344,7 @@ msgstr "το `%s' δεν είναι κανονικό αρχείο"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -40541,7 +40566,7 @@ msgstr "αυτός είναι ο πρώτος ορισμός"
 msgid "declaration of %qD shadows a parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -40551,7 +40576,7 @@ msgstr ""
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -40561,214 +40586,214 @@ msgstr "Δεν υπάρχει προηγούμενη κανονική έκφρα
 msgid "nested extern declaration of %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, fuzzy, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, fuzzy, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, fuzzy, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη συνάρτηση αυτή)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη συνάρτηση αυτή)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
 # src/request.c:263
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, fuzzy, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, fuzzy, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, fuzzy, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "Πρόωρο τέλος της κανονικής έκφρασης"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, fuzzy, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, fuzzy, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, fuzzy, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr ""
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr ""
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, fuzzy, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, fuzzy, gcc-internal-format
 msgid "empty declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr ""
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr ""
@@ -40776,28 +40801,28 @@ msgstr ""
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, fuzzy, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr ""
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr ""
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -40806,269 +40831,269 @@ msgstr "έχουν παραληφθεί ορίσματα"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr ""
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr ""
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr ""
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, fuzzy, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr ""
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr ""
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr ""
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr ""
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "διπλό κλειδί"
 
 # src/request.c:806 src/request.c:912
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr ""
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -41076,713 +41101,713 @@ msgstr ""
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr ""
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr ""
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, fuzzy, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, fuzzy, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr ""
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, fuzzy, gcc-internal-format
 msgid "union has no named members"
 msgstr "επώνυμα μέλη"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, fuzzy, gcc-internal-format
 msgid "union has no members"
 msgstr "επώνυμα μέλη"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, fuzzy, gcc-internal-format
 msgid "struct has no named members"
 msgstr "επώνυμα μέλη"
 
 # src/request.c:37
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, fuzzy, gcc-internal-format
 msgid "struct has no members"
 msgstr "%s σε %s"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 # src/shred.c:1134
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, fuzzy, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "ο επιστρεφόμενος τύπος προκαθορίζεται σε `int'"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "διατήρηση ωρών στο %s"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr ""
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "ο επιστρεφόμενος τύπος προκαθορίζεται σε `int'"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -41790,257 +41815,257 @@ msgstr "έχουν παραληφθεί ορίσματα"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "σφάλμα εγγραφής %s"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -42060,7 +42085,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "Μη ορισμένο όνομα %s"
@@ -42070,7 +42095,7 @@ msgstr "Μη ορισμένο όνομα %s"
 msgid "ISO C forbids an empty translation unit"
 msgstr ""
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr ""
@@ -42106,7 +42131,7 @@ msgid "unknown type name %qE"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -42126,7 +42151,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -42141,7 +42166,7 @@ msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζοντ
 msgid "unexpected attribute"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -42179,7 +42204,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -42237,7 +42262,7 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -42282,14 +42307,14 @@ msgstr "έχουν παραληφθεί ορίσματα"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, fuzzy, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "σκουπίδια στο τέλος του αριθμού"
@@ -42374,7 +42399,7 @@ msgstr "διπλό όνομα χαρακτήρα `%s'"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -42434,7 +42459,7 @@ msgstr ""
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -42449,7 +42474,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -42474,17 +42499,17 @@ msgstr ""
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr ""
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -42504,12 +42529,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -42524,8 +42549,8 @@ msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχ
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -42552,12 +42577,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -42949,12 +42974,12 @@ msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χ
 msgid "no type or storage class may be specified here,"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
@@ -42964,51 +42989,51 @@ msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 msgid "unknown property attribute %<%s%s%>"
 msgstr ""
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -43018,18 +43043,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "πάρα πολλά ορίσματα"
@@ -43049,53 +43074,53 @@ msgstr ""
 msgid "%qD is not a variable"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -43117,107 +43142,107 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr ""
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr ""
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr ""
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, fuzzy, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "μη έγκυρο δικαίωμα"
@@ -43227,17 +43252,17 @@ msgstr "μη έγκυρο δικαίωμα"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -43257,22 +43282,22 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -43287,82 +43312,82 @@ msgstr "Μη έγκυρη ημερομηνία `%s'."
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr ""
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -43377,7 +43402,7 @@ msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 msgid "expected function name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -43387,27 +43412,27 @@ msgstr "Το `%s' δεν είναι κατάλογος."
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, gcc-internal-format
 msgid "expected %<allocator%>"
 msgstr ""
@@ -43417,82 +43442,82 @@ msgstr ""
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr ""
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr ""
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr ""
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr ""
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -43502,32 +43527,32 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr ""
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "αναμενόταν ')'\n"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -43537,72 +43562,72 @@ msgstr "διπλό όνομα χαρακτήρα `%s'"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -43617,57 +43642,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr ""
@@ -43677,12 +43702,12 @@ msgstr ""
 msgid "variant %qD is not a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43692,32 +43717,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -43772,42 +43797,42 @@ msgstr "%s: αναμενόταν αριθμητική τιμή."
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr ""
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr ""
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -43822,27 +43847,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -43852,7 +43877,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -43867,7 +43892,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, fuzzy, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -43908,131 +43933,131 @@ msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζοντ
 msgid "function types not truly compatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr ""
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr ""
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr ""
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr ""
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr ""
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr ""
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
 # src/main.c:697 src/main.c:751
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "Άγνωστη γλώσσα `%s'"
 
 # src/main.c:697 src/main.c:751
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "Άγνωστη γλώσσα `%s'"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr ""
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, fuzzy, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, fuzzy, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, fuzzy, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "το πέρασμα του ορίσματος %d του δείκτη στη συνάρτηση"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, fuzzy, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "το πέρασμα του ορίσματος %d του δείκτη στη συνάρτηση"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr ""
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
@@ -44040,1601 +44065,1601 @@ msgstr "Το επώνυμο αντικείμενο δεν είναι αναζη
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr ""
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, fuzzy, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr ""
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "το πέρασμα του ορίσματος %d του δείκτη στη συνάρτηση"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "το πέρασμα του ορίσματος %d του δείκτη στη συνάρτηση"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "πολύ λίγα ορίσματα"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr ""
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr ""
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to absu"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr ""
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr ""
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr ""
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, fuzzy, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "αδυναμία ανάγνωσης καταλόγου locale `%s'"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, fuzzy, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, fuzzy, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr ""
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, gcc-internal-format
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr ""
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr ""
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr ""
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr ""
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr ""
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
 # src/request.c:263
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, fuzzy, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, fuzzy, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, fuzzy, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 #, fuzzy
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 #, fuzzy
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr ""
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, fuzzy, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, fuzzy, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr ""
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, fuzzy, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr ""
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, fuzzy, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr ""
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr ""
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr ""
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr ""
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr ""
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, gcc-internal-format
 msgid "excess elements in %<char%> array initializer"
 msgstr ""
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr ""
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr ""
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr ""
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr ""
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, fuzzy, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, fuzzy, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr ""
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, fuzzy, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr ""
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr ""
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr ""
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -45842,7 +45867,7 @@ msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζε
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -45954,596 +45979,601 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "%s: η επιλογή `-W %s' είναι διφορούμενη\n"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%s: η επιλογή `-W %s' είναι διφορούμενη\n"
 
 # src/main.c:785
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "Ασαφής μορφή `%s'"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "σφάλμα στην ανάγνωση εισόδου: %s"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr ""
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr ""
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "Σφάλμα στο ταίριασμα στην κανονική έκφραση `%s'"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "Σφάλμα στο ταίριασμα στην κανονική έκφραση `%s'"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, fuzzy, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
+
+#: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%s(%A)%>"
@@ -46551,81 +46581,81 @@ msgstr "δεν ταιριάζει συνάρτηση για την κλήση σ
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "η κλήση της υπερφορτωμένης %<%s(%A)%> είναι διφορούμενη"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
@@ -46650,1130 +46680,1130 @@ msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "σφάλμα ταιριάσματος τύπου με προηγούμενη αυτονόητη διακύρηξη"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, fuzzy, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, fuzzy, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "  κατά `%D'"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr ""
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, fuzzy, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, fuzzy, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "εμφάνιση πληροφοριών προόδου"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr ""
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr ""
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr ""
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr ""
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, gcc-internal-format
 msgid "allocation performed here"
 msgstr ""
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "διπλό κλειδί"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr ""
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Μη ορισμένο όνομα %s"
@@ -47783,52 +47813,52 @@ msgstr "Μη ορισμένο όνομα %s"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -47873,7 +47903,7 @@ msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαρ
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
@@ -48260,7 +48290,7 @@ msgstr "αυτός είναι ο πρώτος ορισμός"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -48391,8 +48421,8 @@ msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'
 msgid "%q#D previously defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -48427,52 +48457,52 @@ msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 msgid "previous specification in %q#D here"
 msgstr "%s: Μη έγκυρη ρύθμιση `%s'.\n"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -48485,48 +48515,48 @@ msgstr "αυτός είναι ο πρώτος ορισμός"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "σφάλμα ταιριάσματος τύπου με προηγούμενη αυτονόητη διακύρηξη"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48534,2308 +48564,2323 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr ""
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr ""
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+msgid "%qD is a function, not a type"
+msgstr "Το `%s' δεν είναι κατάλογος."
+
+#: cp/decl.c:4072
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη συνάρτηση αυτή)"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> πρέπει να επιστρέψει %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr ""
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, fuzzy, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "Δεν υπάρχουν αρχεία εισόδου"
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "μη ορισμένο"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "μη ορισμένο"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr ""
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
 # src/shred.c:1134
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -50847,107 +50892,107 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "έχουν παραληφθεί ορίσματα"
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -50956,77 +51001,77 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -51066,7 +51111,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -51076,7 +51121,7 @@ msgstr "δημιουργία αρχείου `%s'\n"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -51402,22 +51447,22 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr ""
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -51525,7 +51570,7 @@ msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
@@ -51535,7 +51580,7 @@ msgstr "δεν είστε μέλος της ομάδας `%s'"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
@@ -51721,412 +51766,412 @@ msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρ
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
 # src/request.c:263
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
 # src/request.c:263
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, fuzzy, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ακατάλληλος τύπος δικτύου :`%s'\n"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, fuzzy, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "μη έγκυρη κατάσταση για την dlopen()"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, fuzzy, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
@@ -52181,62 +52226,62 @@ msgstr ""
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -52417,307 +52462,307 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "αδυναμία προσπέλασης(stat()) αρχείου `%s': %s"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "σφάλμα ταιριάσματος τύπου με προηγούμενη αυτονόητη διακύρηξη"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
 # src/request.c:37
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s: %s: "
 
 # src/request.c:37
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -52742,7 +52787,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -52767,7 +52812,7 @@ msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 msgid "request for member %qE in non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -52847,7 +52892,7 @@ msgstr "Μη έγκυρη ημερομηνία `%s'."
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -52983,7 +53028,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -53108,7 +53153,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "κενό αλφαριθμητικό"
@@ -53158,7 +53203,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
@@ -53188,7 +53233,7 @@ msgstr "το `%s' δεν είναι κανονικό αρχείο"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr ""
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
@@ -53208,12 +53253,12 @@ msgstr "δημιουργία αρχείου `%s'\n"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -53248,7 +53293,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -53263,7 +53308,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "λάθος αριθμός ορισμάτων"
@@ -53278,1115 +53323,1120 @@ msgstr ""
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr ""
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "παλαιού είδους θέση"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr ""
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr ""
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 msgid "condition declares an array"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 msgid "condition declares a function"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 msgid "expected module-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, gcc-internal-format
 msgid "private module fragment"
 msgstr ""
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr ""
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr ""
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, fuzzy, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "πολλαπλός αριθμός επιλογών την εντολή `s'"
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr ""
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr ""
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
 # src/dfa.c:962
 # src/dfa.c:970
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Δεν ορίστηκε συντακτικό"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr ""
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "άγνωστο σετ `%s'"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr ""
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -54395,430 +54445,430 @@ msgstr "το `%s' δεν είναι κανονικό αρχείο"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "δε βρέθηκε ο προεπεξεργαστής C: %s \n"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr ""
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -54827,759 +54877,759 @@ msgstr "διπλό όνομα χαρακτήρα `%s'"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, fuzzy, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Προσδιοριστής αφαιρέθηκε"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
 # src/request.c:37
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s: %s"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -55592,159 +55642,159 @@ msgstr "Το `%s' δεν είναι κατάλογος."
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, fuzzy, gcc-internal-format
 msgid "        %qD"
 msgstr "        `%D'"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        `%D'"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgstr[1] "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -55753,47 +55803,47 @@ msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -55803,493 +55853,493 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  αλλά %d απαιτούνται"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "διπλό όνομα χαρακτήρα `%s'"
 msgstr[1] "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 msgstr[1] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, fuzzy, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
@@ -56307,293 +56357,293 @@ msgstr "δεν είστε μέλος της ομάδας `%s'"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
 # src/request.c:37
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -56605,155 +56655,155 @@ msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
@@ -56889,533 +56939,533 @@ msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 msgid "  since %q+#D declared in base class"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr ""
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "αποτυχία κατά την εγγραφή δεδομένων για την κατηγορία `%s'"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Λείπει παράμετρος για `%s'"
@@ -57423,22 +57473,22 @@ msgstr "Λείπει παράμετρος για `%s'"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -57448,1059 +57498,1059 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 msgid " declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr ""
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 # src/main.c:697 src/main.c:751
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "Άγνωστη γλώσσα `%s'"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr ""
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr ""
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:7956
+#: cp/typeck.c:7963
 #, fuzzy, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, fuzzy, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "xdr_reference: η μνήμη εξαντλήθηκε\n"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "μη έγκυρος χρήστης"
@@ -58766,107 +58816,102 @@ msgstr ""
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
@@ -58886,266 +58931,272 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr "αδυναμία ανάγνωσης καταλόγου locale `%s'"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 msgid "cannot be declared to be a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot be %s"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr "διπλός προσδιοριστής μηνύματος"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, gcc-internal-format
 msgid "string expected for library name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "χωρίς ορίσματα"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 msgid "can only apply to a single declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, fuzzy, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 msgid "circular reference to enum member"
 msgstr "xdr_reference: η μνήμη εξαντλήθηκε\n"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, gcc-internal-format
 msgid "recursive mixin instantiation"
 msgstr ""
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, gcc-internal-format
 msgid "recursive expansion"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 msgid "error instantiating"
 msgstr "σφάλμα εγγραφής %s"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "without `this` cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 msgid "functions cannot be scope"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
@@ -59153,42 +59204,52 @@ msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 msgid "cannot be both final and abstract"
 msgstr "δεν είναι δυνατό να παραληφθεί ο χρήστης και η ομάδα"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -59196,172 +59257,172 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr "RPC: Μη συμβατές εκδόσεις του RPC"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 msgid "does not override any function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, gcc-internal-format
 msgid "structs, unions cannot be abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, gcc-internal-format
 msgid "circular inheritance"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "inherits from duplicate interface %s"
 msgstr "αδυναμία αλλαγής στο κατάλογο \"%s\""
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot inherit from final class %s"
 msgstr "δε βρέθηκε ο προεπεξεργαστής C: %s \n"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "διπλός ορισμός συνόλου"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
@@ -59376,22 +59437,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, gcc-internal-format
 msgid "has forward references"
 msgstr ""
@@ -59451,22 +59512,22 @@ msgstr ""
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
+#: d/dmd/semantic3.c:864
 #, gcc-internal-format
-msgid "no return exp; or assert(0); at end of function"
+msgid "no `return exp;` or `assert(0);` at end of function"
 msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr ""
@@ -60003,7 +60064,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
@@ -61096,12 +61157,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -61282,7 +61343,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -63775,7 +63836,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63856,7 +63917,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -63991,12 +64052,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -64106,542 +64167,542 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "πολύ λίγα ορίσματα"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, fuzzy, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to procedure `%s'"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -64789,33 +64850,33 @@ msgstr ""
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
@@ -64823,22 +64884,22 @@ msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζε
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -65374,7 +65435,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -66549,12 +66610,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -66709,147 +66770,147 @@ msgstr ""
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "%s: Σφάλμα εγγραφής "
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: Σφάλμα κατά την εγγραφή του %s\n"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "%s: Δεν είναι δυνατόν να δημιουργηθεί %s: %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "%s: Προειδοποίηση: η uname απέτυχε: %s\n"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "ΣΦΑΛΜΑ: Αδυναμία δημιουργίας προσωρινού αρχείου για αλλαγή"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "%s: Δεν είναι δυνατόν να ανοιχτεί το %s: %s\n"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -67385,8 +67446,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -69412,7 +69473,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -69529,7 +69590,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -69685,212 +69746,212 @@ msgstr ""
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -69899,12 +69960,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -69913,294 +69974,294 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
 # src/shred.c:1134
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -70209,284 +70270,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -70494,192 +70555,192 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -70687,966 +70748,966 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
 # src/request.c:37
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -72512,17 +72573,17 @@ msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -72613,110 +72674,110 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
 # src/shred.c:1134
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
 # src/shred.c:1134
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
 # src/grep.c:1133
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "άγνωστη μέθοδος καταλόγων"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -72867,7 +72928,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr ""
@@ -72994,7 +73055,7 @@ msgstr "\"Ζώνη %s\" γραμμή και επιλογή -l είναι αμο
 
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "οι επιλογές --string και --check είναι αμοιβαίως αποκλειόμενες"
 
 #: lto/lto-object.c:107
@@ -74107,7 +74168,7 @@ msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr ""
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "μη αναγνωρίσημη επιλογή `-%c'"
@@ -74125,15 +74186,15 @@ msgstr "έχουν παραληφθεί ορίσματα"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, fuzzy, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "παράληψη ορίσματος αρχείου"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, fuzzy, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "ορισμός δικαιωμάτων στο %s"
@@ -74185,7 +74246,7 @@ msgid "unrecognized ivar visibility value %qs"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
 # src/request.c:806 src/request.c:912
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
@@ -74268,95 +74329,95 @@ msgstr "το `%s' δεν είναι κανονικό αρχείο"
 msgid "unknown linker output %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, fuzzy, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: common.opt:1718
+#: common.opt:1722
 #, fuzzy, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "Αρχή αρχείου %s\n"
 
 # src/grep.c:1133
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "άγνωστη μέθοδος καταλόγων"
 
-#: common.opt:2232
+#: common.opt:2236
 #, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr ""
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2690
+#: common.opt:2694
 #, fuzzy, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "άγνωστο σετ `%s'"
 
 # src/request.c:806 src/request.c:912
-#: common.opt:3067
+#: common.opt:3071
 #, fuzzy, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
 # src/request.c:263
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
diff --git a/gcc/po/es.po b/gcc/po/es.po
index 6890a3860c6de..86f26f9a3822d 100644
--- a/gcc/po/es.po
+++ b/gcc/po/es.po
@@ -42,7 +42,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.1-b20200209\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2020-03-22 16:48+0100\n"
 "Last-Translator: Antonio Ceballos Roa <aceballos@gmail.com>\n"
 "Language-Team: Spanish <es@tp.org.es>\n"
@@ -1304,11 +1304,11 @@ msgstr "    incluido en línea de %qs"
 msgid "this is the insn:"
 msgstr "este es la insn:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "no se pueden generar recargas para restricciones imposibles:"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "no se pueden generar recargas para:"
 
@@ -1489,16 +1489,16 @@ msgstr "no se reconoce la insn:"
 msgid "insn does not satisfy its constraints:"
 msgstr "la insn no satisface sus restricciones:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "creado y usado con diferentes opciones de '%s'"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "creado y usado con diferentes opciones de %<-fpic%>"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "creado y usado con diferentes opciones de %<-fpie%>"
 
@@ -1536,7 +1536,7 @@ msgstr "%s%saviso: el encabezado %s versión %s difiere de la versión de la bib
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC heurísticas: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1984,86 +1984,86 @@ msgstr "modificador de longitud en formato strfmon"
 msgid "<command-line>"
 msgstr "<línea-de-órdenes>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "no se admite el operando para el código '%c'"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "operando no válido para '%%%c'"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante de vector no válida"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 #| msgid "incompatible floating point / vector register operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "falta un operando"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "constante no válida"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "operando no válido"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "prefijo de operando no válido '%%%c'"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, c-format
 msgid "invalid address mode"
 msgstr "modo de direccionamiento no válido"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "operación no permitida con el tipo %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "operandos no válidos en la operación binaria"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "se usó '%%&' sin ninguna referencia TLS dinámica local"
@@ -2079,18 +2079,18 @@ msgid "invalid %%r value"
 msgstr "valor %%r no válido"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "valor %%R no válido"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "valor %%N no válido"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "valor %%P no válido"
@@ -2120,7 +2120,7 @@ msgstr "valor %%M no válido"
 msgid "invalid %%U value"
 msgstr "valor %%U no válido"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "valor %%s no válido"
@@ -2130,7 +2130,7 @@ msgstr "valor %%s no válido"
 msgid "invalid %%C value"
 msgstr "valor %%C no válido"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "valor %%E no válido"
@@ -2143,7 +2143,7 @@ msgstr "reubicación unspec desconocida"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "código %%xn no válido"
@@ -2225,35 +2225,35 @@ msgstr "UNSPEC no válido como operando: %d"
 msgid "unrecognized supposed constant"
 msgstr "no se reconoce la constante supuesta"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "operando de desplazamiento no válido"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instrucción de predicado Thumb"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instrucción de predicado en una secuencia condicional"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "No se admite el operando para el código '%c'"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2261,13 +2261,13 @@ msgstr "No se admite el operando para el código '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "operando no válido para el código '%c'"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "la instrucción nunca se ejecuta"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "código de formato Maverick obsoleto '%c'"
@@ -2393,8 +2393,8 @@ msgstr "operando inesperado"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2760,7 +2760,7 @@ msgstr "operación no válida en %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "operando %%P no válido"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "valor %%p no válido"
@@ -2814,7 +2814,7 @@ msgid "post-increment address is not a register"
 msgstr "la dirección de post-incremento no es un registro"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "dirección errónea"
 
@@ -2866,8 +2866,8 @@ msgstr "'%%%c' no es un prefijo de operando válido"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "uso no válido de '%%%c'"
@@ -3011,305 +3011,305 @@ msgstr "Espacio de pila agotado.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Pruebe ejecutar '%s' en el intérprete de órdenes para elevar su límite.\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "%<-mvsx%> requiere coma flotante de hardware"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> necesita direccionamiento indexado"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "%<-mvsx%> y -%<mno-altivec%> son incompatibles"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "%<-mno-altivec%> desactiva vsx"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<-mquad-memory%> requiere modo de 64 bits"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> requiere modo de 64 bits"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> no está disponible en modo little endian"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr "move erróneo"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr "Movimiento de 128 bits erróneo"
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "valor %%J no válido"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "valor %%D no válido"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, c-format
 msgid "invalid %%e value"
 msgstr "valor %%e no válido"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "valor %%f no válido"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "valor %%F no válido"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "valor %%G no válido"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "código %%j no válido"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "código %%J no válido"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "valor %%k no válido"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "valor %%K no válido"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "valor %%O no válido"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "valor %%q no válido"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, c-format
 msgid "invalid %%t value"
 msgstr "valor %%t no válido"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "valor %%T no válido"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "valor %%u no válido"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "valor %%v no válido"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, c-format
 msgid "invalid %%V value"
 msgstr "valor %%V no válido"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "valor %%x no válido"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, c-format
 msgid "invalid %%z value"
 msgstr "valor %%z no válido"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valor %%y no válido, pruebe usando la restricción 'Z'"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 #, fuzzy
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Activa el uso de instrucciones de coma flotante de 128 bits IEEE."
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 msgid "Could not generate addis value for fusion"
 msgstr "No se ha podido generar valor addis para fusión"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr "No se puede generar desplazamiento de carga/almacenamiento para fusión"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr "Fusión GPR errónea"
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "conversión no válida de %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "conversión no válida a %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "conversión no válida de %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "conversión no válida a %<__fpreg%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "las referencias a memoria simbólica sólo se admiten en z10 o posterior"
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "no se puede descomponer la dirección"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "operador de comparación no válido para el modificador de salida 'E'"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "referencia no válida para el modificador de salida 'J'"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "dirección no válida para el modificador de salida 'O'"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "dirección no válida para el modificador de salida 'R'"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "se esperaba una referencia de memoria para el modificador de salida 'S'"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "dirección no válida para el modificador de saida 'S'"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "se esperaba un registro o expresión de memoria para el modificador de salida 'N'"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "se esperaba un registro o expresión de memoria para el modificador de salida 'M'"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "constante no válida para el modificador de salida '%c'"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "constante no válida - pruebe usar un modificador de salida"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "vector constante no válido para el modificador de salida '%c'"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "expresión no válida - pruebe usar un modificador de salida"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "expresión no válida para el modificador de salida '%c'"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 msgid "vector argument passed to unprototyped function"
 msgstr "se pasó un argumento vector a una función sin prototipo"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr "los tipos difieren en el signo"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr "el operador binario no admite dos operadores bool vector"
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr "el operador binario no admite operador bool vector"
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "el operador binario no admite que se mezclen operandos bool vector y vector de coma flotante"
 
@@ -3572,8 +3572,8 @@ msgstr "({anónimo})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "se esperaba %<;%>"
@@ -3593,7 +3593,7 @@ msgstr "se esperaba %<;%>"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "se esperaba %<)%>"
@@ -3601,7 +3601,7 @@ msgstr "se esperaba %<)%>"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "se esperaba %<]%>"
@@ -3619,21 +3619,21 @@ msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "se esperaba %<(%>"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "se esperaba %<[%>"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "se esperaba %<{%>"
@@ -3644,13 +3644,13 @@ msgstr "se esperaba %<{%>"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "se esperaba %<:%>"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "se esperaba %<while%>"
@@ -3659,7 +3659,7 @@ msgstr "se esperaba %<while%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "se esperaba %<,%>"
@@ -3668,18 +3668,18 @@ msgstr "se esperaba %<,%>"
 msgid "expected %<.%>"
 msgstr "se esperaba %<.%>"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "se esperaba %<@end%>"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "se esperaba %<>%>"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "se esperaba %<,%> o %<)%>"
@@ -3687,28 +3687,28 @@ msgstr "se esperaba %<,%> o %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "se esperaba %<=%>"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "se esperaba %<}%>"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(anónimo)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "se esperaba %<<%>"
@@ -3725,31 +3725,31 @@ msgstr "se esperaba etiqueta"
 msgid "candidate:"
 msgstr "candidato 1:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 #| msgid "Enable user-defined instructions."
 msgid "  after user-defined conversion:"
 msgstr "Activa las instrucciones definidas por el usuario."
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "el candidato es:"
 msgstr[1] "los candidatos son:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "candidato 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "candidato 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "salto a la etiqueta %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "salto a la etiqueta case"
 
@@ -3970,35 +3970,35 @@ msgstr "la variable local %qD no puede aparecer en este contexto"
 msgid "local variable %qD may not appear in this context"
 msgstr "la variable local %qD no puede aparecer en este contexto"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 #, fuzzy
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 #| msgid "invalid use of dependent type %qT"
 msgid "%<using enum%> of dependent type %qT"
 msgstr "uso no válido del tipo dependiente %qT"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 #| msgid "%qT is not an enumeration type"
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%qT no es un tipo de enumeración"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 #| msgid "invalid use of incomplete type %q#T"
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "uso no válido del tipo incompleto %q#T"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "los candidatos son:"
 
@@ -4042,48 +4042,48 @@ msgstr "la conversión descarta la constancia"
 msgid "source type is not polymorphic"
 msgstr "el tipo fuente no es polimórfico"
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argumento de tipo erróneo para el decremento unario"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argumento de tipo erróneo para el incremento unario"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argumento de tipo erróneo para complemento de bits"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argumento de tipo erróneo para abs"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argumento de tipo erróneo para la conjugación"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr "en el argumento para el ! unario"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr "no hay operador de pre-incremento para el tipo"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr "no hay operador de post-incremento para el tipo"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr "no hay operador de pre-decremento para el tipo"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr "no hay operador de post-decremento para el tipo"
 
@@ -4188,7 +4188,7 @@ msgstr "Desajuste de frontera de matriz en la dimensión 2 de la matriz (%ld/%ld
 msgid "Driving:"
 msgstr "Conduciendo:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "argumento actual de INTENT = OUT/INOUT"
 
@@ -4334,7 +4334,7 @@ msgstr "Operador erróneo"
 msgid "Bad type in constant expression"
 msgstr "Tipo erróneo en la expresión constante"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "Fin de módulo inesperado"
 
@@ -4362,11 +4362,11 @@ msgstr "bloque IF"
 msgid "implied END DO"
 msgstr "END DO implícito"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "asignación"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "asignación de puntero"
 
@@ -4452,154 +4452,154 @@ msgstr "resultado con longitud de carácter no constante"
 msgid "bind(c) procedure"
 msgstr "procedimiento bind(c)"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Contexto no válido para el puntero NULL() en %%L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "El operando del operador numérico unitario %%<%s%%> en %%L es %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Entidades de tipos derivados no esperadas en el operador numérico intrínseco binario %%<%s%%> en %%L"
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador numérico binario %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Los operandos del operador de concatenación de cadenas en %%L son %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador lógico %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "El operando del operador .not. en %%L es %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Las cantidades COMPLEX no se pueden comparar en %L"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Los lógicos en %%L se deben comparar con %s en lugar de %s"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador de comparación %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Operador %%<%s%%> desconocido en %%L; ¿quiso decir '%s'?"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Operador %%<%s%%> desconocido en %%L"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "El operando del operador de usuario %%<%s%%>  en %%L es %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador de usuario %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangos inconsistentes para el operador en %%L y %%L"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr "Variable de ciclo"
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr "variable de iterador"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr "Expresión de inicio en el bucle DO"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr "Expresión de fin en el bucle DO"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr "Expresión de paso en el bucle DO"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr "objeto DEALLOCATE"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr "objeto ALLOCATE"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr "elemento en READ"
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Longitudes de CHARACTER diferentes (%ld/%ld) en el constructor de matriz"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Desborde entero al calcular la cantidad de memoria a reservar"
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "El valor del parámetro PDT LEN '%s' no concuerda con el de la declaración «dummy»"
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longitud de la cadena actual no coincide con la declarada para el argumento dummy '%s' (%ld/%ld)"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longitud de la cadena actual es más corta que la declarada para el argumento dummy '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "El objetivo del remapeo de rango es demasiado pequeño (%ld < %ld)"
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr "Asignación de escalar a un array sin espacio asignado"
 
@@ -4729,27 +4729,27 @@ msgstr "La referencia de la matriz está fuera de los límites"
 msgid "Incorrect function return value"
 msgstr "Valor de devolución de la función incorrecto"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 #| msgid "Memory allocation failed"
 msgid "Error allocating %lu bytes"
 msgstr "Falló la asignación de memoria"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "Se intentó alojar la variable ya alojada '%s'"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr "Se intentó alojar una variable ya alojada"
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "Se intentó DEALLOCATE en '%s' sin alojar."
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr "Error reasignando a %lu bytes"
@@ -4948,15 +4948,15 @@ msgstr "-Xbind-now y -Xbind-lazy son incompatibles"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr "considere usar `-pg' en lugar de `-p' con gprof (1)"
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "no se pueden usar -EB y -EL al mismo tiempo"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "no se pueden usar juntos -mfloat-abi=soft y -mfloat-abi=hard"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "no se pueden usar juntos -mbig-endian y -mlittle-endian"
 
@@ -4972,8 +4972,8 @@ msgstr "no existe el tipo de procesador especificado para enlazar"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "no especifique -march=... y -mcpu=... al mismo tiempo"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared y mdll no son compatibles"
 
@@ -5137,10 +5137,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Avisa sobre la creación de matrices temporales."
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "No hace nada. Preservado por compatibilidad hacia atrás."
@@ -5620,160 +5620,160 @@ msgstr "Coloca todas las matrices locales en la pila."
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "Establece la accesibilidad por defecto de las entidades de módulo a PRIVATE."
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "Trata de acomodar los tipos derivados tan compactos como sea posible."
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "Protege paréntesis en las expresiones."
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr "Ruta de fichero de cabecera que debería preincluirse antes de cada unidad de compilación."
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr "Permite la revisión de rango durante la compilación."
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr "Interpreta cualquier REAL(4) como un REAL(8)."
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr "Interpreta cualquier REAL(4) como un REAL(10)."
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr "Interpreta cualquier REAL(4) como un REAL(16)."
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr "Interpreta cualquier REAL(8) como un REAL(4)."
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr "Interpreta cualquier REAL(8) como un REAL(10)."
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr "Interpreta cualquier REAL(8) como un REAL(16)."
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr "Reubica el lado derecho en las asignaciones."
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Usa un marcador de registro de 4 bytes para los ficheros sin formato."
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Usa un marcador de registro de 8 bytes para los ficheros sin formato."
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr "Almacena las variables locales en la pila para permitir recursividad indirecta."
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "Copia las secciones de matriz en un bloque contiguo en la entrada de procedimiento."
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr "-fcoarray=[...]\tEspecifica qué paralelización de comatriz se debe usar."
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr "-fcheck=[...]\tEspecifica qué revisiones de tiempo de ejecución se realizarán."
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "Agrega un segundo guión bajo si el nombre ya tiene un guión bajo."
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr "Aplica signo negativo a valores cero."
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr "Agrega subrayado a los nombres visibles externamente."
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "No hace nada.  Se preserva por compatibilidad hacia atrás."
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr "Enlaza estáticamente la biblioteca de ayuda de GNU Fortran (libgfortran)."
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Conforma al estándar ISO Fortran 2003."
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Conforma al estándar ISO Fortran 2008."
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Conforma al estándar ISO Fortran 2008 incluyendo TS 29113."
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Conforma al estándar ISO Fortran 2018."
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Conforma al estándar ISO Fortran 95."
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr "No conforma a nada en particular."
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr "Acepta las extensiones para dar soporte a código heredado."
@@ -6471,7 +6471,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7101,8 +7101,8 @@ msgstr "-faligned-new=<N> Usa alojamiento de tipo sobrealineado de C++17 para al
 msgid "Allow variadic functions without named parameter."
 msgstr "Permite funciones variadic sin parámetro nombrado."
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr "Ya no se admite."
@@ -7469,473 +7469,468 @@ msgstr "Especifica las dimensiones de cálculo predeterminadas de OpenACC."
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "Activa OpenMP (implica -frecursive en Fortran)."
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "Activa las directivas SIMD de OpenMP."
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "Reconoce palabras clave de C++ como \"compl\" y \"xor\"."
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "Busca y utiliza ficheros PCH aún cuando se esté preprocesando."
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr "Degrada los errores de concordancia a avisos."
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr "Activa las extensiones de lenguaje de Plan9."
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr "Trata al fichero de entrada como previamente preprocesado."
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, fuzzy, no-c-format
 #| msgid "-ftrack-macro-expansion=<0|1|2>  Track locations of tokens coming from macro expansion and display them in error messages."
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr "-ftrack-macro-expansion=<0|1|2>  Rastrea las ubicaciones de los elementos que provienen de la expansión de macros y los muestra en mensajes de error."
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, fuzzy, no-c-format
 #| msgid "-fno-pretty-templates Do not pretty-print template specializations as the template signature followed by the arguments."
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr "-fno-pretty-templates No da formato legible a las especializaciones de plantilla como la firma de plantilla seguida por los argumentos."
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr "Trata los valores de retorno conocidos de sprintf como constantes."
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "Usa el modo Fix-and-Continue para indicar que los ficheros objeto se pueden intercambiar en tiempo de ejecución."
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 #| msgid "Deprecated in GCC 9.  This switch has no effect."
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "Obsoleto en GCC 9.  Esta opción no tiene efecto."
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr "Genera información de descriptor de tipo en tiempo de ejecución."
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "Usa el tipo entero más estrecho posible para tipos de enumeración."
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "Fuerza que el tipo subyacente de \"wchar_t\" sea \"unsigned short\"."
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "Cuando no se proporcione \"signed\" o \"unsigned\" hace signed el campo de bits."
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr "Hace que \"char\" sea signed por defecto."
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "Admite desasignación con tamaño de C++14."
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr "-fsso-struct=[big-endian|little-endian|native]\tEstablece el orden de almacenamiento de escalares predeterminado."
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr "Muestra las estadísticas acumuladas durante la compilación."
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "Asume que los valores de tipo de enumeración están siempre dentro del rango mínimo de ese tipo."
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr "Sigue los requisitos de orden de evaluación de C++17 para expresiones de asignación, desplazamiento, llamadas a funciones miembro, etc."
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "Establece el número máximo de notas de instanciación de plantilla para un solo aviso o error."
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "-ftemplate-depth-<número>\tEspecifica la profundidad máxima de instanciación de plantilla."
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "-fno-threadsafe-statics\tNo genera código seguro en hilos para inicializar statics locales."
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "Cuando no se proporcione \"signed\" o \"unsigned\" hacer unsigned el campo de bits."
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "Hace que \"char\" sea unsigned por defecto."
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr "Usa __cxa_atexit para registrar destructores."
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "Usa __cxa_get_exception_ptr para el manejo de excepciones."
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "Marca todos los métodos y funciones incluidos en línea con visibilidad hidden."
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "Cambia la visibilidad para coincidir con Microsoft Visual Studio por defecto."
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr "Emite símbolos comunes como símbolos débiles."
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-fwide-exec-charset=<cset>\tConvierte todas las cadenas anchas y constantes de cáracter al conjunto de caracteres <cset>."
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "Genera una directiva #line que apunte al directorio de trabajo actual."
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "Genera la búsqueda no estricta de clases (a través de objc_getClass()) para usarlas en el modo Zero-Link."
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr "Vuelca las declaraciones a un fichero .decl."
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "-femit-struct-debug-baseonly\tInformación de depuración reducida agresiva para structs."
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "-femit-struct-debug-reduced\tInformación de depuración reducida conservadora para structs."
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "-femit-struct-debug-detailed=<lista-espec>\tInformación de depuración reducida detallada para structs."
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr "Interpreta imaginario, coma fija u otro sufijo de número gnu como el literal numérico correspondiente en lugar de un literal numérico definido por el usuario."
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <dir>\tAgrega el <dir>ectorio al final de la ruta de inclusión del sistema."
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "-imacros <fichero>\tAcepta la definición de macros en el <fichero>."
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-imultilib <dir>\tDefine <dir> como el subdirectorio de inclusión de multilib."
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "-include <file>\tIncluye los contenidos del <fichero> antes de otros ficheros."
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "-iprefix <ruta>\tEspecifica la <ruta> como un prefijo para las siguientes dos opciones."
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <dir>\tEstablece el <dir>ectorio como el directorio raíz del sistema."
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <dir>\tAgrega el <dir>ectorio al inicio de la ruta de inclusión del sistema."
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-iquote <dir>\tAgrega el <dir>ectorio al final de la ruta de inclusión de citas."
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <dir>\tAgrega el <dir>ectorio al final de la ruta de inclusión del sistema."
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <dir>\tAgrega el <dir>ectorio al final de la ruta de inclusión principal."
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "No busca directorios de inclusión del sistema por defecto (aquellos especificados con -isystem aún serán utilizados)."
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr "No busca directorios de inclusión del sistema por defecto para C++."
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr "Genera encabezado C de características específicas de la plataforma."
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr "Reasocia nombres de fichero al incluir ficheros"
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Conforma al estándar ISO 1998 C++ revisado por la corrección técnica 2003."
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Conforma al estándar ISO 2011 C++."
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Obsoleto en favor de -std=c++11."
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Obsoleto en favor de -std=c++14."
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Conforma al estándar ISO 2014 C++."
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr "Obsoleto en favor de -std=c++17."
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "Conforma al estándar ISO 2017 C++."
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2020(?) C++ draft standard (experimental and incomplete support)."
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Conforma al borrador del estándar ISO 2020(?) C++ (soporte experimental e incompleto)."
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2020(?) C++ draft standard (experimental and incomplete support)."
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Conforma al borrador del estándar ISO 2020(?) C++ (soporte experimental e incompleto)."
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Conforma al estándar ISO 2012 C."
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "Obsoleto en favor de -std=c11."
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Conforma al estándar ISO 2017 C (publicado en 2018)."
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Conforma al borrador del estándar ISO 202X C (soporte experimental e incompleto)"
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Conforma al estándar ISO 1990 C."
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Conforma al estándar ISO 1999 C."
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr "Obsoleto en favor de -std=c99."
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Conforma al estándar ISO 1998 C++ revisado por la corrección técnica 2003 con extensiones GNU."
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Conforma al estándar ISO 2011 C++ con extensiones GNU."
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Obsoleto en favor de -std=gnu++11."
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Obsoleto en favor de -std=gnu++14."
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Conforma al estándar ISO 2014 C++ con extensiones GNU."
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "Obsoleto en favor de -std=gnu++17."
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "Conforma al estándar ISO 2017 C++ con extensiones GNU."
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2020(?) C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Conforma al borrador del estándar ISO 2020(?) C++ con extensiones GNU (soporte experimental e incompleto)."
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2020(?) C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Conforma al borrador del estándar ISO 2020(?) C++ con extensiones GNU (soporte experimental e incompleto)."
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Conforma al estándar ISO 2011 C con extensiones GNU."
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Obsoleto en favor de -std=gnu11."
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Conforma al estándar ISO 2017 C (publicado en 2018) con extensiones GNU."
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Conforma al borrador del estándar ISO 202X C con extensiones GNU (soporte experimental e incompleto)."
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Conforma al estándar ISO 1990 C con extensiones GNU."
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Conforma al estándar ISO 1999 C con extensiones GNU."
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Obsoleto en favor de -std=gnu99."
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Conforma al estándar ISO 1990 C tal y como se enmendó en 1994."
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Obsoleto en favor de -std=iso9899:1999."
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "Habilita el preprocesamiento tradicional."
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\tSoporte para los trigrafos de ISO C."
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr "No predefine las macros específicas del sistema y específicas de GCC."
@@ -8185,6 +8180,12 @@ msgstr "Compila con el modo entero de 32-bit"
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+#| msgid "Emit implicit instantiations of templates."
+msgid "Emit template instantiations as weak symbols."
+msgstr "Emite instanciaciones implícitas de plantillas."
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9451,145 +9452,157 @@ msgstr "Admite más de 8192 entradas GOT en ColdFire."
 msgid "Support TLS segment larger than 64K."
 msgstr "Admite segmentos TLS más grandes que 64K."
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr "Asume que la CPU destino está configurada como big endian."
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr "Asume que el CPU destino está configurado como little endian."
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "-mbranch-cost=N\tEstablece el costo de las ramificaciones aproximadamente a N instrucciones."
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr "Al generar código -fpic, permite el uso de PLTs. Se hace caso omiso con fno-pic."
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "Especifica el convenio de llamadas de enteros y de coma flotante."
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Trata de mantenter la pila alineada a esta potencia de 2."
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "ABIs admitidas (para usar con la opción -mabi=):"
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Usa instrucciones de división y de raíz cuadrada de coma flotante de hardware."
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr "Usa instrucciones de hardware para la división entera."
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr "-march=\tGenera código para el RISC-V ISA dado (por ejemplo, RV64IM).  Las cadenas ISA deben ser minúsculas."
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=PROCESADOR\tOptimiza la salida para el PROCESADOR."
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 #| msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "-mtune=PROCESADOR\tOptimiza la salida para el PROCESADOR."
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "-msmall-data-limit=N\tColoca los datos globales y estáticos más pequeños que <N> bytes en una sección especial (en algunos objetivos)."
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "Usa código de prólogo y epílogo más pequeño pero más lento."
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr "Especifica el modelo de código."
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr "No genera accessos a memoria sin alinear"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr "Modelos de código conocidos (para uso con la opción -mcmodel=):"
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr "Utiliza operadores %reloc() en vez de macros de ensamblador para cargar direcciones."
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr "Aprovecha los descansos del enlazador para reducir el número de instrucciones requeridas para materializar direcciones de símbolos."
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr "Emite el atributo ELF de RISC-V."
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr "Usa la alineación de los datos dada."
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr "Las opciones conocidas para alineamiento de datos (para usar con la opción -malign-data=):"
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr "USa la guarda de protección de la pila dada."
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Argumentos válidos para -mstack-protector-guard=:"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Usa el registro base dado para direccionar la guarda de protección de la pila."
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Usa el desplazamiento dado para direccionar la guarda de protección de la pila."
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, fuzzy, no-c-format
 #| msgid "Supported ABIs (for use with the -mabi= option):"
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "ABIs admitidas (para usar con la opción -mabi=):"
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, fuzzy, no-c-format
 #| msgid "The version of the C++ ABI in use."
 msgid "Set the version of RISC-V ISA spec."
@@ -9725,12 +9738,6 @@ msgstr "Los dialectos de TLS posibles:"
 msgid "The code model option names for -mcmodel:"
 msgstr "Los nombres de las opciones de modelos de código para -mcmodel:"
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr "Asume que la CPU destino está configurada como big endian."
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9752,12 +9759,6 @@ msgstr "Solución alternativa para la errata de ARM Cortex-A53 número 835769."
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr "Solución alternativa para la errata de ARM Cortex-A53 número 843419."
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr "Asume que el CPU destino está configurado como little endian."
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -17114,2197 +17115,2197 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <dir>\tEstablece el nombre del directorio a usar para los volcados."
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr "La versión de la ABI de C++ que se está usando."
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr "Optimiza los bucles de forma agresiva empleando restricciones del lenguaje."
 
-#: common.opt:978
+#: common.opt:982
 #, no-c-format
 msgid "Align the start of functions."
 msgstr "Alinea el inicio de las funciones."
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr "Alinea las etiquetas que solamente se alcanzan saltando."
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr "Alinea todas las etiquetas."
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr "Alinea el inicio de los bucles."
 
-#: common.opt:1009
+#: common.opt:1013
 #, fuzzy, no-c-format
 #| msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr "Permitir que el paso de mezcla de almacenamientos introduzca almacenamientos desalineados si es legal hacerlo."
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing."
 msgid "Enable static analysis pass."
 msgstr "Habilita el preprocesamiento tradicional."
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr "Selecciona qué sanear."
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr "Selecciona el tipo de saneamiento de cobertura."
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr "-fsanitize-sections=<sec1,sec2,...>\tSanea las variables globales en las secciones definidas por el usuario."
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr "Tras el diagnóstico de comportamiento indefinido intenta continuar la ejecución."
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Esta opción es obsoleta; utilice en su lugar -fsanitize-recover=."
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr "Usa trap en lugar de una función de biblioteca para sanear el comportamiento indefinido."
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Genera tablas de desenredo que sean exactas en cada límite de instrucción."
 
-#: common.opt:1069
+#: common.opt:1073
 #, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "Genera instrucciones auto-inc/dec."
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Usa información de perfil de muestra para los pesos de los nodos de los grafos de llamadas. El fichero de perfil predeterminado es fbdata.afdo en 'pwd'."
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Usa la información de perfil de muestra para los pesos de los nodos de los grafos de llamadas. El fichero de perfil se especifica en el argumento."
 
-#: common.opt:1087
+#: common.opt:1091
 #, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Genera código para revisar los límites antes de indexar matrices."
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Reemplaza add, compare, branch con branch en la cuenta de registros."
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr "Usa la información de análisis de perfil para las probabilidades de ramificación."
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 #| msgid "Output stack usage information on a per-function basis."
 msgid "Output callgraph information on a per-file basis."
 msgstr "Información de uso de pila de salida basada por función."
 
-#: common.opt:1115
+#: common.opt:1119
 #, fuzzy, no-c-format
 #| msgid "Output stack usage information on a per-function basis."
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "Información de uso de pila de salida basada por función."
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<registro>\tMarca el <registro> como preservado entre funciones."
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<registro>\tMarca el <registro> como corrupto por llamadas de función."
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr "Guarda registros alrededor de llamadas de función."
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "Esta opción es obsoleta; no lo utilice."
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "Revisa el valor de devolución de new en C++."
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr "Realiza comprobaciones de consistencia internas."
 
-#: common.opt:1150
+#: common.opt:1154
 #, no-c-format
 msgid "Enable code hoisting."
 msgstr "Activa la elevación de código."
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Busca oportunidades para reducir los ajustes de pila y las referencias de pila."
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 #| msgid "Do not put uninitialized globals in the common section."
 msgid "Put uninitialized globals in the common section."
 msgstr "No pone globales sin inicializar en la sección común."
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<opts>]\tCompila con y sin p.e. -gtoggle, y compara el volcado de insns finales."
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "Ejecuta sólo la segunda compilación de -fcompare-debug."
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Realiza la eliminación de comparaciones después de terminar el alojamiento de registros."
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "No realizar optimizaciones que incrementan notablemente el uso de la pila."
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Realiza el paso de optimización de copia-propagación de registros."
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr "Realiza optimizaciones de saltos cruzados."
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Cuando se esté ejecutando CSE, sigue los saltos a sus objetivos."
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr "Omite el paso de reducción de rango al realizar divisiones complejas."
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "La multiplicación y la división complejas siguen las reglas Fortran."
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr "Coloca los elementos de datos en su propia sección."
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Enumera todos los contadores de depuración disponibles con sus límites y cuentas."
 
-#: common.opt:1214
+#: common.opt:1218
 #, fuzzy, no-c-format
 #| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<contador>:<límite>[,<contador>:<límite>,...]\tEstablece el límite del contador de depuración."
 
-#: common.opt:1218
+#: common.opt:1222
 #, fuzzy, no-c-format
 #| msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr "-fdebug-prefix-map=<antiguo>=<nuevo> Asocia un nombre de directorio a otro en la información de depuración."
 
-#: common.opt:1222
+#: common.opt:1226
 #, fuzzy, no-c-format
 #| msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr "-ffile-prefix-map=<antiguo>=<nuevo> Asocia un nombre de directorio a otro en la información de depuración."
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "Muestra la sección .debug_types al usar la información de depuración DWARF v4."
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr "Posterga la extracción de argumentos de funciones de la pila hasta más tarde."
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Intenta rellenar las ranuras de retraso de las instrucciones de ramificación."
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr "Borra instrucciones muertas que pueden lanzar excepciones."
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr "Borra las revisiones de punteros nulos sin uso."
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr "Hace fluir datos extra para permitir desvirtualización más agresiva en el modo de transformación local LTO."
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr "Realiza desvirtualización especulativa."
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Trata de convertir las llamadas virtuales a llamadas directas."
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\tIndica la frecuencia con que se debe emitir la ubicación del código al inicio de los diagnósticos con corte de línea."
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr "Muestra la línea de código con un signo de intercalación para indicar la columna."
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tColorea los diagnósticos."
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy, no-c-format
 #| msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tColorea los diagnósticos."
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr "Imprime indicaciones fix-it (arreglar) en formato legible por una máquina."
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr "Imprime indicaciones fix-it (arreglar) en stder en formato diff unificado."
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Asocia adecuadamente los mensajes de diagnóstico con la opción de línea de orden que los controla."
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, fuzzy, no-c-format
 #| msgid "-ftabstop=<number>\tDistance between tab stops for column reporting."
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "-ftabstop=<número>\tDistancia entre topes de tabulador para informes en columnas."
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, fuzzy, no-c-format
 #| msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<paso>=rango1+rango2 desactiva un paso de optimización."
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, no-c-format
 #| msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<paso>=rango1+rango2 activa un paso de optimización."
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<tipo>\tVuelca varios internos del compilador a un fichero."
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=fichero\tVuelca al fichero las insns al final de la traducción."
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=fichero\tEscribe todas las declaraciones al fichero como código Go."
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Suprime la salida de direcciones en los volcados de depuración."
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr "Recoge y vuelca información de depuración en un fichero temporal si ha ocurrido ICE en el compilador de C/C++."
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr "Vuelca información detallada de las ubicaciones de código fuente en la representación interna de GCC."
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr "Vuelca pasadas de optimización."
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Suprime la salida de números de instrucción, notas de números de linea y direcciones en los volcados de depuración."
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Suprime la salida de los números insn previos y siguientes en los volcados de depuración."
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Activa las tablas CFI a través de directivas del ensamblador GAS."
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr "Realiza la inclusión en línea temprana."
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Realiza la reducción interprocedural de los agregados."
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Realiza la eliminación de símbolos sin uso en la información de depuración."
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr "Realiza la eliminación de tipos sin uso en la información de depuración."
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "No suprime la información de depuración de clases C++."
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr "Activa el manejo de excepciones."
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Realiza un número de optimizaciones menores y costosas."
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tEspecifica el manejo del exceso de precisión de coma flotante."
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts--18661]\tEspecifica qué valores de FLT_EVAL_METHOD están permitidos."
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Muestra los objetos lto que contienen tanto el lenguaje intermedio como la salida binaria."
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Asume que no se generan NaNs o infinitos."
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<registro>\tMarca el <registro> como no disponible para el compilador."
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "No aloja floats y doubles en registros de precisión extendida."
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Realiza el paso de la propagación hacia adelante en RTL."
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast]\tRealiza contracción de expresión de coma flotante."
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr "Permite a las funciones internas ceil, floor, round, trunc generar excepciones \"inexactas\"."
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr "Permite que las direcciones de las funciones se conservern en registros."
 
-#: common.opt:1586
+#: common.opt:1590
 #, no-c-format
 msgid "Place each function into its own section."
 msgstr "Coloca cada función en su propia sección."
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr "Realiza la eliminación de subexpresiones comunes globales."
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Realiza el movimiento de la carga mejorada durante la eliminación de subexpresiones comunes globales."
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Realiza el movimiento de guardado después de la eliminación de subexpresiones comunes globales."
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Realiza la carga redundante después de la eliminación de almacenamiento en la eliminación de subexpresiones comunes globales"
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Realiza la eliminación de subexpresiones comunes globales tras la finalización de la asignación de registros."
 
-#: common.opt:1624
+#: common.opt:1628
 #, fuzzy, no-c-format
 #| msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr "-fgnat-encodings=[all|gdb|minimal]\tSelecciona el equilibrio entre codificaciones GNAT y DWARF estándar emitidos en la información de depuración."
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr "Activa in y out de la representación Graphite."
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr "Activa la transformación Graphite Identity."
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Activa las cargas de elevación adyacentes para fomentar la generación de instrucciones move condicionales."
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr "Marca todos los bucles como paralelos."
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "Activa las transformaciones anidadas de bucle.  Igual que -floop-nest-optimize."
 
-#: common.opt:1659
+#: common.opt:1663
 #, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr "Activa el intercambio de bucles en árboles."
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr "Realiza unroll-and-jam en los bucles."
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr "Activa el soporte para la memoria transaccional de GNU."
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "Usa STB_GNU_UNIQUE si lo admite el ensamblador."
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr "Activa el optimizador de anidamiento de bucles."
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr "Fuerza que los accesos de campos de bit coincidan con su anchura de tipo."
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr "Mezcla los almacenamientos adyacentes."
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr "Activa la predicción de probabilidades de ramificación."
 
-#: common.opt:1703
+#: common.opt:1707
 #, no-c-format
 msgid "Process #ident directives."
 msgstr "Procesa directivas #ident."
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Realiza la conversión de saltos condicionales a equivalentes sin ramificación."
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Realiza la conversión de saltos condicionales a ejecución condicional."
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none]\tEstablece el nivel de reúso de la pila para variables locales."
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Convierte saltos condicionales en los bucles más internos a equivalentes sin ramificación."
 
-#: common.opt:1743
+#: common.opt:1747
 #, no-c-format
 msgid "Do not generate .size directives."
 msgstr "No genera directivas .size."
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr "Realiza la inclusión en línea indirecta."
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "Activa la inclusión en línea de la la función declarada \"inline\", y desactiva todas las demás inclusiones en línea."
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Integra las funciones en sus invocadores cuando se sabe que el tamaño del código no crece."
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Integra las funciones que no se declaran \"inline\" en sus invocadores cuando es rentable."
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "Integra las funciones sólo requeridas por su invocador único."
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<número>\tLimita el tamaño de las funciones incluidas en línea a <número>."
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Coloca en línea las operaciones __atomic cuando una secuencia de instrucciones lock free está disponible"
 
-#: common.opt:1783
+#: common.opt:1787
 #, fuzzy, no-c-format
 #| msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr "-fcf-protection=[full|branch|return|none]\tInstrumenta las funciones con comprobaciones para verificar que las instrucciones de transferencia del flujo de control jump/call/return tienen objetivos válidos."
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Instrumenta funciones de entrada y salida con llamadas de análisis de perfil."
 
-#: common.opt:1810
+#: common.opt:1814
 #, fuzzy, no-c-format
 #| msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "-finstrument-functions-exclude-functions-list=nombre,... No instrumenta las funciones enlistadas."
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, no-c-format
 #| msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=fichero,... No instrumenta las funciones enlistadas en ficheros."
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr "Realiza la propagación interprocedural de las constantes."
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Realiza la clonación para hacer la propagación constante Interprocedural más fuerte."
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Realiza la propagación interprocedural de las constantes por bits."
 
-#: common.opt:1834
+#: common.opt:1838
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis."
 msgid "Perform interprocedural modref analysis."
 msgstr "Realiza el análisis interprocedural de puntero-a."
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr "Realiza la propagación de perfil interprocedural."
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr "Realiza el análisis interprocedural de puntero-a."
 
-#: common.opt:1846
+#: common.opt:1850
 #, no-c-format
 msgid "Discover pure and const functions."
 msgstr "Descubre funciones pure y const."
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Realiza plegamiento de código idéntico en funciones y variables de solo lectura."
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr "Realiza plegamiento de código idéntico en funciones."
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr "Realiza plegamiento de código idéntico en variables."
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables."
 msgid "Discover read-only and non addressable static variables."
 msgstr "Descubre variables estáticas de sólo lectura y no direccionables."
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables."
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "Descubre variables estáticas de sólo lectura y no direccionables."
 
-#: common.opt:1870
+#: common.opt:1874
 #, fuzzy, no-c-format
 #| msgid "Use caller save register across calls if possible."
 msgid "Reduce stack alignment on call sites if possible."
 msgstr "Usa registro de guarda de invocador entre llamadas si es posible."
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr "Realiza la Propagación de Rango Valor IPA."
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority]\tEstablece el algoritmo IRA a usar."
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed]\tEstablece las regiones para IRA."
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "Usa el cálculo de presión de registros basado en IRA en optimizaciones de izado RTL."
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "Usa el cálculo de presión de registros basado en IRA en optimizaciones de bucle RTL."
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr "Comparte ranuras para ahorrar registros hard diferentes."
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Comparte ranuras de pila para pseudo-registros derramados."
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<número>\tControla el nivel de mensajes de diagnóstico de IRA."
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr "Optimiza la inducción de variables en los árboles."
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Usa tablas de salto para las declaraciones switch suficientemente grandes."
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements."
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "Usa tablas de salto para las declaraciones switch suficientemente grandes."
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Genera código para las funciones aún si están completamente incluidas en línea."
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "Genera código para las funciones estáticas aunque nunca se las llame."
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr "Emite variables static const aún si no se usan."
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr "Da a los símbolos externos un subrayado inicial."
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr "Hacer rematerialización sensible a CFG en LRA."
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr "Activa las optimizaciones de tiempo de enlace."
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Optimización en tiempo de enlace con el número de trabajos paralelos o el servidor de trabajos."
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr "Espcifica el algoritmo para particionar símbolos y variables en tiempo de enlazado."
 
-#: common.opt:2004
+#: common.opt:2008
 #, fuzzy, no-c-format
 #| msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr "-flto-compression-level=<número>\tUsa el nivel de compresión de zlib <número> para IL."
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "Reporta varias estadísticas de optimización de tiempo de enlace."
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Reporta varias estadísticas de optimización de tiempo de enlace solo para WPA."
 
-#: common.opt:2020
+#: common.opt:2024
 #, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "Establece errno después de las funciones matemáticas internas."
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<número>\tNúmero máximo de errores a reportar."
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr "Reporta el alojamiento en memoria permanente."
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Reporta el alojamiento en memoria permanente solo en WPA."
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Intenta mezclar constantes idénticas y variables constantes."
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Intenta mezclar constantes idénticas a través de las unidades de compilación."
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Intenta mezclar cadenas de depuración idénticas a través de las unidades de compilación."
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<número>\tLimita los diagnósticos a <número> caracteres por línea.  0 suprime el corte de línea."
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Realiza la planificación SMS basada en módulo antes del primer paso de calendarización."
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Realiza la planificación módulo basada en SMS con movimientos permitidos de registros."
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr "Mueve las computaciones invariantes de bucles fuera de los bucles."
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr "Usa el paso de eliminación de código muerto de RTL."
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "Usa la eliminación de almacenamiento muerto de RTL."
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Activa/Desactiva la planificación tradicional en bucles que ya pasaron la calendarización módulo."
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr "Permite las excepciones síncronas que no son llamadas."
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy, no-c-format
 #| msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr "-foffload=<targets>=<options>  Especifica objetivos de descarga y opciones para ellos."
 
-#: common.opt:2087
+#: common.opt:2091
 #, fuzzy, no-c-format
 #| msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr "-foffload-abi=[lp64|ilp32]     Establece el ABI que usar en un compilador de descarga."
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr "Cuando sea posible no genera marcos de pila."
 
-#: common.opt:2104
+#: common.opt:2108
 #, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Activa todos los volcados de información de optimización en stderr."
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<type>=filename]\tVuelca los detalles de optimización del compilador."
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimiza las llamadas recursivas hermanadas y de extremo."
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr "Realiza la inclusión en línea parcial."
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Reporta la ubicación de memoria antes de la optimización interprocedural."
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr "Empaqueta juntos a los miembros de la estructura sin agujeros."
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<número>\tEstablece la alineación inicial máxima de estructuras miembro."
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr "Devuelve los agregados small en memoria, no en registros."
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr "Realiza el pelado de bucles."
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr "Activa las optimizaciones de mirilla específicas de la máquina."
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Activa un paso de mirilla RTL antes de sched2."
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Genera código independiente de posición si es posible (modo large)."
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Genera código independiente de posición para ejecutables si es posible (modo large)."
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Genera código independiente de posición si es posible (modo small)."
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Genera código independiente de posición para ejecutables si es posible (modo small)."
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr "Usa PLT para llamadas PIC (-fno-plt: carga la dirección desde GOT en el sitio de la llamada)."
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr "Especifica un plugin a cargar."
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<nom>-<clave>[=<valor>]\tEspecifica el argumento <clave>=<valor> para el plugin <nom>bre."
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr "Ejecuta la optimización comunizadora predictiva."
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Genera instrucciones de precargado, si están disponibles, para matrices en bucles."
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr "Activa el código básico de análisis de perfil del programa."
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr "Genera nombres de ruta de fuentes absolutos para gcov."
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr "Inserta el código de análisis de perfil de programa basado en arc."
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Establece el directorio de nivel principal para almacenar los datos de perfilado. El predeterminado es 'pwd'."
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy, no-c-format
 #| msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgid "Select the name for storing the profile note file."
 msgstr "Establece el directorio de nivel principal para almacenar los datos de perfilado. El predeterminado es 'pwd'."
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Activa la corrección de datos de entrada de perfilado inconsistente de flujo."
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tEstablece el método de actualización del perfil."
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Activa las opciones comunes para generar información de análisis de perfil para optimizaciones dirigidas por retroalimentación de perfil."
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Activa las opciones comunes para generar información de análisis de perfil para optimizaciones dirigidas por retroalimentación de perfili, y establece -fprofile-dir=."
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Activa las opciones comunes para realizar optimizaciones dirigidas por retroalimentación de perfil."
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Activa las opciones comunes para realizar optimizaciones dirigidas por retroalimentación de perfil, y establece -fprofile-dir=."
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr "Inserta el código para perfilar valores de expresiones."
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr "Informa sobre la coherencia del perfil."
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr "Activa reordenación de funciones que mejora ubicación de código."
 
-#: common.opt:2305
+#: common.opt:2309
 #, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr "Inserta instrucciones NOP en cada entrada de función."
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<cadena>\tHace que se pueda reproducir la compilación utilizando la <cadena>."
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr "Guarda las opciones de la línea de órdenes de gcc en el fichero objeto."
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr "Devuelve agregados small en registros."
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr "Le dice al DSE que el almacenamiento para un objeto C++ está muerto cuando el constructor comienza y cuando el destructor termina."
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Alivio de la presión de registro a través del encogimiento de rango en vivo."
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr "Realiza el paso de optimización de renombrado de registros."
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Realiza paso de optimización por fusión de instrucciones dependiente de objetivo."
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Reordena los bloques básicos para mejorar la ubicación del código."
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr "-freorder-blocks-algorithm=[simple|stc]\tEstablece el algoritmo de ordenación de bloque básico usado."
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Reordena los bloques básicos y particionar en secciones caliente y fría."
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr "Reordena las funciones para mejorar la ubicación del código."
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Ejecuta un paso de eliminación de subexpresión común después de las optimizaciones de bucles."
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Desactiva las optimizaciones que asumen la conducta de un FP que redondea por defecto."
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr "Activa la planificación entre bloques básicos."
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Activa la planificación de insn sensible a la presión de registros."
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr "Permite el movimiento especulativo de insn que no son load."
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr "Permite el movimiento especulativo de algunas loads."
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr "Permite el movimiento especulativo de más loads."
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<número>\tEstablece el nivel de detalle del planificador."
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Si se calendariza después de la recarga, hace la planificación de superbloque."
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr "Recalendariza las instrucciones antes del alojamiento de registros."
 
-#: common.opt:2449
+#: common.opt:2453
 #, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr "Recalendariza las instrucciones después del alojamiento de registros."
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Calendariza instrucciones usando el algoritmo de planificación selectivo."
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr "Ejecuta la planificación selectiva después de recargar."
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr "Corre autotests usando la ruta dada para localizar los ficheros de test."
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Realiza el `pipelining' de software de los bucles internos durante la planificación selectiva."
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Realiza el `pipelining' de software de los bucles externos durante la planificación selectiva."
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Recalendariza las regiones `pipelined' sin `pipelining'."
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr "Permite interponer función (o variables) por otras con semántica diferente (o inicializador) respectivamente por enlazador dinámico."
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr "Permite la planificación prematura de insns encoladas."
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<número>\tEstablece el número de insns encoladas que se pueden calendarizar prematuramente."
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Establece la revisión de distancia de dependencias en la planificación prematura de insns encoladas."
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<número>\tEstablece la revisión de distancia de dependencias en la planificación prematura de insns encoladas."
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Activa la heurística de grupo en el planificador."
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Activa la heurística de ruta crítica en el planificador."
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Activa la heurística de instrucción especulativa en el planificador."
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Activa la heurística de rango en el planificador."
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Activa la heurística de última instrucción en el planificador."
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Activa la heurística de cuenta dependiente en el planificador."
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr "Accede datos en la misma sección que los puntos de anclaje compartidos."
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Activa el paso de Eliminación de Extensiones Redundantes."
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Muestra los números de columna en los diagnósticos, cuando estén disponible.  Activado por defecto."
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Emite prólogos de función sólo después de que las partes de la función que los necesitan, en vez de al principio de la función."
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "Estrecha-envuelve partes del prólogo y epílogo por separado."
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Desactiva las optimizaciones observables con IEEE señalando NaNs."
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Desactiva las optimizaciones de coma flotante que ignoran el signo de IEEE para cero."
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr "Convierte las constantes de coma flotante a constantes de precisión simple."
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Divide los tiempos de vida de las variables de inducción cuando se desenrollen los bucles."
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "Genera marcos de pila discontiguos."
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr "Divide los tipos anchos en registros independientes."
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy, no-c-format
 #| msgid "Split wide types into independent registers."
 msgid "Split wide types into independent registers earlier."
 msgstr "Divide los tipos anchos en registros independientes."
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Activa la propagación hacia atrás de propiedades en uso a nivel SSA."
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr "Optimiza patrones condicionales usando nodos SSA PHI."
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Optimiza la cantidad de registros stdarg guardados en pila al principio de la función."
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Aplica la expansión de variables cuando se desenrollan los bucles."
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tInserta código de revisión de la pila en el programa."
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Inserta código de revisión de la pila en el programai.  Igual que -fstach-check=specific."
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\tCaptura si la pila pasa del <registro>."
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<nombre>\tCaptura si la pila pasa del símbolo <nombre>."
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "Usa propolice como un método de protección de pila."
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr "Usa un método de protección de pila para cada función."
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Usa un método de protección de pila inteligente para ciertas funciones."
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Usa método de protección de pila solo para funciones con el atributo stack_protect."
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr "Información de uso de pila de salida basada por función."
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr "Asume que se aplican las reglas estrictas de alias."
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Trata el desbordamiento con signo como indefinido.  Negado como -fwrapv -fwrapv-pointer."
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr "Implementa operaciones __atomic mediante llamadas de biblioteca a funciones __sync antiguas."
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr "Busca errores de sintaxis, y termina."
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr "Crea ficheros de datos necesarios para \"gcov\"."
 
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr "Realiza optimizaciones de hilado de saltos."
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr "Reporta el tiempo tomado por cada paso del compilador."
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr "Registra los tiempos tomados por subfases por separado."
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tEstablece el modelo de generación de código por defecto para almacenamiento thread-local."
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Reordena las funciones de nivel superior, variables y asms."
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr "Realiza la formación de superbloques a través de la duplicación de colas."
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr "Para objetivos que normalmente necesitan trampolines para las funciones anidadas, siempre los genera en lugar de usar descriptores."
 
-#: common.opt:2722
+#: common.opt:2726
 #, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "Asume que las operaciones de coma flotante pueden atrapar."
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Atrapar desbordamientos signed en adición, sustracción y multiplicación."
 
-#: common.opt:2730
+#: common.opt:2734
 #, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Activa la optimización SSA-CCP en árboles."
 
-#: common.opt:2734
+#: common.opt:2738
 #, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Activa la optimización SSA-BIT-CCP en árboles."
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr "Activa la copia de encabezado de bucles en árboles."
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "Activa coalescencia SSA de variables de usuario."
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr "Activa la propagación de copia en árboles."
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr "Transforma los almacenamientos condicionales a incondicionales."
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr "Realiza la conversión de las inicializaciones de switch."
 
-#: common.opt:2774
+#: common.opt:2778
 #, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Activa la optimización de eliminación de código muerto SSA en árboles."
 
-#: common.opt:2778
+#: common.opt:2782
 #, no-c-format
 msgid "Enable dominator optimizations."
 msgstr "Activa las optimizaciones dominadoras."
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "Activa la mezcla de colas en árboles."
 
-#: common.opt:2786
+#: common.opt:2790
 #, no-c-format
 msgid "Enable dead store elimination."
 msgstr "Activa la eliminación de almacenamiento muerto."
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "Activa la propagación hacia adelante en árboles."
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Activa la Eliminación de Redundancia Completa en árboles."
 
-#: common.opt:2798
+#: common.opt:2802
 #, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "Activa la optimizaciones de longitud de cadenas en árboles."
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detecta rutas que disparan comportamiento erróneo o indefinido debido a desreferencia de puntero nulo.  Aisla esas rutas del flujo de control principal y convierte la sentencia con comportamiento erróneo o indefinido en una trampa."
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detecta rutas que disparan comportamiento erróneo o indefinido debido a un uso indebido de un valor nuloen un atributo returns_nonnull o nonnull.  Aisla esas rutas del flujo de control principal y convierte la sentencia con comportamiento erróneo o indefinido en una trampa."
 
-#: common.opt:2815
+#: common.opt:2819
 #, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "Activa la distribución de bucles en árboles."
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Activa la distribución de bucles por patrones transformados en una llamada a biblioteca."
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr "Permite el movimiento invariante de bucles en árboles."
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr "Crea variables de inducción canónica en los bucles."
 
-#: common.opt:2835
+#: common.opt:2839
 #, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr "Activa las optimizaciones de bucles a nivel de árbol."
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "-ftree-parallelize-loops=<número>\tActiva la paralelización automática de bucles."
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Activa las cargas de elevación de punteros condicionales."
 
-#: common.opt:2847
+#: common.opt:2851
 #, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Activa las optimizaciones SSA-PRE en árboles."
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr "En optimización SSA-PRE en árboles, activa eliminación de redundancia parcial-parcial."
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Realiza el análisis puntero-a función-local en árboles."
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr "Activa la reasociación a nivel de árbol."
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr "Activa el hundimiento de código SSA en árboles."
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr "Realiza reducción de fuerza de línea directa."
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr "Realiza el reemplazo escalar de agregados."
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Reemplaza expresiones temporales en el paso SSA->normal."
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Realizar la división de rango vivo durante el paso SSA->normal."
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr "Realiza la Propagación de Rango Valor en árboles."
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr "Divide las rutas que llevan a bordes traseros de bucle."
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr "Asume que las declaraciones comunes pueden sustituirse por las que tienen un array postrero mayor."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr "Compila la unidad de compilación completa a la vez."
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Realiza el desenrollamiento del bucle cuando se conoce la cuenta de iteración."
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr "Realiza el desenrollamiento del bucle para todos los bucles."
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Permite la optimización para la aritmética de coma flotante la cual puede cambiar el resultado de la operación debido a redondeo."
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Igual que -fassociative-math para las expresiones que incluyen división."
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Permite optimizaciones matemáticas que pueden violar los estándares IEEE ó ISO."
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Realiza la eliminación de opciones de bucle."
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Realiza la división de bucles."
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Sólo genera tablas de desenredo para manejo de excepciones."
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Usa el enlazador bfd eb lugar del predeterminado."
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Usa el enlazador de oro eb lugar del predeterminado."
 
-#: common.opt:2964
+#: common.opt:2968
 #, fuzzy, no-c-format
 #| msgid "Use the gold linker instead of the default linker."
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Usa el enlazador de oro eb lugar del predeterminado."
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Realiza seguimiento de variables."
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Realiza seguimiento de variables con asignación de anotaciones."
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Cambia -fvar-tracking-assignments."
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Realiza el seguimiento de variables y también marca las variables que no se inicializaron."
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Activa la vectorización en árboles."
 
-#: common.opt:3011
+#: common.opt:3015
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Activa la vectorización de bucles en árboles."
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Activa la vectorización de bloque básico (SLP) en árboles."
 
-#: common.opt:3019
+#: common.opt:3023
 #, fuzzy, no-c-format
 #| msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr "Especifica el modelo de coste para vectorización. -fvect-cost-model=[unlimited|dynamic|cheap]\tEspecifica el modelo de coste para vectorización."
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, no-c-format
 #| msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tEspecifica el modelo de coste de la vectorización para código marcado con directiva simd."
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Activa el modelo de coste de vectorizador dinámico.  Se preserva por compatibilidad hacia atrás."
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Activa la propagación de copia de la información escalar-evolución."
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Agrega comentarios extra a la salida de ensamblador."
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tEstablece la visibilidad de símbolos por defecto."
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "Valida los punteros vtable antes de usarlos."
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Contadores de verificación de vtable de salida."
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Información sobre los conjuntos de vectores de verificación de vtable de salida."
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Usa perfiles de valor de expresión en las optimizaciones."
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Construye redes y divide usos no relacionados de una sola variable."
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Activa la eliminación de código muerto condicional para llamadas internas."
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Realiza optimizaciones del programa completo."
 
 # wraps around? No entiendo bien. cfuga
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Asume que el desbordamiento de punteros se envuelve."
 
 # wraps around? No entiendo bien. cfuga
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Asume que el desbordamiento aritmético con signo se envuelve."
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Pone los datos inicializados a cero en la sección bss."
 
-#: common.opt:3135
+#: common.opt:3139
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls."
 msgid "Clear call-used registers upon function return."
 msgstr "Guarda registros alrededor de llamadas de función."
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Genera información de depuración en el formato por defecto."
 
-#: common.opt:3143
+#: common.opt:3147
 #, fuzzy, no-c-format
 #| msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "Asume soporte del ensamblador para las directivas .loc (DWARF2+)"
 
-#: common.opt:3147
+#: common.opt:3151
 #, fuzzy, no-c-format
 #| msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "Asume soporte del ensamblador para visualización en las directivas .loc (DWARF2+)"
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Registro DW_AT_decl_column y DW_AT_call_column en DWARF."
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Genera información de depuración en la versión predeterminada del formato DWARF."
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Genera información de depuración en el formato DWARF v2 (o posterior)."
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Genera información de depuración en el formato extendido por defecto."
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 #| msgid "Generate extended entry point information for inlined functions"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Genera información extendida sobre el punto de entrada para funciones en línea"
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "No genera nombres públicos DWARF y secciones de tipos públicos."
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Genera nombres públicos DWARF y secciones de tipos públicos."
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Genera nombres públicos DWARF y secciones de tipos públicos con extensiones GNU."
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Guarda las opciones de la línea de órdenes de gcc en DW_AT_producer de DWARF."
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Genera información de depuración en ficheros .dwo separados."
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Genera información de depuración en el formato STABS."
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Genera información de depuración en el formato STABS extendido."
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "No emite adiciones DWARF más allá de la versión seleccionada."
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Cambia la generación de información de depuración."
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Genera información de depuración en el formato VMS."
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Genera información de depuración en el formato XCOFF."
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Genera información de depuración en el formato XCOFF extendido."
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Genera secciones de depuración comprimidas."
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<formato>\tGenera secciones de depuración comprimidas en formato <formato>."
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tDefine <dir> como el directorio de plugins por defecto."
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <dir>\tDefine <dir> como el subdirectorio de inclusión de multilib."
 
-#: common.opt:3320
+#: common.opt:3324
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <fichero>\tColoca la salida en el <fichero>."
 
-#: common.opt:3324
+#: common.opt:3328
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Activa el análisis de perfil de las funciones."
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Como -pedantic pero los muestra como errores."
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "No muestra las funciones compiladas o el tiempo transcurrido."
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Activa la salida detallada."
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Muestra la versión del compilador."
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Suprime avisos."
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Crea una biblioteca compartida."
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "No genera un ejecutable independiente de posición enlazado dinámicamente."
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Genera un ejecutable independiente de posición enlazado dinámicamente."
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Genera un ejecutable independiente de posición estático."
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Usa registro de guarda de invocador entre llamadas si es posible."
@@ -19457,1130 +19458,1140 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr "Número máximo de argumentos que un PHI puede tener antes de que el hilador FSM no intente hacer hilo a través de su bloque."
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr "Factor de escala que se aplicará al número de bloques en un camibo de hilo cuando se compara con el número de sentencias (escaladas)."
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr "Factor de escala que se aplicará al número de sentencias en un camino de hilo cuando se compara con el número de bloques (escaladas)."
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "La tasa de intervalo para la cuenta de ejecución de bordes críticos que permitan la eliminación de redundancia después de la recarga."
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "La tasa de intervalo para realizar la eliminación parcial de redundancia después de la recarga."
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr "Factor de escala en el cálculo de la distancia máxima a la cual se puede mover una expresión por optimizaciones GCSE."
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr "Costo al cual las optimizaciones GCSE no restringirán la distancia que puede viajar una expresión."
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "Expansión mínima de la pila para iniciar la recolección de basura, como un porcentaje del tamaño total de la pila."
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "Tamaño mínimo de la pila antes de comenzar a recolectar basura, en kilobytes."
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr "Número máximo de arrays por scop."
 
-#: params.opt:210
+#: params.opt:215
 #, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr "Número máximo de parámetros en un SCoP."
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal count of repetitions of basic block in program given basic block needs to have to be considered hot (used in non-LTO mode)."
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "La selección de fracción de la cuenta maximal de repeticiones del bloque básico en el bloque básico dado de programa que necesita para ser considerado caliente (utilizado en modo no LTO)."
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot."
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "La selección de fracción de la frecuencia máxima de ejecuciones de bloque básico en la función dada que el bloque básico necesita para ser considerado caliente."
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "Cuánto puede crecer la unidad de compilación dada a causa de la inclusión en línea (en porcentaje)."
 
-#: params.opt:242
+#: params.opt:247
 #, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "El límite superior para compartir constantes enteras."
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr "Rango de evaluación de oportunidad ipa-cp que aún se considera beneficioso para clonar."
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr "Bonificación de tiempo de compilación que IPA-CP asigna a los candidatos que dan a conocer los límites o los pasos de los bucles."
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions."
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "La máxima profundidad para la inclusión en línea recursiva para funciones incluidas en línea."
 
-#: params.opt:258
+#: params.opt:263
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Incluir en línea recursivamente solo cuando la probabilidad de que la llamada se ejecute exceda el parámetro."
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr "Penalización porcentual que recibirán las funciones recursivas cuando se evalúen para clonación."
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr "Penalización porcentual que recibirán las funciones que contien una sola llamada a otra función cuando se evalúen para clonación."
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "Cuánto puede crecer la unidad de compilación dada a causa de la propagación constante interprocedural (en porcentaje)."
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large."
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "El tamaño de la unidad de traducción que será considerado grande."
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr "Tamaño máximo de una lista de valores asociada con cada parámetro para propagación constante entre procedimientos."
 
-#: params.opt:282
+#: params.opt:287
 #, fuzzy, no-c-format
 #| msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr "Número máximo de elementos de contenido agregado de un parámetro en funciones de salto y celosías."
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr "Número máximo de sentencias que visitará el análisis de parámetros formales de IPA basado en el análisis de alias de una función dada."
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr "Número máximo de elementos de contenido agregado de un parámetro en funciones de salto y celosías."
 
-#: params.opt:294
+#: params.opt:299
 #, fuzzy, no-c-format
 #| msgid "Maximum number of conditional store pairs that can be sunk."
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "Número máximo de pares de almacenamiento condicional que se pueden hundir."
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr "El crecimiento máximo permitido del número y el tamaño total de los parámetros nuevos ipa-sra que reemplazan un puntero a un agregado con."
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr "El número de registros conservados sin uso en cada clase por el movimiento invariante del bucle."
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr "Tamaño máximo de la tabla de conflictos en MB."
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr "Número de bucles máximo para el RA regional."
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "Si el número de candidatos en el conjunto es menor, siempre se tratará de eliminar los ivs sin usar durante su optimización."
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "Límite en el número de candidatos bajo el cual todos los candidatos se consideran en optimizaciones iv."
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "Límite en el número de usos de iv en bucles optimizados en optimizaciones iv."
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr "El tamaño de la línea del caché L1."
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr "El tamaño del caché L1i."
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr "El tamaño del caché L2."
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Máximo crecimiento causado por la inclusión en línea de una función grande (en porcentaje)."
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr "El tamaño del cuerpo de la función que será  considerado grande."
 
-#: params.opt:366
+#: params.opt:371
 #, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "El tamaño del marco de la pila que será considerado grande."
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Máximo crecimiento de marco de pila causado por la inclusión en línea (en porcentaje)."
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr "El tamaño de la unidad de traducción que será considerado grande."
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "El coste mínimo de una expresión costosa en el movimiento invariante del bucle."
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr "Verdadero si una operación de non-short-circuit es óptima."
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr "Tamaño de bloques para el bloqueo de bucles."
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "El número máximo de instrucciones en anidamiento de bucle para intercambio de bucle."
 
-#: params.opt:398
+#: params.opt:403
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically."
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "El número máximo de iteraciones de bucle que se predicen estáticamente."
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr "Número máximo de bloques básicos en bucles para movimiento invariante de bucle."
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr "Número máximo de referencia de datos en bucles para construir dependencias de datos de bucles."
 
-#: params.opt:410
+#: params.opt:415
 #, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "El número máximo de instrucciones en un bucle interior que se consideran para versionar."
 
-#: params.opt:414
+#: params.opt:419
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "El número máximo de instrucciones ien un bucle exterior que se consideran para versionar, por encima de las instrucciones en los bucles interiores."
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr "El número máximo de pseudos de recarga que se tienen en cuenta durante el vaciado de pseudos de no recarga."
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr "Tamaño maximal de una partición para LTO (en instrucciones estimadas)."
 
-#: params.opt:430
+#: params.opt:435
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP."
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr "número máximo de parámetros en un SCoP."
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr "Tamaño minimal de una partición para LTO (en instrucciones estimadas)."
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr "Número de particiones en las que se debe dividir el programa."
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "El número máximo de instrucciones para considerar el desenrollo en un bucle en promedio."
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr "El número máximo de intentos de combinar insns para combinar."
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "La profundidad máxima de un bucle anidado que nosotros pelamos completamente."
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "El número máximo de pelados en un solo bucle que está completamente pelado."
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "El número máximo de insns en un bucle completamente pelado."
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "El número máximo de bordes entrantes para considerar el salto cruzado."
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr "El número máximo de instrucciones que CSE procesa antes de descargar."
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr "La longitud máxima de la ruta considerada en cse."
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr "El número máximo de ubicaciones grabadas por cselib."
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr "Máx. número de marcadores de depuración para expandir o poner en línea."
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "El número máximo de instrucciones para considerar el llenado de una ranura de retraso."
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "El número máximo de instrucciones para considerar la búsqueda de información de registros en vivo exacta."
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr "Número máximo de almacenamientos locales activos en la eliminación de almacenamiento muerto RTL."
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "El número máximo de inclusiones de instrucciones en línea anidadas realizado por el inlineador temprano."
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "El número máximo de campos en una estructura antes de que el análisis de punteros trate a la estructura como una sola variable."
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr "Número máximo de bloques básicos en un camino de hilo de salto de máquina de estados."
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr "Número máximo de instrucciones que se copiarán cuando se dupliquen bloques en un camino de hilo de salto de máquina de estados."
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "Número máximo de caminos de hilo de salto nuevos que se crearán para una máquina de estados."
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "La tasa máxima de inserciones para borrados de expresiones en GCSE."
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE."
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "La cantidad máxima de memoria a ser asignada por GCSE."
 
 # 'desfactorizar' no me gusta. ¿Alguna sugerencia? - cfuga
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "El número máximo de insns a duplicar al desfactorizar gotos calculados."
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "El factor de expansión máximo al copiar bloques básicos."
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr "Profundidad máxima de la búsqueda en el árbol dominador por expresiones para levantar."
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "El número máximo de instrucciones cuando se hace inclusión en línea automáticamente."
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "El número máximo de instrucciones que una función incluida en línea puede crecer a través de inclusión en línea recursiva."
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "El número máximo de instrucciones que una función que no se incluye en línea puede crecer a través de inclusión en línea recursiva."
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "El número máximo de instrucciones en una sola función elegible para inclusión en línea."
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr "El número máximo de instrucciones cuando se hace inclusión en línea por tamaño."
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "El número máximo de instrucciones cuando se hace inclusión en línea de funciones pequeñas automáticamente."
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "La máxima profundidad para la inclusión en línea recursiva para funciones incluidas en línea."
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "La máxima profundidad para la inclusión en línea recursiva para funciones que no son incluidas en línea."
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Número máximo de operaciones isl; 0 significa que no hay límite"
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "Límite en el coste de una expresión para calcular el número de iteraciones."
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "Límite en el número de iteraciones que evalúa el algoritmo de análisis de número de iteraciones de fuerza bruta."
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "Número máximo de sentencias permitidas en un bloque que necesitan ser duplicadas al hacer hilos de saltos."
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "El número máximo de nodos RTL que se pueden grabar como el último valor del combinador."
 
 # 'desfactorizar' no me gusta. ¿Alguna sugerencia? - cfuga
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "El número máximo de instrucciones en encabezamiento de bucle a duplicar en el paso de encabezamientos de bucles."
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "El número máximo de intentos hacia atrás que debe hacer el planificador cuando planifique un bucle módulo."
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr "Longitud máxima del conjunto antic parcial al realizar pre optimización de árbol."
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "El número máximo de ramificaciones en la ruta hacia una secuencia pelada."
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "El número máximo de pelados en un solo bucle."
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr "El número máximo de insns en un bucle pelado."
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "La longitud máxima de la lista de operaciones pendientes del planificador."
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "El número máximo de bloques en una región para ser considerada para planificación de interbloqueo."
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "El número máximo de insns en una región para ser consideradas para planificación de interbloqueo"
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr "Máxima profundidad de cadenas sqrt que se utilizará cuando se sintetice la exponenciación mediante una constante real."
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "El número máximo de iteraciones de bucle que se predicen estáticamente."
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "El número máximo de instrucciones para buscar hacia atrás al buscar por una recarga equivalente."
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Número máximo de insns en bloque básico que se consideran para conversión-if RTL."
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr "Coste máximo permitido para la secuencia que generaría el paso de conversión-if RTL para una rama que se considera predecible."
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr "Coste máximo permitido para la secuencia que generaría el paso de conversión-if RTL para una rama que se considera no predecible."
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "El número máximo de iteraciones a través de CFG para extender regiones."
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "El retraso máximo de conflicto para que una insn sea considerada para movimiento especulativo."
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "El número máximo de instrucciones listas para ser ejecutadas que el planificador tendrá en cuenta durante el primer paso de planificación."
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr "Longitud máxima de los rastreos de candidatos para reducción de fuerza de línea directa."
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr "Número máximo de definiciones posibles visitadas cuando se desvirtualiza especulativamente."
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr "Máxima profundidad permitida de recursividad cuando se consulta una propiedad de un nombre SSA."
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "Número máximo de almacenamientos constantes que hay que mezclar en el paso de mezcla de almacenamientos."
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "Número máximo de pares de almacenamiento condicional que se pueden hundir."
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 #| msgid "Maximum number of constant stores to merge in the store merging pass."
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "Número máximo de almacenamientos constantes que hay que mezclar en el paso de mezcla de almacenamientos."
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr "Cantidad máxima de bbs similares con las cuales comparar un bb."
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr "Cantidad máxima de iteraciones del paso sobre una función."
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr "Número máximo de cadenas para las que el paso de optimización de strlen rastreará longitudes de cadenas."
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr "El número máximo de desenrollos de un solo bucle."
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "El número máximo de instrucciones para considerar el desenrollo en un bucle."
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "El número máximo de insns en un bucle sin switch."
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "El número máximo de eliminación de opciones en un solo bucle."
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "Si se usa -fvariable-expansion-in-unroller, el número máximo de veces que una variable individual se expandirá durante el desenrollo de bucles."
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr "Profundidad máxima de recursión para expandir expresiones de rastreo de variables."
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr "Máximo tamaño de lista loc para que deban añadirse ops inversas."
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr "Tamaño máximo de las tablas de dispersión de rastreo de variables."
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr "Número máximo de aserciones que hay que añadir a lo largo del borde predefinido de una sentencia switch durante VRP."
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "El número máximo de instrucciones coincidentes para considerar el salto cruzado."
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Incluir en línea recursivamente solo cuando la probabilidad de que la llamada se ejecute exceda el parámetro."
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr "Tasa mínima de insns a precargar para activar la precarga para un bucle con una cuenta de viajes desconocida."
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr "El UID mínimo a usar para una insn que no es de depuración."
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr "Tamaño mínimo de las variables que participan en la compartición de ranuras de pila cuando no hay optimización."
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "La probabilidad mínima de alcanzar un bloque fuente para la planificación especulativa entre bloques."
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "Si se usa -ftree-vectorize, el límite de bucle mínimo de un bucle para considerarse en la vectorización."
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr "Tamaño de la porción de planificación omp para bucles paralelizadps por parloops."
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Número mínimo de iteraciones por thread de un bucle paralelizado interior."
 
-#: params.opt:790
+#: params.opt:808
 #, fuzzy, no-c-format
 #| msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr "Tamaño de la porción de planificación omp para bucles paralelizadps por parloops."
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr "Probabilidad máxima de la entrada BB de la región de división (en porcentaje relativo a la entrada BB de la función) para que suceda la inclusión en línea parcial."
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "Salida estimada máxima de la ramificación considerada predecible."
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "El número de insns ejecutadas antes de completar la precarga."
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr "Tasa mínima de insns a ops de mem para activar la precarga en un bucle."
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr "Utiliza id de función interno en búsqueda de perfil."
 
-#: params.opt:840
+#: params.opt:858
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of a loop nest we completely peel."
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "La profundidad máxima de un bucle anidado que nosotros pelamos completamente."
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr "Número máximo de desambiguaciones que realizar por cada acceso a memoria."
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "Límite en la complejidad de expresiones en el analizador escalar de evoluciones."
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "Límite en el tamaño de expresiones usadas en el analizador escalar de evoluciones."
 
-#: params.opt:856
+#: params.opt:874
 #, fuzzy, no-c-format
 #| msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into; at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr "Indicador de control del modelo de planificador de prebuscador automático hardware.  Número de ciclos hacia delante que el modelo examina: con '0' solo se activa la heurística de ordenación de instrucciones.  Desactivado de forma predeterminada."
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr "La distancia mínima entre store y load en posible conflicto."
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr "Qué algoritmo -fsched-pressure aplicar."
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "La probabilidad mínima de éxito de especulación (en porcentaje), para que esa insn especulativa se calendarize."
 
 # TODO Mejorar traducción de 'across it'.
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr "Probabilidad mínima que debe tener un borde para que el planificador guarde su estado a través de él."
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "El número máximo de instrucciones en la lista ready que se consideran elegibles para renombrado."
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr "El tamaño máximo de la ventana de búsqueda hacia adelante de la planificación selectiva."
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "El número máximo de veces que se puede planificar una insns."
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr "El número de precargas que se pueden ejecutar simultánamente."
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr "Frecuencia de ejecución relativa al bloque objetivo (como un porcentaje) requerida para hundir una declaración."
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "El número de ciclos que el planificador de cambio de módulo considera al revisar conflictos utilizando DFA."
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "Umbral en el número promedio de bucles considerado por el planificador de cambio de módulo."
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "Factor para ajustar el límite superior que el planificador de cambio de módulo utiliza para planificar un bucle."
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr "El valor mínimo de la cuenta de etapa que el planificador módulo swing generará."
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr "Máximo tamaño, en unidades de almacenamiento, de un agregado para tenerlo en cuenta en escalarización cuando se compila para tamaño."
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr "Máximo tamaño, en unidades de almacenamiento, de un agregado para tenerlo en cuenta en escalarización cuando se compila para velocidad."
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 #| msgid "The maximum number of stmts in loop nest for loop interchange."
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "El número máximo de instrucciones en anidamiento de bucle para intercambio de bucle."
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "El límite inferior para considerar un almacenamiento temporal para protección contra destrucción de pila."
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr "Tamaño de guarda de la pila expresado como potencia de dos en bytes."
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr "Intervalo en el cual sondear la pila expresado como potencia de dos en bytes."
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr "Permitir que el paso de mezcla de almacenamientos introduzca almacenamientos desalineados si es legal hacerlo."
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "La tasa máxima entre el tamaño de la matriz y las ramificaciones switch para que tenga lugar una conversión switch."
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 #| msgid "Maximum number of parameters in a SCoP."
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "Número máximo de parámetros en un SCoP."
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 #| msgid "Maximum number of parameters in a SCoP."
 msgid "Maximum number of references stored in each modref base."
 msgstr "Número máximo de parámetros en un SCoP."
 
-#: params.opt:960
+#: params.opt:978
 #, fuzzy, no-c-format
 #| msgid "Maximum number of constant stores to merge in the store merging pass."
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "Número máximo de almacenamientos constantes que hay que mezclar en el paso de mezcla de almacenamientos."
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 #| msgid "Maximum number of disambiguations to perform per memory access."
 msgid "Maximum number of tests performed by modref query."
 msgstr "Número máximo de desambiguaciones que realizar por cada acceso a memoria."
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, fuzzy, no-c-format
 #| msgid "Maximum number of queries into the alias oracle per store."
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "El número máximo de consultas al oráculo de alias por almacenamiento."
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr "Tamaño en bytes después del cual los agregados thread-local se deben instrumentar con las funciones de registro en lugar de pares save/restore."
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "El porcentaje de la función, ponderado por la frecuencia de ejecución, que debe ser cubierto por la información de rastreo. Se utiliza cuando la retroalimentación de análisis de perfil no está disponible."
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "El porcentaje de la función, ponderado por la frecuencia de ejecución, que debe ser cubierto por la información de rastreo. Se utiliza cuando está disponible la retroalimentación del análisis de perfil."
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Máximo crecimiento de código causado por duplicación de colas (en porcentaje)."
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "Detener el crecimiento hacia adelante si la probabilidad del mejor borde es menor que este umbral (en porcentaje). Se utiliza cuando la retroalimentación de análisis de perfil no está disponible."
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "Detener el crecimiento hacia adelante si la probabilidad del mejor borde es menor que este umbral (en porcentaje). Se utiliza cuando la retroalimentación de análisis de perfil está disponible."
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "Detener el crecimiento inverso si la probabilidad inversa del mejor borde es menor que este umbral (en porcentaje)."
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr "Establece el número máximo de instrucciones ejecutadas en paralelo en el árbol de reasociación. Si es 0, usa la heurística dependiente del objetivo."
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 #| msgid "Emit implicit instantiations of templates."
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "Emite instanciaciones implícitas de plantillas."
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr "Número máximo de llamadas anidadas para buscar dependencias de control durante el análisis de variables sin inicializar."
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "Instrucción contabilizada para el prólogo y epílogo de la función y otras sobrecargas."
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "Tiempo contabilizado para el prólogo y epílogo de la función y otras sobrecargas."
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, fuzzy, no-c-format
 #| msgid "The minimum fraction of profile runs a given basic block execution count must be not to be considered unlikely."
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr "Fracción mínima de ejecuciones de perfil que el número de ejecuciones de un bloque básico dado no debe alcanzar para ser considerado improbable."
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr "Máximo factor de desenrrollado para la transformación unroll-and-jam."
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr "Usa instrucciones de envenamiento/desenvenenamiento directo para variables iguales o menores que este número."
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr "Decide si se usan tipos canónicos."
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "Activa la vectorización de epílogos de bucles usando un tamaño menor de vector."
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr "Número máximo de pelados de bucle para mejorar alineación de las referencias de datos en un bucle."
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "Límite en el número de revisiones de tiempo de ejecución insertadas por las versiones de bucle del vectorizador para revisión de alias."
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Límite en el número de revisiones de tiempo de ejecución insertadas por las versiones de bucle del vectorizador para revisión de alineación."
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20611,7 +20622,7 @@ msgid "expected boolean type"
 msgstr "se esperaba un tipo booleano"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "se esperaba un entero"
@@ -20677,7 +20688,7 @@ msgstr "faltan argumentos"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "demasiados argumentos"
@@ -21033,7 +21044,7 @@ msgstr "Se hace caso omiso del atributo %qE debido a un conflicto con el atribut
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "declaración previa aquí"
@@ -21089,7 +21100,7 @@ msgstr "se descartan los atributos de tipo después de que el tipo ya se defini
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -21118,20 +21129,20 @@ msgstr "se descartan los atributos de tipo después de que el tipo ya se defini
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21142,8 +21153,8 @@ msgstr "se descarta el atributo %qE"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "falta el atributo %<target%> para %qD multiversionado"
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "declaración previa de %qD"
@@ -21153,61 +21164,61 @@ msgstr "declaración previa de %qD"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D se declaró anteriormente con el atributo dllimport: se descarta dllimport"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D se redeclara sin el atributo dllimport después de ser referenciado con enlace dllimport"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D se redeclara sin el atributo dllimport: se descarta el dllimport previo"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared as  dllimport: attribute ignored"
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "la función inline %q+D se declara como dllimport: se descarta el atributo"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "la definición de la función %q+D se marca como dllimport"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "la definición de la variable %q+D se marca como dllimport"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "se requiere enlace externo para el símbolo %q+D debido al atributo %qE"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qE implica visibilidad por defecto, pero %qD ya se había declarado con una visibilidad diferente"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "%qD target declared here"
 msgstr "%qD se declaró aquí"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -21320,7 +21331,7 @@ msgstr "el argumento %qD se declara aquí"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "el desplazamiento %qwi fuera de los límites de la constante de cadena"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -21346,513 +21357,513 @@ msgstr "el tercer argumento de %<__builtin_prefetch%> debe ser una constante"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "el tercer argumento para %<__builtin_prefetch%> es no válido; se usa cero"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qD declared here"
 msgid "source object declared here"
 msgstr "el argumento %qD se declara aquí"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "source object allocated here"
 msgstr "se declara aquí"
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "%K%qD: el tamaño especificado %E excede el tamaño máximo %E del objeto"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr "%K%qD: el tamaño especificado %E excede el tamaño máximo %E del objeto"
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "%K%qD: el tamaño especificado %E excede el tamaño máximo %E del objeto"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr "%K%qD: el tamaño especificado %E excede el tamaño máximo %E del objeto"
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "%K%qD: el tamaño especificado entre %E y %E excede el tamaño de objeto máximo %E"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD: el tamaño especificado entre %E y %E excede el tamaño de objeto máximo %E"
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "%K%qD: el tamaño especificado entre %E y %E excede el tamaño de objeto máximo %E"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD: el tamaño especificado entre %E y %E excede el tamaño de objeto máximo %E"
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified bound %E exceeds destination size %E"
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "destination object declared here"
 msgstr "%qD se declaró aquí"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 #| msgid "a function-definition is not allowed here"
 msgid "destination object allocated here"
 msgstr "una definición de función no se permite aquí"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E bytes from a region of size %E"
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr "%K%qD leyendo %E bytes en una región de tamaño %E"
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E bytes from a region of size %E"
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr "%K%qD leyendo %E bytes en una región de tamaño %E"
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E bytes from a region of size %E"
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr "%K%qD leyendo %E bytes en una región de tamaño %E"
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr "directiva %<%.*s%> escribiendo %wu byte en una región de tamaño %wu"
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 #| msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir %E byte en una región de tamaño %E desborda el destino"
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr "directiva %<%.*s%> escribiendo %wu byte en una región de tamaño %wu"
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir %E bytes en una región de tamaño %E desborda el destino"
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr "directiva %<%.*s%> escribiendo %wu byte en una región de tamaño %wu"
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 #| msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir %E byte en una región de tamaño %E desborda el destino"
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr "directiva %<%.*s%> escribiendo %wu byte en una región de tamaño %wu"
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 #| msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir %E byte en una región de tamaño %E desborda el destino"
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir %E bytes o más en una región de tamaño %E desborda el destino"
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir %E bytes o más en una región de tamaño %E desborda el destino"
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir entre %E y %E bytes en una región de tamaño %E desborda el destino"
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir entre %E y %E bytes en una región de tamaño %E desborda el destino"
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E bytes from a region of size %E"
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr "%K%qD leyendo %E bytes en una región de tamaño %E"
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr "%K%qD leyendo %E bytes en una región de tamaño %E"
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%Kreading %E byte from a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
@@ -21861,7 +21872,7 @@ msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] "%K%qD leyendo %E byte en una región de tamaño %E"
 msgstr[1] "%K%qD leyendo %E bytes en una región de tamaño %E"
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E byte from a region of size %E"
 #| msgid_plural "%K%qD reading %E bytes from a region of size %E"
@@ -21870,183 +21881,183 @@ msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] "%K%qD leyendo %E byte en una región de tamaño %E"
 msgstr[1] "%K%qD leyendo %E bytes en una región de tamaño %E"
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu bytes into a destination of size %wu"
 msgid "at offset %s into destination object %qE of size %s"
 msgstr "%qE manda %wu bytes a un destino de tamaño %wu"
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr "%qD se declaró aquí"
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "at offset %s into source object %qE of size %s"
 msgstr "en una llamada a la función %qD declarada aquí"
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr "%qD se declaró aquí"
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr "el límite de %K%qD %E especificado es igual al tamaño del destino"
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "faltan argumentos para la función %<va_start%>"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "argumento no válido para %qD"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "no se admite el argumento para %qD"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr "llamar a %qD con un argumento distinto de cero es arriesgado"
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "ambos argumentos de %<__builtin_clear_cache%> deben ser punteros"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "se generó un trampolín para la función anidada %qD"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD cambió su semántica en GCC 4.4"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "argumento de modelo de memoria no válido para la función interna"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "la falla de modelo de memoria no puede ser más fuerte que el modelo de memoria exitoso para %<__atomic_compare_exchange%>"
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "falla de modelo de memoria no válido para %<__atomic_compare_exchange%>"
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "modelo de memoria no válido para %<__atomic_load%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "modelo de memoria no válido para %<__atomic_store%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 1 to %qs"
 msgstr "el argumento constante está fuera de rango para %qs"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-integer argument 1 to %qs"
 msgstr "el argumento constante está fuera de rango para %qs"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_thread_pointer is not supported on this target"
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "no se admite __builtin_thread_pointer en este objetivo"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_set_thread_pointer is not supported on this target"
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "no se admite __builtin_set_thread_pointer en este objetivo"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelax is only supported for RTP PIC"
 msgid "%qs only supported in OpenACC code"
 msgstr "-mrelax sólo se admite pare el PIC de RTP"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 0 to %qs"
 msgstr "el argumento constante está fuera de rango para %qs"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument %qs to %qs"
 msgid "illegal argument 0 to %qs"
@@ -22054,127 +22065,127 @@ msgstr "argumento %qs no válido para %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kuso no válido de %<__builtin_va_arg_pack ()%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kuso no válido de %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "el segundo argumento de %<__builtin_longjump%> debe ser 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "el formato objetivo no soporta infinito"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "se usó %<va_start%> en una función con argumentos fijos"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "número erróneo argumentos para la función %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "se llamó a %<__builtin_next_arg%> sin un argumento"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "número erróneo de argumentos para la función %<__builtin_next_arg%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "el segundo parámetro de %<va_start%> no es el último argumento nombrado"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "la conducta es indefinida cuando el segundo parámetro de %<va_start%> se declara con almacenamiento %<register%>"
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kel primer argumento de %qD debe ser un puntero, el segundo una constante entera"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Kel último argumento de %qD no es una constante entera entre 0 y 3"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "se declara aquí"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 #| msgid "required from %q#D\n"
 msgid "returned from %qD"
 msgstr "se requiere desde %q#D\n"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 #| msgid "required from %q#D\n"
 msgid "returned from %qT"
 msgstr "se requiere desde %q#D\n"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "obtained here"
 msgstr "se definió union aquí"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "assigned here"
 msgstr "se definió union aquí"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -22960,309 +22971,309 @@ msgstr "los bloques básicos no están ubicados consecutivamente"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "el número de notas bb en la cadena insn (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "la cuenta de borde llamador no es válida"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing counts for called function %s"
 msgid "missing direct call for speculation %i"
 msgstr "Faltan las cuentas para la función invocada %s"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "falta una barrera después del bloque %i"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "campo aux establecido para el borde %s->%s"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "cuenta de cgraph no válida"
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "clon en línea en el mismo grupo comdat"
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "inline clone is forced to output"
 msgid "inline clone count is not compatible"
 msgstr "se fuerza en la salida un clon incluido en línea"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "%<priority%> value must be non-negative"
 msgid "tp_first_run must be non-negative"
 msgstr "el valor de %<priority%> debe ser no negativo"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "los símbolos locales deben definirse"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "clon incluido en línea visible externamente"
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "clon incluido en línea con dirección tomada"
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "se fuerza en la salida un clon incluido en línea"
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 #| msgid "returns_nonnull attribute on a function not returning a pointer"
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "atributo returns_nonnull en una función que no devuelve puntero"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "se define el campo aux para el borde indirecto desde %s"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "edge count is not compatible with function count"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Un borde indirecto de %s no está marcado como indirecto o tiene indirect_info asociado, la declaración correspondiente es: "
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "función comdat-local llamada por %s fuera de su comdat"
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "el puntero inlined_to está mal"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "múltiples llamantes inline"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "se estableció el puntero inlined_to para llamantes no-inline"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "la cuenta de borde llamador no coincide con la cuenta BB"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "la cuenta de llamadas indirectas no coincide con la cuenta BB"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "se estableció el puntero inlined_to, pero no se encontraron predecesores"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "el puntero inlined_to se refiere a sí mismo"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "el cgraph_node tiene un clone_of erróneo"
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "el cgraph_node tiene una lista de clones errónea"
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "el cgraph_node está en la lista de clones pero no es clon"
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "el cgraph_node tiene un puntero prev_clone erróneo"
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "lista de clones doblemente ligada corrrupta"
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias tiene bordes de llamada"
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias tiene una referencia que no es alias"
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias tiene más de una referencia alias"
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "El alias analizado no tiene referencia"
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "No hay un borde fuera de un nodo thunk"
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Más de un borde fuera de un nodo thunk"
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "No se supone que thunk tenga cuerpo"
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt compartida:"
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "puntos de borde para una declaración errónea:"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "un borde indirecto con un llamante desconocido que corresponde a call_stmt con una declaración conocida:"
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "falta el borde de callgraph para la llamada stmt:"
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "referencia a sentencia muerta"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "el borde %s->%s no tiene un call_stmt correspondiente"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "un borde indirecto desde %s no tiene un call_stmt correspondiente"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of register to a different size"
 msgid "origin points to a different parent"
 msgstr "conversión de registro a un tamaño diferente"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "falló verify_cgraph_node"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: section %s is missing"
 msgid "%s: section %s.%d is missing"
@@ -23354,12 +23365,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "se descarta el atributo %<weakref%> porque ya se inicializó la variable"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "se usa %q+F pero nunca se define"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
@@ -23436,7 +23447,7 @@ msgstr "el tamaño del valor de devolución de %q+D es de %u bytes"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "el tamaño del valor de devolución de %q+D es más grande que %wd bytes"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "se encontraron nodos sin memoria liberada"
@@ -23870,12 +23881,12 @@ msgstr "se descarta la opción posiblemente conflictiva %<-fopt-info-%s%>"
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr "sólo se admiten múltiples personalidades EH con ensambladores que admiten la directiva cfi.personality"
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "se encontró UNSPEC %s (%d) que no está delegitimado la ubicación de variable"
@@ -23895,7 +23906,7 @@ msgstr "rtx compartido"
 msgid "internal consistency failure"
 msgstr "falla interna de consistencia"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: se usa emit_insn donde se necesita emit_jump_insn:\n"
@@ -24033,42 +24044,42 @@ msgstr "no se puede cerrar el fichero de volcado de insn final %qs: %m"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "se truncó la constante de coma fija grande implícitamente al tipo de coma fija"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparación siempre es %d debido a la anchura del campo de bit"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar la prueba de rango"
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "la comparación siempre es %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "un %<or%> de pruebas no equivalentes sin coincidencia siempre es 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "un %<and%> de pruebas equivalentes mutuamente exclusivas siempre es 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "se asume que el desbordamiento con signo no sucede cuando se reduce la constante en comparación"
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "se asume que el desbordamiento con signo no sucede cuando se combinan constantes alrededor de una comparación"
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold check: el árbol original cambió por un pliegue"
@@ -24085,7 +24096,7 @@ msgstr "el tamaño total de los objetos locales es demasiado grande"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "el tamaño total de los objetos locales es demasiado grande"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "restricción imposible en %<asm%>"
@@ -24737,7 +24748,7 @@ msgstr "desreferencia a puntero nulo"
 msgid "function may return address of local variable"
 msgstr "la función puede devolver la dirección de una variable local"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "la función devuelve la dirección de una variable local"
@@ -25122,73 +25133,73 @@ msgstr "el límite especificado %wu supera el tamaño %wu del objeto de destino"
 msgid "%Gnull format string"
 msgstr "cadena de formato nula"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 #| msgid "use of %<alloca%>"
 msgid "%Guse of %<alloca%>"
 msgstr "uso de %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 #| msgid "argument to variable-length array may be too large"
 msgid "%Gargument to variable-length array may be too large"
 msgstr "el argumento para el array de longitud variable podría ser demasiado grande"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 #| msgid "argument to %<alloca%> may be too large"
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "el argumento para %<alloca%> podría ser demasiado grande"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, fuzzy, gcc-internal-format
 #| msgid "limit is %u bytes, but argument may be as large as %s"
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr "el límite es %u bytes, pero el argumento puede alcanzar un tamaño de %s"
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 #| msgid "argument to variable-length array is too large"
 msgid "%Gargument to variable-length array is too large"
 msgstr "el argumento para el array de longitud variable es demasiado grande"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 #| msgid "argument to %<alloca%> is too large"
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "el argumento para %<alloca%> es demasiado grande"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, fuzzy, gcc-internal-format
 #| msgid "limit is %u bytes, but argument is %s"
 msgid "limit is %wu bytes, but argument is %s"
 msgstr "el límite es %u bytes, pero el es %s"
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 #| msgid "unbounded use of variable-length array"
 msgid "%Gunbounded use of variable-length array"
 msgstr "uso no acotado de array de longitud variable"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 #| msgid "unbounded use of %<alloca%>"
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "uso no acotado de %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 #, fuzzy
 #| msgid "use of %<alloca%> within a loop"
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "uso de %<alloca%> dentro de un bucle"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 #| msgid "argument to variable-length array is zero"
 msgid "%Gargument to variable-length array is zero"
 msgstr "al argumento del array de longitud variable es cero"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 #| msgid "argument to %<alloca%> is zero"
 msgid "%Gargument to %<alloca%> is zero"
@@ -25308,7 +25319,7 @@ msgstr "%K%qD: el límite especificado entre %E y %E excede el tamaño de objeto
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr "%G%qD desborda puntero entre el desplazamiento %s y el tamaño %s accediendo al array %qD con el tipo %qT"
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "el array %qD se declaró aquí"
@@ -25334,11 +25345,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "el desplazamiento de %G%qD %s está fuera de los límites ] del objeto %qD con tipo %qT"
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD se declara aquí"
@@ -25420,328 +25431,328 @@ msgstr "el atributo %<fallthrough%> no antecede una etiqueta case o default"
 msgid "using result of function returning %<void%>"
 msgstr "se usa el resultado de una función que devuelve %<void%>"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-memory input %d must stay in memory"
 msgid "non-memory output %d must stay in memory"
 msgstr "la entrada que no es de memoria %d debe permanecer en memoria"
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "l-valor no válido en la salida asm %d"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "la entrada que no es de memoria %d debe permanecer en memoria"
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "la entrada de memoria %d no es directamente direccionable"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variable %qE used in target region"
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "se usó la variable threadprivate %qE en una región objetivo"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing target region"
 msgid "enclosing region"
 msgstr "región objetivo contenedora"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "se usó la variable threadprivate %qE en una región objetivo"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "región objetivo contenedora"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "se usó la variable threadprivate %qE en una tarea sin atar"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "tarea contenedora"
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "no se especificó %qE en el %qs que lo contiene"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "%qs contenedora"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "no se especificó %qE en la construcción OpenACC %qs que lo contiene"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "construcción OpenACC %qs que lo contiene"
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE con cláusula %<link%> usada en la función %<routine%>"
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE requiere una directiva %<declare%> para poder usarse en una función%<routine%>"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 #| msgid "%qE not specified in enclosing %qs"
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "no se especificó %qE en el %qs que lo contiene"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing target region"
 msgid "enclosing %<target%>"
 msgstr "región objetivo contenedora"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "la variable %qE se declaró en la región %<host_data%> que la contiene"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD referenciada en la región de destino no tiene un tipo al que asociarla"
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "la variable de iteración %qE se predetermina lineal"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "la variable de iteración %qE debe ser private"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "la variable de iteración %qE no debe ser firstprivate"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "la variable de iteración %qE no debe ser reduction"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "la variable de iteración %qE no debe ser lineal"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> en una construcción %<target%>"
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %<lastprivate%>"
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "%qD no es una variable en la cláusula %<lastprivate%>"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "aún no se admite el modelo de código %<large%>"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "cláusula %<linear%> para una variable que no es iterador de bucle especificada en una construcción combinada con %<distribute%>"
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "se asocia el campo %qE de una estructura de longitud variable"
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE aparece más de una vez en las cláusulas map"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "la variable copyprivate %qE no es threadprivate o private en el contexto externo"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "la variable %s %qE es private en el contexto externo"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "se esperaba el modificador de cláusula %qs %<if%> en vez de %qs"
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD en cláusula %<map%> implícita"
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> implícita en una construcción %<target%>"
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> en una construcción %<target%>"
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "se ha usado la misma variable en cláusulas %<firstprivate%> y %<lastprivate%> en una construcción %<distribute%>"
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "cláusula de datos incompatible con reducción en %qE; se promociona a present_or_copy"
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "reducción privada no válida en %qE"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, fuzzy, gcc-internal-format
 #| msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "la cláusula %<linear%> no puede especificarse junto con la cláusula %<ordered%> con un parámetro"
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> en una construcción %<target%>"
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> en una construcción %<target%>"
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, fuzzy, gcc-internal-format
 #| msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "construcción %<teams%> no bien anidada dentro de construcción %<target%>"
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, fuzzy, gcc-internal-format
 #| msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "las regiones %<distribute%> deben estar estrictamente anidadas dentro de construcciones %<teams%>"
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, fuzzy, gcc-internal-format
 #| msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "solamente a las regiones %<distribute%> o %<parallel%> se les permite estar estrictamente anidadas dentro de la región %<teams%>"
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "el combinador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_out%> ni %<omp_in%>"
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "la construcción %<ordered%> con cláusula %<depend%> debe estar bien anidada dentro de un bucle con una cláusula %<ordered%> con un parámetro"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "la variable %qE no es una iteración del bucle más externo %d; se esperaba %qE"
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "el número de variables en la cláusula %<depend(sink)%> no coincide con el número de variables de iteración"
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, fuzzy, gcc-internal-format
 #| msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "más de una cláusula %<depend(source)%> en una construcción %<ordered%>"
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, fuzzy, gcc-internal-format
 #| msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "cláusula %<depend(source)%> especificada junto con cláusulas %<depend(sink:)%> en la misma construcción"
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "falló la gimplificación"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT se promueve a %qT cuando pasa a través de %<...%>"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(así que debe pasar %qT y no %qT a %<va_arg%>)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si se alcanza este código, el programa abortará"
@@ -26208,23 +26219,23 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%s cannot be used in %<asm%> here"
 msgstr "no se puede usar %s en asm aquí"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr "se requiere puntero de marco, mas reservado"
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr "para %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "el tamaño del marco es demasiado grande para una revisión confiable de la pila"
@@ -26245,12 +26256,12 @@ msgstr "el operando %<asm%> tiene restricciones imposibles"
 msgid "unable to find a register to spill"
 msgstr "no se puede encontrar un registro para vaciar"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "restricciones de operandos inconsistentes en un %<asm%>"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
@@ -27004,12 +27015,12 @@ msgstr "el argumento para %qs no está entre %d y %d"
 msgid "unrecognized argument in option %qs"
 msgstr "no se reconoce el argumento en la opción %qs"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para %qs son: %s; ¿quiso decir %qs?"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "los argumentos válidos para %qs son: %s"
@@ -27143,7 +27154,7 @@ msgstr "la memoria transaccional no se admite con excepciones que no son llamada
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr "las anclas de seccions se deben desactivar cando el reordenamiento de nivel principal se desactiva"
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> no funciona con excepciones en esta arquitectura"
@@ -27705,25 +27716,25 @@ msgstr "los registros usados explícitamente deben ser agrupados en la parte sup
 msgid "output operand %d must use %<&%> constraint"
 msgstr "el operando de salida %d debe usar la restricción %<&%>"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "validate_value_data: [%u] next_regno erróneo para la cadena vacía (%u)"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: Loop in regno chain (%u)"
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "validate_value_data: Ciclo en la cadena regno (%u)"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "validate_value_data: [%u] oldest_regno erróneo (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
@@ -27789,13 +27800,13 @@ msgstr "no se puede recargar operandos constantes enteros en %<asm%>"
 msgid "impossible register constraint in %<asm%>"
 msgstr "es imposible la restricción de registros en %<asm%>"
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "este objetivo no admite %qs"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "se usó la restricción %<&%> sin una clase de registro"
@@ -27826,53 +27837,53 @@ msgstr "la restricción del operando %<asm%> es incompatible con el tamaño del
 msgid "output operand is constant in %<asm%>"
 msgstr "el operando de salida es constante en %<asm%>"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "Revisión RTL: acceso de elt %d de '%s' con el último elt %d en %s, en %s:%d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "Revisión RTL: se esperaba el tipo elt %d '%c', se tiene '%c' (rtx %s) en %s, en %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "Revisión RTL: se esperaba el tipo elt %d '%c' ó '%c', se tiene '%c' (rtx %s) en %s, en%s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "Revisión RTL: se esperaba el código '%s', se tiene '%s' en %s, en %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "Revisión RTL: se esperaba el código '%s' ó '%s', se tiene '%s' en %s, en %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "Revisión RTL: se esperaba el código '%s' ó '%s', se tiene '%s' en %s, en %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "Revisión RTL: se intentó tratar un símbolo que no es de bloque como un símbolo de bloque en %s, en %s:%d"
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "Revisión RTL: acceso de hwi elt %d de vector con el último elt %d en %s, en %s:%d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "Revisión RTL: acceso de elt %d de vector con el último elt %d en %s, en %s:%d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "Revisión de opción RTL: se usó %s con el código rtx inesperado '%s' en %s, en %s:%d"
@@ -27917,23 +27928,23 @@ msgstr "la restricción de coincidencia hace referencia a un número de operando
 msgid "invalid punctuation %qc in constraint"
 msgstr "puntuación %qc no válida en la restricción"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "la restricción coincidente no permite un registro"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate asm operand name %qs"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "nombre de operando asm %qs duplicado"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "falta la llave final para el operando nombrado"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "operador %qs nombrado sin definir"
@@ -28660,9 +28671,9 @@ msgstr "operando no válido para %%R"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in parameter %i"
 msgid "type mismatch in %qs"
@@ -28704,7 +28715,7 @@ msgstr "operando de desplazamiento no válido en MEM_REF"
 msgid "invalid clique in %qs"
 msgstr "uso no válido de %qD"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
@@ -28921,391 +28932,391 @@ msgstr "operandos no válidos en la operación terniaria"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "el primer argumento de una VEC_COND_EXPR debe ser de tipo vector de booleanos del mismo número de elementos que el resultado"
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "vector types expected in sad expression"
 msgid "vector types expected in %qs"
 msgstr "se esperaban tipos vector en una expresión de permutación de vector"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, fuzzy, gcc-internal-format
 #| msgid "vectors with different element number found in vector permute expression"
 msgid "vectors with different element number found in %qs"
 msgstr "se encontraron vectores con número de elementos diferentes en la expresión de permutación"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offload table in %s"
 msgid "invalid mask type in %qs"
 msgstr "tabla de descarga no válida en %s"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "not allowed type combination in BIT_INSERT_EXPR"
 msgid "not allowed type combination in %qs"
 msgstr "no se permite combinar tipos en BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size in BIT_INSERT_EXPR"
 msgid "invalid position or size in %qs"
 msgstr "posición o tamaño no válido en BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 #| msgid "'h' applied to non-register operand"
 msgid "%qs into non-mode-precision operand"
 msgstr "`h' aplicado a un operando no registro"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 #| msgid "insertion out of range in BIT_INSERT_EXPR"
 msgid "insertion out of range in %qs"
 msgstr "inserción fuera de rango en BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 #| msgid "vector insertion not at element boundary"
 msgid "%qs not at element boundary"
 msgstr "inserción de vector no en contorno de elemento"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial conversion at assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "conversión que no es trivial en la asignación"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "non-decl/MEM_REF LHS in clobber statement"
 msgid "%qs LHS in clobber statement"
 msgstr "non-decl/MEM_REF LHS en sentencia clobber"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "operando no válido para %%R"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rhs for gimple memory store"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "rhs no válido para el almacenamiento de memoria gimple"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect type of vector CONSTRUCTOR elements"
 msgid "incorrect type of vector %qs elements"
 msgstr "tipo incorrecto de elementos de CONSTRUCTOR de vector"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect number of vector CONSTRUCTOR elements"
 msgid "incorrect number of vector %qs elements"
 msgstr "número incorrecto de elementos de CONSTRUCTOR de vector"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "tipo incorrecto de elementos de CONSTRUCTOR de vector"
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "vector CONSTRUCTOR with non-NULL element index"
 msgid "vector %qs with non-NULL element index"
 msgstr "CONSTRUCTOR de vector con índice de elemento no NULL"
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, fuzzy, gcc-internal-format
 #| msgid "vector CONSTRUCTOR element is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "el elemento CONSTRUCTOR de vector no es un valor GIMPLE"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "non-vector CONSTRUCTOR with elements"
 msgid "non-vector %qs with elements"
 msgstr "CONSTRUCTOR no vector con elementos"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR con una condición que es siempre falsa"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "operando no válido en la declaración return"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "conversión no válida en la declaración return"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "el destino de goto no es una etiqueta ni un puntero"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "operando no válido para la declaración switch"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "sentencia switch de tipo no entero"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "etiqueta case default no váilda en sentencia switch"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, fuzzy, gcc-internal-format
 #| msgid "invalid CASE_CHAIN"
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "CASE_CHAIN no válido"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "etiqueta case no váilda en sentencia switch"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "rango case no váildo en sentencia switch"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "discordancia en precisión de tipo en sentencia switch"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "discordancia de tipos para etiqueta case en sentencia switch"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "etiquetas case no ordenadas en sentencia switch"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "label's context is not the current function decl"
 msgid "label context is not the current function declaration"
 msgstr "el contexto de la etiqueta no es la declaración de función actual"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect entry in label_to_block_map"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "entrada incorrecta en label_to_block_map"
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "definición incorrecta del número de relleno de aterrizaje"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "código de comparación no válido en la condición gimple"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "etiquetas no válidas en la condición gimple"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "resultado PHI no válido"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "falta la definición PHI"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "argumento PHI no válido"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in PHI argument %u"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "tipos incompatibles en el argumento PHI %u"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "falló verify_gimple"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, fuzzy, gcc-internal-format
 #| msgid "dead STMT in EH table"
 msgid "dead statement in EH table"
 msgstr "STMT muerto en la tabla EH"
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "la ubicación referencia un bloque que no está en el árbol de bloques"
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "Local declaration from a different function"
 msgid "local declaration from a different function"
 msgstr "Declaración local desde una función diferente"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "se estableció gimple_bb (phi) a un bloque básico erróneo"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "nodo PHI con ubicación"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "compartición incorrecta de nodos de árbol"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "PHI virtual con ubicaciones de argumento"
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "se estableció gimple_bb (stmt) a un bloque básico erróneo"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "se marcó la sentencia para throw, pero no lo hace"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "se marcó la sentencia para throw en medio del bloque"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "falló verify_gimple"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK tiene IL asociado con él"
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK tiene IL asociado con él"
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "caida para salir del bb %d"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "etiqueta no local "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "etiqueta de relleno de aterrizaje EH "
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "etiqueta "
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "control de flujo enmedio del bloque básico %d"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "borde de caída después de una sentencia de control en bb %d"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "borde verdadero/falso después de una expresión que no es GIMPLE_COND en bb %d"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "banderas de borde de salida erróneas al final del bb %d"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "goto explícito al final del bb %d"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "el borde de devolución no apunta a exit en el bb %d"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "se encontró un case por defecto que no está al inicio del vector case"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "las etiquetas case no están ordenadas:"
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "borde de salida extra %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "falta el borde %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "la función %<noreturn%> devuelve"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "el control alcanza el final de una función que no es void"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -30499,7 +30510,7 @@ msgstr "los datos COMMON thread-local no están implementados"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "la alineación solicitada para %q+D es mayor que la alineación implementada de %wu"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %q+D"
@@ -30665,7 +30676,7 @@ msgstr "flujo de bytecode: se esperaba la etiqueta %s en lugar de %s"
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "flujo de bytecode: la etiqueta %s no está en el rango esperado [%s, %s]"
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported mode %s\n"
 msgid "unsupported record layout"
@@ -31335,7 +31346,7 @@ msgstr "atributo %qE a continuación de %qE"
 msgid "type was previously declared %qE"
 msgstr "el tipo se declaró previamente %qE"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> solo se puede especificar para funciones virtuales"
@@ -31355,7 +31366,7 @@ msgstr "%qD no es compatible con %qD"
 msgid "%qE argument is not a function"
 msgstr "el argumento %qE no es una función"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "el mensaje obsoleto no es una cadena"
@@ -31829,12 +31840,12 @@ msgstr "?: usando constantes enteras en contexto boolean"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "el compilador puede asumir que la dirección de %qD siempre se evaluará como %<true%>"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "se sugieren paréntesis alrededor de la asignación usada como valor verdadero"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "uso no válido de %<restrict%>"
@@ -32000,13 +32011,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "el atributo %<fallthrough%> se especificó con un parámetro"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "faltan argumentos para la función %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "demasiados argumentos para la función %qE"
@@ -32996,7 +33007,7 @@ msgstr "no se admite la concatenación no estándar de literales de cadena"
 msgid "traditional C rejects string constant concatenation"
 msgstr "C tradicional rechaza la concatenación de constantes de cadenas"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -33049,7 +33060,7 @@ msgstr "cláusula %<depend(source)%> especificada junto con cláusulas %<depend(
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipo no válido para la variable de iteración %qE"
@@ -33064,17 +33075,17 @@ msgstr "variable de iteración %<_Atomic%> %qE"
 msgid "%qE is not initialized"
 msgstr "%qE no está inicializado"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "falta el predicado controlador"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predicado controlador no válido"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "falta la expresión de incremento"
@@ -33084,7 +33095,7 @@ msgstr "falta la expresión de incremento"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expresión de incremento no válida"
@@ -33153,7 +33164,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -33763,8 +33774,8 @@ msgstr "<valor-devolución>"
 msgid "wrong type argument to %s"
 msgstr "argumento de tipo erróneo para %s"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "desbordamiento en la expresión constante"
@@ -34256,17 +34267,17 @@ msgstr "decremento de la función %qD"
 msgid "function %qD used as %<asm%> output"
 msgstr "se usó la función %qD como salida %<asm%>"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "asignación de la ubicación de sólo lectura %qE"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "incremento de la ubicación de sólo lectura %qE"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "decremento de la ubicación de sólo lectura %qE"
@@ -34447,8 +34458,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparación entre los tipos %qT y %qT"
@@ -34531,38 +34542,38 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 msgstr[1] "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "esta condición tiene bifurcaciones idénticas"
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr "la macro se expande en múltiples sentencias"
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr "algunas partes de la expansión de macro no están flanqueadas por esta cláusula %qs"
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "se definió union aquí"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 #| msgid "size mismatch in argument %d of %qE"
 msgid "mismatch in bound %Z of argument %u declared as %s"
@@ -34570,54 +34581,54 @@ msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "no coincide el tamaño en el argumento %d de %qE"
 msgstr[1] "no coincide el tamaño en el argumento %d de %qE"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as %s"
 msgstr "se declaró previamente aquí"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to variable-length array is zero"
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "al argumento del array de longitud variable es cero"
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as a pointer %s"
 msgstr "se declaró previamente aquí"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as an ordinary array %s"
 msgstr "se declaró previamente aquí"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument %d of %qE must be a pointer type"
 msgid "argument %u of type %s declared as a pointer"
 msgstr "el argumento %d de %qE debe ser un tipo puntero"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unbounded use of variable-length array"
 msgid "previously declared as a variable length array %s"
 msgstr "uso no acotado de array de longitud variable"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as an array %s"
 msgstr "se declaró previamente aquí"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "argument %u of type %s declared with %u variable bound"
@@ -34625,7 +34636,7 @@ msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 msgstr[1] "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %q+D with attribute noinline"
 msgid "previously declared as %s with %u variable bound"
@@ -34633,73 +34644,73 @@ msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "declaración previa de %q+D con el atributo noinline"
 msgstr[1] "declaración previa de %q+D con el atributo noinline"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "el argumento de tipo %qT no coincide con %qT"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as %s with bound argument %E"
 msgstr "se declaró previamente aquí"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %<%c%s%>"
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "declaración previa de %<%c%s%>"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previously declared as %s with bound %qs"
 msgstr "declaración previa de %q+#D"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s with mismatched bound"
 msgstr "el argumento de tipo %qT no coincide con %qT"
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -34714,7 +34725,7 @@ msgstr "%qs no es una opción válida para el preprocesador"
 msgid "too many input files"
 msgstr "demasiados ficheros de entrada"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -34748,14 +34759,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "se pasa opción no reconocida a %%:target_mode_check"
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "los argumentos válidos son: %s; ¿quiso decir %qs?"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "los argumentos válidos son: %s"
@@ -34920,70 +34931,70 @@ msgstr "-mregparm=%d no está entre 0 y %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr "para la opción -mcache-block-size=X, las X válidas son: 4, 8, 16, 32, 64, 128, 256, o 512"
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> requires %<-mfp32%>"
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "%<-march=%s%> requiere %<-mfp32%>"
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: invalid ISA string"
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "-march=%s: cadena ISA no válida"
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: unsupported ISA substring %qs"
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr "-march=%s: subcadena ISA %qs no válida"
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr "-march=%s: la cadena ISA debe empezar por rv32 o rv64"
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%> no es compatible con la ABI seleccionada"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%> no es compatible con la ABI seleccionada"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "-march=%s: la cadena ISA debe empezar por rv32 o rv64"
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: unsupported ISA substring %qs"
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr "-march=%s: subcadena ISA %qs no válida"
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
@@ -35160,86 +35171,86 @@ msgstr "%s genera conflicto con ppc (se hace caso omiso de los indicadores de ar
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr "%s genera conflicto con ppc64 (se hace caso omiso de los indicadores de arquitectura)"
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "falló al abrir el fichero temporal %s para la salida LTO"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "el atributo de compatibilidad vtable 2.95 %qE sólo aplica cuando se compila una kext"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "el atributo de compatibilidad vtable 2.95 %qE sólo aplica a clases C++"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "no se admiten los atributos de visibilidad protected en esta configuración; descartados"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "falló al abrir el fichero de temporal %s con salida LTO"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fobjc-abi-version%> >= 2 must be used for %<-m64%> targets with %<-fnext-runtime%>"
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> >= 2 sólo se debe usar en objetivos %<-m64%> con %<-fnext-runtime%>"
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fobjc-abi-version%> >= 2 is not supported on %<-m32%> targets with %<-fnext-runtime%>"
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> >= 2 no se admite en objetivos %<-m32%> con %<-fnext-runtime%>"
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "no se admite %<__int%d%> para este objetivo"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "%<-mdynamic-no-pic%> anula a %<-fpic%>, %<-fPIC%>, %<-fpie%> o %<-fPIE%>"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "la función interna %qD requiere la opción %<-mconstant-cfstrings%>"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "la función interna %qD sólo toma un argumento"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "falta una literal CFString"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "la expresión literal CFString no es una constante de cadena"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, fuzzy, gcc-internal-format
 #| msgid "%s in CFString literal"
 msgid "non-ASCII character in CFString literal"
 msgstr "%s en la literal CFString"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "%s in CFString literal"
 msgid "embedded NUL in CFString literal"
@@ -35248,7 +35259,7 @@ msgstr "%s en la literal CFString"
 #: config/host-darwin.c:65
 #, fuzzy, gcc-internal-format
 #| msgid "couldn%'t unmap pch_address_space: %m"
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "no se puede hacer unmap de pch_address_space: %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -35391,403 +35402,403 @@ msgstr "%<#pragma GCC optimize%> no es una cadena o un número"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "basura al final de #pragma GCC coprocessor %E"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new no se puede aplicar a un tipo de función"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<for%> after %qs"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "se esperaba %<fork%> después de %qs"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "el modificador de característica %qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "el modificador de característica %qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the SPE ABI extensions."
 msgid "this operation requires the SVE ISA extension"
 msgstr "No usa las extensiones de ABI SPE."
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%qE requires the SVE ISA extension"
 msgstr "Usa las extensiones de ABI SPE."
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs option"
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "la función interna %qs requiere la opción %qs"
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, fuzzy, gcc-internal-format
 #| msgid "unknown flag passed in -moverride=%s (%s)"
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "indicador pasado en -moverride=%s (%s) desconocido"
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "cadena %s mal formada\n"
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid format of %s"
 msgid "invalid format for sve_width"
 msgstr "formato no válido de %s"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %h value"
 msgid "invalid sve_width value: %d"
 msgstr "valor %h no válido"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "falta la cadena de ajuste en la opción (%s)"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "opción de cadena de ajuste desconocida (%s)"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Especifica el orden de asignación de registros"
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs no es un desplazamiento válido en %qs"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments are: %s"
 msgid "valid arguments are: %s;"
 msgstr "los argumentos válidos son: %s"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "falta el nombre de la cpu en %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "modificador de característica no válido en %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument %qs to %qs"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "argumento %qs no válido para %qs"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr "%<-mmsa%> debe usarse con %<-mfp64%> y %<-mhard-float%>"
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arguments for %<-fpatchable_function_entry%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "argumento no válido para %<-fpatchable_function_entry%>"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arguments for %<-fpatchable_function_entry%>"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "argumento no válido para %<-fpatchable_function_entry%>"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arguments for %<-fpatchable_function_entry%>"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "argumento no válido para %<-fpatchable_function_entry%>"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "falta el nombre de la arquitectura en %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -march"
 msgid "unknown value %qs for %<-march%>"
 msgstr "valor %qs desconocido para -march"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-march=%s%>"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "modificador de característica no válido en %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "falta el nombre de la cpu en %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "valor %qs desconocido para -mtune"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "la opción -mcpu=%s genera un conflicto con la opción -march=%s"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 #| msgid "assembler does not support -mabi=ilp32"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "el ensamblador no tiene soporte para -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %<-f%s%>"
 msgstr "modelo de código %qs con -f%s"
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "falta el nombre en atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "valor no válido (\"%s\") en el pragma o atributo %<target()%>"
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "falta el nombre en el pragma o atributo %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, fuzzy, gcc-internal-format
 #| msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "falta el nombre en atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, fuzzy, gcc-internal-format
 #| msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "falta el valor en el pragma o atributo %<target()%>"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "pragma o atributo %<target()%> mal formado"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "el pragma o atributo %<target(\"%s\")%> no acepta un argumento"
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "el pragma o atributo %<target(\"%s\")%> no acepta forma negada"
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "el pragma o atributo %<target(\"%s=%s\")%> no es válido"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "el argumento del atributo %<target%> no es una cadena"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "el pragma o atributo %<target(\"%s\")%> no es válido"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "pragma o atributo %<target(\"%s\")%> mal formado"
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Klane %wd fuera de rango %wd - %wd"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "vía %wd fuera de rango %wd - %wd"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported simdlen %d"
 msgid "unsupported simdlen %wd"
 msgstr "simdlen %d no admitido"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported return type %qT for simd"
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported return type %qT for simd"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type %qT for simd"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "no se admite el tipo de argumento %qT para simd"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -35857,7 +35868,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "valor %qs erróneo para -mmemory-latency"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -35986,18 +35997,18 @@ msgstr "el argumento del atributo %qE no es \"ilink1\" o \"ilink2\""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "el argumento del atributo %qE no es \"ilink\" o \"firq\""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -36447,238 +36458,244 @@ msgstr "el CPU objetivo no admite las instrucciones THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "el CPU objetivo no admite accesos sin alinear"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "switch -mcpu=%s conflicts with -march=%s switch"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "la opción -mcpu=%s genera un conflicto con la opción -march=%s"
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check es incompatible con -mno-apcs-frame"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic y -mapcs-reent son incompatibles"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "no se admite el código reentrante APCS.  Descartado"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "el límite del tamaño de la estructura sólo se puede establecer a 8, 32 o 64"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "el límite del tamaño de la estructura sólo se puede establecer a 8 o 32"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "El PIC de RTP es incompatible con -msingle-pic-base"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= es inútil sin -fpic"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "no se puede usar '%s' para registro PIC"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "no se admite -freorder-blocks-and-partition en esta arquitectura"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "las opciones fp16 seleccionadas son incompatibles"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt requiere una ABI compatible con AAPCS para una operación adecuada"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "el abi iwmmxt requiere un cpu capaz de iwmmxt"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "el CPU objetivo no admite trabajo interno"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS no admite -mcaller-super-interworking"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS no admite -mcallee-super-interworking"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 sin ldrh"
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "la CPU objetivo no admite las instrucciones de seguridad ARMv8-M"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard: selected processor lacks an FPU"
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr "-mfloat-abi=hard: el procesador seleccionado carece de FPU"
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard y VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "variante PCS derivada de un no AAPCS"
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "las funciones variadic debe usar la variante AAPCS base"
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "variante PCS"
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "ABI de VFP de coma flotante dura de Thumb-1"
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "el atributo %qE no está disponible para funciones con argumentos pasados en la pila"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "el atributo %qE no está disponible para funciones con un número variable de argumentos"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "el atributo %qE no está disponible para funciones que devuelven valor en la pila"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored without -mcmse option."
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "se descarta el atributo %qE sin la opción -mcmse."
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "el atributo %qE no tiene efecto en funciones con enlazado estático"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "el atributo %qE se aplica solamente al tipo base de un puntero a función"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd fuera de rango %wd - %wd"
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd fuera de rango %wd - %wd"
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "no se puede calcular la ubicación real del parámetro apilado"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Fin de módulo inesperado"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "no hay registros inferiores disponibles para extraer registros superiores"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "no se pueden codificar las Rutinas de Servicios de Interrupción en el modo Thumb"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific para Thumb-1"
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "fpu no válida para el atributo o pragma del objetivo %qs"
@@ -36686,22 +36703,22 @@ msgstr "fpu no válida para el atributo o pragma del objetivo %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "selección automática de fpu actualmente no permitida aquí"
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "arquitectura no válida para el atributo o pragma objetivo %qs"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "atributo o pragma objetivo %qs desconocido"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -36785,17 +36802,17 @@ msgstr "no se admite -fpie"
 msgid "%<-fPIE%> is not supported"
 msgstr "no se admite -fPIE"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "los atributos de función %qs y %qs son mutuamente excluyentes"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la función %qs no puede tener argumentos"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la función %qs no puede devolver un valor"
@@ -37588,134 +37605,134 @@ msgstr "El parámetro para la función interna debe ser una cadena constante o l
 msgid "parameter to builtin not valid: %s"
 msgstr "El parámetro para la función interna no es válido: %s"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't be called directly"
 msgid "interrupt service routine cannot be called directly"
 msgstr "no se puede llamar directamente a la rutina de servicio de interrupciones"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 2-bit"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "el quinto argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 3-bit"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 4-bit"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 5-bit"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "el penúltimo argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "el tercer argumento debe ser una constante de comparación"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "modo de comparación incorrecto"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "operando de redondeo incorrecto"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 4-bit"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 5-bit"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "el selector debe ser una constante entera en el rango 0..%wi"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE necesita la opción isa desconocida"
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE necesita la opción isa %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 32-bit"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "el último argumento debe ser un inmediato"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "el último argumento debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "el argumento delantero debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "operando de pista incorrecto"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 #| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -37739,550 +37756,550 @@ msgstr "No se admiten versiones múltiples de funciones virtuales"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "el versionado múltiple necesita ifunc, que no se admite en este objetivo"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "el modelo de código %s no admite el modo PIC"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "el argumento del atributo %qE no es una cadena"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "se desconoce attribute(target(\"%s\"))"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "El atributo SEQUENCE en %C ya se especificó en la declaración TYPE"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "El atributo %s de '%s' genera un conflicto con el atributo %s en %L"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "argumento %qs incorrecto para la opción %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "los rangos de tamaño de la opción %qs deberían ser crecientes"
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "se especificó un nombre de estrategia %qs incorrecto para la opción %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "no se admite el nombre de estrategia %qs especificado para la opción %qs para código de 32 bits"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "se especificó una alineación %qs desconocida para la opción %qs"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "el valor máximo para el último rango de tamaños debería ser -1 para la opción %qs"
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "se especificaron demasiados rangos de tamaños en la opción %qs"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, fuzzy, gcc-internal-format
 #| msgid "unknown parameter to option -mtune-ctrl: %s"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "parámetro desconocido para la opción -mtune-ctrl: %s"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "no se admite Intel MCU psABI en el modo %s"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> es obsoleto; use en su lugar %<-mtune=k8%> o %<-mtune=generic%> como sea adecuado"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> es obsoleto; use %<target(\"tune=k8\")%> o %<target(\"tune=generic\")%> en su lugar como convenga"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "el modelo de direcciones %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 #| msgid "-mabi=ms not supported with X32 ABI"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "no se admite -mabi=ms con X32 ABI"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "la memoria transaccional no se admite con %<-fsanitize=address%>"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "la memoria transaccional no se admite con %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsanitize=leak%> is incompatible with %<-fsanitize=thread%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-fsanitize=leak%> es incompatible con %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "el modelo de código %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "no se admite -masm=intel en esta configuración"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "no está compilado el modo bit-%i"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<generic%> solo se puede usar para el ajuste %<-tune=%>"
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<generic%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<intal%> solo se puede usar para el ajuste %<-mtune=%>"
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<intel%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "el CPU que seleccionó no admite el conjunto de instrucciones x86-64"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-march=%>"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s; ¿qiuso decir %qs?"
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-mtune=%>"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "se descarta -mregparm en modo de 64-bit"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored for Intel MCU psABI"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "se descarta -mregparm para Intel MCU psABI"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d no está entre 0 y %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "se descarta %<-mrtd%> en el modo de 64bit"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "se descarta %<target(\"rtd\")%> en el modo de 64bit"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "no se admite -mpreferred-stack-boundary en este objetivo"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d no está entre %d y %d"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d no está entre %d y 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "-mnop-mcount no está implementada para -fPIC"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "se usó %<-msseregparm%> sin SSE activado"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "se usó %<target(\"ssseregparm\")%> sin SSE activado"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "el conjunto de instrucciones SSE está desactivado, usando la aritmética 387"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "el conjunto de instrucciones 387 está desactivado, usando la aritmética SSE"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "la prueba de pila requiere %<-maccumulate-outgoing-args%> para ser correcta"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "la prueba de pila requiere %<target(\"accumulate-outgoing-args\"%> para ser correcta"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "el registro ebp fijo requiere %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "el registro ebp fijo requiere %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry no se admite para 32-bit en combinación con -fpic"
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry no es compatible con SEH"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, fuzzy, gcc-internal-format
 #| msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "-mcall-ms2sysv-xlogues no es compatible con %s"
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "opción desconocida para -mrecip=%s"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs no es un número válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs no es un desplazamiento válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs no es un registro base válido en -mstack-protector-guard-reg="
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "interrupción y atributos desnudos no es compatible"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, fuzzy, gcc-internal-format
 #| msgid "Only DWARF debug format is supported for interrupt service routine."
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "Solo se admite el formato de depuración DWARF para la rutina de servicio de interrupciones."
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "Las instrucciones %s no están permitidas en funciones con el atributo no_caller_saved_registers"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "los atributos fastcall y regparm no son compatibles"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "los atributos regparam y thiscall no son compatibles"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "el atributo %qE requiere un argumento constante entero"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "los atributos fastcall y cdecl no son compatibles"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "los atributos fastcall y stdcall no son compatibles"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "los atributos fastcall y thiscall no son compatibles"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "los atributos stdcall y cdecl no son compatibles"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "los atributos stdcall y fastcall no son compatibles"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "los atributos stdcall y thiscall no son compatibles"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "los atributos cdecl y thiscall no son compatibles"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "se usó el atributo %qE para método no de clase"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "se descarta el atributo incompatible %qE"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "el atributo %qE solamente está disponible para 64-bit"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "los atributos ms_abi y sysv_abi no son compatibles"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "el atributo %qE requiere una constante entera como argumento"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "el argumento del atributo %qE no es (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la rutina de servicio de interrupciones debería tener un puntero como primer argumento"
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "la rutina de atención de interrupciones debería tener como segundo argumento un unsigned %sint"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la rutina de servicio de interrupciones solo puede tener un argumento puntero y un argumento entero opcional"
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't have non-void return value"
 msgid "interrupt service routine must return %<void%>"
@@ -38770,7 +38787,7 @@ msgstr "%qE no puede tener los atributos %qs y %qs al mismo tiempo"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE se redeclaró con los atributos %qs en conflicto"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "el atributo %qE requiere una cadena como argumento"
@@ -39907,63 +39924,63 @@ msgstr "__delay_cycles está limitado a números de bucles de 32 bits"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "cpu %qs desconocida para -mtune"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, fuzzy, gcc-internal-format
 #| msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "-mdiv requiere -march para subsumir la extensión %<M%>"
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, fuzzy, gcc-internal-format
 #| msgid "requested ABI requires -march to subsume the %qc extension"
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "la ABI solicitada requiere -march para subsumir la extensión %qc"
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "ABI requires -march=rv%d"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI requiere -march=rv%d"
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d debe estar entre %d y %d"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs no es un registro base válido en %qs"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs no es un número válido en %qs"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
@@ -40510,248 +40527,249 @@ msgstr "%qs usa el registro r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "No se admite un marco de pila mayor de 2G con -fsplit-stack"
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs requiere %qs o %qs"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs requiere la arquitectura PowerPC64, activando"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 #| msgid "-mcall-aixdesc incompatible with -mabi=elfv2"
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mcall-aixdesc es incompatible con -mabi=elfv2"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires a PowerPC64 cpu"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 requiere un procesador PowerPC64"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "-mcmodel es incompatible con otras opciones toc"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 #| msgid "FPA is unsupported in the AAPCS"
 msgid "%qs unsupported for this ABI"
 msgstr "no se admite FPA en el AAPCS"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "no se admite %qs para Darwin de 64 bits; es incompatible con las bibliotecas C y C++ instaladas"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "no se admite AltiVec en este objetivo"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "no se admite %qs en sistemas little endian"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "la opción del objetivo power9 es incompatible con %<%s=<xxx%> para <xxx> menor que power9"
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs es incompatible con las opciones desactivadas explícitamente"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs requiere %qs"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes long double size"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "el atributo o pragma target cambia el tamaño de double long"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, fuzzy, gcc-internal-format
 #| msgid "%qs requires full ISA 3.0 support"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%qs requiere suporte pleno de ISA 3.0"
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "Using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Se usa long double de precisión extendida de IEEE"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "Using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Se usa long double de precisión extendida de IBM"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs necesita soporte para VSX"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, fuzzy, gcc-internal-format
 #| msgid "The -mfloat128 option may not be fully supported"
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr "Es posible que la opción -mfloat128 no funcione perfectamente"
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs requiere suporte pleno de ISA 3.0"
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "tipo de ABI de biblioteca de vectorización desconocida (%qs) para la opción %qs"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "el atributo o pragma target cambia la ABI Altivec"
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "el atributo o pragma target cambia la ABI darwin64"
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs necesita un registro bae válido"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "opción desconocida para %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs está obsoleto y no está recomendada bajo ninguna circunstancia"
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "la disposición de los agregados que contienen vectores con alineamiento de %d bytes cambió en GCC 5"
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "no hay análisis de perfil del código de 64-bit para esta ABI"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "no se puede tomar la dirección de una función anindada si se usa la opción %qs"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "el uso de %<long double%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "el uso de tipos booleanos en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "el uso de %<complex%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "el uso de tipos de coma flotante decimal en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "el uso de %<long%> en tipos AltiVec no es válido para código de 64 bits sin %qs"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "el uso de %<long%> en tipos AltiVec es obsoleto; use %<int%>"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<long long%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<double%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "cpu %qs no válida para %s%qs%s"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s no está permitido"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s no es válido"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno=%s%> anula %<-m%s%>"
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "el versionado múltiple necesita ifunc, que no se admite en este objetivo"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "No se admiten versiones múltiples de funciones virtuales"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -40938,7 +40956,7 @@ msgstr "las instrucciones FPU de RX no admiten NaNs e infinitos"
 msgid "builtin vec_step can only be used on vector types."
 msgstr "la interna vec_step solo puede usarse con tipos vectoriales."
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "se requiere un valor constante para la interna %qF, argumento %d"
@@ -41013,215 +41031,221 @@ msgstr "%qs es obsoleto"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "el argumento constante %d para la función interna %qF está fuera de rango para el tipo de objetivo"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "constant argument %d for builtin %qF is out of range ("
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "el argumento constante %d para la función interna %qF está fuera de rango ("
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range (0.."
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "el argumento constante %d para la función interna %qF está fuera de rango (0.."
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range (0.."
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "el argumento constante %d para la función interna %qF está fuera de rango (0.."
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr "la función interna %qF no se admite sin -mhtm (predeterminado con -march=zEC12 y superiores)."
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr "la función interna %qF requiere -mvx (predeterminado con -march=z13 y superiores)."
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr "la función interna %qF requiere z14 o superior."
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin %qF requires z14 or higher."
 msgid "Builtin %qF requires z15 or higher."
 msgstr "la función interna %qF requiere z14 o superior."
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin %qF requires z14 or higher."
 msgid "Builtin %qF requires arch14 or higher."
 msgstr "la función interna %qF requiere z14 o superior."
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<tipo de función sobrecargada sin resolver>"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "icode interno erróneo"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "argumento no válido %d para la función interna %qF"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "el atributo %qE solicitado no es una pareja de constantes enteras no negativas separadas por coma o es demasiado grande (máx. %d)"
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "el argumento del atributo %qE no es (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "el tamaño total de las variables locales excede el límite de la arquitectura"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "el tamaño de marco de la función %qs de %wd bytes excede el límite de pila definido por el usuario de %d bytes.  Se agrega una trampa incondicional."
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "el tamaño de marco de la función %qs de %wd bytes es mayor que la mitad del tamaño de la pila. La revisión dinámica no será confiable. No se emitirá revisión para esta función."
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "el tamaño de marco de %qs es de %wd bytes"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs utiliza alojamiento dinámico de pila"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "%<__RTL%> function cannot be compiled with %<-flto%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "la función %<__RTL%> no se puede compilar con %<-flto%>"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "no se admite la ABI de 64-bit en el modo ESA/390"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, fuzzy, gcc-internal-format
 #| msgid "thunk-inline is only supported with -mindirect-branch-jump"
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline solo se admite con -mindirect-branch-jump"
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "vector de hardware no está disponible en %s"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, fuzzy, gcc-internal-format
 #| msgid "hardware vector support not available with -msoft-float"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "vector de hardware no está disponible con -msoft-float"
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en %s"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en el modo ESA/390"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp no se puede usar en conjunción con -msoft-float"
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "no se admiten -mbackchain -mpacked-stack -mhard-float en combinación"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "el tamaño de la pila debe ser mayor que el valor de la guardia de pila"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "el tamaño de la pila no debe ser mayor a 64k"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard implica el uso de -mstack-size"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "el atributo %qE solo se admite para SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "los argumentos para %qs deben ser enteros no negativos"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "el argumento para %qs es demasiado grande (máx. %d)"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-pic-data-is-text-relative cannot be used without -fpic/-fPIC"
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "-mno-pic-data-is-text-relative no puede utilizarse sin -fpic/-fPIC"
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "se desconoce attribute(target(\"%s\"))"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "no se admite el valor %qs para el atributo %<target%>"
@@ -41580,18 +41604,24 @@ msgstr "-fexcess-precision=standard para Ada"
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr "la información de depuración STABS para Ada está obsoleta y ya no se admite"
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "insn contains an invalid address !"
+msgid "%s contains too many lines"
+msgstr "¡ La insn contiene una dirección no válida !"
+
+#: ada/gcc-interface/trans.c:1642
 #, fuzzy, gcc-internal-format
 #| msgid "subprogram %q+F not marked Inline_Always"
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr "el subprograma %q+F no está marcado Inline_Always"
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "el subprograma padre no puede ser inline"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 #| msgid "subprogram %q+F not marked Inline"
 msgid "subprogram %q+F not marked %<Inline%>"
@@ -41662,8 +41692,8 @@ msgstr "el atributo %qs solamente se aplica a tipos de matriz"
 msgid "could not read the BRIG file"
 msgstr "no se puede leer el fichero BRIG"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "no se descarta el valor void como debería de ser"
@@ -41723,7 +41753,7 @@ msgstr "se define la variable %qD pero no se usa"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "el tipo de la matriz %q+D se completó de forma incompatible con la inicialización implícita"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "se definió originalmente aquí"
@@ -41957,7 +41987,7 @@ msgstr "la declaración de %q+D oscurece a una declaración previa que no es var
 msgid "declaration of %qD shadows a parameter"
 msgstr "la declaración de %qD oscurece un parámetro"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "la declaración de %qD oscurece a una declaración global"
@@ -41967,7 +41997,7 @@ msgstr "la declaración de %qD oscurece a una declaración global"
 msgid "declaration of %qD shadows a previous local"
 msgstr "la declaración de %qD oscurece a una declaración local previa"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "aquí está la declaración oscurecida"
@@ -41977,216 +42007,216 @@ msgstr "aquí está la declaración oscurecida"
 msgid "nested extern declaration of %qD"
 msgstr "declaración externa anidada de %qD"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "declaración implícita de la función %qE; ¿quiso decir %qs?"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "declaración implícita de la función %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "include %qs or provide a declaration of %qD"
 msgid "include %qs or provide a declaration of %qE"
 msgstr "incluya %qs o proporcione una declaración de %qD"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "declaración implícita incompatible de la función interna %qD"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "incluya %qs o proporcione una declaración de %qD"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "declaración implícita incompatible de la función %qD"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE no se declaró aquí (no en una función); ¿quiso decir %qs?"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE no se declaró aquí (primer uso en esta función); ¿quiso decir %qs?"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE no se declaró aquí (primer uso en esta función)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "cada identificador sin declarar se reporta sólo una vez para cada función en el que aparece"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "la etiqueta %qE es referenciada fuera de cualquier función"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "salto al ámbito de un identificador con tipo modificado variablemente"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "el salto evita la inicialización de la variable"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "salto a una expresión de declaración"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "declaración duplicada de la etiqueta %qE"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "etiqueta %qD duplicada"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "C tradicional carece de un espacio de nombres separado para etiquetas, el identificador %qE genera un conflicto con"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "el switch salta sobre la inicialización de la variable"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch inicia aquí"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "switch salta dentro de una expresión de declaración"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE definido como un tipo erróneo de etiqueta"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "se descarta el atributo %qE en tipos"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "struct/union sin nombre que no define ninguna instancia"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "una declaración vacía con especificadores de clase de almacenamiento no redeclara la etiqueta"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "una declaración vacía con calificador de tipo no redeclara la etiqueta"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "una declaración vacía con %<_Alignas%> no redeclara la etiqueta"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "nombre de tipo sin uso en una declaración vacía"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> en una declaración vacía"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> en una declaración vacía"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> en una declaración vacía en ámbito de fichero"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> en una declaración vacía en ámbito de fichero"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "especificador de clase de almacenamiento sin uso en una declaración vacía"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "%qs sin uso en declaración vacía"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "calificador de tipo sin uso en una declaración vacía"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "%<_Alignas%> sin uso en la declaración vacía"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of attributes in empty declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "declaración vacía"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 no admite %<static%> o calificadores de tipo en los declaradores de parámetros de matrices"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 no admite declaradores de matriz %<[*]%>"
@@ -42194,29 +42224,29 @@ msgstr "ISO C90 no admite declaradores de matriz %<[*]%>"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "no se permite %<[*]%> en otro lugar que no sea el ámbido de prototipo de función"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D generalmente es una función"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD está inicializado (utilice __typeof__ en su lugar)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "la función %qD está inicializada como una variable"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "el parámetro %qD está inicializado"
@@ -42225,273 +42255,273 @@ msgstr "el parámetro %qD está inicializado"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "la variable %qD tiene inicializador pero de tipo de dato incompleto"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %q+D given attribute %qs"
 msgstr "se le dió a la función incluida en línea %q+D un atributo noinline"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "el miembro const sin inicializar en %qT es no válido en C++"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD se debe inicializar"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "el inicializador no puede determinar el tamaño de %q+D"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "falta el tamaño de la matriz en %q+D"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "matriz %q+D de tamaño cero o negativo"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "el tamaño de almacenamiento de %q+D no es constante"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "se descarta el especificador asm para la variable local que no es estática %q+D"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "no se puede poner un objeto con un campo volatile en register"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD is invalid in C++"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "const %qD sin inicializar es no válida en C++"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D en directiva de objetivo de declaración no tiene tipo asociable"
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C prohíbe declaraciones adelantadas de parámetros"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "definir un tipo en una literal compuesta es no válido en C++"
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "la anchura del campo de bits %qs no es una constante entera"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "la anchura del campo de bits %qs no es una expresión constante entera"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "anchura negativa en el campo de bit %qs"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "anchura cero para el campo de bits %qs"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "el campo de bits %qs tiene un tipo no válido"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "no se puede declarar el campo de bits %qs con un tipo %<warn_if_not_aligned%>"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "el tipo de campo de bits %qs es una extensión de GCC"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "la anchura de %qs excede su tipo"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs es más estrecho que los valores de su tipo"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 prohíbe la matriz %qE cuyo tamaño no se puede evaluar"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 prohíbe la matriz cuyo tamaño no se puede evaluar"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 prohíbe la matriz de longitud variable"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "%qE variablemente modificado en el ámbito del fichero"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "campo variablemente modificado en el ámbito del fichero"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "el tipo de dato por defecto es %<int%> en la declaración de %qE"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "el tipo de dato por defecto es %<int%> en el nombre de tipo"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "%<const%> duplicado"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "%<restrict%> duplicado"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "%<volatile%> duplicado"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "%<_Atomic%> duplicado"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "espacios de direcciones nombrados generan un conflicto (%s vs %s)"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "tipo matriz cualificado %<_Atomic%>"
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "la definición de la función se declaró como %<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "la definición de la función se declaró como %<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "la definición de la función se declaró como %<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "la definición de la función se declaró como %<auto%>"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "se especificó una clase de almacenamiento para el campo de la estructura %qE"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "se especificó una clase de almacenamiento para el campo de la estructura"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "se especificó una clase de almacenamiento para el parámetro %qE"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "se especificó una clase de almacenamiento para un parámetro sin nombre"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "se especificó una clase de almacenamiento para el nombre de tipo"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE se inicializó y declaró como %<extern%>"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE tiene %<extern%> e inicializador al mismo tiempo"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "la declaración del ámbito de fichero de %qE especifica %<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "la declaración del ámbito de fichero de %qE especifica %<register%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "la función anidada %qE se declaró %<extern%>"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "el ámbito de la función %qE es implícitamente auto y declarado %qs"
@@ -42499,715 +42529,715 @@ msgstr "el ámbito de la función %qE es implícitamente auto y declarado %qs"
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static o calificadores de tipo en un declarador de matriz que no es parámetro"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "la declaración de %qE como una matriz de voids"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "declaración de nombre de tipo como una matriz de voids"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "declaración de %qE como una matriz de funciones"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "declaración de nombre de tipo como una matriz de funciones"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "uso no válido de una estructura con un miembro de matriz flexible"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "el tamaño de la matriz %qE es de un tipo no entero"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "el tamaño de la matriz sin nombre es de un tipo no entero"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "el tamaño de la matriz %qE es de un tipo incompleto"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "el tamaño de la matriz sin nombre es de un tipo incompleto"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C prohíbe la matriz %qE de tamaño cero"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C prohíbe matrices de tamaño cero"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "el tamaño de la matriz %qE es negativo"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "el tamaño de la matriz sin nombre es negativo"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "el tamaño de la matriz %qE es demasiado grande"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "el tamaño de la matriz sin nombre es demasiado grande"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "el tipo matriz tiene tipo de elemento %qT incompleto"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de %qE como una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE que se declaró como función devuelve una función"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "el nombre de tipo que se declaró como función devuelve una función"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE que se declaró como función devuelve una matriz"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "el nombre de tipo que se declaró como función devuelve una matriz"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "la definición de la función tiene un tipo de devolución void calificado"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "tipo de función calificada %<_Atomic%>"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C prohíbe los tipos de función calificados"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs combinado con el calificador %<auto%> para %qE"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs combinado con el calificador %<register%> para %qE"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "se especificó %qs para la variable auto %qE"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "se especificó %qs para el parámetro %qE"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "se especificó %qs para el parámetro sin nombre"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "se especificó %qs para el campo de estructura %qE"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "se especificó %qs para el campo de estructura"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "el campo de bits %qE tiene un tipo atómico"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "el campo de bits tiene un tipo no atómico"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "se especificó la alineación para la definición de tipo %qE"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "se especificó la alineación para el objeto %<register%> %qE"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "se especificó la alineación para el parámetro %qE"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "se especificó la alineación para el parámetro sin nombre"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "se especificó la alineación para el campo de bits %qE"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "se especificó la alineación para el campo de bits sin nombre"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "se especificó la alineación para la función %qE"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "los especificadores %<_Alignas%> no pueden reducir la alineación de %qE"
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "los especificadores %<_Alignas%> no pueden reducir la alineación del campo sin nombre"
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "la definición de tipo %q+D se declaró como %<inline%>"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "la definición de tipo %q+D se declaró como %<_Noreturn%>"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C prohíbe los tipos de función const o volatile"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un miembro de una estructura o union no puede tener un tipo modificado variablemente"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "se declaró la variable o campo %qE como void"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "se descartan los atributos en los declaradores de parámetros de matriz"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "el parámetro %q+D se declaró %<inline%>"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "el parámetro %q+D se declaró %<_Noreturn%>"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "el campo %qE se declaró como una función"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "el campo %qE tiene tipo de dato incompleto"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "el campo sin nombre tiene tipo de dato incompleto"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "clase de almacenamiento no válida para la función %qE"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "no se puede incluir en línea la función %<main%>"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> se declaró como %<_Noreturn%>"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 no admite %<_Noreturn%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 no admite %<_Noreturn%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "una variable previamente declarada como %<static%> se redeclara como %<extern%>"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "la variable %q+D se declaró como %<inline%>"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "la variable %q+D se declaró como %<_Noreturn%>"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "función no anidada con tipo modificado variablemente"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "un objeto con tipo modificado variablemente no debe tener enlace"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "la declaración de la función no es un prototipo"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "nombres de parámetros (sin tipos) en la declaración de la función"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "el parámetro %u (%q+D) tiene tipo incompleto"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "el parámetro %u tiene tipo incompleto"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "el parámetro %u (%q+D) tiene tipo void"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "el parámetro %u tiene tipo void"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "no se puede calificar %<void%> si es el único parámetro"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> debe ser el único parámetro"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "el parámetro %q+D sólo tiene una declaración posterior"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "%<%s %E%> declarado dentro de la list de parámetros no será visible fuera de esta definición o declaración"
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "se definió el tipo enum aquí"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "se definió struct aquí"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "se definió union aquí"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "redefinición de %<union %E%>"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "redefinición de %<struct %E%>"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "redefinición anidada de %<union %E%>"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "redefinición anidada de %<struct %E%>"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "la definición de tipo en %qs es no válida en C++"
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la declaración no declara nada"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 no admite structs/unions sin nombre"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 no admite structs/unions sin nombre"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "miembro %q+D duplicado"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr "una struct vacía tiene tamaño 0 en C y tamaño 1 en C++"
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "una union vacía tiene tamaño 0 en C y tamaño 1 en C++"
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union no tiene miembros nombrados"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union no tiene miembros"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct no tiene miembros nombrados"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct no tiene miembros"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "miembro de matriz flexible en union"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "miembro de matriz flexible en estructura sin miembros con nombre"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "el tipo %qT es demasiado grande"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union no se puede hacer transparente"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "redefinición anidada de %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeclaración de %<enum %E%>"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "el modo especificado es demasiado pequeño para valores enumerados"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "los valores de enumeración exceden el rango del entero más grande"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "el valor de enumerador para %qE no es una constante entera"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "el valor de enumerador para %qE no es una expresión constante entera"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "desbordamiento en valores de enumeración"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C restringe los valores de enumeración al rango de %<int%>"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "se le dió a la función incluida en línea %qD un atributo noinline"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "el tipo de devolución es un tipo de dato incompleto"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "el tipo de devolución por defecto es %<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "Avisa sobre funciones globales sin prototipos"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "no hay un prototipo previo para %qD"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "se usó %qD sin prototipo antes de su definición"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "no hay declaración previa para %qD"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "se usó %qD sin declaración antes de su definición"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "el tipo de devolución de %qD no es %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "calificado %<_Atomic%> el tipo de retorno de %qD"
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD generalmente es una función que no es static"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "declaraciones de parámetros de estilo antiguo en la definición de una función prototipo"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "C tradicional rechaza la definición de funciones de estilo ISO C"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "ISO C no admite coma flotante decimal"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "definición de función de estilo antiguo"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "falta el nombre del parámetro de la lista de parámetros"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "múltiples parámetros nombrados %qD"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "el tipo de %qD es %<int%> por defecto"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "el parámetro %qD tiene tipo incompleto"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "existe la declaración para el parámetro %qD pero no hay tal parámetro"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "el número de argumentos no coinciden con el prototipo interno"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "el número de argumentos no coinciden con el prototipo"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "declaración de prototipo"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "el argumento promovido %qD no coincide con el prototipo interno"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "el argumento promovido %qD no coincide con el prototipo"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "el argumento %qD no coincide con el prototipo interno"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "el argumento %qD no coincide con el prototipo"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "se definió el parámetro %qD pero no se usa"
@@ -43215,260 +43245,260 @@ msgstr "se definió el parámetro %qD pero no se usa"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "sólo se permiten las declaraciones iniciales del bucle %<for%> en modo C99 o C11"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "use la opción -std=c99, -std=gnu99, -std=c11 o -std=gnu11 para compilar su código"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 no admite declaradores de matriz %<[*]%>"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable static %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable %<extern%> %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de %qD que no es variable en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "calificadores de espacio de direcciones incompatibles %qs y %qs"
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "especificador %qE de declaración duplicado"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dos o más tipos de datos en los especificadores de la declaración"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> es demasiado largo para GCC"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 no admite %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 no admite tipos complejos"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C no admite tipos saturantes"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE duplicado"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C no admite los tipos %<__int%d%>"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "no se admite %<__int%d%> para este objetivo"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 no admite tipos booleanos"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C no admite el tipo %<_float%d%s%>"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "no se admite %<_float%d%s%> para este objetivo"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C no admite coma flotante decimal"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "no se admiten tipos de coma fija para este objetivo"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C no admite tipos de coma fija"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "la búsqueda en C++ de %qD devolvería un campo, no un tipo"
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE falla al ser un typedef o un tipo interno del compilador"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE no está al inicio de la declaración"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "se usó %qE con %<auto%>"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "se usó %qE con %<register%>"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 no admite %qE"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 no admite %qE"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> antes de %<extern%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> antes de %<static%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "%<_Thread_local%> o %<__thread%> duplicado"
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "múltiples clases de almacenamiento en los especificadores de declaración"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "se usó %qs con %qE"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "se usó %<_Sat%> sin %<_Fract%> o %<_Accum%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C no admite tipos enteros complejos"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "el combinador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "el nicializador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_priv%> ni %<omp_orig%>"
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "desplazamiento a la izquierda o valor negativo"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "la cuenta de desplazamiento a la izquierda es negativa"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "cuenta de desplazamiento a la izquierda >= anchura del tipo"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "cuenta de desplazamiento a la derecha >= anchura del tipo"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "cuenta de desplazamiento a la izquierda >= anchura del elemento del vector"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "cuenta de desplazamiento a la derecha >= anchura del elemento del vector"
@@ -43489,7 +43519,7 @@ msgstr "marcador de conflicto en control de versiones en el fichero"
 msgid "to match this %qs"
 msgstr "%J  otro tipo aquí"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "se esperaba fin de línea"
@@ -43499,7 +43529,7 @@ msgstr "se esperaba fin de línea"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C prohíbe una unidad de traducción vacía"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
@@ -43536,7 +43566,7 @@ msgid "unknown type name %qE"
 msgstr "nombre de tipo %qE desconocido"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "se esperaban especificadores de declaración"
@@ -43557,7 +43587,7 @@ msgstr "el atributo %<fallthrough%> no está seguido de %<;%>"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "se esperaba %<;>, identificador o %<(%>"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "se descartan los atributos de prefijo para los métodos"
@@ -43572,7 +43602,7 @@ msgstr "se descartan los atributos de prefijo para las implementaciones"
 msgid "unexpected attribute"
 msgstr "atributo inesperado"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "el atributo %<fallthrough%> no está seguido de %<;%>"
@@ -43610,7 +43640,7 @@ msgstr "%<__auto_type%> requiere una declaración de datos inicializados"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> sólo se puede utilizar con una declaración simple"
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "se esperaba %<,%> o %<;%>"
@@ -43669,7 +43699,7 @@ msgstr "la expresión en la aserción static no es una constante"
 msgid "static assertion failed: %E"
 msgstr "falló la aserción estática: %E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -43716,14 +43746,14 @@ msgstr "un enum vacío no es válido"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "se esperaba un identificador"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "coma al final de la lista de enumeradores"
@@ -43809,7 +43839,7 @@ msgstr "se esperaban especificadores de declaración o %<...%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "los paquetes de parámetros deben estar al final de la lista de parámetros"
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "%qE attribute does not take any arguments"
@@ -43871,7 +43901,7 @@ msgstr "ISO C90 prohíbe mezclar declaraciones y código"
 msgid "expected %<}%> before %<else%>"
 msgstr "se esperaba %<}%> antes de %<else%>"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> sin un %<if%> previo"
@@ -43886,7 +43916,7 @@ msgstr "etiqueta al final de una declaración compuesta"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "se esperaba una declaración"
@@ -43911,17 +43941,17 @@ msgstr "se esperaba un identificador o %<*%>"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "solo el atributo %<fallthrough%> se puede aplicar a sentencias nulas"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<if%>"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<else%>"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "se sugieren llaves explícitas para evitar un %<else%> ambiguo"
@@ -43941,12 +43971,12 @@ msgstr "múltiples variables de iteración en una enumeración rápida"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "variable de iteración no válida en la enumeración rápida"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "falta la condición del bucle en bucle con pragma %<GCC ivdep%>"
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "falta la condición del bucle en bucle con pragma %<GCC unroll%>"
@@ -43962,8 +43992,8 @@ msgstr "falta la colección en la enumeración rápida"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "calificador-cv duplicado"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "first seen here"
@@ -43993,12 +44023,12 @@ msgstr "ISO C prohíbe la omisión del término medio de una expresión ?:"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "la división %<sizeof (%T) / sizeof (%T)%> no computa el número de elementos del array"
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "el primer operando %<sizeof%> se declaró aquí"
@@ -44392,13 +44422,13 @@ msgstr "se esperaba una declaración método objective-c"
 msgid "no type or storage class may be specified here,"
 msgstr "ninguna clase de almacenamiento o tipo se puede especificar aquí,"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "empty property attribute list"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -44410,55 +44440,55 @@ msgstr "falta el atributo Code"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %<@%> before Objective-C string"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "%<@%> repetida antes de la cadena Objective-C"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected %qE selector name"
 msgstr "se esperaba una declaración de selección"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, fuzzy, gcc-internal-format
 #| msgid "setter name must terminate with %<:%>"
 msgid "setter method names must terminate with %<:%>"
 msgstr "el nombre del setter debe terminar con %<:%>"
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> requiere una expresión de asignación que evaluada dé una constante entera no negativa menor que %u"
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> debe estar en el alcance del fichero"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
@@ -44469,18 +44499,18 @@ msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "se esperaba una declaración for, while o do"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "demasiadas cláusulas %qs"
@@ -44501,53 +44531,53 @@ msgstr "se esperaba %<,%> o %<)%>"
 msgid "%qD is not a variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD no es una variable puntero"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "se esperaba %<none%> o %<present%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "se esperaba %<none%> o %<shared%>"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "se esperaba %<data%>, %<update%>, %<enter%> o %<exit%>"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "se esperaba %<data%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "demasiadas cláusulas %<if%>"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "demasiadas cláusulas %<if%> sin modificador"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si alguna cláusula %<if%> tiene modificador, entonces todas las cláusulas %<if%> tienen que usar modificador"
@@ -44569,116 +44599,116 @@ msgstr "el valor de %<num_threads%> debe ser positivo"
 msgid "%<num_tasks%> value must be positive"
 msgstr "el valor de %<num_tasks%> debe ser positivo"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "el valor de %<grainsize%> debe ser positivo"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "el valor de %<priority%> debe ser no negativo"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "se esperaba una expresión entera"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> o %<max%>"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "la expresión %qs debe ser integral"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "el valor de %qs debe ser positivo"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "demasiados argumentos %<static%>"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argumento inesperado"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "el argumento de %<tile%> necesita una constante entera positiva"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<concurrent%>"
 msgstr "se esperaba %<new%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> o identificador"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "se usaron al mismo tiempo los modificadores %<monotonic%> y %<nonmonotonic%>"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<runtime%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<auto%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "género de planificador no válido"
@@ -44688,18 +44718,18 @@ msgstr "género de planificador no válido"
 msgid "%<num_teams%> value must be positive"
 msgstr "el valor de %<num_teams%> debe ser positivo"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "el valor de %<thread_limit%> debe ser positivo"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -44722,23 +44752,23 @@ msgstr "%Hel argumento de collapse necesita ser una expresión entera constante
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "el modificador de característica %qs es incompatible con %s %s"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "tipo de dependencia no válida"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "tipo de mapa no válida"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -44756,83 +44786,83 @@ msgstr "género de planificador no válido"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "se esperaba una cláusula %<#pragma acc%>"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs no es válido para %qs"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs debe ser la primera cláusula de %qs"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "no hay cláusulas válidas especificadas en %<#pragma acc declare%>"
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "sección de matriz en %<#pragma acc declare%>"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD debe ser una variable global en %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "cláusula OpenACC no válida en el alcance del fichero"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de la variable %<extern%> %qD en %<#pragma acc declare%>"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de la variable %<global%> %qD en %<#pragma acc declare%>"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD debe ser una variable global en %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "La variable %qD se usa más de una vez con %<#pragma acc declare%>"
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "se esperaba %<data%> después de %<#pragma acc %s%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> no tiene cláusula de movimiento de datos"
@@ -44847,7 +44877,7 @@ msgstr "%qE no se ha declarado"
 msgid "expected function name"
 msgstr "se esperaba nombre de función"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD no hace referencia a una función"
@@ -44857,27 +44887,27 @@ msgstr "%qD no hace referencia a una función"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> no está inmediatamente seguido de una declaración o definición de función"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> no está inmediatamente seguido de una única declaración o definición de función"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> debe aplicarse antes de uso"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> debe aplicarse antes de definición"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> debe contener al menos una cláusula %<device%>, %<host%> o %<self%>"
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<allocator%>"
@@ -44888,94 +44918,94 @@ msgstr "se esperaba %<operator%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable ya no se admite"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> o identificador"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forma no válida de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operador no válido para %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> usa dos expresiones diferentes para la memoria"
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "se esperaba %<data%>, %<update%>, %<enter%> o %<exit%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, fuzzy, gcc-internal-format
 #| msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgid "%<flush%> list specified together with memory order clause"
@@ -44986,34 +45016,34 @@ msgstr "la cláusula %<linear%> no puede especificarse junto con la cláusula %<
 msgid "expected %<(%> or end of line"
 msgstr "se esperaba %<(%> o fin de línea"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<present%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "se esperaba %<none%> o %<present%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "el parámetro de la cláusula %<ordered%> es menor que %<collapse%>"
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "la cláusula %<linear%> no puede especificarse junto con la cláusula %<ordered%> con un parámetro"
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "se esperaba una declaración de iteración o una inicialización"
@@ -45023,74 +45053,74 @@ msgstr "se esperaba una declaración de iteración o una inicialización"
 msgid "not enough perfectly nested loops"
 msgstr "no hay suficientes bucles perfectamente anidados"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "los bucles colapsados no están perfectamente anidados"
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable de iteración %qD no debe ser firstprivate"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "se esperaba %<fork%> después de %qs"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "se esperaba %<point%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> con map-type distinto de %<to%>, %<from%>, %<tofrom%> y %<alloc%> en la cláusula %<map%>"
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> con map-type distinto de %<to%> y %<alloc%> en la cláusula %<map%>"
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> con map-type distinto de %<from%>, %<release%> y %<delete%> en la cláusula %<map%>"
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> con map-type distinto de %<to%>, %<from%>, %<tofrom%> y %<alloc%> en la cláusula %<map%>"
@@ -45107,67 +45137,67 @@ msgstr "%<#pragma omp declare simd%> debe ir seguida de una declaración o defin
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> debe ir seguida de una declaración o definición de función"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "se esperaba una declaración de selección"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, fuzzy, gcc-internal-format
 #| msgid "constructor not allowed for non-vector types"
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "no se permite un constructor para tipos que no sean vectores"
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%<no-custom-%s%> no acepta argumentos"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "score argument must be non-negative"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "se esperaba una cadena literal"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "se esperaba una expresión entera"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, fuzzy, gcc-internal-format
 #| msgid "property %qs already specified in %<@synthesize%>"
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "la propiedad %qs ya se especificó en %<@synthesize%>"
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "se esperaba %<data%>, %<update%>, %<enter%> o %<exit%>"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -45179,13 +45209,13 @@ msgstr "se esperaba %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "'%s' en %L no es una función"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 #| msgid "%qs and %qs are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%qs y %qs son incompatibles"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -45196,33 +45226,33 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> no inmediatamente seguida de una declaración o definición de función"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> no inmediatamente seguida de una declaración o definición de función sencilla"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "se esperaba %<target%>"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "se esperaba %<declare%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> sin su correspondiente %<#pragma omp declare target%>"
@@ -45277,45 +45307,45 @@ msgstr "se esperaba nombre-de-función %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "se esperaba %<simd%>, %<reduction%> o %<target%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "aún no se admite el modelo de código %<large%>"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<pragma omp requires%> requires at least one clause"
@@ -45333,27 +45363,27 @@ msgstr "ISO C prohíbe los tipos de función calificados"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE se declaró %<threadprivate%> después del primer uso"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE tiene tipo incompleto"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sin activar el soporte para memoria transaccional"
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> dentro de un %<__transaction_relaxed%>"
@@ -45364,7 +45394,7 @@ msgstr "%<__transaction_cancel%> dentro de un %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "la llamada a la función %<transaction_may_cancel_outer%> no está en una transacción más externa o %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> no está dentro de %<__transaction_atomic%>"
@@ -45379,7 +45409,7 @@ msgstr "llave sin cerrar"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD tiene un tipo de dato incompleto %qT"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "uso no válido de la expresión void"
@@ -45421,130 +45451,130 @@ msgstr "el atributo %qE no está disponible para funciones con un número variab
 msgid "function types not truly compatible in ISO C"
 msgstr "los tipos de función no son totalmente compatibles en ISO C"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and vector types"
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "no se pueden mezclar operandos de tipos de coma flotante decimal y vector"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and complex types"
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "no se pueden mezclar operandos de tipos de coma flotante decimal y complejos"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and other float types"
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "no se pueden mezclar operandos de tipos de coma flotante decimal otros tipos de coma flotante"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "los punteros a matrices con calificadores distintos son incompatibles en ISO C"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "los tipos no son totalmente compatibles"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "tipos de objetivo a incompatibles en C++"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "los tipos de devolución de función no son compatibles debido a %<volatile%>"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "la conversión de una literal compuesta de matriz a un puntero está malformada en C++"
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT no tiene un miembro llamado %qE; ¿quiso decir %qE?"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr "accediendo a un miembro %qE de una estructura atómica %qE"
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "accediendo a un miembro %qE de una unión atómica %qE"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr "%qE es un puntero; ¿pretendía utilizar %<->%>?"
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "petición del miembro %qE en algo que no es una estructura o unión"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "el valor del subíndice no es ni matriz ni puntero ni vector"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "el subíndice de la matriz no es un entero"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "el valor de subíndice es un puntero a función"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C prohíbe el subíndice de una matriz %<register%>"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C90 prohíbe el subíndice de una matriz no-lvaluada"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr "se definió la constante enum aquí"
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> sobre el parámetro matriz %qE de función devolverá el tamaño de %qT"
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "el objeto %qE llamado no es una función ni un puntero a función"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "el objeto %qD llamado no es una función ni un puntero a función"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "el objeto llamado no es una función ni un puntero a función"
@@ -45552,1666 +45582,1666 @@ msgstr "el objeto llamado no es una función ni un puntero a función"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "función llamada a través de un tipo de dato que no es compatible"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "se llamó a una función con tipo de devolución void calificado"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "el tipo de dato del parámetro formal %d está incompleto"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "se pasa el argumento %d de %qE como entero en lugar de coma flotante debido al prototipo"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "se pasa el argumento %d de %qE como entero en lugar de complejo debido al prototipo"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "se pasa el argumento %d de %qE como complejo en lugar de coma flotante debido al prototipo"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "se pasa el argumento %d de %qE como coma flotante en lugar de entero debido al prototipo"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "se pasa el argumento %d de %qE como complejo en lugar de entero debido al prototipo"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "se pasa el argumento %d de %qE como coma flotante en lugar de complejo debido al prototipo"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "se pasa el argumento %d de %qE como %<float%> en lugar de %<double%> debido al prototipo"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "se pasa el argumento %d de %qE como %qT en lugar de %qT debido al prototipo"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "se pasa el argumento %d de %qE con anchura diferente debido al prototipo"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "se pasa el argumento %d de %qE como unsigned debido al prototipo"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "se pasa el argumento %d de %qE como signed debido al prototipo"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "demasiados argumentos para el método %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "demasiados argumentos para la función %qE"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "conversión implícita de %qT a %qT al pasar el argumento a la función"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "faltan argumentos para la función %qE"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "la comparación con una literal de cadena resulta en una conducta no especificada"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "comparación entre puntero y entero"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "¿pretendía desreferenciar el puntero?"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "comparación entre %qT y %qT"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "se usó un puntero de tipo %<void *%> en la sustracción"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "se utilizó un puntero a una función en la sustracción"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmética en puntero a un tipo de dato incompleto"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmética en puntero a un agregado vacío"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> en una expresión booleana"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "¿pretendía utilizar la negación lógica?"
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C no admite %<~%> para conjugaciones complejas"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "argumento de tipo erróneo para abs"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "argumento de tipo erróneo para el signo de exclamación unario"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "el incremento de un valor de enumeración es no válido en C++"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "el decremento de un valor de enumeración es no válido en C++"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "incremento de una expresión booleana"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "decremento de una expresión booleana"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C no admite %<++%> y %<--%> en tipos complejos"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "argumento de tipo erróneo para el incremento"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "argumento de tipo erróneo para el decremento"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "incremento de puntero a un tipo incompleto %qT"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "decremento de puntero a un tipo incompleto %qT"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "se toma la dirección de la expresión de tipo %<id%>"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "no se puede tomar la dirección del campo de bits %qD"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of an unaligned member"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "no se puede tomar la dirección de un miembro desalineado"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "se solicitó la dirección de la variable de registro %qD"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "se usó la variable de registro global %qD en la función anidada"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "se usó la variable de registro %qD en la función anidada"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "se solicitó la dirección de la variable de registro global %qD"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "se solicitó la dirección de la variable de registro %qD"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "matriz no-lvaluada en la expresión condicional"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro resultado del condicional"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, fuzzy, gcc-internal-format
 #| msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr "un operando de ?: cambia de tipo de signo de %qT a %qT debido al tipo sin signo de otro operando"
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C prohíbe una expresión condicional con sólo un lado void"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "se usaron punteros a espacios de direcciones discontinuos en la expresión condicional"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "el puntero a matriz pierde el calificador en la expresión condicional"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C prohíbe expresiones condicionales entre %<void *%> y punteros de función"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "los tipos de datos punteros no coinciden en la expresión condicional"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "los tipos de datos punteros no coinciden en la expresión condicional"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "los tipos de datos punteros/enteros no coinciden en la expresión condicional"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "los tipos de datos no coinciden en la expresión condicional"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "in call to %qD, declared here"
 msgstr "%qD se declara aquí"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "el operador del lado izquierdo de la expresión coma no tiene efecto"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "el operador del lado derecho de la expresión coma no tiene efecto"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr "la conversión agrega el calificador %q#v al tipo de función"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "la conversión descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "para estar seguro todos los punteros intermedios en la conversión de %qT a %qT se deben calificar como %<const%>"
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "la conversión especifica el tipo matriz"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "la conversión especifica el tipo función"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C prohíbe la conversión de un no escalar al mismo tipo"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C prohíbe la conversión al tipo union"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "conversión a tipo union desde un tipo no presente en union"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "conversión al puntero de espacio de direcciones %s desde un puntero de espacio de direcciones genérico discontinuo"
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "conversión a un puntero de espacio de direcciones genérico desde un puntero de espacio de direcciones %s discontinuo"
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "conversión a un puntero de espacio de direcciones %s desde un puntero de espacio de direcciones %s discontinuo"
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "la conversión incrementa la alineación requerida del tipo del destino"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "conversión de puntero a entero de tamaño diferente"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "conversión desde una llamada a función de tipo %qT al tipo %qT que no coincide"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "conversión a puntero desde un entero de tamaño diferente"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C prohíbe la conversión de un apuntador a función a un tipo de objeto apuntador"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C prohíbe la conversión de objeto apuntador a un tipo de apuntador a función"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "conversión entre tipos de función incompatibles desde %qT a %qT"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "definir un tipo en una conversión es no válido en C++"
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "asignación a expresión con tipo matriz"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "conversión de enum en una asignación es no válido en C++"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(cerca de la inicialización de %qs)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "matriz inicializada con una constante de cadena entre paréntesis"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "se esperaba %qT pero el argumento es de tipo %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "built-in %qD declared here"
 msgstr "la rutina %qD se declara aquí"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "la conversión de enum al pasar el argumento %d de %qE es no válido en C++"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "la conversión de enum desde %qT a %qT en una asignación no es válida en C++"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "la conversión de enum desde %qT a %qT en una inicialización no es válida en C++"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "la conversión de enum desde %qT a %qT en un return no es válida en C++"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %q#T to %q#T"
 msgid "implicit conversion from %qT to %qT"
 msgstr "conversión de %q#T a %q#T"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "el paso del argumento %d de %qE hace que la función calificada con %q#v apunte desde una no calificada"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "la asignación hace que la función calificada con %q#v apunte desde una no calificada"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "la inicialización hace que la función calificada con %q#v apunte desde una no calificada"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "la devolución hace que la función calificada con %q#v apunte desde una no calificada"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "la asignación descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "la inicialización descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "la devolución descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C prohíbe la conversión de argumentos a tipo union"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "no se permite la petición para la conversión implícita de %qT a %qT en C++"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "se pasa el argumento %d de %qE desde un puntero a espacio de direcciones no contenido"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "asignación desde puntero a espacio de direcciones no contenido"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "inicialización desde puntero a espacio de direcciones no contenido"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "devolución desde puntero a espacio de direcciones no contenido"
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "el argumento %d de %qE puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la asignación puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la inicialización puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "el tipo de devolución puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "se pasa el argumento %d de %qE desde un tipo de puntero incompatible"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, fuzzy, gcc-internal-format
 #| msgid "assignment to %qT from incompatible pointer type %qT"
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "asignación a %qT desde un tipo de puntero %qT incompatible"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of %qT from incompatible pointer type %qT"
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "inicialización de %qT desde un tipo de puntero %qT incompatible"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, fuzzy, gcc-internal-format
 #| msgid "returning %qT from a function with incompatible return type %qT"
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "se devuelve %qT desde una función con tipo de devolución %qT incompatible"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C prohíbe el paso del argumento %d de %qE entre un puntero a función y %<void *%>"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C prohíbe la asignación entre un puntero a función y %<void *%>"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C prohíbe la inicialización entre un puntero a función y %<void *%>"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C prohíbe la devolución entre un puntero a función y %<void *%>"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "el puntero que apunta en el paso del argumento %d de %qE difiere en signo"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "el puntero que apunta en la asignación de %qT a %qT difiere en signo"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "el puntero que apunta en la inicialización de %qT a %qT difiere en signo"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "el puntero que apunta en el paso del argumento %d de %qE difiere en signo"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "se pasa el argumento %d de %qE desde un tipo de puntero incompatible"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "assignment to %qT from incompatible pointer type %qT"
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "asignación a %qT desde un tipo de puntero %qT incompatible"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "asignación a %qT desde un tipo de puntero %qT incompatible"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of %qT from incompatible pointer type %qT"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "inicialización de %qT desde un tipo de puntero %qT incompatible"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "inicialización de %qT desde un tipo de puntero %qT incompatible"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "returning %qT from a function with incompatible return type %qT"
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "se devuelve %qT desde una función con tipo de devolución %qT incompatible"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "se devuelve %qT desde una función con tipo de devolución %qT incompatible"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "el paso del argumento %d de %qE crea un puntero desde un entero sin una conversión"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "la asignación a %qT desde %qT crea un puntero desde un entero sin una conversión"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "la inicialización de %qT desde %qT crea un puntero desde un entero sin una conversión"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "el retorno de %qT desde una función con tipo de retorno %qT crea un puntero desde un entero sin una conversión"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "el paso del argumento %d de %qE crea un entero desde un puntero sin una conversión"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "la asignación a %qT desde %qT crea un entero desde un puntero sin una conversión"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "la inicialización de %qT desde %qT crea un entero desde un puntero sin una conversión"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "el retorno de %qT desde una función con tipo de retorno %qT crea un entero desde un puntero sin una conversión"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "tipo incompatible para el argumento %d de %qE"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "tipos incompatible en la asignación al tipo %qT del tipo %qT"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "tipos incompatibles en la inicialización del tipo %qT usando el tipo %qT"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "tipos incompatible al devolver el tipo %qT pero se esperaba %qT"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "C tradicional rechaza la inicialización automática de agregados"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of %qT from incompatible pointer type %qT"
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "inicialización de %qT desde un tipo de puntero %qT incompatible"
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "matriz de tipo inapropiado inicializada con una constante de cadena"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "uso no válido de matriz no-lvaluada"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "el elemento inicializador no es una constante"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "matriz inicializada con una expresión matrizal que no es constante"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "el elemento inicializador no es calculable al momento de la carga"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "inicializador no válido"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "no se pueden inicializar los tipos de vector opacos"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "grupo extra de llaves al final del inicializador"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "llaves alrededor del inicializador escalar"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inicialización de un miembro de matriz flexible en un contexto anidado"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "faltan llaves alrededor del inicializador"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "falta el inicializador para el campo %qD de %qT"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "inicializador escalar vacío"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "elementos extras en el inicializador escalar"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "índice de matriz en el inicializador que no es matriz"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "el nombre del campo no está en el inicializador de record o union"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "el índice de matriz en el inicializador no es de tipo entero"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "el índice de matriz en el inicializador no es una expresión constante entera"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "el índice de matriz no es una constante en el inicializador"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "el índice de matriz en el inicializador excede los límites de la matriz"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "rango de índices vacío en el inicializador"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "el rango de índices de la matriz en el inicializador excede los límites de la matriz"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "campo inicializado con efectos colaterales sobreescritos"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "campo inicializado sobreescrito"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "la conversión de enum en la inicialización es no válida en C++"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "exceso de elementos en el inicializador de matriz de caracteres"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "exceso de elementos en el inicializador de struct"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "inicialización posicional de un campo de %<struct%> declarado con el atributo %<designated_init%>"
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "inicialización no estática de un miembro de matriz flexible"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "exceso de elementos en el inicializador de union"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "C tradicional rechaza la inicialización de unions"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "exceso de elementos en el inicializador de matriz"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "exceso de elementos en el inicializador de vector"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "exceso de elementos en el inicializador de escalar"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C prohíbe %<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la función declarada %<noreturn%> tiene una declaración %<return%>"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> sin valores, en una función que no devuelve void"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> con valor, en una función que devuelve void"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C prohíbe %<return%> con expresión, en una función que devuelve void"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "la función devuelve la dirección de una etiqueta"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "la cantidad de switch no es un entero"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "no se convierte la expresión de switch %<long%> a %<int%> en ISO C"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "la etiqueta de case no es una expresion constante entera"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "la etiqueta case no se encuentra dentro de una declaración switch"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "la etiqueta %<default%> no está dentro de una declaración switch"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "la declaración break no está dentro de un bucle o switch"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "salida no válida de un bloque estructurado OpenMP"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "se usó la declaración break en un bucle for de OpenMP"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "la declaración continue no está dentro de un bucle"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "declaración sin efecto"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "la declaración de la expresión tiene tipo de dato incompleto"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "se comparan vectores con tipos de elemento diferentes"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "se comparan vectores con números de elementos diferentes"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "no se puede encontrar un tipo entero del mismo tamaño que %qT"
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "no es segura la comparacion de coma flotante con == o !="
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "la comparación siempre se evalúa como %<false%> para la dirección de %qD que nunca será NULL"
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "la comparación siempre se evalúa como %<true%> para la dirección de %qD que nunca será NULL"
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "la comparación de punteros a espacios de direcciones discontinuos"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C prohíbe la comparación de %<void *%> con un puntero de función"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "la comparación de diferentes tipos de puntero carece de una conversión"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "comparación entre puntero y entero"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "comparación de punteros completos e incompletos"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C prohíbe la comparación entre punteros a funciones"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "comparación ordenada de puntero con un puntero nulo"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparación ordenada de puntero con el entero cero"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro operando de la expresión binaria"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "se usa un valor de tipo matriz que no se puede cambiar a puntero cuando se requiere un escalar"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "se usa un valor de tipo struct cuando se requiere un escalar"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "se usa un valor de tipo union cuando se requiere un escalar"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "se usa un tipo vector cuando se requiere un escalar"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> debe especificar una de las cláusulas %<parallel%>, %<for%>, %<sections%> o %<taskgroup%>"
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<parallel%> or %<target%> %<if%> clause modifier"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "se esperaba el modificador de cláusula %<parallel%> o %<target%> %<if%>"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> debe especificar una de las cláusulas %<parallel%>, %<for%>, %<sections%> o %<taskgroup%>"
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE en cláusula %qs"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "campo de bits %qE en cláusula %qs"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE no es un miembro de una unión"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qE in %qs clause"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "campo de bits %qE en cláusula %qs"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many %qs clauses"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%Hdemasiadas cláusulas %qs"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "la longitud %qE de la sección de matriz no es de tipo integral"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "expected single pointer in %qs clause"
 msgstr "El puntero Cray '%s' en la cláusula %s en %L"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "sección de matriz de longitud cero en la cláusula %qs"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "límite inferior negativo en sección de matriz en cláusula %qs"
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "longitud negativa en sección de matriz en cláusula %qs"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "límite inferior %qE por encima del tamaño de la sección de matriz en cláusula %qs"
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "longitud %qE por encima del tamaño de la sección de matriz en cláusula %qs"
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "límite superior %qE por encima del tamaño de la sección de matriz en cláusula %qs"
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for array function parameter length expression must be specified"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for pointer type length expression must be specified"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "la sección de matriz no es contigua en la cláusula %qs"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE no es de tipo puntero o matriz"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "arrojando NULL, que tiene un tipo integral, que no es puntero"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified array type"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "tipo matriz cualificado %<_Atomic%>"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "el parámetro %qD tiene tipo incompleto"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "campo de bits %qD con tipo no integral"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "condition expression refers to iteration variable %qD"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "la expresión de la condición hace referencia a la variable de iteración %qD"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "condition expression refers to iteration variable %qD"
 msgid "end expression refers to outer iterator %qD"
 msgstr "la expresión de la condición hace referencia a la variable de iteración %qD"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 #| msgid "initializer expression refers to iteration variable %qD"
 msgid "step expression refers to outer iterator %qD"
 msgstr "la expresión inicializadora hace referencia a la variable de iteración %qD"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected pointer in %qs clause"
 msgstr "se esperaba un puntero"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "aún no se admite el modelo de código %<large%>"
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "aún no se admite el modelo de código %<large%>"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD en la cláusula %<reduction%> es una matriz de tamaño cero"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "ISO C prohíbe los tipos de función calificados"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qE in %qs clause"
 msgid "zero sized type %qT in %qs clause"
 msgstr "campo de bits %qE en cláusula %qs"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qE in %qs clause"
 msgid "variable sized type %qT in %qs clause"
 msgstr "campo de bits %qE en cláusula %qs"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE tiene tipo no válido para %<reduction(%s)%>"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
 msgstr "No se encontró una definición de etiqueta para %qs"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE debe ser %<threadprivate%> para %<copin%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "cláusula lineal aplicada a variable no puntero no integral con tipo %qT"
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "cláusula %<linear%> paso %qE no es ni constante ni parámetro"
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de reducción"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE no es una variable en la cláusula %<firstprivate%>"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE no es una variable en la cláusula %<lastprivate%>"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE no es una variable en la cláusula %<saligned%>"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "%qE en la cláusula %<aligned%> no es un puntero ni una matriz"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE no es una variable en la cláusula %<saligned%>"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "No se permite una sección de matriz en la llamada '%s' en %L"
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "la fuente no es un puntero"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs no es un puntero ni una matriz"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la cláusula %<inbranch%> es incompatible con %<notinbranch%>"
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE está predeterminado como %qs para %qs"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "el valor de la cláusula %<simdlen%> es mayor que el valor de la cláusula %<safelen%>"
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "no se puede utilizar %<va_arg%> con orden de almacenamiento inverso"
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "el segundo argumento para %<va_arg%> es del tipo incompleto %qT"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ requiere un tipo promovido, no un tipo enum, en %<va_arg%>"
@@ -47443,7 +47473,7 @@ msgstr "  no hay una conversión de %qH a %qI"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  no hay una conversión conocida para el argumento %d de %qH a %qI"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -47562,729 +47592,735 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "conversión de %qH a %qI en una expresión constante convertida"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "la llamada del %<%D(%A)%> sobrecargado es ambigua"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "la función puntero-a-miembro %qE no se puede llamar sin un objeto; considere utilizar %<.*%> o %<->*%>"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "no hay coincidencia para la llamada a %<(%T) (%A)%>"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "la llamada de %<(%T) (%A)%> es ambigua"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "sobrecarga ambigua para "
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr "no hay coincidencia para "
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (los tipos de los operandos son %qT, %qT y %qT)"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "(los tipos de los operandos son %qT y %qT)"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr "(el tipo del operando %qT)"
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "ternary %<operator?:%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "no hay coincidencia para el %<operator?:%> terniario en %<%E ? %E : %E%>"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> en %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> en %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs en %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%>"
 msgid "%<operator %s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator%s%> en %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> en %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> en %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ prohíbe la omisión del término medio de una expresión ?:"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, fuzzy, gcc-internal-format
 #| msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "el tipo escalar %qT inferido no es un tipo entero ni coma flotante del mismo tamaño que %qT"
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "la conversión del escalar %qH al vector %qT implica truncado"
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "tipos de vector incompatibles en la expresión condicional: %qT, %qT y %qT"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "el segundo operando del operador condicional es del tipo %<void%>, pero el tercer operando no es una expresión throw ni del tipo %<void%>"
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "el tercer operando del operador condicional es del tipo %<void%>, pero el segundo operando no es una expresión throw ni del tipo %<void%>"
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "los operandos de ?: tienen tipos diferentes %qT y %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  y cada tipo puede convertirse al otro"
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "conversión implícita de %qH a %qI para coincidir con otro resultado del condicional"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "no coincide el enumeral en la expresión condicional: %qT vs %qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "la expresión condicional entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "la expresión condicional entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "tipos enumeral y no enumeral en la expresión condicional"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo, intentando en su lugar el operador prefijo"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "el tipo de devolución de %qD no es %<int%>"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "comparación entre %q#T y %q#T"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "función de desalojo %q+D sin ubicación"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "función de desalojo %q+D sin ubicación"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "no existe una función de desalojo correspondiente para %qD"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "no hay un %<operator %s%> adecuado para %qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "desde este contexto"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "se declara aquí"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "desde este contexto"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "se declara aquí"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D es inaccesible"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "se pasó NULL al argumento %P de %qD que no es puntero"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "  declared here"
 msgstr "se declara aquí"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "se convierte al tipo %qT que no es puntero desde NULL"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "se convierte %<false%> a tipo puntero para el argumento %P de %qD"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "se convierte %<false%> al tipo puntero %qT"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  argumento de inicialización %P de %qD"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "demasiadas llaves alrededor del inicializador para %qT"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 #| msgid "invalid user-defined conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "conversión definida por el usuario no válida de %qT a %qT"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "conversión no válida de %qT a %qT"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "la conversión a %qT desde la lista del inicializador usaría el constructor explícito %qD"
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "inicialización a un tipo de referencia volatile %q#T desde un r-valor de tipo %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+#| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
+
+#: cp/call.c:7911
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "inicialización a un tipo de referencia volatile %q#T desde un r-valor de tipo %qT"
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "no se puede unir el campo de bits %qE a %qT"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "no se unir el campo packed %qE a %qT"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "no se puede unir el r-valor %qE a %qT"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "conversión implícita de %qT a %qT al pasar el argumento a la función"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "el paso de objetos de tipo no-copiable-trivialmente %q#T a través de %<...%> se admite condicionalmente"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "no se puede recibir el tipo de referencia %qT a través de %<...%>"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "la recepción de objetos de tipo no-copiable-trivialmente %q#T a través de %<...%> se admite condicionalmente"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluación recursiva del argumento por defecto para %q#D"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "la llamada a %qD usa el argumento por defecto para el parámetro %P, el cual no se ha definido aún"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "el argumento de la llamada a función puede ser un candidato para un atributo de formato"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted function %q+D with default argument"
 msgid "use of multiversioned function without a default"
 msgstr "función definida por defecto %q+D con argumento por defecto"
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  en la llamada a %qD"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT no es una base inaccesible de %qT"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD no puede ser thread-local porque es de tipo %qT que no es trivial"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "use #include en su lugar"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "; use value-initialization instead"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD no puede ser thread-local porque es de tipo %qT que no es trivial"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "use #include en su lugar"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "; use copy-initialization instead"
 msgstr "Extensión: reinicialización de '%s' en %L"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "la conversión a void no accederá al objeto de tipo no-copiable-trivialmente %qT"
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%#qT declared here"
 msgstr "%qD se declara aquí"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "la constante se refiere a sí misma"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "no se puede convertir %qT a %qT"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "llamada a %qD que no es función"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "no se puede llamar directamente al constructor %<%T::%D%>"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "  for a function-style cast, remove the redundant %<::%D%>"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  para una conversión de estilo de función, borre el %<::%D%> redundante"
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "la llamada del %<%s(%A)%> sobrecargado es ambigua"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "virtual abstracto `%#D' llamado desde un constructor"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "virtual abstracto `%#D' llamado desde un destructor"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "no se puede llamar a la función miembro %qD sin un objeto"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "al pasar %qT se escoge %qT sobre %qT"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "se escoge %qD sobre %qD"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  para la conversión de %qT a %qT"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  porque la secuencia de conversión para el argumento es mejor"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "no coincide el argumento por defecto en la resolución de sobrecarga"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " candidato 1: %q+#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " candidato 2: %q+#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ dice que estos son ambiguos, aún cuando la peor conversión para el primero es mejor que la peor conversión para el segundo:"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "un enlace temporal a %qD sólo persiste hasta que el constructor termina"
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -48314,1261 +48350,1261 @@ msgstr "no se puede convertir de la base %qT al tipo derivado %qT a través de l
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "no se puede convertir de la base %qT al tipo derivado %qT a través de la base virtual %qT"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "no se puede convertir de la base %qT al tipo derivado %qT a través de la base virtual %qT"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration here"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "genera un conflicto con la declaración previa aquí"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "version inherited from %qT declared here"
 msgstr "la rutina %qD se declara aquí"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "no se puede sobrecargar %q+#D"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %q#D"
 msgstr "declaración previa de %q+#D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "especificaciones de acceso en conflicto para el método %q+D, descartado"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "especificaciones de acceso en conflicto para el campo %qE, descartado"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  debido al método local %q+#D con el mismo nombre"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "local method %q#D declared here"
 msgstr "%qD se declara aquí"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  debido al miembro local %q+#D con el mismo nombre"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT se declara aquí"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "no se puede derivar de la base %<final%> %qT al tipo derivado %qT"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "todos las funciones miembros en la clase %qT son privadas"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T solamente define un destructor privado y no tiene friends"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T solamente define constructores privados y no tiene friends"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D es público, pero requiere que exista un objeto %q#T"
 
 # Ojo, no es impostor, sino impositor, el que impone. cfuga
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "no hay un impositor único final para %qD en %qT"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "no se puede sobrecargar %q+#D"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D se marca como %<override%>, pero no hace override"
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "se marca %q+#D como %<final%>, pero no es virtual"
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD estaba oculto"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  por %qD"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D no válido; una union anónima solo puede tener miembros con datos no estáticos públicos"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "esta flexibilidad es obsoleta y será eliminada"
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "campo de bits %q+#D con tipo no entero"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "la anchura del campo de bits %q+D no es una constante entera"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "anchura negativa en el campo de bits %q+D"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "anchura cero para el campo de bits %q+D"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "la anchura de %q+D excede su tipo"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D es demasiado pequeño para contener todos los valores de %q#T"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "no se permite el miembro %q+#D con constructor en la union"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "no se permite el miembro %q+#D con destructor en la union"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en la union"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D no debe ser static porque es el miembro de una unión"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "el dato miembro que no es estático %qD tiene un tipo de clase Java"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "el campo %q+D no válidamente se declara como un tipo de función"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "se descartan los atributos packed por el campo %q+#D sin empacar que no es POD"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "múltiples campos inicializados en la unión %qT"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "campo %q+#D con el mismo nombre que la clase"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T tiene miembros punteros a datos"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  pero no se impone a %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  o a %<operator=(cont %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  pero no se impone a %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "el alineamiento de %qD se ha incrementado en -fabi-version=9 (GCC 5.2)"
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD will increase in -fabi-version=9"
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "la alineación de %qD aumentará en -fabi-version=9"
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "se especificó un inicializador para el método %q+D que no es virtual"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "el método anula tanto %<transaction_pure%> como los métodos %qE"
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "el método declarado como %qE anula el método %qE"
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "la clase envolvente de la función miembro que no es estática %<constexpr%> %q+#D no es un tipo literal"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T no es literal porque:"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE does not designate a constexpr function"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "la expresión %qE no designa una función constexpr"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T no es un agregado, no tiene un constructor trivial por defecto y no tiene un constructor %<constexpr%> que no es un constructor copy o move"
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  la clase base %qT de %q+T no es literal"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has volatile type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "la clase base %q#T tiene un destructor no virtual"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "referencia %q+#D que no es static en una clase sin un constructor"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "miembro const %q+#D que no es static en una clase sin un constructor"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "base directa %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "base virtual %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "el desplazamiento de %q+D no cumple con la ABI y puede cambiar en una versión futura de GCC"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "el tamaño de la matriz %qE es demasiado grande"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "uso no válido de %<...%> con algo que no es rebanada"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "uso no válido de una estructura con un miembro de matriz flexible"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "redefinición de %q#T"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinición de %q#T"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T tiene funciones virtuales y destructor no virtual accesible"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "type transparent class %qT does not have any fields"
 msgid "type transparent %q#T does not have any fields"
 msgstr "la clase transparente tipo %qT no tiene ningún campo"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "la clase transparente tipo %qT tiene clases base"
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "la clase transparente tipo %qT tiene funciones virtuales"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "la definición de %qD no coincide con %<#include <initializer_list>%>"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "se trató de terminar struct, pero fue sacado debido a errores previos de decodificación"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "no se reconoce la cadena de lenguaje %<\"%E\"%>"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "no se puede resolver la función sobrecargada %qD basándose en la conversión al tipo %qT"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "no hay coincidencias al convertir la función %qD al tipo %q#T"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "la conversión de la función sobrecargada %qD al tipo %q#T es ambigua"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "asumiendo el puntero a miembro %qD"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un puntero a miembro solamente se puede formar con %<&%E%>)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "no hay suficiente información de tipo"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "no se puede convertir %qE desde el tipo %qT al tipo %qT"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
 msgstr "redeclarado aquí como %q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "el tipo %qT de variable %<constexpr%> %qD no es literal"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "la variable %qD del tipo %qT que no es literal en una función %<constexpr%>"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type %qT"
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "el parámetro puede no tener el tipo modificado variablemente %qT"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "el constructor heredado %qD no es %<constexpr%>"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "tipo no válido del parámetro %d en la función %<constexpr%> %q+#D"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type %qT of constexpr function %q+D"
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "tipo de devolución %qT no válido para la función constexpr %q+D"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T tiene clases base virtuales"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr constructor does not have empty body"
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr "el constructor constexpr no tiene cuerpo vacío"
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "el constructor %<constexpr%> para union %qT debe inicializar exactamente un dato miembro que no es static"
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, fuzzy, gcc-internal-format
 #| msgid "body of constexpr function %qD not a return-statement"
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr "el cuerpo de la función constexpr %qD no es una declaración de devolución"
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not usable as a constexpr function because:"
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D no se puede usar como una función constexpr porque:"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on calls to these functions"
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "Avisa en las llamadas a estas funciones"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E no es una expresión constante"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function %qE"
 msgstr "función interna"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 #| msgid "originally defined here"
 msgid "originally declared %<const%> here"
 msgstr "se definió originalmente aquí"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a base type for type %qT"
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "el tipo %qT no es un tipo base para el tipo %qT"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 #| msgid "variable %D of type %<io%> must be uninitialized"
 msgid "virtual table pointer is used uninitialized"
 msgstr "la variable %D de tipo %<io%> no debe ser inicializada"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 #| msgid "  %qT is an ambiguous base class of %qT"
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "  %qT es una clase base ambigua de %qT"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-constexpr function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "llamada a la función %qD que no es constexpr"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE does not designate a constexpr function"
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "la expresión %qE no designa una función constexpr"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr "no se permite -client_name con -dynamiclib"
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocation performed here"
 msgstr "se declara aquí"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr "no se permite -client_name con -dynamiclib"
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, fuzzy, gcc-internal-format
 #| msgid "Attempting to allocate already allocated variable"
 msgid "deallocation of already deallocated storage"
 msgstr "Se intentó alojar una variable ya alojada"
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a previous local"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "la declaración de %qD oscurece a una declaración local previa"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 #| msgid "%qD called in a constant expression"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "se llamó %qD en una expresión constante"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "se llamó %qD en una expresión constante"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "se usó %qD antes de su definición"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "la llamada tiene una dependencia circular"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "el operador del lado izquierdo de la expresión coma no tiene efecto"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD mutable no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "se accede al miembro %qD  en lugar del miembro inicializado %qD en la expresión constante"
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 #| msgid "ifunc is not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "no se admiten ifunc en este objetivo"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "se accede al valor de %qE a través de glvalue %qT en una expresión constante"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 #| msgid "the value of %qD is not usable in a constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "el valor de %qD no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "se declara aquí"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "use of the value of the object being constructed in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "uso del valor del objeto en construcción en una expresión constante"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "el valor de %qD no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "se usó %qD en su propio inicializador"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D no es const"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D es volatile"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD no se inicializó con una expresion constante"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD no se declaró %<constexpr%>"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from  %s to %s at %L"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "Cambio de valor en la conversión de %s a %s en %L"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from  %s to %s at %L"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Cambio de valor en la conversión de %s a %s en %L"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversión del tipo puntero %qT al tipo aritmético %qT en una expresión constante"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 #| msgid "%s%qs%s is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "%s%qs%s no está permitido"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "expression %qE is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE must be directly called"
 msgid "function concept must be called"
 msgstr "la función interna %qE ha de ser llamada directamente"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "expresión %qE inesperada de género %s"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "conversión no válida de una expresión r-valuada de tipo %qT al tipo %qT"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast no válido del tipo `%T' al tipo `%T'"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "la dirección de un objeto %qE con hilo local o almacenamiento automático no es una expresión constante"
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "inicialización de una matriz que no es constante"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "label definition is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "AST inesperado de género %s"
@@ -49578,58 +49614,58 @@ msgstr "AST inesperado de género %s"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "la dirección de %qD siempre se evaluará como %<true%>"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD no es un tipo"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT no es un tipo de clase"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE no es de tipo puntero o matriz"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not have integral type"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -49679,7 +49715,7 @@ msgstr "inicialización a un tipo de referencia que no es constante %q#T desde u
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "la conversión de %qT a %qT descarta los calificadores"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "la conversión de %qT a %qT no dereferencía a los punteros"
@@ -50081,7 +50117,7 @@ msgstr "de la declaración previa de %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %qD"
@@ -50234,8 +50270,8 @@ msgstr "la declaración previa %q+#D que no es función"
 msgid "%q#D previously defined here"
 msgstr "se define %q+#D previamente aquí"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
@@ -50276,60 +50312,60 @@ msgstr "argumento por defecto dado para el parámetro %d de %q#D"
 msgid "previous specification in %q#D here"
 msgstr "después de la especificación previa en %q+#D"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration %qD conflicts with builtin"
 msgstr "genera un conflicto con la declaración interna %q#D"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of namespace %qD conflicts with"
 msgid "declaration %qD conflicts with import"
 msgstr "la declaración del espacio de nombres %qD genera un conflicto con"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 #| msgid "  also declared as %q#D here"
 msgid "import declared %q#D here"
 msgstr "  también declarado como %q#D aquí"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting declaration %qD"
 msgstr "declaraciones de %q#D en conflicto"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration %q#D here"
 msgstr "la declaración previa de %q+D estaba aquí"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "la definición previa de %q+D estaba aquí"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "la declaración previa de %q+D estaba aquí"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "declaración redundante de %qD en el mismo ámbito"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %qD is not first declaration"
@@ -50343,50 +50379,50 @@ msgstr "se borró la definición de %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "especialización explícita de %qD después del primer uso"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 #| msgid "'setter' attribute of property %qD conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "el atributo 'setter' de la propiedad %qD genera un conflicto con la declaración previa"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "redefinición de %q#D"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD genera un conflicto con la función utilizada"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D no se declaró en la clase"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D se redeclaró incluida en línea con el atributo %<gnu_inline%>"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D se redeclaró incluida en línea sin el atributo %<gnu_inline%>"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %q+D redeclared"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -50394,707 +50430,713 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "la redeclaración de friend %q#D no puede tener argumentos de plantilla por defecto"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "declaración thread-local de %q#D después de una declaración que no es thread-local"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "declaración que no es thread-local de %q#D después de una declaración thread-local"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "redeclaración de %q#D"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%s' in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "declaración redundante de `%s' en el mismo ámbito"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "a previous local"
 msgid "previous label"
 msgstr "un local previo"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  desde aquí"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  sale del bloque estructurado OpenMP"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  cruza la inicialización de %q+#D"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  entra al ámbito de %q+#D el cual tiene un destructor que no es trivial"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  entra al bloque try"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  entra al bloque catch"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  entra al bloque estructurado OpenMP"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "se esperaba una declaración"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  salta la inicialización de %q+#D"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  entra al ámbito de %q+#D el cual tiene un destructor que no es trivial"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "se usa %qD sin parámetros de plantilla"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD no es una plantilla de función"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T no es una clase"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "no hay una plantilla de clase llamada %q#T en %q#T"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la búsqueda de %qT en %qT es ambigua"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es una plantilla de clase"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es un tipo"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "los parámetros de la plantilla no coinciden con la plantilla"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "no se admite -falign-labels=%d"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con constructor en un agregado anónimo"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con destructor en un agregado anónimo"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en un agregado anónimo"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "el atributo para %q#T debe estar a continuación de la palabra clave %qs"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "tipos múltiples en una declaración"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeclaración del tipo interno de C++ %qT"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> sólo se puede especificar para variables o declaraciones de función"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "falta el nombre del tipo en la declaración typedef"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ prohíbe structs anónimos"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sólo se puede especificar dentro de una clase"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sólo se puede especificar para constructores"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "se descartó %<typedef%> en esta declaración"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> no se puede usar en declaraciones de tipo"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "se descartan los atributos aplicados al tipo de clase %qT fuera de la definición"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "se descartan los atributos aplicados al tipo dependiente %qT sin una declaración asociada"
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD está inicializado (utilice decltype en su lugar)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la declaración de %q#D tiene %<extern%> y está inicializada"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la definición de %q#D se marca como %<dllimport%>"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "declaración plantilla de %q#D"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "declaración de la plantilla miembro %qD no válida"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ no permite que %<%T::%D%> se defina como %<%T::%D%>"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "inicialización duplicada de %qD"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la declaración de %q#D fuera de la clase no es una definición"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D tiene inicializador pero de tipo de dato incompleto"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementos de la matriz %q#D con tipo de dato incompleto"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "el agregado %q#D tiene un tipo incompleto y no se puede definir"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD declarado como referencia pero no se inicializa"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "se usó un nombre en un inicializador designado de estilo GNU para una matriz"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "el nombre %qD se utiliza en un inicializador designado en estilo GNU para una matriz"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "no se admiten los inicializadores designados como no triviales"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "el inicializador no puede determinar el tamaño de %qD"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "falta el tamaño de la matriz en %qD"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "matriz %qD de tamaño cero"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %qD"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "el tamaño de almacenamiento de %qD no es constante"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  puede evitar esto eliminando el inicializador"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "const %qD sin inicializar"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T no tiene constructor por defecto proporcionado por el usuario"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "el constructor no es proporcionado por el usuario porque está marcado explícitamente por defecto en el cuerpo de la clase"
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, fuzzy, gcc-internal-format
 #| msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "y el constructor implícitamente definido no inicializa %q+#D"
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipo %qT no válido como inicializador para un vector de tipo %qT"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "el inicializador para %qT debe estar encerrado entre llaves"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "se usa %<[%E] =%> en un inicializador designado en estilo GNU para la clase %qT"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT no tiene un dato miembro que no es static llamado %qD"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "invalid initializer for %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "asignador C99 %qE fuera del inicializador agregado"
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "demasiados inicializadores para %qT"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "faltan llaves alrededor del inicializador para %qT"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementos de la matriz %q#T tienen tipo de dato incompleto"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "literal compuesta de tamaño variable"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D tiene un tipo incompleto"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "el objeto escalar %qD requiere un elemento en el inicializador"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98 %qD debe ser inicializado por un constructor, no por %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "matriz %qD inicializada con una constante de cadena entre paréntesis %qE"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "inicializador no válido para el miembro static con constructor"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant in-class initialization invalid for static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(se requiere una inicialización fuera de la clase)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "%s: recursive invocation of constructor %qs"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s: invocación recursiva del constructor %qs"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration cannot name destructor"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "uan declaración de uso no puede nombrar al destructor"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member function (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "uso no válido de la función miembro (¿Olvidó el %<&%>?)"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "se oscurece la declaración de tipo previa de %q#D"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "el atributo %qE se aplica solamente a variables en almacenamiento estático"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la función %q#D se inicializa como una variable"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  no se puede usar la asignación obsoleta en %q+D porque tiene un destructor"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 #| msgid "cannot form pointer to member of non-class %q#T"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -51102,7 +51144,7 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "se especificó %qs para el campo de estructura"
 msgstr[1] "se especificó %qs para el campo de estructura"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "only %u name provided for structured binding"
@@ -51110,1773 +51152,1784 @@ msgid_plural "only %u names provided for structured binding"
 msgstr[0] "inicializador no válido para la cadena de bits"
 msgstr[1] "inicializador no válido para la cadena de bits"
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "tipo no válido para la variable de iteración %qE"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "no se puede aplicar %<offsetof%> al dato miembro static %qD"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "el inicializador no puede determinar el tamaño de %qT"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "falta el tamaño de la matriz en %qT"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "matriz %qT de tamaño cero"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "el destructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "el constructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD se declaró como una variable %<virtual%>"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de variable"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD se declaró como un parámetro %<virtual%>"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD se declaró como un parámetro %<inline%>"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de parámetro"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD se declaró como un tipo %<virtual%>"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD se declaró como un tipo %<inline%>"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de tipo"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD se declaró como un campo %<virtual%>"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD se declaró como un campo %<inline%>"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de campo"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D se declaró con una especificación de excepción"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la definición de %qD no está en un espacio de nombres que contenga a %qT"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la función miembro static %q#D se declara con calificadores de tipo"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "el método Java %qD tiene un tipo de devolución %qT que no es de Java"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "concept %qD has no definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "a function concept cannot be constrained"
 msgstr "no se puede instrumentar la función"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD no es una función plantilla"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definiendo la especialización explícita %qD en la declaración friend"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "uso no válido del id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "no se permiten los argumentos por defecto en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "no se permite %<inline%> en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "la declaración de %q#D fuera de la clase no es una definición"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "no se puede declarar %<::main%> como inline"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "no se puede declarar %<::main%> como static"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "no se puede declarar %<::main%> como static"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "la declaración de %qD como algo que no es función"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "operador literal con enlace C"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD tien una lista de argumentos no válida"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, fuzzy, gcc-internal-format
 #| msgid "integer suffix %<%s%> shadowed by implementation"
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo entero %<%s%> por la implementación"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, fuzzy, gcc-internal-format
 #| msgid "floating point suffix %<%s%> shadowed by implementation"
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo de coma flotante %<%s%> por la implementación"
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "los sufijos de operador literal que no están precedidos por %<_%> están reservados para estandarización futura"
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD debe ser una función que no sea miembro"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> debe devolver %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "la definición de %qD declarado implícitamente"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "la definición de %qD explícitamente por defecto"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D explicitly defaulted here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D explícitamente por defecto aquí"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "no hay una función miembro %q#D declarada en la clase %qT"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+#| msgid "specialization of %qD must appear at namespace scope"
+msgid "concept must be defined at namespace scope"
+msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo incompleto"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "se necesita %<constexpr%> para la inicialización en la clase no válida del miembro de datos static %q#D de tipo que no es integral"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo que no es literal"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "inicialización en la clase no válida para el miembro de datos static de tipo %qT que no es integral"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ prohíbe la inicialización en la clase del miembro static %qD que no es constante"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ prohíbe la inicialización de la constante miembro %qD del tipo %qT que no es entero"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "el tamaño de la matriz %qD tiene un tipo %qT que no es integral"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de tamaño cero"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ prohíbe matrices de tamaño cero"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de longitud variable"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ prohíbe las matrices de longitud variable"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "se usa la matriz de longitud variable %qD"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "se usó la matriz de longitud variable"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "desbordamiento en la dimensión de la matriz"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "se crea la matriz de %qT"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "la declaración de %qD como una matriz de voids"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "se crea la matriz de voids"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "la declaración de %qD como una matriz de funciones"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "se crea la matriz de funciones"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "la declaración de %qD como una matriz de referencias"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "se crea la matriz de referencias"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "la declaración de %qD como una matriz de miembros de función"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "se crea la matriz de miembros de función"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de %qD como una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "una matriz multidimensional debe tener límites para todas las dimensiones excepto para la primera"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la especificación del tipo de devolución para el constructor es no válida"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "se especificó un tipo de devolución para %<operator %T%>"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "se declaró la variable o campo sin nombre como void"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "se declaró la variable o campo como void"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "uso no válido del nombre calificado %<::%D%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "uso no válido del nombre calificado %<%T::%D%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "uso no válido del nombre calificado %<%D::%D%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "la declaración de %qD como algo que no es función"
 
 #  FIXME traducción
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "declaración de %qD como algo que no es miembro"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "falta el id del declarador; se utiliza la palabra reservada %qD"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la definición de la función no declara parámetros"
 
 #  FIXME traducción
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "la declaración de %qD como algo que no es función"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "declaración de %qD como %<typedef%>"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "la declaración de %qD como parámetro"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "no se especificó ninguna clase"
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%> no puede aparecer en una declaración typedef"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dos o más tipos de datos en la declaración de %qs"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ prohíbe la declaración de %qs sin tipo"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "no se admite %<__int128%> en este objetivo"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ no admite %<__int128%> para %qs"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> y %<unsigned%> se especificaron juntos para %qs"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> y %<short%>  se especificaron juntos para %qs"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qT"
 msgstr "se usó %qs con %qE"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex no válido para %qs"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "declaración typedef no válida en la declaración de parámetros"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro de plantilla %qs"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro %qs"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weak"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "la función indirecta %q+D no se puede declarar weak"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "la función anidada %qs se declaró %<extern%>"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la declaración del nivel superior de %qs especifica %<auto%>"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "el ámbito de la función %qs es implícitamente auto y declarado %<__thread%>"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "especificadores de clase de almacenamiento no válidos en las declaraciones de funciones friend"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "se descarta el atributo"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un atributo que atañe a un especificador de tipo se descarta"
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Se esperaba un paréntesis izquierdo"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la función %qs usa el especificador de tipo %<auto%> sin un tipo de devolución trailing"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "uso no válido de %<auto%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "no se declaró la función %qs con tipo de devolución trailing con el especificador de tipo %<auto%>"
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified return type of %qD"
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "calificado %<_Atomic%> el tipo de retorno de %qD"
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs que se declaró como función devuelve una función"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs que se declaró como función devuelve una matriz"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "la función %<noreturn%> devuelve un valor que no es void"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "el destructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "los constructores tal vez no sean cv-calificados"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "los constructores no se pueden declarar virtual"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la declaración friend no está en una definición de clase"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "no se puede definir la función friend %qs en una definición de clase local"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "los destructores no pueden tener parámetros"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "no se puede declarar el puntero a %q#T"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "no se puede declarar el puntero al miembro %q#T"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "no se puede declarar la referencia a %q#T, el cual no es una definición de tipo o un argumento de tipo de plantilla"
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "el id de plantilla %qD se usa como un declarador"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "las funciones miembros son implícitamente friends de su clase"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "calificación extra %<%T::%> en el miembro %qs"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "no se puede definir la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "no se puede declarar la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "no se puede declarar el miembro %<%T::%s%> dentro de %qT"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "%qs que no es parámetro no puede ser un paquete de parámetro"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "los datos miembro pueden no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "el parámetro puede no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> en una declaración vacía"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "el miembro que no es objeto %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la referencia %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "la definición de tipo se declaró %<auto%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "el nombre del typedef puede no ser un especificador-de-nombre-anidado"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ prohíbe el tipo anidado %qD con el mismo nombre que la clase que lo contiene"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "se especificó %<inline%> para la declaración de clase friend"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "los parámetros de la plantilla no pueden ser friends"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "la declaración friend requere una llave de clase, p.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "la declaración friend requiere una llave de clase, p.e. %<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "se intenta hacer que la clase %qT sea un friend de ámbito global"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "calificadores no válidos en el tipo de función que no es miembro"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "el declarador abstracto %qT se usó como declaración"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "no se puede usar %<::%>  en la declaración de parámetros"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "no se puede declarar que el parámetro %q+D sea del tipo abstracto %qT"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD no es una plantilla de función"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "el parámetro se declaró %<auto%>"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "uso no válido del nombre-de-plantilla %qE sin una lista de argumentos"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared %<auto%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "se declaró el miembro dato que no es static como %<auto%>"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "uso no válido de %<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "declaración de la función %qD en un contexto no válido"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD no se puede declarar virtual, ya que siempre es static"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el destructor %qD"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el constructor %qD"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "no se puede abrir %s"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "la variable %qD se redeclaró como función"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "el tipo original se definió aquí"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "el campo %qD tiene tipo de dato incompleto"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "el nombre %qT tiene tipo de dato incompleto"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %qs"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr static data member %qD must have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "el miembro dato static constexpr %qD debe tener un inicializador"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<auto%> es no válida para la función %qs"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<register%> es no válida para la función %qs"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "no se permiten los especificadores-virt en %qs fuera de una definición de clase"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<static%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "función virtual %qs que no es clase"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "se definió %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "se declaró %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "no se puede declarar que la función miembro %qD tenga enlace estático"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "no se puede declarar una función static dentro de otra función"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> puede no ser utilizado cuando se define (opuesto a la declaración) un dato miembro static"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "se declaró el miembro static %qD como %<register%>"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "no se puede declarar explícitamente que el miembro %q#D tenga un enlace externo"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la declaración de la variable constexpr %qD no es una definición"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la declaración de %q#D no tiene inicializadores"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs inicializado y declarado como %<extern%>"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs tiene %<extern%> e inicializador al mismo tiempo"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "el argumento por defecto %qE usa %qD"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "el argumento por defecto %qE usa la variable local %qD"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "tipo de parámetro cualificado %<_Atomic%> %qT de %q+D"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye un puntero a matriz %qT de límite desconocido"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye una referencia a matriz %qT de límite desconocido"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructor no válido; tal vez quiso decir %<%T (const %T&)%>"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD no se puede declarar como static"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD debe ser una función miembro que no sea static"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD debe ser una función miembro que no sea static o una función que no sea miembro"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD debe tener un argumento de tipo clase o enumerado"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ prohíbe la sobrecarga del operador ?:"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD no debe tener un número variable de argumentos"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD debe tomar cero o un argumentos"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD debe tomar uno o dos argumentos"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su argumento"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su segundo argumento"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD debe tomar un argumento exactamente"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD no puede tener argumentos por defecto"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "la conversión a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "la conversión a una referencia al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "la conversión al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "la conversión a una referencia a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "la conversión a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "el %qD definido por el usuario siempre evalúa ambos argumentos"
 
 #  En esta traducción se emplea 'devolver' por 'return'. Si embargo, aquí
 #  se cambió por cacofonía: no es agradable escuchar 'debe devolver'. cfuga
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "el prefijo %qD debe regresar %qT"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "el postfijo %qD debe regresar %qT"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD debe devolver por valor"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "usando el parámetro de tipo plantilla %qT después de %qs"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "se usa especialización de plantilla %qT alias después de %qs"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "se usó el nombre de definición de tipo %qD después de %qs"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD tiene una declaración previa aquí"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "se refirió a %qT como %qs"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T tiene una declaración previa aquí"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "se refirió a %qT como un enum"
@@ -52888,60 +52941,60 @@ msgstr "se refirió a %qT como un enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "se requiere un argumento de plantilla para %<%s %T%>"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD tiene el mismo nombre que la clase en la cual se declaró"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT no es una plantilla"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "uso del enum %q#D sin declaración previa"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeclaración de %qT como algo que no es plantilla"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "no se puede declarar %qD que sea un tipo de campo de bits"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union derivada %qT no válida"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
@@ -52949,49 +53002,49 @@ msgstr "el tipo %qT no es una base directa o virtual de %qT"
 
 #  No me gusta mucho esta traducción. Creo que es mejor
 #  "el tipo base %qT no es de tipo struct o clase". cfuga
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "el tipo base %qT falla en ser un tipo struct o clase"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipo recursivo %qT sin definir"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "tipo base duplicado %qT no válido"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "no coinciden scoped/unscoped en el enum %q#T"
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "la definición previa está aquí"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "no coincide el tipo subyacente en el enum %q#T"
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tipos subyacentes diferentes en el enum %q#T"
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 #| msgid "Option %s with different values"
 msgid "cannot define %qD in different module"
 msgstr "Opción %s con valores diferentes"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -53001,83 +53054,83 @@ msgstr "el tipo subyacente %<%T%> de %<%T%> debe ser un tipo integral"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ningún tipo integral puede representar todos los valores de enumerador de %qT"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "desbordamiento en valores de enumeración en %qD"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<%T%>"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "definición múltiple de %q#T"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> debe devolver una referencia a %<*this%>"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "los tipos de devolución de función no son compatibles debido a %<volatile%>"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ya se definió en la clase %qT"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -53119,7 +53172,7 @@ msgstr "no se puede borrar una función.  Solamente los punteros a objetos son a
 msgid "deleting %qT is undefined"
 msgstr "el borrado de %qT está indefinido"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "declaración plantilla de %q#D"
@@ -53129,7 +53182,7 @@ msgstr "declaración plantilla de %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "las listas de parámetro de plantilla proporcionadas no coinciden con los parámetros de plantilla de %qD"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "se declaró el destructor %qD como una plantilla miembro"
@@ -53488,24 +53541,24 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "se convierte lambda la cual usa %<...%> a un puntero de función"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "se usó la función borrada %q+D"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -53628,7 +53681,7 @@ msgstr "la referencia a %<%T::%D%> es ambigua"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT no tiene un miembro llamado %qE; ¿quiso decir %qE?"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD no es un miembro de %qT"
@@ -53639,7 +53692,7 @@ msgstr "%qD no es un miembro de %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT no tiene un miembro llamado %qE; ¿quiso decir %qE?"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD no es un miembro de %qD"
@@ -53837,433 +53890,433 @@ msgstr "inicialización por valor del tipo de referencia %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD se debe inicializar en la lista de inicialización de miembros"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "miembro const sin inicializar en %q#T"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
 msgid "%q#D should be initialized"
 msgstr "%qD se debe inicializar"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "miembro referencia sin inicializar en %q#T"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D se inicializará después de"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "la base %qT se inicializará después de"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  base %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  cuando se inicializó aquí"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "se dieron inicializaciones múltiples para %qD"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "se dieron inicializaciones múltiples para la base %qT"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "inicializaciones para múltiples miembros de %qT"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "la clase base %q#T debe ser inicializada explícitamente en la copia del constructor"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "la clase %qT no tiene ningún campo llamado %qD"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D es un dato miembro static; sólo se puede inicializar en su definición"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "inicializador sin nombre para %qT, el cual no tiene clases base"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "inicializador sin nombre para %qT, el cual usa herencia múltiple"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD es tanto una base directa como una base virtual indirecta"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "el tipo %qT no es una base directa o virtual de %qT"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "el tipo %qT no es una base directa de %qT"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "la matriz se debe inicializar con un inicializador dentro de llaves"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT no es un tipo de clase"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "el tipo incompleto %qT no tiene al miembro %qD"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "puntero no válido al campo de bits %qD"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "uso no válido del dato miembro no static %qD"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "un miembro referencia sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "un miembro referencia sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "miembro referencia sin inicializar en %q#T"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "un miembro const sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "un miembro const sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "miembro const sin inicializar en %q#T"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "at offset %wi from %qD declared here"
 msgstr "en una llamada a la función %qD declarada aquí"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "en una llamada a la función %qD declarada aquí"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "desbordamiento entero en la expresión"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "double quoted strings not allowed in #if expressions"
 msgid "variably modified type not allowed in new-expression"
 msgstr "no se permite cadenas con comillas dobles en expresiones #if"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "tipo %<void%> no válido para new"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "const sin inicializar en %<new%> de %q#T"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "no se encontró un %qD adecuado en la clase %qT"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la petición para el miembro %qD es ambigua"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "la clase %qT no tiene ningún campo llamado %qD"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "inicializador entre paréntesis en la matriz new"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new no se puede aplicar a un tipo de referencia"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new no se puede aplicar a un tipo de función"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "se detectó un posible problema en la invocación del operador delete:"
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "el inicializador termina prematuramente"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "tamaño de matriz desconocida en delete"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "se detectó un posible problema en la invocación del operador delete:"
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "si borra un objeto de tipo de clase abstracta %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "si borra un objeto de tipo de clase polimórfica %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "la literal compuesta tiene tamaño variable"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "no se puede capturar %qE por referencia"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete type %q#T"
 msgid "capture by copy of incomplete type %qT"
 msgstr "uso no válido del tipo incompleto %q#T"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "no se capturó %<this%> para esta función lambda"
@@ -54322,68 +54375,68 @@ msgstr "no hay argumentos para %qD que dependan de un parámetro de plantilla, p
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(si utiliza %<-fpermissive%>, G++ aceptará su código, pero permitir el uso de un nombre sin declarar es obsoleto)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, fuzzy, gcc-internal-format
 #| msgid "mangling typeof, use decltype instead"
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr "se decodifica typeof, utilice decltype en su lugar"
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "mangling __underlying_type"
 msgid "mangling %<__underlying_type%>"
 msgstr "se decodifica __underlying_type"
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "se decodifica el tipo de coma fija desconocido"
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "decodificando %C"
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "se omitió el operando de enmedio de %<?%>: no se puede revolver el operando"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
@@ -54587,339 +54640,339 @@ msgstr "%q+#D es implícitamente deleted por que la definición por defecto esta
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "does not match expected signature %qD"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "no coincide la firma esperada %qD"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "does not match expected signature %qD"
 msgid "expected signature: %qD"
 msgstr "no coincide la firma esperada %qD"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, fuzzy, gcc-internal-format
 #| msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "la función %q+D explícitamente por defecto no se puede declarar como constexpr porque la declaración implícita no es constexpr:"
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "una plantilla no se puede definir por defecto"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD no se puede definir por defecto"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "función definida por defecto %q+D con argumento por defecto"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D genera un conflicto con una declaración previa"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D esconde el destructor para %q#T"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "declaraciones de %q#D en conflicto"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "debido a diferentes especificaciones de excepciones"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "la declaración de %q#D oscurece un parámetro"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "una declaración friend %qD en una clase local sin declaración previa"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%q#D does not have external linkage"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here"
 msgstr "%q+#D se declaró aquí"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> nombra al destructor"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "declaración de uso para un no miembro en el ámbito de la clase"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE no es una clase, un espacio de nombres o una enumeración"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "declaración plantilla de %q#D"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "declaración de uso para un no miembro en el ámbito de la clase"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "el tipo %qT no es una base directa de %qT"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qE no se ha declarado"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration cannot name destructor"
 msgid "using-declaration may not name namespace %qD"
 msgstr "uan declaración de uso no puede nombrar al destructor"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nombra al constructor en %qT"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la declaración de %qD no está en un espacio de nombres alrededor de %qD"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "calificación explícita en la declaración de %qD"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD se debería declarar dentro de %qD"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qE no se ha declarado"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D se declaró como friend"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "el atributo %qD no tiene signifcado porque los miembros del espacio de nombres anónimo tiene símbolos locales"
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "se descarta la directiva de atributo %qD"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "límite máximo de %d espacios de nombres buscados para %qE"
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "alternativa sugerida:"
 msgstr[1] "alternativas sugeridas:"
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not available for %s architecture"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%s no está disponible para la arquitectura %s"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 #| msgid "weak %q+D cannot be defined %qE"
 msgid "the macro %qs had not yet been defined"
 msgstr "weak %q+D no se puede definir como %qE"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "se definió struct aquí"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "la opción %qs ya no se admite"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgid "you can use an inline namespace instead"
 msgstr "Esta opción es obsoleta; utilice en su lugar -fsanitize-recover=."
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "'%s' en %L es ambiguo"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "no se permite aquí el alias del espacio de nombres %qD, se asume que es %qD"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, fuzzy, gcc-internal-format
 #| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "los atributos de método sólo se deben especificar al final"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 #| msgid "%qD conflicts with used function"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD genera un conflicto con la función utilizada"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "la definición previa está aquí"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX entrando a pop_everything ()\n"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -54946,7 +54999,7 @@ msgstr "el identificador %qE es una palabra clave en C++11"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -54972,7 +55025,7 @@ msgstr "%<::%E%> no se ha declarado"
 msgid "request for member %qE in non-class type %qT"
 msgstr "solicitud por el miembro %qE en el tipo %qT que no es clase"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> no se ha declarado"
@@ -55054,7 +55107,7 @@ msgstr "id-de-plantilla no válido"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "una literal de coma flotante no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "una conversión a un tipo diferente de un tipo integral o de enumeración no puede aparecer en una expresión constante"
@@ -55200,7 +55253,7 @@ msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu+
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, fuzzy, gcc-internal-format
 #| msgid "%<@required%> is not available in Objective-C 1.0"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -55335,7 +55388,7 @@ msgstr "no se puede encontrar un operador literal de cadena %qD con argumentos %
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "se esperaba una declaración"
@@ -55391,7 +55444,7 @@ msgstr "las expresiones-de-declaraciones no se permiten fuera de funciones ni en
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "se esperaba una expresión primaria"
@@ -55422,7 +55475,7 @@ msgstr "el ámbito %qT antes de %<~%> no es un nombre-de-clase"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
@@ -55444,12 +55497,12 @@ msgstr "declaración de %<~%T%> como miembro de %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "se usa el nombre-de-definición-de-tipo %qD como un declarador de destructor"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "se esperaba un id sin calificar"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD no es una plantilla"
@@ -55488,7 +55541,7 @@ msgstr "se esperaban especificadores de nombre anidados"
 msgid "expected nested-name-specifier"
 msgstr "se esperaban especificadores de nombre anidados"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "los tipos no se pueden definir en conversiones"
@@ -55504,7 +55557,7 @@ msgstr "no se pueden definir tipos en una expresión %<typeid%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -55520,1217 +55573,1223 @@ msgstr "ISO C++ prohíbe las literales compuestas"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "uso no válido de %qD"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> no es un miembro clase"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "tipo que no es escalar"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ no permite %<alignof%> con algo que no es tipo"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<noexcept%>"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-expression"
 msgid "types may not be defined in %qs expressions"
 msgstr "no se pueden definir tipos en una expresión new"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_thread_pointer is not supported on this target"
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr "no se admite __builtin_thread_pointer en este objetivo"
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "no se pueden definir tipos en una expresión new"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "se prohíbe el límite de matriz después del id-de-tipo entre paréntesis"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Se esperaba un tipo de expresión"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "no se pueden definir tipos en un id-tipo-nuevo"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "la expresión en el declarador-new debe tener un tipo integral o de enumeración"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "uso de conversión de estilo antiguo"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "el operador %<>>%> se tratará como dos en llaves en ángulo derechas en C++11"
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "se sugieren paréntesis alrededor de la expresión %<>>%>"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ no permite ?: con el operando medio omitido"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, fuzzy, gcc-internal-format
 #| msgid "use of cast expressions as lvalues is deprecated"
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "el uso de expresiones de conversión como l-valores es obsoleto"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+#| msgid "lambda-expression in unevaluated context"
+msgid "lambda-expression in template parameter type"
+msgstr "expresión lambda en un contexto sin evaluar"
+
+#: cp/parser.c:10819
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "se esperaba el fin de la lista-de-captura"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "la captura por copia explícita de %<this%> es redundante con la captura por copia por defecto"
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "ya se capturó %qD en la expresión lambda"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 #| msgid "cannot capture %qE by reference"
 msgid "%<this%> cannot be captured by reference"
 msgstr "no se puede capturar %qE por referencia"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer for lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 #| msgid "capture of non-variable %qD "
 msgid "capture of non-variable %qE"
 msgstr "captura de %qD que no es variable "
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "captura de la variable %qD con duración de almacenamiento que no es automática"
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "demasiadas cláusulas %<if%>"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "la captura por copia explícita de %qD es redundante con la captura por copia por defecto"
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "la captura por referencia explícita de %qD es redundate con la captura por referencia por defecto"
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "se especificó un argumento por defecto para el parámetro lambda"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "%<volatile%> duplicado"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "se esperaba una declaración etiquetada"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "la etiqueta case %qE no está dentro de una declaración switch"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "se necesita %<typename%> antes de %qE porque %qT es un ámbito dependiente"
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nombra el constructor, no el tipo"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "declaración compuesta en una función constexpr"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "se esperaba una declaración de selección"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "la función devuelve una matriz"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "el campo %qE se declaró como una función"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "no se pueden definir tipos en condiciones"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "se esperaba un inicializador"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "non-local variable %q#D uses local type %qT"
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "la variable %q#D que no es local usa el tipo local %qT"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "la expresión %<for%> basada en rango de tipo %qT es de tipo incompleto"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "tipos begin/end inconsistentes para la declaración %<for%> basada en rango: %qT y %qT"
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "se esperaba una declaración de iteración"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "declaración compuesta en una función constexpr"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ prohíbe los gotos calculados"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "se esperaba una declaración de salto"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-name"
 msgid "expected module-name"
 msgstr "se esperaba un nombre de plantilla"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "method declaration not in @interface context"
 msgid "module-declaration not permitted in header-unit"
 msgstr "la declaración de método no está en el contexto @interface"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 #| msgid "volatile argument"
 msgid "private module fragment"
 msgstr "argumento volátil"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "import-declaration must be at global scope"
 msgstr "declaración de uso para un no miembro en el ámbito de la clase"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 #| msgid "invalid linkage-specification"
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "especificación de enlace no válida"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "%qE may only occur once in an export declaration"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "attributes are not permitted in this position"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "attributes may not be specified before"
 msgid "attributes may be inserted here"
 msgstr "los atributos no se pueden especificar antes"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "<;%> extra"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label%> no está al inicio de un bloque"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "se prohíbe mezclar declaraciones y definiciones-de-función"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in range-based for loops"
 msgid "initializer in range-based %<for%> loop"
 msgstr "no se pueden definir tipos en bucles for basados en rango"
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "declaraciones múltiples `%T' y `%T'"
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "empty structured binding declaration"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "invalid initializer for structured binding declaration"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "se usó %<friend%> fuera de la clase"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> cambiará su significado en C++11; por favor bórrelo"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier invalid in condition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "especificador-decl no válido en la condición"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 #| msgid "%qD invalid in %qT"
 msgid "%qD invalid in lambda"
 msgstr "%qD no válido en %qT"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier invalid in condition"
 msgid "type-specifier invalid in lambda"
 msgstr "especificador-decl no válido en la condición"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la definición de clase no se puede declarar como friend"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in an exception-specification"
 msgid "types may not be defined in explicit-specifier"
 msgstr "no se pueden definir tipos en una especificación de excepción"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "especificación de enlace no válida"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<decltype%>"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-type-id"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "no se pueden definir tipos en un id-tipo-nuevo"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "solamente los constructores toman inicializadores miembro"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "no se puede expandir el inicializador para el miembro %<%D%>"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "inicializador mem para %qD después de una delegación de constructor"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "delegación de constructor después de un inicializador mem para %qD"
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "inicializador de clase base de estilo antiguo anacrónico"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (un inicializador de miembro calificado es implícitamente un tipo)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, fuzzy, gcc-internal-format
 #| msgid "missing space between %<\"\"%> and suffix identifier"
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "falta un espacio entre %<\"\"%> y el identificador sufijo"
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "se esperaba un identificador sufijo"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "se esperaba una cadena vacía después de la palabra clave %<operator%>"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in ternary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operandos no válidos en la operación terniaria"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operador inesperado"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "no se admite la palabra clave %<export%>, y se descartará"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<export%> not implemented, and will be ignored"
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "no se admite la palabra clave %<export%>, y se descartará"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, fuzzy, gcc-internal-format
 #| msgid "-mexr is used without -ms"
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr "se usó -mexr sin -ms"
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "invalid constrained type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "parámetro de captura no válido"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros plantilla %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "los paquetes de parámetro de plantilla no pueden tener argumentos por defecto"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> no puede iniciar una lista de argumentos de plantilla"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> es una forma alternativa para %<[%>. Inserte espacios en blanco entre %<<%> y %<::%>"
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si utiliza %<-fpermissive%>, G++ aceptará su código)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-type template argument"
 msgid "invalid template-argument-list"
 msgstr "argumento de plantilla que no es tipo no válido"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "se esperaba un argumento de plantilla"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "error de decodificación en la lista de argumentos de plantilla"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "se esperaba un nombre de plantilla"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilice %<%T::template %D%> para indicar que es una plantilla"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "se esperaba un argumento de plantilla"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argumento de plantilla que no es tipo no válido"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<inline%>"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<constexpr%>"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<constexpr%>"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "especialización de plantilla con enlace C"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "se esperaba un specificador de tipo"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "se esperaba un id de plantilla para el tipo"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "se esperaba un nombre de tipo"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE no nombra a un tipo"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "concept defined here"
 msgstr "se definió union aquí"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "se esperaba %<,%> o %<)%>"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, fuzzy, gcc-internal-format
 #| msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "el especificador de tipo elaborado para un ámbito enumerado no debe usar la palabra clave %<%D%>"
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 #| msgid "typedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "el nombre del typedef puede no ser un especificador-de-nombre-anidado"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la declaración %qD no declara nada"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "se descartan los atributos en el tipo sin instanciar"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "se descartan los atributos en un especificador de tipo elaborado que no es una declaración adelantada"
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD es una plantilla de enumeración"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "se esperaba %<;%> o %<{%>"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "no se puede agregar una lista de enumerador a una instanciación de plantilla"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "la declaración de %qD en el espacio de nombres %qD el cual no incluye a %qD"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "la declaración de %qD en %qD la cual no incluye a %qD"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "no se permite la calificación extra"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "especificador enumerador opaco sin nombre"
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "el especificador enumerador opaco debe usar un identificador simple"
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qE no nombra a un tipo"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD no es un nombre-de-espacio-de-nombres"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "namespace name required"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "El enumerador no puede tener atributos %C"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 #| msgid "varargs function cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "la función varargs no puede ser inline"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "namespace %qD entered"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un id-de-plantilla no puede aparecer en una declaración-using"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "las declaraciones access son obsoletas en favor de las declaraciones using: sugerencia: use la palabra clave %<using%>"
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration here"
 msgid "opaque-enum-declaration here"
 msgstr "declaración previa aquí"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "no se pueden definir tipos en declaraciones de plantilla alias"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "calificador-cv duplicado"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT no es un espacio de nombres"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter %qD outside function body"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "se usó el parámetro %qD fuera del cuerpo de la función"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "nombres de parámetros (sin tipos) en la declaración de la función"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesized initializer in array new"
 msgid "remove parentheses to default-initialize a variable"
 msgstr "inicializador entre paréntesis en la matriz new"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "nombres de parámetros (sin tipos) en la declaración de la función"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD redeclared as variable"
 msgid "add parentheses to declare a variable"
 msgstr "la función %qD se redeclaró como variable"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "una definición de función no se permite aquí"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "no se permite una especificación-asm en una definición-de-función"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "no se permiten atributos en una definición-de-función"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "se esperaba un constructor, un destructor, o una conversión de tipo"
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "se proporcionó un inicializador para la función"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "se redeclara la función %q+D como inline"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "el límite de la matriz no es una constante entera"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "no se puede definir el miembro de la definición de tipo dependiente %qT"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> no es un tipo"
@@ -56739,463 +56798,463 @@ msgstr "%<%T::%E%> no es un tipo"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "declarador no válido"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "uso no válido del constructor como una plantilla"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "use %<%T::%D%> en lugar de %<%T::%D%> para nombrar el constructor en un nombre calificado"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "qualified-id in declaration"
 msgstr "tipo no válido en la declaración"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "se esperaba un declarador"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD es un espacio de nombres"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "se esperaba un operador puntero"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "calificador-cv duplicado"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "especificadores `virtual' múltiples"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "--resource requiere -o"
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "especificador-virt duplicado"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments after %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "%qT not permitted in template argument"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "uso no válido de %qT"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "no se pueden definir tipos en argumentos de plantilla"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "se esperaba un especificador de tipo"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "se esperaba %<,%> o %<...%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "no se pueden definir tipos en tipos de parámetro"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "los argumentos por defecto sólo se permiten para parámetros de función"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros plantilla no puede tener un argumento por defecto"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros no puede tener un argumento por defecto"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ no permite inicializadores designados de C99"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "se esperaba un nombre de clase"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "se esperaba %<;%> después de la definición de struct"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "se esperaba %<{%> o %<:%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "no se puede especificar %<override%> para una clase"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la calificación global del nombre de clase es no válida"
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "el nombre calificado no nombra una clase"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nombre de clase no válido en la declaración de %qD"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "una especialización explícita se debe preceder con %<template <>%>"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "la plantilla de función %qD se redeclaró commo una plantilla de clase"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "no se puede resolver el tipo typename"
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "definición previa de %q+#T"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "se esperaba una llave de clase"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03 se debe usar una llave-clase cuando se declara un friend"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, fuzzy, gcc-internal-format
 #| msgid "alignment specified for unnamed bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "se especificó la alineación para el campo de bits sin nombre"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "campo de bits %qD con tipo no integral"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "especificador-pure en la definición-de-función"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "especificador pure no válido (sólo se permite %<= 0%>)"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "un inicializador dentro de llaves no se permite aquí"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> specified more than once in base-specified"
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "se especificó %<virtual%> más de una vez en la base especificada"
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "more than one access specifier in base-specified"
 msgid "more than one access specifier in base-specifier"
 msgstr "más de un especificador de acceso en la base especificada"
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (la clase base es implícitamente un tipo)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "no se pueden definir tipos en una especificación de excepción"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "debido a diferentes especificaciones de excepciones"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, fuzzy, gcc-internal-format
 #| msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "las especificaciones de excepción dinámicas son obsoletas en C++0x; utilice %<noexcept%> en su lugar"
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "El atributo %qE genera un conflicto con el atributo %s"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "se esperaba un identificador o %<(%>"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, fuzzy, gcc-internal-format
 #| msgid "%<fallthrough%> attribute specified multiple times"
 msgid "attribute %qs specified multiple times"
 msgstr "atributo %<fallthrough%> especificado múltiples veces"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 #| msgid "expression must be integral"
 msgid "expression must be enclosed in parentheses"
 msgstr "la expresión debe ser integral"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "asm template is not a string constant"
 msgid "result type is not a plain type-constraint"
 msgstr "la plantilla asm no es una cadena constante"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not an integer constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "la alineación solicitada no es una constante entera"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "el miembro especializado %<%T::%E%> requiere sintaxis %<template<>%>"
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "declaración no válida de %<%T::%E%>"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "faltan listas-de-parámetros-de-plantilla"
@@ -57204,650 +57263,650 @@ msgstr "faltan listas-de-parámetros-de-plantilla"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "demasiadas listas-de-parámetros-de-plantilla"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "ya no se admiten los valores de devolución nombrados"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "declaración no válida de plantilla miembro en la clase local"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "plantilla con enlace C"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "especialización explícita no válida"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "declaración plantilla de %<typedef%>"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "la declaración no declara nada"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "la especialización de plantilla explícita no puede tener una clase de almacenamiento"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> debe ser %<> >%> dentro de una lista de argumentos de plantilla anidada"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%<>>%> sobrante, use %<>%> para terminar una lista de argumentos de plantilla"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "uso no válido de %qD en la especificación de enlace"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> antes de %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 no admite %<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "se usaron al mismo tiempo %<_Sat%> y %<char%> en los especificadores de declaración"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE duplicado"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs duplicado"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "se esperaba %<new%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "se esperaba %<delete%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "se esperaba %<return%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "se esperaba %<extern%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "se esperaba %<static_assert%>"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "se esperaba %<decltype%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "se esperaba %<class%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "se esperaba %<template%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "se esperaba %<namespace%>"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "se esperaba %<using%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "se esperaba %<asm%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "se esperaba %<try%>"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "se esperaba %<catch%>"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "se esperaba %<throw%>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>"
 msgid "expected %<auto%>"
 msgstr "se esperaba %<data%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "se esperaba %<__label__%>"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "se esperaba %<@try%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "se esperaba %<@synchronized%>"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "se esperaba %<@throw%>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "se esperaba %<__transaction_atomic%>"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "se esperaba %<__transaction_relaxed%>"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "se esperaba %<@end%>"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "se esperaba %<::%>"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "se esperaba %<...%>"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "se esperaba %<*%>"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "se esperaba %<~%>"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "se esperaba %<:%> o %<::%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "se usó la etiqueta %qs al nombrar a %q#T"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T se declaró previamente aquí"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT se declaró con mayor visibilidad que su base %qT"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 #| msgid "expected class-key"
 msgid "replace the class-key with %qs"
 msgstr "se esperaba una llave de clase"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 #| msgid "  first declared as %q#D here"
 msgid "%qT first declared as %qs here"
 msgstr "  declarado inicialmente como %q#D aquí"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD se redeclaró con acceso diferente"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (como desambiguador) sólo se permite dentro de plantillas"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "el fichero termina en el argumento por defecto"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construct Objective-C++ %<@%D%> mal ubicado"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> debe especificar un tipo como un argumento"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nombre de selector Objective-C++ no válido"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "se esperaba una declaración de método de objective-c++"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "los atributos de método se deben especificar al final"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs sobrante después de los métodos Objective-C++"
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "tipo no válido para la variable de de instancia"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "se esperaba un identificador después de %<@protocol%>"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "los atributos no se pueden especificar antes de la palabra clave de Objective-C++ %<@%D%>"
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "se descartan los atributos de prefijo antes de %<@%D%>"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "tipo no válido para la propiedad"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown property attribute %qE"
 msgstr "atributo de propiedad desconocido"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "se esperaba una expresión entera"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in parameter types"
 msgid "types may not be defined in iterator type"
 msgstr "no se pueden definir tipos en tipos de parámetro"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%> en OpenMP"
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, fuzzy, gcc-internal-format
 #| msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable de iteración %qD no debe ser reduction"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "no hay suficientes bucles DO para los !$OMP DO colapsados en %L"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp end declare target%> sin su correspondiente %<#pragma omp declare target%>"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "se esperaba una expresión id"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "no se pueden definir tipos nuevos en un tipo de devolución"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, fuzzy, gcc-internal-format
 #| msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "tipo calificado const, volatile o restrict en %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD no es una función plantilla miembro"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> más externo no está dentro del %<__transaction_atomic%> más externo"
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  o una función %<transaction_may_cancel_outer%>"
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC coprocessor"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC coprocessor malformado"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "no se han implementado las optimizaciones intermódulos para C++"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "no se permiten las conversiones estándar en este contexto"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "el dato miembro %qD no puede ser una plantilla miembro"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "declaración de la plantilla miembro %qD no válida"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "especialización explícita en el ámbito %qD que no es espacio de nombres"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "las plantillas de clase contenedoras no son explícitamente especializadas"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "especialización de %qD en un espacio de nombres diferente"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr " de la definición de %q+#D"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "instanciación explícita de %qD en el espacio de nombres %qD (el cual no incluye el espacio de nombres %qD)"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "el nombre de la clase oscurece la plantilla de parámetro de plantilla %qD"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of alias template %qD"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "especialización de %qT después de la instanciación"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -57855,156 +57914,156 @@ msgstr " de la definición de %q+#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "especialización de %qT después de la instanciación %qT"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "no se permite la especialización de plantilla de %qD por ISO C++"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "especialización de %qD después de la instanciación"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD no es una plantilla de función"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD no es una variable"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "el id-de-plantilla %qD para %q+D no coincide con ninguna declaración de plantilla"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "se encontró %d %<template<>%>, se necesita %d para especializar una plantilla de función miembro"
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "especialización de plantilla %qD ambigua para %q+D"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "especialización explícita de %qD después del primer uso"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "instanciación explícita de %qD en el espacio de nombres %qD (el cual no incluye el espacio de nombres %qD)"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "especialización explícita de %qD después del primer uso"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing primary template attributes %s"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing primary template attribute %s"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "no se usan la plantilla de lista de parámetros en la instanciación explícita"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "se proporcionó una definición para la instanciación explícita"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "demasiadas listas de parámetros de plantilla en la declaración de %qD"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "faltan listas de parámetros de plantilla en la declaración de %qD"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "la especialización explícita de %qD se debe preceder con %<template <>%>"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "no se permite la especialización parcial de la función de plantilla %qD"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "no se permite la especialización parcial de la función de plantilla %qD"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "se especificó un argumento por defecto en la especialización explícita"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD no es una función plantilla"
@@ -58017,180 +58076,180 @@ msgstr "%qD no es una función plantilla"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "especialización de la función miembro especial declarada implícitamente"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "la función no miembro %qD se declaró en %qT"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "una declaración friend %qD en una clase local sin declaración previa"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 #| msgid "shadowed declaration is here"
 msgid "friend declaration here"
 msgstr "aquí está la declaración oscurecida"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "El argumento de ACOS en %L debe estar entre -1 y 1"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "la expansión del inicializador base %<%T%> no contiene paquetes de parámetro"
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "el patrón de expansión %<%T%> no contiene paquetes de argumento"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "el patrón de expansión %<%E%> no contiene paquetes de argumento"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "no se expanden los paquetes de parámetro con %<...%>"
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "el tipo de parámetro de plantilla %qT se declaró %<friend%>"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of variable concept %q#D"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "no se usan los parámetros de plantilla en la especialización parcial:"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "demasiados argumentos para la función %qE"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template %qD"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qE debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qT debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "el tipo %qT del argumento de plantilla %qE depende de un parámetro de plantilla"
 msgstr[1] "el tipo %qT del argumento de plantilla %qE depende de parámetros de plantilla"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of %qT after instantiation of %qT"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "especialización parcial de %qT después de la instanciación %qT"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "no hay un argumento por defecto para %qD"
@@ -58199,51 +58258,51 @@ msgstr "no hay un argumento por defecto para %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "el parámetro de paquete %qE debe estar al final de la lista de parámetros de plantilla"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en la re-declaración friend de la plantilla de función"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las declaraciones friend de la plantilla de función"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los argumentos de plantilla por defecto no se pueden usar en las plantillas de función sin -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las especializaciones parciales"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "template %qD declared"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "clase de plantilla sin nombre"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -58254,65 +58313,65 @@ msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "declaración de la plantilla de %qD no válida"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definición de plantilla de %q#D que no es plantilla"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "se esperaban %d niveles de parámetros de plantilla para %q#D, se obtuvieron %d"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#T"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  pero se requieren %d"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "los argumentos de plantilla para %qD no coinciden con la plantilla original %qD"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilice template<> para una especialización explícita"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT no es un tipo plantilla"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "no se especificaron los especificadores de plantilla en la declaración de %qD"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "se redeclaró con %d parámetro de plantilla"
 msgstr[1] "se redeclaró con %d parámetros de plantilla"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -58321,138 +58380,138 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "la declaración previa de %q+#D usó %d parámetro de plantilla"
 msgstr[1] "la declaración previa de %q+#D usó %d parámetros de plantilla"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parámetro de plantilla %q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeclarado aquí como %q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinición del argumento por defecto para %q#D"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %q#D with different constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "debe ser un puntero-a-miembro de la forma %<&X::Y%>"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD no es un miembro de %qT"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  no se puede deducir el parámetro de plantilla %qD"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  los tipos %qT y %qT tiene calificadores-cv incompatibles"
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  no coinciden los tipos %qT y %qT"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  el parámetro de plantilla %qD no es un paquete de parámetro, pero el argumento %qD sí"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  el argumento de plantilla %qE no coincide con la constante puntero-a-miembro %qE"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE no es equivalente a %qE"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  deducción de paquete de parámetros inconsistente con %qT y %qT"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  se deducen tipos en conflicto para el parámetro %qT (%qT y %qT)"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  se deducen valores en conflicto para el parámetro %qE que no es tipo (%qE y %qE)"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  el tipo de función miembro %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -58461,323 +58520,323 @@ msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  el candidato espera %d argumento, se proporcionaron %d"
 msgstr[1] "  el candidato espera %d argumentos, se proporcionaron %d"
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  no se puede convertir %qE (tipo %qT) al tipo %qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT es una clase base ambigua de %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT no es derivado de %qT"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  los parámetros de plantilla de un argumento de plantilla plantilla son inconsistentes con otros argumentos de plantilla deducidos"
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "  can't deduce a template for %qT from non-template type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  no se puede deducir una plantilla para %qT del tipo %qT que no es plantilla"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument %qE does not match %qD"
 msgid "  template argument %qE does not match %qE"
 msgstr "  el argumento de plantilla %qE no coincide con %qD"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qE no es una variable"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque las literales de cadena nunca se pueden usar en este contexto"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "in template argument for type %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT debido a conflictos en la calificación cv"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un l-valor"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D no es un argumento válido de plantilla para el tipo %qT porque una referencia variable no tiene una dirección constante"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es un puntero"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es de tipo %qT"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attributes in template argument %qE"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "se usó el nombre-de-clase-inyectada %qD como un argumento de plantilla plantilla"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "uso no válido del destructor %qE como un tipo"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "para hacer referencia a un tipo miembro de un parámetro de plantilla, use %<typename %E%>"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  se esperaba una constante de tipo %qT, se obtuvo %qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  se esperaba un tipo, se obtuvo %qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  se esperaba una plantilla de tipo %qD, se obtuvo %qT"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "no se puede convertir el argumento de plantilla %qE a %qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "el argumento de plantilla %d es no válido"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "provisto por %q+D"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumento por defecto dado para el parámetro %d de %q#D"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D no es una plantilla de función"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "se usa el tipo %qT que no es plantilla como una plantilla"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "para la declaración de plantilla %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "falla interna de consistencia"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d (use -ftemplate-depth= para incrementar el máximo) al sustituir %qS"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "miembro de matriz flexible en union"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a potential constant expression"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE no es una expresión constante potencial"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%T%>"
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%E%>"
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "redefinición del argumento por defecto para %q#D"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "se crea un puntero a función miembro del tipo %qT que no es clase"
@@ -58795,305 +58854,305 @@ msgstr "se crea un puntero a función miembro del tipo %qT que no es clase"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD tiene tipo de función"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipo de parámetro %qT no válido"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "en la declaración %q+D"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "la función devuelve una matriz"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "la función devuelve una función"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "se forma la referencia a void"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "se forma un puntero para referenciar al tipo %qT"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "se forma una referencia para referenciar al tipo %qT"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "se crea un puntero al miembro de tipo void"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT no es de tipo clase, struct o union"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo enumerado"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo de clase"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificador %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "el nombre dependiente %qE se decodifica como un no tipo, pero la instanciación genera un tipo"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "escriba %<typename %E%> si quiere un tipo"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "se usa el campo no válido %qD"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "uso no válido de la expresión de expansión de paquete"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "use %<...%> para expandir el paquete de argumentos"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD no se declaró en este ámbito, y no se encontraron declaraciones en la búsqueda dependiente de argumentos en el punto de la instanciación"
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "no se encontraron declaraciones en la base dependiente %qT pur la búsqueda no calificada"
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "use %<this->%D%> en su lugar"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "use %<%T::%D%> en su lugar"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D se declaró aquí, después en la unidad de translación"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "número erróneo de argumentos para %<__builtin_choose_expr%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD no es una clase o un espacio de nombres"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT es/usa un tipo anónimo"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "el argumento de plantilla para %qD usa el tipo local %qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT es un tipo modificado variablemente"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  se trata de instanciar %qD"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciación explícita de %q#D que no es plantilla"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "el tipo %qT para la instanciación explícita %qD no coincide con el tipo declarado %qT"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciación explícita de %q#D"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciación explícita duplicada de %q#D"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 prohíbe el uso de %<extern%> en instanciaciones explícitas"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "clase de almacenamiento %qD aplicada a la instanciación de una plantilla"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciación explícita de la plantilla %qD que no es clase"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciación explícita del tipo %qT que no es plantilla"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciación explícita de %q#T antes de la definición de la plantilla"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ prohíbe el uso de %qE en las instanciaciones explícitas"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciación explícita duplicada de %q#T"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -59106,173 +59165,173 @@ msgstr "especialización explícita de %qD después del primer uso"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciación explícita de %qD pero no hay una definición disponible"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d al instanciar %q+D, posiblemente de la generación de tabla virtual (use -ftemplate-depth= para incrementar el máximo)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template non-type parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT no es un espacio de nombres"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction failed:"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "la función no se consideró para la inclusión en línea"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "explicit deduction guide declared here"
 msgstr "en una llamada a la función %qD declarada aquí"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %qT in template argument"
@@ -59425,587 +59484,587 @@ msgstr "%q+#D no se puede declarar"
 msgid "  since %q+#D declared in base class"
 msgstr "  ya que se declaró %q+#D en la clase base"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared %<constexpr%>"
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%qD no se declaró %<constexpr%>"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "se sugieren llaves explícitas alrededor del cuerpo vacío en la declaración %<do%>"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "catching non-reference type %q#T"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 #| msgid "type of asm operand %qE could not be determined"
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "no se puede determinar el tipo del operando asm %qE"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "__label__ declarations are only allowed in function scopes"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "las declaraciones __label__ sólo se permiten en ámbitos de función"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "uso no válido del miembro %q+D en la función miembro static"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "%qE missing template arguments"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "no se permiten argumentos para el destructor"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> no está disponible para funciones miembro static"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "uso no válido de %<this%> en la función que no es miembro"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "uso no válido de %<this%> en el nivel principal"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ámbito calificador no válido en el nombre del seudo-destructor"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificado %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE no es de tipo %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "la literal compuesta del tipo %qT que no es objeto"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "los parámetros de tipo plantilla debe usar la palabra clave %<class%> o %<typename%>"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "uso no válido del tipo %qT como un valor por defecto para una plantilla de parámetro de plantilla"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argumento por defecto no válido para una plantilla de parámetro de plantilla"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "la definición de %q#T dentro de la lista de parámetros de plantilla"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "definición no válida del tipo calificado %qT"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "especificación de clase base no válida"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD no se capturó"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "uso de la variable %<auto%> desde la función contenedora"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "uso de parámetro desde la función contenedora"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter %qD outside function body"
 msgid "use of parameter outside function body"
 msgstr "se usó el parámetro %qD fuera del cuerpo de la función"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "no se permite el parámetro de plantilla %qD de tipo %qT en una expresión integral constante porque no es de tipo integral o de enumeración"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "uso de la plantilla de clase %qT como expresión"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "la petición por el miembro %qD es ambigua en la red de herencia múltiple"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD no puede aparecer en una expresion constante"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "el tipo de %qE es desconocido"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT no es un tipo de enumeración"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter pack __bases only valid in template declaration"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "Los paquetes de parámetros __bases sólo son válidos en la declaración de plantilla"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "no se puede aplicar %<offsetof%> al destructor %<~%T%>"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE tiene tipo no válido para %<reduction%>"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD no es una variable en la cláusula %<firstprivate%>"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD no es una variable en la cláusula %<lastprivate%>"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<device%> id must be integral"
 msgstr "el final de la rebanada debe ser entero"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE no es una variable en la cláusula %<saligned%>"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "demasiadas cláusulas %qs"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD no es un fichero, espacio de nombres o variable de ámbito de bloque"
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directiva %<threadprivate%> %qE no está en la definición %qT"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la diferencia entre %qE y %qD no tiene tipo entero"
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "falló la aserción estática: %s"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, fuzzy, gcc-internal-format
 #| msgid "self-comparison always evaluates to false"
 msgid "%qE evaluates to false"
 msgstr "autocomparación siempre falsa"
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condición que no es constante para una aserción estática"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 #| msgid "decltype cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "el tipo de declaración no puede resolver la dirección de la función sobrecargada"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "third operand of conditional expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -60014,22 +60073,22 @@ msgstr "argumento no admitido para %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -60039,1148 +60098,1149 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "los calificadores %qV no se pueden aplicar a %qT"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "statement-expression in a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid " declared here"
 msgstr "se declara aquí"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "la clase base %qT tiene calificadores cv"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not captured"
 msgid "%qD is not public"
 msgstr "%qD no se capturó"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD no es una variable"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD has a non-structural type"
 msgstr "%qD no es un tipo"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "el argumento del atributo %qE no es una constante de cadena"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be applied to variables with specific sections"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "el atributo %qE no se puede aplicar a variables con secciones específicas"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "%qE attribute takes no arguments"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "el atributo %qE no se aplica a funciones"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "la init_priority solicitada no es una constante entera"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "solo se puede usar el atributo %qE en definiciones de rango de fichero de objetos de tipo class"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "la init_priority solicitada está fuera de rango"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "la init_priority solicitada está reservada para uso interno"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "el atributo %qE no se admite en esta plataforma"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "%.*s is not a valid universal character"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%.*s no es un carácter universal válido"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> no es un declarador válido"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "se descarta el atributo %qE en tipos que no son clases"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "el atributo %qE se aplica solamente a funciones, no a %s"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "El atributo %s se aplica a %s %s en %L"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "cero como constante de puntero nulo"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "revisión lang_*: falló en %s, en %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la comparación entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la conversión entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la expresión condicional entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ prohíbe la comparación entre punteros de tipo %<void *%> y punteros a función"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ prohíbe la conversión entre punteros de tipo %<void *%> y punteros a función"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ prohíbe la expresión condicional entre punteros de tipo %<void *%> y punteros a función"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la comparación entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la conversión entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la expresión condicional entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "canonical types differ for identical types %T and %T"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "los tipos canónicos difieren para los tipos idénticos %T y %T"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "el mismo nodo de tipo canónico para los tipos diferentes %T y %T"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "aplicación no válida de %qs a una función miembro"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "aplicación no válida de %<sizeof%> a un campo de bits"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ prohíbe la aplicación de %<sizeof%> a una expresión de tipo de función"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "aplicación no válida de %<__alignof%> a un campo de bits"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ prohíbe la aplicación de %<__alignof%> a una expresión de tipo de función"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "se toma la dirección de la matriz temporal"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "conversión obsoleta de una constante de cadena a %qT"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "conversión obsoleta de una constante de cadena a %qT"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "solicitud por el miembro %qD en %qE, el cual es de tipo puntero %qT (¿ Tal vez quiso utilizar %<->%> ?)"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "solicitud por el miembro %qD en %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "uso no válido del dato miembro no static %qE"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD  of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "acceso no válido a datos del miembro que no es static %qD  del objeto NULL"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "el tipo de objeto %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "el tipo que se destruye es %qT, pero el destructor se refiere a %qT"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> no es un miembro de %qT"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT no es una base de %qT"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD no es una función plantilla miembro"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT no es de tipo puntero-a-objeto"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "uso no válido del índice de matriz en puntero a miembro"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "uso no válido del unario %<*%> en puntero a miembro"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "uso no válido de la conversión implícita en puntero a miembro"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "falta el subíndice en la referencia de la matriz"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "se declaró el subíndice de la matriz como %<register%>"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "el valor indicado por el subíndice no es ni matriz ni puntero"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "falta un objeto en el uso de %qE"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ prohíbe la llamada %<::main%> dentro del mismo programa"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "se debe usar %<.*%> o %<->*%> en la llamada a la función puntero-a-miembro en %<%E (...)%>, p.e. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "faltan argumentos para el constructor %q#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "demasiados argumentos para la función miembro %q#D"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "faltan argumentos para la función miembro %q#D"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "demasiados argumentos para la función %q#D"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "faltan argumentos para la función %q#D"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "demasiados argumentos para el método %q#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "faltan argumentos para el método %q#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "demasiados argumentos para la función"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "faltan argumentos para la función"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "el parámetro %P de %qD tiene el tipo incompleto %qT"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "el parámetro %P tiene el tipo incompleto %qT"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "la dirección de %qD nunca debe ser NULL"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, fuzzy, gcc-internal-format
 #| msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "la comparación siempre se evalúa como %<true%> para la dirección de %qD que nunca será NULL"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "la conversión entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "la comparación entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "conversión del tipo puntero %qT al tipo aritmético %qT en una expresión constante"
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "se asume la conversión al tipo %qT desde la función sobrecargada"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "se usó NULL en la aritmética"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ prohíbe la comparación entre puntero y entero"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "comparación ordenada de puntero con el entero cero"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "comparación sin orden en el argumento de coma no flotante"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro operando de la expresión binaria"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operadores no válidos de tipos %qT y %qT para el binario %qO"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero de tipo %<void *%> en la sustracción"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a una función en la sustracción"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a un método en la sustracción"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "uso no válido de un puntero a un tipo incompleto en aritmética de punteros"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "se toma la dirección del constructor %qE"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "se toma la dirección del destructor %qE"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "uso no válido de %qE para formar una función puntero a miembro"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  se requiere un id calificado"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "no se pueden usar paréntesis alrededor de %qE para formar una función-puntero-a-miembro"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro no estática sin calificar o entre paréntesis para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro limitada para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "se toma la dirección del temporal"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ prohíbe tomar la dirección de la función %<::main%>"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "no se puede crear un puntero al miembro referencia %qD"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "no se puede tomar la dirección del campo de bits %qD"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of an immediate function %qD"
 msgstr "se toma la dirección del destructor %qE"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "se toma la dirección de la expresión de tipo %<id%>"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ prohíbe decrementar un enum"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "no se puede incrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "no se puede decrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe incrementar un puntero de tipo %qT"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe decrementar un puntero de tipo %qT"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, fuzzy, gcc-internal-format
 #| msgid "use of cast expressions as lvalues is deprecated"
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "el uso de expresiones de conversión como l-valores es obsoleto"
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "no se puede tomar la dirección de %<this%> que es una expresión r-valuada"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "se solicitó la dirección de la variable register explícita %qD"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "se solicitó la dirección de %qD, la cual se declaró como %<register%>"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "el inicializador de lista para el tipo que no es clase no debe estar entre paréntesis"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en en inicializador"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en el inicializador de memoria"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "se trata la lista de expresiones como una expresión compuesta en la conversión funcional"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "se trata la lista de expresiones como una expresión compuesta %s"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "no hay contexto para resolver el tipo de %qE"
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "la conversión del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %q#T"
 msgstr "%qT usa el tipo local %qT"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "static_cast no válido del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "se convierte de %qT a %qT"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "conversión no válida de una expresión r-valuada de tipo %qT al tipo %qT"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "la conversión de %qT a %qT pierde precisión"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 #, fuzzy
 #| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "la comparación entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "la conversión de %qT a %qT incrementa la alineación requerida del tipo del destino"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ prohíbe la conversión entre puntero a función y puntero a objeto"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "conversión no válida del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "uso no válido de const_cast con tipo %qT, que no es puntero, referencia, ni un tipo puntero-a-datos-miembro"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "uso no válido de const_cast con tipo %qT, el cual es un puntero o referencia a un tipo de función"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "const_cast no válido de un valor-r de tipo %qT al tipo %qT"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "const_cast no válido del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ prohíbe la conversión a un tipo de matriz %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "conversión no válida al tipo de función %qT"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  en la evaluación de %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "se asigna a una matriz desde una lista de inicializador"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipos incompatible en la asignación de %qT a %qT"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "se usó una matriz como inicializador"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "asignación de matriz no válida"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   en la conversión del puntero a función miembro"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "puntero a la conversión miembro a través de la base virtual %qT"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   en la conversión del puntero a miembro"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversión no válida del tipo %qT a partir del tipo %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "no se puede convertir %qT a %qT en el argumento por defecto"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "no se puede convertir %qT a %qT en el paso de argumentos"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
 msgstr "no se puede convertir %qT a %qT en la devolución"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "no se puede convertir %qT a %qT en la asignación"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "el parámetro %qP de %qD puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "el parámetro puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "el objetivo de conversión puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "el objetivo de inicialización puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la asignación puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "al pasar el argumento %P de %q+D"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "se devuelve la referencia al temporal"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "se devolvió una referencia a la variable local %q+D"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "not enough values in return statement"
 msgid "redundant move in return statement"
 msgstr "faltan valores en la declaración de devolución"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "se devuelve un valor de un destructor"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "no se puede regresar de un manejador de una función-intenta-bloque de un constructor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "se devuelve un valor de un constructor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 #| msgid "<brace-enclosed initializer list>"
 msgid "returning initializer list"
 msgstr "<lista inicializador dentro de llaves>"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "se deducen los tipos inconsistentes %qT y %qT para el tipo de devolución lambda"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> no debe regresar NULL a menos que se declare %<throw()%> (o -fcheck-new esté en efecto)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 #| msgid "using temporary as lvalue"
 msgid "using rvalue as lvalue"
@@ -61469,113 +61529,107 @@ msgstr "llaves alrededor del inicializador escalar"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "no se puede inicializar el agregado del tipo %qT con una literal compuesta"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "el tipo de %qD no coincide con la declaración original"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "no existe el campo %qD en la union que se está inicializando"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valor de índice en lugar del nombre del campo en el inicializador de union"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "se detectó una delegación de puntero circular"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "el operando base de %<->%> tiene el tipo %qT que no es puntero"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "el resultado de %<operator->()%> produce un resultado que no es puntero"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "el operando base de %<->%> no es un puntero"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "no se puede usar %qE como un puntero miembro, porque es de tipo %qT"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "no se puede aplicar el puntero a miembro %qE a %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "el tipo de puntero a miembro %qT es incompatible con el tipo objeto %qT"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "conversión funcional al tipo de matriz %qT"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-#| msgid "in template argument for type %qT "
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "en el argumento de plantilla para el tipo %qT "
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "inicialización por valor no válida del tipo de referencia"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "llamada a la función %qD la cual arroja el tipo incompleto %q#T"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "llamada a una función la cual arroja el tipo incompleto %q#T"
@@ -61595,301 +61649,307 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "extern symbols cannot have initializers"
 msgstr "El external '%s' en %L no puede tener un inicializador"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, fuzzy, gcc-internal-format
 #| msgid "asm not allowed in %<transaction_safe%> function"
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "no se permite asm en una función %<transaction_safe%>"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variables cannot be of type void"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "cannot be declared to be a function"
 msgstr "new no se puede aplicar a un tipo de función"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of %<struct %E%>"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "redefinición de %<struct %E%>"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be %s"
 msgstr "no se puede abrir %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be `scope` and `%s`"
 msgstr "no se puede abrir %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, fuzzy, gcc-internal-format
 #| msgid "\"defined\" cannot be used as a macro name"
 msgid "field cannot be `scope`"
 msgstr "\"defined\" no se puede usar como un nombre de macro"
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "Use the Cygwin interface"
 msgid "field not allowed in interface"
 msgstr "Usa la interfaz Cygwin"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, fuzzy, gcc-internal-format
 #| msgid "old-style parameter declaration"
 msgid "only parameters or foreach declarations can be ref"
 msgstr "declaración de parámetros de estilo antiguo"
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "variable-size type declared outside of any function"
 msgid "inout variables can only be declared inside inout functions"
 msgstr "tipo de tamaño variable declarado fuera de cualquier función"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer list construction invalid for `%D'"
 msgid "default construction is disabled for type %s"
 msgstr "construcción de la lista de inicializadores no válida para `%D'"
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "reference to dead statement"
 msgid "reference to scope class must be scope"
 msgstr "referencia a sentencia muerta"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 #| msgid "only zero initializers are allowed in section %qs"
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "solo se permiten inicializadores a cero en la sección %qs"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 #| msgid "macro names must be identifiers"
 msgid "manifest constants must have initializers"
 msgstr "los nombres de macro deben ser identificadores"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "braced spec body %qs is invalid"
 msgid "size of type %s is invalid"
 msgstr "el cuerpo de la especificación entre llaves %qs es no válido"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%s does not have a default initializer"
 msgstr "El dummy '%s' en %L no puede tener un inicializador"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "is not a static and cannot have static initializer"
 msgstr "El external '%s' en %L no puede tener un inicializador"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "static storage variables cannot have destructors"
 msgstr "la clase Java %qT no puede tener un destructor"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "string expected for library name"
 msgstr "se esperaba un nombre de clase"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "function name expected for start address"
 msgstr "efectos colaterales inesperados en la dirección"
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 #| msgid "expected function name"
 msgid "string expected for mangled name"
 msgstr "se esperaba nombre de función"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "sin argumentos"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on primary template declaration."
 msgid "can only apply to a single declaration"
 msgstr "Avisa en la declaración de la plantilla primeraria."
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%s'"
 msgid "pragma is missing closing `;`"
 msgstr "falta el tamaño de la matriz en %s"
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "repeated using declaration %q+D"
 msgid "incomplete mixin declaration (%s)"
 msgstr "se repitió usando la declaración %q+D"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, fuzzy, gcc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "base type must not be void"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "must have at least one catch per try block"
 msgid "enum %s must have at least one member"
 msgstr "se debe tener por lo menos un catch por cada bloque try"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "circular reference to enum member"
 msgstr "se devuelve la referencia al temporal"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, fuzzy, gcc-internal-format
 #| msgid "%s: partial loss of precision"
 msgid "has inexact value, due to loss of precision"
 msgstr "%s: pérdida parcial de precisión"
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgid "template tuple parameter must be last one"
 msgstr "los parámetros de tipo plantilla debe usar la palabra clave %<class%> o %<typename%>"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "inserción en línea recursiva"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "inserción en línea recursiva"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "error instantiating"
 msgstr "error al escribir %qs"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs must be the first clause of %qs"
 msgid "%s must be a function instead of %s"
 msgstr "%qs debe ser la primera cláusula de %qs"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "functions cannot be scope"
@@ -61898,45 +61958,55 @@ msgstr "las funciones virtual no pueden ser friend"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s method can't be abstract"
 msgid "%s functions cannot be abstract"
 msgstr "el método %s no puede ser abstracto"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about overloaded virtual function names."
 msgid "cannot override a non-virtual function"
 msgstr "Advierte de nombres de funciones virtuales sobrecargadas."
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify both -C and -o"
 msgid "cannot be both final and abstract"
 msgstr "no se pueden especificar -C y -o al mismo tiempo"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -61944,194 +62014,194 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overriding final function %q+D"
 msgid "cannot override final function %s"
 msgstr "se anula la función final %q+D"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "multiple save reg attributes to function %qD"
 msgid "multiple overrides of same function"
 msgstr "múltiples atributos de guardar registro para la función %qD"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+D has incompatible attributes %qs and %qs"
 msgid "incompatible covariant types %s and %s"
 msgstr "%q+D tiene atributos incompatibles %qs y %qs"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not refer to a function"
 msgid "does not override any function"
 msgstr "%qD no hace referencia a una función"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overriding final function %q+D"
 msgid "cannot override final function %s.%s"
 msgstr "se anula la función final %q+D"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "naked attribute only applies to functions"
 msgid "override only applies to class member functions"
 msgstr "atributo desnudo se aplica solamente a funciones"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn about overloaded virtual function names."
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "Advierte de nombres de funciones virtuales sobrecargadas."
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "first argument must be []byte"
 msgid "first argument must be type size_t, not %s"
 msgstr "el primer argumento debe ser []byte"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "vector types expected in sad expression"
 msgid "one argument of type void* expected, not %s"
 msgstr "se esperaban tipos vector en una expresión de permutación de vector"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "%s method can't be abstract"
 msgid "structs, unions cannot be abstract"
 msgstr "el método %s no puede ser abstracto"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `static' invalid for function `%s' declared out of global scope"
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr "la clase de almacenamiento `static' es no válida para la función `%s' declarada fuera del ámbito global"
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer"
 msgid "base type must be class or interface, not %s"
 msgstr "El puntero Cray en %C debe ser un entero"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Cyclic class inheritance%s"
 msgid "circular inheritance"
 msgstr "Herencia%s con ciclo de clase"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer"
 msgid "base type must be interface, not %s"
 msgstr "El puntero Cray en %C debe ser un entero"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "se descarta el directorio duplicado \"%s\"\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot inherit from final class %s"
 msgstr "no se puede encontrar el fichero para la clase %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type transparent class %qT has virtual functions"
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "la clase transparente tipo %qT tiene funciones virtuales"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: created with -g%s, but used with -g%s"
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr "%s: creado con -g%s, pero se usó con -g%s"
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, fuzzy, gcc-internal-format
 #| msgid "circular inheritance in interface declaration for `%s'"
 msgid "circular inheritance of interface"
 msgstr "herencia circular en la declaración de interfaz para `%s'"
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "mixin templates are not regular templates"
 msgstr "los parámetros de la plantilla no coinciden con la plantilla"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "el id-de-plantilla %qD para %q+D no coincide con ninguna declaración de plantilla"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot read %s"
 msgid "cannot resolve"
 msgstr "No se puede leer %s"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rank mismatch in expression %qE"
 msgid "cannot alias an expression %s"
@@ -62148,22 +62218,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr "falló al abrir %s: %s"
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "Alias has non-alias reference"
 msgid "has forward references"
@@ -62232,23 +62302,22 @@ msgstr "modificador de tipo no válido dentro de la declaración del puntero"
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "el tipo de devolución de función no puede ser función"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "the call requires ifunc, which is not supported by this target"
 msgid "naked assembly functions with contracts are not supported"
@@ -62828,7 +62897,7 @@ msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "'I' en %L y 'J' en %L no pueden ser constantes literal BOZ al mismo tiempo"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid suffix on integer constant"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -64079,12 +64148,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Se truncó la cadena de inicialización que inicia en %L para coincidir con la variable (%d%d)"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "El índice de inicio de la subcadena en %L es menor a uno"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "El índice de final de la subcadena en %L excede la longitud de la cadena"
@@ -64287,7 +64356,7 @@ msgstr "Especificación INTENT errónea en %C"
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003: parámetro de tipo diferido en %C"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -67037,7 +67106,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -67131,7 +67200,7 @@ msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un buc
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -67276,12 +67345,12 @@ msgstr "El primer argumento de la asignación definida en %L debe ser INTENT(OUT
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la asignación definida en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "El primer argumento de la interfaz de operador en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la interfaz de operador en %L debe ser INTENT(IN)"
@@ -67406,635 +67475,635 @@ msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y escalar)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y rango %d)"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Argumento de procedimiento no válido en %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento dummy '%s' en %L: %s"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to contiguous pointer dummy '%s' at %L must be simply contigous"
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "El argumento actual para el puntero dummy contiguo '%s' en %L debe ser simplemente contiguo"
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "El argumento actual INTENT(%s) en %L puede interferir con el argumento actual en %L."
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "No coincide el tipo en el argumento '%s' en %L; se pasa %s a %s"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "El argumento actual de forma asumida en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must have the same declared type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "El argumento actual para '%s' en %L debe tener el mismo tipo declarado"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Corank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "No coincide el corango en el argumento '%s' en %L (%d y %d)"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be simply contiguous"
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "El argumento actual para '%s' en %L debe ser simplemente contiguo"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Argumento actual para el dummy que no es INTENT(OUT) '%s' en %L, el cual es LOCK_TYPE o tiene un componente LOCK_TYPE"
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Argumento actual para el dummy que no es INTENT(OUT) '%s' en %L, el cual es LOCK_TYPE o tiene un componente LOCK_TYPE"
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' has to be a pointer or assumed-shape array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "El argumento dummy '%s' tiene que ser un puntero o una matriz de tamaño asumida sin atributo CONTIGUOUS - porque el argumento actual en %L no es simplemente contiguo y ambos son ASYNCHRONOUS o VOLATILE"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument '%s'"
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Se pasa una comatriz en %L al argumento dummy INTENT(OUT) '%s', que no es comatriz, alojable"
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray dummy argument '%s', which is invalid if the allocation status is modified"
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Se pasa una comatriz en %L al argumento dummy '%s' que no es comatriz, el cual es no válido si se modifica el estado de alojamiento"
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic scalar passed to array dummy argument '%s' at %L"
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Se pasó un escalar polimórfico al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Se pasó un elemento de forma asumida o puntero a matriz al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Se pasó un elemento de forma asumida o puntero a matriz al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Extensión: Argumento actual CHARACTER de género diferente a C_CHAR, sin género por defecto escalar con argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Argumento actual CHARACTER escalar con argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "El argumento de palabra clave '%s' en %L ya está asociado con otro argumento actual"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Más argumentos actuales que formales en la llamada a procedimento en %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Falta la especificación de devolución alternativa en la llamada a subrutina en %L"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Especificación de devolución alternativa inesperada en la llamada a subrutina en %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Null pointer at %L to non-pointer dummy '%s'"
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Puntero nulo en %L a un dummy '%s' que no es puntero"
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "No coincide la longitud de carácter (%ld/%ld) entre el argumento actual y el argumento dummy puntero o alojable '%s' en %L"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "No coincide la longitud de carácter (%ld/%ld) entre el argumento actual y el argumento dummy de forma asumida '%s' en %L"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L to allocatable or pointer dummy argument '%s' must have a deferred length type parameter if and only if the dummy has one"
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "El argumento actual en %L para el argumento alojable o dummy puntero '%s' debe tener un parámetro de tipo de longitud diferido si y sólo si el dummy tiene uno"
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "La longitud del carácter del argumento actual es más corta que la del argumento dummy '%s' (%lu/%lu) en %L"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "El argumento actual contiene muy pocos elementos para el argumento dummy '%s' (%lu/%lu) en %L"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Se esperaba un puntero procedimiento para el argumento '%s' en %L"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Falta un procedimiento para el argumento '%s' en %L"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "El argumento actual para '%s' no puede ser una matriz de tamaño asumido en %L"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "El argumento actual para '%s' debe ser un puntero en %L"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy '%s'"
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: El argumento actual que no es puntero en %L para el puntero dummy '%s'"
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to pointer dummy '%s'"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Argumento actual coindizado en %L para el puntero dummy '%s'"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to allocatable dummy '%s' requires INTENT(IN)"
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "El argumento actual coindizado en %L para el dummy alojable '%s' requiere INTENT(IN)"
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy '%s' has neither ASYNCHRONOUS nor VOLATILE"
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "El argumento actual coindizado ASYNCHRONOUS o VOLATILE en %L requiere que el dummy '%s' no tenga ASYNCHRONOUS ni VOLATILE"
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy '%s' requires either VALUE or INTENT(IN)"
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "El argumento actual coindizado en %L con componente último alojable para el dummy '%s' requiere uno de VALUE o INTENT(IN)"
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "Actual CLASS array argument for '%s' must be a full array at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "El argumento de la matriz CLASS actual para '%s' debe ser una matriz completa en %L"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "El argumento actual para '%s' debe ser ALLOCATABLE en %L"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument '%s'"
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "El argumento actual de sección de matriz con subíndices vectoriales en %L es incompatible con el atributo INTENT(OUT), INTENT(INOUT), VOLATILE o ASYNCHRONOUS del argumento dummy '%s'"
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de forma asumida en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de sección de matriz en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de matriz de puntero en %L requiere un argumento dummy de forma asumida o matriz de puntero '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Falta la especificación de devolución alternativa en la llamada a subrutina en %L"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Falta el argumento actual para el argumento '%s' en %L"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "El mismo argumento actual está asociado con el argumento INTENT(%s) '%s' y el argumento INTENT(%s) '%s' en %L"
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "El argumento del procedimiento en %L es local a un procedimiento PURE y tiene el atributo POINTER"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "El argumento coindizado en %L en un procedimiento PURE se pasa a un argumento INTENT(%s)"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "El argumento actual coindizado en %L es un procedimiento PURE se pasa a un argumento dummy POINTER"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument '%s'"
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "El argumento actual polimórfico coindizado en %L se pasa al argumento dummy polimórfico '%s'"
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "El procedimiento '%s' que se llama en %L no tiene una interfaz explícita"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "El procedimiento '%s' que se llama en %L no tiene una interfaz explícita"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Se llamó al procedimiento '%s' con una interfaz implícita en %L"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "El objeto puntero '%s' en %L debe tener una interfaz de función explícita o declrararse como matriz"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, fuzzy, gcc-internal-format
 #| msgid "The allocatable object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "El objeto allocatable '%s' en %L debe tener una interfaz de función explícita o declararse como matriz"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable function '%s' at %L must have an explicit function interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "La función allocatable '%s' en %L debe tener una interfaz de función explícita"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento '%s' en %L"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "El símbolo '%s' en %L ya tenía una interfaz explícita"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "El argumento actual de LOCK_TYPE o con componente LOCK_TYPE en %L requiere una interfaz explícita para el procedimiento '%s'"
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "El argumento actual de LOCK_TYPE o con componente LOCK_TYPE en %L requiere una interfaz explícita para el procedimiento '%s'"
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "se requiere el argumento MOLD para NULL en %L"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento '%s' en %L"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Se llamó al procedimiento de componente puntero '%s' con una interfaz implícita en %L"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure pointer component '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento de componente puntero '%s' en %L"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "Se require MOLD= en un argumento NULL en %L: Ambigüedad entre las funciones específicas %s y %s "
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D es un alias del símbolo sin definir %qE"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "La entidad '%s' en %C ya está presente en la interfaz"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - too many interface type"
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "error interno - demasiados tipos de interfaz"
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "No se puede sobreescribir el GENERIC '%s' en %L"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "'%s' en %L sobreescribe un enlace de procedimiento declarad como NON_OVERRIDABLE"
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "'%s' en %L no debe ser DEFERRED porque sobreescribe un enlazado que no es DEFERRED"
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "'%s' en %L sobreescribe un procedimiento PURE y también debe ser PURE"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "'%s' en %L sobreescribe un procedimiento ELEMENTAL y también debe ser ELEMENTAL"
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "'%s' en %L sobreeescribe un procedimiento que no es ELEMENTAL y tampoco debe ser ELEMENTAL"
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "'%s' en %L sobreescribe una SUBROUTINE y también debe ser una SUBROUTINE"
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "'%s' en %L sobreescribe una FUNCTION y también debe ser una FUNCTION"
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, fuzzy, gcc-internal-format
 #| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento '%s' que sobreescribe en %L: %s"
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "'%s' en %L sobreescribe un procedimiento PUBLIC y no debe ser PRIVATE"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "El argumento dummy '%s' de '%s' en %L se debe llamar '%s' para que coincida con el argumento correspondiente al procedimiento sobreescrito"
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, fuzzy, gcc-internal-format
 #| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento '%s' que sobreescribe en %L: %s"
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "'%s' en %L debe tener el mismo nombre de argumentos formales que el procedimiento sobreeescrito"
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "'%s' en %L sobreescribe un enlace NOPASS y también debe ser NOPASS"
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "'%s' en %L sobreescribe un enlace con PASS y también debe ser PASS"
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "El argumento dummy del objeto pasado de '%s' en %L debe estar en la misma posición que el argumento dummy del objeto pasado del procedimiento sobreescrito"
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "La etiqueta %s en %L debe ser de tipo %s"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "El argumento dim en %L debe ser de tipo entero"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "El argumento %s en %L debe ser de longitud uno"
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued %s '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "La función %s valuada con carácter '%s' en %L no debe tener longitud asumida"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "El argumento actual para '%s' debe ser un puntero en %L"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "No se permite la declaración DATA en %C en un procedimiento PURE"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL procedure '%s' at %L must have an explicit interface"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "El procedimiento ELEMENTAL '%s' en %L debe tener una interfaz explícita"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to procedure `%s'"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "faltan argumentos para el procedimiento `%s'"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to procedure `%s'"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -68202,36 +68271,36 @@ msgstr "no se permite el intrínseco transformacional '%s' en %L en una expresi
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fortran 2003: Función elemental como expresión de inicialización con argumentos que no son enteros/carácter en %L"
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in DO CONCURRENT block at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en el bloque DO CONCURRENT en %L no es PURE"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "La llamada de subrutina al intrínseco '%s' en %L no es PURE"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Extensión: Conversión de %s a %s en %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Conversión de %s a %s en %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Posible cambio de valor en la conversión de %s a %s en %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Conversión de %s a %s en %L"
@@ -68239,25 +68308,25 @@ msgstr "Conversión de %s a %s en %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "No se puede convertir %s a %s en %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "No se puede convertir %s a %s en %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "'%s' declarado en %L puede oscurecer al intrínseco del mismo nombre. Para llamar al intrínsico, tal vez se requieran declaraciones INTRINSIC explícitas."
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
@@ -68857,7 +68926,7 @@ msgstr "NAMELIST '%s' en la declaración READ en %L contiene el símbolo '%s' el
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L es polimórfico y requiere un procedimiento de entrada/salida definido"
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -70151,12 +70220,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -70316,161 +70385,161 @@ msgstr "El operador intrínseco %qs referenciado en %L no se encontró en el mó
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): símbolo de módulo %qs incorrecto"
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Símbolo no escrito"
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file %qs for writing at %C: %s"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "No se puede abrir el fichero de módulo %qs para escritura en %C: %s"
 
 # El mensaje de error seguramente está mal redactado. cfuga
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Error al escribir al fichero de módulo %qs para escritura: %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file %qs: %s"
 msgid "Cannot delete module file %qs: %s"
 msgstr "No se puede borrar el fichero de módulo %qs: %s"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file %qs to %qs: %s"
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "No se puede renombrar el fichero de módulo %qs a %qs: %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file %qs: %s"
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "No se puede borrar el fichero de módulo temporal %qs: %s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "El símbolo %qs en %C ya se había declarado"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Imposible crear símbolo para %s"
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "El símbolo %qs referenciado en %L, no está en el estándar seleccionado"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "El símbolo %qs referenciado en %L no se encontró en el módulo intrínseco ISO_C_BINDING"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "El símbolo %qs ya se había declarado"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "El uso del módulo intrínseco %qs en %C tiene conflictos con un nombre de módulo no intrínseco usado previamente"
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "El uso de la constante nombrada NUMERIC_STORAGE_SIZE del módulo intrínseco ISO_FORTRAN_ENV en %L es incompatible con la opción %s"
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "El uso de la constante nombrada NUMERIC_STORAGE_SIZE del módulo intrínseco ISO_FORTRAN_ENV en %C es incompatible con la opción %s"
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "El símbolo '%s' referenciado en %L no se encontró en el módulo intrínseco ISO_FORTRAN_ENV"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CLOSE statement at %L requires a UNIT number"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "La declaración CLOSE en %L requiere un número UNIT"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003: Módulo intrínseco ISO_FORTRAN_ENV en %C"
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_C_BINDING module at %C"
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003: Módulo ISO_C_BINDING en %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "No se puede encontrar un módulo intrínseco llamado '%s' en %C"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "No se puede abrir el fichero de módulo '%s' para lectura en %C: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "El uso del módulo '%s' que no es intrínseco en %C tiene conflictos con el nombre del módulo intrínseco usado previamente"
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "El fichero '%s' abierto en %C no es un fichero de módulo GFORTRAN"
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -71059,8 +71128,8 @@ msgstr "Basura inesperada después de la declaración $OMP ORDERED en %C"
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula IF en %L requiere una expresión LOGICAL escalar"
@@ -73322,7 +73391,7 @@ msgstr "El intrínseco '%s' declarado como INTRINSIC en %L no está disponible e
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "El procedimiento que no es RECURSIVE '%s' en %L posiblemente se está llamando a sí mismo recursivamente. Declárelo RECURSIVE o utilice -frecursive"
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "La etiqueta %d referenciada en %L nunca se define"
@@ -73454,7 +73523,7 @@ msgstr "No se puede resolver la función específica '%s' en %L"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -73637,18 +73706,18 @@ msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 msgid "Impure function at %L might not be evaluated"
 msgstr "una función always_inline tal vez no se puede incluir en línea"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "El argumento por valor en %L no puede ser una matriz o una sección de matriz"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
@@ -73656,7 +73725,7 @@ msgstr "El argumento por valor en %L no puede ser una matriz o una sección de m
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
@@ -73664,196 +73733,196 @@ msgstr "Género no válido para %s en %L"
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Género no válido para %s en %L"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la codimensión %d"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la codimensión %d"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tranco ilegal de cero en %L"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "falta el subíndice en la referencia de la matriz"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "No se especificó el límite superior a la derecha de la sección de matriz de tamaño asumido en %L"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango de coíndice no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "El coíndice en la codimensión %d debe ser un escalar en %L"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "El índice de matriz en %L debe ser escalar"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "El índice de matriz en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Extensión: índice de matriz REAL en %L"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "El argumento dim en %L debe ser escalar"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "El argumento dim en %L debe ser de tipo entero"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "El índice de matriz en %L es una matriz de rango %d"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "El índice de inicio de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "El índice de inicio de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "El índice de final de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "El índice de final de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "El índice de final de la subcadena en %L es demasiado grande"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referencia de matriz errónea en %L"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo POINTER en %L"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo ALLOCATABLE en %L"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "No se deben especificar dos o más referencias de parte con rango que no es cero en %L"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -73863,12 +73932,12 @@ msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -73878,312 +73947,312 @@ msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' at %L with BIND(C) attribute must have an explicit interface"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "El procedimiento '%s' en %L con atributo BIND(C) debe tener una interfaz explícita"
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s', usada en una expresión de especificación, se referencía en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s' se usa en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Subobjecto polimórfico de un objeto coindizado en %L"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objeto coindizado con subcomponente alojable polimórfico en %L"
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qs es obsoleto"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Error en la especificación de tipo en %L"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "El objeto pasado en %L debe ser escalar"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a componente procedimiento-puntero en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo NOPASS en %L debe ser escalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "No se encontró un enlace específico coincidente para la llamada al GENERIC '%s' en %L"
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' en %L debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' en %L debe ser una FUNCTION"
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s en %L debe ser un escalar"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%s at %L must be integer"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s en %L debe ser INTEGER"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "La expresión de paso en el bucle DO en %L no puede ser cero"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "El bucle DO en %L se ejecutará cero veces"
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "La expresión de inicio FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "La expresión de fin FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "La expresión de tranco FORALL en %L debe ser un %s escalar"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "La expresión de tranco FORALL en %L no puede ser cero"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "El índice FORALL '%s' no puede aparecer en la especificación triplet en %L"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "El objeto de alojamiento en %L debe ser ALLOCATABLE o un POINTER"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objeto alojable coindizado en %L"
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "La expresión fuente en %L debe ser escalar o tener el mismo rango que el objeto de alojamiento en %L"
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "La expresión fuente en %L y el objeto de alojamiento en %L deben tener la misma forma"
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "El tipo de entidad en %L es de tipo incompatible con la expresión fuente en %L"
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "El objeto de alojamiento en %L y la expresión fuente en %L deben tener el mismo parámetro de tipo de género"
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "El alojamiento %s del tipo de base ABSTRACT en %L requiere una especificación de tipo o una expresión source"
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Alojar %s en %L con especificación de tipo requiere el mismo parámetro de longitud de carácter que el de la declaración"
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Especificación de matriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' no debe aparecer en la especificación de matriz en %L en la misma declaración ALLOCATE donde se aloja a sí misma"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Se esperaba '*' en la especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Especificación de comatriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat en %L no no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG en %L es inútil sin una etiqueta STAT"
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg en %L no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "El objeto de alojamiento en %L también aparece en %L"
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
@@ -74192,303 +74261,303 @@ msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "La expresión en la declaración CASE en %L debe ser de tipo %s"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "La expresión en la declaración CASE en %L debe ser de género %d"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "La expresión en la declaración CASE en %L debe ser escalar"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "La expresión de selección en una declaración GOTO computada en %L debe ser una expresión entera escalar"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "El argumento de la declaración SELECT en %L no puede ser %s"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "El argumento de la declaración SELECT en %L debe ser una expresión escalar"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "La expresión en la declaración CASE en %L no está en el rango de %s"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "El DEFAULT CASE en %L no puede tener después un segundo DEFAULT CASE en %L"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "No se permite un rango lógico en una declaración CASE en %L"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Se repite un valor lógico constante en una declaración CASE en %L"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La especificación de rango en %L nunca puede coincidir"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "El bloque SELECT CASE lógico en %L tiene más de dos cases"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "El nombre '%s' no se puede usar como un operador definido en %C"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L cannot be NULL()"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L has no type"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "El selector debe ser polimórfico en la declaración SELECT TYPE en %L"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L must not be coindexed"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "El tipo derivado '%s' en %L debe ser una extensión de '%s'"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloque CLASS IS doble en la declaración SELECT TYPE  en %L"
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexto no válido para el puntero NULL() en %%L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STOP code at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "El código STOP en %L debe ser escalar"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede ser polimórfico a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes de puntero a procedimiento"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes ALLOCATABLE a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes PRIVATE"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "El elemento de transferencia de datos en %L no puede ser una referencia completa a una matriz de tamaño asumido"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "El argumento ACQUIRED_LOCK= en %L debe ser una variable LOGICAL escalar"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "El argumento de conjunto de imagen en %L debe estar entre 1 y num_images()"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "La declaración en %L no es una declaración de objetivo de ramificación válida para la declaración de ramificación en %L"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "La ramificación en %L puede resultar en un bucle infinito"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción CRITICAL por la etiqueta en %L"
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la etiqueta en %L"
@@ -74496,203 +74565,203 @@ msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la et
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "La etiqueta en %L no está en el mismo bloque que la declaración GOTO en %L"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "La máscara WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "El objetivo de asignación WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Asignación definida por el usuario de un no-ELEMENTAL en WHERE en %L"
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Declaración sin soporte dentro de WHERE en %L"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "No se usa el FORALL con índice '%s' en el lado izquierdo de la asignación en %L y podría causar múltiples asignaciones a este objeto"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "Fortran 2008: Constructor BLOCK en %C"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Una construcción FORALL externa ya tiene un índice con este nombre %L"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "la cláusula WHERE/ELSEWHERE en %L requiere una matriz LOGICAL"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Se truncará la expresión CHARACTER en la asignación (%d/%d) en %L"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "La expresión con coíndice en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Asignación a una variable coindizada en %L en un procedimiento PURE"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "La variable no debe ser polimórfica en la asignación intrínseca en %L - revise que hay una subrutina específica coincidente para el operador '='"
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable coindizada no debe tener un componente último alojable en la asignación en %L"
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Asignación de puntero de procedimiento no válida en %L"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero."
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "La declaración ASSIGNED GOTO en %L requiere una variable INTEGER"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "La variable '%s' no se ha asignado a una etiqueta objetivo en %L"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "La declaración RETURN alternativa en %L requiere de un especificador de devolución SCALAR-INTEGER"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "La declaración de ASSIGN en %L requiere una variable INTEGER escalar por defecto"
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Género no válido para %s en %L"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "La declaración IF aritmética en %L requiere una expresión numérica"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condición de salida del bucle DO WHILE en %L debe ser una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula de máscara FORALL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Se declaró el parámetro '%s' sin uso en %L"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -74700,7 +74769,7 @@ msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -74709,66 +74778,66 @@ msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en %L"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longitud de la cadena en %L es demasiado grande"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz allocatable '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "El objeto escalar '%s' en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz de puntero '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "La matriz '%s' en %L no puede tener una forma diferida"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "El tipo '%s' de la variable CLASS '%s' en %L no es extensible"
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS '%s' en %L debe ser dummy, allocatable o pointer"
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "El tipo '%s' no se puede asociar al anfitrión en %L porque está bloqueado por un objeto incompatible del mismo nombre declarado en %L"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008: SAVE implícito para la variable de módulo '%s' en %L, se necesita por la inicialización por defecto"
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -74776,1043 +74845,1043 @@ msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "El módulo o la matriz del programa principal '%s' en %L deben tener una forma constante"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "La entidad con longitud de carácter asumida en %L debe ser un argumento de prueba o un PARAMETER"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "El allocatable '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "El external '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "El dummy '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "El intrinsic '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "El resultado de la función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "La matriz automática '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La función de declaración valuada con carácter '%s' en %L debe tener longitud constante"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' es de un tipo PRIVATE y no puede ser un argumento dummy de '%s', el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: El procedimiento '%s' en la interfaz PUBLIC '%s' en %L toma argumentos dummy de '%s' el cual es PRIVATE"
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "El objeto external '%s' en %L puede no tener un inicializador"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La función ELEMENTAL '%s' en %L debe tener un resultado escalar"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La función de declaración '%s' en %L no debe tener atributo puntero o alojable"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser matriz-valuada"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser recursiva"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "El procedimiento '%s' en %s en %L no tiene una interfaz explícita"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "El procedimiento dummy '%s' en %C no puede tener una interfaz genérica"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo SAVE en '%s' en %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo INTENT en '%s' en %L"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo RESULT en '%s' en %L"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "El atributo EXTERNAL genera un conflicto con el atributo FUNCTION en '%s' en %L"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Al resultado del puntero de procedimiento '%s' en %L le falta el atributo puntero"
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "El procedimiento FINAL '%s' en %L no debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "El procedimiento FINAL en %L debe tener exactamente un argumento"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "El argumento del procedimiento FINAL en %L debe ser de tipo '%s'"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser un POINTER"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "El argumento del procedimiento final en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser OPTIONAL"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser INTENT(OUT)"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "El procedimiento FINAL que no es escalar en %L debe tener un argumento sharp asumido"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "El procedimiento FINAL '%s' declarado en %L tiene el mismo rango (%d) que '%s'"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Sólo se declaran procedimientos FINAL de matriz para el tipo derivado '%s' definido en %L, se sugiere también uno escalar"
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' y '%s' no pueden ser FUNCTION/SUBROUTINE mezcladas para el GENERIC '%s' en %L"
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' y '%s' para el GENERIC '%s' en %L son ambiguos"
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "El enlace específico '%s' no está definido como objetivo del GENERIC '%s' en %L"
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "El GENERIC '%s' en %L debe apuntar a un enlace específico, '%s' es GENERIC también"
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "El GENERIC '%s' en %L no puede sobreescribir el enlace específico con el mismo nombre"
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "El operador enlazado a tipo en %L no puede ser NOPASS"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' debe ser un procedimiento de módulo o un procedimiento externo con una interfaz explícita en %L"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argumento dummy pasado como objeto no polimórfico de '%s' en %L"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser POINTER"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente de '%s'"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente heredado de '%s'"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "El tipo derivado '%s' declarado en %L debe ser ABSTRACT porque '%s' es DEFERRED y no se sobreescribió"
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "El componente de comatriz '%s' en %L debe sel alojable con forma diferida"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "El componente '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "El componenten '%s' en %L con componente comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "El componente '%s' en %L tiene el atributo CONTIGUOUS porque no es un puntero de matriz"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "El argumento de ICHAR en %L debe ser de longitud uno"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento de componente puntero '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento de componente puntero '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser escalar"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede tener el atributo POINTER"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "El componente '%s' de '%s' en %L tiene el mismo nombre que un procedimiento enlazado a tipo heredado"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longitud de carácter del componente '%s' necesita ser una expresión de especificación constante en %L"
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, fuzzy, gcc-internal-format
 #| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "El componente de carácter '%s' de '%s' en %L con longitud diferida debe ser POINTER o ALLOCATABLE"
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: el componente '%s' es un tipo PRIVATE y no puede ser un componente de '%s' el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "El componente polimórfico %s en %L en SEQUENCE o de tipo BIND(C) %s"
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "El componente %s del tipo SEQUENCE declarado en %L no tiene el atributo SEQUENCE"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Especificaciones de control de E/S en conflicto en %0 y %1"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, fuzzy, gcc-internal-format
 #| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Como al extender el tipo '%s' en %L tiene un componente de comatriz, el tipo padre '%s' también debe tener uno"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "El tipo derivado '%s' que no es extensible en %L no debe ser ABSTRACT"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: El nombre genérico '%s' de la función '%s' en %L tiene el mismo nombre que el tipo derivado en %L"
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: Objeto de matriz NAMELIST '%s' con forma asumida en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con forma que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con longitud de carácter que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' se declaró PRIVATE y no puede ser miembro de una lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE asociados a uso y no puede ser miembro de la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE y no puede ser un miembro de la lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo NAMELIST en '%s' en %L"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "La matriz de parámetro '%s' en %L no puede ser automática ni de forma diferida"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "El PARAMETER de tipo implícito '%s' en %L no coincide con un tipo IMPLICIT posterior"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipo derivado incompatible en PARAMETER en %L"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "El bloque COMMON '%s' en %L no puede tener el atributo EXTERNAL"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "El atributo PROTECTED genera un conflicto con el atributo EXTERNAL en %L"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo PROTECTED en %L"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Especificación errónea para la matriz de tamaño asumido en %C"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "La matriz de tamaño asumido en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "El símbolo en %L no es una variable DUMMY"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' en %L no puede tener el atributo VALUE porque no es un argumento dummy"
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable dummy de carácter '%s' en %L con atributo VALUE debe tener longitud constante"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable dummy de carácter interoperable con C '%s' en %L con atributo VALUE debe ser de longitud uno"
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "El tipo derivado '%s' en %L es de tipo '%s', el cual no se ha definido"
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "No se permite la matriz de forma asumida '%s' en %L en una expresión de inicialización"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable '%s' en %L no puede ser BIND(C) porque no es un bloque COMMON ni se declaró en el ámbito de nivel de módulo"
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: La función PUBLIC %s '%s' en %L es de tipo derivado PRIVATE '%s'"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "El argumento dummy INTENT(OUT) '%s' en %L es ASSUMED SIZE y por lo tanto no puede tener un inicializador por defecto"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "El resultado de la función '%s' en %L no puede ser una comatriz o tener un componente comatriz"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable '%s' en %L con componente de comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable '%s' en %L es una comatriz y no es ALLOCATABLE, SAVE ni un argumento dummy"
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable comatriz allocatable '%s' en %L debe tener forma diferida"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable '%s' en %L es INTENT(OUT) y por lo tanto no puede ser una comatriz allocatable o tener componentes comatriz"
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "No se guarda (SAVE) el threadprivate en %L"
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Se espera la lista de entidades nombradas %C"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "El elemento BLOCK DATA '%s' en %L debe estar en COMMON"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "La matriz DATA '%s' en %L se debe especificar en una declaración previa"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "El elemento DATA '%s' en %L no puede tener un coíndice"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "El elemento DATA '%s' en %L es un puntero y entonces debe ser una matriz completa"
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the ALLOCATABLE attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "El argumento '%s' del procedimiento elemental en %L no puede tener el atributo ALLOCATABLE"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Sección de matriz no constante en %L en la declaración DATA"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "La declaración DATA en %L tiene más variables que valores"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el inicio del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el final del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "La declaración DATA en %L tiene más valores que variables"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Se define la etiqueta %d en %L pero no se usa"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Se define la etiqueta %d en %L pero no se puede usar"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L debe tener el atributo SEQUENCE para ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L no puede tener componentes ALLOCATABLE que sean un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de tipo derivado '%s' en %L con inicializadores por defecto no puede ser un objeto EQUIVALENCE con una variable en COMMON"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L con componente(s) de puntero no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Error sintáctico en la declaración EQUIVALENCE en %L"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Todos o ninguno de los objetos en el conjunto EQUIVALENCE en %L deben tener el atributo PROTECTED"
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "El miembro de bloque común '%s' en %L no puede ser un objeto EQUIVALENCE en el procedimiento puro '%s'"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nombrada '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "La matriz '%s' en %L con límites que no son constantes no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "El componente de estructura '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La subcadena en %L tiene longitud cero"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Longitudes de carácter diferentes en la asignación de puntero en %L"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "La función PUBLIC '%s' en %L no puede ser del tipo PRIVATE '%s'"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' en %L no tiene tipo IMPLICIT"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "El procedimiento de operador de usuario '%s' en %L no puede ser de longitud de carácter asumido"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "El primer argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "El segundo argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "La interfaz de operador en %L debe tener, cuando mucho, dos argumentos"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -76748,19 +76817,19 @@ msgstr "Se sobreescriben los inicializadores desiguales en EQUIVALENCE en %L"
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, fuzzy, gcc-internal-format
 #| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "El número de elementos en el constructor de matriz en %L requiere un incremento del límite superior %d permitido.  Vea la opción -fmax-array-constructor"
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L for argument '%s'"
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Se crea una matriz temporal en %L para el argumento '%s'"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipo de expresión errónea durante la caminata (%d)"
@@ -76862,121 +76931,121 @@ msgstr "expresión de inicialización que no es constante en %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "variable intrínseca que no es un procedimiento"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return value of function %qs at %L not set"
 msgstr "No se define el valor de devolución de la función '%s' en %L"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Aún no se admite un parámetro de tipo diferido"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "ya existe la declaración del extremo trasero para la variable de módulo %s"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Se declaró la variable '%s' sin uso en %L"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "El argumento dummy '%s' en %L se declaró INTENT(OUT) pero no se estableció"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type dummy argument '%s' at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "El argumento dummy de tipo derivado '%s' en %L se declaró INTENT(OUT) pero no se estableció y no tiene un inicializador por defecto"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 #| msgid "Unused dummy argument '%s' at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "Argumento dummy sin uso '%s' en %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "Unused module variable '%s' which has been explicitly imported at %L"
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Variable de módulo '%s' sin uso la cual se importó explícitamente en %L"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused variable %qs declared at %L"
 msgstr "Se declaró la variable '%s' sin uso en %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Unused parameter %qs declared at %L"
 msgstr "Se declaró el parámetro '%s' sin uso en %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' which has been explicitly imported at %L"
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Parámetro '%s' sin uso el cual se importó explícitamente en %L"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 #| msgid "Return value '%s' of function '%s' declared at %L not set"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "No se define el valor de devolución '%s' de la función '%s' declarada en %L"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Sorry, allocatable scalar coarrays are not yet supported at %L"
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Lo siento, aún no se admiten las comatrices escalares alojables en %L"
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Sorry, allocatable scalar coarrays are not yet supported at %L"
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Lo siento, aún no se admiten las comatrices escalares alojables en %L"
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Operador intrínseco desconocido"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Lista de argumentos de función desconocida en %L"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -77148,7 +77217,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
@@ -77286,7 +77355,7 @@ msgstr "-fwpa y -fltrans son mutuamente exclusivos"
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
 #| msgid "-fwpa and -fltrans are mutually exclusive"
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-fwpa y -fltrans son mutuamente exclusivos"
 
 #: lto/lto-object.c:107
@@ -78426,7 +78495,7 @@ msgstr "No se reconoce la opción como valor de endianess: %qs"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "No se reconoce la opción para para valor inicial de coma flotante: %qs"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "No se reconoce la opción: %qs"
@@ -78444,15 +78513,15 @@ msgstr "falta el nombre de macro después de %qs"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "falta un nombre de fichero después de %qs"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "falta una ruta después de %qs"
@@ -78506,7 +78575,7 @@ msgstr "Falta el nombre de la clase"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "no se reconoce el valor de visibilidad de ivar %qs"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "no se reconoce el valor del orden de almacenamiento de escalares %qs"
@@ -78590,94 +78659,94 @@ msgstr "%qs es obsoleto"
 msgid "unknown linker output %qs"
 msgstr "salida %qs del enlazador desconocida"
 
-#: common.opt:1502
+#: common.opt:1506
 #, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "estilo de exceso de precisión %qs desconocido"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr "especificación desconocida para el conjunto de valores de FLT_EVAL_METHOD a permitir %qs"
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "estilo de contracción de coma flotante %qs desconocido"
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "nivel de reúso de la pila %qs desconocido"
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "nivel de protección del flujo de control %qs desconocido"
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "algoritmo IRA %qs desconocido"
 
-#: common.opt:1902
+#: common.opt:1906
 #, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "región IRA %qs desconocida"
 
-#: common.opt:1980
+#: common.opt:1984
 #, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "modelo de partición LTO %qs desconocido"
 
-#: common.opt:2082
+#: common.opt:2086
 #, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "faltan opciones u objetivos después de %qs"
 
-#: common.opt:2090
+#: common.opt:2094
 #, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "descarga ABI %qs desconocida"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 #| msgid "unknown profile update method %qs"
 msgid "unknown profile reproducibility method %qs"
 msgstr "método de actualización de perfil desconocido %qs"
 
-#: common.opt:2248
+#: common.opt:2252
 #, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "método de actualización de perfil desconocido %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 #| msgid "unknown Stack Reuse Level %qs"
 msgid "unknown Live-Patching Level %qs"
 msgstr "nivel de reúso de la pila %qs desconocido"
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "algoritmo %qs de reordenación de bloque básico desconocido"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "modelo TLS %qs desconocido"
 
-#: common.opt:3026
+#: common.opt:3030
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "modelo %qs de coste de vectorizador desconocido"
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "no se reconoce el valor de visibilidad %qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "prioridad %qs de inicialización de verificación de vtable desconocida."
@@ -79108,6 +79177,11 @@ msgstr "modelo TLS %qs desconocido"
 #~ msgid "%qT has a mutable member"
 #~ msgstr "%q#T tiene miembros punteros a datos"
 
+#, fuzzy
+#~| msgid "in template argument for type %qT "
+#~ msgid "cannot deduce template arguments for %qT from %<()%>"
+#~ msgstr "en el argumento de plantilla para el tipo %qT "
+
 #, fuzzy
 #~| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 #~ msgid "ASYNCHRONOUS= specifier at %L must be of default CHARACTER kind"
@@ -80785,9 +80859,6 @@ msgstr "modelo TLS %qs desconocido"
 #~ msgid "argument 1 of %s must be a constant"
 #~ msgstr "el argumento 1 de %s debe ser una constante"
 
-#~ msgid "constant argument %d for builtin %qF is out of range ("
-#~ msgstr "el argumento constante %d para la función interna %qF está fuera de rango ("
-
 #~ msgid "CPUs older than z900 are not supported for -fsplit-stack"
 #~ msgstr "Las CPUs más antiguas que z900 no se admiten con -fsplit-stack"
 
@@ -80962,11 +81033,6 @@ msgstr "modelo TLS %qs desconocido"
 #~ msgid "lambda-expression in unevaluated context"
 #~ msgstr "expresión lambda en un contexto sin evaluar"
 
-#, fuzzy
-#~| msgid "lambda-expression in unevaluated context"
-#~ msgid "lambda-expression in template-argument"
-#~ msgstr "expresión lambda en un contexto sin evaluar"
-
 #, fuzzy
 #~| msgid "%qD is not %<constexpr%>"
 #~ msgid "%<try%> in %<constexpr%> function"
diff --git a/gcc/po/fi.po b/gcc/po/fi.po
index 69b96cc95988b..41e52ce94049b 100644
--- a/gcc/po/fi.po
+++ b/gcc/po/fi.po
@@ -32,7 +32,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 11.1-b20210321\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2021-03-23 21:16+0200\n"
 "Last-Translator: Lauri Nurmi <lanurmi@iki.fi>\n"
 "Language-Team: Finnish <translation-team-fi@lists.sourceforge.net>\n"
@@ -1282,12 +1282,12 @@ msgstr "Muodostin %qs"
 msgid "this is the insn:"
 msgstr "tämä on käsky:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 #, fuzzy
 msgid "unable to generate reloads for:"
 msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
@@ -1470,17 +1470,17 @@ msgstr "tunnistamaton käsky:"
 msgid "insn does not satisfy its constraints:"
 msgstr "alustusalkio ei ole vakio"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, fuzzy, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
@@ -1519,7 +1519,7 @@ msgstr "%s%swarning: %s-otsakeversio %s eroaa kirjastoversiosta %s.\n"
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC heuristinen/heuristiikka??: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1990,86 +1990,86 @@ msgstr "pituusmääre strfmon-muotoilussa"
 msgid "<command-line>"
 msgstr "<komentorivi>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "virheellinen const_double-operandi"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "virheellinen rotate-käsky"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "virheellinen const_double-operandi"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "puuttuva operandi"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "virheellinen rotate-käsky"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "muotomerkkijonolla on epäkelpo operandinumero"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "virheellinen etuliite ”0b” liukulukuvakiolle"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 msgid "invalid address mode"
 msgstr "virheellinen %%G-tila"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "Virheellinen liukulukuoperaatio"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2085,18 +2085,18 @@ msgid "invalid %%r value"
 msgstr "virheellinen %%r-arvo"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "virheellinen %%R-arvo"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "virheellinen %%N-arvo"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "virheellinen %%P-arvo"
@@ -2126,7 +2126,7 @@ msgstr "virheellinen %%M-arvo"
 msgid "invalid %%U value"
 msgstr "virheellinen %%U-arvo"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "virheellinen %%s-arvo"
@@ -2136,7 +2136,7 @@ msgstr "virheellinen %%s-arvo"
 msgid "invalid %%C value"
 msgstr "virheellinen %%C-arvo"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "virheellinen %%E-arvo"
@@ -2149,7 +2149,7 @@ msgstr "uudelleensijoitusvirhe"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "virheellinen %%xn-koodi"
@@ -2232,35 +2232,35 @@ msgstr "virheellinen lauseke kohdemuuttujana"
 msgid "unrecognized supposed constant"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Virheellinen käsky"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, fuzzy, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2268,13 +2268,13 @@ msgstr "fr30_print_operand: tuntematon koodi"
 msgid "invalid operand for code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "kutsu  %2d ei suoritettu koskaan\n"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
@@ -2408,8 +2408,8 @@ msgstr "odottamaton siirros"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2812,7 +2812,7 @@ msgstr "Virheellinen operaatiokoodi"
 msgid "invalid %%P operand"
 msgstr "virheellinen %%P-operandi"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "virheellinen %%p-arvo"
@@ -2871,7 +2871,7 @@ msgid "post-increment address is not a register"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "virheellinen osoite"
 
@@ -2926,8 +2926,8 @@ msgstr "Nolla ei ole kelvollinen lausekenimiö kohdassa %C"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "virheellinen ”%%%c”:n käyttö"
@@ -3073,310 +3073,310 @@ msgstr "Pinotila loppui.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Älä käytä laitteistoliukulukuja"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Poista käytöstä POSIX ACLs -tuki"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 #, fuzzy
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 #, fuzzy
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 #, fuzzy
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 #, fuzzy
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "Tuota little-endian-koodia"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 #, fuzzy
 msgid "bad move"
 msgstr "Siirrä alas"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 #, fuzzy
 msgid "Bad 128-bit move"
 msgstr "Käytä 128-bittistä long double -tyyppiä"
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 msgid "invalid %%A value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "virheellinen %%D-arvo"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "virheellinen %%E-arvo"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "virheellinen %%f-arvo"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "virheellinen %%F-arvo"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "virheellinen %%G-arvo"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "virheellinen %%j-koodi"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "virheellinen %%J-koodi"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "virheellinen %%k-arvo"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "virheellinen %%K-arvo"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "virheellinen %%O-arvo"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "virheellinen %%q-arvo"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 msgid "invalid %%t value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "virheellinen %%T-arvo"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "virheellinen %%u-arvo"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "virheellinen %%v-arvo"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 msgid "invalid %%V value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "virheellinen %%x-arvo"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 msgid "invalid %%z value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "virheellinen vektoripermutaatiovakio"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 #, fuzzy
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Älä luo #line-direktiivejä"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 #, fuzzy
 msgid "Bad GPR fusion"
 msgstr "Virheelliset merkit"
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, fuzzy, c-format
 msgid "cannot decompose address"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr "tyypit eroavat etumerkillisyyden osalta"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 #, fuzzy
 msgid "binary operator does not support two vector bool operands"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 #, fuzzy
 msgid "binary operator does not support vector bool operand"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 #, fuzzy
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "kohdemuoto ei tue äärettömyyttä"
@@ -3652,8 +3652,8 @@ msgstr "({nimetön})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "”)” oli odotus"
@@ -3673,7 +3673,7 @@ msgstr "”)” oli odotus"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "”)” oli odotus"
@@ -3681,7 +3681,7 @@ msgstr "”)” oli odotus"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "”)” oli odotus"
@@ -3700,21 +3700,21 @@ msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "”)” oli odotus"
@@ -3725,13 +3725,13 @@ msgstr "”)” oli odotus"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -3740,7 +3740,7 @@ msgstr "odotettiin %<,%> tai %<;%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "”)” oli odotus"
@@ -3750,18 +3750,18 @@ msgstr "”)” oli odotus"
 msgid "expected %<.%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -3769,28 +3769,28 @@ msgstr "odotettiin %<,%> tai %<;%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(nimetön)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "”)” oli odotus"
@@ -3806,30 +3806,30 @@ msgstr "odotettiin %<,%> tai %<;%>"
 msgid "candidate:"
 msgstr "ehdokas 1:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "Ota käyttöön käyttäjän määrittelemät käskyt"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ehdokas on:"
 msgstr[1] "ehdokkaat ovat:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "ehdokas 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "ehdokas 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "hyppy nimiöön %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "hyppy case-nimiöön"
 
@@ -4065,31 +4065,31 @@ msgstr "paikallinen muuttuja %qD ei voi esiintyä tässä yhteydessä"
 msgid "local variable %qD may not appear in this context"
 msgstr "paikallinen muuttuja %qD ei voi esiintyä tässä yhteydessä"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 #, fuzzy
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 msgid "%<using enum%> of dependent type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "ehdokkaat ovat:"
 
@@ -4142,52 +4142,52 @@ msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 msgid "source type is not polymorphic"
 msgstr "lähde ei ole osoitin"
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "unaariselle miinus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "unaariselle plus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bittikomplementille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "konjugaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "unaariselle huutomerkille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 #, fuzzy
 msgid "no post-increment operator for type"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 #, fuzzy
 msgid "no post-decrement operator for type"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
@@ -4295,7 +4295,7 @@ msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 msgid "Driving:"
 msgstr "Varoitus:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4447,7 +4447,7 @@ msgstr "  eikä %<operator=(const %T&)%>"
 msgid "Bad type in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "Odottamaton END-lause kohdassa %C"
@@ -4482,11 +4482,11 @@ msgstr "lohkolaite"
 msgid "implied END DO"
 msgstr "syötteen loppu"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "sijoitus"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 #, fuzzy
 msgid "pointer assignment"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
@@ -4598,165 +4598,165 @@ msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 msgid "bind(c) procedure"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, fuzzy, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, fuzzy, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, fuzzy, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, fuzzy, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, fuzzy, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 #, fuzzy
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, fuzzy, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "tuntematon binäärioperaattori"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "tuntematon binäärioperaattori"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, fuzzy, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, fuzzy, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr "Silmukkamuuttuja"
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 #, fuzzy
 msgid "iterator variable"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "Ennenaikainen säännöllisen lausekkeen loppu"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 #, fuzzy
 msgid "STAT variable"
 msgstr "tiedoston tilan lukeminen epäonnistui"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%qD ei ole muuttuja"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 #, fuzzy
 msgid "item in READ"
 msgstr "Soita numero"
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "uutta arkistoa ei voi lukita"
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, fuzzy, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Odotettiin PARAMETER-symbolia kompleksivakiossa kohdassa %C"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, fuzzy, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, fuzzy, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, fuzzy, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "virheellinen taulukkosijoitus"
@@ -4888,26 +4888,26 @@ msgstr "Taulukkoviite rajojen ulkopuolella"
 msgid "Incorrect function return value"
 msgstr "Virheellinen funktion paluuarvo"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 msgid "Error allocating %lu bytes"
 msgstr "Muistinvaraus epäonnistui"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr ""
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, fuzzy, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "yritettiin käyttää ominaisuutta, jolle ei ole tukea: ”%s”"
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -5123,17 +5123,17 @@ msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 #, fuzzy
 msgid "may not use both -EB and -EL"
 msgstr "ei voi käyttää sekä valitsinta -m32 että -m64"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 #, fuzzy
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "valitsimia -mbig-endian ja -mlittle-endian ei voi käyttää yhdessä"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "valitsimia -mbig-endian ja -mlittle-endian ei voi käyttää yhdessä"
 
@@ -5151,8 +5151,8 @@ msgstr "linkitystä varten ei ole määritelty suoritinta"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "ei voi määritellä sekä valitsinta -C että valitsinta -o"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 #, fuzzy
 msgid "shared and mdll are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
@@ -5327,10 +5327,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Varoita laskutoimituksista funktio-osoittimilla"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Ei tee mitään. Säilytetty yhteensopivuuden vuoksi."
@@ -5805,160 +5805,160 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr ""
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr ""
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "ehdotetaan sulkeita %<+%>:n ympärille %<<<%>:n sisällä"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr "Polku otsaketiedostoon, joka esisisällytetään kunkin käännösyksikön alkuun."
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, fuzzy, no-c-format
 msgid "Enable range checking during compilation."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr "Tulkitse kaikki REAL(4):t REAL(8):na."
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr "Tulkitse kaikki REAL(4):t REAL(10):nä."
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr "Tulkitse kaikki REAL(4):t REAL(16):na."
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr "Tulkitse kaikki REAL(8):t REAL(4):nä."
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr "Tulkitse kaikki REAL(8):t REAL(10):nä."
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr "Tulkitse kaikki REAL(8):t REAL(16):na."
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr ""
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, fuzzy, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Käytä big-endian-muotoa muotoilemattomille tiedostoille"
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, fuzzy, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Käytä big-endian-muotoa muotoilemattomille tiedostoille"
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, fuzzy, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr ""
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr ""
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Ei tee mitään. Säilytetty yhteensopivuuden vuoksi."
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Noudata ISO Fortran 2003 -standardia"
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Noudata ISO Fortran 2009 -standardia"
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Noudata ISO Fortran 2009 -standardia"
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Noudata ISO Fortran 2009 -standardia"
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Noudata ISO Fortran 95 -standardia"
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr "Älä noudata mitään erityisesti."
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr ""
@@ -6637,7 +6637,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7266,8 +7266,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr "kenttä %qE esitelty funktiona"
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr "Ei enää tuettu."
@@ -7624,466 +7624,461 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, fuzzy, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "Luokittelematon lause IF-lauseessa kohdassa %C"
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "Tunnista C++:n avainsanat kuten ”compl” ja ”xor”."
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr ""
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, fuzzy, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr "Käsittele kaikki varoitukset virheinä"
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, fuzzy, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr "Käsittele syötetiedosto jo esikäännettynä."
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr "Käsittele tunnettuja sprintf-paluuarvoja vakioina."
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr ""
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "Poistettu GCC 10:ssä. Tämä valitsin ei vaikuta mihinkään."
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, fuzzy, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr "Tuota bittikäskyjä"
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "Käytä luetelluille tyypeille kapeinta mahdollista kokonaislukutyyppiä."
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "Pakota ”wchar_t”:n taustatyypiksi ”unsigned short”."
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "Kun ”signed” tai ”unsigned” on antamatta, tee bittikentästä etumerkillinen."
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr "Tee ”char”-tyypistä oletuksena etumerkillinen."
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, fuzzy, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr "Näytä kääntämisen aikana kertyneet tilastot."
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "Oleta, että luetellun tyypin arvot ovat aina kyseisen tyypin vähimmäisvälillä."
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, fuzzy, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr ""
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, fuzzy, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "Älä luo säieturvallista koodia paikallisten staattisten muuttujien alustamiseksi"
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "Kun ”signed” tai ”unsigned” on antamatta, tee bittikentästä etumerkitön."
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, fuzzy, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "Tee ”char”-tyypistä oletuksena etumerkitön"
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, fuzzy, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr "käytä aina numeroita käyttäjän/ryhmän nimissä"
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr ""
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr ""
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr ""
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr ""
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr ""
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr ""
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, fuzzy, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr "%qD:n esittely void-taulukkona"
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, fuzzy, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-isystem <hakemisto>\tLisää <hakemisto> järjestelmän include-polun alkuun"
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, fuzzy, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "  -o <tiedosto>            Ohjaa tuloste <tiedostoon>\n"
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, fuzzy, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-isysroot <hakemisto>\tAseta <hakemisto> järjestelmän juurihakemistoksi"
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr ""
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, fuzzy, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "Määrittele <polku> etuliitteeksi seuraaville kahdelle valitsimelle"
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, fuzzy, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <hakemisto>\tAseta <hakemisto> järjestelmän juurihakemistoksi"
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, fuzzy, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <hakemisto>\tLisää <hakemisto> järjestelmän include-polun alkuun"
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, fuzzy, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-isystem <hakemisto>\tLisää <hakemisto> järjestelmän include-polun alkuun"
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, fuzzy, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-isystem <hakemisto>\tLisää <hakemisto> järjestelmän include-polun alkuun"
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, fuzzy, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-isystem <hakemisto>\tLisää <hakemisto> järjestelmän include-polun alkuun"
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr ""
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr ""
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, fuzzy, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr ""
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Noudata ISO 1998 C++ -standardia GNU-laajennoksineen"
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Noudata ISO 2011 C++ -standardia."
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Noudata ISO 2014 C++ -standardia."
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "Noudata ISO 2017 C++ -standardia."
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Noudata ISO 2014 C++ -standardia (kokeellinen ja epätäydellinen tuki)"
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Noudata ISO 2020(?) C++ -standardiluonnosta (kokeellinen ja epätäydellinen tuki)."
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Noudata ISO 2011 C -standardia."
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Noudata ISO 2017 C -standardia (julkaistu 2018)."
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Noudata ISO 202X C -standardiluonnosta (kokeellinen ja epätäydellinen tuki)."
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Noudata ISO 1990 C -standardia"
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Noudata ISO 1999 C -standardia"
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Noudata ISO 1998 C++ -standardia GNU-laajennoksineen"
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Noudata ISO 1990 C -standardia GNU-laajennoksineen"
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Noudata ISO 1990 C -standardia GNU-laajennoksineen"
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "Noudata ISO 1990 C -standardia GNU-laajennoksineen"
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Noudata ISO 1998 C++ -standardia GNU-laajennoksineen ja"
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Noudata ISO 1998 C++ -standardia GNU-laajennoksineen ja"
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Noudata ISO 1990 C -standardia GNU-laajennoksineen"
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Noudata ISO 1990 C -standardia GNU-laajennoksineen"
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Noudata ISO 1998 C++ -standardia GNU-laajennoksineen ja"
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Noudata ISO 1990 C -standardia GNU-laajennoksineen"
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Noudata ISO 1999 C -standardia GNU-laajennoksineen"
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Noudata ISO 1990 C -standardia vuoden 1994 korjauksineen"
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Vanhentunut, ks. -std=c99"
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, fuzzy, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "virheellinen esikääntäjän direktiivi #%s"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, fuzzy, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "kolmoismerkki ??%c ohitettiin, ota käyttöön valitsimella -trigraphs"
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr ""
@@ -8328,6 +8323,11 @@ msgstr "Käännä koodi big-endian-tilaa varten"
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9565,143 +9565,155 @@ msgstr ""
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, fuzzy, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr "Tuota koodia big-endian-tilassa"
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, fuzzy, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr "Tuota koodia big-endian-tilassa"
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "Määrittele käytettävä ABI"
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr ""
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, fuzzy, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr "Estä kaikkien laitteistoliukulukukäskyjen käyttö"
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "Tuota little-endian-koodia"
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr ""
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, fuzzy, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, fuzzy, no-c-format
 msgid "Specify the code model."
 msgstr "Malli:"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr "Älä luo #line-direktiivejä"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, fuzzy, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, fuzzy, no-c-format
 msgid "Use the given data alignment."
 msgstr "Käytä H8/300-kohdistussääntöjä"
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, fuzzy, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, fuzzy, no-c-format
 msgid "Use given stack-protector guard."
 msgstr "Kelvolliset argumentit ovat:\n"
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, fuzzy, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Kelvolliset argumentit ovat:\n"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, fuzzy, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, fuzzy, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Kelvolliset argumentit ovat:\n"
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, fuzzy, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, fuzzy, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr "Käytössä olevan C++-ABIn versio."
@@ -9836,12 +9848,6 @@ msgstr "I/O mahdollista"
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, fuzzy, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr "Tuota koodia big-endian-tilassa"
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9862,12 +9868,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, fuzzy, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr "Tuota koodia big-endian-tilassa"
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -17112,2162 +17112,2162 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr "Käytössä olevan C++-ABIn versio."
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, no-c-format
 msgid "Align the start of functions."
 msgstr "Kohdista funktioiden alut."
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr "Tasaa kaikki nimikkeet."
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr "Kohdista silmukoiden alut."
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 msgid "Enable static analysis pass."
 msgstr "virheellinen esikääntäjän direktiivi #%s"
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy, no-c-format
 msgid "Select what to sanitize."
 msgstr "Mikä on Crowdin?"
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr "Mikä on Crowdin?"
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, fuzzy, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, fuzzy, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Käytä poikkeustenkäsittelyä"
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1095
+#: common.opt:1099
 #, fuzzy, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr "luo kutsukaavio"
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr ""
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "Tämä valitsin on vanhentunut; älä käytä."
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "Tarkista C++:n new’n paluuarvo."
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, fuzzy, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr "Sähkökatko"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 msgid "Enable code hoisting."
 msgstr "Ota käyttöön funktioprofilointi."
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, fuzzy, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "aseta vianjäljityksen tulostetiedoston nimi"
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, fuzzy, no-c-format
 msgid "Place data items into their own section."
 msgstr "ensimmäinen käyttökerta kussakin funktiossa.)"
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1236
+#: common.opt:1240
 #, fuzzy, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, fuzzy, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, fuzzy, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "     --color[=<milloin>]  väritä tuloste (auto, always tai never)\n"
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr "     --color[=<milloin>]  väritä tuloste (auto, always tai never)\n"
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr ""
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, fuzzy, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "  -o <tiedosto>            Ohjaa tuloste <tiedostoon>\n"
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, fuzzy, no-c-format
 msgid "Dump optimization passes."
 msgstr "%s: virheellinen ylikirjoituskertojen määrä"
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Ota käyttöön CFI-taulut GAS-assembler-direktiivien kautta."
 
-#: common.opt:1467
+#: common.opt:1471
 #, fuzzy, no-c-format
 msgid "Perform early inlining."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:1475
+#: common.opt:1479
 #, fuzzy, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Sähkökatko"
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr "Käytä poikkeustenkäsittelyä."
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Suorita useita pieniä, kalliita optimointeja."
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1550
 #, fuzzy, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: common.opt:1554
+#: common.opt:1558
 #, fuzzy, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 msgid "Place each function into its own section."
 msgstr "ensimmäinen käyttökerta kussakin funktiossa.)"
 
-#: common.opt:1590
+#: common.opt:1594
 #, fuzzy, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:1594
+#: common.opt:1598
 #, fuzzy, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:1598
+#: common.opt:1602
 #, fuzzy, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:1602
+#: common.opt:1606
 #, fuzzy, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:1607
+#: common.opt:1611
 #, fuzzy, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, fuzzy, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:1633
+#: common.opt:1637
 #, fuzzy, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr "luo kutsukaavio"
 
-#: common.opt:1637
+#: common.opt:1641
 #, fuzzy, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr "Merkitse kaikki silmukat rinnakkaisiksi."
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, fuzzy, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:1667
+#: common.opt:1671
 #, fuzzy, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:1671
+#: common.opt:1675
 #, fuzzy, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr "Ota käyttöön lisämääreiden tuki"
 
-#: common.opt:1675
+#: common.opt:1679
 #, fuzzy, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "muunnos merkistöstä ”%s” ei ole tuettu"
 
-#: common.opt:1683
+#: common.opt:1687
 #, fuzzy, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, fuzzy, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 msgid "Process #ident directives."
 msgstr "Älä luo #line-direktiivejä"
 
-#: common.opt:1707
+#: common.opt:1711
 #, fuzzy, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: common.opt:1711
+#: common.opt:1715
 #, fuzzy, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, fuzzy, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 msgid "Do not generate .size directives."
 msgstr "Älä luo #line-direktiivejä"
 
-#: common.opt:1747
+#: common.opt:1751
 #, fuzzy, no-c-format
 msgid "Perform indirect inlining."
 msgstr "Käytä epäsuoria kutsuja"
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, fuzzy, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: common.opt:1761
+#: common.opt:1765
 #, fuzzy, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: common.opt:1765
+#: common.opt:1769
 #, fuzzy, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, fuzzy, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: common.opt:1810
+#: common.opt:1814
 #, fuzzy, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: common.opt:1818
+#: common.opt:1822
 #, fuzzy, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr "Sähkökatko"
 
-#: common.opt:1822
+#: common.opt:1826
 #, fuzzy, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Sähkökatko"
 
-#: common.opt:1830
+#: common.opt:1834
 #, fuzzy, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Sähkökatko"
 
-#: common.opt:1834
+#: common.opt:1838
 #, fuzzy, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr "Sähkökatko"
 
-#: common.opt:1838
+#: common.opt:1842
 #, fuzzy, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr "Sähkökatko"
 
-#: common.opt:1842
+#: common.opt:1846
 #, fuzzy, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr "Sähkökatko"
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 msgid "Discover pure and const functions."
 msgstr "epäkelpo tallennusluokka funktiolle %qs"
 
-#: common.opt:1850
+#: common.opt:1854
 #, fuzzy, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:1858
+#: common.opt:1862
 #, fuzzy, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr ""
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, fuzzy, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, fuzzy, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr "Tuota bittikäskyjä"
 
-#: common.opt:1941
+#: common.opt:1945
 #, fuzzy, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "nimike yhdyslauseen lopussa"
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "nimike yhdyslauseen lopussa"
 
-#: common.opt:1949
+#: common.opt:1953
 #, fuzzy, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Tuota koodia big-endian-tilassa"
 
-#: common.opt:1953
+#: common.opt:1957
 #, fuzzy, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "Tuota koodia big-endian-tilassa"
 
-#: common.opt:1957
+#: common.opt:1961
 #, fuzzy, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr "Tuota koodia big-endian-tilassa"
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, fuzzy, no-c-format
 msgid "Enable link-time optimization."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:2016
+#: common.opt:2020
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "Tunnista sisäiset funktiot"
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:2028
+#: common.opt:2032
 #, fuzzy, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr "Muistinvarausvirhe"
 
-#: common.opt:2032
+#: common.opt:2036
 #, fuzzy, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Muistinvarausvirhe"
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:2124
+#: common.opt:2128
 #, fuzzy, no-c-format
 msgid "Perform partial inlining."
 msgstr "Onnistui osittain"
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 #, fuzzy, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: common.opt:2148
+#: common.opt:2152
 #, fuzzy, no-c-format
 msgid "Perform loop peeling."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2152
+#: common.opt:2156
 #, fuzzy, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2164
 #, fuzzy, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: common.opt:2164
+#: common.opt:2168
 #, fuzzy, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: common.opt:2168
+#: common.opt:2172
 #, fuzzy, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: common.opt:2172
+#: common.opt:2176
 #, fuzzy, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr "Anna ladattava liitännäinen."
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, fuzzy, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:2192
+#: common.opt:2196
 #, fuzzy, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Tuota bittikäskyjä"
 
-#: common.opt:2196
+#: common.opt:2200
 #, fuzzy, no-c-format
 msgid "Enable basic program profiling code."
 msgstr "Ota käyttöön funktioprofilointi"
 
-#: common.opt:2200
+#: common.opt:2204
 #, fuzzy, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr "virheellinen versionumero ”%s”"
 
-#: common.opt:2204
+#: common.opt:2208
 #, fuzzy, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr "Ota käyttöön funktioprofilointi"
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2293
+#: common.opt:2297
 #, fuzzy, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr "ehdotetaan sulkeita %<+%>:n ympärille %<<<%>:n sisällä"
 
-#: common.opt:2297
+#: common.opt:2301
 #, fuzzy, no-c-format
 msgid "Report on consistency of profile."
 msgstr "Profiilissa on päättämätön kommentti"
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr "keskeytysfunktiolla ei saa olla argumentteja"
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, fuzzy, no-c-format
 msgid "Return small aggregates in registers."
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, fuzzy, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2368
+#: common.opt:2372
 #, fuzzy, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:2372
+#: common.opt:2376
 #, fuzzy, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2401
+#: common.opt:2405
 #, fuzzy, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2417
+#: common.opt:2421
 #, fuzzy, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2421
+#: common.opt:2425
 #, fuzzy, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr "HALLINTA"
 
-#: common.opt:2425
+#: common.opt:2429
 #, fuzzy, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr "HALLINTA"
 
-#: common.opt:2429
+#: common.opt:2433
 #, fuzzy, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr "HALLINTA"
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2445
+#: common.opt:2449
 #, fuzzy, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, fuzzy, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr "HALLINTA"
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2506
+#: common.opt:2510
 #, fuzzy, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2514
+#: common.opt:2518
 #, fuzzy, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2522
+#: common.opt:2526
 #, fuzzy, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, fuzzy, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, fuzzy, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr "ylivuoto implisiittisessä vakiomuunnoksessa"
 
-#: common.opt:2571
+#: common.opt:2575
 #, fuzzy, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Tuota bittikäskyjä"
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "Tuota little-endian-koodia"
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, fuzzy, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Tuota bittikäskyjä"
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "Ota käyttöön saturation-käskyt"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr "Ota käyttöön saturation-käskyt"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Ota käyttöön saturation-käskyt"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "epäkelpo osoitintila %qs"
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2659
+#: common.opt:2663
 #, fuzzy, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Käsittele puuttuvia otsikkotiedostoja luotavina tiedostoina"
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr "Tarkasta syntaksivirheet ja lopeta."
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2675
+#: common.opt:2679
 #, fuzzy, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2710
+#: common.opt:2714
 #, fuzzy, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "Käytä ohjelmistoliukulukuja"
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2742
+#: common.opt:2746
 #, fuzzy, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2750
+#: common.opt:2754
 #, fuzzy, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2758
+#: common.opt:2762
 #, fuzzy, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2766
+#: common.opt:2770
 #, fuzzy, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2770
+#: common.opt:2774
 #, fuzzy, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr "enum-muunnos alustuksessa on virheellistä C++-kielessä"
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 msgid "Enable dominator optimizations."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:2782
+#: common.opt:2786
 #, fuzzy, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 msgid "Enable dead store elimination."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2790
+#: common.opt:2794
 #, fuzzy, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2794
+#: common.opt:2798
 #, fuzzy, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2819
+#: common.opt:2823
 #, fuzzy, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2823
+#: common.opt:2827
 #, fuzzy, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2831
+#: common.opt:2835
 #, fuzzy, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr "Tuota bittikäskyjä"
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2839
+#: common.opt:2843
 #, fuzzy, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "Käytä auto_maattisisennystä"
 
-#: common.opt:2843
+#: common.opt:2847
 #, fuzzy, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, fuzzy, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Sähkökatko"
 
-#: common.opt:2859
+#: common.opt:2863
 #, fuzzy, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2867
+#: common.opt:2871
 #, fuzzy, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, fuzzy, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr "Sähkökatko"
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2887
+#: common.opt:2891
 #, fuzzy, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2908
+#: common.opt:2912
 #, fuzzy, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2940
+#: common.opt:2944
 #, fuzzy, no-c-format
 msgid "Perform loop unswitching."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2944
+#: common.opt:2948
 #, fuzzy, no-c-format
 msgid "Perform loop splitting."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, fuzzy, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Käytä poikkeustenkäsittelyä"
 
-#: common.opt:2956
+#: common.opt:2960
 #, fuzzy, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Käytä PowerPC-64 -käskykantaa"
 
-#: common.opt:2960
+#: common.opt:2964
 #, fuzzy, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Käytä PowerPC-64 -käskykantaa"
 
-#: common.opt:2964
+#: common.opt:2968
 #, fuzzy, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Käytä PowerPC-64 -käskykantaa"
 
-#: common.opt:2976
+#: common.opt:2980
 #, fuzzy, no-c-format
 msgid "Perform variable tracking."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, fuzzy, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:3003
+#: common.opt:3007
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Ota käyttöön moniydintuki"
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:3015
+#: common.opt:3019
 #, fuzzy, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:3019
+#: common.opt:3023
 #, fuzzy, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:3050
+#: common.opt:3054
 #, fuzzy, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, fuzzy, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Ota käyttöön moniydintuki"
 
-#: common.opt:3103
+#: common.opt:3107
 #, fuzzy, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Ota käyttöön moniydintuki"
 
-#: common.opt:3107
+#: common.opt:3111
 #, fuzzy, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3115
+#: common.opt:3119
 #, fuzzy, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:3119
+#: common.opt:3123
 #, fuzzy, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:3123
+#: common.opt:3127
 #, fuzzy, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Käsittele puuttuvia otsikkotiedostoja luotavina tiedostoina"
 
-#: common.opt:3127
+#: common.opt:3131
 #, fuzzy, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Käsittele puuttuvia otsikkotiedostoja luotavina tiedostoina"
 
-#: common.opt:3131
+#: common.opt:3135
 #, fuzzy, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr ""
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Tuota vianjäljitystietoja oletusmuodossa."
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, fuzzy, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:3175
+#: common.opt:3179
 #, fuzzy, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa"
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr "indeksoitu arvo on osoitin funktioon"
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, fuzzy, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3207
+#: common.opt:3211
 #, fuzzy, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3211
+#: common.opt:3215
 #, fuzzy, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, fuzzy, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3223
+#: common.opt:3227
 #, fuzzy, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:3227
+#: common.opt:3231
 #, fuzzy, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, fuzzy, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa."
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa."
 
-#: common.opt:3262
+#: common.opt:3266
 #, fuzzy, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa"
 
-#: common.opt:3280
+#: common.opt:3284
 #, fuzzy, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3284
+#: common.opt:3288
 #, fuzzy, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "Tuota isel-käskyjä"
 
-#: common.opt:3291
+#: common.opt:3295
 #, fuzzy, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-isysroot <hakemisto>\tAseta <hakemisto> järjestelmän juurihakemistoksi"
 
-#: common.opt:3295
+#: common.opt:3299
 #, fuzzy, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-isysroot <hakemisto>\tAseta <hakemisto> järjestelmän juurihakemistoksi"
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <tiedosto>            Ohjaa tuloste <tiedostoon>\n"
 
-#: common.opt:3324
+#: common.opt:3328
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Ota käyttöön funktioprofilointi."
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3374
+#: common.opt:3378
 #, fuzzy, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Ota käyttöön yksityiskohtainen tuloste."
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Näytä kääntäjän versio."
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Vaienna varoitukset."
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Luo jaettu kirjasto."
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Älä luo dynaamisesti linkitettyä paikkariippumatonta suoritettavaa tiedostoa."
 
-#: common.opt:3476
+#: common.opt:3480
 #, fuzzy, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Luo paikkariippumaton suoritettava tiedosto"
 
-#: common.opt:3480
+#: common.opt:3484
 #, fuzzy, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Luo paikkariippumaton suoritettava tiedosto"
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19409,1105 +19409,1115 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr ""
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr ""
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr ""
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr ""
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr ""
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, fuzzy, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "Sähkökatko"
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, fuzzy, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr ""
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr ""
 
-#: params.opt:326
+#: params.opt:331
 #, fuzzy, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: params.opt:330
+#: params.opt:335
 #, fuzzy, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: params.opt:334
+#: params.opt:339
 #, fuzzy, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr "L1-välimuistirivin koko."
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr "L1-välimuistin koko."
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr "L2-välimuistin koko."
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr ""
 
-#: params.opt:362
+#: params.opt:367
 #, fuzzy, no-c-format
 msgid "The size of function body to be considered large."
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr ""
 
-#: params.opt:374
+#: params.opt:379
 #, fuzzy, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr ""
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, fuzzy, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:398
+#: params.opt:403
 #, fuzzy, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, fuzzy, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:446
+#: params.opt:451
 #, fuzzy, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:450
+#: params.opt:455
 #, fuzzy, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:454
+#: params.opt:459
 #, fuzzy, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:458
+#: params.opt:463
 #, fuzzy, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:462
+#: params.opt:467
 #, fuzzy, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:466
+#: params.opt:471
 #, fuzzy, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:470
+#: params.opt:475
 #, fuzzy, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:474
+#: params.opt:479
 #, fuzzy, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:478
+#: params.opt:483
 #, fuzzy, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:482
+#: params.opt:487
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:486
+#: params.opt:491
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:490
+#: params.opt:495
 #, fuzzy, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:494
+#: params.opt:499
 #, fuzzy, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr ""
 
-#: params.opt:502
+#: params.opt:507
 #, fuzzy, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:506
+#: params.opt:511
 #, fuzzy, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:510
+#: params.opt:515
 #, fuzzy, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:514
+#: params.opt:519
 #, fuzzy, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:522
+#: params.opt:527
 #, fuzzy, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr ""
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:538
+#: params.opt:543
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:542
+#: params.opt:547
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:546
+#: params.opt:551
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:550
+#: params.opt:555
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:554
+#: params.opt:559
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:558
+#: params.opt:563
 #, fuzzy, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:562
+#: params.opt:567
 #, fuzzy, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:566
+#: params.opt:571
 #, fuzzy, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr ""
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr ""
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr ""
 
-#: params.opt:582
+#: params.opt:587
 #, fuzzy, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:586
+#: params.opt:591
 #, fuzzy, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:590
+#: params.opt:595
 #, fuzzy, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, fuzzy, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:602
+#: params.opt:607
 #, fuzzy, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:606
+#: params.opt:611
 #, fuzzy, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:610
+#: params.opt:615
 #, fuzzy, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, fuzzy, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, fuzzy, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, fuzzy, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:630
+#: params.opt:635
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:634
+#: params.opt:639
 #, fuzzy, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, fuzzy, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:650
+#: params.opt:655
 #, fuzzy, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:654
+#: params.opt:659
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, fuzzy, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:682
+#: params.opt:687
 #, fuzzy, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:694
+#: params.opt:699
 #, fuzzy, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, fuzzy, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:714
+#: params.opt:719
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:718
+#: params.opt:723
 #, fuzzy, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:722
+#: params.opt:727
 #, fuzzy, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr ""
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, fuzzy, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:750
+#: params.opt:755
 #, fuzzy, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, fuzzy, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr ""
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, fuzzy, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr ""
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, fuzzy, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, fuzzy, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr "virheellinen versionumero ”%s”"
 
-#: params.opt:840
+#: params.opt:858
 #, fuzzy, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:844
+#: params.opt:862
 #, fuzzy, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, fuzzy, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, fuzzy, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, fuzzy, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr ""
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr ""
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr ""
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr ""
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:928
+#: params.opt:946
 #, fuzzy, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr ""
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:960
+#: params.opt:978
 #, fuzzy, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, fuzzy, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "parametrin %qs maksimiarvo on %u"
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr ""
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr ""
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, fuzzy, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:1020
+#: params.opt:1038
 #, fuzzy, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: params.opt:1024
+#: params.opt:1042
 #, fuzzy, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: params.opt:1028
+#: params.opt:1046
 #, fuzzy, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: params.opt:1032
+#: params.opt:1050
 #, fuzzy, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, fuzzy, no-c-format
 msgid "Whether to use canonical types."
 msgstr "Käytetäänkö järjestelmän fonttia"
 
-#: params.opt:1056
+#: params.opt:1074
 #, fuzzy, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: params.opt:1060
+#: params.opt:1078
 #, fuzzy, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr ""
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20538,7 +20548,7 @@ msgid "expected boolean type"
 msgstr "odotettiin totuusarvotyyppiä"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "odotettiin kokonaislukua"
@@ -20612,7 +20622,7 @@ msgstr "liian vähän argumentteja"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "liian monta argumenttia"
@@ -21017,7 +21027,7 @@ msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
@@ -21072,7 +21082,7 @@ msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -21101,20 +21111,20 @@ msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21125,8 +21135,8 @@ msgstr "%qE-attribuuttia ei huomioida"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
@@ -21136,59 +21146,59 @@ msgstr "%qD:lle ei ole edellistä esittelyä"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, fuzzy, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr ""
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qE edellyttää oletusnäkyvyyttä, mutta %qD on jo esitelty eri näkyvyydellä"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -21290,7 +21300,7 @@ msgstr "%qD esitelty ei-parametrina"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "siirros vakiomerkkijonon rajojen ulkopuolelle"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE esitelty täällä"
@@ -21315,720 +21325,720 @@ msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "%<__builtin_prefetch%>-funktion kolmas argumentti on epäkelpo; käytetään nollaa"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "%Kargumentin %i arvo %qE ylittää olion enimmäiskoon %E"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "%Kargumentin %i arvo %qE ylittää olion enimmäiskoon %E"
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "%Kargumentin %i arvo %qE ylittää olion enimmäiskoon %E"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr "%Kargumentin %i arvo %qE ylittää olion enimmäiskoon %E"
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 msgid "source object declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, fuzzy, gcc-internal-format
 msgid "source object allocated here"
 msgstr "esitelty täällä"
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "%Kargumentin %i arvo %qE ylittää olion enimmäiskoon %E"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr "%Kargumentin %i arvo %qE ylittää olion enimmäiskoon %E"
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "%Kargumentin %i arvo %qE ylittää olion enimmäiskoon %E"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr "%Kargumentin %i arvo %qE ylittää olion enimmäiskoon %E"
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 msgid "destination object declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 msgid "destination object allocated here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, fuzzy, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, fuzzy, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, fuzzy, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, fuzzy, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, fuzzy, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, fuzzy, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, fuzzy, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, fuzzy, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, fuzzy, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, fuzzy, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, fuzzy, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, fuzzy, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa %wu tavun %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, fuzzy, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa %wu tavun %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, fuzzy, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, fuzzy, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa %wu tavun %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, fuzzy, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, fuzzy, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa %wu tavun %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, fuzzy, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, fuzzy, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, fuzzy, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, fuzzy, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, fuzzy, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, fuzzy, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, fuzzy, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, fuzzy, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, fuzzy, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, fuzzy, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, fuzzy, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, fuzzy, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, fuzzy, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, fuzzy, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, fuzzy, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, fuzzy, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, fuzzy, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, fuzzy, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, fuzzy, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, fuzzy, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 msgstr[1] "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, fuzzy, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 msgstr[1] "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, fuzzy, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, fuzzy, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, fuzzy, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, fuzzy, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr "%qE tulostaa vähintään %wu tavua (oletetaan %wu) %wu tavun kokoiseen kohteeseen"
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr "%qD esiteltiin täällä"
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr "%qD esiteltiin täällä"
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "liian vähän argumentteja funktiolle %<va_start%>"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "argumentti %qd ei ole vakio"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "ei-tuettu argumentti funktiolle %<__builtin_frame_address%>"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, fuzzy, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "Tuntematon arkkitehtuuri ”%s”"
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, fuzzy, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, fuzzy, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 1 to %qs"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr "virheellinen argumentti 0 %qs:lle"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%>-fuktion toisen argumentin pitää olla 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "funktiota %<va_start%> käytetty funktiossa, jolla on kiinteä määrä argumentteja"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "väärä määrä argumentteja funktiolle %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>-funktion toinen parametri ei ole viimeinen nimetty argumentti"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "esitelty täällä"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 msgid "returned from %qD"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 msgid "returned from %qT"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 msgid "obtained here"
 msgstr "union määritelty täällä"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 msgid "assigned here"
 msgstr "union määritelty täällä"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -22791,302 +22801,302 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, fuzzy, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "polku puuttuu %qs:n jälkeen"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, fuzzy, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "virheellinen sisäinen makro ”%s”"
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "virheellinen sisäinen makro ”%s”"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "%s: kenttä ”%s” ei saa olla määritelty"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "virheellinen sisäinen makro ”%s”"
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "%<return%> arvon kanssa voidin palauttavassa funktiossa"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "Väärä taikaluku --- RESERVED_13"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, fuzzy, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "Väärä taikaluku --- RESERVED_13"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, fuzzy, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "Väärä taikaluku --- RESERVED_13"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Väärä taikaluku --- RESERVED_13"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, fuzzy, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "bittikentän %qs leveys on negatiivinen"
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, fuzzy, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Ei ole tuettu"
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, fuzzy, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "Stmt-sisäkkäistysvirhe."
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "tyhjä esittely"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "lauseella ei ole vaikutusta"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, fuzzy, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, fuzzy, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "symtab_node::verify epäonnistui"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s: osaa ”%.*s” ei tunneta"
@@ -23167,12 +23177,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "nimike %q+D määritelty mutta käyttämättä"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "sisäkkäinen funktio %q+D esitelty mutta ei koskaan määritelty"
@@ -23242,7 +23252,7 @@ msgstr "taulukon %qE koko on liian suuri"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "taulukon %qE koko on liian suuri"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, fuzzy, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "Tämä merkkijono löytyi Poeditin käännösmuistista."
@@ -23646,12 +23656,12 @@ msgstr "tunnistamaton komentorivivalitsin %<-fopt-info-%s%>"
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -23671,7 +23681,7 @@ msgstr "jaettu muistiobjekti"
 msgid "internal consistency failure"
 msgstr "Sähkökatko"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -23801,42 +23811,42 @@ msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "suuri kokonaisluku implisiittisesti katkaistu etumerkittömäksi tyypiksi"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, fuzzy, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "looginen"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, fuzzy, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "looginen"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23851,7 +23861,7 @@ msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, fuzzy, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "virheellinen ”asm”: "
@@ -24472,7 +24482,7 @@ msgstr "null-osoittimen käyttö"
 msgid "function may return address of local variable"
 msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
@@ -24842,62 +24852,62 @@ msgstr "%qE esitelty funktion palauttavana funktiona"
 msgid "%Gnull format string"
 msgstr "%s muotoilumerkkijonossa kohdassa %L"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 msgid "%Guse of %<alloca%>"
 msgstr "%<alloca%>:n käyttö"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 msgid "%Gargument to variable-length array may be too large"
 msgstr "muuttuvapituisen taulukon argumentti voi olla liian suuri"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "%<alloca%>:n argumentti voi olla liian suuri"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr "raja on %wu tavua, mutta argumentin koko voi olla jopa %s"
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 msgid "%Gargument to variable-length array is too large"
 msgstr "muuttuvapituisen taulukon argumentti on liian suuri"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "%<alloca%>:n argumentti on liian suuri"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr "raja on %wu tavua, mutta argumentti on %s"
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 #, fuzzy
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "%<alloca%>:n käyttö silmukassa"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 msgid "%Gargument to variable-length array is zero"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 msgid "%Gargument to %<alloca%> is zero"
 msgstr "%<alloca%>-funktion argumentti on nolla"
@@ -25033,7 +25043,7 @@ msgstr "%Kargumentin %i arvo %qE ylittää olion enimmäiskoon %E"
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "taulukko %qD esitelty täällä"
@@ -25063,11 +25073,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "Arvo sallitun välin ulkopuolella."
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD esitelty täällä"
@@ -25149,310 +25159,310 @@ msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 msgid "using result of function returning %<void%>"
 msgstr "%<return%> arvon kanssa voidin palauttavassa funktiossa"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 msgid "enclosing region"
 msgstr "# Ei kohde:"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "# Ei kohde:"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, fuzzy, gcc-internal-format
 msgid "enclosing task"
 msgstr "          %s"
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "          %s"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, fuzzy, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, fuzzy, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "%qs määritelty parametrille %qE"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr "# Ei kohde:"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, fuzzy, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, fuzzy, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "paikallinen muuttuja %qD ei voi esiintyä tässä yhteydessä"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "odotettiin %<operator%>"
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, fuzzy, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "%qD ei ole malli"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, fuzzy, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, fuzzy, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, fuzzy, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, fuzzy, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, fuzzy, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, fuzzy, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 " EPÄONNISTUI\n"
 "\n"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT muunnetaan tyypiksi %qT, kun se viedään %<...%>:n läpi"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(eli kannattaisi antaa %qT eikä %qT funktiolle %<va_arg%>)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jos tämä koodi saavutetaan, ohjelma keskeytyy"
@@ -25901,22 +25911,22 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr "Hahmoa %s ei voi käyttää"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, fuzzy, gcc-internal-format
 msgid "for %qD"
 msgstr "nimellä %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr ""
@@ -25936,12 +25946,12 @@ msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
 msgid "unable to find a register to spill"
 msgstr "Tiedostoa ”%s” ei löytynyt."
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, fuzzy, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "Kumoamistoimintojen enimmäismäärä"
@@ -26649,12 +26659,12 @@ msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 msgid "unrecognized argument in option %qs"
 msgstr "tuntematon komentorivivalitsin %qs"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Kelvolliset argumentit:"
@@ -26779,7 +26789,7 @@ msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -27275,22 +27285,22 @@ msgstr ""
 msgid "output operand %d must use %<&%> constraint"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr ""
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr ""
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr ""
@@ -27352,12 +27362,12 @@ msgstr "virheellinen lvalue asm-tulosteessa %d"
 msgid "impossible register constraint in %<asm%>"
 msgstr "virheellinen ”asm”: "
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: reload.c:3720
+#: reload.c:3726
 #, fuzzy, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
@@ -27387,52 +27397,52 @@ msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
 msgid "output operand is constant in %<asm%>"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: rtl.c:850
+#: rtl.c:860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: rtl.c:860
+#: rtl.c:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: rtl.c:870
+#: rtl.c:880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: rtl.c:879
+#: rtl.c:889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: rtl.c:889
+#: rtl.c:899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: rtl.c:927
+#: rtl.c:937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: rtl.c:937
+#: rtl.c:947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: rtl.c:947
+#: rtl.c:957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: rtl.c:958
+#: rtl.c:968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
@@ -27477,22 +27487,22 @@ msgstr "muotomerkkijonolla on epäkelpo operandinumero"
 msgid "invalid punctuation %qc in constraint"
 msgstr "virheellinen vektoripermutaatiovakio"
 
-#: stmt.c:430
+#: stmt.c:431
 #, fuzzy, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "cv-määreen kaksoiskappale"
 
-#: stmt.c:621
+#: stmt.c:622
 #, fuzzy, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "Sulje"
 
-#: stmt.c:650
+#: stmt.c:651
 #, fuzzy, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "odottamaton siirros"
@@ -28170,9 +28180,9 @@ msgstr "virheellinen %%r-arvo"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
@@ -28207,7 +28217,7 @@ msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 msgid "invalid clique in %qs"
 msgstr "%qD:n virheellinen käyttö"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
@@ -28422,364 +28432,364 @@ msgstr "Virheellinen liukulukuoperaatio"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, fuzzy, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "Taulukkotyyppi      : %s\n"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "Ei ole hakemisto"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "Ei välitetä lausenimiöstä tyhjässä lauseessa kohdassa %L"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "virheellinen %%r-arvo"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, fuzzy, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, fuzzy, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, fuzzy, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, fuzzy, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, fuzzy, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "enum-muunnos palautuksessa on virheellistä C++-kielessä"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "goto-kohde ei ole nimiö eikä osoitin"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "ei-kokonaislukutyyppi switch-lausekkeessa"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, fuzzy, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "Ensimmäinen/seuraava ketju rikki"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, fuzzy, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "nimike yhdyslauseen lopussa"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "nimike yhdyslauseen lopussa"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "parametrien nimet (ilman tyyppejä) funktion esittelyssä"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, fuzzy, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "muotomerkkijonolla on epäkelpo operandinumero"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "virheellinen versionumero ”%s”"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, fuzzy, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "MD5-tulos on:\n"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "puuttuva ”]”"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "Virheellinen argumentti"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple epäonnistui"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, fuzzy, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) on asetettu väärään peruslohkoon"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, fuzzy, gcc-internal-format
 msgid "PHI node with location"
 msgstr "symtab_node::verify epäonnistui"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, fuzzy, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 "Vihje: %s\n"
 "\n"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) on asetettu väärään peruslohkoon"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple epäonnistui"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "ei-paikallinen nimiö "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "nimiö "
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "vuonohjauskäsky peruslohkon sisällä"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "väärä määrä argumentteja funktiolle %<va_start%>"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "väärä määrä argumentteja funktiolle %<va_start%>"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "useita default-nimikkeitä samassa switch-lauseessa"
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "ylimääräisiä tyyppimääreitä muotoiluargumentissa (argumentti %d)"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "”I”-lippu"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>-funktio palaa"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "ei-void-tyyppisen funktion loppu saavutettu"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "attribuutilla warn_unused_result esitellyn funktion paluuarvoa ei huomioida"
@@ -29881,7 +29891,7 @@ msgstr ""
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
@@ -30042,7 +30052,7 @@ msgstr "ei voitu luoda uutta ELF-lohkoa: %s"
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "ei voitu luoda uutta ELF-lohkoa: %s"
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 msgid "unsupported record layout"
 msgstr "tuntematon värimoodi"
@@ -30646,7 +30656,7 @@ msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 msgid "type was previously declared %qE"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
@@ -30666,7 +30676,7 @@ msgstr "%qD ei ole %qD:n jäsen"
 msgid "%qE argument is not a function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
@@ -31093,12 +31103,12 @@ msgstr "lueteltu tyyppi määritelty täällä"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD:n osoite tulee aina olemaan %<true%>"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "ehdotetaan sulkeita totuusarvona käytetyn sijoituksen ympärille"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
@@ -31259,13 +31269,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "liian monta argumenttia funktiolle %qE"
@@ -32215,7 +32225,7 @@ msgstr "virheellinen loppuliite ”%.*s” liukulukuvakiolla"
 msgid "traditional C rejects string constant concatenation"
 msgstr "perinteinen C ei salli merkkijonovakioiden katenointia"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -32265,7 +32275,7 @@ msgstr "%<void%> vain parametrina ei ole oikeutettu"
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
@@ -32280,17 +32290,17 @@ msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 msgid "%qE is not initialized"
 msgstr "%qE:a ei ole alustettu"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "’(’ puuttuu predikaatin jäljestä"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "puuttuva kasvatuslauseke"
@@ -32300,7 +32310,7 @@ msgstr "puuttuva kasvatuslauseke"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "virheellinen kasvatuslauseke"
@@ -32365,7 +32375,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -32930,8 +32940,8 @@ msgstr "<paluuarvo>"
 msgid "wrong type argument to %s"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
@@ -33420,17 +33430,17 @@ msgstr "funktion %qD vähennys"
 msgid "function %qD used as %<asm%> output"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "kirjoitussuojatun sijainnin %qE sijoitus"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "kirjoitussuojatun sijainnin %qE kasvatus"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "kirjoitussuojatun sijainnin %qE vähennys"
@@ -33611,8 +33621,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
@@ -33689,159 +33699,159 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "sijoitus hylkää kohdeosoitintyypin määreitä"
 msgstr[1] "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "union määritelty täällä"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 msgstr[1] "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr "esitelty aiemmin täällä"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
 msgstr "esitelty aiemmin täällä"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
 msgstr "esitelty aiemmin täällä"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr "esitelty aiemmin täällä"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 msgstr[1] "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "%q+D:lla on edellinen esittely täällä"
 msgstr[1] "%q+D:lla on edellinen esittely täällä"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, fuzzy, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr "esitelty aiemmin täällä"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "%<%c%s%>:n aikasempi esittely"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr "edellinen esittely %q+D"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -33856,7 +33866,7 @@ msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 msgid "too many input files"
 msgstr "liikaa syötetiedostoja"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "tuntematon cc_attr-arvo"
@@ -33887,14 +33897,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "tuntematon komentorivivalitsin %qs"
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "kelvolliset argumentit ovat: %s; tarkoititko %qs?"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "kelvolliset argumentit ovat: %s"
@@ -34044,62 +34054,62 @@ msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%s %qs"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%s %qs"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "%s %qs"
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<%s%> on tuntematon"
@@ -34260,89 +34270,89 @@ msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "%s: virhe kirjoitettaessa tiedostoa ”%s”: %s\n"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, fuzzy, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, fuzzy, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "%s: virhe kirjoitettaessa tiedostoa ”%s”: %s\n"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, fuzzy, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "Rinnakkaiset työt (-j) eivät ole tuettuja tällä alustalla."
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr ""
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, fuzzy, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, fuzzy, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, fuzzy, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr "null-merkit säilytetään literaalissa"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr "null-merkit säilytetään literaalissa"
 
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr ""
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34478,366 +34488,366 @@ msgstr "%<#pragma GCC optimize%> ei ole merkkijono eikä luku"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "tuntematon #pragma GCC coprocessor %E"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%s %qs"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%s %qs"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "Älä varoita Microsoft-laajennosten käytöstä"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, fuzzy, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "Käytä 64-bittistä ABIa"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 "Käyttö: %s [MERKKIJONO]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "virheellinen %%h-arvo"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 "Käyttö: %s [MERKKIJONO]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "tuntematon valitsin -%s"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Funktio %qs"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "Kelvolliset argumentit:"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "tuntematon konetila %qs"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, fuzzy, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr "-Wformat-y2k jätetty huomiotta ilman valitsinta -Wformat"
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s ei tue %%n$-operandinumeromuotoilua"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, fuzzy, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, fuzzy, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, fuzzy, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, fuzzy, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, fuzzy, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, fuzzy, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "tuntematon värimoodi"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
@@ -34898,7 +34908,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, fuzzy, gcc-internal-format
 msgid "bad builtin fcode"
@@ -35018,18 +35028,18 @@ msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -35459,223 +35469,228 @@ msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 msgid "target CPU does not support unaligned accesses"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check on yhteensopimaton valitsimen -mno-apcs-frame kanssa"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic ja -mapcs-reent ovat yhteensopimattomat"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, fuzzy, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "C++-jäsennin ei tue -dy-valitsinta, jätetään se huomiotta"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "Muodostin %qs"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "Tiedostoa ”%s” ei löytynyt."
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS ei tue valitsinta -mcallee-super-interworking"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, fuzzy, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE-attribuutti pätee vain funktioihin, ei %s"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE-attribuutti pätee vain funktioihin, ei %s"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, fuzzy, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, fuzzy, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "epäkelpo vektorityyppi attribuutille %qs"
@@ -35683,22 +35698,22 @@ msgstr "epäkelpo vektorityyppi attribuutille %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "epäkelpo vektorityyppi attribuutille %qE"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "<tuntematon>"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -35777,17 +35792,17 @@ msgstr "%<-fpie%> ei ole tuettu"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> ei ole tuettu"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "valitsimet %s ja %s ovat toisensa poissulkevat"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
@@ -36527,134 +36542,134 @@ msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 msgid "parameter to builtin not valid: %s"
 msgstr "SISÄÄNRAKENNETTU CD %s\n"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, fuzzy, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "<%s> ja <%s> ovat virheellisiä nimiä välille"
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "<%s> ja <%s> ovat virheellisiä nimiä välille"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumentin <%s>:lle on oltava yksittäinen merkki"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 "Vihje: %s\n"
 "\n"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
@@ -36674,516 +36689,516 @@ msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr ""
 "Käyttö: %s KOMENTO [ARGUMENTTI]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "Tuntematon valitsin: %s %s %s"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, fuzzy, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "__COUNTER__ lavennettu direktiivin sisällä valitsimella -fdirectives-only"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-käskykanta poistettu käytöstä, käytetään 387-aritmetiikkaa"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-käskykanta poistettu käytöstä, käytetään SSE-aritmetiikkaa"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "”%s”-liitännäinen on yhteensopiva."
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "tuntematon valitsin -%s"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-attribuutti tarvitsee kokonaislukuvakioargumentin"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attribuutit stdcall ja fastcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
@@ -37638,7 +37653,7 @@ msgstr "%J%qD määritelty sekä tavallisesti että aliaksena"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
@@ -38691,57 +38706,57 @@ msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, fuzzy, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "Funktio %qs"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
@@ -39244,239 +39259,239 @@ msgstr "%qs käyttää rekisteriä r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma extern_prefix ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, fuzzy, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 vaatii PowerPC64-suorittimen, otetaan käyttöön"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mapcs-stack-check on yhteensopimaton valitsimen -mno-apcs-frame kanssa"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 vaatii PowerPC64-suorittimen"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "Muodostin %qs"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "Ei ole tuettu"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "valitsin -mstring ei ole tuettu little-endian-järjestelmissä"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%s %qs"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "<tuntematon>"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, fuzzy, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, fuzzy, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "<tuntematon>"
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "<tuntematon>"
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "tuntematon valitsin -%s"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Vanhentunut. Tämä valitsin ei vaikuta mihinkään"
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, fuzzy, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, fuzzy, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, fuzzy, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, fuzzy, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:20055
+#: config/rs6000/rs6000.c:20172
 #, fuzzy, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ei ole sallittu"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s on virheellinen"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -39655,7 +39670,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, fuzzy, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "virheellinen %%H-arvo"
@@ -39725,200 +39740,205 @@ msgstr "%qE on vanhentunut"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "<sisäänrakennettu>"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "<sisäänrakennettu>"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "%<__builtin_prefetch%>-funktion toinen argumentti on epäkelpo; käytetään nollaa"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, fuzzy, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, fuzzy, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-fPIC ei ole tuettu"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, fuzzy, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, fuzzy, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%q+D:n ensimmäisen argumentin pitäisi olla %<int%>"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qs:n argumentti on liian suuri (maksimi %d)"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -40260,17 +40280,22 @@ msgstr "-fexcess-precision=standard C++-kielelle"
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
+
+#: ada/gcc-interface/trans.c:1642
 #, fuzzy, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
@@ -40337,8 +40362,8 @@ msgstr "attribuutti %qs soveltuu vain taulukkotyyppeihin"
 msgid "could not read the BRIG file"
 msgstr "Tiedoston ”%s” palauttaminen epäonnistui."
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
@@ -40398,7 +40423,7 @@ msgstr "muuttuja %qD asetettu mutta käyttämätön"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "%Jtaulukon %qD tyyppi viimeistelty epäkelvosti implisiittisellä alustuksella"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "alunperin määritelty täällä"
@@ -40620,7 +40645,7 @@ msgstr "%J%qD:n esittely varjostaa edellistä paikallista"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
@@ -40630,7 +40655,7 @@ msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 msgid "declaration of %qD shadows a previous local"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "varjostunut esittely on täällä"
@@ -40640,214 +40665,214 @@ msgstr "varjostunut esittely on täällä"
 msgid "nested extern declaration of %qD"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "sisäisen funktion %qD yhteensopimaton implisiittinen esittely"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "funktion %qD yhteensopimaton implisiittinen esittely"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE esittelemättä täällä (ei funktiossa)"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE esittelemättä täällä (ei funktiossa)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, fuzzy, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Jokaisesta esittelemättömästä tunnisteesta ilmoitetaan vain"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, fuzzy, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "%qD ei ole määritelty funktion näkyvyysalueen ulkopuolella"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, fuzzy, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "hyppy ohittaa muuttujan alustuksen"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, fuzzy, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "%qE-nimiön kaksoisesittely"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "Kaksoiskappale %s-nimiöspesifikaatio kohdassa %C"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "perinteisestä C:stä puuttuu erillinen nimiavaruus nimikkeille, tunniste %qE on ristiriidassa"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "switch hyppää muuttuja-alustuksen yli"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch alkaa tästä"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, fuzzy, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "switch hyppää muuttuja-alustuksen yli"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "nimeämätön tietue/unioni ei määrittele yhtään instanssia"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "tyhjä esittely tallennusluokkamääritteellä ei esittele tunnistetta uudelleen"
 
 # XXX
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "tyhjä esittely tyyppimääreellä ei esittele tunnistetta uudelleen"
 
 # XXX
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "tyhjä esittely tyyppimääreellä ei esittele tunnistetta uudelleen"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "tarpeeton tyyppinimi tyhjässä esittelyssä"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> tiedostoalueen tyhjässä esittelyssä"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> tiedostoalueen tyhjässä esittelyssä"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "tarpeeton tallennusluokkamäärite tyhjässä esittelyssä"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "tarpeeton tyyppinimi tyhjässä esittelyssä"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "tarpeeton tyyppimääre tyhjässä esittelyssä"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "tarpeeton tyyppimääre tyhjässä esittelyssä"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "tyhjä esittely"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 ei tue parametritaulukkoesittelyissä avainsanaa %<static%> tai tyyppimääreitä"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
@@ -40855,28 +40880,28 @@ msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D on yleensä funktio"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "funktio %qD on alustettu kuten muuttuja"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parametri %qD on alustettu"
@@ -40885,268 +40910,268 @@ msgstr "parametri %qD on alustettu"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "alustamaton vakio %qD on virheellinen C++-kielessä"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD tulee alustaa jäsenten alustuslistassa"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "taulukon %q+D koko puuttuu"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "nollan tai negatiivisen kokoinen taulukko %q+D"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "muuttujan %q+D koko muistissa ei ole vakio"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "ei-staattisen paikallismuuttujan %q+D asm-määrittäjä jätetään huomiotta"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "ei voi laittaa volatile-kenttäistä objektia rekisteriin"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "alustamaton vakio %qD on virheellinen C++-kielessä"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, fuzzy, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%qE nimiavaruudessa %qE ei nimeä tyyppiä"
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C kieltää parametrien ennakkoesittelyn"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, fuzzy, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "bittikentän %qs leveys ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bittikentän %qs leveys ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "bittikentän %qs leveys on negatiivinen"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "bittikentän %qs tyyppi on GCC-laajennos"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "bittikentän %qs leveys ylittää tyyppinsä"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs on kapeampi kuin tyyppisensä arvot"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 kieltää taulukon %qE, jonka kokoa ei voida määrittää"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 kieltää taulukot, joiden kokoa ei voida määrittää"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "%qE:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "tyypin nimessä tyyppi on oletuksena %<int%>"
 
 # XXX
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "ylimääräinen %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "ylimääräinen %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "ylimääräinen %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "ylimääräinen %<const%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "%J ristiriitaiset tyyppimääreet %qD:lle"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "funktion määrittely esitelty %<register%>:ksi"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "funktion määrittely esitelty %<typedef%>:ksi"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "tallennusluokka annettu tietueen kentälle %qE"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "tallennusluokka annettu tietueen kentälle"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "tallennusluokka annettu parametrille %qE"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "tallennusluokka annettu nimettömälle parametrille"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "%<auto%> tiedostoalueen tyhjässä esittelyssä"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "%<register%> tiedostoalueen tyhjässä esittelyssä"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
@@ -41154,711 +41179,711 @@ msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "%qE:n esittely taulukollisena void-alkioita"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "tyyppinimen esittely taulukollisena void-alkioita"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "%qE:n esittely taulukollisena funktioita"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "tyyppinimen esittely taulukollisena funktioita"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "nimettömän taulukon koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "nimettömän taulukon koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C kieltää nollan kokoisen taulukon %qE"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C kieltää nollan kokoisen taulukon"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "taulukon %qE koko on negatiivinen"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "nimettömän taulukon koko on negatiivinen"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "taulukon %qE koko on liian suuri"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "nimettömän taulukon koko on liian suuri"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, fuzzy, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "tyyppinimi esitelty funktion palauttavana funktiona"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE esitelty taulukon palauttavan funktiona"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "tyyppinimi esitelty taulukon palauttavan funktiona"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, fuzzy, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "funktion määrittely oikeuttaa tyhjän paluutyypin"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tyyppimääritteet jätetään huomiotta funktion paluutyypissä"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "tyyppimuunnos määrittää funktiotyypin"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C kieltää const- ja volatile-funktiotyypit"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs määritelty nimettömälle parametrille"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs määritelty tietueen kentälle %qE"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs määritelty tietueen kentälle"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "bittikentällä %qE on atominen tyyppi"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "bittikentällä on atominen tyyppi"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "kohdistusta ei voi määritellä %q+D:lle"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "%qs määritelty nimettömälle parametrille"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "%qs määritelty tietueen kentälle %qE"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "kohdistusta ei voi määritellä %q+D:lle"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C kieltää const- ja volatile-funktiotyypit"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, fuzzy, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "muuttuja tai kenttä %qE esitelty voidiksi"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "epäkelpo tallennusluokka funktiolle %qE"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "%<static%>-määreellä esitelty muuttuja esitelty uudelleen %<extern%>-tyyppiseksi"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, fuzzy, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "funktion esittely ei ole prototyyppi"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parametrien nimet (ilman tyyppejä) funktion esittelyssä"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parametrilla %u (%q+D) on vaillinainen tyyppi"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "parametrilla %u in vaillinainen tyyppi"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parametrin %u (%q+D) tyyppi on void"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "parametrin %u tyyppi on void"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, fuzzy, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%>:in on oltava ainoa parametri"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%>:in on oltava ainoa parametri"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parametrilla %q+D on vain etukäteisesittely"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "struct määritelty täällä"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "union määritelty täällä"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> uudelleenmääritelty"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> uudelleenmääritelty"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "sisäkkäinen %<union %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "sisäkkäinen %<struct %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "esittely ei esittele mitään"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ei tue nimettömiä structeja/unioneita"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ei tue nimettömiä structeja/unioneita"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr "tyhjän structin koko on C:ssä 0, C++:ssa 1"
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "tyhjän unionin koko on C:ssä 0, C++:ssa 1"
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "unionilla ei ole nimettyjä jäseniä"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "unionilla ei ole jäseniä"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "structilla ei ole nimettyjä jäseniä"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "structilla ei ole jäseniä"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "Arvo on liian suuri annetulle tietotyypille"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "unionista ei voi tehdä läpinäkyvää"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "sisäkkäinen %<enum %E%>:n uudelleenmäärittely"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "annettu tila on liian pieni luetelluille arvoille"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "luetellun tyypin arvot ylittävät suurimman kokonaisluvun arvoalueen"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C rajoittaa luetellun tyypin arvot %<int%>-tyypin arvoalueelle"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "paluutyyppi on oletuksena %<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%qD:lle ei ole edellistä prototyyppiä"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "vanhanmallisia parametriesittelyitä prototyypitetyssä funktiomäärittelyssä"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "perinteinen C ei hyväksy ISO C -tyylisiä funktiomäärittelyitä"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "ISO C90 ei tue tyyppiä %<long long%>"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "vanhanmallinen funktiomäärittely"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parametrin nimi puuttuu parametriluettelosta"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD esitelty ei-parametrina"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "useita parametreja nimellä %qD"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD:n oletustyyppi on %<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "argumenttien määrä ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "prototyypin esittely"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "ylennetty argumentti %qD ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "ylennetty argumentti %qD ei vastaa prototyyppiä"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argumentti %qD ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumentti %qD ei sovi prototyyppiin"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametri %qD on alustettu"
@@ -41866,258 +41891,258 @@ msgstr "parametri %qD on alustettu"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-silmukan alkuesittelyt ovat sallittuja vain C99-tilassa"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "käytä valitsinta -std=c99 tai -std=gnu99 koodisi kääntämiseen"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "staattisen muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
 # XXX: alkuesittely
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, fuzzy, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> on liian pitkä GCC:lle"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE:n kaksoiskappale"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C90 ei tue tyyppiä %<long long%>"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ei ole esittelyn alussa"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "käytetty %<__thread%> ennen %<static%>:a"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "kaksinkertainen %<_Thread_local%> tai %<__thread%>"
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "käytetty sekä %<__thread%> että %<auto&>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ei tue kompleksikokonaislukutyyppejä"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "negatiivisen arvon siirto vasemmalle"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vasemmalle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "oikealle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "oikealle siirron lukumäärä >= tyypin leveys"
@@ -42137,7 +42162,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "toinen täsmäävyys on täällä"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
@@ -42147,7 +42172,7 @@ msgstr "odotettiin %<(%> tai rivin loppu"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C kieltää tyhjät käännösyksiköt"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
@@ -42183,7 +42208,7 @@ msgid "unknown type name %qE"
 msgstr "%qE ei nimeä tyyppiä"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
@@ -42203,7 +42228,7 @@ msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
@@ -42218,7 +42243,7 @@ msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 msgid "unexpected attribute"
 msgstr "Odottamattomat argumentit"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
@@ -42256,7 +42281,7 @@ msgstr "%<auto%> tiedostoalueen tyhjässä esittelyssä"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -42314,7 +42339,7 @@ msgstr "ei-vakio ehto staattiselle väitteelle"
 msgid "static assertion failed: %E"
 msgstr "staattinen väite epäonnistui: %E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "staattinen väite epäonnistui"
@@ -42359,14 +42384,14 @@ msgstr "enum-muunnos palautuksessa on virheellistä C++-kielessä"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "odotettu tunniste"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "luetellun tyypin luettelon lopussa on pilkku"
@@ -42451,7 +42476,7 @@ msgstr "useita tallennusluokkia esittelymääritteissä"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
@@ -42511,7 +42536,7 @@ msgstr "ISO C90 kieltää esittelyjen ja koodin sekoittamisen"
 msgid "expected %<}%> before %<else%>"
 msgstr "#else #else:n jälkeen"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> ilman edeltävää %<if%>:iä"
@@ -42526,7 +42551,7 @@ msgstr "Lohkonimiö ei ole sopiva IF-lauseelle kohdassa %C"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
@@ -42551,17 +42576,17 @@ msgstr "odotettiin tunnistetta tai %<*%>"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<if%>-lauseessa"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<else%>-lauseessa"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "ehdotetaan aaltosulkeita epäselvän %<else%>:n välttämiseksi"
@@ -42581,12 +42606,12 @@ msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -42601,8 +42626,8 @@ msgstr "lopetusalkio puuttuu funktiokutsusta"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "cv-määreen kaksoiskappale"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr "nähty ensimmäisen kerran tässä"
@@ -42629,12 +42654,12 @@ msgstr "ISO C kieltää ?:-lausekkeen ilman keskimmäistä termiä"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "%Jviimeksi käytetty täällä"
@@ -43027,12 +43052,12 @@ msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 msgid "no type or storage class may be specified here,"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, fuzzy, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "<tuntematon>"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "puuttuva Code-attribuutti"
@@ -43042,51 +43067,51 @@ msgstr "puuttuva Code-attribuutti"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "<tuntematon>"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "<tuntematon>"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "toistuva %<@%> Objective-C-merkkijonon edellä"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, fuzzy, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "kuori on annettava polkuineen"
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
@@ -43096,18 +43121,18 @@ msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%s: liian monta arvoa"
@@ -43127,53 +43152,53 @@ msgstr "odotettiin %<,%> tai %<;%>"
 msgid "%qD is not a variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -43195,107 +43220,107 @@ msgstr "%<num_threads%>-arvon on oltava positiivinen"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "odotettiin %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> tai %<max%>"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "%s: liian monta argumenttia\n"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, fuzzy, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "sekä %<long%> että %<void%> esittelymääritteissä"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
@@ -43305,17 +43330,17 @@ msgstr "%qE määritelty vääränlaisena tunnisteena"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -43335,22 +43360,22 @@ msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "virheellinen const_double-operandi"
@@ -43365,82 +43390,82 @@ msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "Funktio %qs"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, fuzzy, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, fuzzy, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -43455,7 +43480,7 @@ msgstr "%qE on esittelemättä"
 msgid "expected function name"
 msgstr "odotettiin luokan nimeä"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
@@ -43465,27 +43490,27 @@ msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 msgid "expected %<allocator%>"
 msgstr "odotettiin %<operator%>"
@@ -43495,82 +43520,82 @@ msgstr "odotettiin %<operator%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, fuzzy, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
@@ -43580,32 +43605,32 @@ msgstr "%<void%> vain parametrina ei ole oikeutettu"
 msgid "expected %<(%> or end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -43615,73 +43640,73 @@ msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 msgid "not enough perfectly nested loops"
 msgstr "liian vähän argumentteja"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, fuzzy, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "liian vähän argumentteja"
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
 # XXXXXXX
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -43696,57 +43721,57 @@ msgstr "%Jvanhanmallinen funktiomäärittely"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "  siirtyy catch-lohkoon"
@@ -43756,12 +43781,12 @@ msgstr "  siirtyy catch-lohkoon"
 msgid "variant %qD is not a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43771,32 +43796,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, fuzzy, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "# Ei kohde:"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
@@ -43851,42 +43876,42 @@ msgstr "odotettiin luokan nimeä"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "-pipe ei ole tuettu"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -43901,27 +43926,27 @@ msgstr "käytetään muuttuvapituista taulukkoa"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%J%qD esitelty avoimeksi kutsumisen jälkeen"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parametrilla %u in vaillinainen tyyppi"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -43931,7 +43956,7 @@ msgstr "odotettiin %<,%> tai %<;%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "Käyttö: %s <transaktiotiedosto> <tiedostojärjestelmä>\n"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -43946,7 +43971,7 @@ msgstr "          %s"
 msgid "%qD has an incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
@@ -43987,127 +44012,127 @@ msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 msgid "function types not truly compatible in ISO C"
 msgstr "funktiotyypit eivät aidosti yhteensopivia ISO C:n mukaan"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr ""
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr ""
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr ""
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "osoittimet erimääritteisiin taulukoihin ovat epäyhteensopivia ISO C:ssä"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "tyypit eivät ole ihan yhteensopivia"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, fuzzy, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "tyypit eivät ole ihan yhteensopivia"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "funktion paluuarvojen tyypit eivät ole yhteensopivia %<volatile%>:n takia"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, fuzzy, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, fuzzy, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr "pyydetty jäsentä %qE jostakin, joka ei ole tietue eikä unioni"
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, fuzzy, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "pyydetty jäsentä %qE jostakin, joka ei ole tietue eikä unioni"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, fuzzy, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "pyydetty jäsentä %qE jostakin, joka ei ole tietue eikä unioni"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, fuzzy, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, fuzzy, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "taulukon indeksi ei ole kokonaisluku"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "indeksoitu arvo on osoitin funktioon"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C kieltää %<register%>-taulukon indeksoinnin"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C kieltää %<register%>-taulukon indeksoinnin"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, fuzzy, gcc-internal-format
 msgid "enum constant defined here"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "kutsuttu objekti %qE ei ole funktio"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
@@ -44115,1602 +44140,1602 @@ msgstr "funktiokutsu epäsopivan tyypin läpi"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, fuzzy, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "keskeytysfunktiolla on oltava void-paluutyyppi"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "muodollisen parametrin %d tyyppi on vaillinainen"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan kokonaislukuna eikä liukulukuna prototyypin takia"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan kokonaislukuna eikä kompleksisena prototyypin takia"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan kompleksisena eikä liukulukuna prototyypin takia"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan liukulukuna eikä kokonaislukuna prototyypin takia"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan kompleksisena eikä kokonaislukuna prototyypin takia"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan liukulukuna eikä kompleksisena prototyypin takia"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan tyyppinä %<float%> eikä %<double%> prototyypin takia"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan liukulukuna eikä kokonaislukuna prototyypin takia"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan eri levyisenä prototyypin takia"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan etumerkittömänä prototyypin takia"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "funktion %2$qE argumentti %1$d annetaan etumerkillisenä prototyypin takia"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "liikaa argumentteja metodille %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "vertailu merkkijonoliteraalin kanssa aiheuttaa määrittelemätöntä toimintaa"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "osoittimen ja kokonaisluvun välinen vertailu"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "vähennyslaskussa käytetty %<void *%>-tyyppistä osoitinta"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "vähennyslaskussa käytetty osoitinta funktioon"
 
 # XXX
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "funktio-osoitinta käytetty laskutoimituksessa"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> totuusarvolausekkeelle"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C ei tue %<~%>-merkkiä kompleksikonjugaateissa"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to absu"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "unaariselle huutomerkille annettu väärä tyyppiargumentti"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "luetellun arvon kasvattaminen on virhe C++:ssa"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "luetellun arvon vähentäminen on virhe C++:ssa"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "odotettiin lauseketta"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "odotettiin lauseketta"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C ei tue kompleksityyppien %<++%>- ja %<--%>-operaatioita"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, fuzzy, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "odotettiin lauseketta"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "sisäkkäisessä funktiossa käytetty globaalia rekisterimuuttujaa %qD"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "halutaan globaalin rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, fuzzy, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C kieltää ehtolausekkeet, joissa on vain yksi tyhjä puoli"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, fuzzy, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C kieltää ehtolausekkeet %<void *%>-tyypin ja funktio-osoittimen välillä"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "ehtolausekkeessa on osoitin/kokonaislukutyyppiristiriita"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, fuzzy, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 #, fuzzy
 msgid "cast adds %q#v qualifier to function type"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 #, fuzzy
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "osoitinkohdetyypin määreitä häviää tyyppimuunnoksessa"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "tyyppimuunnos määrittää taulukkotyypin"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "tyyppimuunnos määrittää funktiotyypin"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C kieltää tyyppimuuntamasta ei-skalaaria samaksi tyypiksi"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C kieltää tyyppimuunnokset unionityyppeihin"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "unioniin kuulumattoman tyypin muunnos unionityypiksi"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "kohdetyypin vaatima kohdistus kasvaa tyyppimuunnoksessa"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "tyyppimuunnos %qT-tyyppisestä funktiokutsusta yhteensopimattomaan tyyppiin %qT"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "tyyppimuunnos erikokoisesta kokonaisluvusta osoittimeksi"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C kieltää funktio-osoittimen muuntamisen objektiosoitintyypiksi"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C kieltää objektiosoittimen muuntamisen funktio-osoitintyypiksi"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "muunnos funktiotyypistä %qT epäyhteensopivaan funktiotyyppiin %qT"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, fuzzy, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "virheellinen taulukkosijoitus"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "taulukko alustetaan suluilla ympäröidystä merkkijonovakiosta"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, fuzzy, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "enum-muunnos alustuksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "enum-muunnos palautuksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 #, fuzzy
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "alustus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 #, fuzzy
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "%d. argumentti funktiolle %qE hylkää kohdeosoitintyypin %qv-määritteen"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "sijoitus hylkää kohdeosoitintyypin %qv-määritteen"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "alustus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "palautus hylkää kohdeosoitintyypin %qv-määritteen"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C kieltää argumenttien muuntamisen unionityypiksi"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "implisiittinen muunnos tyypistä %qT tyyppiin %qT ei ole sallittu C++:ssa"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, fuzzy, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, fuzzy, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "alustus yhteensopimattomasta osoitintyypistä"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, fuzzy, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, fuzzy, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, fuzzy, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, fuzzy, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "alustus yhteensopimattomasta osoitintyypistä"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C kieltää funktio-osoittimen ja %<void *%>-tyypin väliset sijoitukset"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C kieltää funktio-osoittimen ja %<void *%>-tyypin väliset sijoitukset"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C kieltää funktio-osoittimen ja %<void *%>-tyypin väliset alustukset"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C kieltää funktio-osoittimen ja %<void *%>-tyypin väliset palautukset"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "sijoitus yhteensopimattomasta osoitintyypistä"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "alustus yhteensopimattomasta osoitintyypistä"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "alustus yhteensopimattomasta osoitintyypistä"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "sijoituksessa tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "alustuksessa tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "sijoitus tekee osoittimesta kokonaisluvun ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "alustus tekee osoittimesta kokonaisluvun ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "yhteensopimattomat tyypit sijoituksessa tyyppiin %qT tyypistä %qT"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "yhteensopimattomat tyypit alustettaessa tyyppiä %qT käyttäen tyyppiä %qT"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "yhteensopimattomat tyypit alustettaessa tyyppiä %qT käyttäen tyyppiä %qT"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "perinteinen C ei hyväksy automaattista koostealustusta"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen alustus"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "alustus yhteensopimattomasta osoitintyypistä"
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "sopimattomasta tyypistä koostuva taulukko alustetaan merkkijonovakiosta"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "alustusalkio ei ole vakio"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "taulukko alustetaan muuttuvasta taulukkolausekkeesta"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "alustusalkiota ei pystytä laskemaan latausajankohtana"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "epäkelpo alustin"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "alustimen lopussa on ylimääräinen lohko"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "joustavan taulukkojäsenen alustaminen sisäkkäisessä asiayhteydessä"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "tyhjä skalaarialustin"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "skalaarialustimessa ylimääräisiä alkioita"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, fuzzy, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "ylimääräisiä alkioita union-alustimessa"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "ei-vakio taulukkoindeksi alustimessa"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "taulukkoindeksi alustimessa ylittää taulukon rajat"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "tyhjä indeksiväli alustimessa"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "taulukkoindeksiväli alustimessa ylittää taulukon rajat"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, fuzzy, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "alustettu kenttä ylikirjoitettu"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "alustettu kenttä ylikirjoitettu"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "enum-muunnos alustuksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 msgid "excess elements in %<char%> array initializer"
 msgstr "ylimääräisiä alkioita merkkitaulukkoalustimessa"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "ylimääräisiä alkioita struct-alustimessa"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, fuzzy, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "Varoita mahdollisesti puuttuvista aaltosuluista alustimissa"
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen ei-staattinen alustus"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "ylimääräisiä alkioita union-alustimessa"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "perinteinen C ei hyväksy unionien alustusta"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "ylimääräisiä alkioita taulukkoalustimessa"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "ylimääräisiä alkioita skalaarialustimessa"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C90 kieltää yhdysliteraalit"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%>-esitellyllä funktiolla on %<return%>-lause"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> ilman arvoa ei-voidin palauttavassa funktiossa"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> arvon kanssa voidin palauttavassa funktiossa"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C kieltää %<return%>:in lausekkeen kanssa voidin palauttavassa funktiossa"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 msgid "function returns address of label"
 msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, fuzzy, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "yhteensopivuusvalitsin (jätetään huomiotta)"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "%<long%>-tyyppistä switch-lauseketta ei muunneta %<int%>-tyyppiin ISO C:ssä"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, fuzzy, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, fuzzy, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, fuzzy, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "lauseella ei ole vaikutusta"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, fuzzy, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "liukulukujen vertailu operaattoreilla == ja != on epävarmaa"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, fuzzy, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C kieltää %<void *%>:n ja funktio-osoittimen vertailun"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, fuzzy, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "erilaisten Objective-C-tyyppien vertailusta puuttuu tyyppimuunnos"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "osoittimen ja kokonaisluvun välinen vertailu"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "täydellisen ja vaillinaisen osoittimen vertailu"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C kieltää funktio-osoittimien suuruusvertailun"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "käytetty osoittimeksi muuntumatonta taulukkoa paikassa, jossa vaaditaan skalaari"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "käytetty tietuetyypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, fuzzy, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "odotettiin %<operator%>"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, fuzzy, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, fuzzy, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, fuzzy, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, fuzzy, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, fuzzy, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "iteraattorin askellus ei-kokonaislukutyypillä"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, fuzzy, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, fuzzy, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "tyyppimuunnos määrittää funktiotyypin"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, fuzzy, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, fuzzy, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, fuzzy, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, fuzzy, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, fuzzy, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, fuzzy, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, fuzzy, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "lähde ei ole osoitin"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, fuzzy, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, fuzzy, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "__COUNTER__ lavennettu direktiivin sisällä valitsimella -fdirectives-only"
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, fuzzy, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, fuzzy, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, fuzzy, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, fuzzy, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%>-funktion ensimmäinen argumentti ei ole tyyppiä %<va_list%>"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -45919,7 +45944,7 @@ msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -46032,687 +46057,692 @@ msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "operaatioita semop-kutsua kohden enintään = %d\n"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "Ei vastaavuutta"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "Virheellinen järjestelmäkutsu"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "moniselitteinen argumentti %s %s:lle"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "Ei vastaavuutta"
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, fuzzy, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E::%E%> ei ole luokka eikä nimiavaruus"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "<tuntematon operaattori>"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E::%E%> ei ole tyyppi"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<%s %E%> esitelty parametriluettelon sisällä"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ kieltää ?:-lausekkeen käytön ilman keskimmäistä termiä"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, fuzzy, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 #, fuzzy
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "ehtolausekkeessa etumerkkinen ja etumerkitön tyyppi"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, fuzzy, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "Funktio %qs:"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "Funktio %qs:"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, fuzzy, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%<operator new%>:n on palautettava tyyppi %qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "annettu NULL funktion %2$qD ei-osoitinargumenttina %1$P"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  esitelty täällä"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "muunnetaan %<false%> osoitintyyppiksi %2$qD:n argumentissa %1$P"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "liikaa aaltosulkeita %qT:n alustimen ympärillä"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:7532
+#: cp/call.c:7536
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
+
+#: cp/call.c:7911
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi välittää %<...%>:n kautta"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
 # XXX
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "%Hswitch-lauseesta puuttuu default-nimike"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "%J%qD esitelty turhaan uudestaan"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "liikaa argumentteja muodostimelle %q#D"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, fuzzy, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD tyhjentää ei-triviaalintyyppisen objektin %#qT%s"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, fuzzy, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; käytä kopiosijoitusta sen sijaan"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; käytä kopioalustusta sen sijaan"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD kirjoittaa ei-triviaalisti-kopioitavaan tyyppiin %#qT%s"
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, fuzzy, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT esitelty täällä"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "Kopiomuodostin %qs"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "%s: valitsin on moniselitteinen; vaihtoehdot:"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "arvon palautus muodostimesta"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "arvon palautus muodostimesta"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "arvon palautus hajottimesta"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, fuzzy, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, fuzzy, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " ehdokas 1: %q+#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " ehdokas 2: %q+#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++:n mukaan nämä ovat moniselitteisiä siitä huolimatta, että ensimmäisen huonoin muunnos on parempi kuin toisen huonoin:"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
@@ -46747,1127 +46777,1127 @@ msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, fuzzy, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, fuzzy, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, fuzzy, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "%q+D esitelty täällä"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD perii %E-ABI-tunnisteen, jota %qT käyttää (paluutyypissään)"
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "esitelty täällä"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD perii %E-ABI-tunnisteen, jota %qT käyttää (tyypissään)"
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, fuzzy, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qD perii %E-ABI-tunnisteen, jota %qT käyttää (paluutyypissään)"
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, fuzzy, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qD perii %E-ABI-tunnisteen, jota %qT käyttää (paluutyypissään)"
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, fuzzy, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%q+D esitelty täällä"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%Jnimike %qD määritelty, mutta ei käytetty"
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, fuzzy, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "Näytä _piilotetut"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "nimellä %qD"
 
 # semi-fuzzy
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "Varoita perittyjen metodien puuttuvista toteutuksista"
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bittikenttä %q#D, jolla on ei-kokonaislukutyyppi %qT"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bittikentän %q+D leveys ei ole kokonaislukuvakio"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bittikentän %q+D leveys negatiivinen"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bittikentän %q+D leveys nolla"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "bittikentän %qs leveys ylittää tyyppinsä"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D on liian pieni sisältämään %q#T:n kaikkia arvoja"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "ei argumentteja"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "ei argumentteja"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "ei argumentteja"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D ei voi olla staattinen koska se on unionin jäsen"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "kentällä %q+#D on sama nimi kuin luokalla"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  mutta ei ylikuormitusta %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eikä %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  mutta ei ylikuormitusta %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "indeksoitu arvo on osoitin funktioon"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "%qT:n hajotin on moniselitteinen"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "liikaa argumentteja metodille %qE"
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "%q+D-funktion paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T ei ole literaali, koska:"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT on sulkeumatyyppi, joka on literaali vasta C++17:stä alkaen"
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T:n hajotin on epätriviaali"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "esittely ei esittele mitään"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, fuzzy, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, fuzzy, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "tyhjästä luokasta %qT perittyjen luokkien rakenne saattaa muuttua GCC:n tulevissa versioissa"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "taulukon %qE koko on liian suuri"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T uudelleenmääritelty"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, fuzzy, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "Kieli:"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, fuzzy, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, fuzzy, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, fuzzy, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "liian vähän argumentteja"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%q+D esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, fuzzy, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, fuzzy, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "C++98:ssa %qD on alustettava muodostimessa, ei käyttäen %<{...}%>"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "epäkelpo tallennusluokka funktiolle %qs"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "epäkelpo tallennusluokka funktiolle %qs"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T ei ole luokka"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "alustamaton const %qD"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, fuzzy, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr "alunperin määritelty täällä"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "esittely ei esittele mitään"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, fuzzy, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr "valitsimia -client_name ja -dynamiclib ei voi käyttää yhdessä"
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, gcc-internal-format
 msgid "allocation performed here"
 msgstr "varaus suoritettu täällä"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, fuzzy, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr "valitsimia -client_name ja -dynamiclib ei voi käyttää yhdessä"
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, fuzzy, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "protokollalla %qE on kehäriippuvuus"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, fuzzy, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%qs ei ole tuettu tällä kohteella"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, fuzzy, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "varattu täällä"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "%s%qs%s ei ole sallittu"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "odotettiin %<template%>"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, fuzzy, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "virheellinen %%s-arvo"
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Jako nollalla kohdassa %L"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "taulukon alustus ei-vakiolla"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Odottamaton %s-lause kohdassa %C"
@@ -47877,52 +47907,52 @@ msgstr "Odottamaton %s-lause kohdassa %C"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD:n osoite tulee aina olemaan %<true%>"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, fuzzy, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD ei ole tyyppi"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qT ei ole luokkatyyppi"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "          %s"
@@ -47968,7 +47998,7 @@ msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
@@ -48353,7 +48383,7 @@ msgstr "edellisestä esittelystä %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "edellinen esittely %q+D"
@@ -48483,8 +48513,8 @@ msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 msgid "%q#D previously defined here"
 msgstr "%q+#D määritelty aiemmin täällä"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
@@ -48519,52 +48549,52 @@ msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 msgid "previous specification in %q#D here"
 msgstr "%q+D:n edellinen esittely oli täällä"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr "%q+D:n osoitealue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr "nimiavaruuden %qD esittely on ristiriidassa"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr "esitelty täällä"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "%q+D:n edellinen esittely oli täällä"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "%qD uudelleenesitellään tarpeettomasti samalla näkyvyysalueella"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "%qD:n poistettu määrittely"
@@ -48577,48 +48607,48 @@ msgstr "%qD:n poistettu määrittely"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48626,2301 +48656,2317 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "säiekohtainen esittely %q#D seuraa ei-säiekohtaista esittelyä"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "ei-säiekohtainen esittely %q#D seuraa säiekohtaista esittelyä"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, fuzzy, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "%q+D:n data-alue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "edellinen esittely"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  täältä"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, fuzzy, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  siirtyy try-lohkoon"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, fuzzy, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "lauseella ei ole vaikutusta"
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD ei ole funktiomalli"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T ei ole luokka"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nimeää %q#T:n, joka ei ole tyyppi"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T:n attribuutin on oltava %qs-avainsanan perässä"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "useita tyyppejä yhdessä esittelyssä"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ kieltää nimettömät structit"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "parametrilla %q+D on vain etukäteisesittely"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "muuttujalla %q#D on alustin, mutta vaillinainen tyyppi"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD esitelty viitteenä, mutta alustamatta"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, fuzzy, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD:n koko muistissa ei ole tunnettu"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD:n koko muistissa ei ole vakio"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  voit kiertää tämän poistamalla alustimen"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "alustamaton const %qD"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "liikaa alustimia %qT:lle"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "muuttuvakokoinen yhdysliteraali"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D on vaillinaista tyyppiä"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalaariobjekti %qD vaatii yhden alkion alustimeensa"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "C++98:ssa %qD on alustettava muodostimessa, ei käyttäen %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "taulukko %qD alustettu sulkujen sisällä olevalla merkkijonoliteraalilla %qE"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, fuzzy, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, fuzzy, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD esitelty viitteenä, mutta ei ole alustettu"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "liian vähän argumentteja muodostimelle %q#D"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-tallennusluokkamääritteen käyttö"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "%q+D:n edellinen esittely"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE-attribuutti soveltuu vain muuttujiin ja funktioihin"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktio %q#D alustetaan kuin muuttuja"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "nimike %qD esitelty muttei määritelty"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "%qD:n poistettu määrittely"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "%qD ei ole malli"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, fuzzy, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "virheellinen IACC-argumentti"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, fuzzy, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "paluutyyppi on oletuksena %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr "%qD:n esittely ei-funktiona"
+
+#: cp/decl.c:10378
 #, fuzzy, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "keskeytysfunktiolla on oltava void-paluutyyppi"
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
 # semi-fuzzy
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, fuzzy, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ kieltää jäsenen %qD alustuksen"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "taulukon %qD koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon %qD"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "taulukon koon ylivuoto"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "luodaan void-taulukko"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD:n esittely void-taulukkona"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "luodaan void-taulukko"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD:n esittely funktioiden taulukkona"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "luodaan funktioiden taulukko"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "luodaan viitteiden taulukko"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD:n esittely funktiojäsenten taulukkona"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "luodaan funktiojäsenten taulukkoa"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, fuzzy, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "nimetön muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "määrittelemättömän tyypin %<%s %s%> epäkelpo käyttö"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktion määrittely ei esittele parametrejä"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ kieltää muuttujan %qs esittelyn ilman tyyppiä"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "sekä %<signed%> että %<unsigned%> määritelty %qs:lle"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "sekä %<long%> että %<short%> määritelty %qs:lle"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, fuzzy, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "tallennusluokka annettu malliparametrille %qs"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "useita tallennusluokkia %qs:n esittelyssä"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "%<auto%> tiedostoalueen tyhjässä esittelyssä"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, fuzzy, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuuttia ei huomioida"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "tarpeettomat sulkeet %qs:n esittelyssä"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses"
 msgstr "Odotettiin oikeaa sulkumerkkiä lausekkeessa kohdassa %C"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs esitelty taulukon palauttavan funktiona"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%>-funktio palauttaa ei-void-arvon"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "muodostin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "muodostimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "muodostimia ei voi esitellä virtuaalisiksi"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hajottimilla ei voi olla parametreja"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, fuzzy, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ylimääräinen kvalifiointi %<%T::%> jäsenelle %qs"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "vain muodostimen esittely voi olla %<explicit%>"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "kentällä %q+#D on sama nimi kuin luokalla"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD ei ole funktiomalli"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kopiomuodostin %qs"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "tiedostoa %s ei voi avata"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "tallennusluokka %<auto%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "tallennusluokka %<register%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, fuzzy, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, fuzzy, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D:n esittelyllä ei ole alustimia"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "virheellinen muodostin; tarkoitit todennäköisesti %<%T (const %T&)%>"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, fuzzy, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ kieltää ?:-operaattorin ylikuormituksen"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD:n on otettava joko nolla tai yksi argumenttia"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD:n on otettava joko yksi tai kaksi argumenttia"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, fuzzy, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, fuzzy, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "<paluuarvo> "
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "<paluuarvo> "
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, fuzzy, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "<paluuarvo> "
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "lueteltu tyyppi määritelty täällä"
@@ -50932,105 +50978,105 @@ msgstr "lueteltu tyyppi määritelty täällä"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD-viittaus on moniselitteinen"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD:llä on sama nimi kuin luokalla, jossa se on esitelty"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ei ole malli"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "on ristiriidassa %q+#D:n edellisen esittelyn kanssa"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT määritelty monella suoralla kannoalla"
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT määritelty suoralla virtuaalisella kannalla"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "edellinen määrittely täällä"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
@@ -51039,77 +51085,77 @@ msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, fuzzy, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "funktion paluuarvojen tyypit eivät ole yhteensopivia %<volatile%>:n takia"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD on jo määritelty"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%q+D:n oletustyyppi on %<int%>"
@@ -51149,7 +51195,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malliesittelylle %q+D"
@@ -51159,7 +51205,7 @@ msgstr "malliesittelylle %q+D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
@@ -51485,22 +51531,22 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "poistettu funktio %q+D"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -51605,7 +51651,7 @@ msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
@@ -51615,7 +51661,7 @@ msgstr "%qD:n esittely %qT:n jäsenenä"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD ei ole %qD:n jäsen"
@@ -51801,408 +51847,408 @@ msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekke
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD tulee alustaa jäsenten alustuslistassa"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "parametri %qD on alustettu"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D alustetaan jäljempänä kuin"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD alustetaan jäljempänä kuin"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, fuzzy, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  kanta %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  tässä alustuksessa"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "useita parametreja nimellä %qD"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "kantaluokka %q#T pitäisi alustaa eksplisiittisesti kopiomuodostimessa"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, fuzzy, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, fuzzy, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, fuzzy, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ei ole luokkatyyppi"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, fuzzy, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "virheellinen osoitin bittikenttään %qD"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, fuzzy, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, fuzzy, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, fuzzy, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, fuzzy, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, fuzzy, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, fuzzy, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, fuzzy, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "kokonaislukuylivuoto lausekkeessa"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, fuzzy, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "%qD on jo määritelty"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, fuzzy, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, fuzzy, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, fuzzy, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, fuzzy, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, fuzzy, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "muotoilu %s päättyy %%:iin"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, fuzzy, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "taulukon %qE koko on negatiivinen"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, fuzzy, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, fuzzy, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "yhdysliteraalin koko on muuttuva"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "versioviitetaulukolle ei voi varata muistia"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, fuzzy, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr "%qE on vanhentunut"
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr "lisää eksplisiittinen %<this%>- tai %<*this%>-kaappaus"
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "Lambda-funktio"
@@ -52257,62 +52303,62 @@ msgstr ""
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(G++ hyväksyy koodin %<-fpermissive%>-valitsimella)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, fuzzy, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, fuzzy, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr "Tyyppi"
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, fuzzy, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "Tyyppi"
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "kolmoismerkki ??%c muunnettu merkiksi %c"
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -52493,302 +52539,302 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "%qT ei ole malli"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
 # XXX
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "malliesittelylle %q+D"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q+D:n data-alue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend-esittely %qD paikallisessa luokassa ilman edeltävää esittelyä"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D esitelty täällä"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, fuzzy, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE ei ole luokka, nimiavaruus eikä lueteltu tyyppi"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, fuzzy, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, fuzzy, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%<fast_interrupt%>-attribuuttidirektiivi jätetty huomiotta"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "ehdotettu vaihtoehto:"
 msgstr[1] "ehdotetut vaihtoehdot:"
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%qE on vanhentunut"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "määriteltiin myöhemmin tässä"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "edellinen määrittely täällä"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -52813,7 +52859,7 @@ msgstr "tunniste %qE on ristiriidassa C++:n varatun sanan kanssa"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
@@ -52838,7 +52884,7 @@ msgstr "%<::%E%> on esittelemättä"
 msgid "request for member %qE in non-class type %qT"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> on esittelemättä"
@@ -52918,7 +52964,7 @@ msgstr "muodostimen virheellinen käyttö mallina"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, fuzzy, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
@@ -53054,7 +53100,7 @@ msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
@@ -53179,7 +53225,7 @@ msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -53229,7 +53275,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "odotettiin lauseketta"
@@ -53259,7 +53305,7 @@ msgstr "%qT ei ole luokka tai nimiavaruus"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
@@ -53279,12 +53325,12 @@ msgstr "%<~%T%>:n esittely %qT:n jäsenenä"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ID"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ei ole malli"
@@ -53319,7 +53365,7 @@ msgstr "useita tallennuspaikkoja esittelymääritteissä"
 msgid "expected nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
@@ -53334,7 +53380,7 @@ msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
@@ -53349,1113 +53395,1118 @@ msgstr "ISO C++ kieltää yhdysliteraalit"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> ei ole luokan jäsen"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, fuzzy, gcc-internal-format
 msgid "non-scalar type"
 msgstr "pyydetty muuntoa ei-skalaarityypiksi"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, fuzzy, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "vanhanmallisen tyyppimuunnoksen käyttö"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "suosittellaan sulkumerkkejä %<>>%>-lausekkeen ympärille"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr "oletusargumentti määritelty lambda-parametrille"
+
+#: cp/parser.c:10819
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, fuzzy, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "versioviitetaulukolle ei voi varata muistia"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, fuzzy, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, fuzzy, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "poistettu funktio %q+D"
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, fuzzy, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "ylimääräinen %<volatile%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, fuzzy, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "nimike yhdyslauseen lopussa"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 msgid "condition declares an array"
 msgstr "taulukon palauttava funktio"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 msgid "condition declares a function"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ kieltää lasketut goto-käskyt"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 msgid "expected module-name"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr "kaksoiskappale-rajapintaesittely luokalle %qE"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 msgid "private module fragment"
 msgstr "ylimääräinen %<volatile%>"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "%s: virheellinen kenttämääritys %s"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr "attribuuttia ei huomioida"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> ei ole lohkon alussa"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "tyhjä indeksiväli alustimessa"
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, fuzzy, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "tyhjä indeksiväli alustimessa"
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> saa uuden merkityksen C++11:ssä; poista se"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD ei kelpaa lambdassa"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, fuzzy, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "%s: virheellinen kenttämääritys %s"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "ei voi laajentaa alustinta jäsenelle %<%D%>"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "leveä merkkijonovakio %<asm%>-lauseessa"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Avainsana %s on tuntematon tai sillä ei vielä ole toteutusta"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "Avainsana %s on tuntematon tai sillä ei vielä ole toteutusta"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(G++ hyväksyy koodin -fpermissive-valitsimella)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "odotettiin %<template%>"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, fuzzy, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "Odotettu nimi"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 msgid "concept defined here"
 msgstr "union määritelty täällä"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, fuzzy, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ei ole malli"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "odotettiin %<namespace%>"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, fuzzy, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "odotettiin %<namespace%>"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, fuzzy, gcc-internal-format
 msgid "namespace name required"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "siirryttiin %qD-nimiavaruuteen"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "cv-määreen kaksoiskappale"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "tyyppimääritteet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT ei ole nimiavaruus"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "poistettu funktio %q+D"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "parametrien nimet (ilman tyyppejä) funktion esittelyssä"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "parametrien nimet (ilman tyyppejä) funktion esittelyssä"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr "funktio %qD esitelty uudelleen muuttujana"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "Varoita kun kaikki muodostimet ja hajottimet ovat yksityisiä"
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "%Jsisäänrakennettu funktio %qD esitelty ei-funktiona"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ei ole tyyppi"
@@ -54464,430 +54515,430 @@ msgstr "%<%T::%E%> ei ole tyyppi"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "id="
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-määreen kaksoiskappale"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, fuzzy, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "-m64 vaatii PowerPC64-suorittimen"
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr "täsmäämättömät argumentit"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "odotettiin %<,%> tai %<...%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C90 ei tue joustavia taulukkojäseniä"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, fuzzy, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ei löydetä luokkaa %qE"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ sallii bittikenttien määritteet vain ennen %<:%>-merkkiä"
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bittikentällä %qD on ei-kokonaislukutyyppi %qT"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-tarkenne funktiomäärittelyssä"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "ylimääräinen %<;%> luokansisäisen funktiomäärittelyn perässä"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "epäkelpo osoitintila %qs"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 ei salli dynaamisia poikkeusmäärittelyitä"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynaamiset poikkeusmäärittelyt ovat vanhentuneita C++11:ssä"
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "vakio tai tunniste odotettu"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "virheellinen %<%T::%E%>:n esittely"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
@@ -54896,758 +54947,758 @@ msgstr "%J%qD:n edellinen esittely oli täällä"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "nimetyt paluuarvot eivät ole enää tuettuja"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, fuzzy, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "malliesittelylle %q+D"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "    Ei ilmaistuja epäjäseniä\n"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malliesittelylle %q+D"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "esittely ei esittele mitään"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "%<sizeof...%>-argumentti on ympäröitävä sulkeilla"
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sekä %<_Sat%> että %<char%> esittelymääritteissä"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "ylimääräinen %<const%>"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "kaksois-%qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "odotettiin %<new%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "odotettiin %<delete%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "odotettiin %<return%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "odotettiin %<extern%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "odotettiin %<static_assert%>"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "odotettiin %<decltype%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "odotettiin %<namespace%>"
 
 # XXXXXXX
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "odotettiin %<=%>, %<,%>, %<;%>, %<asm%> tai %<__attribute__%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "nimiö "
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "Taso 2 ei ole synkronoitu"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "odotettiin %<:%> tai %<...%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs määritelty parametrille %qE"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "esitelty täällä"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "C++98:ssa %<template%> (selventimenä) on sallittu vain malleissa"
 
 # XXX
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, fuzzy, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, fuzzy, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "%qE ei ole Objective-C-luokkanimi eikä -alias"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "ylimääräinen %qs Objective-C++-metodien välissä"
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "<tuntematon>"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "mahdollisia ikisilmukoita ei voi optimoida"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, fuzzy, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, fuzzy, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, fuzzy, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, fuzzy, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, fuzzy, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "_Peru"
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "Käyttö: %s <transaktiotiedosto> <tiedostojärjestelmä>\n"
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "tuntematon #pragma GCC coprocessor %E"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, fuzzy, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, fuzzy, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %d"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD ei ole funktiomalli"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD ei ole muuttujamalli"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "ensiö"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "ensiö"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, fuzzy, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, fuzzy, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, fuzzy, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, fuzzy, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD ei ole mallifunktio"
@@ -55660,159 +55711,159 @@ msgstr "%qD ei ole mallifunktio"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, fuzzy, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, fuzzy, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, fuzzy, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "ensiö"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, fuzzy, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "ensiö"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 msgstr[1] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
@@ -55821,47 +55872,47 @@ msgstr "%qD:lla ei voi olla oletusargumentteja"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "%qD-malli esitelty"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
@@ -55871,493 +55922,493 @@ msgstr "useita tallennuspaikkoja esittelymääritteissä"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD ei ole malli"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  mutta %d vaaditaan"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "%q+D esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "varjostunut esittely on täällä"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "edellinen määrittely oli täällä"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, fuzzy, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  ehdokas odottaa %d argumenttia, %d annettu"
 msgstr[1] "  ehdokas odottaa %d argumenttia, %d annettu"
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  odotettiin %qT-tyyppistä vakiota, saatiin %qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 msgid "provided for %qD"
 msgstr "nimellä %qD"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, fuzzy, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE ei ole esittelyn alussa"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
@@ -56375,212 +56426,212 @@ msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "esittelyssä %q+D"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "taulukon palauttava funktio"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion palauttava funktio"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "käytetään virheellistä kenttää %qD"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT on/käyttää anonyymiä tyyppiä"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "ohjelman alustusta yritettäessä"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 msgid "%s %#qS"
 msgstr ""
@@ -56588,82 +56639,82 @@ msgstr ""
 "%s, %s, %s, %s,\n"
 "%s, %s ja %s.\n"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "%q+D:n edellinen esittely oli täällä"
@@ -56675,153 +56726,153 @@ msgstr "%q+D:n edellinen esittely oli täällä"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Tiedostoa ”%s” on jo tarkasteltu.\n"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ei voi emuloida %qs"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qE:n muunnos tyypistä %qT tyyppiin %qT ei ole yksiselitteinen"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, fuzzy, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
@@ -56956,531 +57007,531 @@ msgstr "%q+D esitelty ystävänä"
 msgid "  since %q+#D declared in base class"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, fuzzy, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<do%>-lauseessa"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, fuzzy, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, fuzzy, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "%<for%>-silmukan alkuesittelyt ovat sallittuja vain C99-tilassa"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "täsmäämättömät argumentit"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, fuzzy, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "ei argumentteja"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, fuzzy, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE ei ole tyyppiä %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "ei-objektityyppinen yhdysliteraali %qT"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, fuzzy, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "malliesittelylle %q+D"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "        %qD"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, fuzzy, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "poistettu funktio %q+D"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, fuzzy, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "poistettu funktio %q+D"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "poistettu funktio %q+D"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "täsmäämättömät argumentit"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE ei ole tyyppi"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "tarpeeton tyyppimääre tyhjässä esittelyssä"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, fuzzy, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "ISO C kieltää nollan kokoisen taulukon %qE"
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, fuzzy, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, fuzzy, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "%qE ei ole malli"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, fuzzy, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "%qE ei ole malli"
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%s:n arvon on oltava kokonaisluku"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, fuzzy, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr "vertailu ”etumerkitön lauseke < 0” on aina epätosi"
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "ei-vakio ehto staattiselle väitteelle"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "ei-tuettu argumentti funktiolle %<__builtin_return_address%>"
@@ -57488,22 +57539,22 @@ msgstr "ei-tuettu argumentti funktiolle %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -57513,1072 +57564,1072 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, gcc-internal-format
 msgid " declared here"
 msgstr " esitelty täällä"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, fuzzy, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "        %qD"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD ei ole tyyppi"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "Rinnakkaiset työt (-j) eivät ole tuettuja tällä alustalla."
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "universaali merkki %.*s ei ole kelvollinen tunniste"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "universaali merkki %.*s ei ole kelvollinen tunniste"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "nolla nollaosoitinvakiona"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä muunnoksesta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ kieltää vertailun %<void *%>-osoittimen ja funktio-osoittimen välillä"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ kieltää muunnoksen %<void *%>-osoittimen ja funktio-osoittimen välillä"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ kieltää ehtolausekkeen %<void *%>-osoittimen ja funktio-osoittimen välillä"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä muunnoksesta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen bittikenttään"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen funktiotyyppiin"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "%<__alignof%>-avainsanaa sovellettu bittikenttään"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen funktiotyyppiin"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "nimikkeen osoitteen ottaminen ei ole standardia"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ kieltää merkkijonovakion muuntamisen %qT:ksi"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "vanhentunut tyyppimuunnos merkkijonovakiosta tyyppiin %qT"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
 # semi-fuzzy
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, fuzzy, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> ei ole luokan jäsen"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, fuzzy, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "taulukon indeksi on taulukkorajojen yläpuolella"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "ISO C kieltää %<register%>-taulukon indeksoinnin"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ kieltää %<::main%>-funktion kutsumisen ohjelmasta"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "funktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "liikaa argumentteja muodostimelle %q#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "liian vähän argumentteja muodostimelle %q#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "liikaa argumentteja jäsenfunktiolle %q#D"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "liian vähän argumentteja jäsenfunktiolle %q#D"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "liikaa argumentteja funktiolle %q#D"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "liian vähän argumentteja funktiolle %q#D"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "liikaa argumentteja metodille %q#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "liian vähän argumentteja funktiolle %q#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "liikaa argumentteja funktiolle"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "liian vähän argumentteja funktiolle"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "kääntäjä voi olettaa, että %qD:n osoite ei koskaan ole NULL"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä muunnoksesta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, fuzzy, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL-arvon käyttö laskutoimituksessa"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ kieltää osoittimen ja kokonaisluvun vertailun"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "ei-liukulukuargumentti kutsussa funktiolle %qE"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ kieltää %<void *%>-tyyppisen osoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ kieltää funktio-osoittimen käytön vähennyslaskussa"
 
 # semi-fuzzy; onko metodi tässä luokan jäsenfunktio ja yllä muu funktio?
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, fuzzy, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "muodostimen %qE osoitteen ottaminen"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, fuzzy, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "id="
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "väliaikaismuuttujan osoitteen ottaminen"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ kieltää %<::main%>-funktion osoitteen ottamisen"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "yritys ottaa bittikentän osoite"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "odotettiin lauseketta"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, fuzzy, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ kieltää enumin vähentämisen"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen kasvattamisen"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen vähentämisen"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "ei voi ottaa %<this%>:in osoitetta, joka on rvalue-lauseke"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, fuzzy, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "halutaan globaalin rekisterimuuttujan %qD osoite"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "esittely ei esittele mitään"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, fuzzy, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "tyyppimuunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "tarpeeton tyyppimuunnos tyyppiin %qT"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7956
+#: cp/typeck.c:7963
 #, fuzzy, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 msgid "cast from %qH to %qI loses precision"
 msgstr "muunnoksessa tyypistä %qT tyyppiin %qT menetetään tarkkuutta"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 #, fuzzy
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "muunnos epäyhteensopivien jäsenosoitintyyppien %qH ja %qI välillä"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "muunnos tyypistä %qT tyyppiin %qT kasvattaa kohdetyypin vaadittua kohdistusta"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "tyyppimuunnos funktio-osoittimen ja olio-osoittimen välillä on ehdollisesti tuettu"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "virheellinen const_cast tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "virheellinen const_cast tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ kieltää tyyppimuunnoksen taulukkotyyppiin %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, fuzzy, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "ei-vakio taulukon indeksi alustimessa"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "taulukkoa käytetty alustimena"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "virheellinen taulukkosijoitus"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, fuzzy, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, fuzzy, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, fuzzy, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "palautettu osoite paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "poista %<std::move%>-kutsu"
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "%s: liian monta arvoa"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "arvon palautus hajottimesta"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "arvon palautus muodostimesta"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "taulukon palauttava funktio"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, fuzzy, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> ei saa palauttaa NULLia ellei esittely ole %<throw()%> (tai -fcheck-new ole voimassa)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "virheellinen %%s-arvo"
@@ -58844,107 +58895,102 @@ msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "alustettavassa unionissa ei ole kenttää %qD"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, fuzzy, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "ylimääräisiä alkioita union-alustimessa"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, fuzzy, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "PRINT_OPERAND null-osoitin"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, fuzzy, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "sijoitus yhteensopimattomasta osoitintyypistä"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "tyyppimuunnos määrittää taulukkotyypin"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
@@ -58964,268 +59010,274 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, fuzzy, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "#pragma GCC option ei ole sallittu funktioiden sisällä"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 msgid "cannot be declared to be a function"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "%<struct %E%> uudelleenmääritelty"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot be %s"
 msgstr "tiedostoa %s ei voi avata"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
 msgstr "tiedostoa %s ei voi avata"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, fuzzy, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr "tiedostoa %s ei voi avata"
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, fuzzy, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr "lauseella ei ole vaikutusta"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "#pragma GCC option ei ole sallittu funktioiden sisällä"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr "Odotettiin muuttujanimeä kohdassa %C"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 msgid "string expected for library name"
 msgstr "odotettiin luokan nimeä"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, fuzzy, gcc-internal-format
 msgid "function name expected for start address"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr "odotettiin luokan nimeä"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 #, fuzzy
 msgid "char 0x%02x not allowed in mangled name"
 msgstr "muunnoksessa tyypistä %qT tyyppiin %qT menetetään tarkkuutta"
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 #, fuzzy
 msgid "char 0x%04x not allowed in mangled name"
 msgstr "muunnoksessa tyypistä %qT tyyppiin %qT menetetään tarkkuutta"
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "ei argumentteja"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 msgid "can only apply to a single declaration"
 msgstr "malliesittelylle %q+D"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, fuzzy, gcc-internal-format
 msgid "base type must not be void"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 msgid "circular reference to enum member"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 msgid "recursive mixin instantiation"
 msgstr "    Rekursiiviset jäsenet:\n"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 msgid "recursive expansion"
 msgstr "    Rekursiiviset jäsenet:\n"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 msgid "error instantiating"
 msgstr "virhe kirjoitettaessa i-solmua"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "without `this` cannot be %s"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 msgid "functions cannot be scope"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
@@ -59233,42 +59285,52 @@ msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä."
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 msgid "cannot be both final and abstract"
 msgstr "%J%qD määritelty sekä tavallisesti että aliaksena"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -59276,172 +59338,172 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr "%q+D on yleensä funktio"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr "%q+D:n määritteet %qs ja %qs ovat yhteensopimattomat"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 msgid "does not override any function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "%q+D on yleensä funktio"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä."
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr "argumentin <%s>:lle on oltava yksittäinen merkki"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 msgid "structs, unions cannot be abstract"
 msgstr "unionista ei voi tehdä läpinäkyvää"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr "Tietueen koon on oltava %d:n monikerta."
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 msgid "circular inheritance"
 msgstr "Varoita suorasta virtuaalisesta perinnästä."
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "inherits from duplicate interface %s"
 msgstr "jätetään hakemiston ”%s” kaksoiskappale huomiotta,\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot inherit from final class %s"
 msgstr "määrittelemättömän tyypin %<%s %E%> epäkelpo käyttö"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, fuzzy, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve"
 msgstr "tietokantaa %s ei voi lukea"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
@@ -59456,22 +59518,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr "tiedoston %s avaaminen epäonnistui"
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 msgid "has forward references"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
@@ -59531,22 +59593,22 @@ msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
+#: d/dmd/semantic3.c:864
 #, fuzzy, gcc-internal-format
-msgid "no return exp; or assert(0); at end of function"
+msgid "no `return exp;` or `assert(0);` at end of function"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
@@ -60084,7 +60146,7 @@ msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava vakio"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "epäkelpo osoitintila %qs"
@@ -61178,12 +61240,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "alustusmerkkijono typistetty, jotta se täsmäisi muuttujaan kohdassa %L"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
@@ -61363,7 +61425,7 @@ msgstr "Kaksoiskappale %s-spesifikaatio kohdassa %C"
 msgid "deferred type parameter at %C"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "odotettiin kokonaislukulauseketta"
@@ -63846,7 +63908,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63927,7 +63989,7 @@ msgstr "ylivuoto vakiolausekkeessa"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -64062,12 +64124,12 @@ msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
@@ -64177,542 +64239,542 @@ msgstr "ehtolausekkeessa on tyyppiristiriita"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L on jo liitetty toiseen varsinaiseen argumenttiin"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Odotettiin proseduuriosoitinta argumentille ”%s” kohdassa %L"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Varsinainen argumentti kohteelle ”%s” ei voi olla oletetunkokoinen taulukko kohdassa %L"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, fuzzy, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "  eikä %<operator=(const %T&)%>"
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "ei voi emuloida %qs"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, fuzzy, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "ei voi kirjoittaa tiedostoon %s: %m"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei saa olla OPTIONAL"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
@@ -64857,33 +64919,33 @@ msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Laajennus: Muunnos tyypistä %s tyypiksi %s kohdassa %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
@@ -64891,22 +64953,22 @@ msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -65442,7 +65504,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -66614,12 +66676,12 @@ msgstr "  eikä %<operator=(const %T&)%>"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, fuzzy, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, fuzzy, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "vektoriylivuoto lausekkeessa"
@@ -66774,147 +66836,147 @@ msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuud
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "Ei voi avata moduulitiedostoa ”%s” kirjoittamista varten kohdassa %C: %s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Virhe kirjoitettaessa moduulitiedostoa %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "Ei voida poistaa moduulitiedostoa ”%s”: %s"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Ei voida nimetä uudelleen moduulitiedostoa ”%s” nimellä ”%s”: %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "Ei voida poistaa tilapäistä moduulitiedostoa ”%s”: %s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "tyhjä esittely"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "odotettiin ”::” moduuliluonteen jälkeen paikassa %C, mutta ei löytynyt"
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "odotettiin ”::” moduuliluonteen jälkeen paikassa %C, mutta ei löytynyt"
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "odotettiin ”::” moduuliluonteen jälkeen paikassa %C, mutta ei löytynyt"
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Ei voi avata moduulitiedostoa ”%s” lukemista varten kohdassa %C: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -67450,8 +67512,8 @@ msgstr "tyhjä esittely"
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "decltypen argumentin on oltava lauseke"
@@ -69474,7 +69536,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
@@ -69589,7 +69651,7 @@ msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
@@ -69745,212 +69807,212 @@ msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 msgid "Impure function at %L might not be evaluated"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "%s: paniikki: Virheellinen ”l_value” %d\n"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "%s: paniikki: Virheellinen ”l_value” %d\n"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, fuzzy, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, fuzzy, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Arvo sallitun välin ulkopuolella."
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -69959,12 +70021,12 @@ msgstr "muuttuvakokoista objektia ei voi alustaa"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -69973,293 +70035,293 @@ msgstr "muuttuvakokoista objektia ei voi alustaa"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "<tyyppivirhe>"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "tulosta ei voi kirjoittaa: %s"
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
@@ -70268,284 +70330,284 @@ msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABL
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %d-kaltainen"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Tämä pikanäppäin on jo käytössä toiminnolle %s"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "”%s” ei ole kelvollinen makron nimi, sillä se on C++:n operaattori"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Varsinainen argumentti kohteelle ”%s” ei voi olla oletetunkokoinen taulukko kohdassa %L"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Haarautuminen kohdassa %L voi aiheuttaa ikisilmukan"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -70553,192 +70615,192 @@ msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Odottamaton %s-lause WHERE-lohkossa kohdassa %C"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Lohkonimiö ei ole sopiva IF-lauseelle kohdassa %C"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-lauseke kohdassa %L on typistetty (%d/%d)"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "virheellinen %%L-arvo"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Käyttämätön parameteri ”%s” esitelty kohdassa %L"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -70746,114 +70808,114 @@ msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Merkkijonon pituus kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava valemuuttuja"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Varattavalla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
@@ -70861,852 +70923,852 @@ msgstr ""
 "  tai:  %s -l [SIGNAALI]...\n"
 "  tai:  %s -t [SIGNAALI]...\n"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Ulkoisella objektilla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktiolla ”%s” kohdassa %L täytyy olla skalaaritulos"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla taulukkoarvoinen"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla puhdas"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla rekursiivinen"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Valeproseduurilla ”%s” kohdassa %C ei voi olla geneeristä rajapintaa"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa RESULT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribuutti on ristiriidassa FUNCTION-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla skalaari"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, fuzzy, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava valemuuttuja"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, fuzzy, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Proseduurilla ”%s” kohdassa %C on eksplisiittinen rajapinta ja sillä ei saa olla attribuutteja, jotka on esitelty kohdassa %L"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta sitä ei voida käyttää"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Ei voi sijoitaa nimettyyn vakioon kohdassa %C"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Syntaksivirhe merkkipituusspesifikaatiossa kohdassa %C"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla merkkijono"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
@@ -72570,17 +72632,17 @@ msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Luodaan väliaikainen komentotiedosto %s\n"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
@@ -72671,107 +72733,107 @@ msgstr "ei-vakio alustuslauseke kohdassa %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, fuzzy, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, fuzzy, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "Käyttämätön muuttuja ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Käyttämätön muuttuja ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, fuzzy, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "%Jmuuttuja %qD esitelty %<inline%>:ksi"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Käyttämätön muuttuja ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Käyttämätön parameteri ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "last-op"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -72922,7 +72984,7 @@ msgstr "vektoriylivuoto lausekkeessa"
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, fuzzy, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "lauseella ei ole vaikutusta"
@@ -73049,7 +73111,7 @@ msgstr "valitsimet %s ja %s ovat toisensa poissulkevat"
 
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "valitsimet %s ja %s ovat toisensa poissulkevat"
 
 #: lto/lto-object.c:107
@@ -74150,7 +74212,7 @@ msgstr "tuntematon komentorivivalitsin %qs"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "tunnistamaton muotomäärite"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "tuntematon komentorivivalitsin %qs"
@@ -74168,15 +74230,15 @@ msgstr "makron nimi puuttuu %qs:n jälkeen"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "polku puuttuu %qs:n jälkeen"
@@ -74226,7 +74288,7 @@ msgstr "puuttuva luku"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "tunnistamaton muotomäärite"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "tunnistamaton muotomäärite"
@@ -74309,92 +74371,92 @@ msgstr "%qE on vanhentunut"
 msgid "unknown linker output %qs"
 msgstr "syötetiedosto %qs on sama kuin tulostiedosto"
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, fuzzy, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1718
+#: common.opt:1722
 #, fuzzy, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "Funktio %qs"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "Funktio %qs"
 
-#: common.opt:2690
+#: common.opt:2694
 #, fuzzy, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "tls_model-argumentti ei ole merkkijono"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:3067
+#: common.opt:3071
 #, fuzzy, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs:n alustuksen lähistöllä)"
@@ -74404,6 +74466,10 @@ msgstr "(%qs:n alustuksen lähistöllä)"
 msgid "unknown evrp mode %qs"
 msgstr "tls_model-argumentti ei ole merkkijono"
 
+#, fuzzy
+#~ msgid "cannot deduce template arguments for %qT from %<()%>"
+#~ msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
+
 #, fuzzy
 #~ msgid "%K%qD may write %E or more bytes into a region of size %E the destination"
 #~ msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
@@ -75601,10 +75667,6 @@ msgstr "tls_model-argumentti ei ole merkkijono"
 #~ msgid "-freorder-blocks-and-partition does not work on this architecture"
 #~ msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#, fuzzy
-#~ msgid "constant argument %d for builtin %qF is out of range ("
-#~ msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
-
 #, fuzzy
 #~ msgid "bad value (%s) for -mcmodel= switch"
 #~ msgstr "virheellinen aikakatkaisuarvo: %s"
@@ -77261,10 +77323,6 @@ msgstr "tls_model-argumentti ei ole merkkijono"
 #~ msgid "%qE does not have class type"
 #~ msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#, fuzzy
-#~ msgid "lambda-expression in template-argument"
-#~ msgstr "oletusargumentti määritelty lambda-parametrille"
-
 #, fuzzy
 #~ msgid "break statement used with Cilk Plus for loop"
 #~ msgstr "break-lause ei ole silmukan tai switch-lauseen sisässä"
diff --git a/gcc/po/fr.po b/gcc/po/fr.po
index 42aedf7a11bf0..c13512fb62f1e 100644
--- a/gcc/po/fr.po
+++ b/gcc/po/fr.po
@@ -99,7 +99,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 11.1-b20210321\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2021-03-25 13:27+0100\n"
 "Last-Translator: Frédéric Marchal <fmarchal@perso.be>\n"
 "Language-Team: French <traduc@traduc.org>\n"
@@ -1355,11 +1355,11 @@ msgstr "    mis en ligne depuis %qs"
 msgid "this is the insn:"
 msgstr "ceci est la insn :"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "incapacité de générer des recharges pour les contraintes impossible :"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "incapable de générer des recharges pour:"
 
@@ -1530,16 +1530,16 @@ msgstr "insn non reconnaissable:"
 msgid "insn does not satisfy its constraints:"
 msgstr "insn ne satisfait pas à ses contraintes:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "créé et utilisé avec des configurations différentes de « %s »"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "créé et utilisé avec des configurations différentes de %<-fpic%>"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "créé et utilisé avec des configurations différentes de %<-fpie%>"
 
@@ -1577,7 +1577,7 @@ msgstr "%s%savertissement: l'en-tête %s version %s diffère de la version %s de
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "heuristiques %s%sGGC: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2021,83 +2021,83 @@ msgstr "modificateur de longueur dans le format de strfmon"
 msgid "<command-line>"
 msgstr "<ligne-de-commande>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "opérande non supporté pour le code « %c »"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "opérande invalide pour « %%%c »"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante vecteur invalide"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "opérande en virgule flottante ou registre vecteur incompatible pour « %%%c »"
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "opérande de registre incompatible pour « %%%c »"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "opérande manquant"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "constante invalide"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "opérande invalide"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "préfixe d'opérande invalide « %%%c »"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, c-format
 msgid "invalid address mode"
 msgstr "mode d'adresse invalide"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "conversion invalide depuis le type %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "conversion invalide vers le type %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "opération non permise sur le type %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "impossible de combiner les vecteurs GNU et SVE dans l'opération binaire"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "« %%& » utilisé sans référence à un TLS dynamique local"
@@ -2113,18 +2113,18 @@ msgid "invalid %%r value"
 msgstr "valeur %%r invalide"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "valeur %%R invalide"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "valeur %%N invalide"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "valeur %%P invalide"
@@ -2154,7 +2154,7 @@ msgstr "valeur %%M invalide"
 msgid "invalid %%U value"
 msgstr "valeur %%U invalide"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "valeur %%s invalide"
@@ -2164,7 +2164,7 @@ msgstr "valeur %%s invalide"
 msgid "invalid %%C value"
 msgstr "valeur %%C invalide"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "valeur %%E invalide"
@@ -2177,7 +2177,7 @@ msgstr "relocalisation unspec inconnue"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "valeur %%xn invalide"
@@ -2259,35 +2259,35 @@ msgstr "UNSPEC invalide comme opérande : %d"
 msgid "unrecognized supposed constant"
 msgstr "constante supposée non reconnue"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "opérande shift invalide"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruction Thumb établie"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruction établie dans la séquence conditionnelle"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Opérande non supporté pour le code « %c »"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2295,13 +2295,13 @@ msgstr "Opérande non supporté pour le code « %c »"
 msgid "invalid operand for code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "instruction jamais exécutée"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "code de format Maverick « %c » obsolète"
@@ -2423,8 +2423,8 @@ msgstr "opérande non supporté"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2787,7 +2787,7 @@ msgstr "opération invalide sur %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "opérande %%P invalide"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "valeur %%p invalide"
@@ -2841,7 +2841,7 @@ msgid "post-increment address is not a register"
 msgstr "le post-incrément d'adresse n'est pas un registre"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "mauvaise adresse"
 
@@ -2893,8 +2893,8 @@ msgstr "« %%%c » n'est pas un préfixe d'opérande valide"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "utilisation invalide de « %%%c »"
@@ -3030,286 +3030,286 @@ msgstr "Manque d'espace sur la pile.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Essayez d'exécuter « %s » dans le shell pour augmenter sa limite.\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "%<-mvsx%> nécessite une unité matérielle en virgule flottante"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> nécessite l'adressage indexé"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "%<-mvsx%> et %<-mno-altivec%> sont incompatibles"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "%<-mno-altivec%> désactive vsx"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<-mquad-memory%> requiert le mode 64 bits"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> requiert le mode 64 bits"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> n'est pas disponible en mode petit-boutiste"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr "mauvais déplacement"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr "Mauvais déplacement sur 128 bits"
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, c-format
 msgid "invalid %%A value"
 msgstr "valeur %%A invalide"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "valeur %%D invalide"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, c-format
 msgid "invalid %%e value"
 msgstr "valeur %%e invalide"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "valeur %%f invalide"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "valeur %%F invalide"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "valeur %%G invalide"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "valeur %%j invalide"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "valeur %%J invalide"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "valeur %%k invalide"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "valeur %%K invalide"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "valeur %%O invalide"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "valeur %%q invalide"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, c-format
 msgid "invalid %%t value"
 msgstr "valeur %%t invalide"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "valeur %%T invalide"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "valeur %%u invalide"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "valeur %%v invalide"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, c-format
 msgid "invalid %%V value"
 msgstr "valeur %%V invalide"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "valeur %%x invalide"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, c-format
 msgid "invalid %%z value"
 msgstr "valeur %%z invalide"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valeur %%y invalide, essayez d'utiliser la contrainte « Z »"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Mélange invalide de types en virgule flottante IEEE 128 bits et IBM 128 bits"
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argument AltiVec passé à une fonction sans prototype"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 msgid "Could not generate addis value for fusion"
 msgstr "N'a pu générer de valeur addis pour la fusion"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Impossible de générer un offset load/store pour la fusion"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr "Mauvaise fusion GPR"
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "conversion invalide depuis le type %<__vector_quad%>"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "conversion invalide vers le type %<__vector_quad%>"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "conversion invalide depuis le type %<__vector_pair%>"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "conversion invalide vers le type %<__vector_pair%>"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "conversion invalide depuis le type %<* __vector_quad%>"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "conversion invalide vers le type %<* __vector_quad%>"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "conversion invalide depuis le type %<* __vector_pair%>"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "conversion invalide vers le type %<* __vector_pair%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "les références mémoire symboliques sont uniquement supportées sur z10 ou ultérieur"
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "adresse indécomposable"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "opérateur de comparaison invalide pour le modificateur de sortie « E »"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "référence invalide pour le modificateur de sortie « J »"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « O »"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « R »"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "référence mémoire attendue pour le modificateur de sortie « S »"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « S »"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "registre ou expression mémoire attendue pour le modificateur de sortie « N »"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "registre ou expression mémoire attendue pour le modificateur de sortie « M »"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "constante invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "constante invalide - essayez un modificateur de sortie"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "vecteur constant invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "expression invalide - essayez un modificateur de sortie"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "expression invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 msgid "vector argument passed to unprototyped function"
 msgstr "vecteur passé en argument à une fonction sans prototype"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr "les types diffèrent sur le type signé/non-signé"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr "l'opérateur binaire ne supporte pas deux opérandes booléens vectoriels"
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr "l'opérateur binaire ne supporte pas l'opérande booléen vectoriel"
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "l'opérateur binaire ne supporte pas le mélange d'un booléen vectoriel avec un vecteur en virgule flottante"
 
@@ -3572,8 +3572,8 @@ msgstr "({anonyme})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> attendu"
@@ -3593,7 +3593,7 @@ msgstr "%<;%> attendu"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> attendu"
@@ -3601,7 +3601,7 @@ msgstr "%<)%> attendu"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> attendu"
@@ -3619,21 +3619,21 @@ msgstr "%<;%>, %<,%> ou %<)%> attendu"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> attendu"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> attendu"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> attendu"
@@ -3644,13 +3644,13 @@ msgstr "%<{%> attendu"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> attendu"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> attendu"
@@ -3659,7 +3659,7 @@ msgstr "%<while%> attendu"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> attendu"
@@ -3668,18 +3668,18 @@ msgstr "%<,%> attendu"
 msgid "expected %<.%>"
 msgstr "%<.%> attendu"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> attendu"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> attendu"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> ou %<)%> attendu"
@@ -3687,28 +3687,28 @@ msgstr "%<,%> ou %<)%> attendu"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> attendu"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> attendu"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> ou %<}%> attendu"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(anonyme)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> attendu"
@@ -3723,29 +3723,29 @@ msgstr "étiquette attendue"
 msgid "candidate:"
 msgstr "candidat :"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 msgid "  after user-defined conversion:"
 msgstr "  après la conversion définie par l'utilisateur :"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "le candidat est :"
 msgstr[1] "les candidats sont :"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "candidat 1 :"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "candidat 2 :"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "saut à l'étiquette %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "saut à l'étiquette du « case »"
 
@@ -3964,27 +3964,27 @@ msgstr "le paramètre %qD ne peut pas apparaître dans ce contexte"
 msgid "local variable %qD may not appear in this context"
 msgstr "la variable locale %qD ne peut pas apparaître dans ce contexte"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using enum%> est uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 msgid "%<using enum%> of dependent type %qT"
 msgstr "%<using enum%> du type dépendant %qT"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%<using enum%> du type non-énuméré %q#T"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "%<using enum%> du type incomplet %qT"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr "%<using enum%> de %qT avant le spécificateur de son énmuération"
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "les candidats sont :"
 
@@ -4028,48 +4028,48 @@ msgstr "la conversion supprime l'attribut « const »"
 msgid "source type is not polymorphic"
 msgstr "le type source n'est pas polymorphique"
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "type d'argument erroné pour le moins unaire"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "type d'argument erroné pour le plus unaire"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "type d'argument erroné pour le complément de bit"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "type d'argument erroné pour abs"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "type d'argument erroné pour la conjugaison"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr "dans l'argument d'un unaire !"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr "pas d'opérateur de pré-incrémentation pour le type"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr "pas d'opérateur de post-incrémentation pour le type"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr "pas d'opérateur de pré-décrémentation pour le type"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr "pas d'opérateur de post-décrémentation pour le type"
 
@@ -4174,7 +4174,7 @@ msgstr "Désaccord de la limite du tableau pour la dimension 2 du tableau (%ld/%
 msgid "Driving:"
 msgstr "Pilotage:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "argument effectif de INTENT = OUT/INOUT"
 
@@ -4304,7 +4304,7 @@ msgstr "Mauvais opérateur"
 msgid "Bad type in constant expression"
 msgstr "Mauvais type dans l'expression constante"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "Fin de module inattendue"
 
@@ -4332,11 +4332,11 @@ msgstr "bloc IF"
 msgid "implied END DO"
 msgstr "END DO implicite"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "affectation"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "affectation de pointeur"
 
@@ -4422,154 +4422,154 @@ msgstr "résultat avec une longueur de caractères non constante"
 msgid "bind(c) procedure"
 msgstr "procédure bind(c)"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Contexte invalide pour un pointeur NULL() à %%L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "L'opérande de l'opérateur numérique unaire %%<%s%%> à %%L est %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Entités de type dérivé inattendues dans l'opérateur numérique intrinsèque binaire %%<%s%%> à %%L"
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur numérique binaire %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur de concaténation de chaînes à %%L sont %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur logique %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "L'opérande de l'opérateur .not. à %%L est %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Les quantités COMPLEX ne peuvent pas être comparées à %L"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Les valeurs logiques à %%L doivent être comparées avec %s au lieu de %s"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur de comparaison %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Opérateur %%<%s%%> inconnu à %%L; vouliez-vous utiliser « %s » ?"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Opérateur %%<%s%%> inconnu à %%L"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "L'opérande de l'opérateur utilisateur %%<%s%%> à %%L est %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur utilisateur %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangs inconsistant pour l'opérateur à %%L et %%L"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr "Variable de boucle"
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr "variable d'itérateur"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr "Expression de départ dans la boucle DO"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr "Expression de fin dans la boucle DO"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr "Expression de pas dans la boucle DO"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr "objet DEALLOCATE"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr "objet ALLOCATE"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr "élément dans READ"
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Longueurs de CHARACTER différentes (%ld/%ld) dans le constructeur de tableau"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Débordement d'entier en calculant la quantité de mémoire à allouer"
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "La valeur du paramètre PDT LEN « %s » n'est pas en accord avec celle dans la déclaration fictive"
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longueur réelle de la chaîne ne correspond pas à celle déclarée pour l'argument fictif « %s » (%ld/%ld)"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longueur réelle de la chaîne est plus courte que celle déclarée pour l'argument fictif « %s » (%ld/%ld)"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "La cible du remappage de rang est trop petite (%ld < %ld)"
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr "Assignation d'un scalaire à un tableau non alloué"
 
@@ -4694,26 +4694,26 @@ msgstr "Référence de tableau hors limites"
 msgid "Incorrect function return value"
 msgstr "Valeur de retour de fonction invalide"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, c-format
 msgid "Error allocating %lu bytes"
 msgstr "Erreur en allouant %lu octets"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "Tentative d'allouer la variable « %s » qui est déjà allouée"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr "Tentative d'allouer une variable déjà allouée"
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "Tentative d'utiliser DEALLOCATE sur « %s » qui n'est pas alloué"
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr "Erreur en ré-allouant %lu octets"
@@ -4908,15 +4908,15 @@ msgstr "-Xbind-now et -Xbind-lazy sont incompatibles"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr "envisagez d'utiliser « -pg » au lieu de « -p » avec gprof (1)"
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "ne peut utiliser -EB et -EL ensemble"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-mfloat-abi=soft et -mfloat-abi=hard ne peuvent pas être utilisés ensemble"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian et -mlittle-endian ne peuvent être utilisés ensemble"
 
@@ -4932,8 +4932,8 @@ msgstr "pas de type de processeur spécifié pour l'édition de liens"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "ne spécifiez pas à la fois -march=… et -mcpu=…"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared et mdll ne sont pas compatibles"
 
@@ -5093,10 +5093,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Avertir à propos de la création de temporaires de tableaux."
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Ne fait rien. Préservé pour rétro-compatibilité."
@@ -5571,160 +5571,160 @@ msgstr "Placer tous les tableaux locaux sur la pile."
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "Fixer l'accessibilité par défaut des entités du module à PRIVATE."
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "Essayer de disposer les types dérivés de manière aussi compacte que possible."
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "Protéger les parenthèses dans les expressions."
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr "Chemin vers le fichier d'en-tête qui devrait être pré-inclu avant chaque unité de compilation."
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr "Activer la validation des limites pendant la compilation."
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr "Interpréter tout REAL(4) comme un REAL(8)."
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr "Interpréter tout REAL(4) comme un REAL(10)."
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr "Interpréter tout REAL(4) comme un REAL(16)."
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr "Interpréter tout REAL(8) comme un REAL(4)."
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr "Interpréter tout REAL(8) comme un REAL(10)."
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr "Interpréter tout REAL(8) comme un REAL(16)."
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr "Ré-allouer le membre de gauche dans les affectations."
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Utiliser un marqueur sur 4 octets pour les fichiers non formatés."
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Utiliser un marqueur sur 8 octets pour les fichiers non formatés."
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr "Allouer les variables locales sur la pile pour autoriser la récursion indirecte."
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "Copier les sections de tableaux dans un bloc contigu lors de l'entrée dans une procédure."
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr "-fcoarray=<none|single|lib>\tSpécifier quelle parallélisation co-tableau utiliser."
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr "-fcheck=[...]\tSpécifier quels contrôles à l'exécution doivent être réalisés."
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "Ajouter un deuxième souligné si le nom contient déjà un souligné."
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr "Appliquer le signe négatif aux valeurs zéro."
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr "Interdire l'optimisation des appels de fin de fonction quand la routine appelante peut avoir omis les longueurs des caractères."
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr "Ajouter un souligné aux noms visibles depuis l'extérieur."
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Ne fait rien. Préservé pour rétro-compatibilité."
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr "Lier statiquement la bibliothèque d'assistance GNU Fortran (libgfortran)."
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Être conforme au standard Fortran ISO 2003."
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Être conforme au standard Fortran ISO 2008."
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Être conforme au standard Fortran ISO 2008 y compris TS 29113."
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Être conforme au standard Fortran ISO 2018."
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Être conforme au standard Fortran ISO 95."
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr "Pas de conformité particulière."
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr "Accepter les extensions pour prendre en charge du code ancien."
@@ -6403,8 +6403,9 @@ msgid "Warn for deallocation calls with arguments returned from mismatched alloc
 msgstr "Avertir à propos d'appels de désallocation avec des arguments retournés par des fonctions d'allocation non correspondantes."
 
 #: c-family/c.opt:803
-#, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+#, fuzzy, no-c-format
+#| msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr "Avertir à propos de désaccords entre les appels à l'opérateur « new » ou « delete » et l'appel correspondant à la fonction d'allocation ou de désallocation."
 
 #: c-family/c.opt:808
@@ -7028,8 +7029,8 @@ msgstr "-faligned-new=<N>\tUtiliser l'allocation de types sur-alignés du C++17
 msgid "Allow variadic functions without named parameter."
 msgstr "Autoriser les fonctions variadiques sans paramètre nommé."
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr "Prise en charge supprimée."
@@ -7386,466 +7387,461 @@ msgstr "Spécifier les dimensions de calculs par défaut pour OpenACC."
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr "-fopenacc-kernels=[decompose|parloops]\tSpécifier le mode de gestion des constructions « kernels » OpenACC."
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "Activer OpenMP (implique -frecursive en Fortran)."
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "Activer les directives SIMD de OpenMP."
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "Reconnaître les mots clés C++ comme « compl » et « xor »."
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "Rechercher et utiliser les fichiers PCH même pendant le pré-traitement."
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr "Transformer les erreurs de conformité en simples avertissements."
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr "Activer les extensions de langage Plan 9."
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr "Considérer que le fichier d'entrée a déjà été pré-traité."
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr "-ftrack-macro-expansion=<0|1|2>\tTracer les emplacements des éléments qui proviennent des remplacement des macros et les afficher dans les messages d'erreurs."
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr "Ne pas embellir l'affichage des spécialisations de patrons sous la forme de la signature du patron suivie des arguments."
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr "Traiter les valeurs de retour connues de sprintf comme des constantes."
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "Utilisé avec le mode Fix-and-Continue pour indiquer que les fichiers objets peuvent être insérés pour remplacer ceux du programme durant l'exécution."
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "Supprimé dans GCC 10.  Cette option n'a aucun effet."
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr "Générer l'information pour les types de descripteurs lors de l'exécution."
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "Utiliser le type d'entier le plus étroit possible pour les types d'énumérations."
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "Forcer le type sous-jacent de « wchar_t » à être « unsigned short »."
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "Lorsque ni « signed » ni « unsigned » n'est fourni, le champ de bits doit être signé."
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr "Rendre les « char » signés par défaut."
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "Activer le support pour les désallocations avec taille connue du C++14."
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr "-fsso-struct=[big-endian|little-endian|native]\tFixer l'ordre de stockage par défaut des scalaires."
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr "Afficher les statistiques accumulées durant la compilation."
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "Supposer que les valeurs d'un type énuméré sont toujours dans la plage minimum de ce type."
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr "Suivre les exigences du C++17 concernant l'ordre d'évaluation des expressions d'affectations, des décalages, des appels aux fonctions membres, etc."
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "Fixer le nombre maximum de notes d'instanciations de patrons pour un seul avertissement ou erreur."
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "-ftemplate-depth=<nombre>\tSpécifier la profondeur maximale d'instanciation d'un patron."
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "-fno-threadsafe-statics\tNe pas générer de code sûr du point de vue des threads pour initialiser les statiques locaux."
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "Lorsque ni « signed » ni « unsigned » n'est fourni, le champ de bits doit être non signé."
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "Rendre les « char » non signés par défaut."
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr "Utiliser __cxa_atexit pour enregistrer les destructeurs."
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "Utiliser __cxa_get_exception_ptr dans la gestion des exceptions."
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "Marquer toutes les fonctions et méthodes mises en ligne comme ayant la visibilité « cachée »."
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "Changer la visibilité pour correspondre à Microsoft Visual Studio par défaut."
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr "Produire les symboles communs comme des symboles faibles."
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-fwide-exec-charset=<jeucar>\tConvertir toutes les chaînes et les constantes de caractères larges vers le jeu de caractères <jeucar>."
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "Générer une directive #line pointant sur le répertoire de travail courant."
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "Générer une recherche de classes molle (via objc_getClass()) pour l'utilisation en mode Zero-Link."
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr "Vidanger les déclarations dans un fichier .decl."
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "-femit-struct-debug-baseonly\tInformations de débogage agressivement réduites pour les structs."
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "-femit-struct-debug-reduced\tInformations de débogage modérément réduites pour les structs."
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "-femit-struct-debug-detailed=<liste-spec>\tInformations de débogage réduites mais détaillées pour les structs."
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr "Interpréter les nombres imaginaires, en virgule fixe ou avec d'autres suffixes gnu comme le nombre littéral correspondant au lieu d'un nombre littéral défini par l'utilisateur."
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <répertoire>\tAjouter <répertoire> à la fin du chemin système d'inclusion."
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "-imacros <fichier>\tAccepter la définition de macros dans le <fichier>."
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-imultilib <répertoire>\tChoisir <répertoire> comme le sous-répertoire d'inclusion de multilib."
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "-include <fichier>\tInclure le contenu du <fichier> avant les autres fichiers."
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "-iprefix <chemin>\tSélectionner le <chemin> comme préfixe pour les deux prochaines options."
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <répertoire>\tSélectionner le <répertoire> comme répertoire racine système."
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <répertoire>\tAjouter le <répertoire> au début du chemin d'inclusion système."
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-iquote <répertoire>\tAjouter le <répertoire> à la fin du chemin d'inclusion avec guillemets."
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <répertoire>\tAjouter le <répertoire> à la fin du chemin d'inclusion système."
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <répertoire>\tAjouter le <répertoire> à la fin du chemin d'inclusion principal."
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "Ne pas rechercher dans les répertoires d'inclusion standards du système (ceux spécifiés avec -isystem seront quand même utilisés)."
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr "Ne pas rechercher dans les répertoires d'inclusion standards du système pour le C++."
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr "Générer les en-têtes C des options spécifiques à la plate-forme."
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr "Remapper les noms des fichiers lors de l'inclusion des fichiers."
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Être conforme au standard C++ ISO 1998 révisé par les corrections techniques de 2003."
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Être conforme au standard C++ ISO 2011."
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Rendu obsolète en faveur de -std=c++11."
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Rendu obsolète en faveur de -std=c++14."
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Être conforme au standard C++ ISO 2014."
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr "Rendu obsolète en faveur de -std=c++17."
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "Être conforme au standard C++ ISO 2017."
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Conforme au standard ISO C++ de 2020 (support expérimental et incomplet)."
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Être conforme au brouillon du standard C++ ISO 2023 (support expérimental et incomplet)."
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Être conforme au standard C ISO 2011."
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "Rendu obsolète en faveur de -std=c11."
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Être conforme au standard C ISO 2017 (publié en 2018)."
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Conforme au brouillon du standard C ISO 202X (support expérimental et incomplet)."
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Être conforme au standard C ISO 1990."
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Être conforme au standard C ISO 1999."
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr "Rendu obsolète en faveur de -std=c99."
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Être conforme au standard C++ ISO 1998 révisé par les corrections techniques de 2003 avec les extensions GNU."
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Être conforme au standard C++ ISO 2011 avec les extensions GNU."
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Rendu obsolète en faveur de -std=gnu++11."
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Rendu obsolète en faveur de -std=gnu++14."
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Être conforme au standard C++ ISO 2014 avec les extensions GNU."
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "Rendu obsolète en faveur de -std=gnu++17."
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "Être conforme au standard C++ ISO 2017 avec les extensions GNU."
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Conforme au standard ISO C++ de 2020 avec les extensions de GNU (support expérimental et incomplet)."
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Être conforme au brouillon du standard C++ ISO 2023 avec les extensions GNU (support expérimental et incomplet)."
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Être conforme au standard C ISO 2011 avec les extensions GNU."
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Rendu obsolète en faveur de -std=gnu11."
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Être conforme au standard C ISO 2017 (publié en 2018) avec les extensions GNU."
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Conforme au brouillon du standard C ISO 202X avec les extensions de GNU (support expérimental et incomplet)."
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Être conforme au standard C ISO 1990 avec les extensions GNU."
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Être conforme au standard C ISO 1999 avec les extensions GNU."
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Rendu obsolète en faveur de -std=gnu99."
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Être conforme au standard C ISO 1990 tel que amendé en 1994."
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Rendu obsolète en faveur de -std=iso9899:1999."
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr "-stdlib=[libstdc++|libc++]\tLa bibliothèque standard à utiliser pour les en-têtes C++ et l'exécutable."
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "Activer le pré-traitement traditionnel."
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\tSupporter les trigrammes du C ISO."
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr "Ne pas prédéfinir les macros spécifiques au système et à GCC."
@@ -8090,6 +8086,12 @@ msgstr "Compiler avec le code unittest."
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr "-fversion=<niveau|ident>\tCompiler en code version >= <niveau> ou identifié par <ident>."
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+#| msgid "Emit implicit instantiations of templates."
+msgid "Emit template instantiations as weak symbols."
+msgstr "Produire des instanciations implicites pour les patrons."
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9327,143 +9329,155 @@ msgstr "Supporter plus de 8192 entrées dans la GOT d'un ColdFire."
 msgid "Support TLS segment larger than 64K."
 msgstr "Supporter des segments TLS plus grands que 64K."
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr "Supposer que le processeur cible est configuré comme gros-boutiste."
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr "Supposer que le processeur cible est configuré comme petit-boutiste."
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "-mbranch-cost=N\tDéfinir le coût des branchements à, approximativement, N instructions."
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr "Lors de la génération de code -fpic, autoriser l'utilisation des PLT. Ignoré avec fno-pic."
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "Spécifier la convention d'appel pour les entiers et les virgules flottantes."
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Essayer de conserver l'alignement de la pile sur cette puissance de 2."
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "ABI supportées (à utiliser avec l'option -mabi=):"
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Utiliser les instructions matérielles pour la division et la racine carrée en virgule flottante."
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr "Utiliser les instructions matérielles pour la division entière."
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr "-march=\tGénérer du code pour l'ISA RISC-V demandée (par ex. RV64IM).  Les chaînes ISA doivent être en minuscules."
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=PROCESSEUR\tOptimiser la sortie pour le PROCESSEUR."
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "-mcpu=PROCESSEUR\tUtiliser l'architecture et optimiser la sortie pour le PROCESSEUR."
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "-msmall-data-limit=N\tPlacer les données globales et statiques plus petites que <nombre> octets dans une section spéciale (sur certaines cibles)."
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "Utiliser du code plus petit mais plus lent pour le prologue et l'épilogue."
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr "Convertir les adresses BASE + GRAND_OFFSET en NOUVELLE_BASE + PETIT_OFFSET pour autoriser plus d'accès mémoire à être générés comme instructions compressées. Cible actuellement les chargements/stockages d'entiers 32 bits."
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr "Spécifier le modèle de code."
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr "Ne pas générer des accès mémoire non alignées."
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr "Modèles de code connus (à utiliser avec l'option -mcmodel=):"
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr "Utiliser les opérateurs %reloc(), plutôt que les macros en assembleur, pour charger les adresses."
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr "Tirer profit des relaxations de l'éditeur de liens pour réduire le nombre d'instructions requises pour matérialiser les adresses des symboles."
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr "Émettre l'attribut ELF RISC-V."
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr "Utiliser l'alignement de données spécifié."
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr "Choix connus pour l'alignement de données (à utiliser avec l'option -malign-data=):"
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr "Utiliser la méthode donnée pour protéger la pile."
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Arguments valides pour -mstack-protector-guard=:"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Utiliser le registre de base donné pour adresser la protection de la pile."
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Utiliser le décalage donné pour adresser la protection de la pile."
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "Spécifications ISA supportées (à utiliser avec l'option -misa-spec=):"
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr "Définir la version des spécifications ISA RISC-V."
@@ -9598,12 +9612,6 @@ msgstr "Les dialectes TLS possibles:"
 msgid "The code model option names for -mcmodel:"
 msgstr "Les noms d'options du modèle de code pour -mcmodel:"
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr "Supposer que le processeur cible est configuré comme gros-boutiste."
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9624,12 +9632,6 @@ msgstr "Correctif pour l'erratum numéro 835769 de l'ARM Cortex-A53."
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr "Correctif pour l'erratum numéro 843419 de l'ARM Cortex-A53."
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr "Supposer que le processeur cible est configuré comme petit-boutiste."
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -16854,2166 +16856,2166 @@ msgstr "-dumpbase-ext .<ext>    Laisser tomber le .<ext> à la fin du nom du fic
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <répertoire>\tDéfinir le nom du répertoire à utiliser pour les vidanges."
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr "La version de l'ABI C++ à utiliser."
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr "Optimiser agressivement les boucles en utilisant les contraintes du langage."
 
-#: common.opt:978
+#: common.opt:982
 #, no-c-format
 msgid "Align the start of functions."
 msgstr "Aligner le début des fonctions."
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr "Aligner les étiquettes qui sont uniquement atteintes par sauts."
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr "Aligner toutes les étiquettes."
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr "Aligner le début des boucles."
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr "Autoriser le compilateur à introduire de nouvelles concurrences de données lors des stockages."
 
-#: common.opt:1013
+#: common.opt:1017
 #, no-c-format
 msgid "Enable static analysis pass."
 msgstr "Activer l'étape d'analyse statique."
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr "Sélectionner quoi assainir."
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr "Sélectionner le type de la couverture d'assainissement."
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr "-fasan-shadow-offset=<nombre>\tUtiliser un décalage personnalisé pour la mémoire des informations de validation (shadow memory)."
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr "-fsanitize-sections=<sec1,sec2,…>\tAssainir les variables globales dans les sections définies par l'utilisateur."
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr "Essayer de continuer l'exécution après avoir diagnostiqué un comportement indéfini."
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Cette option est obsolète; utilisez -fsanitize-recover= à la place."
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr "Utiliser un déroutement au lieu d'une fonction de la bibliothèque pour signaler des comportements indéfinis détectés par le code d'assainissement."
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Générer des tables de retour en arrière (unwind tables) qui sont exactes à chaque limite d'instruction."
 
-#: common.opt:1069
+#: common.opt:1073
 #, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "Générer des instructions auto-inc/dec."
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Utiliser des informations de profilage par échantillonnage pour le poids des nœuds du graphe d'appels. Le fichier profile par défaut est fbdata.afdo dans « pwd »."
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Utiliser des informations de profilage par échantillonnage pour le poids des nœuds du graphe d'appels. Le fichier profile est spécifié en argument."
 
-#: common.opt:1087
+#: common.opt:1091
 #, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Générer du code pour vérifier les bornes avant d'indexer les tableaux."
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Remplacer add, compare, branch par des branchements utilisant un registre compteur."
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr "Utiliser les informations de profilage pour les probabilités de branchements."
 
-#: common.opt:1111
+#: common.opt:1115
 #, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr "Fournir les informations du graphe d'appels pour chaque fichier."
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "Fournir les informations du graphe d'appels pour chaque fichier avec les décorations."
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<registre>\tMarquer le <registre> comme étant préservé au travers des fonctions."
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<registre>\tMarquer le <registre> comme étant corrompu par les appels de fonctions."
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr "Sauvegarder les registres autour des appels de fonctions."
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "Cette option est obsolète; ne l'utilisez pas."
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "Vérifier la valeur retournée par new en C++."
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr "Réaliser des validations internes d'intégrité."
 
-#: common.opt:1150
+#: common.opt:1154
 #, no-c-format
 msgid "Enable code hoisting."
 msgstr "Activer la sortie du code hors des boucles."
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Chercher des opportunités de réduire les ajustements de pile et les références à la pile."
 
-#: common.opt:1158
+#: common.opt:1162
 #, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr "Placer les globales non initialisées dans la section commune."
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<opts>]\tCompiler avec et sans l'option (par ex. -gtoggle) et comparer la vidange des insns finales."
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "N'exécuter que la seconde compilation de -fcompare-debug."
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Réaliser l'élimination des comparaisons après que l'allocation des registres ait été terminée."
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "Ne pas appliquer les optimisations qui augmentent notablement l'utilisation de la pile."
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Effectuer une étape d'optimisation par propagation des copies des registres."
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr "Exécuter l'optimisation des sauts croisés."
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Lorsque CSE s'exécute, suivre les sauts jusqu'à leurs cibles."
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr "Omettre l'étape de réduction de plage en réalisant des divisions complexes."
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Les multiplications et les divisions complexes suivent les règles du Fortran."
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr "Placer les éléments de données dans leur propre section."
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Lister tous les compteurs de débogage disponibles avec leurs limites et leurs valeurs."
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<compteur>[:<limite_inf1>-]<limite_sup1>[:<limite_inf2>-<limite_sup2>:…][,<compteur>:…]\tDéfinir la limite du compteur de débogage."
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr "-fdebug-prefix-map=<old>=<new>\tRemplacer un nom de répertoire par un autre dans les informations de débogage."
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr "-ffile-prefix-map=<old>=<new>\tRemplacer un nom de répertoire par un autre dans le résultat de la compilation."
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "Écrire une section .debug_types lorsque debuginfo de DWARF v4 est utilisé."
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr "Retarder à plus tard le dépilage des arguments des fonctions hors de la pile."
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Tenter de remplir les créneaux de retard (delay slots) des instructions de branchement."
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr "Supprimer les instructions inutiles qui peuvent déclencher des exceptions."
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr "Supprimer les vérifications inutiles des pointeurs nuls."
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr "Produire des données supplémentaires pour fournir une dévirtualisation plus agressive dans le mode de transformation local de LTO."
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr "Réaliser une dévirtualisation spéculative."
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Essayer de convertir les appels virtuels en appels directs."
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\tIndiquer combien de fois les informations sur l'emplacement dans le code source doivent être répétées au début des lignes de diagnostiques écrites sur plusieurs lignes."
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr "Montrer la ligne source avec un curseur indiquant la colonne."
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr "Montrer les étiquettes annotant les plages du code source lorsque le code source est montré."
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr "Montrer les numéros de lignes dans la marge de gauche lorsque le code source est montré."
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tAfficher les diagnostiques en couleur."
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr "-fdiagnostics-urls=[never|always|auto]\tEmbarquer les URL dans les diagnostiques."
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr "-fdiagnostics-column-unit=[display|byte]\tSélectionner si les numéros de colonnes sont sortis comme colonnes d'affichage (par défaut) ou des octets bruts."
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr "-fdiagnostics-column-origin=<numéro>\tDéfini le numéro de la première colonne.  Le défaut est basé sur 1 en accord avec le style GNU mais certains utilitaires peuvent attendre une base zéro, par exemple."
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr "-fdiagnostics-format=[text|json]\tChoisir le format de sortie."
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr "Afficher les indices pour la correction sous forme lisible par une machine."
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr "Afficher les indices pour la correction vers stderr au format diff unifié."
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Amender les messages de diagnostiques appropriés avec les options de la ligne de commande qui les contrôlent."
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr "Afficher les identificateurs CWE pour les messages de diagnostiques, quand disponibles."
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr "Spécifier comment imprimer les chemins de contrôle de flux associés avec un diagnostique."
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr "Arrêter toute fonctionnalité de diagnostique qui complique la sortie telles que les numéros de lignes, la couleur et URL d'avertissement."
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "-ftabstop=<nombre>      Distance entre les tabulations pour un rapport en colonnes."
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr "Montrer les profondeurs des piles d'événements dans les chemins."
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr "Définir la largeur minimale de la marge de gauche du code source lorsque le code source est montré."
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<étape>=range1+range2\tdésactiver une étape d'optimisation."
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<étape>=range1+range2\tactiver une étape d'optimisation."
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\tVidanger diverses données internes du compilateur dans un fichier."
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=fichier\tVidanger dans un fichier les insns à la fin d'une traduction."
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=fichier\tÉcrire toutes les déclarations dans un fichier sous forme de code Go."
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Supprimer la sortie des adresses dans les vidanges de débogage."
 
 # ICE=Internal Compiler Error
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr "Collecter et décharger les informations de débogage dans un fichier temporaire si une erreur interne du compilateur a eu lieu dans le compilateur C/C++."
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr "Vidanger les informations détaillées sur la représentation interne de GCC des emplacements du code source."
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr "Vidanger les étapes d'optimisation."
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Supprimer la sortie des numéros d'instructions, des numéros de lignes et des adresses dans les vidanges de débogage."
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Supprimer la sortie des numéros d'insn précédents et suivants dans les vidanges de débogage."
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Activer les tables CFI via les directives de l'assembleur GAS."
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr "Exécuter la mise en ligne très tôt."
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Réaliser la réduction interprocédurale des agrégats."
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Effectuer l'élimination des symboles inutilisés dans les informations de débogage."
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr "Effectuer l'élimination des types inutilisés dans l'information de débogage."
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "Ne pas supprimer les informations de débogage des classes C++."
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr "Activer le traitement des exceptions."
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Effectuer un nombre d'optimisations mineures et coûteuses."
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tSpécifier la manière de gérer l'excédant de précision en virgule flottante."
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpécifier les valeurs permises pour FLT_EVAL_METHOD."
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Produire les objets LTO contenant à la fois le langage intermédiaire et la sortie binaire."
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Supposer qu'aucun NaN ni aucun infini ne sont générés."
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr "Supposer que les boucles avec une sortie vont se terminer et ne jamais boucler indéfiniment."
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<registre>\tMarquer le <registre> comme n'étant pas disponible pour le compilateur."
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Ne pas allouer des float ni des double dans des registres en précision étendue."
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Réaliser une étape de propagation dans RTL (Register Transfer Language)."
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast]\tRéaliser la contraction d'expression en virgule flottante."
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr "Autoriser les fonctions internes ceil, floor, round, trunc à déclencher des exceptions « inexactes »."
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr "Autoriser le maintien des adresses de fonctions dans les registres."
 
-#: common.opt:1586
+#: common.opt:1590
 #, no-c-format
 msgid "Place each function into its own section."
 msgstr "Placer chaque fonction dans sa propre section."
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr "Exécuter l'élimination des sous-expressions communes globales."
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Exécuter le mouvement de chargement amélioré lors de l'élimination des sous-expressions communes globales."
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Exécuter le mouvement de stockage après l'élimination des sous-expressions communes globales."
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Réaliser les chargements redondants après l'élimination des stockages dans les sous-expressions communes globales."
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Exécuter l'élimination des sous-expressions communes globales après que l'allocation des registres soit terminée."
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr "-fgnat-encodings=[all|gdb|minimal]\tSélectionner l'équilibre entre les encodages GNAT et le DWARF standard produit dans les informations de débogage."
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr "Activer les entrées et sorties de la représentation Graphite."
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr "Activer la transformation d'identité Graphite."
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Activer la sortie de chargements adjacents hors d'une boucle pour encourager la génération d'instructions de déplacements conditionnels."
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr "Améliorer la capacité de GCC à suivre les numéros de colonnes dans les grands fichiers source au détriment d'une compilation plus lente."
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr "Marquer toutes les boucles comme étant parallèles."
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "Activer les transformations de boucles imbriquées.  Identique à -floop-nest-optimize."
 
-#: common.opt:1659
+#: common.opt:1663
 #, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr "Activer l'échange de boucles sur les arbres."
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr "Réaliser le unroll-and-jam."
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr "Activer le support pour la mémoire transactionnelle GNU."
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "Utiliser STB_GNU_UNIQUE si supporté par l'assembleur."
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr "Activer l'optimisation de boucles imbriquées."
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr "Forcer les accès aux champs de bits à correspondre à la largeur de leur type."
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr "Fusionner les stockages adjacents."
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr "Activer l'estimation des probabilités de branchement."
 
-#: common.opt:1703
+#: common.opt:1707
 #, no-c-format
 msgid "Process #ident directives."
 msgstr "Traiter les directives #ident."
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Convertir les sauts conditionnels en équivalents sans branchements."
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Convertir les sauts conditionnels en exécutions conditionnelles."
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none]\tDéfinir le niveau de réutilisation de la pile pour les variables locales."
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Convertir les sauts conditionnels des boucles les plus à l'intérieur en équivalents sans branchement."
 
-#: common.opt:1743
+#: common.opt:1747
 #, no-c-format
 msgid "Do not generate .size directives."
 msgstr "Ne pas générer de directives .size."
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr "Réaliser la mise en ligne indirecte."
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "Activer la mise en ligne de fonctions déclarées « inline ». Le désactiver désactive toutes les mises en ligne."
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Intégrer les fonctions à l'intérieur de leurs appelants s'il est établi que la taille du code ne grandira pas."
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Intégrer les fonctions qui ne sont pas déclarées « inline » dans leurs appelants quand cela est profitable."
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "Intégrer les fonctions qui ne sont requises que par leur unique appelant."
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<nombre>\tLimiter la taille des fonction mises en ligne à <nombre>."
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Mettre en ligne les opérations __atomic quand une séquence d'instructions sans blocage est disponible."
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr "-fcf-protection=[full|branch|return|none|check]\tInstrumentaliser les fonctions avec des contrôles pour vérifier que les instructions de contrôle de flux jump/call/return ont une cible valable."
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Ajouter des appels de profilage aux entrées et aux sorties des fonctions."
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=nom,...\tNe pas ajouter les appels de profilage aux fonctions listées."
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=fichier,...\tNe pas ajouter les appels de profilage aux fonctions listées dans les fichiers."
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr "Réaliser la propagation interprocédurale des constantes."
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Réaliser un clonage pour rendre plus forte la propagation interprocédurale des constantes."
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Réaliser la propagation interprocédurale des constantes de bits."
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr "Réaliser l'analyse interprocédurale modref."
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr "Réaliser la propagation interprocédurale de profiles."
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr "Réaliser l'analyse interprocédurale des pointeurs et références."
 
-#: common.opt:1846
+#: common.opt:1850
 #, no-c-format
 msgid "Discover pure and const functions."
 msgstr "Découvrir les fonctions pures et const."
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Fusionner le code identique (Identical Code Folding) pour les fonctions et les variables en lecture seule."
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr "Fusionner le code identique (Identical Code Folding) pour les fonctions."
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr "Fusionner le code identique (Identical Code Folding) pour les variables."
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr "Découvrir les variables statiques en lecture seule et non adressables."
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "Découvrir les variables statiques en lecture seule, en écriture seule et non adressables."
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr "Réduire l'alignement de la pile à l'endroit de l'appel, si possible."
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr "Effectuer la propagation des plages de valeurs IPA."
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority]\tDéfinir l'algorithme IRA utilisé."
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed]\tDéfinir les régions pour IRA."
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "Utiliser le calcul de la pression sur les registres basé sur IRA dans les optimisations qui ont pour but de sortir du code hors d'une boucle durant la phase RTL."
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "Utiliser le calcul de la pression sur les registres basé sur IRA dans les optimisations de boucles durant la phase RTL."
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr "Partager les emplacements pour sauvegarder différents registres matériels."
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Partager les emplacements sur la pile pour faire déborder les pseudo registres."
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<nombre>\tContrôler le niveau des messages de diagnostique de IRA."
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr "Optimiser les variables d'induction dans les arbres."
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Utiliser des tables de sauts pour des instructions switch suffisamment grandes."
 
-#: common.opt:1945
+#: common.opt:1949
 #, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "Utiliser des tests de bits pour des instructions switch suffisamment grandes."
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Générer le code pour les fonctions même si elles sont complètement mises en ligne."
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "Générer le code pour les fonctions statiques même si elles ne sont jamais appelées."
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr "Produire les variables constantes statiques même si elles ne sont pas utilisées."
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr "Préfixer les symboles externes avec un caractère de soulignement."
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr "Faire une rematérialisation sensible au CFG pendant LRA."
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr "Activer les optimisations durant l'édition de liens."
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Les optimisations durant l'édition de liens sont faites avec un nombre de tâches parallèles ou un serveur de tâches."
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr "Spécifier l'algorithme pour partitionner les symboles et les variables durant l'édition de liens."
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr "-flto-compression-level=<nombre>\tUtiliser le niveau de compression <nombre> de zlib/zstd pour le langage intermédiaire (IL)."
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "Rapporter diverses statistiques d'optimisation durant l'édition de liens."
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Rapporter diverses statistiques d'optimisation durant l'édition de liens uniquement dans le mode d'analyse complète du programme (mode WPA)."
 
-#: common.opt:2020
+#: common.opt:2024
 #, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "Changer la valeur de errno après les fonctions mathématiques internes."
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<nombre>\tNombre maximum d'erreurs à rapporter."
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr "Produire un rapport sur l'allocation de mémoire permanente."
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Produire un rapport sur l'allocation de mémoire permanente dans le mode d'analyse complète du programme (WPA mode)."
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Tenter de fusionner les constantes et les variables constantes identiques."
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Tenter de fusionner les constantes identiques au travers des unités de compilation."
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Tenter de fusionner les chaînes de débogage identiques au travers des unités de compilation."
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<nombre>\tLimiter la longueur des diagnostiques à <nombre> caractères par ligne.  0 supprime le retour automatique à la ligne."
 
 # SMS= Swing Module Scheduler: est-il besoin de le préciser ?
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Réaliser l'ordonnancement modulo basé sur SMS avant la première étape de l'ordonnancement."
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Réaliser l'ordonnancement modulo basé sur SMS en autorisant les déplacements de registres."
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr "Déplacer hors des boucles les calculs invariants par rapport aux boucles."
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr "Utiliser l'étape d'élimination du code RTL mort."
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "Utiliser l'étape d'élimination des stockages RTL morts."
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Activer/Désactiver l'ordonnancement traditionnel dans les boucles qui sont déjà passées par l'ordonnancement modulo."
 
 # Je ne comprends même pas comment le message anglais est censé être compréhensible !
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr "Supporter les exceptions émises par des routines de déroutement."
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr "-foffload=<cibles>=<options>\tSpécifier les cibles pour les déchargements et leurs options."
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr "-foffload-abi=[lp64|ilp32]\tDéfinir l'ABI à utiliser dans un compilateur de déchargement."
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr "Lorsque c'est possible, ne pas générer des trames de pile."
 
-#: common.opt:2104
+#: common.opt:2108
 #, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Activer toutes les vidanges des informations d'optimisation sur stderr."
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<type>=fichier]\tVidanger les détails de l'optimisation du compilateur."
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr "Écrire un fichier FICHSRC.opt-record.json détaillant quelles optimisations ont été réalisées."
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimiser les appels récursifs dans des fonctions apparentées (sibbling call) et à la fin de la fonction (tail call)."
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr "Réaliser une mise en ligne partielle."
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Produire un rapport sur l'allocation de mémoire avant l'optimisation interprocédurale."
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr "Empaqueter les membres des structures ensemble sans trous."
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<nombre>\tDéfinir l'alignement initial maximum des membres d'une structure."
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr "Retourner les petits agrégats en mémoire, pas dans les registres."
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr "Effectuer l'aplatissage des boucles."
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr "Activer les optimisations sur de petits segments de code (peephole) spécifiques à la machine."
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Activer une étape d'optimisation sur de petits segments de code (peephole) par RTL avant sched2."
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Générer du code indépendant de la position si possible (mode large)."
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Générer du code indépendant de la position pour les exécutables si possible (mode large)."
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Générer du code indépendant de la position si possible (mode petit)."
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Générer du code indépendant de la position pour les exécutables si possible (mode petit)."
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr "Utiliser la PLT pour les appels PIC (-fno-plt: charger l'adresse depuis la GOT à l'endroit de l'appel)."
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr "Spécifier un greffon à charger."
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<nom>-<clé>[=<valeur>]\tSpécifier l'argument <clé>=<valeur> pour le greffon <nom>."
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr "Exécuter l'optimisation de mise en commun prédictive."
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Générer des instructions de préchargement, si disponible, pour les tableaux dans les boucles."
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr "Autoriser le code de profilage de base du programme."
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr "Générer des noms de chemins absolus vers le code source pour gcov."
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr "Insérer le code de profilage basé sur arc du programme."
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Définir le répertoire racine pour stocker les données de profilage. Le répertoire retourné par « pwd » est utilisé par défaut."
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr "Définir le nom pour stocker le fichier de note de profil."
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Autoriser la correction des inconsistances dans le flux d'entrée du profil."
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tDéfinir la méthode de mise à jour du profil."
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr "Ajouter du code de contrôle aux fonctions dans les fichiers dont le nom correspond à une des expressions régulières (séparées par un point-virgule)."
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr "Ajouter du code de contrôle aux fonctions dans les fichiers dont le nom ne correspond pas à une des expressions régulières (séparées par un point-virgule)."
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tNiveau de contrôle de la reproductibilité du profil collecté par -fprofile-generate."
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr "Supprimer le préfixe du chemin absolu avant de dégrader le nom pour -fprofile-generate= et -fprofile-use=."
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Activer les options communes pour la génération d'informations de profilage pour l'optimisation directe à partir des données collectées par le profilage."
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Activer les options communes pour la génération d'informations de profilage pour l'optimisation directe à partir des données collectées par le profilage et définir -fprofile-dir=."
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr "Enregistrer l'information du profile dans la section .gcov_info au lieu d'utiliser un constructeur/destructeur."
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr "Enregistrer l'information du profile dans la section spécifiée au lieu d'utiliser un constructeur/destructeur."
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr "Ne pas supposer que les fonctions qui ne sont pas exécutées durant l'exécution d'exercice sont « froides »."
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Activer les options communes pour réaliser une optimisation directe à partir des informations recueillies par le profilage."
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Activer les options communes pour réaliser une optimisation directe à partir des informations recueillies par le profilage et définir -fprofile-dir=."
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr "Insérer du code pour profiler les valeurs des expressions."
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr "Rapport sur la cohérence du profilage."
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr "Activer la réorganisation des fonctions qui améliore le placement du code."
 
-#: common.opt:2305
+#: common.opt:2309
 #, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr "Insérer des instructions NOP à chaque entrée de fonction."
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<chaîne>\tRendre la compilation reproductible en utilisant <chaîne>."
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr "Enregistrer, dans le fichier objet, les options en ligne de commande passées à gcc."
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr "Retourner les petits agrégats dans les registres."
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr "Informer DSE que la zone de stockage d'un objet C++ est morte quand le constructeur démarre et quand le destructeur se termine."
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr "-flive-patching=[inline-only-static|inline-clone]\tContrôler les optimisations IPA pour fournir une compilation sûr pour la correction à chaud. En même temps, fourni un contrôle à de multiples niveaux sur les optimisations IPA activées."
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr "Informer DCE de retirer les allocations C++ inutilisées."
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Soulager la pression sur les registres en réduisant la portée pendant laquelle une valeur peut rester dans un registre."
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr "Effectuer une étape d'optimisation pour renommer les registres."
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Effectuer une étape d'optimisation de fusion des instructions selon la cible."
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Réorganiser les blocs de base pour améliorer le placement du code."
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr "-freorder-blocks-algorithm=[simple|stc]\tDéfinir l'algorithme de réorganisation des blocs de base."
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Réorganiser les blocs de base et les partitions dans des sections chaude et froide."
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr "Réorganiser les fonctions pour améliorer le placement du code."
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Ajouter une étape d'élimination des sous-expressions communes après l'optimisation des boucles."
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Interdire les optimisations qui supposent un comportement par défaut pour l'arrondis des virgules flottantes."
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr "Activer l'ordonnancement à travers les blocs de base."
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Activer l'ordonnancement des insns sensible à la pression sur les registres."
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr "Autoriser le mouvement spéculatif des non chargements."
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr "Autoriser le mouvement spéculatif de certains chargements."
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr "Autoriser le mouvement spéculatif de plus de chargements."
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<numéro>\tDéfinir le niveau de verbosité de l'ordonnanceur."
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Si l'ordonnancement est fait après le rechargement, faire un ordonnancement des super blocs."
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr "Réordonnancer les instructions avant l'allocation de registres."
 
-#: common.opt:2449
+#: common.opt:2453
 #, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr "Réordonnancer les instructions après l'allocation de registres."
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Ordonnancer les instructions en utilisant l'algorithme d'ordonnancement sélectif."
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr "Exécuter l'ordonnancement sélectif après le rechargement."
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr "Exécuter les autodiagnostics en utilisant le chemin donné pour trouver les fichiers de tests."
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Réaliser la mise en pipeline logicielle des boucles internes durant l'ordonnancement sélectif."
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Réaliser la mise en pipeline logicielle des boucles externes durant l'ordonnancement sélectif."
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Réordonnancer les régions mises en pipeline sans la mise en pipeline."
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr "Permettre l'interposition des fonctions (ou des variables) par d'autres avec une sémantique différente (ou initialiseur) par l'éditeur de lien dynamique."
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr "Autoriser l'ordonnancement prématuré de insns dans la queue."
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<nombre>\tFixer le nombre d'insns dans la queue qui peuvent être prématurément ordonnancées."
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Définir la distance de vérification de la dépendance dans l'ordonnancement prématuré des insns dans la queue."
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<nombre>\tDéfinir la distance de vérification de la dépendance dans l'ordonnancement prématuré des insns dans la queue."
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Activer l'heuristique de groupe dans l'ordonnanceur."
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Activer l'heuristique du chemin critique dans l'ordonnanceur."
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Activer l'heuristique des instructions spéculatives dans l'ordonnanceur."
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Activer l'heuristique de rang dans l'ordonnanceur."
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Activer l'heuristique de la dernière instruction dans l'ordonnancement."
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Activer l'heuristique du décompte des dépendances dans l'ordonnanceur."
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr "Accéder au données dans la même section à partir du point d'ancrage partagé."
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Activer l'étape d'élimination des extensions redondantes."
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Afficher les numéros des colonnes dans les diagnostiques quand ils sont disponibles. Activé par défaut."
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Produire les prologues des fonctions uniquement devant les parties qui en ont besoin au lieu de les produire au début des fonctions."
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "Emballer séparément les parties du prologue et de l'épilogue."
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Désactiver les optimisations observables par les NaN (Not a Number: pas un nombre) IEEE si ces NaN produisent un effet visible."
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Désactiver les optimisations des virgules flottantes qui ignorent le signe du zéro défini par IEEE."
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr "Convertir les constantes en virgule flottante en constantes en simple précision."
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Scinder le temps de vie des variables d'induction quand des boucles sont dépliées."
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "Générer des trames de pile discontinues."
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr "Scinder les types larges dans des registres indépendants."
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr "Scinder les types larges dans des registres indépendants plus tôt."
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Activer la propagation vers le haut des propriétés d'utilisation au niveau SSA."
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr "Optimiser les motifs conditionnels utilisant les nœuds PHI SSA."
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Optimiser le nombre de registres stdarg sauvegardés sur la pile au début d'une fonction."
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Appliquer l'expansion des variables quand les boucles dont dépliées."
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tInsérer du code de vérification de la pile dans le programme."
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Insérer du code de vérification de la pile dans le programme. Identique à -fstack-check=specific."
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr "Insérer du code pour sonder chaque page de l'espace de la pile quand il est alloué pour protéger contre des attaques visant une collision de pile (stack-clash)."
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<registre>\tFaire un déroutement si la pile va au delà du <registre>."
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<nom>\tFaire un déroutement si la pile va au delà du symbole <nom>."
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "Utiliser ProPolice comme méthode de protection de la pile."
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr "Utiliser une méthode de protection de la pile pour chaque fonction."
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Utiliser une méthode intelligente de protection de la pile pour certaines fonctions."
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "N'utiliser une méthode de protection de la pile que sur les fonctions qui ont l'attribut stack_protection."
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr "Fournir les informations d'utilisation de la pile pour chaque fonction."
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr "Supposer que la règle selon laquelle une zone mémoire ne peut être accessible que par un seul pointeur (strict aliasing) s'applique."
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Traiter les débordements signés comme étant indéfinis. Inversé par -fwrapv -fwrapv-pointer."
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr "Implémenter les opérations __atomic via des appels de bibliothèque aux fonctions historiques __sync."
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr "Vérifier les erreurs de syntaxes et puis stopper."
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr "Créer les fichiers de données nécessaires à « gcov »."
 
 # Jump threading= des sauts consécutifs sont remplacés par un saut vers la cible finale
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr "Réaliser les optimisations d'enfilage des sauts."
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr "Rapporter le temps pris par chaque étape de la compilation."
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr "Enregistrer le temps pris par chaque sous-étape séparément."
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tDéfinir le modèle de génération de code par défaut pour le stockage local au thread."
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Réorganiser les fonctions, les variables et l'assembleur au plus haut niveau."
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr "Exécuter la formation du super bloc via la duplication de la queue."
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr "Pour les cibles qui requièrent normalement des trampolines pour les fonctions imbriquées, toujours les générer au lieu d'utiliser des descripteurs."
 
-#: common.opt:2722
+#: common.opt:2726
 #, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "Supposer que les opérations en virgule flottante peuvent générer des déroutements."
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Générer des déroutements pour les débordements signés dans les additions, soustractions et multiplications."
 
-#: common.opt:2730
+#: common.opt:2734
 #, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Activer les optimisations SSA-CCP sur les arbres."
 
-#: common.opt:2734
+#: common.opt:2738
 #, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Activer les optimisations SSA-BIT-CCP sur les arbres."
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr "Activer la copie des en-têtes de boucles sur les arbres."
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "Activer la coalescence SSA sur les variables utilisateur."
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr "Activer la propagation de copie sur les arbres."
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr "Transformer les stockages conditionnels en stockages inconditionnels."
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr "Réaliser la conversion des initialisations de « switch »."
 
-#: common.opt:2774
+#: common.opt:2778
 #, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Activer l'optimisation de l'élimination du code mort SSA sur les arbres."
 
-#: common.opt:2778
+#: common.opt:2782
 #, no-c-format
 msgid "Enable dominator optimizations."
 msgstr "Activer l'optimisation des dominateurs."
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "Activer la fusion des appels en fin de fonction (tail call) sur les arbres."
 
-#: common.opt:2786
+#: common.opt:2790
 #, no-c-format
 msgid "Enable dead store elimination."
 msgstr "Activer l'élimination des stockages morts."
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "Activer la propagation vers l'avant sur les arbres."
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Activer l'élimination redondante totale (Full Redundancy Elimination) sur les arbres."
 
-#: common.opt:2798
+#: common.opt:2802
 #, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "Activer l'optimisation des longueurs de chaînes sur les arbres."
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Détecter les chemins qui déclenchent un comportement erroné ou indéfini dû au déréférencement d'un pointeur nul. Isoler ces chemins du flux de contrôle principal et transformer les instructions avec un comportement erroné ou indéfini en instructions de déroutement."
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Détecter les chemins qui déclenchent un comportement erroné ou indéfini dû à une valeur nulle utilisée d'une manière interdite par l'attribut returns_nonnull ou nonnull. Isoler ces chemins du flux de contrôle principal et transformer l'instruction avec un comportement erroné ou indéfini en une instruction de déroutement."
 
-#: common.opt:2815
+#: common.opt:2819
 #, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "Activer la distribution des boucles sur les arbres."
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Activer la distribution des boucles pour les motifs transformés en appels de bibliothèque."
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr "Activer les mouvements invariants de boucles sur les arbres."
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr "Créer des variables d'induction canoniques dans les boucles."
 
-#: common.opt:2835
+#: common.opt:2839
 #, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr "Activer les optimisations de boucles au niveau de l'arbre."
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "-ftree-parallelize-loops=<number>\tActiver la parallélisation automatique des boucles."
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Activer la sortie hors des boucles des chargements par des pointeurs conditionnels."
 
-#: common.opt:2847
+#: common.opt:2851
 #, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Activer l'optimisation SSA-PRE sur les arbres."
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr "Dans l'optimisation SSA-PRE sur les arbres, activer l'élimination de la redondance partielle-partielle."
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Réaliser une analyse de ce qui est pointé, locale à la fonction, sur les arbres."
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr "Activer la réassociation au niveau de l'arbre."
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr "Activer la descente du code SSA sur les arbres."
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr "Exécuter la simplification des instructions dupliquées lors de l'aplatissage d'une boucle (Straight-Line Strength Reduction)."
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr "Exécuter le remplacement des scalaires des agrégats."
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Remplacer les expressions temporaires durant l'étape SSA->normale."
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Réaliser une scission de la portée active durant l'étape SSA->normale."
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr "Réaliser une propagation de la plage de valeurs sur les arbres."
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr "Scinder les chemins conduisant à des arêtes de retour d'une boucle."
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr "Supposer que les déclarations communes peuvent être remplacées par d'autres se terminant par un tableau plus grand."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr "Compiler une unité de compilation entière à la fois."
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Dérouler les boucles quand le nombre d'itérations est connu."
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr "Dérouler toutes les boucles."
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Autoriser l'optimisation de l'arithmétique en virgule flottante qui peut changer le résultat de l'opération à cause de l'arrondi."
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Identique à -fassociative-math pour les expressions contenant des divisions."
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Permettre les optimisations mathématiques qui peuvent violer les standards IEEE ou ISO."
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Déplacer les boucles à l'intérieur des branchements quand c'est possible."
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Scinder les boucles pour éliminer des conditions qui sont constantes sur une plage de la boucle (Loop Splitting)."
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr "Décliner les versions des boucles basées sur le fait que les indices ont un pas de un."
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Générer uniquement les tables de retour en arrière pour la gestion des exceptions."
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Utiliser l'éditeur de liens bfd au lieu de l'éditeur par défaut."
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Utiliser l'éditeur de liens gold au lieu de l'éditeur par défaut."
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Utiliser l'éditeur de liens lld de LLVM au lieu de l'éditeur par défaut."
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Réaliser le pistage des variables."
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Réaliser le pistage des variables en annotant les affectations."
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Basculer -fvar-tracking-assignments."
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Réaliser le pistage des variables et aussi étiqueter les variables qui ne sont pas initialisées."
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Activer la vectorisation sur les arbres."
 
-#: common.opt:3011
+#: common.opt:3015
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Activer la vectorisation des boucles sur les arbres."
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Activer la vectorisation des blocs de base (SLP) sur les arbres."
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpécifie le modèle de coût pour la vectorisation."
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpécifier le modèle de coût de la vectorisation pour du code marqué par la directive simd."
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Activer le modèle de coût du vectoriseur dynamique. Préservé pour rétro-compatibilité."
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Activer la propagation par copie des informations sur l'évolution scalaire."
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Ajouter des commentaires additionnels à la sortie de l'assembleur."
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tDéfinir la visibilité par défaut des symboles."
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "Valider les pointeurs dans la vtable avant de les utiliser."
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Sortir les compteurs de vérifications des vtables."
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Sortir les informations sur les ensembles de pointeurs pour la vérification des vtables."
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Utiliser les profils des valeurs des expressions dans les optimisations."
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Construire une toile et séparer les utilisations sans relations d'une variable seule."
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Activer l'élimination conditionnelle du code mort pour les appels internes."
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Réaliser les optimisations sur tout le programme."
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Supposer que le débordement de pointeur revient au départ."
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Supposer que le débordement de l'arithmétique signée boucle sur la plage accessible."
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Placer des données initialisées à zéros dans la section bss."
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr "Vider les registres utilisés dans l'appel lors du retour de fonction."
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Générer les informations de débogage dans le format par défaut."
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "Supposer que l'assembleur supporte les directives .loc (DWARF2+)."
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "Supposer que l'assembleur supporte les vues dans les directives .loc (DWARF2+)."
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Enregistrer DW_AT_decl_column et DW_AT_call_column dans DWARF."
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Générer les informations de débogage dans la version par défaut du format DWARF."
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Générer les informations de débogage dans le format DWARF v2 (ou ultérieur)."
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr "Utiliser le format DWARF 32 bits en émettant les informations de débogage DWARF."
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr "Utiliser le format DWARF 64 bits en émettant les informations de débogage DWARF."
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Générer les informations de débogage dans le format étendu par défaut."
 
-#: common.opt:3191
+#: common.opt:3195
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Générer des information étendues pour les points d'entrées des fonctions en ligne."
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr "Calculer les points de réinitialisation locview sur base des estimations des longueurs des insns."
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Ne pas générer les sections DWARF pubnames et pubtypes."
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Générer les sections DWARF pubnames et pubtypes."
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Générer les sections DWARF pubnames et pubtypes avec les extensions GNU."
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Enregistrer les options de la ligne de commande de gcc dans DW_AT_producer de DWARF."
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Générer les informations de débogage dans des fichiers .dwo séparés."
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Générer les informations de débogage dans le format STABS."
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Générer les informations de débogage dans le format STABS étendu."
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr "Émettre des emplacements de points d'arrêt progressifs recommandés"
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Ne pas produire les suppléments DWARF au delà de la version sélectionnée."
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr "Ajouter les attributs de description à certains DIEs DWARF qui n'ont pas d'attribut de nom."
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Inverser l'option actuelle de génération des informations de débogage."
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr "Augmenter les listes de positions de variables avec des vues progressives."
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Générer les informations de débogage dans le format VMS."
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Générer les informations de débogage dans le format XCOFF."
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Générer les informations de débogage dans le format XCOFF étendu."
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Générer des sections de débogage compressées."
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<format>\tGénérer les sections de débogage compressées dans le format <format>."
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<répertoire>\tDéfinir le <répertoire> comme étant le répertoire par défaut des modules externes."
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <répertoire>\tDéfinir le <répertoire> comme étant le sous-répertoire d'inclusion multiarch."
 
-#: common.opt:3320
+#: common.opt:3324
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <fichier>\tPlacer la sortie dans le <fichier>."
 
-#: common.opt:3324
+#: common.opt:3328
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Autoriser le profilage des fonctions."
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Comme -pedantic mais les avertissements sont rapportés comme des erreurs."
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Ne pas afficher les fonctions compilées ni le temps écoulé."
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Activer la sortie en mode bavard."
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Afficher la version du compilateur."
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Supprimer les avertissements."
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Créer une bibliothèque partagée."
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Ne pas créer un exécutable indépendant de la position dynamiquement lié."
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Créer un exécutable indépendant de la position dynamiquement lié."
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Créer un exécutable statique indépendant de la position."
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Faire sauvegarder les registres par l'appelant au travers des appels si possible."
@@ -19155,1106 +19157,1117 @@ msgstr "--param=evrp-mode=[legacy|ranger|legacy-first|ranger-first|ranger-trace|
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr "Le nombre maximum d'arguments qu'un PHI peut avoir avant que le FSM qui est responsable de l'enchaînement arrête d'essayer d'enchaîner les sauts dans ses blocs."
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr "Facteur d'échelle à appliquer au nombre de blocs dans un chemin de sauts enchaînés lors de la comparaison avec le nombre d'expressions (mises à l'échelle)."
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr "Facteur d'échelle à appliquer au nombre d'expressions dans un chemin de sauts enchaînés lors de la comparaison de blocs (mis à l'échelle)."
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "Le rapport seuil du décompte d'exécution des arêtes critiques qui permet l'élimination des redondances après rechargement."
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "Le rapport seuil pour réaliser l'élimination des redondances partielles après le rechargement."
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr "Facteur d'échelle dans le calcul de la distance maximale qu'une expression peut être déplacée par les optimisations de GCSE."
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr "Coût auquel les optimisations de GCSE ne contraindront pas la distance de déplacement d'une expression."
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "L'expansion minimale du tas pour lancer la collecte des rebuts, en pourcentage de la taille totale du tas."
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "La taille minimale du tas avant de commencer la collecte des rebuts, en kilooctets."
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr "Le nombre d'exécutions du bloc de base qui est considéré « chaud ». Le paramètre est utilisé uniquement avec GIMPLE FE."
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr "Est-ce que les erreurs codegen devraient produire des erreurs interne du compilateur (ICE) avec -fchecking."
 
-#: params.opt:206
+#: params.opt:211
 #, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr "Le nombre maximum de tableaux par SCoP."
 
-#: params.opt:210
+#: params.opt:215
 #, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr "Le nombre maximum de paramètres dans un SCoP."
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr "Le nombre d'éléments pour lesquels la vérification de la table de hachage est faite pour chaque élément cherché."
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "Le dénominateur n de la fraction 1/n du nombre d'exécutions maximum d'un bloc de base dans le programme entier qu'un bloc de base doit avoir pour au moins être considéré comme « chaud » (utilisé en mode non-LTO)."
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr "Le nombre de pour milles les plus exécutés de l'exécution profilée sur le programme entier dans lesquelles le nombre d'exécutions du bloc de base doit faire partie pour être considéré comme « chaud » (utilisé en mode LTO)."
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "Le dénominateur n de la fraction 1/n de la fréquence d'exécution du bloc d'entrée d'une fonction qu'un bloc de base de cette fonction doit avoir au moins pour être considéré comme « chaud »."
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr "L'échelle (en pourcents) appliquée à inline-insns-single et les limites auto quand l'heuristique indique que la mise en ligne est très profitable."
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr "L'estimation de l'accélération minimale permettant au code de mise en ligne d'ignorer inline-insns-single et inline-insns-auto."
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "Quelle croissance d'une unité de compilation peut être tolérée en raison de la mise en ligne (en pourcentage)."
 
-#: params.opt:242
+#: params.opt:247
 #, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "La limite supérieure pour partager des entiers constants."
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr "Le seuil de l'évaluation de l'opportunité de IPA-CP qui est encore considérée comme bénéfique au clone."
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr "Bonus à la compilation que IPA-CP assigne aux candidats qui rendent les limites ou les pas des boucles connus."
 
-#: params.opt:254
+#: params.opt:259
 #, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "La profondeur maximale de clonage récursif pour les fonctions auto-récursives."
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Cloner récursivement uniquement quand la probabilité qu'un appel soit exécuté excède le paramètre."
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr "Le pourcentage de pénalité que des fonctions récursives recevront quand elles seront évaluées pour un clonage."
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr "Le pourcentage de pénalité que des fonctions contenant un unique appel à une autre fonction recevront quand elles seront évaluées pour un clonage."
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "Quelle croissance d'une unité de compilation peut être tolérée à cause de la propagation interprocédurale de constantes (en pourcentage)."
 
-#: params.opt:274
+#: params.opt:279
 #, no-c-format
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "La taille d'une unité de traduction que l'étape IPA-CP considère comme grande."
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr "La taille maximale d'une liste de valeurs associées à chaque paramètre pour la propagation de constantes interprocédurale."
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr "Le nombre maximum d'instructions visitées durant la découverte de l'offset d'une fonction de saut."
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr "Le nombre maximum d'expressions qui seront visitées par l'analyse des paramètres formels de IPA basé sur l'analyse d'alias dans une fonction quelconque."
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr "Le nombre maximum d'éléments contenus dans un agrégat d'un paramètre dans des fonctions de saut ou des maillages."
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "Le nombre maximum d'opérations dans une expression de paramètre qui peut être traitée par l'analyse IPA."
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr "Le nombre maximum de prédicats différents utilisés pour garder une trace des propriétés des boucles dans l'analyse IPA."
 
 # Frédéric: Est-ce que la phrase en anglais veut dire quelque chose ?
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr "Le nombre maximum d'extrémités de frontière de plage de « case » dans une instruction « switch » utilisée durant la génération du résumé de la fonction IPA."
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr "Parties maximales que IPA-SRA suit par paramètre formel, par conséquent, est aussi le nombre maximum de remplacements d'un paramètre formel."
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr "La croissance maximale autorisée du nombre et de la taille totale des nouveaux paramètres que IPA-SRA remplace par un pointeur vers un agrégat."
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr "Le nombre de registres de chaque classe laissés inutilisés par les déplacements invariants au niveau des boucles."
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr "La taille max de la table des conflits en Mo."
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr "Le nombre max de boucles pour l'allocation de registre régional."
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "Si le nombre de candidats dans l'ensemble est plus petit, on essaie toujours de retirer les IV inutilisés durant son optimisation."
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "Limite sur le nombre de candidats en dessous de laquelle tous les candidats sont pris en compte dans les optimisations d'IV."
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "Limite sur le nombre d'utilisations d'IV dans une boucle optimisée dans des optimisations d'IV."
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr "Le rapport maximum d'augmentation de la taille du code lors de l'expansion en une table de sauts (en pourcent). Le paramètre est utilisé lors d'une optimisation pour la taille."
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr "Le rapport maximum d'augmentation de la taille du code lors de l'expansion en une table de sauts (en pourcent). Le paramètre est utilisé lors d'une optimisation pour la vitesse."
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr "La taille de ligne du cache L1."
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr "La taille du cache L1."
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr "La taille du cache L2."
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Croissance maximale due à la mise en ligne d'une grande fonction (en pourcentage)."
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr "La taille du corps d'une fonction à considérer comme étant grand."
 
-#: params.opt:366
+#: params.opt:371
 #, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "La taille de la trame de pile qui est considérée comme étant grande"
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Croissance maximale de la trame de pile causée par la mise en ligne (en pourcentage)."
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr "La taille d'une unité de traduction à considérer comme grande."
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr "Nombre maximum de fichiers de modules C++ ouverts simultanément lors du chargement paresseux."
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "Le coût minimum d'une expression onéreuse dans le déplacement d'un invariant de boucle."
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr "Vrai si une opération qui n'est pas un court-circuit est optimale."
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr "La taille des blocs pour le découpage de boucle en blocs (loop blocking)."
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "Le nombre maximum de stmts dans une boucle imbriquée pour l'échange de boucle."
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "Le rapport du pas minimum pour que l'échange de boucle soit profitable."
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr "Le nombre max de blocs de base dans une boucle pour un déplacement de boucle invariant."
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr "Le nombre maximum de datarefs dans une boucle pour construire les dépendances de données de la boucle."
 
-#: params.opt:410
+#: params.opt:415
 #, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "Le nombre maximum d'instructions dans une boucle interne qui est envisagée pour la déclinaison de version."
 
-#: params.opt:414
+#: params.opt:419
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "Le nombre maximum d'instructions dans une boucle externe qui est envisagée pour la déclinaison de version en plus des instruction dans la boucle interne."
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr "La probabilité minimale, en pourcents, qu'une arrête enchaîne immédiatement sur une autre pour décider d'ajouter un BB à un EBB d'héritage dans LRA."
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr "Le nombre maximum de pseudos rechargeables qui doivent être considérés pendant le déversement de pseudos qui ne peuvent pas être rechargés."
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr "La taille maximale d'une partition pour LTO (en instructions estimées)."
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr "nombre maximum de partitions LTO envoyées en parallèle dans le flux."
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr "La taille minimale d'une partition pour LTO (en instructions estimées)."
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr "Le nombre de partitions dans lesquelles il faudrait scinder le programme."
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "Le nombre maximum d'instructions à envisager de déplier en moyenne dans une boucle."
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr "Le nombre maximum de tentatives de combinaisons d'insns à combiner."
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "La profondeur maximum de boucles imbriquées que nous aplatissons complètement."
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Le nombre maximum de réductions d'une boucle simple qui est complètement aplatie."
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "Le nombre maximum d'insns d'une boucle complètement aplatie."
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "Le nombre maximum d'arêtes entrantes à considérer pour les sauts croisés."
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr "Le nombre maximum d'instructions que CSE traite avant vidange."
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr "La longueur maximale des chemins considérés dans cse."
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Les positions mémoire maximum enregistrées par cselib."
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr "Nombre max de marqueurs de débogage à étendre ou mettre en ligne."
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "Le nombre maximum d'instructions à considérer pour remplir un créneau de délai."
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "Le nombre maximum d'instructions à considérer pour trouver les informations correctes d'un registre actif."
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr "Le nombre maximum de stockages locaux actifs dans l'élimination des stockages morts de RTL."
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "Le nombre maximum de mises en ligne indirectes imbriquées réalisées par les premières mises en ligne."
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "Le nombre maximum de champs dans une structure avant que l'analyse de pointeur traite la structure comme une seule variable."
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr "Le nombre maximum de blocs de base sur le chemin de sauts enchaînés d'un automate à états finis."
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr "Le nombre maximum d'instructions à copier en dupliquant des blocs le long du chemin de sauts enchaînés d'un automate à états finis."
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "Le nombre maximum de nouveaux chemins pour enchaîner des sauts pour un automate à états finis."
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "Le rapport maximum entre les insertions et les suppressions d'expressions dans GCSE."
 
-#: params.opt:518
+#: params.opt:523
 #, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "La quantité maximale de mémoire à être allouée par GCSE, en kilooctets."
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "Le nombre maximum d'insns à dupliquer lors de la défactorisation des goto calculés."
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "Le facteur d'expansion maximum en copiant des blocs de base."
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr "Profondeur maximum de recherche dans l'arbre des dominateurs pour trouver des expressions à élever."
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "Le nombre maximum d'instructions lors de la mise en ligne automatique."
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "Le nombre maximum d'instructions qu'une fonction en ligne peut grandir par la mise en ligne récursive."
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "Le nombre maximum d'instructions qu'une fonction pas en ligne peut grandir par la mise en ligne récursive."
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "Le nombre maximum d'instructions dans une seule fonction éligible à la mise en ligne."
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr "Le nombre maximum d'instructions lors de la mise en ligne pour la taille."
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "Le nombre maximum d'instructions lors de la mise en ligne automatique de petites fonctions."
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "La profondeur maximum de mise en ligne récursive pour les fonctions en ligne."
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "La profondeur maximum de mise en ligne récursive pour les fonctions pas en ligne."
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Le nombre maximum d'opérations isl, 0 pour illimité"
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "Limite sur le coût d'une expression pour calculer le nombre d'itérations."
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "Limite le nombre d'itérations que l'algorithme d'analyse du nombre d'itérations évalue par la force brute."
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "Le nombre maximum d'expressions autorisées dans un bloc qui doit être dupliqué pour enchaîner des sauts."
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "Le nombre maximum de nœuds RTL qui peuvent être enregistrés comme dernière valeur du combinateur."
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "Le nombre maximum d'insns dans l'en-tête d'une boucle qui sont dupliquées par l'étape de copie des en-têtes de boucles."
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "Le nombre maximum de retours en arrière que l'ordonnanceur doit essayer lors de l'ordonnancement modulo d'une boucle."
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr "La longueur maximale de l'ensemble ANTIC partiel lors de la pré-optimisation de l'arbre."
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "Le nombre maximum de branches sur le chemin pour aplatir une séquence."
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "Le nombre maximum de dépliages pour aplatir une boucle."
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr "Le nombre maximum d'insns dans une boucle aplatie."
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "La longueur maximale de la liste des opération en attente d'ordonnancement."
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "Le nombre maximum de blocs dans une région à considérer pour l'ordonnancement interblocs."
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "Le nombre maximum d'insns dans une région à considérer pour l'ordonnancement interblocs."
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr "Profondeur maximum des chaînes de racines carrées à utiliser lors de la synthèse d'une élévation à la puissance par une constante réelle."
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "Le nombre maximum d’itérations de boucles qui sont prédites statiquement."
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "Le nombre maximum d'instructions à rechercher en arrière lors d'une recherche d'une recharge équivalente."
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Le nombre maximum d'insns dans un bloc de base pour considérer une conversion du if par RTL."
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr "Coût maximum admissible pour la séquence qui serait générée par l'étape de conversion des « if » du RTL pour un branchement qui est considéré comme prévisible."
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr "Coût maximum admissible pour la séquence qui serait générée par l'étape de conversion des « if » du RTL pour un branchement qui est considéré comme imprévisible."
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "Le nombre maximum d'itérations au travers du CFG pour étendre des régions."
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "Le délai conflictuel maximum pour qu'une insn soit prise en compte pour un déplacement spéculatif."
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "Le nombre maximum d'instructions prêtes à être expédiées qui doivent être prises en compte par l'ordonnanceur durant le premier passage de l'ordonnancement."
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr "La longueur maximale de la recherche dans les candidats pour la simplification des instructions dupliquées lors de l'aplatissage d'une boucle (Straight-Line Strength Reduction)."
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr "Le nombre maximum de may-defs visités lors d'une dévirtualisation spéculative."
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr "La profondeur de récursion maximum permise en interrogeant une propriété d'un nom SSA."
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "Le nombre maximum de stockages constants à fusionner dans l'étape de fusion des stockages."
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "Le nombre maximum de paires de stockage conditionnel qui peuvent être descendues."
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "Le nombre maximum de chaines de stockages à suivre en même temps dans l'étape de fusion des stockages."
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr "La quantité maximale de bbs similaires à comparer avec un bb."
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr "Le nombre maximum d'itérations du passage sur une fonction."
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr "Le nombre maximum de chaînes pour lesquelles l'optimisation de strlen conserve la longueur des chaînes."
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr "Nombre maximum d'arguments dans un PHI supporté par la conversion de « if » TREE à moins que la boucle soit marquée avec un pragma simd."
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Le nombre maximum de dépliages d'une boucle."
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "Le nombre maximum d'instructions à envisager de déplier dans une boucle."
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "Le nombre maximum d'insns d'une boucle qui est déplacée à l'intérieur de ses branchements."
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Le nombre maximum de déplacements d'une seule boucle à l'intérieur de ses branchements."
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "Si -fvariable-expansion-in-unroller est utilisé, le nombre maximum de fois qu'une variable individuelle sera développée pendant le dépliage de la boucle."
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr "La profondeur de récursion max pour développer les expressions de pistage de variables."
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr "La taille max de la liste des emplacements pour laquelle des opérations inverses devraient être ajoutées."
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr "La taille max des tables de hachage pour le pistage des variables."
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr "Nombre maximum de VALEURs traitées lors d'un appel à find_base_term."
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr "Le nombre maximum d'assertions à ajouter le long de l'arête par défaut d'une instruction switch pendant le VRP."
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "Le nombre minimum d'instructions concordantes à considérer pour les sauts croisés."
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Mettre en ligne récursif uniquement quand la probabilité que l'appel soit exécuté dépasse le paramètre."
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr "Le rapport min entre les insns et les pré-extractions pour activer la pré-extraction dans une boucle avec un nombre inconnu d'itérations."
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr "Le seuil minimum pour la probabilité qu'une instruction de condition semi-invariante déclenche un scindage de boucle"
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr "Le UID minimum à utiliser pour une insn qui n'est pas pour le débogage."
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr "La taille minimale des variables contribuant au partage d'un emplacement de pile quand il n'y a pas d'optimisation."
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "La probabilité minimum d'atteindre un bloc source pour l'ordonnancement spéculatif interblocs."
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "Si -ftree-vectorize est utilisé, la limite minimale de boucle d'une boucle prise en compte pour la vectorisation."
 
-#: params.opt:782
+#: params.opt:787
+#, fuzzy, no-c-format
+#| msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr "-fopenacc-kernels=[decompose|parloops]\tSpécifier le mode de gestion des constructions « kernels » OpenACC."
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr "Taille des fragments de l'ordonnanceur OMP pour des boucles parallélisées par parloops."
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Le nombre minimum d'itérations par thread d'une boucle parallélisée la plus à l'intérieur."
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tType d'ordonnancement de l'ordonnanceur OMP pour des boucles parallélisées par parloops."
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr "Probabilité maximum que l'entrée B8 d'une région scindée (en pourcent relatif à l'entrée B8 de la fonction) pour réaliser la mise en ligne partielle."
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "Estimation maximale de la conclusion des branches considérées prévisibles."
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr "Faut-il générer des indices de pré-extraction logicielle pour des pas non constants."
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "Le nombre d'insns exécutées avant que la pré-extraction soit terminée."
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr "Le rapport min entre les insns et les opérandes mémoire pour activer la pré-extraction dans une boucle."
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr "Le pas constant minimum au delà duquel il faut utiliser des indices de pré-extraction."
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr "Utiliser un ID de fonction interne dans la recherche de profilage."
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "La profondeur maximum de boucles imbriquées qu'il faut entièrement numéroter par valeur de manière optimiste."
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr "Le nombre maximum de désambiguïsations à réaliser par accès mémoire."
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "Limite sur la complexité des expressions dans l'analyseur d'évolution de scalaires."
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "Limite sur la taille des expressions utilisées dans l'analyseur d'évolution de scalaires."
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr "Fanion de contrôle du modèle de l'ordonnanceur avec pré-extraction automatique matérielle. Nombre de cycles d'anticipation que le modèle examine, la valeur « 0 » active uniquement l'heuristique de tri des instructions. Désactivé par défaut."
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr "Distance minimale entre un « store » et un « load » qui peuvent entrer en conflit."
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr "Quel algorithme de -fsched-pressure appliquer."
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "La probabilité minimale de succès de spéculation (en pourcent) de telle manière que l'insn spéculative sera ordonnancée."
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr "La probabilité minimale qu'une arête doit avoir pour que l'ordonnanceur sauvegarde son état d'un bout à l'autre."
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "Le nombre maximum d'instructions dans la liste « prêtes » qui sont considérées éligibles pour être renommées."
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr "La taille maximum de la fenêtre d'anticipation de l'ordonnanceur sélectif."
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "Le nombre maximum de fois qu'une insn peut être ordonnancée."
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr "Le nombre de pré-extractions qui peuvent se dérouler en même temps."
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr "Fréquence d'exécution relative du bloc cible (en pourcent) requis pour faire descendre (sink) une expression."
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "Le nombre de cycles que le « Swing Modulo Scheduler » prend en compte lorsqu'il vérifie les conflits en utilisant DFA."
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "Un seuil sur le nombre moyen d'itérations prises en compte par le « Swing Modulo Scheduler »."
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "Un facteur pour ajuster la limite supérieure que le « Swing Modulo Scheduler » utilise pour ordonnancer une boucle."
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr "La valeur minimum du décompte des étapes que le « Swing Modulo Scheduler » va générer."
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr "La taille maximale, en unité de stockage, d'un agrégat qui devrait être considéré pour une conversion scalaire lors d'une compilation pour l'espace."
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr "La taille maximale, en unité de stockage, d'un agrégat qui devrait être considéré pour une conversion scalaire lors d'une compilation pour la vitesse."
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr "Nombre maximum d'accès artificiels pour activer la propagation vers l'avant que le remplacement scalaire d'agrégats gardera pour une variable locale."
 
-#: params.opt:924
+#: params.opt:942
 #, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "Le nombre maximum d'affectations SSA_NAME à suivre en déterminant une valeur."
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "La limite inférieure pour qu'un tampon soit considéré pour être protégé contre l'écrasement de la pile."
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr "Taille de la protection de la pile exprimée comme une puissance de deux en octets."
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr "Intervalle durant lequel sonder la pile, exprimé comme une puissance de deux en octets."
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr "Autoriser l'étape de fusion des stockages à introduire des stockages non alignés s'il est légal de faire ainsi."
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr "Taille maximale d'une région de fusion de stockage unique en octets."
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "La rapport maximum entre la taille du tableau et les branchements du switch pour qu'une conversion du switch ait lieu."
 
-#: params.opt:952
+#: params.opt:970
 #, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "Le nombre maximum de bases stockées dans chaque arbre modref."
 
-#: params.opt:956
+#: params.opt:974
 #, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr "Le nombre maximum de références stockées dans chaque base modref."
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "Le nombre maximum d'accès stockés dans chaque référence modref."
 
-#: params.opt:964
+#: params.opt:982
 #, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr "Le nombre maximum de tests réalisées par la requête modref."
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr "La profondeur maximale de la recherche DFS utilisée par l'analyse d'évasion de modref."
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "Le nombre maximum de points d'évasion suivis par modref par nom SSA."
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr "La taille en octets au delà de laquelle des agrégats locaux au thread doivent être manipulés par les fonctions de journalisation au lieu de paires de save/restore."
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "Le pourcentage d'une fonction, pondéré par la fréquence d'exécution, qui doit être couvert par la formation de la trace. Utilisé lorsque le feedback par profilage n'est pas disponible."
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "Le pourcentage d'une fonction, pondéré par la fréquence d'exécution, qui doit être couvert par la formation de la trace. Utilisé lorsque le feedback par profilage est disponible."
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Croissance maximale du code par la duplication de queue (en pourcentage)."
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "Stopper la croissance anticipée si la probabilité des meilleures arêtes est inférieure à ce seuil (en pourcentage). Utilisé lorsque le feedback par profilage n'est pas disponible."
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "Stopper la croissance anticipée si la probabilité des meilleures arêtes est inférieure à ce seuil (en pourcentage). Utilisé lorsque le feedback par profilage est disponible."
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "Stopper la croissance renversée si la probabilité inverse des meilleures arêtes est inférieure à ce seuil (en pourcentage)."
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr "Fixe le nombre maximum d'instructions exécutées en parallèle dans un arbre ré-associé. Si 0, utilise l'heuristique dépendant de la cible."
 
-#: params.opt:1008
+#: params.opt:1026
 #, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "Produire une instrumentalisation spéciale pour les accès à des volatiles."
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr "Produire des appels instrumentalisés à __tsan_func_entry() et __tsan_func_exit()."
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr "Nombre maximum d'appels imbriqués pour rechercher une dépendance de contrôle pendant l'analyse d'une variable non initialisée."
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "Instruction prise en compte pour le prologue, l'épilogue et d'autres surcharges des fonctions."
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "Temps pris en compte pour le prologue, l'épilogue et d'autres surcharges des fonctions."
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr "Instruction prise en compte pour la surcharge du fragment d'une fonction."
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr "Temps pris en compte pour la surcharge du fragment d'une fonction."
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr "Le dénominateur n de la fraction 1/n du nombre d'exécutions profilées sur le programme entier en dessous duquel le nombre d'exécutions d'un bloc de base doit se trouver afin que le bloc de base soit considéré comme improbable."
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr "Facteur de déroulement maximum pour le unroll-and-jam"
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr "Pourcentage minimum de memrefs qui doit être éliminé pour que le unroll-and-jam soit estimé profitable."
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr "Utiliser des instructions d'empoisonnement/dés-empoisonnement direct pour les variables plus petites ou égales à ce nombre."
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr "Faut-il utiliser les types canoniques."
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "Activer la vectorisation de l'épilogue d'une boucle en utilisant une taille de vecteur plus petite."
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr "Le nombre maximum d'aplatissages de boucles pour améliorer l'alignement des références aux données dans une boucle."
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "Limite sur le nombre de vérifications à l'exécution pour détecter les pointeurs qui se recouvrent (pointer aliasing) que le code qui décline les versions des boucles vectorisées doit insérer."
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Limite sur le nombre de vérifications à l'exécution de l'alignement que le code qui décline les versions des boucles vectorisées doit insérer."
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr "Contrôle comment le vectoriseur de boucle utilise des vecteurs partiels.  0 signifie jamais, 1 signifie uniquement pour les boucles dont le besoin d'itérer peut être retiré, 2 signifie pour toutes les boucles. La valeur par défaut est 2."
@@ -20285,7 +20298,7 @@ msgid "expected boolean type"
 msgstr "type booléen attendu"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "entier attendu"
@@ -20349,7 +20362,7 @@ msgstr "pas assez d'arguments"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "trop d'arguments"
@@ -20704,7 +20717,7 @@ msgstr "l'attribut %qE est ignoré car il est en conflit avec l'attribut %qs"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "déclaration précédente ici"
@@ -20759,7 +20772,7 @@ msgstr "les attributs de type sont ignorés après que le type ait déjà été
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -20788,20 +20801,20 @@ msgstr "les attributs de type sont ignorés après que le type ait déjà été
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -20812,8 +20825,8 @@ msgstr "attribut %qE ignoré"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "attribut %<target%> manquant pour %qD avec plusieurs versions"
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "déclaration précédente de %qD"
@@ -20823,59 +20836,59 @@ msgstr "déclaration précédente de %qD"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "les attributs appliqués à %qT après sa définition sont ignorés"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D déjà déclaré avec l'attribut dllexport: dllimport est ignoré"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D redéclaré sans l'attribut dllimport après avoir été référencé avec une liaison pour une dll"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D redéclaré sans l'attribut dllimport: le dllimport précédent est ignoré"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "fonction « inline » %q+D déclarée en tant que dllimport: attribut ignoré"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "la définition de la fonction %q+D est marquée dllimport"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "la définition de la variable %q+D est marquée dllimport"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "classe de liaison externe requise pour le symbole %q+D en raison de l'attribut %qE"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qE implique la visibilité par défaut mais %qD a déjà été déclaré avec une visibilité différente"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] "%qD spécifie un attribut plus restrictif que sa cible %qD: %s"
 msgstr[1] "%qD spécifie des attributs plus restrictifs que sa cible %qD: %s"
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "cible %qD déclarée ici"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -20977,7 +20990,7 @@ msgstr "l'argument référencé est déclaré ici"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "le décalage %qwi est hors des limites de la chaîne constante"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE déclaré ici"
@@ -21002,720 +21015,720 @@ msgstr "le troisième argument de %<__builtin_prefetch%> doit être une constant
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "le troisième argument de %<__builtin_prefetch%> est invalide; utilisation de zéro"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "%K%qD la limite spécifiée %E peut excéder la taille maximale de l'objet %E"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "%K%qD la limite spécifiée %E excède la taille maximale de l'objet %E"
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "%Kla limite spécifiée %E peut excéder la taille maximale de l'objet %E"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr "%Kla limite spécifiée %E excède la taille maximale de l'objet %E"
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "%K%qD la limite spécifiée [%E, %E] peut excéder la taille maximale %E de l'objet"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr "%K%qD la limite spécifiée [%E, %E] excède la taille maximale %E de l'objet"
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "%Kla limite spécifiée [%E, %E] peut excéder la taille maximale %E de l'objet"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "%Kla limite spécifiée [%E, %E] excède la taille maximale %E de l'objet"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr "%K%qD la limite spécifiée %E peut excéder la taille de la source %E"
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr "%K%qD la limite spécifiée %E excède la taille de la source %E"
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr "%Kla limite spécifiée %E peut excéder la taille de la source %E"
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr "%Kla limite spécifiée %E excède la taille de la source %E"
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr "%K%qD la limite spécifiée [%E, %E] peut excéder la taille de la source %E"
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr "%K%qD la limite spécifiée [%E, %E] excède la taille de la source %E"
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr "%Kla limite spécifiée [%E, %E] peut excéder la taille de la source %E"
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr "%Kla limite spécifiée [%E, %E] excède la taille de la source %E"
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, gcc-internal-format
 msgid "source object declared here"
 msgstr "l'objet source déclaré ici"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr "objet source alloué ici"
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "%K%qD la taille %E spécifiée peut excéder la taille maximale %E de l'objet"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr "%K%qD la taille %E spécifiée excède la taille maximale %E de l'objet"
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "%Kla taille %E spécifiée peut excéder la taille maximale %E de l'objet"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr "%Kla taille %E spécifiée excède la taille maximale %E de l'objet"
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "%K%qD la taille spécifiée entre %E et %E peut excéder la taille maximale %E de l'objet"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD la taille spécifiée entre %E et %E excède la taille maximale %E de l'objet"
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "%Kla taille spécifiée entre %E et %E peut excéder la taille maximale %E de l'objet"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr "%Kla taille spécifiée entre %E et %E excède la taille maximale %E de l'objet"
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr "%K%qD la limite spécifiée %E peut excéder la taille de la destination %E"
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr "%K%qD la limite spécifiée %E excède la taille de la destination %E"
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr "%Kla limite spécifiée %E peut excéder la taille de la destination %E"
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr "%Kla limite spécifiée %E excède la taille de la destination %E"
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr "%K%qD la limite spécifiée [%E, %E] peut excéder la taille de la destination %E"
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr "%K%qD la limite spécifiée [%E, %E] excède la taille de la destination %E"
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr "%Kla limite spécifiée [%E, %E] excède la taille de la destination %E"
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, gcc-internal-format
 msgid "destination object declared here"
 msgstr "l'objet de destination déclaré ici"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, gcc-internal-format
 msgid "destination object allocated here"
 msgstr "l'objet de destination alloué ici"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr "%K%qD peut accéder %E octet dans une région de taille %E"
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr "%K%qD accède %E octet dans une région de taille %E"
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr "%K%qD peut accéder %E octets dans une région de taille %E"
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr "%K%qD accède %E octets dans une région de taille %E"
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr "%Kpeut accéder %E octet dans une région de taille %E"
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr "%Kaccède %E octet dans une région de taille %E"
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr "%Kpeut accéder %E octets dans une région de taille %E"
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr "%Kaccède %E octets danss une région de taille %E"
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr "%K%qD peut accéder %E octets ou plus dans une région de taille %E"
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr "%K%qD accède %E octets ou plus dans une région de taille %E"
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr "%Kpeut accéder %E octets ou plus dans une région de taille %E"
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr "%Kaccède %E octets ou plus dans une région de taille %E"
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr "%K%qD peut accéder entre %E et %E octets dans une région de taille %E"
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr "%K%qD accède entre %E et %E octets dans une région de taille %E"
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr "%Kpeut accéder entre %E et %E octets dans une région de taille %E"
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr "%Kaccède entre %E et %E octets dans une région de taille %E"
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr "%K%qD peut écrire %E octet dans une région de taille %E"
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr "%K%qD écrire %E octet dans une région de taille %E déborde de la destination"
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr "%K%qD peut écrire %E octets dans une région de taille %E"
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: l'écriture de %E octets dans une région de taille %E déborde de la destination"
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr "%Kpeut écrire %E octet dans une région de taille %E"
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr "%Kl'écriture de %E octet dans une région de taille %E déborde de la destination"
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr "%Kpeut écrire %E octets dans une région de taille %E"
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr "%Kl'écriture de %E octets dans une région de taille %E déborde de la destination"
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr "%K%qD peut écrire %E octets ou plus dans une région de taille %E"
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr "%K%qD l'écriture de %E octets ou plus dans une région de taille %E déborde de la destination"
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr "%Kpeut écrire %E octets ou plus depuis une région de taille %E"
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr "%Kl'écriture de %E octets ou plus dans une région de taille %E déborde de la destination"
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr "%K%qD peut écrire entre %E et %E octets dans une région de taille %E"
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD écrire entre %E et %E octets dans une région de taille %E déborde de la destination"
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr "%Kpeut écrire entre %E et %E octets dans une région de taille %E"
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%Kécrire entre %E et %E octets dans une région de taille %E déborde de la destination"
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr "%K%qD peut lire %E octet depuis une région de taille %E"
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr "%K%qD lecture de %E octet depuis une région de taille %E"
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr "%K%qD peut lire %E octets depuis une région de taille %E"
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr "%K%qD lecture de %E octets depuis une région de taille %E"
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr "%Kpeut lire de %E octet depuis une région de taille %E"
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr "%Klecture de %E octet depuis une région de taille %E"
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr "%Kpeut lire %E octets depuis une région de taille %E"
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr "%Klecture de %E octets depuis une région de taille %E"
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr "%K%qD peut lire %E octets ou plus depuis une région de taille %E"
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr "%K%qD lecture de %E octets ou plus depuis une région de taille %E"
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr "%Kpeut lire %E octets ou plus depuis une région de taille %E"
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr "%Klecture de %E octets ou plus depuis une région de taille %E"
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr "%K%qD peut lire entre %E et %E octets depuis une région de taille %E"
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr "%K%qD lecture entre %E et %E octets depuis une région de taille %E"
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr "%Kpeut lire entre %E et %E octets depuis une région de taille %E"
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr "%Klecture entre %E et %E octets depuis une région de taille %E"
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] "%K%qD attend %E octet dans une région de taille %E"
 msgstr[1] "%K%qD attend %E octets dans une région de taille %E"
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] "%Kattend %E octet dans une région de taille %E"
 msgstr[1] "%Kattend %E octets dans une région de taille %E"
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr "%K%qD attend %E octets ou plus dans une région de taille %E"
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr "%Kattend %E octets ou plus dans une région de taille %E"
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr "%K%qD attend entre %E et %E octets dans une région de taille %E"
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr "%Kattend entre %E et %E octets dans une région de taille %E"
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr "à l'offset %s dans l'objet destination %qE de taille %s"
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr "l'objet destination %qE de taille %s"
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr "à l'offset %s dans l'objet destination d'une taille %s alloué par %qE"
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr "l'objet destination avec la taille %s alloué par %qE"
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr "à l'offset %s dans l'objet source %qE de taille %s"
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr "l'objet source %qE de taille %s"
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr "à l'offset %s dans l'objet source de taille %s alloué par %qE"
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr "l'objet source de taille %s alloué par %qE"
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr "%K%qD la limite %E spécifiée est égale à la taille de la destination"
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "trop peu d'arguments pour la fonction %<va_start%>"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "argument invalide pour %qD"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "argument non supporté par %qD"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr "appeler %qD avec un argument non nul n'est pas sûr"
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "les deux arguments de %<__builtin___clear_cache%> doivent être des pointeurs"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "trampoline généré pour la fonction imbriquée %qD"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD a changé de sémantique dans GCC 4.4"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "spécificateur d'architecture inconnu dans le modèle mémoire de la fonction interne"
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "argument de modèle mémoire invalide dans la fonction interne"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "le modèle mémoire en cas d'échec ne peut pas être plus fort que le modèle mémoire en cas de succès pour %<__atomic_compare_exchange%>"
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "modèle mémoire en cas d'échec invalide pour %<__atomic_compare_exchange%>"
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "modèle mémoire invalide pour %<__atomic_load%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "modèle mémoire invalide pour %<__atomic_store%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr "argument 1 non constant pour %qs"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, gcc-internal-format
 msgid "non-integer argument 1 to %qs"
 msgstr "argument 1 non entier pour %qs"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "%<__builtin_thread_pointer%> n'est pas supporté sur cette cible"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "%<__builtin_set_thread_pointer%> n'est pas supporté sur cette cible"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr "%qs est seulement supporté dans du code OpenACC"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr "argument non constant 0 pour %qs"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr "argument 0 invalide pour %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kutilisation invalide de %<__builtin_va_arg_pack ()%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kutilisation invalide de %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "le deuxième argument de %<__builtin_longjmp%> doit être 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "le format cible ne supporte pas l'infini"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> utilisé dans une fonction ayant des arguments fixes"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "nombre erroné d'arguments pour la fonction %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> appelé sans argument"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "nombre erroné d'arguments pour la fonction %<__builtin_next_arg%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "le deuxième paramètre de %<va_start%> n'est pas le dernier argument nommé"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "le comportement est indéfini quand le second paramètre de %<va_start%> est déclaré avec le stockage %<register%>"
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kle premier argument de %qD doit être un pointeur et le second une constante entière"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Kle dernier argument de %qD n'est pas une constante entière entre 0 et 3"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr "%K%qD appelé sur le pointeur %qE avec l'offset%s non nul"
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "déclaré ici"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, gcc-internal-format
 msgid "returned from %qD"
 msgstr "retourné depuis %qD"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, gcc-internal-format
 msgid "returned from %qT"
 msgstr "retourné depuis %qT"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, gcc-internal-format
 msgid "obtained here"
 msgstr "obtenu ici"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr "%K%qD appelé sur l'objet %qD non alloué"
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr "%K%qD appelé sur un pointeur vers un objet %qE non alloué"
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, gcc-internal-format
 msgid "assigned here"
 msgstr "assigné ici"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr "%K%qD appelé sur un pointeur retourné depuis une fonction d'allocation inappropriée"
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr "%K%qD appelé sur un pointeur vers un objet non alloué"
@@ -22479,302 +22492,302 @@ msgstr "les blocs de base n'ont pas été disposés consécutivement"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "le nombre d'annotations des bb dans la chaîne des insn (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "le nombre d'arêtes de l'appelant est invalide"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr "appel indirect manquant dans la séquence d'appel spéculative"
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr "l'appel indirect dans la séquence d'appel spéculative n'a pas le fanion spéculatif"
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr "les arrêtes spéculatives ne sont pas adjacentes"
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr "l'appel direct à %s dans la séquence d'appel spéculative n'a pas de fanion spéculatif"
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr "l'appel direct à %s dans une séquence d'appel spéculative a speculative_id %i hors limites"
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr "appel direct dupliqué pour %s dans la séquence d'appel spéculative avec speculative_id %i"
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr "le hachage de l'instruction d'appel ne pointe pas vers la première arrête directe de la séquence d'appel spéculative"
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr "référence %s dupliquée dans la séquence d'appel spéculative avec speculative_id %i"
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "appel direct manquant pour la spéculation %i"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "référence manquante pour la spéculation %i"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr "le nombre de cibles spéculatives %i est en désaccord avec num_speculative_call_targets %i"
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "champ aux défini pour l'arête %s->%s"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "décompte cgraph invalide"
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "clone en ligne dans la même liste du groupe comdat"
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "le nombre de clones en ligne n'est pas compatible"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "tp_first_run doit être non négatif"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "les symboles locaux doivent être définis"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "clone en ligne visible depuis l'extérieur"
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "clone en ligne avec l'adresse prise"
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "le clone en ligne est forcé à sortir"
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr "calls_comdat_local est défini en dehors d'un groupe comdat"
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr "fanion calls_comdat_local invalide"
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "l'attribut malloc devrait être utilisé pour une fonction qui retourne un pointeur"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "champ aux défini pour une arête indirecte depuis %s"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "le décompte d'arêtes n'est pas compatible avec le décompte de fonction"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Une arête indirecte depuis %s n'est pas marquée comme indirecte ou a un indirect_info associé, l'instruction correspondante est: "
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr "l'arête a, à la fois, call_stmt et lto_stmt_uid définis"
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "la fonction locale comdat est appelée par %s en dehors de son comdat"
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "le pointeur inlined_to est faux"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "appelants en ligne multiples"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "pointeur inlined_to défini pour des appelants pas en ligne"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "le décompte des arêtes de l'appelant ne correspond pas au décompte du BB"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "le décompte des appels indirects ne correspond pas au décompte du BB"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr "la référence a, à la fois, stmt et lto_stmt_uid définis"
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "le pointeur inlined_to est défini mais aucun prédécesseur trouvé"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "le pointeur inlined_to fait référence à lui même"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "le cgraph_node a un mauvais clone_of"
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "le cgraph_node a une mauvaise liste de clones"
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "le cgraph_node est dans la liste des clones mais il n'est pas un clone"
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "le cgraph_node a un mauvais pointeur prev_clone"
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "la liste doublement liée des clones est corrompue"
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "L'alias a des arêtes d'appel"
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "L'alias a une référence qui n'est pas un alias"
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "L'alias a plus d'une référence alias"
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "L'alias analysé n'a pas de référence"
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Pas d'arête hors du nœud du fragment"
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Plus d'une arête sortante hors du nœud du fragment"
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Le fragment n'est pas supposé avoir un contenu"
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt partagé:"
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "l'arête pointe vers la mauvaise déclaration:"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "une arête indirecte avec un appelé inconnu correspondant à un call_stmt avec une déclaration connue:"
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "arête callgraph manquante pour l'appel stmt:"
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "référence à une instruction morte"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "l'arête %s->%s n'a pas de call_stmt correspondant"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "une arête indirecte depuis %s n'a pas de call_stmt correspondant"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr "origine manquante pour un nœud dans une liste imbriquée"
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "l'origine pointe vers un parent différent"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node a échoué"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s: la section %s.%d est manquante"
@@ -22855,12 +22868,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "l'attribut %<weakref%> est ignoré car la variable est initialisée"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F utilisé mais jamais défini"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F déclaré %<static%> mais jamais défini"
@@ -22930,7 +22943,7 @@ msgstr "la valeur retournée par %q+D a une taille de %u octets"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "la taille de la valeur retournée par %q+D est supérieure à %wu octets"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "des nœuds ont été trouvé avec une mémoire non libérée"
@@ -23337,12 +23350,12 @@ msgstr "ignore l'option %<-fopt-info-%s%> qui entre peut-être en conflit"
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr "les personnalités EH multiples sont uniquement supportées avec les assembleurs qui supportent la directive %<.cfi_personality%>"
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr "%<-gdwarf-6%> est émis sous la version 5 avec des incompatibilités"
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "UNSPEC non délégitimisé %s (%d) trouvé à l'emplacement de la variable"
@@ -23362,7 +23375,7 @@ msgstr "rtx partagé"
 msgid "internal consistency failure"
 msgstr "défaut d'inconsistance interne"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn utilisé là où emit_jump_insn est attendu :\n"
@@ -23492,42 +23505,42 @@ msgstr "n'a pu fermer le fichier de vidange des insn finales %qs: %m"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "la constante de grande taille en virgule fixe a été tronquée implicitement en un type en virgule fixe"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparaison est toujours %d en raison de la largeur du champ de bits"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "suppose qu'un débordement signé n'a pas lieu quand le test de la plage est simplifié"
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "comparaison est toujours %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "un %<or%> de tests de non égalités non appariés est toujours 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "un %<and%> de tests d'égalités mutuellement exclusifs est toujours 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "suppose qu'un débordement signé n'a pas lieu lorsque la constante dans la comparaison est réduite"
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "suppose qu'un débordement signé n'a pas lieu lorsque des constantes sont combinées autour d'une comparaison"
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vérification fold: arbre originale modifié par fold"
@@ -23542,7 +23555,7 @@ msgstr "la taille totale %wu des objets locaux dépasse le maximum %wu"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "la taille totale des objets locaux dépasse le maximum %wu"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "contrainte impossible dans %<asm%>"
@@ -24160,7 +24173,7 @@ msgstr "déréférencement d'un pointeur null"
 msgid "function may return address of local variable"
 msgstr "la fonction peut retourner l'adresse d'une variable locale"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "la fonction retourne l'adresse d'une variable locale"
@@ -24526,53 +24539,53 @@ msgstr "la limite spécifiée %wu dépasse la taille %wu de l'objet de destinati
 msgid "%Gnull format string"
 msgstr "%Gchaîne de format nulle"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 msgid "%Guse of %<alloca%>"
 msgstr "%Gutilisation de %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 msgid "%Gargument to variable-length array may be too large"
 msgstr "%Gl'argument vers un tableau de longueur variable peut être trop grand"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "%Gl'argument vers %<alloca%> peut être trop grand"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr "la limite est %wu octets mais l'argument peut être aussi grand que %s"
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 msgid "%Gargument to variable-length array is too large"
 msgstr "%Gl'argument vers un tableau de longueur variable est trop grand"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "%Gl'argument vers %<alloca%> est trop grand"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr "la limite est %wu octets mais l'argument a %s"
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 msgid "%Gunbounded use of variable-length array"
 msgstr "%Gutilisation d'un tableau de longueur variable sans limite"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "%Gutilisation de %<alloca%> sans limite"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "%Gutilisation de %<alloca%> dans une boucle"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 msgid "%Gargument to variable-length array is zero"
 msgstr "%Gl'argument d'un tableau de longueur variable est zéro"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 msgid "%Gargument to %<alloca%> is zero"
 msgstr "%Gl'argument de %<alloca%> est zéro"
 
@@ -24686,7 +24699,7 @@ msgstr "%G%qD la limite spécifiée entre %wu et %wu excède la taille maximale
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr "%G%qD subit un débordement de pointeur entre le décalage %s et la taille %s en accédant au tableau %qD avec le type %qT"
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "tableau %qD déclaré ici"
@@ -24712,11 +24725,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "%G%qD le décalage %s est hors des limites de l'objet %qD avec le type %qT"
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD déclaré ici"
@@ -24792,311 +24805,311 @@ msgstr "l'attribut %<fallthrough%> ne précède pas un « case » ou un « de
 msgid "using result of function returning %<void%>"
 msgstr "utilisation du résultat d'une fonction qui retourne %<void%>"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr "la sortie %d qui n'est pas une zone mémoire doit rester en mémoire"
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "l-valeur invalide dans la sortie %<asm%> %d"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "l'entrée %d qui n'est pas une zone mémoire doit rester en mémoire"
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "l'entrée mémoire %d n'est pas directement adressable"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "la variable privée au thread %qE est utilisée dans une région avec la clause %<order(concurrent)%>"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, gcc-internal-format
 msgid "enclosing region"
 msgstr "région englobante"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "la variable privée au thread %qE est utilisée dans la région cible"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "région cible englobante"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "la variable privée au thread %qE est utilisée dans une tâche non liée"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "tâche englobante"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE non spécifié dans la région %qs englobante"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "région %qs englobante"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE non spécifié dans la construction OpenACC %qs englobante"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "construction OpenACC %qs englobante"
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE avec une clause %<link%> utilisée dans une fonction %<routine%>"
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE requiert une directive %<declare%> pour l'utilisation dans une fonction %<routine%>"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "%qE non spécifié dans le %<target%> englobant"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr "%<target%> englobant"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "la variable %qE est déclarée dans une région %<host_data%> englobante"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD est référencé dans une région cible qui n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "la variable d'itération %qE est prédéterminée linéaire"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "la variable d'itération %qE devrait être privée"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "la variable d'itération %qE ne devrait pas être « firstprivate »"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "la variable d'itération %qE ne devrait pas être une réduction"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "la variable d'itération %qE ne devrait pas être linéaire"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr "clause %<lastprivate%> conditionnelle sur la construction %qs"
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "variable non scalaire %qD dans la clause %<lastprivate%> conditionnelle"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr "modificateur de réduction %<task%> sur une construction avec une clause %<nowait%>"
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr "modificateur de réduction %<task%> invalide sur une construction autre que %<parallel%>, %qs ou %<sections%>"
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "clause %<inscan%> %<reduction%> sur la construction %qs"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "la clause %<linear%> pour une variable autre qu'un itérateur de boucle est spécifiée sur une construction combinée avec %<distribute%>"
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "champ de correspondance %qE d'une structure de longueur variable"
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE apparaît plus d'une fois dans la clause de correspondance (map)"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "la variable « copyprivate » %qE n'est pas « threadprivate » ou privée dans le contexte extérieur"
 
 # le %s est remplacé par des mots-clé non traduits tels que « firstprivate », « lastprivate »,…
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "la variable « %s » %qE est privée dans le contexte extérieur"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "modificateur de clause %qs %<if%> attendu au lieu de %qs"
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr "%qD est spécifié dans la clause %qs mais pas dans la clause %<inscan%> %<reduction%> sur la construction contenante"
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD dans la clause implicite %<map%>"
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD dans la clause implicite %<firstprivate%> dans la construction %<target%>"
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD dans la clause %<firstprivate%> dans la construction %<target%>"
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "la même variable est utilisée dans les clauses %<firstprivate%> et %<lastprivate%> dans la construction %<distribute%>"
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "clause de données avec réduction sur %qE incompatible; promu en %<present_or_copy%>"
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr "%qD spécifié dans la clause %<inscan%> %<reduction%> mais dans dans la clause directive %<scan%>"
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "réduction privée invalide sur %qE"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "la clause %<inscan%> %<reduction%> est utilisée avec la clause %<linear%> pour une variable autre qu'un itérateur de boucle"
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "type %<mutexinoutset%> dans la clause %<depend%> sur un constructeur %<taskwait%>"
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr "la clause %qs ne peut pas apparaître sur %qs non rectangulaire"
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "le %<lastprivate%> conditionnel sur l'itérateur de boucle %qD est ignoré"
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "la clause %<bind%> n'est pas spécifiée sur une construction %<loop%> pas imbriquée dans une autre construction OpenMP"
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "%<bind(parallel)%> sur une construction %<loop%> imbriquée dans une construction %<simd%>"
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "%<bind(team)%> sur une région %<loop%> pas strictement imbriquée dans une région %<team%>"
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "la clause %<lastprivate%> sur une construction %<loop%> fait référence à une variable %qD qui n'est pas l'itérateur de boucle"
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "une construction %<ordered%> avec une clause %<depend%> doit être étroitement imbriquée dans une boucle avec une clause %<ordered%> avec un paramètre"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "la variable %qE n'est pas une itération de la boucle %d la plus à l'extérieur, %qE attendu"
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "le nombre de variables dans la clause %<depend%> avec le modificateur %<sink%> ne correspond pas au nombre de variables d'itérations"
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "plus d'une clause %<depend%> avec le modificateur %<source%> sur une construction %<ordered%>"
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "une clause %<depend%> avec le modificateur %<source%> a été spécifiée avec des clauses %<depend%> avec le modificateur %<sink%> sur la même construction"
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "la gimplification a échoué"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT a été promu en %qT lors du passage à travers %<...%>"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(vous devriez donc passer %qT et non %qT à %<va_arg%>)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si ce code est atteint, le programme s'arrêtera"
@@ -25545,22 +25558,22 @@ msgstr "Fonction %qs, paramètre %u, a des accès IPA-SRA qui se chevauchent"
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr "Fonction %s, paramètre %u, est utilisée mais n'a pas certains accès IPA-SRA"
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s ne peut être utilisé dans %<asm%> ici"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr "un pointeur de trame est requis, mais il est réservé"
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr "pour %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "taille de trame trop grande pour une vérification fiable de la pile"
@@ -25580,12 +25593,12 @@ msgstr "l'opérande %<asm%> a des contraintes impossibles"
 msgid "unable to find a register to spill"
 msgstr "impossible de trouver un registre à déverser"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "contraintes d'opérande inconsistantes dans un %<asm%>"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "le nombre maximum d'insns de rechargement générées par insn est atteint (%d)"
@@ -26294,12 +26307,12 @@ msgstr "l'argument de %qs n'est pas entre %d et %d"
 msgid "unrecognized argument in option %qs"
 msgstr "argument non reconnu pour l'option %qs"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "les arguments valables pour %qs sont: %s; vouliez vous utiliser %qs ?"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "les arguments valables pour %qs sont: %s"
@@ -26424,7 +26437,7 @@ msgstr "la mémoire transactionnelle n'est pas supportée avec des exceptions sa
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr "les ancres de sections doivent être désactivées quand la réorganisation au plus haut niveau est désactivée"
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> ne fonctionne pas avec les exceptions sur cette architecture"
@@ -26926,22 +26939,22 @@ msgstr "les registres explicitement utilisés doivent être groupés en haut de
 msgid "output operand %d must use %<&%> constraint"
 msgstr "l'opérande de sortie %d doit utiliser la contrainte %<&%>"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "%qs: [%u] %<next_regno%> erroné pour une chaîne vide (%u)"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "%qs: boucle dans la chaîne %<next_regno%> (%u)"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "%qs: [%u] %<oldest_regno%> erroné (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr "%qs: [%u] registre non vide dans la chaîne (%s %u %i)"
@@ -27004,12 +27017,12 @@ msgstr "ne peut recharger l'opérande constante entière dans %<asm%>"
 msgid "impossible register constraint in %<asm%>"
 msgstr "contrainte de registre impossible dans %<asm%>"
 
-#: reload.c:2687
+#: reload.c:2692
 #, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "cette cible ne supporte pas %<asm goto%> avec les sorties dans %<asm%>"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "contrainte %<&%> utilisée sans classe de registre"
@@ -27040,52 +27053,52 @@ msgstr "la contrainte de l'opérande %<asm%> est incompatible avec la taille de
 msgid "output operand is constant in %<asm%>"
 msgstr "l'opérande de sortie est une constante dans %<asm%>"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "vérification RTL: accès à elt %d de « %s » avec le dernier elt %d dans %s, à %s:%d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "vérification RTL: elt %d attendu de type « %c », a « %c » (rtx %s) dans %s, à %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "vérification RTL: elt %d attendu de type « %c » ou « %c », a trouvé « %c » (rtx %s) dans %s, à %s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "vérification RTL: code attendu « %s », a trouvé « %s » dans %s, à %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "vérification RTL: code attendu « %s » ou « %s », a trouvé « %s » dans %s, à %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "vérification RTL: code attendu « %s », « %s » ou « %s », a trouvé « %s » dans %s, à %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "vérification RTL: tentative de traiter un symbole non bloc comme un symbole bloc dans %s, à %s:%d"
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "vérification RTL: accès à elt hwi %d du vecteur avec le dernier elt %d dans %s, at %s:%d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "vérification RTL: accès à elt %d du vecteur avec le dernier elt %d dans %s, à %s:%d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "vérification du fanion RTL: %s utilisé avec un code rtx inattendu « %s » dans %s, à %s:%d"
@@ -27130,22 +27143,22 @@ msgstr "la contrainte correspondante fait référence à un numéro d'opérande
 msgid "invalid punctuation %qc in constraint"
 msgstr "ponctuation %qc invalide dans la contrainte"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "la contrainte correspondante n'autorise pas un registre"
 
-#: stmt.c:524
+#: stmt.c:525
 #, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "le nom d'opérande %<asm%> %qs apparaît en double"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "accolade de fermeture manquante pour l'opérande nommé"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "opérande nommé %qs non défini"
@@ -27823,9 +27836,9 @@ msgstr "opérande invalide pour %qs"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "désaccord de type dans %qs"
@@ -27860,7 +27873,7 @@ msgstr "opérande de décalage invalide dans %qs"
 msgid "invalid clique in %qs"
 msgstr "clique invalide dans %qs"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr "%qs dans IL gimple"
@@ -28066,362 +28079,362 @@ msgstr "opérandes invalides dans l'opération ternaire"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "le premier argument d'un %qs doit être d'un type vectoriel booléen du même nombre d'éléments que le résultat"
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "types vectoriels attendus dans %qs"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "des vecteurs avec un nombre d'éléments différents ont été trouvés dans %qs"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "type de masque invalide dans %qs"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "combinaison de types pas permise dans %qs"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "position ou taille invalide dans %qs"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "%qs dans un opérande non-mode-precision"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "insertion hors limites dans %qs"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qs pas à la frontière d'un élément"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "conversion non triviale dans %qs"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "membre de gauche de %qs dans une instruction écrasée"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "opérande invalide dans %qs"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "membre de droite invalide pour un stockage mémoire gimple : %qs"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "type incorrect pour les éléments d'un vecteur %qs"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "nombre incorrect pour les éléments d'un vecteur %qs"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "type incorrect pour les éléments d'un vecteur CONSTRUCTOR"
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr "vecteur %qs avec un index d'élément non nul"
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "l'élément d'un vecteur %qs n'est pas une valeur GIMPLE"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "non vecteur %qs avec des éléments"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr "%qs avec une condition toujours fausse"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "opérande invalide dans l'instruction de retour"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "conversion invalide dans une instruction de retour"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "la destination du « goto » n'est ni une étiquette ni un pointeur"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "opérande invalide pour l'instruction « switch »"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "instruction « switch » avec un type non entier"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "étiquette invalide pour le « case » par défaut dans l'instruction « switch »"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "%<CASE_CHAIN%> invalide"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "étiquette invalide pour un « case » dans l'instruction « switch »"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "plage du « case » invalide dans l'instruction « switch »"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "désaccord dans la précision du type dans l'instruction « switch »"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "désaccord de type pour l'étiquette du « case » dans l'instruction « switch »"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "les « case » ne sont pas triés dans l'instruction « switch »"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "le contexte de l%'étiquette n'est pas la déclaration de la fonction actuelle"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "entrée incorrecte dans %<label_to_block_map%>"
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "configuration incorrecte pour le numéro de la zone d'atterrissage des exceptions (landing pad)"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "code de comparaison invalide dans la condition gimple"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "étiquettes invalides dans la condition gimple"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "résultat %<PHI%> invalide"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "définition %<PHI%> manquante"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "argument %<PHI%> invalide"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "types incompatibles dans l'argument %<PHI%> %u"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "%<verify_gimple%> a échoué"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "instruction sans effet dans la table EH"
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "le bloc des références vers les emplacements n'est pas dans l'arbre des blocs"
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "déclaration locale depuis une fonction différente"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) est défini avec un mauvais bloc de base"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "nœud PHI avec emplacement"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "partage incorrect des nœuds de l'arbre"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "PHI virtuel avec des emplacements d'arguments"
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) est défini avec un mauvais bloc de base"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "l'instruction est marquée comme produisant une exception mais elle ne le fait pas"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "une instruction est marquée comme produisant une exception au milieu du bloc"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple a échoué"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK a un nœud dans le langage intermédiaire (IL) qui lui est associé"
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK a un nœud dans le langage intermédiaire (IL) qui lui est associé"
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fallthru pour sortir du bloc de base %d"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "étiquette non locale "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "étiquette de la zone d'atterrissage du gestionnaire d'exceptions "
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "étiquette"
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "contrôle de flux au milieu du bloc de base %d"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "arête fallthru après une instruction de contrôle dans le bb %d"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "arête vrai/faux après un non GIMPLE_COND dans le bb %d"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "mauvais fanions d'une arête sortante à la fin du bb %d"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "« goto » explicite à la fin du bb %d"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "l'arête de retour ne pointe pas vers la sortie dans le bb %d"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "« case » par défaut rencontré mais pas au début du vecteur des « case »"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "étiquettes « case » pas triées: "
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "arête sortante supplémentaire %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "arête manquante %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "une fonction avec %<noreturn%> retourne une valeur"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "le contrôle a atteint la fin d'une fonction non « void »"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "la valeur retournée par %qD est ignorée alors qu'elle est déclarée avec l'attribut %<warn_unused_result%>"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "la valeur retournée est ignorée pour une fonction déclarée avec l'attribut %<warn_unused_result%>"
@@ -29507,7 +29520,7 @@ msgstr "les données COMMON locales au thread ne sont pas implémentées"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "l'alignement requis pour %q+D est plus grand que l'alignement implémenté de %wu"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "la taille de stockage de %q+D est inconnue"
@@ -29668,7 +29681,7 @@ msgstr "flux bytecode: balise %s attendue au lieu de %s"
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "flux bytecode: la balise %s n'est pas dans la plage [%s, %s] attendue"
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, gcc-internal-format
 msgid "unsupported record layout"
 msgstr "structure de l'enregistrement non supportée"
@@ -30276,7 +30289,7 @@ msgstr "l'attribut %qE suit %qE"
 msgid "type was previously declared %qE"
 msgstr "le type a été précédemment déclaré %qE"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> ne peut être spécifié que pour une fonction virtuelle"
@@ -30296,7 +30309,7 @@ msgstr "%qD n'est pas compatible avec %qD"
 msgid "%qE argument is not a function"
 msgstr "l'argument de %qE n'est pas une fonction"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "le message déprécié n'est pas une chaîne"
@@ -30722,12 +30735,12 @@ msgstr "%<?:%> utilisant des constantes entières dans un contexte booléen"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "le compilateur peut supposer que l'adresse de %qD sera toujours évaluée à %<true%>"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "parenthèses suggérées autour de l'affectation utilisée comme valeur dans une condition"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "usage de %<restrict%> invalide"
@@ -30889,13 +30902,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "l'attribut %<fallthrough%> est spécifié avec un paramètre"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "trop peu d'arguments pour la fonction %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "trop d'arguments pour la fonction %qE"
@@ -31830,7 +31843,7 @@ msgstr "concaténation non standard de chaînes littérales non supportée"
 msgid "traditional C rejects string constant concatenation"
 msgstr "le C traditionnel rejette la concaténation de chaînes constantes"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> avec la clause %<hint%> requiert un nom sauf quand %<omp_sync_hint_none%> est utilisé"
@@ -31880,7 +31893,7 @@ msgstr "type de dépendance %<depobj%> spécifié dans la clause %<depend%> d'un
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "le modificateur %<iterator%> ne peut pas être spécifié sur une construction %<depobj%>"
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "type invalide pour la variable d'itération %qE"
@@ -31895,17 +31908,17 @@ msgstr "variable d'itération %<_Atomic%> %qE"
 msgid "%qE is not initialized"
 msgstr "%qE n'est pas initialisé"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "prédicat de contrôle manquant"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "prédicat de contrôle invalide"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "expression d'incrémentation manquante"
@@ -31915,7 +31928,7 @@ msgstr "expression d'incrémentation manquante"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "l'incrément n'est pas la constante 1 ou -1 pour la condition %<!=%>"
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expression d'incrémentation invalide"
@@ -31980,7 +31993,7 @@ msgstr "modificateur de réduction %<task%> invalide sur une construction pas co
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr "clause %<inscan%> %<reduction%> sur une construction autre que %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr "%qD spécifié dans la clause %<allocate%> mais pas dans dans la clause de privatisation explicite"
@@ -32545,8 +32558,8 @@ msgstr "<valeur de retour>"
 msgid "wrong type argument to %s"
 msgstr "argument de type erroné pour %s"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "débordement dans l'expression constante"
@@ -33031,17 +33044,17 @@ msgstr "décrémentation de la fonction %qD"
 msgid "function %qD used as %<asm%> output"
 msgstr "la fonction %qD est utilisée comme sortie %<asm%>"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "affectation de l'emplacement %qE en lecture seule"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "incrémentation de l'emplacement %qE en lecture seule"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "décrémentation de l'emplacement %qE en lecture seule"
@@ -33221,8 +33234,8 @@ msgstr "%<memset%> utilisé avec un paramètre de longueur qui est la constante
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr "%<memset%> utilisé avec une longueur égale au nombre d'éléments sans être multiplié par la taille des éléments"
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparaison entre les types %qT et %qT"
@@ -33298,163 +33311,163 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "passage de l'argument %i aux alias qualifiés avec %qs avec l'argument %Z"
 msgstr[1] "passage de l'argument %i aux alias qualifiés avec %qs avec les arguments %Z"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "cette condition a des branches identiques"
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr "la macro s'étend en des instructions multiples"
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr "certaines parties de l'expansion de la macro ne sont pas protégées par cette instruction %qs"
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr "convertir un pointeur %qT compacté (alignement %d) vers un pointeur %qT (alignement %d) peut résulter en une valeur de pointeur non alignée"
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, gcc-internal-format
 msgid "defined here"
 msgstr "défini ici"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr "prendre l'adresse du membre compacté de %qT peut résulter en une valeur de pointeur non alignée"
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "désaccord de la limite %Z de l'argument %u déclaré comme %s"
 msgstr[1] "désaccord des limites %Z de l'argument %u déclaré comme %s"
 
 # la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr "précédemment déclarée comme %s"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "l'argument %u de type %s a été déclaré comme un tableau de longueur variable"
 
 # la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
 msgstr "précédemment déclarée comme un pointer %s"
 
 # la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
 msgstr "précédemment déclarée comme un tableau ordinaire %s"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr "l'argument %u de type %s a été déclaré comme un pointeur"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr "précédemment déclaré comme un tableau de longueur variable %s"
 
 # la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr "précédemment déclarée comme un tableau %s"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr "l'argument %u de type %s a été déclaré comme un tableau ordinaire"
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] "argument %u de type %s déclaré avec %u limite variable"
 msgstr[1] "argument %u de type %s déclaré avec %u limites variables"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "précédemment déclaré comme %s avec %u limite variable"
 msgstr[1] "précédemment déclaré comme %s avec %u limites variables"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] "l'argument %u de type %s a été déclaré avec %u limite variable non spécifiée"
 msgstr[1] "l'argument %u de type %s a été déclaré avec %u limites variables non spécifiées"
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] "précédemment déclaré comme %s avec %u limite variable non spécifiée"
 msgstr[1] "précédemment déclaré comme %s avec %u limites variables non spécifiées"
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] "ultérieurement déclaré comme %s avec %u limite variable non spécifiée"
 msgstr[1] "ultérieurement déclaré comme %s avec %u limites variables non spécifiées"
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr "l'argument %u de type %s est déclaré avec l'argument de limite %E non correspondant"
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "l'argument %u de type %s est déclaré avec la limite %<%s%> non correspondante"
 
 # la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr "précédemment déclarée comme %s avec l'argument de limite %E"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "précédemment déclaré comme %s avec la limite %<%s%>"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr "précédemment déclaré comme %s avec la limite %qs"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr "argument %u de type %s avec la limite non correspondante"
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr "l'expression ne calcule pas le nombre d'éléments dans son tableau ; le type de l'élément est %qT, pas %qT"
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr "ajoutez des parenthèses autour de %qE pour ne plus recevoir cet avertissement"
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr "ajoutez des parenthèses autour du deuxième %<sizeof%> pour ne plus recevoir cet avertissement"
@@ -33469,7 +33482,7 @@ msgstr "%qs n'est pas une option valide pour le préprocesseur"
 msgid "too many input files"
 msgstr "trop de fichiers d'entrée"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "valeur %qs inconnue pour %<-mcpu%>"
@@ -33500,14 +33513,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "option non reconnue passée à %%:target_mode_check"
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "les arguments valides sont: %s; vouliez-vous utiliser %qs ?"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "les arguments valables sont: %s"
@@ -33657,62 +33670,62 @@ msgstr "l'argument de %<-misr-secure=%d%> n'est pas entre 0 et 3"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr "dans l'option %<-mcache-block-size=X%>, les valeurs valides pour X sont: 4, 8, 16, 32, 64, 128, 256, ou 512"
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr "%<-march=%s%>: L'extension « %s » apparaît plus d'une fois."
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "%<-march=%s%>: Nombre attendu après %<%dp%>."
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "%<-march=%s%>: rv%de n'est pas une ISA de base valable"
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr "la version de « g » sera omise, veuillez spécifier la version pour chaque extension individuellement."
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr "%<-march=%s%>: le premier sous-ensemble ISA doit être %<e%>, %<i%> ou %<g%>"
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr "%<-march=%s%>: sous-ensemble ISA %<%c%> non supporté"
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr "%<-march=%s%>: la chaîne ISA n'est pas dans l'ordre canonique. %<%c%>"
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>: le nom de %s doit avoir plus d'une lettre"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%> %s doit être séparé par _"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "%<-march=%s%>: la chaîne ISA doit commencer par rv32 ou rv64"
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr "%<-march=%s%>: chaîne ISA inattendue à la fin : %qs"
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<-mcpu=%s%>: CPU inconnu"
@@ -33873,89 +33886,90 @@ msgstr "%s est en conflit avec ppc (fanions arch ignorés)"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr "%s est en conflit avec ppc64 (fanions arch ignorés)"
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "échec à l'ouverture du fichier temporaire %s pour la sortie LTO"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "l'attribut de compatibilité %qE 2.95 ne s'applique qu'à la compilation d'un kext (extension du noyau)"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "l'attribut de compatibilité %qE 2.95 ne s'applique qu'à des classes C++"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "l'attribut de visibilité protégée n'est pas supporté dans cette configuration; ignoré"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "échec à l'ouverture du fichier temporaire %s avec la sortie LTO"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> 2 doit être utilisé pour les cibles 64 bits avec %<-fnext-runtime%>"
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> %d n'est pas supporté sur les cibles 32 bits avec %<-fnext-runtime%>"
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "%<-gsplit-dwarf%> n'est pas supporté sur cette plateforme, il est ignoré"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "%<-mdynamic-no-pic%> écrase %<-fpic%>, %<-fPIC%>, %<-fpie%> ou %<-fPIE%>"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr "%<-mpic-symbol-stubs%> n'est pas requis pour du code 64 bits (ignoré)"
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "la fonction intégrée %qD exige le fanion %<-mconstant-cfstrings%>"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "la fonction intégrée %qD ne prend qu'un seul argument"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "la CFString littérale est manquante"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "l'expression CFString littérale n'est pas une constante de type chaîne de caractères"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr "caractère non ASCII dans une CFString littérale"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr "NUL inclus dans une CFString littérale"
 
 #: config/host-darwin.c:65
-#, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+#, fuzzy, gcc-internal-format
+#| msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "ne peut délier la mémoire %<pch_address_space%> %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34091,362 +34105,362 @@ msgstr "%<#pragma GCC aarch64%> existe une chaîne en paramètre"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "option %qs inconnue pour %<#pragma GCC aarch64%>"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "l'attribut %qE ne peut pas être appliqué à un type de fonction SVE"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "%<%s%> inattendu après %<%s%>"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs est incompatible avec l'utilisation de types en virgule flottante"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs est incompatible avec l'utilisation de types vectoriels"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "le modificateur de fonctionnalité %qs est incompatible avec l'utilisation de types en virgule flottante"
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "le modificateur de fonctionnalité %qs est incompatible avec l'utilisation de types vectoriels"
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "cette opération requiert l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "vous pouvez activer SVE en utilisant l'option %<-march%> sur la ligne de commande ou en utilisant l'attribut ou le pragma %<target%>"
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "l'argument de type %qT requiert l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "le type SVE %qT ne peut pas être passé en argument à une fonction sans prototype"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 9.1"
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "%qE requiert l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "les appels à des fonctions de type %qT requièrent l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "sondes de pile pour les trames SVE"
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "fanion inconnu passé à %<-moverride=%s%> (%s)"
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "chaîne %s mal formée\n"
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "format invalide pour sve_width"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "valeur invalide pour sve_width: %d"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "chaîne d'ajustement manquante dans l'option (%s)"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "option d'ajustement inconnue (%s)"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "%<-mstack-protector-guard=global%> et %<-mstack-protector-guard-offset=%qs%> incompatibles"
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "%<-mstack-protector-guard-offset%> et %<-mstack-protector-guard-reg%> doivent être utilisés tous les deux avec %<-mstack-protector-guard=sysreg%>"
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr "spécifie un registre système avec une chaîne de courte longueur."
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs n'est pas un décalage valide dans %qs"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr "seules les valeurs 12 (4 ko) et 16 (64 ko) sont supportées pour la taille de garde. La valeur %d donnée (%llu ko) est hors limites"
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr "la taille %<%d%> de la sécurité anti-collision de la pile doit être égale à l'intervalle de sondage %<%d%>"
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "les arguments valables sont: %s;"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "nom de processeur manquant dans %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "modificateur de fonctionnalité %qs invalide dans %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "argument invalide donné à %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr "%<%s%> doit être seul pour %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "argument %<%s%> invalide pour %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "argument %<%s%> invalide pour %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "argument manquant pour %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "nom d'architecture manquant dans %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "valeur %qs inconnue pour %<-march%>"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "modificateur de fonctionnalité %qs invalide dans %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "nom de processeur manquant dans %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "valeur %qs inconnue pour %<-mtune%>"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "l'option %<-mcpu=%s%> est en conflit avec l'option %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "l'assembleur ne supporte pas %<-mabi=ilp32%>"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr "la signature de l'adresse de retour n'est supportée qu'avec %<-mabi=lp64%>"
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "modèle de code %qs avec %<-f%s%>"
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode ilp32"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nom manquant dans le pragma ou l'attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nom invalide (« %s ») dans le pragma ou l'attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "modificateur de fonctionnalité %s invalide avec la valeur (\"%s\") dans le pragma ou l'attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nom manquant dans le pragma ou l'attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nom invalide (« %s ») dans le pragma ou l'attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "argument manquant dans le pragma ou l'attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "type de protection (\"%s\") invalide dans le pragma ou l'attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "nom invalide (« %s ») dans le pragma ou l'attribut %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "valeur manquante dans le pragma ou l'attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "le pragma ou l'attribut %<target()%> est mal composé"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'accepte pas d'argument"
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'autorise pas de forme négative"
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "le pragma ou l'attribut %<target(\"%s=%s\")%> n'est pas valide"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "l'argument %<target%> de l'attribut n'est pas une chaîne"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'est pas valide"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> est mal composé"
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "le passage de paramètre pour l'argument de type %qT avec des membres %<[[no_unique_address]]%> a changé dans %{GCC 10.1%}"
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "le passage par paramètre pour l'argument de type %qT quand C++17 est activé a changé pour correspondre à C++14 %{dans GCC 10.1%}"
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Kl'avenue %wd est hors des limites %wd - %wd"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "avenue %wd hors des limites %wd - %wd"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "simdlen %wd non supportée"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "GCC ne supporte actuellement pas les types de tailles mélangés pour les fonctions %<simd%>"
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "GCC ne supporte actuellement pas le type de retour %qT pour les fonctions %<simd%>"
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "type de retour %qT non supporté pour des fonctions %<simd%>"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "GCC ne supporte actuellement pas un argument de type %qT pour des fonctions %<simd%>"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "GCC ne supporte actuellement pas simdlen %wd pour le type %qT"
@@ -34507,7 +34521,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "valeur %qs erronée pour %<-mmemory-latency%>"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -34627,18 +34641,18 @@ msgstr "l'argument de l'attribut %qE n'est pas « ilink1 » ni « ilink2 »"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "l'argument de l'attribut %qE n'est pas « ilink » ni « firq »"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -35068,223 +35082,230 @@ msgstr "le processeur cible ne supporte pas les instructions THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "le processeur cible ne supporte pas les accès non alignés"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "l'option %<-mcpu=%s%> est en conflit avec l'option %<-march=%s%>"
+
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "%<-mapcs-stack-check%> incompatible avec %<-mno-apcs-frame%>"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "%<-fpic%> et %<-mapcs-reent%> sont incompatibles"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "Le code réentrant APCS n'est pas supporté.  Ignoré"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr "l'option %<-mstructure-size-boundary%> est dépréciée"
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "la frontière de la taille de la structure peut seulement être 8, 32 ou 64"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "la frontière de la taille de la structure peut seulement être 8 ou 32"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC est incompatible avec %<-msingle-pic-base%>"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "le mode FDPIC n'est pas supporté en mode Thumb-1"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "%<-mpic-register=%> est inutile sans %<-fpic%>"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "incapable d'utiliser %qs pour un registre PIC"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> n'est pas supporté sur cette architecture"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "les options fp16 sélectionnées sont incompatibles"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt exige une ABI compatible AAPCS pour fonctionner correctement"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "l'abi iwmmxt requiert un processeur avec iwmmxt"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "le processeur cible ne supporte pas l'interopérabilité"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS ne supporte pas %<-mcaller-super-interworking%>"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS ne supporte pas %<-mcallee-super-interworking%>"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 et pas de ldrh"
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "le processeur cible ne supporte pas les extensions de sécurité ARMv8-M"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr "Les extensions de sécurité ARMv8-M sont incompatibles avec le FPU sélectionné"
 
-#: config/arm/arm.c:3859
-#, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+#: config/arm/arm.c:3864
+#, fuzzy, gcc-internal-format
+#| msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr "%<-mfloat-abi=hard%>: le processeur sélectionné n'a pas de FPU"
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "%<-mfloat-abi=hard%> et VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "variante PCS qui n'est pas dérivée de AAPCS"
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "les fonctions variadiques doivent utiliser la variante du AAPCS de base"
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "variante PCS"
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "ABI VFP en virgule flottante matérielle du Thumb-1"
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr "argument de type %qT pas permis avec -mgeneral-regs-only"
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 7.1"
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr "les registres FP pourraient être écrasés malgré l'attribut %qE : compilez avec %<-mgeneral-regs-only%>"
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "l'attribut %qE n'est pas disponible pour les fonctions avec des arguments passés sur la pile"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "l'attribut %qE n'est pas disponible pour les fonctions avec un nombre variable d'arguments"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "l'attribut %qE n'est pas disponible pour les fonctions qui retournent une valeur sur la pile"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "l'attribut %qE est ignoré sans l'option %<-mcmse%>."
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "l'attribut %qE n'a pas d'effet sur les fonctions statiques"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "l'attribut %qE ne s'applique qu'au type de base d'un pointeur vers une fonction"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "l'accès à un stockage local au thread n'est actuellement pas supporté avec %<-mpure-code%> ou %<-mslow-flash-data%>"
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd hors des limites %wd - %wd"
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd hors des limites %wd - %wd"
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "incapable de calculer la position réelle des paramètres sur la pile"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Saut lointain thumb1 inattendu"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "pas de registre bas disponible pour dépiler les registres hauts"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "les routines du service d'interruption ne peuvent pas être codées en mode Thumb-1"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> pour Thumb-1"
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "fpu invalide pour l'attribut ou le pragma cible %qs"
@@ -35292,22 +35313,22 @@ msgstr "fpu invalide pour l'attribut ou le pragma cible %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "la sélection automatique du fpu n'est actuellement pas permise ici"
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "architecture invalide pour l'attribut ou le pragma cible %qs"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "attribut ou pragma cible %qs inconnu"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "fanions asm non supportés en mode thumb1"
@@ -35386,17 +35407,17 @@ msgstr "%<-fpie%> n'est pas supporté"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> n'est pas supporté"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "les attributs de fonction %qs et %qs sont mutuellement exclusifs"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la fonction avec l'attribut %qs ne peut pas avoir d'argument"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la fonction avec l'attribut %qs ne peut pas retourner une valeur"
@@ -36139,132 +36160,132 @@ msgstr "le paramètre à une fonction interne doit être une chaîne sous forme
 msgid "parameter to builtin not valid: %s"
 msgstr "le paramètre à la fonction interne n'est pas valable: %s"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "une routine de service d%'interruption ne peut pas être appelée directement"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 2 bits"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "le cinquième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "le troisième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 3 bits"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "l'avant dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "le troisième argument doit être une constante de comparaison"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "mode de comparaison incorrect"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "opérande d'arrondi incorrect"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "le sélecteur doit être une constante entière dans la plage [0, %wi]"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE a besoin d'une option isa inconnue"
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE a besoin de l'option isa %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 32 bits"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "le dernier argument doit être une valeur immédiate"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "le dernier argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "le quatrième argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "opérande d'indice incorrect"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "l'argument de l'intrinsèque %<xabort%> doit être une valeur immédiate sur 8 bits"
@@ -36284,514 +36305,514 @@ msgstr "des versions multiples de fonctions virtuelles ne sont pas supportées"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "les versions multiples requièrent %<ifunc%> qui n'est pas supporté sur cette cible"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "le modèle de code %s ne supporte pas le mode PIC"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "l'argument de l'attribut %qs n'est pas une chaîne"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "l'argument %qs de l'attribut %qs est inconnu"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "la valeur %qs de l'attribut était déjà spécifiée dans l'attribut %qs"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "la valeur %qs de l'attribut est inconnue dans l'attribut %qs"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "argument %qs erroné pour l'option %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "les plages de tailles de l'option %qs devraient être croissantes"
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "nom de stratégie %qs erroné spécifié pour l'option %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "le nom de stratégie %qs spécifié pour l'option %qs n'est pas supporté pour du code 32 bits"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "alignement %qs inconnu spécifié pour l'option %qs"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "la valeur maximale pour la dernière plage de taille de l'option %qs devrait être -1"
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "trop de plages de tailles spécifiées dans l'option %qs"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "paramètre inconnu dans l'option %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "la psABI du MCU Intel n'est pas supportée dans le mode %s"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> est déprécié; utilisez plutôt %<-mtune=k8%> ou %<-mtune=generic%> selon ce qui est approprié"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> est déprécié; utilisez plutôt %<target(\"tune=k8\")%> ou %<target(\"tune=generic\")%> selon ce qui est approprié"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> pas supporté pour du code 32 bits"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> pas supporté pour du code 32 bits"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "le mode d'adresse %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> pas supporté avec l'ABI X32"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> n'est pas supportée avec %<-fsanitize=address%>"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> n'est pas supportée avec %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> n'est pas supportée avec %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode x32"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> n'est pas supporté dans cette configuration"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "mode %i bits pas compilé"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "le processeur sélectionné ne supporte pas le jeu d'instructions x86-64"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "valeur erronée (%qs) pour l'option %<-march=%>"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "valeur erronée (%qs) pour l'attribut %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "valeur erronée (%qs) pour l'option %<-mtune=%>"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "valeur erronée (%qs) pour l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> est ignoré en mode 64 bits"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> est ignoré avec la psABI du MCU Intel"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> n'est pas entre 0 et %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> est ignoré en mode 64 bits"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> est ignoré en mode 64 bits"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> n'est pas supporté pour cette cible"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> n'est pas entre %d et %d"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> n'est pas entre %d et 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> n'est pas compatible avec cette cible"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> n'est pas implémenté pour %<-fPIC%>"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "jeu d'instructions SSE désactivé, l'arithmétique 387 est utilisée"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "jeu d'instructions 387 désactivé, l'arithmétique SSE est utilisée"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "le sondage de la pile requiert %<-maccumulate-outgoing-args%> pour être correcte"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "le sondage de la pile requiert %<target(\"accumulate-outgoing-args\")%> pour être correcte"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "le registre ebp fixé requiert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "le registre ebp fixé requiert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> n'est pas supporté en 32 bits en combinaison avec %<-fpic%>"
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> n'est pas compatible avec SEH (gestionnaire d'exceptions structuré)"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> n%'est actuellement pas supporté avec SEH"
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "option inconnue pour %<-mrecip=%s%>"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs n'est pas un nombre valable dans %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs n'est pas un décalage valable dans %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs n'est pas un registre de base valable dans %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> n'est pas compatible avec cette cible"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "les attributs d'interruption et nus sont incompatibles"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "seul le format de débogage DWARF est supporté pour les routines de service d'interruptions"
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> et %<-fcf-protection%> sont incompatibles"
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> et %<-fcf-protection%> sont incompatibles"
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service exception"
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service d'interruption"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "les instructions %s ne sont pas autorisées dans la fonction avec l%'attribut %<no_caller_saved_registers%>"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "les attributs fastcall et regparm sont incompatibles"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "les attributs regparam et thiscall sont incompatibles"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante entière"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "l'argument pour l'attribut %qE est plus grand que %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "les attributs fastcall et cdecl sont incompatibles"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall sont incompatibles"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et thiscall sont incompatibles"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "les attributs stdcall et cdecl sont incompatibles"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "les attributs stdcall et fastcall sont incompatibles"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "les attributs stdcall et thiscall sont incompatibles"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "les attributs cdecl et thiscall sont incompatibles"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "l'attribut %qE est utilisé pour une méthode qui n'est pas une classe"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "l'attribut incompatible %qE est ignoré"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "l'attribut %qE est uniquement disponible en 32 bits"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "l'argument de l'attribut %qE n'est ni zéro ni un"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "les attributs %qs et %qs sont incompatibles"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante chaîne de caractères"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "l'argument de l'attribut %qE n'est pas (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la routine de service d'interruption devrait avoir un pointeur comme premier argument"
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "la routine de service d'interruption devrait avoir %qs comme deuxième argument"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la routine de service d'interruption ne peut avoir qu'un argument de type pointeur et un argument entier optionnel"
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "la routine de service d'interruption doit retourner %<void%>"
@@ -37245,7 +37266,7 @@ msgstr "%qE ne peut pas avoir les deux attributs %qs et %qs en même temps"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE redéclaré avec les attributs conflictuels %qs"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "l'attribut %qE requiert une chaîne comme argument"
@@ -38303,57 +38324,57 @@ msgstr "%<__delay_cycles%> est limité à des décomptes de boucles sur 32 bits"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "processeur %qs inconnu pour %<-mtune%>"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "l'ABI pour des structures aplaties avec un champ de bits d'une taille non nulle a changé dans GCC 10"
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "l'argument de l'attribut %qE n'est pas « user », « supervisor » ou « machine »"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> requiert %<-march%> pour incorporer l'extension %<M%>"
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "l'ABI demandée requiert %<-march%> pour incorporer l'extension %qc"
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e requiert l'ABI ilp32e"
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "l'ABI requiert %<-march=rv%d%>"
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> doit être entre %d et %d"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "l'attribut RISC-V ELF %<-mriscv-attribute%> requiert GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs n'est pas un registre de base valable dans %qs"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs n'est pas un nombre valide dans %qs"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "la fonction %qs ne peut pas avoir un type d'interruption différent"
@@ -38857,239 +38878,241 @@ msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Une trame de pile plus grande que 2G n'est pas supportée par %<-fsplit-stack%>"
 
 # le premier %qs est un mot non traduit tel que « private », « shared » ou « threadprivate ».
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs requiert %qs ou %qs"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs requiert une architecture PowerPC64, elle est maintenant activée"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "%<-mcall-aixdesc%> incompatible avec %<-mabi=elfv2%>"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "%<-m64%> requiert un processeur PowerPC64"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "%<-mcmodel%> est incompatible avec les autres options toc"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "%qs n'est pas supporté par cette ABI"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "%qs n'est pas supporté sur Darwin 64 bits; il est incompatible avec les bibliothèques C et C++ installées"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec pas supporté par cette cible"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "%qs n'est pas supporté sur des systèmes petits boutistes"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "l'option de la cible power9 est incompatible avec %<%s=<xxx>%> pour <xxx> inférieur à power9"
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs est incompatible avec les options explicitement désactivées"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs requiert %qs"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "l'attribut cible ou le pragma change la taille du %<long double%>"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%qs requiert le support ISA 2.06 complet"
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Utilisation du %<long double%> en précision étendue de IEEE"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Utilisation du %<long double%> en précision étendue de IBM"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs requiert le support VSX"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr "L'option %<-mfloat128%> peut ne pas être totalement supportée"
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs requiert le support ISA 3.0 complet"
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "type d'ABI de la bibliothèque de vectorisation (%qs) inconnu pour l'option %qs"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI AltiVec"
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI darwin64"
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs a besoin d'un registre de base valable"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "option inconnue pour %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs est déprécié et recommandé dans aucune circonstance"
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "l'agencement des agrégats contenant des vecteurs alignés sur %d octets a changé avec GCC 5"
 
-#: config/rs6000/rs6000.c:10582
-#, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+#: config/rs6000/rs6000.c:10675
+#, fuzzy, gcc-internal-format
+#| msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs est un type opaque et vous ne pouvez pas le remplacer avec d'autres valeurs."
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "pas de profilage du code 64 bits pour cette ABI"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Vous ne pouvez pas prendre l'adresse d'une fonction imbriquée si vous utilisez l'option %qs"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<long double%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "l'utilisation des types booléens dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<complex%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "l'utilisation de types décimaux en virgule flottante dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "l'utilisation de %<long%> dans les types AltiVec est invalide pour du code 64 bits sans %qs"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "l'utilisation de %<long%> dans les types Altivec est obsolète; utilisez %<int%>"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<long long%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<double%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "processeur %qs invalide pour %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s n'est pas permis"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s est invalide"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> désactive %<-m%s%>"
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "l'attribut %<target_clones%> requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "les versions multiples requièrent ifunc qui n'est pas supporté sur cette cible"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Des versions multiples de fonctions virtuelles ne sont pas supportées"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "le résultat de l'instruction xxspltidp n'est pas défini pour des valeurs d'entrée sous-normales"
@@ -39268,7 +39291,7 @@ msgstr "Les instructions du FPU RX ne supportent pas les NaN et les infinis"
 msgid "builtin vec_step can only be used on vector types."
 msgstr "la fonction interne vec_step peut uniquement être utilisée sur des types vectoriels."
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "valeur constante requise pour l'argument %2$d de la fonction interne %1$qF"
@@ -39338,200 +39361,206 @@ msgstr "la variante correspondant à %qs est obsolète."
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite pour le type cible"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "constant argument %d for builtin %qF is out of range ("
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "l'argument constant %d de la fonction interne %qF est hors limite ("
+
+#: config/s390/s390.c:766
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite (0..%wu)"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite (%wd..%wd)"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr "la fonction interne %qF n'est pas supportée sans %<-mhtm%> (par défaut avec %<-march=zEC12%> et supérieur)."
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr "la fonction interne %qF requiert %<-mvx%> (par défaut avec %<-march=z13%> et supérieur)."
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr "La fonction interne %qF requiert z14 ou supérieur."
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr "La fonction interne %qF requiert z15 ou supérieur."
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr "La fonction interne %qF requiert arch14 ou supérieur."
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "fonction interne surchargée non résolue"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "icode de fonction interne erroné"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "argument %d invalide pour la fonction interne %qF"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "l'attribut %qE demandé n'est pas une paire de constantes entières non négatives séparées par une virgule ou est trop grand (max. %d)"
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "l'argument de l'attribut %qE n'est pas (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "la taille totale des variables locales excède la limite de l'architecture"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "la taille de la trame de la fonction %qs est de %wd octets. Elle dépasse la limite de %d octets de la pile fournie par l'utilisateur. Un déroutement inconditionnel est ajouté."
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "la taille de la trame de la fonction %qs est de %wd octets. C'est plus que la moitié de la taille de la pile. Le contrôle dynamique ne serait pas fiable. Aucun contrôle n'est généré pour cette fonction."
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "la taille de la trame de %qs est de %wd octets"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs utilise l'allocation de pile dynamique"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "les fonctions imbriquées ne savent pas être profilées avec %<-mfentry%> sur un s390"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "l'ABI 64 bits n'est pas supportée en mode ESA/390"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline est uniquement supporté avec %<-mindirect-branch-jump%>"
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "le support des vecteurs matériels n'est pas disponible sur %s"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "le support des vecteurs matériels n'est pas disponible avec %<-msoft-float%>"
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "les instructions décimales en virgule flottante matérielles ne sont pas disponibles sur %s"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "les instructions décimales en virgule flottante matérielles ne sont pas disponibles en mode ESA/390"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> ne peut être utilisé en conjonction avec %<-msoft-float%>"
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> ne sont pas supportés en combinaison"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "la taille de la pile doit être plus grande que la valeur de la protection de la pile"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "la taille de la pile ne peut pas être plus grande que 64k"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> implique l'utilisation de %<-mstack-size%>"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-prologue-check requiert un entier dans la plage 0..4095"
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-prologue-target requiert un entier dans la plage 0..4095"
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-epilogue-check requiert un entier dans la plage 0..4095"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-epilogue-target requiert un entier dans la plage 0..4095"
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> est supporté uniquement sur des processeurs 64 bits"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "les arguments de %qs doivent être des entiers non négatifs"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "l'argument de %qs est trop grand (max. %d)"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> ne peut pas être utilisé sans %<-fpic%>/%<-fPIC%>"
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) est inconnu"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "la valeur %qs n'est pas supportée par l'attribut %<target%>"
@@ -39873,17 +39902,23 @@ msgstr "%<-fexcess-precision=standard%> pour Ada"
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr "les informations de débogage STABS de Ada sont obsolètes et ne sont plus supportées"
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "STOP code at %C contains too many digits"
+msgid "%s contains too many lines"
+msgstr "Le code de STOP à %C contient trop de chiffres"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr "le sous-programme %q+F n'est pas marqué comme étant %<Inline_Always%>"
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "le sous-programme parent ne peut pas être mis en ligne"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr "le sous-programme %q+F n'est pas marqué comme étant %<Inline%>"
@@ -39949,8 +39984,8 @@ msgstr "l'attribut %qs s'applique seulement aux types tableaux"
 msgid "could not read the BRIG file"
 msgstr "n'a pu lire le fichier BRIG"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "la valeur void n'a pas été ignorée comme elle aurait dû l'être"
@@ -40010,7 +40045,7 @@ msgstr "variable %qD définie mais non utilisée"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "le type du tableau %q+D est complété de manière incompatible avec une initialisation implicite"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "défini initialement ici"
@@ -40232,7 +40267,7 @@ msgstr "la déclaration de %q+D masque la déclaration précédente de quelque c
 msgid "declaration of %qD shadows a parameter"
 msgstr "la déclaration de %qD masque un paramètre"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "la déclaration de %qD masque une déclaration globale"
@@ -40242,7 +40277,7 @@ msgstr "la déclaration de %qD masque une déclaration globale"
 msgid "declaration of %qD shadows a previous local"
 msgstr "la déclaration de %qD masque la déclaration locale précédente"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "la déclaration masquée est ici"
@@ -40252,212 +40287,212 @@ msgstr "la déclaration masquée est ici"
 msgid "nested extern declaration of %qD"
 msgstr "déclaration externe imbriquée de %qD"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "déclaration implicite de la fonction %qE; vouliez-vous utiliser %qs ?"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "déclaration implicite de la fonction %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr "incluez %qs ou fournissez une déclaration de %qE"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "déclaration implicite incompatible pour la fonction interne %qD"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "incluez %qs ou fournissez une déclaration de %qD"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "déclaration implicite incompatible de la fonction %qD"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE non déclaré ici (hors de toute fonction); vouliez-vous utiliser %qs ?"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE non déclaré ici (hors de toute fonction)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE non déclaré (première utilisation dans cette fonction); vouliez-vous utiliser %qs ?"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE non déclaré (première utilisation dans cette fonction)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "chaque identificateur non déclaré est rapporté une seule fois pour chaque fonction dans laquelle il apparaît"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "l'étiquette %qE est référencée à l'extérieur de toute fonction"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "saut dans la portée de l'identificateur avec un type modifié par une variable"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "le saut passe outre l'initialisation d'une variable"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "l'étiquette %qD est définie ici"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "saut dans l'expression d'une instruction"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "déclaration de l'étiquette %qE en double"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "étiquette %qD dupliquée"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "le C traditionnel n'a pas d'espace de noms séparé pour les étiquettes, l'identificateur %qE est en conflit"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "le « switch » passe outre l'initialisation d'une variable"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "le « switch » débute ici"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "le « switch » saute dans l'expression d'une instruction"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE est défini comme un mauvais type de balise"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attribut %qE appliqué à %qD avec un type de retour void"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "l'attribut %qE peut uniquement être appliqué aux fonctions ou aux structures, unions ou aux types énumérés"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "struct/union sans nom ne définissant aucune instance"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "la déclaration vide avec un spécificateur de classe de stockage ne redéclare pas la balise"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "la déclaration vide avec un qualificatif de type ne redéclare pas la balise"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "la déclaration vide avec %<_Alignas%> ne redéclare pas la balise"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "nom de type inutile dans la déclaration vide"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> dans une déclaration vide"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> dans une déclaration vide"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> dans une déclaration vide ayant tout le fichier comme portée"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> dans une déclaration vide ayant tout le fichier comme portée"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "spécificateur de classe de stockage inutile dans la déclaration vide"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "%qs inutile dans la déclaration vide"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "qualificatif de type inutile dans la déclaration vide"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "%<_Alignas%> inutile dans une déclaration vide"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr "utilisation invalide des attributs dans une déclaration vide"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "déclaration vide"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "le C90 ISO ne supporte pas %<static%> ou les qualificatifs de types dans les déclarateurs de tableau de paramètres"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "le C90 ISO ne supporte pas %<[*]%> dans les déclarateurs de tableau"
@@ -40465,28 +40500,28 @@ msgstr "le C90 ISO ne supporte pas %<[*]%> dans les déclarateurs de tableau"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> n'est pas permis ailleurs que dans la portée du prototype d'une fonction"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D est habituellement une fonction"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD est initialisé (utilisez plutôt %<__typeof__%>)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "la fonction %qD est initialisée comme une variable"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "le paramètre %qD est initialisé"
@@ -40495,267 +40530,267 @@ msgstr "le paramètre %qD est initialisé"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "un objet de taille variable peut ne pas être initialisé"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "la variable %qD est initialisée mais a un type incomplet"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr "la fonction en ligne %q+D a reçu l'attribut %qs"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "le membre constant non initialisé dans %qT est invalide en C++"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD devrait être initialisé"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "l'initialiseur n'a pu déterminer la taille de %q+D"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "taille de tableau manquante dans %q+D"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "tableau %q+D de taille nulle ou négative"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "la taille de stockage de %q+D n'est pas une constante"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "spécificateur %<asm%> ignoré pour la variable locale non statique %q+D"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "impossible de mettre un objet avec un champ volatile dans un registre"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, gcc-internal-format
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "%<const %qD%> non initialisé est invalide en C++"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D dans la directive de déclaration de cible n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "le C ISO interdit la déclaration anticipée des paramètres"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "définir un type dans un littéral composé (compound literal) est invalide en C++"
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "la largeur du champ de bits %qs n'est pas une constante entière"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "la largeur du champ de bits %qs n'est pas une expression constante entière"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "largeur négative du champ de bits %qs"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "largeur nulle pour le champ de bits %qs"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "le champ de bits %qs a un type invalide"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "ne peut déclarer le champ de bits %qs avec un type %<warn_if_not_aligned%>"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "le type de champ de bit %qs est une extension de GCC"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "la largeur de %qs excède son type"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs est plus étroit que les valeurs de son type"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "le C90 ISO interdit le tableau %qE dont la taille ne peut être évaluée"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "le C90 ISO interdit le tableau dont la taille ne peut être évaluée"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "le C90 ISO interdit le tableau %qE de taille variable"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "le C90 ISO interdit le tableau de taille variable"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "%qE modifié par une variable ayant une portée sur tout le fichier"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "champ modifié par une variable au niveau de la portée du fichier"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "le type %<int%> est utilisé par défaut dans la déclaration de %qE"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "le type %<int%> est utilisé par défaut dans le nom du type"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "%<const%> dupliqué"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "%<restrict%> dupliqué"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "%<volatile%> dupliqué"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "%<_Atomic%> dupliqué"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "les espaces d'adresses nommés sont en conflits (%s contre %s)"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "type de tableau qualifié avec %<_Atomic%>"
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "définition de fonction déclarée %<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "définition de fonction déclarée %<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "définition de fonction déclarée %<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "définition de fonction déclarée %qs"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "classe de stockage spécifiée pour le champ de la structure %qE"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "classe de stockage spécifiée pour le champ de la structure"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "classe de stockage spécifiée pour le paramètre %qE"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "classe de stockage spécifiée pour le paramètre sans nom"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "classe de stockage spécifiée pour un typename"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE initialisé et déclaré %<extern%>"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE a, à la fois, %<extern%> et un initialiseur"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "la déclaration de %qE au niveau du fichier spécifie %<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "la déclaration de %qE au niveau du fichier spécifie %<register%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "fonction imbriquée %qE» déclarée %<extern%>"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "%qE au niveau de la fonction est implicitement « auto » et déclaré %qs"
@@ -40763,712 +40798,712 @@ msgstr "%qE au niveau de la fonction est implicitement « auto » et déclaré
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "« static » ou qualificatifs de type dans un déclarateur de tableau n'étant pas un paramètre"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "déclaration de %qE comme un tableau de « void »"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "déclaration du nom de type comme un tableau de « void »"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "déclaration de %qE comme un tableau de fonctions"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "déclaration du nom de type comme un tableau de fonctions"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "utilisation invalide d'une structure ayant un membre qui est un tableau flexible"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "la taille du tableau %qE a un type qui n'est pas un entier"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "la taille du tableau sans nom a un type qui n'est pas un entier"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "la taille du tableau %qE a un type incomplet"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "la taille du tableau sans nom a un type incomplet"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "le C ISO interdit le tableau de taille nulle %qE"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "le C ISO interdit le tableau de taille nulle"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "la taille du tableau %qE est négative"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "la taille du tableau sans nom est négative"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "la taille du tableau %qE est trop grande"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "la taille du tableau sans nom est trop grande"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "le C90 ISO ne supporte pas les membres qui sont des tableaux flexibles"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> n'est pas dans une déclaration"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "le type du tableau a un élément de type %qT incomplet"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la déclaration de %qE comme tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "la déclaration du tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE déclaré comme une fonction retournant une fonction"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "nom de type déclaré comme une fonction retournant une fonction"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE déclaré comme une fonction retournant un tableau"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "nom de type déclaré comme une fonction retournant un tableau"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "la définition de la fonction a un type de retour « void » qualifié"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "les qualificatifs de type sont ignorés sur le type retourné par la fonction"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "type de fonction qualifié par %<_Atomic%>"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "le C ISO interdit les types de fonction qualifiés"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs combiné avec le qualificatif %<auto%> pour %qE"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs combiné avec le qualificatif %<register%> pour %qE"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs est spécifié pour la variable auto %qE"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs est spécifié pour le paramètre %qE"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs est spécifié pour un paramètre non nommé"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs spécifié pour le champ %qE de la structure"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs spécifié pour un champ d'une structure"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "le champ de bits %qE a un type atomique"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "le champ de bits a un type atomique"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "un alignement est spécifié pour le typedef %qE"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "un alignement est spécifié pour l'objet %<register%> %qE"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "un alignement est spécifié pour le paramètre %qE"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "un alignement est spécifié pour un paramètre sans nom"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "un alignement est spécifié pour le champ de bits %qE"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "un alignement est spécifié pour un champ de bits sans nom"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "un alignement est spécifié pour la fonction %qE"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "les spécificateurs %<_Alignas%> ne peuvent pas réduire l'alignement de %qE"
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "les spécificateurs %<_Alignas%> ne peuvent pas réduire l'alignement du champ sans nom"
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "le typedef %q+D est déclaré %<inline%>"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "le typedef %q+D est déclaré %<_Noreturn%>"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "le C ISO interdit les fonctions de type volatile ou constante"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un membre d'une structure ou d'une union ne peut pas avoir de type modifié par une variable"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variable ou champ %qE déclaré « void »"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "les attributs dans un déclarateur de tableau de paramètres sont ignorés"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "paramètre %q+D déclaré %<inline%>"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "paramètre %q+D déclaré %<_Noreturn%>"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "champ %qE déclaré comme une fonction"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "le champ %qE est d'un type incomplet"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "un champ sans nom a un type incomplet"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "classe de stockage invalide pour la fonction %qE"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "la fonction %<main%> ne peut pas être mise en ligne"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> est déclarée %<_Noreturn%>"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "le C99 ISO ne supporte pas %<_Noreturn%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "le C90 ISO ne supporte pas %<_Noreturn%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "une variable précédemment déclarée %<static%> est redéclarée %<extern%>"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variable %q+D déclarée %<inline%>"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variable %q+D déclarée %<_Noreturn%>"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "fonction non imbriquée avec un type modifié par une variable"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "un objet avec un type modifié par une variable ne peut pas avoir de classe de liaison"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "la déclaration de fonction n'est pas un prototype"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "noms de paramètres (sans type) dans la déclaration de fonction"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "le paramètre %u (%q+D) a un type incomplet"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "le paramètre %u a un type incomplet"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "le paramètre %u (%q+D) a le type void"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "le paramètre %u a le type void"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "un %<void%> comme seul paramètre ne peut être qualifié"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> doit être le seul paramètre"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "le paramètre %q+D n'a qu'une déclaration anticipée"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "%<%s %E%> est déclaré à l'intérieur d'une liste de paramètres et ne sera pas visible en dehors de cette définition ou déclaration"
 
 # le %s est « struct », « union » ou « enum »
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "le %s anonyme est déclaré à l'intérieur d'une liste de paramètres et ne sera pas visible en dehors de cette définition ou déclaration"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "type « enum » défini ici"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "« struct » défini ici"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "« union » défini ici"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "redéfinition de %<union %E%>"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "redéfinition de %<struct %E%>"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "redéfinition imbriquée de %<union %E%>"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "redéfinition imbriquée de %<struct %E%>"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "définir le type dans l'expression %qs est invalide en C++"
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la déclaration ne déclare rien du tout"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "le C99 ISO ne supporte pas les structures et unions sans nom"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "le C90 ISO ne supporte pas les structures et unions sans nom"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "membre %q+D dupliqué"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr "une structure vide a une taille 0 en C et une taille 1 en C++"
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "une union vide a une taille 0 en C et une taille 1 en C++"
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "l'union n'a aucun membre nommé"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "l'union n'a aucun membre"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "la structure n'a aucun membre nommé"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "la structure n'a aucun membre"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "tableau flexible comme membre de l'union"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "le tableau flexible n'est pas le dernier membre à la fin de la structure"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "tableau flexible comme membre d'une structure sans aucun membre nommé"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "le type %qT est trop grand"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "une union ne peut pas être rendue transparente"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "redéfinition imbriquée de %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redéclaration de %<enum %E%>"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "le mode spécifié est trop petit pour les valeurs énumérées"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "les valeurs de l'énumération excèdent les limites du plus grand entier"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "la valeur de l'énumérateur pour %qE n'est pas une constante entière"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "la valeur de l'énumérateur pour %qE n'est pas une expression constante entière"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "débordement dans les valeurs de l'énumération"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "le C ISO restreint les valeurs de l'énumérateur à la plage d'un %<int%>"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "la fonction à mettre en ligne %qD a reçu l'attribut %qs"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "le type du retour est un type incomplet"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "le type du retour devient %<int%> par défaut"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D est définie comme fonction variadique sans prototype"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "aucun prototype précédent pour %qD"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD a été utilisé sans prototype avant sa définition"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "aucune déclaration précédente pour %qD"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD a été utilisé sans déclaration avant sa définition"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "le type de retour de %qD n'est pas %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "type de retour qualifié avec %<_Atomic%> pour %qD"
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD est normalement une fonction non statique"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "déclaration de paramètres selon l'ancien style dans la définition de fonction prototypée"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "le C traditionnel rejette les définitions de fonctions de style C ISO"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "le C ISO ne supporte pas l'omission des noms des paramètres dans les définitions de fonctions avant C2X"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "définition de fonction selon l'ancien style"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "nom du paramètre manquant dans la liste des paramètres"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD déclaré comme un non paramètre"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "plusieurs paramètres nommés %qD"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "paramètre %qD déclaré avec le type « void »"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "le type de %qD devient %<int%> par défaut"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "le paramètre %qD a un type incomplet"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "déclaration du paramètre %qD mais pas de tel paramètre"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "le nombre d'arguments ne concorde pas avec celui du prototype interne"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "le nombre d'arguments ne concorde pas avec celui du prototype"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "déclaration de prototype"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "l'argument promu %qD ne concorde pas avec le prototype interne"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "l'argument promu %qD ne concorde pas avec le prototype"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "l'argument %qD ne concorde pas avec le prototype interne"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "l'argument %qD ne concorde pas avec le prototype"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "« return » manquant dans une fonction devant retourner une valeur"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "le paramètre %qD est défini mais pas utilisé"
@@ -41476,257 +41511,257 @@ msgstr "le paramètre %qD est défini mais pas utilisé"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "les déclarations initiales de boucles %<for%> ne sont permises qu'en mode C99 et C11"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "utilisez l'option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> ou %<-std=gnu11%> pour compiler votre code"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "le C90 ISO ne supporte pas les déclarations initiales de la boucle %<for%>"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable statique %qD dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable %<extern%> %qD dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de %qD (qui n'est pas une variable) dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "les qualificatifs d'espace d'adresses %qs et %qs sont incompatibles"
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "spécificateur de déclaration %qE dupliqué"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "deux types de données ou plus dans le spécificateur de déclaration"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> est trop long pour GCC"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "le C90 ISO ne supporte pas %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "le C90 ISO ne supporte pas les types « complex »"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "le C ISO ne supporte pas les types saturants"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE dupliqué"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "le C ISO ne supporte pas les types %<__int%d%>"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> n'est pas supporté sur cette cible"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "le C90 ISO ne supporte pas les types booléens"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "le C ISO ne supporte pas le type %<_Float%d%s%>"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> n'est pas supporté sur cette cible"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "le C ISO ne supporte pas les virgules flottantes décimales avant C2X"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "les types en virgule fixe ne sont pas supportés pour cette cible"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "le C ISO ne supporte pas les types en virgule fixe"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "la recherche de %qD par le C++ retournerait un champ, pas un type"
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE échoue a être un typedef ou un type interne"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE n'est pas au début de la déclaration"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE utilisé avec %<auto%>"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE utilisé avec %<register%>"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE utilisé avec %<typedef%>"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "le C99 ISO ne supporte pas %qE"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "le C90 ISO ne supporte pas %qE"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> avant %<extern%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> avant %<static%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "%<_Thread_local%> ou %<__thread%> dupliqué"
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "classes de stockage multiples dans les spécificateurs de la déclaration"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs utilisé avec %qE"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> est utilisé sans %<_Fract%> ou %<_Accum%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C ISO ne supporte pas un simple %<complex%> signifiant %<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%> suivi des attributs %<[[]]%>"
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "le C ISO interdit les types entiers complexes"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "le combinateur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "l'initialiseur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_priv%> ni %<omp_orig%>"
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "décalage vers la gauche d'une valeur négative"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "le compteur de décalages vers la gauche est négatif"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "le compteur de décalages vers la droite est négatif"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "compteur de décalages vers la gauche >= à la largeur du type"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "compteur de décalages vers la droite >= à la largeur du type"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "compteur de décalages vers la gauche >= à la largeur de l'élément du vecteur"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "compteur de décalages vers la droite >= à la largeur de l'élément du vecteur"
@@ -41746,7 +41781,7 @@ msgstr "marqueur de conflit de contrôle de version dans le fichier"
 msgid "to match this %qs"
 msgstr "pour correspondre à ce %qs"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "fin de ligne attendue"
@@ -41756,7 +41791,7 @@ msgstr "fin de ligne attendue"
 msgid "ISO C forbids an empty translation unit"
 msgstr "le C ISO interdit une unité de traduction vide"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> sans %<#pragma omp end declare target%> correspondant"
@@ -41792,7 +41827,7 @@ msgid "unknown type name %qE"
 msgstr "nom de type %qE inconnu"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "spécificateurs de déclaration attendus"
@@ -41812,7 +41847,7 @@ msgstr "attribut %<fallthrough%> au plus haut niveau"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identificateur ou %<(%> attendu"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "les attributs de préfixes sont ignorés pour les méthodes"
@@ -41827,7 +41862,7 @@ msgstr "les attributs de préfixes sont ignorés pour les implémentations"
 msgid "unexpected attribute"
 msgstr "attribut inattendu"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "l'attribut %<fallthrough%> n'est pas suivi par %<;%>"
@@ -41865,7 +41900,7 @@ msgstr "%<__auto_type%> requiert une déclaration de donnée initialisée"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> peut uniquement être utilisé avec un seul déclarateur"
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> ou %<;%> attendu"
@@ -41923,7 +41958,7 @@ msgstr "l'expression dans l'assertion statique n'est pas une constante"
 msgid "static assertion failed: %E"
 msgstr "échec de l'assertion statique: %E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "l'assertion statique a échoué"
@@ -41968,14 +42003,14 @@ msgstr "un enum vide est invalide"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identificateur attendu"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "virgule à la fin de la liste d'énumerateurs"
@@ -42060,7 +42095,7 @@ msgstr "spécificateurs de déclaration ou %<...%> attendu"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "les parenthèses doivent être omises si la liste des arguments de l'attribut est vide"
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "l'attribut %qE ne prend pas d'argument"
@@ -42120,7 +42155,7 @@ msgstr "le C90 ISO interdit les mélanges de déclarations et de code"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> attendu avant %<else%>"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> sans %<if%> précédent"
@@ -42135,7 +42170,7 @@ msgstr "étiquette à la fin d'une déclaration composée"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "instruction attendue"
@@ -42160,17 +42195,17 @@ msgstr "identificateur ou %<*%> attendu"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "seul l'attribut %<fallthrough%> peut être appliqué à une instruction nulle"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<if%>"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<else%>"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "des accolades explicites sont suggérées pour éviter toute ambiguïté sur le %<else%>"
@@ -42190,12 +42225,12 @@ msgstr "variables d'itération multiples dans l'énumération rapide"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "variable d'itération invalide dans l'énumération rapide"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "condition de boucle manquante dans la boucle avec le pragma %<GCC ivdep%>"
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "condition de boucle manquante dans la boucle avec le pragma %<GCC unroll%>"
@@ -42210,8 +42245,8 @@ msgstr "collection manquante dans l'énumération rapide"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "qualificatif %<asm%> %qE dupliqué"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr "vu pour la première fois ici"
@@ -42238,12 +42273,12 @@ msgstr "le C ISO interdit l'omission du terme central de l'expression %<?:%>"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "la division %<sizeof (%T) / sizeof (%T)%> ne calcule pas le nombre d'éléments dans le tableau"
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "le premier opérande %<sizeof%> a été déclaré ici"
@@ -42634,12 +42669,12 @@ msgstr "une déclaration de méthode objective-c est attendue"
 msgid "no type or storage class may be specified here,"
 msgstr "aucun type ni classe de stockage ne peut être spécifié ici,"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "liste d'attributs de propriété vide"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, gcc-internal-format
 msgid "missing property attribute"
 msgstr "attribut de propriété manquant"
@@ -42649,51 +42684,51 @@ msgstr "attribut de propriété manquant"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "attribut de propriété %<%s%s%> inconnu"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "attribut de propriété inconnu"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "%<=%> attendu après Objective-C %qE"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "nom de sélecteur %qE attendu"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "les noms des méthodes « setter » doivent être terminés par %<:%>"
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> requiert une expression d'affectation qui est évaluée en une constante entière non négative plus petite que %u"
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> ne peut être utilisé que dans des instructions composées"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> doit être dans la portée au niveau du fichier"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> ne peut être utilisé que dans une construction de boucle avec la clause %<inscan%> %<reduction%>"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> ne peut être utilisé que dans une construction %<#pragma omp sections%>"
@@ -42703,18 +42738,18 @@ msgstr "%<#pragma omp section%> ne peut être utilisé que dans une construction
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp requires%> peut uniquement être utilisé dans la portée du fichier"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "instruction « for », « while » ou « do » attendue"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> doit être le premier"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "trop de clauses %qs"
@@ -42734,53 +42769,53 @@ msgstr "%<)%> ou %<,%> attendu"
 msgid "%qD is not a variable"
 msgstr "%qD n'est pas une variable"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD n'est pas une variable pointeur"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "l'argument « collapse » a besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> ou %<present%> attendu"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> ou %<shared%> attendu"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> ou %<exit%> attendu"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> attendu"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "trop de %<if%> avec le modificateur %qs"
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "trop de clauses %<if%>"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "trop de clauses %<if%> sans modificateur"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si une clause %<if%> a un modificateur, alors toutes les clauses %<if%> doivent utiliser un modificateur"
@@ -42802,107 +42837,107 @@ msgstr "la valeur de %<num_threads%> doit être positive"
 msgid "%<num_tasks%> value must be positive"
 msgstr "la valeur de %<num_tasks%> doit être positive"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "la valeur de %<grainsize%> doit être positive"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "la valeur de %<priority%> doit être positive ou nulle"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "expression entière constante attendue avec une valeur sync-hint valide"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> ou %<default%> attendu"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<scalar%>, %<aggregate%> ou %<pointer%> attendu"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "trop de clauses %<defaultmap%> avec la catégorie %qs"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "trop de clauses %<defaultmap%> avec une catégorie non spécifiée"
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "l'expression %qs doit être un entier"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "la valeur de %qs doit être positive"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "trop d'arguments pour %<static%>"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argument inattendu"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "l'argument %<tile%> a besoin d'une constante entière positive"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<concurrent%> attendu"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<team%>, %<parallel%> ou %<thread%> attendu"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "les arguments ordonnés ont besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> ou identificateur attendu"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "les deux modificateurs %<monotonic%> et %<nonmonotonic%> sont spécifiés"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<runtime%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<auto%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "la taille du fragment doit être positive"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "type d'ordonnancement invalide"
@@ -42912,17 +42947,17 @@ msgstr "type d'ordonnancement invalide"
 msgid "%<num_teams%> value must be positive"
 msgstr "la valeur de %<num_teams%> doit être positive"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "la valeur de %<thread_limit%> doit être positive"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "l'expression d'alignement %<aligned%> doit être une expression entière constante positive"
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "l'expression d'allocation de la clause %<allocate%> a le type %qT plutôt que %<omp_allocator_handle_t%>"
@@ -42942,22 +42977,22 @@ msgstr "l'expression %<safelen%> doit être une expression entière constante po
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "l'expression %<simdlen%> doit être une expression entière constante positive"
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "le modificateur %<iterator%> est incompatible avec %qs"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "type de « depend » invalide"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "type de « map » invalide"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "type de « dist_schedule » invalide"
@@ -42972,82 +43007,82 @@ msgstr "type de « proc_bind » invalide"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<host%>, %<nohost%> ou %<any%> attendu"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr "le gestionnaire d'événement de la clause %<detach%> a le type %qT plutôt que %<omp_event_handle_t%>"
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "clause %<#pragma acc%> attendue"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs n'est pas valide pour %qs"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "les clauses dans un trait %<simd%> devraient être séparées par des %<,%>"
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs doit être la première clause de %qs"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "clause %<#pragma omp%> attendue"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "pas de clause valide spécifiée dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "section de tableau dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD doit être une variable globale dans %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "clause OpenACC invalide au niveau global du fichier"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<extern%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<global%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD doit être une variable déclarée dans la même portée que %<#pragma acc declare%>"
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variable %qD utilisée plus d'une fois avec %<#pragma acc declare%>"
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> attendu après %<#pragma acc %s%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> n'a pas clause de mouvement de données"
@@ -43062,7 +43097,7 @@ msgstr "%qE n'a pas été déclaré"
 msgid "expected function name"
 msgstr "nom de fonction attendu"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD ne fait pas référence à une fonction"
@@ -43072,27 +43107,27 @@ msgstr "%qD ne fait pas référence à une fonction"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une déclaration ou d'une définition de fonction"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> doit être appliqué avant l'utilisation"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> doit être appliqué avant la définition"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> doit contenir au moins une clause %<device%> ou %<host%> ou %<self%>"
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, gcc-internal-format
 msgid "expected %<allocator%>"
 msgstr "%<allocator%> attendu"
@@ -43102,82 +43137,82 @@ msgstr "%<allocator%> attendu"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "l'expression d'allocation de la clause %<allocator%> a le type %qT plutôt que %<omp_allocator_handle_t%>"
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "%<#pragma omp allocated%> n'est pas encore supporté"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "clause %<read%>, %<write%>,  %<update%> ou %<capture%> attendue"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "clause %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> ou %<hint%> attendue"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "trop de clauses atomiques"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "trop de clauses d'ordre de mémoire"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp atomic read%> est incompatible avec les clauses %<acq_rel%> ou %<release%>"
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic write%> est incompatible avec les clauses %<acq_rel%> ou %<acquire%>"
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic update%> est incompatible avec les clauses %<acq_rel%> ou %<acquire%>"
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forme invalide de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "opération invalide pour %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> utilise deux expressions différentes pour la mémoire"
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "l'expression %<depobj%> n'est pas une expression l-valeur"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<in%>, %<out%>, %<inout%> ou %<mutexinoutset%> attendu"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "clause %<depend%>, %<destroy%> ou %<update%> attendue"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<acq_rel%>, %<release%> ou %<acquire%> attendu"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "liste %<flush%> spécifiée avec une clause d'ordre de mémoire"
@@ -43187,32 +43222,32 @@ msgstr "liste %<flush%> spécifiée avec une clause d'ordre de mémoire"
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> ou fin de ligne attendue"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<inclusive%> ou %<exclusive%> attendu"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp scan%> attendu"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "le paramètre de la clause %<ordered%> est plus petit que %<collapse%>"
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "la clause %<linear%> ne peut pas être spécifiée avec la clause %<ordered%> comportant un paramètre"
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "instruction « for » attendue"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "déclaration ou initialisation d'itération attendue"
@@ -43222,72 +43257,72 @@ msgstr "déclaration ou initialisation d'itération attendue"
 msgid "not enough perfectly nested loops"
 msgstr "pas assez de boucles parfaitement imbriquées"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "boucles coalescées imparfaitement imbriquées"
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable d'itération %qD ne devrait pas être « firstprivate »"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "la clause %<ordered%> avec un paramètre ne devrait pas être spécifiée sur la construction %qs"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> avec une clause %<depend%> peut uniquement être utilisé dans des instructions composées"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> attendu après %qs"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> attendu"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur un clause %<map%>"
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> doit contenir au moins une clause %<map%>, %<use_device_ptr%> ou %<use_device_addr%>"
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> doit contenir au moins une clause %<from%> ou %<to%>"
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> avec un type avec correspondance autre que %<to%> ou %<alloc%> sur une clause %<map%>"
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> avec un type « map » autre que %<from%>, %<release%> ou %<delete%> sur une clause %<map%>"
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur une clause %<map%>"
@@ -43302,57 +43337,57 @@ msgstr "%<#pragma omp declare %s%> doit être suivi d'une déclaration ou une d
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> doit être suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "nom de sélecteur de trait attendu"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "sélecteur %qs pas permis pour l'ensemble %qs du sélecteur de contexte"
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "le sélecteur %qs n'accepte aucune propriété"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "l'argument du score doit être une expression entière constante"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "l'argument du score doit être non négatif"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "la propriété doit être une expression entière constante ou une chaîne littérale"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "identificateur ou chaîne littérale attendus"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "la propriété doit être une expression entière constante"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "les propriétés pour le sélecteur %<simd%> ne peuvent pas être spécifiées dans %<metadirective%>"
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<construct%>, %<device%>, %<implementation%> ou %<user%> attendu"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<match%> attendu"
@@ -43362,12 +43397,12 @@ msgstr "%<match%> attendu"
 msgid "variant %qD is not a function"
 msgstr "le variant %qD n'est pas une fonction"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "le variant %qD et la base %qD ont des types incompatibles"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "le variant %qD est interne"
@@ -43377,32 +43412,32 @@ msgstr "le variant %qD est interne"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare %s%> pas immédiatement suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare %s%> pas immédiatement suivi par une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD est spécifié à la fois dans les clauses declare target %<link%> et %<to%>"
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr "la directive avec uniquement des clauses %<device_type%> est ignorée"
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> attendu"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> attendu"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> sans %<#pragma omp declare target%> correspondant"
@@ -43457,42 +43492,42 @@ msgstr "nom de fonction %<(%> attendu"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<&omp_priv%>"
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<simd%>, %<reduction%>, %<target%> ou %<variant%> attendu"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<seq_cst%>, %<relaxed%> ou %<acq_rel%> attendu"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "clause %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> ou %<atomic_default_mem_order%> attendue"
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "la clause %qs sur la directive %<requires%> n'est pas encore supportée"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "clause %qs utilisée lexicalement après la construction de la première cible ou l'API de déchargement"
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "plus d'une clause %<atomic_default_mem_order%> dans une même unité de compilation"
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "clause %<atomic_default_mem_order%> utilisée lexicalement après la première construction %<atomic%> sans clause d'ordre de mémoire"
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> requiert au moins une clause"
@@ -43507,27 +43542,27 @@ msgstr "type %qT de taille nulle dans la clause %<reduction%>"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "type %qT de taille variable dans la clause %<reduction%>"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE est déclaré %<threadprivate%> après la première utilisation"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automatique %qE ne peut être %<threadprivate%>"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE a un type incomplet"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> à l'intérieur de %<__transaction_relaxed%>"
@@ -43537,7 +43572,7 @@ msgstr "%<__transaction_cancel%> à l'intérieur de %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "le %<__transaction_cancel%> extérieur n'est pas dans un %<__transaction_atomic%> extérieur ou une fonction %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> pas à l'intérieur de %<__transaction_atomic%>"
@@ -43552,7 +43587,7 @@ msgstr "pas d'accolade fermante"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD a un type incomplet %qT"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "utilisation invalide de l'expression void"
@@ -43593,127 +43628,127 @@ msgstr "l'attribut %qs ne peut pas être appliqué à une fonction qui ne prend
 msgid "function types not truly compatible in ISO C"
 msgstr "types fonctions pas vraiment compatibles en C ISO"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "les opérandes de types décimaux flottants et vectoriels ne peuvent pas être mélangés"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "les opérandes de types décimaux flottants et complexes ne peuvent pas être mélangés"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "les opérandes de types décimaux flottants ne peuvent pas être mélangés avec d'autres flottants"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "des pointeurs vers des tableaux avec des qualificatifs différents sont incompatibles en C ISO"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "les types ne sont pas vraiment compatibles"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "les types ciblés par les pointeurs sont incompatibles en C++"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "les types retournés par les fonctions ne sont pas compatibles en raison de %<volatile%>"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "convertir un tableau de littéraux composés en un pointeur est mal formé en C++"
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT n'a pas de membre nommé %qE; vouliez-vous employer %qE ?"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT n'a pas de membre nommé %qE"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr "accès au membre %qE d'une structure %qE atomique"
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "accès au membre %qE d'une union %qE atomique"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr "%qE est un pointeur; vouliez-vous utiliser %<->%> ?"
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "accès au membre %qE de quelque chose qui n'est ni une structure ni une union"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "déréférencement d'un pointeur %<void *%>"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "la valeur de l'indice n'est ni un tableau ni un pointeur ni un vecteur"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "l'indice du tableau n'est pas un entier"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "la valeur de l'indice est un pointeur vers une fonction"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "le C ISO interdit d'accéder aux tableaux %<register%> par un indice"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "le C90 ISO interdit d'accéder à un tableau par un indice si le tableau n'est pas une l-valeur"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr "constante enum définie ici"
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> sur le tableau %qE en paramètre de fonction retournera la taille de %qT"
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "l'objet appelé %qE n'est pas une fonction ou un pointeur de fonction"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "l'objet %qD appelé n'est pas une fonction ou un pointeur de fonction"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "l'objet appelé n'est pas une fonction ou un pointeur de fonction"
@@ -43721,1596 +43756,1596 @@ msgstr "l'objet appelé n'est pas une fonction ou un pointeur de fonction"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "fonction appelée à travers un type non compatible"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "fonction appelée avec un type de retour void qualifié"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "le type du paramètre formel %d est incomplet"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "passage de l'argument %d de %qE comme entier au lieu de flottant à cause du prototype"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "passage de l'argument %d de %qE comme entier au lieu de complexe à cause du prototype"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "passage de l'argument %d de %qE comme complexe au lieu de flottant à cause du prototype"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "passage de l'argument %d de %qE comme flottant au lieu d'entier à cause du prototype"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "passage de l'argument %d de %qE comme complexe au lieu d'entier à cause du prototype"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "passage de l'argument %d de %qE comme flottant au lieu de complexe à cause du prototype"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "passage de l'argument %d de %qE comme %<float%> au lieu de %<double%> à cause du prototype"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "passage de l'argument %d de %qE comme %qT au lieu de %qT à cause du prototype"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "passage de l'argument %d de %qE avec des largeurs différentes à cause du prototype"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "passage de l'argument %d de %qE comme un non signé à cause du prototype"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "passage de l'argument %d de %qE comme signé à cause du prototype"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "trop d'arguments pour la fonction %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, gcc-internal-format
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "trop d'arguments pour la fonction interne %qE %d attendus"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "conversion implicite de %qT en %qT lors du passage de l'argument à la fonction"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, gcc-internal-format
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "trop peu d'arguments pour la fonction interne %qE %u attendus"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "une comparaison avec une chaîne littérale produit un résultat non spécifié"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "comparaison entre un pointeur et la constante caractère zéro"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "vouliez-vous déréférencer le pointeur ?"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "comparaison entre %qT et %qT"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "pointeur de type %<void *%> utilisé dans une soustraction"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "pointeur vers une fonction utilisé dans une soustraction"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "arithmétique sur un pointeur vers un type incomplet"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "arithmétique sur un pointeur vers un agrégat vide"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> sur une expression booléenne"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "vouliez-vous utiliser le « non » logique ?"
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "le C ISO ne permet pas d'utiliser %<~%> pour calculer le conjugué d'un complexe"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, gcc-internal-format
 msgid "wrong type argument to absu"
 msgstr "type d'argument erroné pour absu"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "type d'argument erroné pour le point d'exclamation unaire"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "incrémenter une valeur énumérée est invalide en C++"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "décrémenter une valeur énumérée est invalide en C++"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "incrémentation d'une expression booléenne"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "décrémentation d'une expression booléenne"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "le C ISO ne permet pas %<++%> ni %<--%> sur les types complexes"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "type d'argument erroné pour un incrément"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "type d'argument erroné pour un décrément"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "incrément d'un pointeur vers un type incomplet %qT"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "décrément d'un pointeur vers un type incomplet %qT"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "prise de l'adresse d'une expression de type %<void%>"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "ne peut prendre l'adresse du champ de bits %qD"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "ne peut prendre l'adresse d'un scalaire avec un ordre de stockage inversé"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "adresse demandée pour un tableau avec un ordre de stockage scalaire inversé"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "variable globale de registre %qD utilisée dans une fonction imbriquée"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "variable de registre %qD utilisée dans une fonction imbriquée"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "adresse d'une variable registre globale %qD demandée"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "adresse d'une variable registre %qD demandée"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "le tableau n'est pas une l-valeur dans l'expression conditionnelle"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "conversion implicite depuis %qT vers %qT pour correspondre à d'autres résultats de la condition"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr "l'opérande de %<?:%> change de type signé de %qT à %qT à cause du caractère non signé de l'autre opérande"
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "le C ISO interdit une expression conditionnelle dont un seul côté est « void »"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "pointeurs vers des espaces d'adresses disjoints utilisés dans une expression conditionnelle"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "le pointeur vers le tableau perd le qualificatif dans l'expression conditionnelle"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "le C ISO interdit une expression conditionnelle entre %<void *%> et un pointeur de fonction"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, gcc-internal-format
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "non concordance de type de pointeurs entre %qT et %qT de %qD et %qD dans une expression conditionnelle"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "non concordance de type de pointeurs dans une expression conditionnelle"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "non concordance entre un pointeur et un entier dans une expression conditionnelle"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "non concordance de type dans une expression conditionnelle"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "la valeur de retour de %qD est ignorée alors qu'elle est déclarée avec l'attribut %<nodiscard%> : %E"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "la valeur de retour de %qD est ignorée alors qu'elle est déclarée avec l'attribut %<nodiscard%>"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "la valeur de retour de type %qT est ignorée alors qu'elle est déclarée avec l'attribut %<nodiscard%> : %E"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "la valeur de retour de type %qT est ignorée alors qu'elle est déclarée avec l'attribut %<nodiscard%>"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "dans l'appel à %qD, déclaré ici"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "l'opérande à gauche de la virgule n'a pas d'effet"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "l'opérande à droite de la virgule n'a pas d'effet"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr "le transtypage ajoute le qualificatif %q#v au type de la fonction"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "le transtypage annule le qualificatif %qv du type ciblé par le pointeur"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "pour être sûrs, tous les pointeurs intermédiaires dans les transtypages de %qT vers %qT doivent être qualifiés avec %<const%>"
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "le transtypage spécifie un type de tableau"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "le transtypage spécifie un type de fonction"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "le C ISO interdit le transtypage d'un type non scalaire vers lui-même"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "le C ISO interdit le transtypage vers un type union"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "transtypage vers un type union depuis un type absent de l'union"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "transtypage vers un pointeur de l'espace d'adresses %s depuis un pointeur d'espace d'adresses générique disjoint"
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "transtypage vers un pointeur de l'espace d'adresses générique vers un pointeur de l'espace d'adresses %s disjoint"
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "transtypage vers un pointeur de l'espace d'adresses %s depuis un pointeur de l'espace d'adresses %s disjoint"
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "le transtypage augmente l'alignement requis pour le type ciblé"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "transtypage d'un pointeur vers un entier de taille différente"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "transtypage d'un appel de fonction de type %qT vers le type %qT ne correspondant pas"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "transtypage vers un pointeur depuis un entier de taille différente"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "le C ISO interdit la conversion d'un pointeur de fonction en un type de pointeur vers un objet"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "le C ISO interdit la conversion d'un pointeur vers un objet en un type de pointeur vers une fonction"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "transtypage entre des types de fonction incompatibles de %qT vers %qT"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "définir un type dans un transtypage est invalide en C++"
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "affectation vers une expression de type tableau"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "la conversion en enum dans une affectation est invalide en C++"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(près de l'initialisation de %qs)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "tableau initialisé depuis une constante chaîne entre parenthèses"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "%qT attendu mais l'argument est de type %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr "dans %qD, le type de l'argument %d est %qT quand %qT est attendu dans un appel à une fonction interne déclarée sans prototype"
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr "dans %qD, l'argument %d promeut vers %qT quand %qT est attendu dans un appel à une fonction interne déclarée sans prototype"
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr "la fonction interne %qD est déclarée ici"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "la conversion d'un enum lors du passage de l'argument %d de %qE est invalide en C++"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "la conversion d'un enum de %qT vers %qT dans une affectation est invalide en C++"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "la conversion d'un enum de %qT vers %qT durant l'initialisation est invalide en C++"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "la conversion d'un enum de %qT vers %qT durant le retour est invalide en C++"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT"
 msgstr "conversion implicite de %qT vers %qT"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "passer l'argument %d de %qE ajoute le qualificatif %q#v au pointeur de fonction qui n'avait pas de qualificatif"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "l'affectation ajoute la qualificatif %q#v au pointeur de fonction qui n'avait pas de qualificatif"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "l'initialisation ajoute le qualificatif %q#v au pointeur de fonction qui n'avait pas de qualificatif"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "le retour ajoute le qualificatif %q#v au pointeur de fonction qui n'avait pas de qualificatif"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "passer l'argument %d de %qE abandonne le qualificatif %qv du type pointé"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "l'affectation abandonne le qualificatif %qv du type pointé"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "l'initialisation abandonne le qualificatif %qv du type pointé"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "le retour abandonne le qualificatif %qv du type pointé"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "le C ISO interdit la conversion d'argument en type union"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "la conversion implicite de %qT vers %qT n'est pas permise en C++"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "passage de l'argument %d de %qE depuis un pointeur vers un espace d'adresses non fermé"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "affectation depuis un pointeur vers un espace d'adresses non fermé"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "initialisation depuis un pointeur vers un espace d'adresses non fermé"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "retour depuis un pointeur vers un espace d'adresses non fermé"
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "l'argument %d de %qE pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'affectation pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'initialisation pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "le type de retour pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "passage de l'argument %d de %qE depuis un ordre de stockage scalaire incompatible"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "affectation à %qT depuis un type pointeur %qT avec un ordre de stockage scalaire incompatible"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "initialisation de %qT depuis un type pointeur %qT avec un ordre de stockage scalaire incompatible"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "retour de %qT depuis un type pointeur avec un ordre de stockage scalaire %qT incompatible"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "le C ISO interdit de passer l'argument %d de %qE entre un pointeur de fonction et %<void *%>"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "le C ISO interdit l'affectation entre un pointeur de fonction et %<void *%>"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "le C ISO interdit l'initialisation entre un pointeur de fonction et %<void *%>"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "le C ISO interdit le retour entre un pointeur de fonction et %<void *%>"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "les cibles pointées dans le passage de l'argument %d de %qE diffèrent dans la plage signée"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "les cibles pointées dans l'affectation de %qT vers %qT diffèrent dans la plage signée"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "les cibles pointées dans l'initialisation de %qT depuis %qT diffèrent dans la plage signée"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "les cibles pointées en retournant %qT depuis une fonction qui retourne le type %qT  diffèrent dans la plage signée"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "passage de l'argument %d de %qE depuis un type pointeur incompatible"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "affectation à %qT depuis un pointeur vers %qD avec le type incompatible %qT"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "affectation à %qT depuis le type pointeur %qT qui est incompatible"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "initialisation de %qT depuis un pointeur vers %qD avec le type incompatible %qT"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "initialisation de %qT depuis le type pointeur %qT qui est incompatible"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "retour d'un pointeur vers %qD de type %qT depuis une fonction avec le type incompatible %qT"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "retour de %qT depuis une fonction avec le type de retour %qT qui est incompatible"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "le passage de l'argument %d de %qE transforme un entier en pointeur sans transtypage"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "l'affectation à %qT depuis %qT transforme un entier en pointeur sans transtypage"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "l'initialisation de %qT depuis %qT transforme un entier en pointeur sans transtypage"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "retourner %qT depuis une fonction avec le type de retour %qT transforme un entier en pointeur sans transtypage"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "le passage de l'argument %d de %qE transforme un pointeur en entier sans transtypage"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "l'affectation à %qT depuis %qT transforme un pointeur en entier sans transtypage"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "l'initialisation de %qT depuis %qT transforme un pointeur en entier sans transtypage"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "retourner %qT depuis une fonction qui retourne le type %qT transforme un pointeur en entier sans transtypage"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "type incompatible pour l'argument %d de %qE"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "types incompatibles dans l'affectation au type %qT depuis le type %qT"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "types incompatibles dans l'initialisation du type %qT en utilisant le type %qT"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "types incompatibles en retournant le type %qT alors que %qT était attendu"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "le C traditionnel rejette l'initialisation automatique d'agrégats"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisation d'un membre de tableau flexible"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "impossible d'initialiser un tableau de %qT depuis une chaîne de caractères littérale avec un tableau de type %qT"
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "tableau d'un type inapproprié initialisé avec une chaîne constante"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "utilisation invalide d'un tableau n'étant pas une l-valeur"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "un élément de l'initialisation n'est pas une constante"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "tableau initialisé à l'aide d'une expression de tableau non constante"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "un élément de l'initialisation n'est pas une expression constante"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "un élément de l'initialisation n'est pas évaluable lors du chargement"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "initialisation invalide"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "type de vecteur opaque ne peut être initialisé"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "groupe d'accolades superflu à la fin de l'initialisation"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "accolades autour d'une initialisation d'un scalaire"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisation d'un membre de tableau flexible dans un contexte imbriqué"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "accolades manquantes autour de l'initialisation"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "initialisation manquante pour le champ %qD de %qT"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "initialisation vide d'un scalaire"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "éléments superflus dans l'initialisation d'un scalaire"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "index de tableau dans l'initialisation de quelque chose n'étant pas un tableau"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "le nom du champ n'est pas dans l'initialisation de l'enregistrement ou de l'union"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "l'index de tableau dans l'initialisation n'est pas un entier"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "l'index de tableau dans l'initialisation n'est pas une expression entière constante"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "index de tableau non constant dans l'initialisation"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "l'index de tableau dépasse les limites du tableau dans l'initialisation"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "plage de l'index vide dans l'initialisation"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "la plage d'index du tableau excède les limites du tableau dans l'initialisation"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "le champ initialisé a des effets de bord écrasés"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "le champ initialisé est écrasé"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "la conversion en enum durant l'initialisation est invalide en C++"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, gcc-internal-format
 msgid "excess elements in %<char%> array initializer"
 msgstr "trop d'éléments dans l'initialisation de tableau de %<char%>"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "trop d'éléments dans l'initialisation de la structure"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "initialisation par position de champs dans une %<struct%> qui est déclarée avec l'attribut %<designated_init%>"
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "initialisation non statique d'un membre de tableau flexible"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "trop d'éléments dans l'initialisation de l'union"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "le C traditionnel rejette l'initialisation des unions"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "trop d'éléments dans l'initialisation du tableau"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "trop d'éléments dans l'initialisation du vecteur"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "trop d'éléments dans l'initialisation d'un scalaire"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "le C ISO interdit %<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la fonction est déclarée avec %<noreturn%> mais elle utilise l'instruction %<return%>"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> sans valeur dans une fonction retournant autre chose que void"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> avec une valeur dans une fonction retournant un void"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "le C ISO interdit %<return%> avec une expression dans une fonction qui retourne un void"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "la fonction retourne l'adresse d'une étiquette"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "la quantité du switch n'est pas un entier"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "l'expression %<long%> du « switch » n'est pas convertie en %<int%> avec le C ISO"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "l'étiquette du « case » doit être une expression constante entière"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "étiquette « case » en dehors de tout « switch »"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "étiquette %<default%> en dehors de tout « switch »"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "mot-clé « break » à l'extérieur de toute boucle ou « switch »"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "sortie invalide du bloc structuré OpenMP"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "mot-clé « break » utilisé dans une boucle OpenMP"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "mot-clé « continue » à l'extérieur de toute boucle"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "déclaration sans effet"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "l'instruction de l'expression a un type incomplet"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "comparaison de vecteurs avec des types d'éléments différents"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "comparaison de vecteurs avec des nombres d'éléments différents"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "n'a pu trouver un type entier de la même taille que %qT"
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "comparer des nombres flottants à l'aide de %<==%> ou %<!=%> n'est pas sûr"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "la comparaison sera toujours %<false%> car l'adresse de %qD ne sera jamais NULL"
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "la comparaison sera toujours %<true%> car l'adresse de %qD ne sera jamais NULL"
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "comparaison de pointeurs vers des espaces d'adresses disjoints"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "le C ISO interdit la comparaison de %<void *%> avec un pointeur de fonction"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "il manque un transtypage pour comparer des types de pointeurs distincts"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "comparaison entre un pointeur et un entier"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "comparaison de pointeurs complet et incomplet"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "le C ISO interdit les comparaisons ordonnées de pointeurs vers des fonctions"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "comparaison ordonnée d'un pointeur avec un pointeur nul"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparaison ordonnée d'un pointeur avec un zéro entier"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "conversion implicite de %qT vers %qT pour correspondre à d'autres opérandes de l'expression binaire"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "le tableau utilisé ne peut pas être converti en pointeur là où un scalaire est requis"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "valeur de type « struct » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "valeur de type « union » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "valeur de type « vector » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "modificateur de clause %<cancel%> %<if%> attendus"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE dans la clause %qs"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "champ de bits %qE dans la clause %qs"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE est un membre d'une union"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "impossible de déréférencer %qE dans la clause %qs"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD dans la clause %qs"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD est une variable « threadprivate » dans la clause %qs"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "la borne inférieure %qE de la section du tableau n'a pas un type entier"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "la longueur %qE de la section du tableau n'a pas un type entier"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "pointeur unique attendu dans la clause %qs"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "section de tableau ayant une longueur nulle dans la clause %qs"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type tableau dont la limite est inconnue"
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "limite inférieure négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "longueur négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "limite inférieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "longueur %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "limite supérieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
 # Ce message ne veut absolument rien dire !
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "pour une fonction tableau, l'expression de longueur du paramètre doit être spécifiée"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type pointeur"
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "la section du tableau n'est pas contigüe dans la clause %qs"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE n'a pas un type pointeur ou tableau"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "l'itérateur %qD n'a pas le type entier ni le type pointeur"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "l'itérateur %qD a le type qualifié par %<_Atomic%>"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "l'itérateur %qD à le type qualifié par « const »"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "pas de l'itérateur avec un type non entier"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr "l'itérateur %qD a un pas de zéro"
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr "le type de l'itérateur %qD fait référence à l'itérateur extérieur %qD"
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "l'expression de début fait référence à l'itérateur extérieur %qD"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "l'expression de fin fait référence à l'itérateur extérieur %qD"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "l'expression de pas fait référence à l'itérateur extérieur %qD"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "pointeur attendu dans la clause %qs"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "clauses %<inscan%> et non-%<inscan%> %<reduction%> sur la même construction"
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "clause %<inscan%> %<reduction%> avec une section de tableau"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD dans la clause %<reduction%> est un tableau de taille nulle"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE dans la clause %<reduction%>"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr "type de taille nulle %qT dans la clause %qs"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr "type de taille variable %qT dans la clause %qs"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE a un type invalide pour %<reduction(%s)%>"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "réduction définie par l'utilisateur pas trouvée pour %qE"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "type d'élément de longueur variable dans la table de la clause %<reduction%>"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la clause %<nowait%> ne doit pas être utilisée avec %<copyprivate%>"
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE doit être %<threadprivate%> pour %<copyin%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "le modificateur ne devrait pas être spécifié dans la clause %<linear%> sur des constructions %<simd%> ou %<for%>"
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "clause linéaire appliquée à une variable non entière non pointeur de type %qT"
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD dans la clause %<linear%>"
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "le pas %qE de la clause %<linear%> n'est ni une constante ni un paramètre"
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de réduction"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE apparaît plus d'une fois dans les clauses de données"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de données"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD apparaît à la fois dans les clauses « data » et « map »"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<firstprivate%>"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<lastprivate%>"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<aligned%>"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "%qE dans la clause %<aligned%> n'est ni un pointeur ni un tableau"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%<_Atomic%> %qD dans la clause %<aligned%>"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE apparaît plus d'une fois dans les clause %<aligned%>"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<nontemporal%>"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE apparaît plus d'une fois dans les clauses %<nontemporal%>"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<allocate%>"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE apparaît plus d'une fois dans les clause %<allocate%>"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr "clause %<depend%> avec le type de dépendance %<depobj%> sur une section de tableau"
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE n'est pas une une expression l-valeur ni une section de tableau dans la clause %<depend%>"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr "%qE n'a pas le type %<omp_depend_t%> dans la clause %<depend%> avec le type de dépendance %<depobj%>"
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr "%qE ne devrait pas avoir le type %<omp_depend_t%> dans la clause %<depend%> avec un type de dépendance autre que %<depobj%>"
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "la section du tableau n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de mouvement"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses « map »"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD n'a pas un type pour lequel la correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE n'est ni une variable ni un nom de fonction dans la clause %qs"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE apparaît plus d'une fois dans la même directive %<declare target%>"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD n'est pas un argument dans la clause %<uniform%>"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE n'est pas un argument dans la clause %<uniform%>"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "la variable %qs n'est pas un pointeur"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "la clause %<order%> ne doit pas être utilisée avec %<ordered%>"
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "trop de clauses %qs dans une construction de tâche"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la clause %<inbranch%> est incompatible avec %<notinbranch%>"
 
 # le premier %qs est un mot non traduit tel que « private », « shared » ou « threadprivate ».
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE est prédéterminé %qs pour %qs"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%qE qualifié avec %<const%> peut uniquement apparaître dans les clauses %<shared%> ou %<firstprivate%>"
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "la valeur de la clause %<simdlen%> est plus grande que la valeur de la clause %<safelen%>"
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "modificateur d'ordonnancement %<nonmonotonic%> spécifié en même temps que la clause %<ordered%>"
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "clause %qs spécifiée en même temps que la clause %<inscan%> %<reduction%>"
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "le pas de la clause %<linear%> est un paramètre %qD pas spécifié dans la clause %<uniform%>"
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "la clause %<nogroup%> ne doit pas être utilisée avec la clause %<reduction%>"
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "la clause %<detach%> ne doit pas être utilisée avec la clause %<mergeable%>"
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr "l'identificateur de l'événement d'une clause %<detach%> ne devrait pas être dans une clause qui partage des données"
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "impossible d'utiliser %<va_arg%> avec un ordre de stockage inversé"
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "le deuxième argument de %<va_arg%> est du type incompatible %qT"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "le C++ exige un type promu, pas un type enum, dans %<va_arg%>"
@@ -45515,7 +45550,7 @@ msgstr "  pas de conversion connue pour convertir %qH en %qI"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  pas de conversion connue pour convertir l'argument %d depuis %qH vers %qI"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -45624,661 +45659,667 @@ msgstr "initialiser %qH avec %qI dans une expression constante convertie n'est p
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "conversion de %qH vers %qI dans une expression constante convertie"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "pas de fonction correspondant à l'appel %<%D(%A)%>"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "appel ambigu à la surcharge %<%D(%A)%>"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "le pointeur vers la fonction membre %qE ne peut être appelé sans un objet; utilisez %<.*%> ou %<->*%>"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "pas de concordance pour l'appel à %<(%T) (%A)%>"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "l'appel à %<(%T) (%A)%> est ambigu"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "surcharge ambiguë pour "
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr "pas de concordance pour "
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (les types des opérandes sont %qT, %qT et %qT)"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (les types des opérandes sont %qT et %qT)"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (le type de l'opérande est %qT)"
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "%<operator?:%> ternaire"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<operator?:%> ternaire dans %<%E ? %E : %E%>"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> dans %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> dans %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs dans %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%<operator %s%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator %s%> dans %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> dans %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> dans %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "le C++ ISO interdit l'omission du terme au milieu de l'expression %<?:%>"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "le type scalaire inféré %qT n'est pas un type entier ou en virgule flottante de la même taille que %qT"
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "la conversion du scalaire %qH vers le vecteur %qI implique une troncature"
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "types vectoriels incompatibles dans l'expression conditionnelle: %qT, %qT et %qT"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "le deuxième opérande de l'opérateur conditionnel a le type %<void%> mais le troisième opérande n'est ni une expression qui génère une exception ni le type %<void%>"
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "le troisième opérande de l'opérateur conditionnel a le type %<void%> mais le deuxième opérande n'est ni une expression qui génère une exception ni le type %<void%>"
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "les opérandes de %<?:%> ont les types différents %qT et %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  et chaque type peut être converti en l'autre"
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "conversion implicite depuis %qH vers %qI pour correspondre à d'autres résultats de la condition"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "non concordance dans les énumérés de l'expression conditionnelle: %qT vs %qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "l'expression conditionnelle entre le type énuméré %qT et le type en virgule flottante %qT est dépréciée"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "l'expression conditionnelle entre le type en virgule flottante %qT et le type énuméré %qT est dépréciée"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "type énuméré et non énuméré dans l'expression conditionnelle"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "pas de %<%D(int)%> déclaré pour l'opérateur suffixé %qs, on essaie avec l'opérateur préfixé à la place"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "pas de %<%D(int)%> déclaré pour l'opérateur suffixé %qs"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "en C++20, cette comparaison appelle la fonction actuelle récursivement avec les arguments inversés"
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "le type de retour de %qD n'est pas %qs"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "utilisé comme candidat réécrit pour la comparaison de %qT et %qT"
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "comparaison entre %q#T et %q#T"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "le nettoyage pendant une exception pour cet opérateur « new » avec placement sélectionne %<operator delete%> sans placement"
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD est une fonction de désallocation habituelle (sans placement) en C++14 (ou avec %<-fsized-deallocation%>)"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD est une fonction de désallocation habituelle (sans placement)"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "pas de fonction de désallocation correspondante pour %qD"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "pas de %<operator %s%> adapté pour %qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D est privé dans ce contexte"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "déclaré privé ici"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D est protégé dans ce contexte"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "déclaré protégé ici"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D est inaccessible dans ce contexte"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "passage de NULL pour l'argument non pointeur %P de %qD"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  déclaré ici"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "conversion vers un type non pointeur %qT à partir de NULL"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "conversion de %<false%> vers un type pointeur pour l'argument %P de %qD"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "conversion de %<false%> vers le type pointeur %qT"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  initialisation de l'argument %P de %qD"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les conversions vers des tableaux aux limites inconnues sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "trop d'accolades autour de l'initialiseur pour %qT"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "la conversion vers %qH depuis %qI requiert une initialisation directe"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "la conversion définie par l'utilisateur de %qH vers %qI est invalide"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "conversion invalide de %qH vers %qI"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "la conversion de la liste d'initialisation vers %qT utiliserait le constructeur explicite %qD"
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "en C++11 et au delà, un constructeur par défaut peut être explicite"
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "impossible de lier la référence d'une r-valeur de type %qH à une l-valeur de type %qI"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+#| msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "impossible de lier la référence d'une l-valeur non constante de type %qH à une r-valeur de type %qI"
+
+#: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "impossible de lier la référence d'une l-valeur non constante de type %qH à une r-valeur de type %qI"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "impossible de lier la référence de type %qH vers %qI à cause des limites différentes des tableaux"
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "lier la référence du type %qH à %qI abandonne les qualificatifs"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ne peut lier le champ de bits %qE avec %qT"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "ne peut lier le champs empaqueté %qE avec %qT"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "ne peut lier la r-valeur %qE avec %qT"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "conversion implicite de %qH en %qI lors du passage de l'argument à la fonction"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "l'énumération %qT dans une portée limitée est passée au travers de %<...%> en tant que %qT avant %<-fabi-version=6%> et en tant que %qT après"
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "le passage d'objets du type %q#T non trivialement copiables au travers de %<...%> est supporté conditionnellement"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "impossible de recevoir le type référencé %qT au travers de %<...%>"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "la réception d'objets du type %q#T non trivialement copiables au travers de %<...%> est supporté conditionnellement"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "évaluation récursive de l'argument par défaut pour %q#D"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "l'appel à %qD utilise l'argument par défaut du paramètre %P qui n'est pas encore défini"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "l'argument de l'appel de fonction pourrait être un candidat pour un attribut de format"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "utilisation d'une fonction ayant plusieurs versions sans version par défaut"
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "le passage de %qT comme argument %<this%> abandonne les qualificatifs"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dans l'appel de %qD"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT n'est pas une base accessible de %qT"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "passage des arguments à l'élision du constructeur hérité %qD"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "l'affectation depuis le %<initializer_list%> temporaire n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "écriture %qD vers un objet de type %#qT sans affectation par copie triviale"
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "écriture %qD vers un objet de type non trivial %#qT%s"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "écriture %qD vers un objet de type %#qT avec le membre %qs de %qD"
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "écriture %qD vers un objet de type %#qT contenant un pointeur vers le membre de donnée%s"
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; utilisez plutôt une affectation ou une initialisation par valeur"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; utilisez plutôt une affectation"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; utilisez plutôt une initialisation par valeur"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD effacement d'un objet de type %#qT sans affectation par copie triviale%s"
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD effacement d'un objet du type non trivial %#qT%s"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD effacement d'un objet de type %#qT contenant un pointeur vers un membre%s"
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; utilisez plutôt une affectation par copie ou une initialisation par copie"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; utilisez plutôt une affectation par copie"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; utilisez plutôt une initialisation par copie"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD écriture dans un objet de type %#qT sans affectation par copie triviale%s"
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD écriture dans un objet du type non trivialement copiable %#qT%s"
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD écriture dans un objet avec un constructeur par copie supprimé"
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD copie un objet du type non trivial %#qT depuis un tableau de %#qT"
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD copie un objet de type %#qT avec le membre %qs de %qD depuis un tableau de %#qT; utilisez plutôt une affectation ou une initialisation par copie"
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD écriture dans un objet du type non trivial %#qT laisse %wu octets inchangés"
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD écriture dans un objet du type non trivial %#qT laisse %wu octet inchangé"
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD déplacement d'un objet du type non trivialement copiable %#qT; utilisez plutôt %<new%> et %<delete%>"
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD déplacement d'un objet de type %#qT avec un constructeur par copie supprimé; utilisez plutôt %<new%> et %<delete%>"
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD déplacement d'un objet de type %#qT avec un destructeur supprimé"
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD déplacement d'un objet du type non trivial %#qT et de taille %E dans une région de taille %E"
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT déclaré ici"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "le constructeur délègue à lui-même"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 msgid "cannot convert %qH to %qI"
 msgstr "ne peut convertir %qH en %qI"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "appel à la non fonction %qD"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "ne peut appeler le constructeur %<%T::%D%> directement"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "pour un transtypage de style « fonction », enlevez le %<::%D%> redondant"
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "pas de fonction concordante pour l'appel de %<%s(%A)%>"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "appel ambigu à la surcharge %<%s(%A)%>"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "appel à %q#D qui est pur virtuel depuis un initialisateur qui n'est pas un membre statique"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le constructeur"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le destructeur"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "impossible d'appeler la fonction membre %qD sans objet"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "le passage de %qT choisi %qT au lieu de %qT"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "choix de %qD à la place de %qD"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 msgid "  for conversion from %qH to %qI"
 msgstr "  pour la conversion de %qH vers %qI"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  parce que la séquence de conversion pour l'argument est meilleure"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "désaccord dans l'argument par défaut lors de la résolution de la surcharge"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidat 1: %q#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidat 2: %q#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "le C++ ISO indique que ceux-ci sont ambigus même si la plus mauvaise conversion pour le premier est meilleures que la plus mauvaise conversion pour le second:"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "une limite temporaire sur %qD existe uniquement jusqu'à la sortie du constructeur"
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "initialisation invalide pour une référence non constante du type %qH à partir d'une r-valeur de type %qI"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "initialisation invalide pour une référence du type %qH à partir d'une expression de type %qI"
 
@@ -46302,1128 +46343,1128 @@ msgstr "impossible de convertir depuis un pointeur sur la classe de base %qT ver
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "impossible de convertir depuis la classe de base %qT vers la classe dérivée %qT via la classe de base virtuelle %qT"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "impossible de convertir depuis %qT vers la classe de base %qT car %qT est incomplet"
 
 # ce message apparaît juste après le %q#D ci-dessus
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D est en conflit avec la version héritée de %qT"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "la version héritée de %qT est déclarée ici"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D ne peut pas être surchargé par %q#D"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "déclaration précédente de %q#D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "spécifications d'accès conflictuelles pour la méthode %q+D, ignoré"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "spécifications d'accès conflictuelles pour le champ %qE, ignoré"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "%qD invalide dans %q#T à cause de la méthode locale %q#D avec le même nom"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "méthode locale %q#D, déclarée ici"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "%qD invalide dans %q#T à cause du membre local %q#D avec le même nom"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "membre local %q#D déclaré ici"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD hérite de l'étiquette de l'ABI %E que %qT (utilisé dans son type de retour) a déjà"
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT déclaré ici"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD hérite de l'étiquette de l'ABI %E que %qT (utilisé dans son type) a déjà"
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qT n'a pas l'étiquette de l'ABI %E que la classe de base %qT a"
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qT ne possède pas l'étiquette de l'ABI %E que %qT (utilisé dans le type de %qD) possède"
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "impossible de dériver de la classe de base %<final%> %qT dans le type dérivé %qT"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "toutes les fonctions membre de la classe %qT sont privées"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T définit uniquement un destructeur privé et n'a pas d'amis"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T définit uniquement des constructeurs privés et n'a pas d'amis"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D est public mais requiert un objet %q#T existant"
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "pas de redéfinition finale unique pour %qD dans %qT"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD peut être marqué « override »"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D est marqué %<override%> mais il ne redéfini rien"
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D est marqué %<final%> mais il n'est pas virtuel"
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD était caché"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  par %qD"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D est invalide; une union anonyme ne peut avoir que des membres de données publiques non statiques"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "cette flexibilité est dépréciée et sera supprimée"
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "l'élision dans %qD n'est pas héritée"
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "champ de bits %q#D avec le type non entier %qT"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "la largeur du champ de bits %q+D n'est pas une constante entière"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "largeur négative dans le champ de bits %q+D"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "largeur nulle pour le champ de bits %q+D"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "la largeur de %qD dépasse celle de son type"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD est trop petit pour contenir toutes les valeurs de %q#T"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "le membre %q+#D avec un constructeur n'est pas permis dans l'union"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "le membre %q+#D avec destructeur n'est pas permis dans l'union"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "le membre %q#D avec un opérateur d’affectation par copie n'est pas permis dans l'union"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les unions sans restrictions sont disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "en C++98, %q+D ne peut pas être statique parce qu'il est un membre d'une union"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "le membre de donnée non statique %q+D dans une union ne peut pas avoir le type référencé %qT"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "le membre de données %q+D est incorrectement déclaré avec le type d'une fonction"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "le membre de données %q+D est incorrectement déclaré comme type de méthode"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "attribut « packed » ignoré à cause du champ non POD non empaqueté %q#D"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "le membre %q+D ne peut pas être déclaré comme une référence %<mutable%>"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "le membre %q+D ne peut pas être déclaré à la fois %<const%> et %<mutable%>"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "champs multiples initialisés dans l'union %qT"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "le membre %q+D initialisé est déclaré ici"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "champ %q#D avec le même nom que la classe"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T a des membres de données qui sont des pointeurs"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  mais il ne déclare pas %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  ou %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  mais il ne déclare pas %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "membre pointeur %q+D déclaré ici"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "l'alignement de %qD a augmenté avec %<-fabi-version=9%> (GCC 5.2)"
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "l'alignement de %qD augmentera avec %<-fabi-version=9%>"
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initialisation spécifiée pour une méthode non virtuelle %q+D"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "le destructeur pour %qT est ambigu"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "la méthode redéfini à la fois les méthodes %<transaction_pure%> et %qE"
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "la méthode déclarée %qE redéfini la méthode %qE"
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "la classe englobant la fonction membre non statique %<constexpr%> %q+#D n'est pas un type littéral"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T n'est pas littéral à cause de:"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT est un type de fermeture qui n'est un littéral qu'à partir du C++17"
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T a un destructeur non trivial"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T n'a pas de destructeur %<constexpr%>"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T n'est pas un agrégat, n'a pas de constructeur par défaut trivial et n'a pas de constructeur %<constexpr%> qui n'est pas un constructeur de copie ou par déplacement"
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  la classe de base %qT de %q+T n'est pas littérale"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  le membre de donnée non statique %qD a un type non littéral"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  le membre de donnée non statique %qD a un type volatile"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "la classe de base %q#T a un destructeur non virtuel accessible"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "la référence non statique %q#D dans la classe sans un constructeur"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "le membre constant non statique %q#D dans la classe sans un constructeur"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "la base directe %qT est inaccessible dans %qT en raison de l'ambiguïté"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "la base virtuelle %qT est inaccessible dans %qT en raison de l'ambiguïté"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "le décalage relatif de %qD n'est pas compatible avec l'ABI et peut changer dans une version future de GCC"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "la taille du type %qT est trop grande (%qE octets)"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "utilisation invalide de %q#T avec un tableau de taille nulle dans %q#D"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "utilisation invalide de %q#T avec un membre sous forme de tableau flexible dans %q#T"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "membre tableau %q#D déclaré ici"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "membre tableau de taille nulle %qD pas à la fin de %q#T"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "membre tableau de taille nulle %qD dans un %q#T par ailleurs vide"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "dans la définition de %q#T"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "le membre tableau flexible %qD n'est pas à la fin de %q#T"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "membre tableau flexible %qD dans %q#T par ailleurs vide"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "membre %q#D suivant déclaré ici"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redéfinition de %q#T"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T a des fonctions virtuelles et un destructeur non virtuel accessible"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "le type transparent %q#T n'a aucun champ"
 
 # un type transparent est un type qui est passé comme le type qu'elle manipule, par ex decimal32
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "la classe de type transparent %qT a des classes de base"
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "la classe de type transparent %qT a des fonctions virtuelles"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "le type transparent %q#T ne peut être rendu transparent car le type du premier champ a une ABI différente de la classe générale"
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "la définition de %qD ne correspond pas à %<#include <initializer_list>%>"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "la tentative de terminer la struct a été stoppée nette en raison des erreurs précédentes dans l'analyse syntaxique"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "la chaîne de langage %<\"%E\"%> n'est pas reconnue"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ne peut résoudre la fonction surchargée %qD basé sur la conversion vers le type %qT"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "pas de correspondance pour convertir la fonction %qD vers le type %q#T"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "la conversion de la fonction surchargée %qD vers le type %q#T est ambiguë"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "on suppose un pointeur vers le membre %qD"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un pointeur vers un membre peut seulement être formé avec %<&%E%>)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "pas assez d'informations sur le type"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "impossible de convertir %qE du type %qT vers le type %qT"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "la déclaration de %q#D change la signification de %qD"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%qD déclaré ici comme %q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "le type %qT de la variable %<constexpr%> %qD n'est pas littéral"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "la variable %qD du type non littéral %qT dans la fonction %<constexpr%>"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "la variable %<constexpr%> %qD a le type %qT modifié par une variable"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "le constructeur hérité %qD n'est pas %<constexpr%>"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "type invalide pour le paramètre %d de la fonction %<constexpr%> %q+#D"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "les lambdas ne sont implicitement %<constexpr%> qu'à partir du C++17"
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "type retourné %qT invalide pour la fonction %<constexpr%> %q+D"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T a des classes virtuelles de base"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr "le constructeur %<constexpr%> n'a pas de corps vide"
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "le constructeur %<constexpr%> de l'union %qT doit initialiser exactement un membre de donnée non statique"
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "le membre %qD doit être initialisé par l'initialisation des membres dans le constructeur %<constexpr%>"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr "le corps de la fonction %<constexpr%> %qD n'est pas une unique instruction « return »"
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD n'est pas utilisable comme une fonction %<constexpr%> car:"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "l'appel %<constexpr%> déborde au delà de la fin de la fonction"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E n'est pas une expression constante"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "appel à la fonction interne %qE"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "la modification d'un objet constant %qE n'est pas permise dans une expression constante"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr "initialement déclaré %<const%> ici"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr "la référence %<dynamic_cast%> a échoué"
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "le type dynamique %qT de son opérande n'a pas une classe de base du type %qT"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr "le pointeur vers une table virtuelle est utilisé sans avoir été initialisé"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr "le type statique %qT de son opérande est une classe de base non publique du type dynamique %qT"
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "%qT est une classe de base ambigüe du type dynamique %qT de son opérande"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "le type dynamique %qT de son opérande n'a pas une classe de base publique %qT non ambigüe"
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "appel à la fonction non %<constexpr%> %qD"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "l'expression %qE ne désigne pas une fonction %<constexpr%>"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr "désallocation de type tableau sur un objet alloué avec une allocation de type non tableau"
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, gcc-internal-format
 msgid "allocation performed here"
 msgstr "l'allocation a été réalisée ici"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr "désallocation de type non tableau sur un objet alloué avec une allocation de type tableau"
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr "désallocation d'un stockage déjà désalloué"
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr "désallocation d'un stockage qui n'a pas été précédemment alloué"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD est appelé dans une expression constante avant que sa définition soit complète"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD appelé dans une expression constante"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD utilisé avant sa définition"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "l'appel a une dépendance circulaire"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "la profondeur d'évaluation de la %<constexpr%> dépasse le maximum permis %d (utilisez %<-fconstexpr-depth=%> pour augmenter le maximum)"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "l'opérande de droite de l'expression de décalage %q+E est négatif"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "l'opérande de droite de l'expression de décalage %q+E est plus grand ou égal à la précision %wu de l'opérande de gauche"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "l'opérande de gauche de l'expression de décalage %q+E est négatif"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "l'expression de décalage %q+E déborde"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "arithmétique impliquant un pointeur nul dans %qE"
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "la valeur %qE de l'indice du tableau est hors des limites du tableau %qD du type %qT"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "l'indice de tableau non nul %qE est utilisé avec le tableau %qD de type %qT dont les limites sont inconnues"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "la valeur %qE de l'indice du tableau est hors des limites du tableau de type %qT"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "l'indice de tableau non nul %qE est utilisé avec un tableau de type %qT dont les limites sont inconnues"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "accès à un élément non initialisé du tableau"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "déréférencement d'un pointeur nul dans %qE"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE n'est pas une expression constante"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "le mutable %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "accès au membre non initialisé %qD"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "accès au membre %qD au lieu du membre initialisé %qD dans l'expression constante"
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%qs n'est pas une expression constante car %qT est un type union"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%qs n'est pas une expression constante car %qT contient un type union"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qs n'est pas une expression constante car %qT est un type pointeur"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%qs n'est pas une expression constante car %qT contient un type pointeur"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%qs n'est pas une expression constante car %qT est un type référence"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%qs n'est pas une expression constante car %qT contient un type référence"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "%qs n'est pas une expression constante car %qT est un type pointeur vers un membre"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "%qs n'est pas une expression constante car %qT contient un type pointeur vers un membre"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%qs n'est pas une expression constante car %qT est volatile"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qs n'est pas une expression constante car %qT contient un sous-objet volatile"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%qs ne peut pas être évalué de manière constante sur la cible"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr "%qs ne peut pas être évalué de manière constante car le type est trop grand"
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qs ne peut pas être évalué de manière constante car l'argument ne sait pas être encodé"
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "%qs accès à un octet non initialisé à l'offset %d"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs ne peut pas être évalué de manière constante car l'argument ne sait pas être interprété"
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "déréférencement d'un pointeur nul"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "accès à la valeur de %qE au travers d'une gl-valeur %qT dans une expression constante"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "le contenu d'un stockage non initialisé n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "alloué ici"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "utilisation d'un stockage alloué après sa désallocation dans une expression constante"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "la valeur de %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD utilisé dans sa propre initialisation"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D n'est pas const"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D est volatile"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD n'a pas été initialisé par une expression constante"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD n'a pas été déclaré %<constexpr%>"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD n'a pas un type entier ou énuméré"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "la modification de %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "changement du membre actif d'une union de %qD à %qD"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "changement du membre actif d'une union de %qD à %qD durant l'initialisation"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "l'instruction n'est pas une expression constante"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "le décompte des itérations de la boucle %<constexpr%> dépasse la limite permise %d (utilisez %<-fconstexpr-loop-limit=%> pour augmenter la limite)"
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "l'assembleur en ligne n'est pas une expression constante"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr "seul de l'assembleur en ligne non évalué est autorisé dans une fonction %<constexpr%> en C++20"
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "la valeur %qE du type %qT n'est pas une expression constante"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "le décompte des opérations d'évaluation de %<constexpr%> dépasse la limite permise %wd (utilisez %<-fconstexpr-ops-limit=%> pour augmenter la limite)"
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporaire du type %qT non littéral dans une expression constante"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "un %<reinterpret_cast%> n'est pas une expression constante"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversion depuis le type pointeur %qT vers le type arithmétique %qT dans une expression constante"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "le transtypage depuis %qT n'est pas permis"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> n'est pas une expression constante"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "l'expression %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "template-id %qE inattendu"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "un concept de fonction doit être appelé"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "l'adresse d'un appel à %qs n'est pas une expression constante"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "l'expression %qE du sous-type %s est inattendue"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE n'est pas une expression constante car il fait référence aux sous-objets mutables de %qT"
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE n'est pas une expression constante car il fait référence à une variable incomplètement initialisée"
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE n'est pas une expression constante car il fait référence à un résultat de %<operator new%>"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE n'est pas une expression constante car le stockage alloué n'a pas été désalloué"
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "l'évaluation immédiate retourne l'adresse de la fonction immédiate %qD"
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "conversion l-valeur vers r-valeur d'une l-valeur volatile %qE avec le type %qT"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la capture lambda de %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "car il est utilisé comme gl-valeur"
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> d'un entier vers un pointeur"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "prendre l'adresse avec address-of d'un objet %qE qui est local au thread ou a un stockage automatique n'est pas une expression constante"
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "utilisation de %<this%> dans une expression constante"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "expression lambda dans une expression constante avant C++17"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "les fonctions virtuelles ne peuvent pas être %<constexpr%> avant C++20"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "l'expression %<typeid%> n'est pas une expression constante car %qE est un type polymorphique"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "transtypage vers le type non entier %qT dans une expression constante"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD déclaré %<static%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD déclaré %<thread_local%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "la division par zéro n'est pas une expression constante"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> n'est pas une expression constante"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "initialisation d'un tableau non constant"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> n'est pas une expression constante"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "la définition d'une étiquette n'est pas une expression constante"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "arbre syntaxique abstrait (AST=Abstract Syntax Tree) de type %s inattendu"
@@ -47433,53 +47474,53 @@ msgstr "arbre syntaxique abstrait (AST=Abstract Syntax Tree) de type %s inattend
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr "les deux branches de l'instruction %<if%> sont marquées comme %qs"
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> appellera toujours %<terminate%>"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "en C++11, les destructeurs sont %<noexcept%> par défaut"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "en C++11, ce %<throw%> appellera %<terminate%> car les destructeurs sont %<noexcept%> par défaut"
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "l'attribut %qE est ignoré après un %qE antérieur"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD n'est pas un type"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD n'est pas un type de classe"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD n'a pas le type %<const char *%>"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD n'a pas un type entier"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> ne contient pas uniquement que des membres de données non-statiques %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> et %<_M_column%>"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "évaluation de %qs"
@@ -47520,7 +47561,7 @@ msgstr "conversion vers le type référencé non const %q#T depuis une r-valeur
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "la conversion depuis %qH vers %qI écarte les qualificatifs"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "le transtypage de %qT vers %qT ne déréférence pas le pointeur"
@@ -47903,7 +47944,7 @@ msgstr "par rapport à la déclaration précédente de %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "la redéclaration de %qD diffère de %qs dans la déclaration précédente"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "déclaration précédente de %qD"
@@ -48033,8 +48074,8 @@ msgstr "déclaration %<pragma omp declare reduction%> précédente"
 msgid "%q#D previously defined here"
 msgstr "%q#D précédemment défini ici"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D précédemment déclaré ici"
@@ -48069,52 +48110,52 @@ msgstr "argument par défaut donné pour le paramètre %d de %q#D"
 msgid "previous specification in %q#D here"
 msgstr "la spécification précédente dans %q#D est ici"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr "la déclaration %qD est en conflit avec la fonction interne"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr "la déclaration %qD est en conflit avec l'import"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr "l'import a déclaré %q#D ici"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
 msgstr "export conflictuel de la déclaration %qD"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr "la déclaration %q#D précédente est ici"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "la définition précédente de %qD est ici"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "la déclaration précédente de %qD est ici"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "fonction %qD déclarée %<[[noreturn]]%> mais sa première déclaration ne l'était pas"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "déclaration redondante de %qD dans la même étendue"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "définition supprimée de %qD n'est pas la première déclaration"
@@ -48127,48 +48168,48 @@ msgstr "définition supprimée de %qD n'est pas la première déclaration"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "spécialisation explicite de %qD après la première utilisation"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: attribut de visibilité ignoré car il est en conflit avec la déclaration précédente"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "redéfinition de %q#D"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD est en conflit avec la fonction utilisée"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D pas déclaré dans une classe"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D redéclaré en ligne avec l'attribut %<gnu_inline%>"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D redéclaré en ligne sans l'attribut %<gnu_inline%>"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr "le guide de déduction %q+D est redéclaré"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "l'opérateur de comparaison %q+D est remis au défaut après sa première déclaration"
@@ -48176,2301 +48217,2318 @@ msgstr "l'opérateur de comparaison %q+D est remis au défaut après sa premièr
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "la redéclaration de l'ami %q#D ne peut pas avoir d'arguments de patron par défaut"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "la déclaration locale au thread de %q#D suit la déclaration non locale au thread"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "la déclaration non locale au thread de %q#D suit la déclaration locale au thread"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "redéclaration de %q#D"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "redéclaration redondante du membre statique %<constexpr%> %qD"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "l'étiquette locale %qE est en conflit avec l'étiquette existante"
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr "étiquette précédente"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  à partir d'ici"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  sort du block structuré OpenMP"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  croise l'initialisation de %q#D"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  entre dans la portée de %q#D qui a un destructeur non trivial"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  entre dans le bloc %<try%>"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  entre dans le bloc %<catch%>"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  entre dans le bloc structuré OpenMP"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  entre dans l'instruction synchronisée ou atomique"
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  entre dans l'instruction %<constexpr if%>"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  passe outre l'initialisation de %q#D"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  entre dans la portée de %q#D qui a un destructeur non trivial"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD utilisé sans arguments du patron"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD n'est pas un patron de fonction"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T n'est pas une classe"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "pas de patron de classe nommé %q#T dans %q#T"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "pas de type nommé %q#T dans %q#T"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la recherche de %qT dans %qT est ambigüe"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nomme %q#T qui n'est pas un patron de classe"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nomme %q#T qui n'est pas un type"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "les paramètres du patron ne correspondent pas au patron %qD"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> n'est pas une puissance de deux"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un constructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un destructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un opérateur d'affectation par copie n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoré dans la déclaration de %q#T"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "l'attribut pour %q#T doit suivre le mot-clé %qs"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "types multiples dans une déclaration"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redéclaration du type interne C++ %qT"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> peut seulement être spécifié pour des déclarations de variables ou de fonctions"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nom de type manquant dans la déclaration typedef"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "le C++ ISO interdit les structures anonymes"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> peut seulement être spécifié à l'intérieur d'une classe"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> peut seulement être spécifié pour des constructeurs"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "une classe de stockage peut seulement être spécifiée pour des objets et des fonctions"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> a été ignoré dans cette déclaration"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs ne peut pas être utilisé pour des déclarations de types"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoré dans l'instanciation explicite de %q#T"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "aucun attribut peut être appliqué à une instanciation explicite"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "les attributs sont ignorés s'ils sont appliqués à la classe de type %qT en dehors de la définition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "attributs ignorés car ils sont appliqués au type dépendent %qT sans déclaration associée"
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD est initialisé (utilisez plutôt %qs)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la déclaration de %q#D est %<extern%> et est initialisée"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la définition de %q#D est marquée %<dllimport%>"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D n'est pas un membre de donnée statique de %q#T"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "la déclaration du patron non membre de %qD"
 
 # le message ci-dessous est la suite de celui juste ci-dessus
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ne correspond pas à la déclaration du patron membre ici"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "le C++ ISO ne permet pas que %<%T::%D%> soit défini comme %<%T::%D%>"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "initialisation en double de %qD"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la déclaration de %q#D en dehors de la classe n'est pas une définition"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr "la déclaration externe avec la portée bloc %q#D n'est pas permise dans le domaine du module"
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qD déclaré %<thread_local%> dans une fonction %qs"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qD déclaré %<static%> dans une fonction %qs"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D a un initialiseur mais a un type incomplet"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "les éléments du tableau %q#D ont un type incomplet"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "l'agrégat %q#D a un type incomplet et ne peut être défini"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD est déclaré comme référence mais n'est pas initialisé"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nom utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nom %qD utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "les initialisations par désignation non triviales ne sont pas supportées"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "le champ désigné par l'indicateur C99 %qE n'est pas une expression constante entière"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "l'initialisation n'a pu déterminer la taille de %qD"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "taille de tableau manquante dans %qD"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "tableau %qD de taille zéro"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "la taille de stockage de %qD n'est pas connue"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "la taille de stockage de %qD n'est pas constante"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la variable en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la fonction statique en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "vous pouvez contourner cela en enlevant l'initialiseur"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "%<const %D%> non initialisé"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variable %qD non initialisée dans une fonction %<constexpr%>"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "variable %qD non initialisée dans un contexte %<constexpr%>"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T n'a pas de constructeur par défaut fourni par l'utilisateur"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "le constructeur n'est pas défini par l'utilisateur car le constructeur par défaut est explicitement demandé dans le corps de la classe"
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "et le constructeur implicitement défini n'initialise pas %q#D"
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "type %qT invalide pour initialiser un vecteur de type %qT"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "l'initialisation de %qT doit être entre accolades"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> utilisé dans une initialisation par désignation dans le style GNU pour la classe %qT"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT n'a pas de membre de données non statique nommé %qD"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "initialisation invalide pour %q#D"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "le champ désigné par l'indicateur C99 %qE est hors de l'initialisation de l'agrégat"
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "trop d'éléments d'initialisation pour %qT"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades autour de l'initialiseur scalaire pour le type %qT"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "trop d'accolades autour de l'initialiseur scalaire pour le type %qT"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades manquantes autour de l'initialisation pour %qT"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "la liaison structurée à le type incomplet %qT"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "les éléments du tableau %q#T ont un type incomplet"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "littéral composé de taille variable"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D a un type incomplet"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "l'objet scalaire %qD requiert un élément dans l'initialisation"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98, %qD doit être initialisé par un constructeur et non par %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "le tableau %qD est initialisé par la chaîne littérale entre parenthèses %qE"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initialisation invalide pour un membre statique avec constructeur"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique %qD"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique pas en ligne %qD"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(une initialisation en dehors de la classe est requise)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "la référence %qD est initialisée avec elle-même"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "n'a pu trouver la déclaration du variant"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> sur le constructeur %qD"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> sur le destructeur %qD"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> sur %qD par défaut"
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> sur %qD supprimé"
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> sur %qD virtuel"
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "affectation (pas une initialisation) dans la déclaration"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "le C++17 ISO n'autorise pas le spécificateur de classe de stockage %<register%>"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "spécificateur de classe de stockage %<register%> utilisé"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "l'initialisation pour %<decltype(auto) %D%> a un type fonction (avez-vous oublié les %<()%> ?)"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "le concept de variable n'a pas d'initialisation"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "masque la déclaration précédente du type de %q#D"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%<constinit%> peut uniquement être appliqué à une variable avec une durée de stockage statique ou au niveau du thread"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la fonction %q#D est initialisée comme une variable"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une structure anonyme comme membre"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une union anonyme comme membre"
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "impossible de décomposer le membre inaccessible %qD de %qT"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: lui et sa classe de base %qT ont des membres de données non statiques"
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: ses classes de base %qT et %qT ont des membres de données non statiques"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "la liaison structurée fait référence au type incomplet %qT"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "impossible de décomposer le tableau de longueur variable %qT"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u nom fourni pour la liaison structurée"
 msgstr[1] "%u noms fournis pour la liaison structurée"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "seulement %u nom fourni pour la liaison structurée"
 msgstr[1] "seulement %u noms fournis pour la liaison structurée"
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "alors que %qT se décompose en %wu élément"
 msgstr[1] "alors que %qT se décompose en %wu éléments"
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "impossible de décomposer le vecteur de longueur variable %qT"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> n'est pas une expression constante entière"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "alors que %qT se décompose en %E éléments"
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dans l'initialisation de la variable de liaison structurée %qD"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "impossible de décomposer le type union %qT"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "impossible de décomposer le type %qT qui n'est ni une classe ni un tableau"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "impossible de décomposer le type de fermeture lambda %qT"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "la liaison structurée fait référence au type de classe incomplet %qT"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "impossible de décomposer le type de classe %qT sans membre de donnée non statique"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "la variable non locale %qD déclarée %<__thread%> a besoin d'une initialisation dynamique"
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "la variable non locale %qD déclarée %<__thread%> a un destructeur non trivial"
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> en C++11 permet l'initialisation et la destruction dynamique"
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "l'initialisation n'a pu déterminer la taille de %qT"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "taille du tableau manquante dans %qT"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "tableau %qT de taille zéro"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "le destructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "le constructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD est déclaré comme une variable %<virtual%>"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de variable"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD déclaré comme un paramètre %<virtual%>"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD déclaré comme un paramètre %<inline%>"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de paramètre"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD déclaré comme un type %<virtual%>"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD déclaré comme un type %<inline%>"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de type"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD déclaré comme un champ %<virtual%>"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD déclaré comme un champ %<inline%>"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de champ"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D déclaré comme un ami"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D déclaré avec une spécification d'exception"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la définition de %qD n'est pas dans l'espace de noms incluant %qT"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la fonction membre statique %q#D est déclarée avec des qualificatifs de type"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "le concept %q#D est déclaré avec des paramètres de fonction"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "le concept %q#D est déclaré avec un type de retour déduit"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "le concept %q#D a le type de retour %qT qui n'est pas %<bool%>"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "le concept %qD n'a pas de définition"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "un concept de fonction ne peut pas être contraint"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "contraintes sur une fonction sans patron"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "définition de la spécialisation explicite %qD dans la déclaration amie"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "utilisation invalide du template-id %qD dans la déclaration du patron primaire"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "les arguments par défaut ne sont pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> n'est pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "la déclaration amie de %qD spécifie des arguments par défaut et n%'est pas une définition"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "ne peut déclarer %<::main%> comme étant un patron"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "ne peut déclarer %<::main%> comme étant à mettre en ligne"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "ne peut déclarer %<::main%> comme étant %qs"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "ne peut déclarer %<::main%> comme étant static"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "le guide de déduction %qD doit être déclaré au niveau de l'espace de noms"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "le guide de déduction %qD doit être déclaré dans la même portée que %qT"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "le guide de déduction %qD ne peut pas avoir un corps de fonction"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "opérateur littéral avec une classe de liaison C"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD a une liste d'arguments invalide"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "le suffixe entier %qs est masqué par l'implémentation"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "le suffixe en virgule flottante %qs est masqué par l'implémentation"
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "les suffixes d'opérateurs littéraux qui ne sont pas précédés par %<_%> sont réservés pour une standardisation future"
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD doit être une fonction non membre"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> doit retourner %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "définition de %qD déclaré implicitement"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "définition de %qD explicitement par défaut"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicitement par défaut ici"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "pas de fonction membre %q#D déclarée dans la classe %qT"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "ne peut déclarer %<::main%> comme variable globale"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "une variable qui n'est pas un patron ne peut pas avoir %<concept%>"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+#| msgid "deduction guide %qD must be declared at namespace scope"
+msgid "concept must be defined at namespace scope"
+msgstr "le guide de déduction %qD doit être déclaré au niveau de l'espace de noms"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "un concept doit avoir le type %<bool%>"
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "un concept variable ne peut pas être contraint"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D d'un type incomplet"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> est requis pour l'initialisation intra-classe du membre de donnée statique %q#D d'un type non entier"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D du type non littéral"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "initialisation intra-classe invalide du membre de donnée statique du type non entier %qT"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "le C++ ISO interdit l'initialisation intra-classe du membre statique non constant %qD"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "le C++ ISO interdit l'initialisation du membre constant %qD du type non entier %qT"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "la taille du tableau %qD a le type non entier %qT"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "la taille du tableau a le type non entier %qT"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "la taille du tableau %qD n'est pas une expression constante de type entier"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "la taille du tableau n'est pas une expression constante entière"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "le C++ ISO interdit le tableau de taille zéro %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "le C++ ISO interdit le tableau de taille zéro"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "le C++ ISO interdit le tableau de taille variable %qD"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "le C++ ISO interdit le tableau de taille variable"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "le tableau de taille variable %qD est utilisé"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "le tableau de taille variable est utilisé"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "débordement dans la dimension du tableau"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD est déclaré comme tableau de %qT"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "création d'un tableau de %qT"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "déclaration de %qD comme un tableau de « void »"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "création d'un tableau « void »"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "déclaration de %qD comme un tableau de fonctions"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "création d'un tableau de fonctions"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "déclaration de %qD comme un tableau de références"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "création d'un tableau de références"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "déclaration de %qD comme un tableau de fonctions membres"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "création d'un tableau de fonctions membres"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la déclaration de %qD comme tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "le tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la spécification d'un type retourné pour un constructeur est invalide"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un constructeur"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la spécification d'un type retourné pour un destructeur est invalide"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un destructeur"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "type de retour spécifié pour %<operator %T%>"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration de %<operator %T%>"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "type de retour spécifié pour le guide de déduction"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration du guide de déduction"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "paramètre de patron %qT, qui est lui-même un patron, dans la déclaration du guide de déduction"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> dans la déclaration du guide de déduction"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variable non nommée ou champ déclaré void"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variable ou champ déclaré void"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "spécificateur %<inline%> invalide pour la variable %qD déclarée au niveau du bloc"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les variables « inline » sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "utilisation invalide du nom qualifié %<::%D%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%T::%D%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%D::%D%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T n'est pas une classe ou un espace de noms"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "déclaration de %qE comme non fonction"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "déclaration de %qE comme non membre"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "declarator-id manquant; utilisation du mot réservé %qD"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la définition de fonction ne déclare aucun paramètre"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "déclaration de %qD comme non fonction"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "déclaration de %qD comme %<typedef%>"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "déclaration de %qD comme paramètre"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "%qs et %qs spécifiés tous les deux"
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs ne peut pas apparaître dans une déclaration typedef"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "au plus un seul spécificateur %<constinit%> ou %<constexpr%> peut être utilisé"
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "au moins deux types de données dans la déclaration de %qs"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "spécificateurs conflictuels dans la déclaration de %qs"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C++ ISO n'accepte pas qu'un simple %<complex%> signifie %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "le C++ ISO interdit la déclaration de %qs sans type"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> n'est pas supporté par la cible"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "le C++ ISO ne supporte pas %<__int%d%> pour %qs"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> et %<unsigned%> spécifiés ensemble"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> et %<short%> spécifiés ensemble"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs spécifié avec %qT"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs spécifié avec %<decltype%>"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs spécifié avec %<typeof%>"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "« complex » invalide pour %qs"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "le type à remplacer %qT dans le patron doit être suivi d'un simple declarator-id"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "le membre %qD ne peut pas être déclaré à la fois %<virtual%> et %<static%>"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "le membre %qD peut être déclaré à la fois %<virtual%> et %<constexpr%> uniquement avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "la déclaration typedef est invalide dans la déclaration du paramètre"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs du patron"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "un paramètre ne peut pas être déclaré %qs"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> en dehors de la déclaration de classe"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "la déclaration d'une liaison structurée ne peut pas être %qs"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les déclarations de liaisons structurées peuvent être %qs uniquement en %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "la liaison structurée qualifiée avec %<volatile%> est dépréciée"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le %<auto%> du C++98"
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le type %qT"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "le type doit être un %<auto%> qualifié avec CV ou une référence à un %<auto%> qualifié avec CV"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "classes de stockage multiples dans la déclaration de %qs"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "classe de stockage spécifiée pour %qs"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fonction imbriquée %qs déclarée %<extern%>"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la déclaration de %qs hors de toute fonction spécifie %<auto%>"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs dans le champ de la fonction est implicitement déclaré auto et déclaré %<__thread%>"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spécificateurs de classe de stockage invalides dans les déclarations de fonctions amies"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribut ignoré"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un attribut qui appartient à un spécificateur de type est ignoré"
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "parenthèses inutiles dans la déclaration de %qs"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "retirez les parenthèses"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "clause « requires » sur le type de retour"
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la fonction %qs utilise le spécificateur de type %<auto%> sans type de retour à la fin"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "le type de retour déduit est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "une fonction virtuelle ne peut pas avoir un type de retour déduit"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %qT comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %<decltype(auto)%> comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "utilisation invalide de %<decltype(auto)%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "type de classe %qD déduit dans le type de retour de la fonction"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "le guide de déduction pour %qT doit avoir un type de retour à la fin"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "le type de retour %qT à la fin du guide de déduction n'est pas une spécialisation de %qT"
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "le type de retour à la fin est uniquement disponible avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "la fonction %qs avec le type de retour à la fin n'est pas déclarée avec le spécificateur de type %<auto%>"
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "le type de retour qualifié avec %<volatile%> est déprécié"
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs déclaré comme une fonction retournant une fonction"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs déclaré comme une fonction retournant un tableau"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "le type de retour %<constinit%> pour une fonction n'est pas permis"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT en tant que type plutôt qu'un simple %<decltype(auto)%>"
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> ne peut pas être qualifié avec CV"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "le destructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "le constructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "les constructeurs ne peuvent pas être déclarés %<virtual%>"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "les fonctions virtuelles ne peuvent pas être amies"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la déclaration amie n'est pas dans la définition de la classe"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "ne peut définir la fonction amie %qs dans une définition de classe locale"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "la définition de la fonction amie %qs ne peut pas avoir son nom qualifié avec %<::%>"
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "la définition de la fonction amie %qs ne pas avoir son nom qualifié avec %<%D::%>"
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "une fonction de conversion ne peut pas avoir de type de retour à la fin"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destructeurs ne peuvent pas avoir de paramètre"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ne peut déclarer un pointeur vers %q#T"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "ne peut déclarer une référence vers %q#T"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ne peut déclarer un pointeur vers le membre %q#T"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "ne peut déclarer une référence vers le type de fonction qualifié %qT"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ne peut déclarer un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "ne peut déclarer une référence vers %q#T qui n'est pas un typedef ou un argument vers un type d'un patron"
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD utilisé comme un déclarateur"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "les fonctions membres sont implicitement amies de leur classe"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "qualification %<%T::%> additionnelle sur le membre %qs"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "ne peut définir la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "ne peut déclarer la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "ne peut déclarer le membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "le non paramètre %qs ne peut pas être un paquet de paramètres"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "les membres de données ne peuvent pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "le paramètre ne peut pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> en dehors de la déclaration de la classe"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> dans une déclaration amie"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "seuls les déclarations de constructeurs et les opérateurs de conversion peuvent être %<explicit%>"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "le non membre %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "le membre non objet %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la fonction %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%<static%> %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%<const%> %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la référence %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "typedef ne peut pas être une définition de fonction"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "typedef ne peut pas être une définition de fonction membre"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> n'est pas autorisé dans une déclaration de synonyme"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef déclaré %<auto%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "clause « requires » sur un typedef"
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "le nom du typedef ne peut pas être un nom de spécificateur imbriqué"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "le C++ ISO interdit le type imbriqué %qD avec le même nom que la classe englobante"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> spécifié pour la déclaration d'une classe amie"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "les paramètres du patron ne peuvent pas être amis"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d. %<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d %<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "tentative de rendre amie la classe %qT au niveau de la portée globale"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "qualificatifs invalides sur un type de fonction non membre"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "clause « requires » sur type-id"
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "déclaration abstraite %qT utilisée comme déclaration"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "clause « requires » dans la déclaration du type non fonction %qT"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "ne peut utiliser %<::%> dans la déclaration d'un paramètre"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "ne peut déclarer un paramètre avec %<decltype(auto)%>"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "le type à remplacer de la classe %qE n'est pas permis dans ce contexte"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "utilisation de %<auto%> pour un patron de fonction abrégé"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "le paramètre %<auto%> n'est pas permis dans ce contexte"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "paramètre déclaré %<auto%>"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "utilisation invalide du nom de patron %qE sans liste d'arguments"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "membre de donnée non statique déclaré avec %qT comme type à remplacer"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "le C++ ISO interdit le membre tableau flexible %qs"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "le C++ ISO interdit les tableaux flexibles comme membres"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "utilisation invalide de %<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "déclaration de la fonction %qD dans un contexte invalide"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fonction %qD déclarée %<virtual%> à l'intérieur d'une union"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD ne peut pas être déclaré %<virtual%> puisqu'il est toujours statique"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie du destructeur %qD"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "déclaration de %qD comme membre de %qT"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "un destructeur ne peut pas être %qs"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les destructeurs %<constexpr%> sont uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie pour le constructeur %qD"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "un constructeur ne peut pas être un %<concept%>"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "un concept ne peut être une fonction membre"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD ne peut pas être %qs"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "spécialisation du patron de variable %qD déclaré comme une fonction"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "le patron de variable a été déclaré ici"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "le champ %qD a le type incomplet %qT"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "le nom %qT a un type incomplet"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "le champ sans nom n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "membre de donnée statique %qE déclaré %qs"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "le membre statique %<constexpr%> %qD doit avoir une initialisation"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "le membre de donnée non statique %qE est déclaré %qs"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la classe de stockage %<auto%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la classe de stockage %<register%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la classe de stockage %<__thread%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la classe de stockage %<thread_local%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "le spécificateur de type « virt-specifier » sur %qs n'est pas permis en dehors d'une définition de classe"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<static%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<inline%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "fonction non classe virtuelle %qs"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs défini en dehors d'un contexte de classe"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs déclaré en dehors d'un contexte de classe"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "ne peut déclarer la fonction membre %qD comme ayant une classe de liaison statique"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "ne peut déclarer une fonction statique à l'intérieur d'une autre fonction"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> ne peut pas être utilisé lors de la définition (contrairement à la déclaration) d'un membre de donnée statique"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "membre statique %qD déclaré %<register%>"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "ne peut explicitement déclarer le membre %q#D comme ayant une classe de liaison externe"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la déclaration de la variable %<constexpr%> %qD n'est pas une définition"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "une variable ne peut pas être déclarée %<consteval%>"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la déclaration de %q#D n'est pas initialisée"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisé et déclaré %<extern%>"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs a, à la fois, %<extern%> et une initialisation"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "l'argument par défaut %qE utilise %qD"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "l'argument par défaut %qE utilise la variable locale %qD"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "utilisation invalide du type %qT qualifié CV dans la déclaration du paramètre"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "utilisation invalide du type %<void%> dans la déclaration du paramètre"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "le paramètre qualifié avec %<volatile%> est obsolète"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "le paramètre %qD est incorrectement déclaré comme type de méthode"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut un pointeur vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut une référence vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructeur invalide; vous vouliez probablement utiliser %<%T (const %T&)%>"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD ne peut pas être déclaré dans un espace de noms"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD ne peut pas être déclaré statique"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD doit être une fonction membre non statique"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD doit être soit une fonction membre non statique ou une fonction non membre"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD doit avoir un argument de type classe ou énuméré"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "le C++ ISO interdit la surcharge de %<operator ?:%>"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD ne doit pas avoir un nombre variables d'arguments"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD doit avoir zéro ou un argument"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD doit avoir un ou deux arguments"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qD suffixé doit avoir %<int%> comme argument"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qD suffixé doit avoir %<int%> comme second argument"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD ne doit avoir aucun argument"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD doit avoir exactement un argument"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD doit avoir exactement deux arguments"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD ne peut avoir d'arguments par défaut"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "la conversion de %qT vers %<void%> n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "la conversion de %qT en une référence vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "la conversion de %qT vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "la conversion de %qT en une référence vers une classe de base %qT n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "la conversion de %qT vers une classe de base %qT n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "%qD défini par l'usager évalue toujours les 2 arguments"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "%qD préfixé devrait retourner %qT"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "%qD suffixé devrait retourner %qT"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD devrait retourner par valeur"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "utilisation du paramètre du type de patron %qT après %qs"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "utilisation de la spécialisation du patron d'alias %qT après %qs"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "utilisation du nom de typedef %qD après %qs"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD a une déclaration précédente ici"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT référé en tant que %qs"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT a une déclaration précédente ici"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "il est fait référence à %qT comme un enum"
@@ -50482,105 +50540,105 @@ msgstr "il est fait référence à %qT comme un enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argument du patron requis pour %<%s %T%>"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la référence à %qD est ambiguë"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD a le même nom que la classe dans laquelle il est déclaré"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT n'est pas un patron"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "vous voulez peut-être ajouter %<%T::%> explicitement"
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "utilisation de l'enum %q#D sans déclaration précédente"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redéclaration de %qT sous une forme qui n'est pas un patron"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "ne peut déclarer %qD dans un module différent"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "l'union dérivée %qT est invalide"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT est défini avec des bases directes multiples"
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT est défini avec des bases virtuelles directes"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "le type de base %qT n'est pas un « struct » ou une « class »"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "type récursif %qT non défini"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "le type de base dupliqué %qT est invalide"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "non concordance entre un enum simple et un enum fortement typé pour %q#T"
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "définition précédente ici"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "désaccord dans le type sous-jacent de l'enum %q#T"
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "types sous-jacents différents dans l'enum %q#T"
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "impossible de définir %qD dans un module différent"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "le type sous-jacent %qT de %qT doit être un type entier"
@@ -50589,77 +50647,77 @@ msgstr "le type sous-jacent %qT de %qT doit être un type entier"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "aucun type entier ne peut représenter toutes les valeurs de l'énumération pour %qT"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "les valeurs énumérées de %qD doivent être de type entier ou une énumération simple (donc, pas fortement typée)"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "la valeur de l'énumération pour %qD n'est pas une constante entière"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<unsigned long%>"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<long%>"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "débordement dans les valeurs de l'énumération à %qD"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "la valeur de l'énumération %qE est en dehors de la plage du type sous-jacent %qT"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "définition multiple de %q#T"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "le type retourné %q#T est incomplet"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> devrait retourner une référence à %<*this%>"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "« return » manquant dans une fonction retournant %qT"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "seul un type de retour %<auto%> évident peut être déduit en %<void%>"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "« return » manquant dans une fonction %<constexpr%> devant retourner une valeur"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD est déjà défini dans la classe %qT"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "utilisation de %qD avant la déduction de %<auto%>"
@@ -50699,7 +50757,7 @@ msgstr "ne peut détruire une fonction.  Seuls les pointeurs vers des objets son
 msgid "deleting %qT is undefined"
 msgstr "la destruction de %qT est non définie"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "déclaration du patron de %q#D"
@@ -50709,7 +50767,7 @@ msgstr "déclaration du patron de %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "la liste des paramètres du patron fournie ne correspond pas aux paramètres du patron de %qD"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "le destructeur %qD est déclaré en tant que patron membre"
@@ -51034,22 +51092,22 @@ msgstr "car %qT a un %qD fourni par l'utilisateur"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "conversion d'une fonction lambda qui utilise %<...%> en pointeur de fonction"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "utilisation de la fonction supprimée %qD"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "utilisation de la fonction %qD avec des contraintes non satisfaites"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "utilisation du paquet de paramètres intégré %qD en dehors d'un patron"
@@ -51154,7 +51212,7 @@ msgstr "la référence à %<%T::%D%> est ambiguë"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD n'est pas un membre de %qT; vouliez-vous employer %qs ?"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD n'est pas un membre de %qT"
@@ -51164,7 +51222,7 @@ msgstr "%qD n'est pas un membre de %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD n'est pas un membre de %qD; vouliez-vous employer %qs ?"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD n'est pas un membre de %qD"
@@ -51350,408 +51408,408 @@ msgstr "initialisation par valeur du type référencé %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "instanciation récursive de l'initialisation du membre par défaut pour %qD"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "l'initialisation du membre par défaut pour %qD est requise avant la fin de sa classe englobante"
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "initialisation pour le membre tableau flexible %q#D"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr "initialiser %qD depuis %qE n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD devrait être initialisé dans la liste d'initialisation du membre"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD est initialisé avec lui-même"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "initialisation invalide pour le membre tableau %q#D"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "membre constant non initialisé dans %q#T"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D devrait être initialisé"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "membre par référence non initialisé dans %q#T"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD sera initialisé après"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "la base %qT sera initialisée après"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  la base %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  quand elle est initialisée ici"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "initialisations multiples données pour %qD"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "initialisations multiples données pour la base %qT"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "initialisations pour des membres multiples de %qT"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "la classe de base %q#T devrait être explicitement initialisée dans le constructeur par copie"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "la classe %qT n'a aucun champ nommé %qD"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D est un membre de donnée statique; il peut seulement être initialisé lors de sa définition"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D n'est pas un membre de donnée non statique de %qT"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "initialisation sans nom pour %qT, lequel n'a pas de classe de base"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "initialisation sans nom pour %qT, lequel utilise de multiples héritages"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD est à la fois une base directe et une base virtuelle indirecte"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "le type %qT n'est pas une base directe ou virtuelle de %qT"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "le type %qT n'est pas une base directe de %qT"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "le tableau doit être initialisé avec une initialisation entre accolades"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT n'est pas un type de classe"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "le type incomplet %qT n'a pas de membre %qD"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "pointeur invalide vers le champ de bits %qD"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "utilisation invalide de la fonction membre non statique %qD"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "utilisation invalide du membre de donnée non statique %qD"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "le membre de référence non initialisé dans %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "le membre de référence non initialisé dans la base %q#T de %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "membre de référence non initialisé dans la base %q#T de %q#T"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "le membre constant non initialisé dans %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "le membre constant non initialisé dans la base %q#T de %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "membre constant non initialisé dans la base %q#T de %q#T"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un objet de type %<%T [%wu]%> et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "l'opérateur « new » avec placement construit un objet de type %<%T [%wu]%> et de taille %qwu dans une région de type %qT et de taille au plus %qwu"
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un tableau d'objets de type %qT et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "l'opérateur « new » avec placement construit un tableau d'objets de type %qT et de taille %qwu dans une région de type %qT et de taille au moins %qwu"
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un objet de type %qT et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "l'opérateur « new » avec placement construit un objet de type %qT et de taille %qwu dans une région de type %qT et de taille au plus %qwu"
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr "à l'offset %wi de l'objet %qD déclaré ici"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "à l'offset [%wi, %wi] de %qD déclaré ici"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "débordement d'entier dans la taille du tableau"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "la taille du tableau dans l'expression « new » doit être une constante"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "le type modifié par une variable n'est pas permis dans l'expression « new »"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "la nouvelle longueur du tableau non constant doit être spécifiée directement, pas par un %<typedef%>"
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "la nouvelle longueur du tableau non constant doit être spécifiée sans parenthèses autour du id de type"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "type %<void%> invalide pour %<new%>"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "%<new%> de %<initializer_list%> n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "constante non initialisée dans %<new%> de %q#T"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "pas de %qD convenable dans la classe %qT"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la requête pour le membre %qD est ambiguë"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> de type %qT avec l'alignement étendu %d"
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "utilisation de %qD qui n'a pas de paramètre d'alignement"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "utilisez %<-faligned-new%> pour activer le support du « new » sur-aligné du C++17"
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "initialisation entre parenthèses dans le « new » du tableau"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "la taille du tableau dans « new » doit avoir un type entier"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "« new » ne peut pas être appliqué à un type référencé"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "« new » ne peut être appliqué à un type de fonction"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "problème possible détecté dans l'invocation de l'opérateur %<delete []%>"
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni l'opérateur %<delete[]%> spécifique à la classe seront appelés, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "fin prématurée de l'initialisation"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "taille du tableau inconnue dans delete"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "problème possible détecté dans l'invocation de %<operator delete%>"
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni %<operator delete%> spécifique à la classe seront appelés, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "la destruction d'un objet de la classe abstraite %qT qui a un destructeur non virtuel provoquera un comportement indéfini"
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "la destruction d'un objet de la classe polymorphique %qT qui a un destructeur non virtuel pourrait produire un comportement indéfini"
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "le type passé au delete vectoriel n'est ni un pointeur ni un type tableau"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr "le tableau avec une limite déterminée à l'exécution ne peut pas être capturée par copie, uniquement par référence"
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "capture du type modifié par une variable %qT qui n'est pas un tableau N3639 avec une limite déterminée à l'exécution"
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "car le type %qT des éléments du tableau a une taille variable"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "ne peut capturer %qE par référence"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "capture par copie du type incomplet %qT"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr "tentative de capturer %qD dans une instanciation d'une lambda générique"
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr "la capture implicite de %qE via %<[=]%> est dépréciée en C++20"
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr "ajoutez la capture %<this%> ou %<*this%> explicitement"
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> n'a pas été capturé pour cette fonction lambda"
@@ -51806,62 +51864,62 @@ msgstr "il n'y a pas d'argument pour %qD qui dépend d'un paramètre du patron,
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(si vous utilisez %<-fpermissive%>, G++ acceptera votre code, mais permettre l'utilisation d'un nom non déclaré est obsolète)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr "décoration de %<typeof%>, utilisez plutôt %<decltype%>"
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr "décoration de %<__underlying_type%>"
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "décoration du type en virgule fixe inconnu"
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "utilisation du trait interne %qE dans la signature de la fonction, utilisez plutôt la bibliothèque des traits"
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "décoration de %C"
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "l'opérande omis au milieu de %<?:%> ne peut pas être décoré"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "le nom décoré pour %qD changera dans le C++17 car la spécification de l'exception fait partir du type de la fonction"
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "le nom décoré de %qD a changé entre %<%s=%d%> (%qD) et %<%s=%d%> (%qD)"
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "le nom décoré de %qD change entre %<%s=%d%> (%qD) et %<%s=%d%> (%qD)"
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "le nom décoré d'un fragment pour %qD change entre %<-fabi-version=%d%> et %<-fabi-version=%d%>"
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "le nom décoré de %qD change entre %<-fabi-version=%d%> et %<-fabi-version=%d%>"
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "le nom décoré de la variable de protection de l'initialisation pour %qD change entre %<-fabi-version=%d%> et %<-fabi-version=%d%>"
@@ -52042,302 +52100,302 @@ msgstr "%q#D est implicitement supprimé car la définition par défaut serait m
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F est implicitement supprimé car sa spécification d'exception ne correspond pas à la spécification d'exception implicite %qX"
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "la déclaration par défaut %q+D ne correspond pas à la signature attendue"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "signature attendue: %qD"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "la fonction %q+D explicitement par défaut ne peut pas être déclarée %qs car la déclaration implicite n'est pas %qs :"
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "un patron ne peut pas être imposé par défaut"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD ne peut pas être imposé par défaut"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "fonction %q+D imposée par défaut avec un argument par défaut"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "redéclaration de %q#D avec des paramètres de patron différents"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D entre en conflit avec une déclaration précédente"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D cache le constructeur pour %q#D"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "déclarations conflictuelles de l'édition de liens du langage C %q#D"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "à cause de spécifications d'exceptions différentes"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "le paramètre lambda %qD a été déclaré précédemment comme une capture"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "la déclaration de %q#D masque un paramètre"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "la déclaration de %qD masque un membre de %qT"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "déclaration amie %qD dans la classe locale sans déclaration locale antérieure"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "%q#D n'a pas un lien externe"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D déclaré ici"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T%s%D%> nomme le destructeur"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "déclaration « using » pour un non membre au niveau de la portée de la classe"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> avec la portée énumérée %q#T uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT n'est pas une classe, un espace de noms ou une énumération"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "la déclaration « using » non membre nomme le constructeur de %qT"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "déclaration « using » pour un membre en dehors de la portée de la classe"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%qT n'est pas une base directe de %qT"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "vouliez-vous utiliser %<using enum %T::%D%> ?"
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD n'a pas été déclaré dans %qD"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "la déclaration « using » ne peut pas nommer l'espace de nom %qD"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nomme le constructeur dans %qT"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la déclaration de %qD n'est pas dans l'espace de noms entourant %qD"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "qualificatifs explicites dans la déclaration de %qD"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD aurait dû être déclaré à l'intérieur de %qD"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD n'a pas été déclaré dans %qD"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "uniquement ici comme un %<friend%>"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "l'attribut %qD requiert un seul argument NTBS"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "l'attribut %qD n'a pas de signification puisque les membres de l'espace de noms anonyme obtiennent des symboles locaux"
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms anonyme"
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms pas en ligne"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "la directive d'attribut %qD est ignorée"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "limite maximale de %d espaces de noms recherchés pour %qE"
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "alternative suggérée:"
 msgstr[1] "alternatives suggérées:"
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%<std::%s%> est défini dans l'en-tête %qs ; avez-vous oublié %<#include %s%> ?"
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> est uniquement disponible à partir de %s"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "la macro %qs n'a pas encore été définie"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "elle a été définie ici plus tard"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "la déclaration de %<std::initializer_list%> ne correspond pas à %<#include <initializer_list>%> et n%'est pas un patron"
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "la directive « using » %<strong%> n'est plus supportée"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "vous pouvez utiliser un espace de noms en ligne à la place"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "impossible d'imbriquer plus de %d espaces de noms"
 
 # %qs est le nom d'une procédure d'où le féminin
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> est ambigu"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "l'alias de l'espace de noms %qD n'est pas permis ici, on suppose %qD"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "un espace de nom en ligne doit être spécifié à la définition initiale"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD défini ici"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "l'espace de noms %s %qD est en conflit avec la définition atteignable"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "définition atteignable %s ici"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX entre dans %<pop_everything ()%>"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX quitte %<pop_everything ()%>"
@@ -52362,7 +52420,7 @@ msgstr "l'identificateur %qE est un mot clé en C++20"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> n'est pas défini à vrai"
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> pas immédiatement suivi par une déclaration ou une définition de fonction"
@@ -52387,7 +52445,7 @@ msgstr "%<::%E%> n'a pas été déclaré"
 msgid "request for member %qE in non-class type %qT"
 msgstr "requête du membre %qE dans le type %qT qui n'est pas une classe"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> n'a pas été déclaré"
@@ -52467,7 +52525,7 @@ msgstr "template-id invalide"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "le C++ ISO interdit l'utilisation d'un littéral en virgule flottante dans une expression constante"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "un transtypage vers un type autre qu'un entier ou une énumération ne peut pas apparaître dans une expression constante"
@@ -52603,7 +52661,7 @@ msgstr "le %<constinit%> du C++20 est uniquement disponible avec %<-std=c++20%>
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> uniquement disponible avec %<-std=c++20%> ou %<-fconcepts%>"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<requires%> uniquement disponible avec %<-std=c++20%> ou %<-fconcepts%>"
@@ -52728,7 +52786,7 @@ msgstr "impossible de trouver l'opérateur littéral de chaîne %qD avec les arg
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr "le contenu du fragment de module global doit provenir de l'inclusion du préprocesseur"
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "déclaration attendue"
@@ -52779,7 +52837,7 @@ msgstr "les expressions-instructions ne sont pas permises en dehors des fonction
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les expressions fold sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "expression primaire attendue"
@@ -52809,7 +52867,7 @@ msgstr "la portée %qT avant %<~%> n'est pas un nom de classe"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "le mot-clé %<template%> n'est pas permis dans le nom du destructeur"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%<~auto%> est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
@@ -52829,12 +52887,12 @@ msgstr "déclaration de %<~%T%> comme membre de %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "nom du typedef %qD utilisé comme déclaration de destructeur"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualified-id attendu"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD n'est pas un patron"
@@ -52869,7 +52927,7 @@ msgstr "template-id de la variable %qD dans le spécificateur de nom imbriqué"
 msgid "expected nested-name-specifier"
 msgstr "spécificateur de nom imbriqué attendu"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "les types ne peuvent pas être définis dans les transtypages"
@@ -52884,7 +52942,7 @@ msgstr "les types ne peuvent pas être définis dans une expression %<typeid%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_addressof%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_launder%>"
@@ -52899,1114 +52957,1120 @@ msgstr "le C++ ISO interdit les littéraux composés"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "deux %<[%> consécutifs n'introduiront qu'un attribut"
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "utilisation invalide de %qD"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> n'est pas un membre de classe"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "type non scalaire"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "le C++ ISO ne permet pas %<alignof%> avec un non type"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "les types ne peuvent pas être définis dans des expressions %<noexcept%>"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "les types ne peuvent pas être définis dans une expression %qs"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr "%<__builtin_has_attribute%> avec un argument dépendant n'est pas encore supporté"
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "les types ne peuvent pas être définis dans une expression « new »"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "les limites de tableau sont interdites après un type-id entre parenthèses"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "essayez d'enlever les parenthèses autour du type-id"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "l'initialisation de l'expression « new » pour le type %<auto%> exige exactement un élément"
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "liste-expression ou type-id attendu"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "les types ne peuvent pas être définis dans un new-type-id"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "l'expression dans la déclaration « new » doit être un type entier ou un type énuméré"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "utilisation d'un vieux style de transtypage vers %q#T"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "l'opérateur %<>>%> est traité comme deux caractères > en C++11"
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "parenthèses suggérées autour de l'expression %<>>%>"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "le C++ ISO ne permet pas d'omettre l'opérande du milieu de %<?:%>"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "une expression avec une virgule au plus haut niveau dans l'indice d'un tableau est déprécié"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "des types ne peuvent pas être définis dans %<__builtin_offsetof%>"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+#| msgid "lambda-expression in template-argument"
+msgid "lambda-expression in template parameter type"
+msgstr "expression lambda dans l'argument du patron"
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les expressions lambda dans un contexte non évalué sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les expressions lambda dans un argument de patron sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "une expression lambda non locale ne peut pas avoir de capture par défaut"
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "fin de liste de capture attendue"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "la capture par copie explicite de %<this%> est redondante avec la capture par copie par défaut"
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "%qD déjà capturé dans l'expression lambda"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "la capture de %<*this%> est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "ne peut capturer %<this%> par référence"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les captures d'initialisation compactes ne sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr "%<&%> devrait apparaître avant %<...%>"
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "les initialisations par capture des fonctions lambda sont uniquement disponibles avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "initialisation vide pour la capture par initialisation d'une fonction lambda"
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "capture de %qE qui n'est pas une variable"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "capture de la variable %qD avec une durée de stockage non automatique"
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "trop de %<...%> dans la capture lambda"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "la capture par copie explicite de %qD est redondante avec la capture par copie par défaut"
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "la capture par référence explicite de %qD est redondante avec la capture par référence par défaut"
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "les patrons lambda sont uniquement disponibles avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les patrons lambda sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "argument par défaut spécifié pour un paramètre lambda"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "la déclaration d'un paramètre avant des spécificateurs de déclarations lambda est uniquement optionnelle avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "%<mutable%> dupliqué"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "la déclaration d'un paramètre avant le qualificatif d'une transaction lambda est uniquement optionnelle avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "la déclaration d'un paramètre avant la spécification d'une exception lambda est uniquement optionnelle avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "la déclaration d'un paramètre avant le type de retour de fin d'une lambda est uniquement optionnelle avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les lambda %<constexpr%> sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "les attributs au début d'une instruction sont ignorés"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "instruction étiquetée attendue"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "le « case » %qE n'est pas à l'intérieur de l'instruction « switch »"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> doit être utilisé avant %qE car %qT est une portée dépendante"
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nomme le constructeur, pas le type"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "instruction composée dans une fonction %<constexpr%>"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<if constexpr%> uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "l'instruction init dans des instructions de sélection est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "instruction de sélection attendue"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr "la condition déclare un tableau"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr "la condition déclare une fonction"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "des types ne peuvent pas être définis dans des conditions"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initialisation attendue"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr "la variable de boucle %qD de type %qT est liée à un temporaire construit depuis le type %qT"
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr "utilisez le type non référence %qT pour faire une copie explicite ou %qT pour empêcher la copie"
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "la variable de boucle %qD crée une copie du type %qT"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr "utilisez un type de référence pour empêcher la copie"
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "l'expression %<for%> parcourant une plage de type %qT a un type incompatible"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "types différents pour « begin » et « end » de l'instruction %<for%> parcourant une plage: %qT et %qT"
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "instruction d'itération attendue"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les boucles %<for%> parcourant une plage avec un initialiseur sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les boucles %<for%> parcourant une plage sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> dans une fonction %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "le C++ ISO interdit les gotos calculés"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "instruction de saut attendue"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, gcc-internal-format
 msgid "expected module-name"
 msgstr "nom de module attendu"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr "la déclaration de module n'est pas permise dans une unité d'en-tête"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr "le fragment de module privé est uniquement permis dans le domaine d'interface de module ou de partition"
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, gcc-internal-format
 msgid "private module fragment"
 msgstr "fragment de module privé"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr "le déclaration de module est uniquement permise comme première déclaration ou à la fin d'un fragment de module global"
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr "les imports de déclarations post modules doivent être contigües"
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr "insérez peut-être un saut de ligne ou une autre résolution d'ambigüité pour empêcher ceci d'être considéré comme une ligne de contrôle de module"
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr "la déclaration d'import doit être dans la portée globale"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "l'import ne peut pas apparaître directement dans une spécification de classe de liaison"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr "les imports de déclarations post modules ne doivent pas être traduits en inclusions"
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr "les imports de déclarations post modules ne doivent pas provenir de l'inclusion d'en-tête"
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr "%qE peut uniquement apparaître après une déclaration d'interface de module"
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr "%qE peut uniquement apparaître une seule fois dans une déclaration d'export"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr "%<export%> ne fait pas partie de la directive de module suivante"
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "les attributs ne sont pas permis à cette position"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr "les attributs ne peuvent pas être insérés ici"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> superflu"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> pas au début du bloc"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "non variable %qD dans la déclaration avec plus d'une déclaration contenant un type à remplacer"
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "déduction incohérente pour %qT: %qT et puis %qT"
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "mélanger des déclarations et des définitions de fonctions est interdit"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "des types ne peuvent pas être définis dans la déclaration d'une instruction « for » parcourant une plage"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initialisation dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "déclarations multiples dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les liaisons structurées sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "déclaration de liaison structurée vide"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "initialisation invalide pour la déclaration de liaison structurée"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> utilisé en dehors d'une classe"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "le mot-clé %<bool%> n'est pas permis dans une définition de concept en C++20"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr "la syntaxe de définition d'un concept en C++20 est %<concept <name> = <expr>%>"
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> a changé de signification en C++11; retirez-le"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%<decl-specifier%> invalide dans une condition"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD est invalide dans une lambda"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "spécificateur de type invalide dans une lambda"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la définition de classe ne peut pas être déclarée comme amie"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "les patrons ne peuvent pas être %<virtual%>"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "les types ne peuvent pas être définis dans une spécification explicite"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<explicit(bool)%> est uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "spécification de classe de liaison invalide"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "un %<static_assert%> sans message est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "le spécificateur de type %<decltype(auto)%> est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "les types ne peuvent pas être définis dans les expressions %<decltype%>"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "les types ne peuvent pas être définis dans un conversion-type-id"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "utilisation invalide de %<auto%> dans un opérateur de conversion"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "un %<auto%> dans un opérateur de conversion d'un patron membre ne peut jamais être déduit"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "seuls les constructeurs prennent des initialisions membres"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "impossible de développer l'initialisation du membre %qD"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "l'initialisation en mémoire pour %qD suit la délégation du constructeur"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "la délégation du constructeur suit l'initialisation en mémoire pour %qD"
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "ancien style anachronique d'initialisation de classe de base"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (une initialisation de membre qualifiée est implicitement un type)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "mot-clé inattendu; enlevez l'espace entre les guillemets et l'identificateur du suffixe"
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "identificateur de suffixe attendu"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "une chaîne vide était attendue après le mot-clé %<operator%>"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "préfixe d'encodage invalide dans l'opérateur littéral"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "opérateur attendu"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "le mot-clé %<export%> n'est pas implémenté et sera ignoré"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "le mot-clé %<export%> est déprécié et est ignoré"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr "le mot-clé %<-export%> est activé avec %<-fmodules-ts%>"
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "paramètre de type contraint invalide"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "paramètre de type qualifié avec CV"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "utilisation invalide de %<auto%> dans l'argument par défaut du patron"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "les paquets de paramètres des patrons ne peuvent pas avoir d'arguments par défaut"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "template-id attendu"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> ne peut pas être au début d'une liste d'arguments d'un patron"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> est une écriture alternative pour %<[%>. Insérer un espace entre %<<%> et %<::%>"
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si vous utilisez %<-fpermissive%> ou %<-std=c++11%> ou %<-std=gnu++11%> G++ acceptera votre code)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "liste d'arguments de patron invalide"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr "un nom de fonction comme opérande dans le membre de gauche de %<<%> est toujours mal formé en C++20; incluez le nom de la fonction dans %<()%>"
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<(%> attendu après la liste d'arguments de patron"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "erreur d'analyse dans la liste des arguments du patron"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "nom de patron attendu"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD n'est pas un patron mais il est utilisé comme patron"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilisez %<%T::template %D%> pour indiquer que c'est un patron"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "paquet de paramètres attendu avant %<...%>"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "argument de patron attendu"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argument de patron invalide car ce n'est pas un type"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<inline%>"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<constexpr%>"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<consteval%>"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "spécialisation de patron avec édition de liens C"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "spécificateur du type attendu"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "l'utilisation de %<auto%> dans la déclaration d'un paramètre lambda est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "l'utilisation de %<auto%> dans une déclaration de paramètre est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "l'utilisation de %<auto%> dans une déclaration de paramètre est uniquement disponible avec %<-fconcepts-ts%>"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "template-id attendu pour le type"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE ne contraint pas un type"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr "concept défini ici"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<auto%> ou %<decltype(auto)%> attendu après %qE"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr "type à remplacer (« placeholder ») inattendu dans le type de retour contraint"
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "un spécificateur de type élaboré pour un enum fortement typé ne peut pas utiliser le mot-clé %qD"
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%<template%> doit suivre un nom de spécificateur imbriqué"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la déclaration %qD ne déclare rien du tout"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributs ignorés sur un type non instancié"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attributs ignorés sur une instanciation de patron"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attributs ignorés sur un spécificateur de type élaboré qui n'est pas une déclaration anticipée"
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD est un patron d'énumération"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD ne nomme pas une énumération dans %qT"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "un enum fortement typé sans nom n'est pas permis"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> ou %<{%> attendu"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "impossible d'ajouter une liste d'énumération à l'instanciation d'un patron"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "le spécificateur de nom imbriqué %qT pour la déclaration d'un enum ne nomme pas une classe ou un espace de noms"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans l'espace de noms %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "qualification supplémentaire pas permise"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "le C++ ISO interdit un enum vide et sans nom"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "spécificateur enum opaque sans nom"
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "un spécificateur enum opaque doit utiliser un simple identificateur"
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD n'est pas un nom d'espace de nom; vouliez-vous utiliser %qs ?"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD n'est pas un espace de noms"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "espace de noms attendu"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les définitions d'espace de noms imbriqués en ligne sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr "les attributs standards sur les espaces de noms doivent précéder le nom de l'espace de noms"
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les définitions d'espace de noms imbriqués sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "nom d'espace de nom imbriqué attendu"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "nom d'espace de nom attendu"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "une définition d'espace de noms imbriqué ne peut pas avoir d'attribut"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "une définition d'un espace de noms imbriqué ne peut pas être « inline »"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "entrée dans l'espace de noms %qD"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la définition %<namespace%> n'est pas permise ici"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "l'expansion de paquets dans une déclaration « using » est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un template-id ne peut pas apparaître dans l'utilisation de la déclaration"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "une liste séparée par des virgules dans une déclaration « using » est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "les déclarations d'accès sont dépréciées en faveur des déclarations « using »; suggestion: ajoutez le mot-clé %<using%>"
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "déclaration enum opaque ici"
 
 # alias template est un patron appliqué à un alias == patron d'alias
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "les types ne peuvent pas être définis dans des déclarations de patrons d'alias"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<asm%> dans une fonction %<constexpr%> uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "qualificatif %<asm%> %qT dupliqué"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "le qualificatif %<asm%> %qT est ignoré en dehors du corps d'une fonction"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT n'est pas un qualificatif %<asm%>"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "qualificatif %<asm%> en dehors du corps de la fonction"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "l'ambigüité sur les parenthèses vides a été résolue par une déclaration de fonction"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr "retirez les parenthèses pour initialiser par défaut une variable"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr "ou remplacez les parenthèses par des accolades pour initialiser par agrégation une variable"
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr "ou remplacez les parenthèses par des accolades pour initialiser par valeur une variable"
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, gcc-internal-format
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "l'ambigüité sur les parenthèses a été levée par un déclaration de fonction"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr "remplacez les parenthèses par des accolades pour déclarer une variable"
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr "ajoutez des parenthèses pour déclarer une variable"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "une définition de fonction n'est pas permise ici"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "une spécification %<asm%> n'est pas permise dans une définition de fonction"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "des attributs ne sont pas permis dans une définition de fonction"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "constructeur, destructeur ou conversion de type attendu"
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initialisation fournie pour une fonction"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "les attributs après l'initialisation entre parenthèses sont ignorés"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "la non fonction %qD est déclarée comme un patron implicite"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "la limite du tableau n'est pas une constante entière"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "impossible de définir le membre du typedef dépendant %qT"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> n'est pas un type"
@@ -54015,431 +54079,431 @@ msgstr "%<%T::%E%> n'est pas un type"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "déclarateur invalide"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "utilisation invalide du constructeur comme patron"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "utilisez %<%T::%D%> au lieu de %<%T::%D%> pour nommer le constructeur dans un nom qualifié"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id dans une déclaration"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "déclarateur attendu"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD est un espace de noms"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "impossible de former un pointeur vers un membre de la non classe %q#T"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "opérateur pointeur attendu"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "qualificatif CV dupliqué"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "qualificatifs de référence multiples"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE requiert %<-fgnu-tm%>"
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "spécificateurs virtuels (virt-specifier) multiples"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "arguments de patron manquants après %qT"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr "%qT pas permis dans un argument de patron"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "utilisation invalide de %qT"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "les types ne peuvent pas être définis dans les arguments du patron"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "utilisation invalide de %<auto%> dans un argument de patron"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "spécificateur de type attendu"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> ou %<...%> attendu"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "des types ne peuvent pas être définis dans des types de paramètres"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "des arguments par défaut sont uniquement permis pour des paramètres de fonction"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "le corps d'un function-try-block d'un constructeur %<constexpr%> est uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "le corps du function-try-block de la fonction %<constexpr%> est uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les initialisations désignées du C++ sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation de GNU"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation du C99"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "soit toutes les instructions d'initialisation devraient être désignées ou aucune ne devrait l'être"
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> pas permis dans une liste d'initialisation par désignation"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "désignateur %<.%s%> utilisé plusieurs fois dans la même liste d'initialiseurs"
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "nom de classe attendu"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> attendu après la définition de la classe"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> attendu après la définition de la structure"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> attendu après la définition de l'union"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> ou %<:%> attendu"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ne peut spécifier %<override%> pour une classe"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la qualification globale du nom de la classe est invalide"
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "le nom qualifié ne nomme pas une classe"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "le mot-clé %<template%> n'est pas permis dans class-head-name (NdT: nom de classe)"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nom de classe invalide dans la déclaration de %qD"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "une spécialisation explicite doit être précédée par %<template <>%>"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "le patron de fonction %qD est redéclaré comme un patron de classe"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "impossible de résoudre le type de typename"
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "définition précédente de %q#T"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "mot-clé de type classe (class ou struct) attendu"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "le C++ ISO interdit le mot-clé typename dans un paramètre de patron qui est un patron; utilisez %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> ou %<typename%> attendu"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03, le mot-clé class (ou struct) doit être utilisé lors de la déclaration d'un ami"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la déclaration amie ne nomme pas une classe ou une fonction"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "une classe de stockage sur un agrégat anonyme dans une classe n'est pas permis"
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les initialiseurs de membre par défaut pour les champs de bits sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "initialiseur d'un membre par défaut pour un champ de bits sans nom"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "le C++ ISO autorise les attributs de champs de bits uniquement avant l'élément %<:%>"
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "champ de bits %qD a le type non entier %qT"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "spécificateur pur sur une définition de fonction"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "%<;%> supplémentaire après la définition dans la classe"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<,%> égarée à la fin de la déclaration du membre"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> attendu à la fin de la déclaration du membre"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "spécificateur pur invalide (seul %<= 0%> est autorisé)"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "une initialisation entre accolades n'est par permise ici"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> spécifié plus d'une fois dans le spécificateur de base"
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "plus d'un spécificateur d'accès dans le spécificateur de base"
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "le mot-clé %<typename%> n'est pas permis en dehors des patrons"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (la classe de base est implicitement un type)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "les types ne peuvent pas être définis dans une spécification d'exception"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "le C++17 ISO n'autorise pas la spécification dynamique des exceptions"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "les spécifications dynamiques d'exceptions sont dépréciées en C++11"
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "utilisation invalide de %<auto%> dans une spécification d'exception"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<try%> dans une fonction %<constexpr%> uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "des types ne peuvent pas être définis dans une déclaration d'exception"
 
 # Je ne suis pas sûr du tout de la signification de « scoped attribute token »…
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "l'attribut de préfixe « using » est utilisé en même temps qu'un élément d'attribut agissant sur une portée"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "un identificateur est attendu pour le nom d'attribut"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr "les parenthèses doivent être omises si la liste d'arguments d'attributs %qE est vide"
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr "l'attribut %qs est spécifié plusieurs fois"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut attendu avant %<...%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "l'attribut de préfixe « using » est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "l'expression doit être comprise entre parenthèses"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "%<requires%> additionnel manquant pour démarrer une expression « requires »"
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "le type de résultat n'est pas un contrainte de type simple"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "l'exigence sur le type de retour n'est pas une contrainte de type"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "la syntaxe %<template<>%> est requise pour spécialiser %<%T::%E%>"
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "déclaration invalide de %<%T::%E%>"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "trop peu de listes de paramètres pour le patron"
@@ -54448,756 +54512,756 @@ msgstr "trop peu de listes de paramètres pour le patron"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "trop de listes de paramètres pour le patron"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "les valeurs nommées à retourner ne sont plus supportées"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "le C++ ISO n'a pas adopté les patrons d'opérateurs de chaînes littérales prenant un paquet d'arguments de caractères"
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet de paramètres de type non patron %<<char...>%> ou un unique paramètre non-type de type class"
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet de paramètres de type non patron tel que %<<char...>%>"
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr "les introductions de patrons ne font pas partie des concepts C++20 ; utilisez %qs pour l'activer"
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "pas de concept correspondant pour l'introduction du patron"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "déclaration invalide du patron membre dans la classe locale"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "patron avec liaison C"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "spécialisation explicite invalide"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "déclaration de patron de %<typedef%>"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "une déclaration de patron de classe ne doit rien déclarer d'autre"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "une spécialisation explicite de patron ne peut pas avoir une classe de stockage"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> devrait être %<> >%> à l'intérieur d'une liste d'arguments de patron imbriqués"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "le %<>>%> est faux, utilisez %<>%> pour terminer la liste d'arguments du patron"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "l'argument %<sizeof...%> doit être entouré de parenthèses"
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "utilisation invalide de %qD dans la spécification de la classe de liaison"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> avant %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "le C++ ISO 1998 ne permet pas %<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "%<__thread%> et %<thread_local%> sont tous les deux spécifiés"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "%qD dupliqué"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs dupliqué"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> attendu"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> attendu"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> attendu"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> attendu"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> attendu"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> attendu"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> attendu"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> attendu"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> attendu"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> attendu"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> attendu"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> attendu"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> attendu"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> attendu"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> attendu"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<auto%> attendu"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> attendu"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> attendu"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> attendu"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> attendu"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> attendu"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> attendu"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<co_yield%> attendu"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> attendu"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> attendu"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> attendu"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> attendu"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> ou %<::%> attendu"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> ou %<template%> attendu"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "clé d'énumération redondante dans %<enum%s%> en référence à %q#T"
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "étiquette %qs utilisée en nommant %q#T"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T a été précédemment déclaré ici"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "clé de classe %qs redondante en référence à %q#T"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT est déclaré avec clé de classe %qs non concordante"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "retirez la clé de classe ou remplacez là par %qs"
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "remplacez la clé de classe avec %qs"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT est défini en tant que %qs ici"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT déclaré en tant que %qs pour la première fois ici"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD redéclaré avec un accès différent"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "en C++98, %<template%> (afin de lever une ambigüité) est seulement permis à l'intérieur des patrons"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "fin de fichier dans l'argument par défaut"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construction Objective-C++ %<@%D%> mal placée"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "récepteur de message objective-c++ attendu"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "un ou des argument(s) de message objective-c++ est/sont attendu(s)"
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> doit spécifier un type comme un argument"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nom de sélecteur Objective-C++ invalide"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "une déclaration de méthode objective-c++ est attendue"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "les attributs de méthodes doivent être spécifiés à la fin"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs égaré entre des méthodes Objective-C++"
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "type invalide pour la variable d'instance"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identificateur attendu après %<@protocol%>"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "des attributs ne peuvent pas être spécifiés avant le mot-clé %<@%D%> en Objective-C++"
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "les attributs de préfixes sont ignorés avant %<@%D%>"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "type invalide pour une propriété"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "attribut de propriété %qE inconnu"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "liste d'expressions entières attendue"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "l'expression %<wait%> doit être un nombre entier"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "identificateur de réduction invalide"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "des types ne peuvent pas être définis dans des types d'itérateurs"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "une initialisation entre parenthèses n'est pas permise dans une boucle %<for%> de OpenMP"
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "clause %<ordered%> avec un paramètre sur une boucle %<for%> basée sur une portée"
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable d'itération %qD ne devrait pas être une réduction"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "pas assez de boucles « for » à combiner"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> suivi de %<#pragma omp declare %s%>"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "clause d'initialisation invalide"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "expression id (arguments) attendue"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<omp_priv%> ou %<&omp_priv%>"
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "des types ne peuvent pas être définis dans une liste de types de réductions"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "type arithmétique %qT prédéclaré dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "type tableau ou fonction %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "type référence %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "un qualificatif %<const%>, %<volatile%> ou %<__restrict%> est appliqué au type %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> nomme un ensemble de surcharges"
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD ne fait pas référence à une fonction à l'intérieur de l'espace de noms"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "le %<__transaction_cancel%> extérieur n'est pas à l'intérieur d'un %<__transaction_atomic%> extérieur"
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  ou une fonction %<transaction_may_cancel_outer%>"
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma GCC pch_preprocess%> mal composé"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp require%> peut uniquement être utilisé dans la portée du fichier ou de l'espace de noms"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "la compilation multi source n'est pas implémentée pour le C++"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "les types à remplacer ne sont pas permis dans ce contexte"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "les patrons implicites ne peuvent pas être %<virtual%>"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "édition de liens %<extern \"C\"%> démarrée ici"
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "le membre de données %qD ne peut pas être un patron membre"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "déclaration de patron membre %qD invalide"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "spécialisation explicite dans la portée d'un non espace de noms %qD"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "les patrons de classe englobants ne sont pas explicitement spécialisés"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "la spécialisation de %qD doit apparaître dans la portée de l'espace de noms"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "spécialisation de %qD dans différents espaces de noms"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  à partir de la définition de %q#D"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "instanciation explicite de %qD dans l'espace de noms %qD (qui n'englobe pas l'espace de noms %qD)"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "le nom de la classe masque le paramètre de patron %qD qui est lui-même un patron"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "spécialisation du patron d'alias %qD"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "spécialisation explicite du non patron %qT"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "spécialisation de %qT après instanciation"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "à partir de la définition de %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "spécialisation de %qT après instanciation %qT"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "la spécialisation du patron de %qD n'est pas permise par le C++ ISO"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "spécialisation de %qD après instanciation"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD n'est pas un patron de fonction"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD n'est pas un patron de variable"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD pour %q+D ne concorde avec aucune déclaration de patron"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "on a vu %d %<template<>%>, on a besoin de %d pour spécialiser un patron de fonction membre"
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "spécialisation de patron %qD ambiguë pour %q+D"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "les patrons de variables sont uniquement disponibles avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "trop d'en-têtes de patrons pour %qD (devrait être %d)"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "des membres d'une classe spécialisée explicitement sont définis sans en-tête de patron"
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "une spécialisation explicite de %qD en dehors de son espace de noms doit utiliser un spécificateur de nom imbriqué"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "une instanciation explicite de %qD en dehors de son espace de noms doit utiliser un spécificateur de nom imbriqué"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "il pourrait manquer des attributs dans la spécialisation explicite de %q#D"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "attributs de patron principal %s manquant"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "attribut de patron principal %s manquant"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "template-id %qE dans la déclaration de patron primaire"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "liste de paramètres de patron utilisée dans une instanciation explicite"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "définition fournie pour une instanciation explicite"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "trop de listes de paramètres de patron dans la déclaration de %qD"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "trop peu de listes de paramètres de patron dans la déclaration de %qD"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "la spécialisation explicite de %qD doit être introduite par %<template <>%>"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "la spécialisation explicite doit être déclarée %<concept%>"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "la spécialisation partielle du non type %qE n'est pas permise"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "la spécialisation partielle de la non variable ou non classe %qE n'est pas permise"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "argument par défaut spécifié dans la spécialisation explicite"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD n'est pas un patron de fonction"
@@ -55210,159 +55274,159 @@ msgstr "%qD n'est pas un patron de fonction"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "spécialisation d'une fonction membre spéciale déclarée implicitement"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "pas de fonction membre %qD déclarée dans %qT"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "la déclaration amie %qD n'est pas visible par la spécialisation explicite"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "déclaration amie ici"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "spécialisation explicite du concept de fonction %qD"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "l'argument de %<__integer_pack%> doit être compris entre 0 et %d"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "l'expansion de l'initialisation de base %qT ne contient pas de paquet de paramètres"
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "le motif d'expansion %qT ne contient pas de paquet de paramètres"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "le motif d'expansion %qE ne contient pas de paquet de paramètres"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "les paquets de paramètres ne sont pas étendus avec %<...%>"
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "la déclaration du paramètre de patron %q+D masque le paramètre de patron"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "la déclaration de %q+#D masque un paramètre de patron"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "le paramètre de patron %qD est déclaré ici"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "spécialisation du concept de variable %q#D"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "les paramètres du patron ne peuvent pas être déduits dans la spécialisation partielle:"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron et n'a pas plus de contrainte que le patron primaire; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "le patron primaire ici"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "la spécialisation partielle n'est pas plus spécialisée que le patron primaire car elle remplace des paramètres multiples par une expansion d'un paquet"
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "trop d'arguments pour la spécialisation partielle %qT"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la spécialisation partielle de %qD n'est pas plus spécialisée que"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "le patron primaire %qD"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "l'argument %qE du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "l'argument %qT du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "l'argument %qE du patron implique des paramètres du patron"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "le type %qT de l'argument %qE du patron dépend d'un paramètre du patron"
 msgstr[1] "le type %qT de l'argument %qE du patron dépend de paramètres du patron"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "la déclaration de %qD rend ambigüe l'instanciation précédente du patron pour %qD"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spécialisation partielle de %qD après l'instanciation de %qD"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "pas d'argument par défaut pour %qD"
@@ -55371,47 +55435,47 @@ msgstr "pas d'argument par défaut pour %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "le paquet de paramètres %q+D doit être à la fin de la liste des paramètres du patron"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans la redéclaration d'un ami d'un patron d'une fonction"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans les déclarations d'un ami d'un patron"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des patrons de fonctions sans %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des spécialisations partielles"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argument par défaut pour le paramètre de patron pour la classe englobant %qD"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "patron %qD déclaré"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "patron de classe sans nom"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "le patron de membre %qD ne peut pas avoir de spécificateur virtuel (virt-specifier)"
@@ -55421,493 +55485,493 @@ msgstr "le patron de membre %qD ne peut pas avoir de spécificateur virtuel (vir
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "déclaration de patron %qD invalide"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "définition de patron d'un non patron %q#D"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "on attendait %d niveaux de paramètres du patron pour %q#D mais on en a obtenu %d"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "a obtenu %d paramètres de patron pour %q#D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "a obtenu %d paramètres de patron pour %q#T"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  mais %d son requis"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "les arguments du patron %qD ne correspondent pas à ceux du patron original %qD"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilisez %<template<>%> pour une spécialisation explicite"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT n'est pas un type de patron"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "spécificateurs de patron pas spécifiés dans la déclaration de %qD"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redéclaré avec %d paramètre dans le patron"
 msgstr[1] "redéclaré avec %d paramètres dans le patron"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "la déclaration précédente %qD utilisait %d paramètre dans le patron"
 msgstr[1] "la déclaration précédente %qD utilisait %d paramètres dans le patron"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "paramètre %q+#D du patron"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redéclaré ici comme %q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "déclaration du paramètre de patron %q+#D avec des contraintes différentes"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "la déclaration originale apparaît ici"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redéfinition de l'argument par défaut pour %q#D"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "la définition originale apparaît ici"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "redéclaration de %q#D avec des contraintes différentes"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE n'est pas un argument de patron valide pour le type %qT"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "il doit être l'adresse d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "il doit être le nom d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison externe"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "il doit être un pointeur vers un membre de la forme %<&X::Y%>"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "car il est un membre de %qT"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  n%'a pu déduire le paramètre %qD du patron"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  les types %qT et %qT ont des qualificatifs CV incompatibles"
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  types %qT et %qT non concordants"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  le paramètre %qD du patron n'est pas un paquet de paramètres mais l'argument %qD en est un"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  l'argument %qE du patron ne correspond pas à la constante %qE qui est un pointeur vers un membre"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE n'est pas équivalent à %qE"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  déduction du paquet de paramètres inconsistante entre %qT et %qT"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  types déduits conflictuels pour le paramètre %qT (%qT et %qT)"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  valeurs déduites conflictuelles pour le paramètre non type %qE (%qE et %qE)"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  le type tableau %qT dimensionné par une variable n'est pas un argument de patron valable"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  le type fonction membre %qT n'est pas un argument de patron valable"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  le candidat attend au moins %d argument, %d fourni(s)"
 msgstr[1] "  le candidat attend au moins %d arguments, %d fourni(s)"
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  ne peut convertir %qE (type %qT) vers le type %qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT est une classe de base ambigüe de %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT n'est pas dérivé de %qT"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  les paramètres du patron d'un argument de patron qui est lui-même un patron sont inconsistants avec les autres arguments déduits pour le patron"
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  impossible de déduire un patron pour %qT depuis le type non patron %qT"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  l'argument de patron %qE ne correspond pas à %qE"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qE n'est pas une variable"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable de type %qT en C++98 car %qD n'a pas une classe de liaison externe"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "l'adresse du sous-objet %qT de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable car elle n'a pas une durée de stockage statique"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD n'est pas un argument de patron valable car %qD est une variable, pas une adresse d'une variable"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE n'est pas un argument de patron valable pour %qT car ce n'est pas l'adresse d'une variable"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car les chaînes littérales ne peuvent jamais être utilisées dans ce contexte"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "dans l'argument de patron pour le type %qT"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "l'argument de patron %qE pour le type %qT n'est pas une constante durant la compilation"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT à cause de conflits dans les qualificatifs CV"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car ce n'est pas une l-valeur"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D n'est pas un argument de patron valable pour le type %qT car une variable de référence n'a pas une adresse constante"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est un pointeur"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "essayez d'utiliser %qE à la place"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est du type %qT"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "les attributs sur l'argument %qT du patron sont ignorés"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "les attributs dans l'argument %qE du patron sont ignorés"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nom de classe injecté %qD utilisé comme argument de patron qui est lui-même un patron"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "utilisation invalide du destructeur %qE comme un type"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "pour faire référence à un membre type d'un paramètre de patron, utilisez %<typename %E%>"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "non concordance de type/valeur pour l'argument %d dans la liste des paramètres du patron de %qD"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  on attendait une constante de type %qT, on a obtenu %qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  l'argument de patron ambigu pour le paramètre de patron non type est traité comme un type fonction"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  on attendait un patron de classe, on a obtenu %qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  on attendait un type, on a obtenu %qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  on attendait un type, on a obtenu %qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  on attendait un patron de classe, on a obtenu %qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  on attendait un patron de type %qD, on a obtenu %qT"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "désaccord de contrainte à l'argument %d dans la liste des paramètres du patron pour %qD"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  on attendait %qD, on a obtenu %qD"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "impossible de convertir l'argument %qE du patron de %qT vers %qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "l'argument %d du patron est invalide"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être %d)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être au moins %d)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "fournis pour %qD"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du patron d'alias %qD"
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du concept %qD"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "ainsi, toute instanciation avec un paquet de paramètres non vide serait mal formée"
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D n'est pas un patron de fonction"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "type non patron %qT utilisé comme un patron"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "pour la déclaration du patron %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "échec de la contrainte du patron pour %qD"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "utilisation du patron de variable invalide %qE"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum qui est %d (utilisez %<-ftemplate-depth=%> pour augmenter le maximum)"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "membre tableau flexible %qD dans l'union"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "repli de l'expansion vide sur %O"
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE n'est pas le motif entier de l'expansion du paquet"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qT"
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qE"
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  lors de l'instanciation de l'argument par défaut pour l'appel à %qD"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "création d'un pointeur vers la fonction membre d'un type non classe %qT"
@@ -55925,291 +55989,291 @@ msgstr "création d'un pointeur vers la fonction membre d'un type non classe %qT
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD a un type fonction"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "type de paramètre %qT invalide"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dans la déclaration de %q+D"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fonction retournant un tableau"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fonction retournant une fonction"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formation d'une référence vers void"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formation d'un pointeur vers le type de référence %qT"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formation d'une référence vers le type de référence %qT"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formation d'un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formation d'une référence vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "création d'un pointeur vers le membre d'un type non classe %qT"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "création d'un pointeur vers le type de référence au membre %qT"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "création d'un pointeur vers le membre de type void"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD est instancié pour un paquet vide"
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT n'est pas un type class, struct ou union"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT est résolu en %qT qui n'est pas un type d'énumération"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT est résolu en %qT qui n'est pas un type de classe"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "utilisation de %qs dans le patron"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "le nom dépendant %qE est analysé comme un non type, mais son instanciation produit un type"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "utilisez %<typename %E%> si un type est désiré"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "l'initialiseur pour %q#D est développé en une liste vide d'expressions"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "utilisation du champ %qD invalide"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "utilisation invalide de l'expression d'expansion d'un paquet"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "utilisez %<...%> pour dérouler le paquet d'arguments"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "initialisation vide dans l'initialisation par capture de la fonction lambda"
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD n'a pas été déclaré dans cette portée et aucune déclaration a été trouvée par le recherche dépendant des arguments au point d'instanciation"
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "les déclarations dans la base dépendante %qT ne sont pas trouvées par une recherche non qualifiée"
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "utilisez plutôt %<this->%D%>"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "utilisez plutôt %<%T::%D%>"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD déclaré ici, plus loin dans l'unité de traduction"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_convertvector%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT est/utilise un type anonyme"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "l'argument du patron pour %qD utilise le type local %qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT est un type modifié par une variable"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "l'expression intégrale %qE n'est pas une constante"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  tentative d'instancier %qD"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciation de patron ambiguë pour %q#T"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciation de patron ambiguë pour %q#D"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciation explicite du non patron %q#D"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "instanciation explicite du concept de variable %q#D"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instanciation explicite du concept de fonction %q#D"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD n'est pas un membre de données statique d'un patron de classe"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "aucun patron correspondant trouvé pour %qD"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "le type %qT pour l'instanciation explicite %qD ne correspond pas au type déclaré %qT"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciation explicite de %q#D"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciation explicite dupliquée pour %q#D"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "le C++ ISO 1998 interdit l'utilisation de %<extern%> sur des instanciations explicites"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "classe de stockage %qD appliquée à l'instanciation du patron"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciation explicite du patron non classe %qD"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciation explicite du type non patron %qT"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciation explicite de %q#T avant la définition de patron"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "le C++ ISO interdit l'utilisation de %qE sur des instanciations explicites"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciation explicite dupliquée de %q#T"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "la spécification d'exception %qD dépend d'elle-même"
@@ -56221,153 +56285,153 @@ msgstr "la spécification d'exception %qD dépend d'elle-même"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciation explicite de %qD mais pas de définition disponible"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum de %d lors de l'instanciation de %q+D, peut-être via la génération de la table virtuelle (utilisez %<-ftemplate-depth=%> pour augmenter le maximum)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les paramètres de patrons non typés du type classe déduit sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT n'est pas un type valide pour un paramètre non type du patron car il n'est pas structurel"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les paramètres de patrons non typés du type classe sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "le paramètre non type du patron est invalide"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T n'est pas un type valide pour un paramètre non type du patron"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "le mot-clé %<template%> n'est pas permis dans declarator-id"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "un concept ne peut être contraint"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "le concept %qE n'est pas dans la portée de l'espace de noms"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la déduction à partir d'une liste d'initialisation entre accolades requiert %<#include <initializer_list>%>"
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "le patron %qT ne peut être déduit et il est utilisé sans arguments de patron"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "la déduction du patron synonyme est uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "impossible de déduire les arguments du patron pour l'initialisation par copie de %qT car il n'a pas de guides de déduction non explicites ou de constructeur déclaré par l'utilisateur"
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "impossible de déduire les arguments du patron de %qT car il n'a pas de guides de déduction viables"
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "la déduction des arguments du patron de classe a échoué:"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "les guides de déduction explicites ne sont pas pris en compte pour l'initialisation par copie"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "la déduction de l'argument du patron de classe pour %qT a échoué : guide de déduction explicite sélectionné dans l'initialisation par copie de liste"
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "guide de déduction explicite déclaré ici"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT peut ne pas avoir l'intention de supporter la déduction d'argument pour un patron de classe"
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "ajoutez un guide de déduction pour supprimer cet avertissement"
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "l'initialisation par liste directe de %<auto%> requiert exactement un élément"
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "pour la déduction de %<std::initializer_list%>, utilisez l'initialisation par liste copiée (c-à-d ajoutez %<=%> avant le %<{%>)"
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "impossible de déduire le type de retour de la lambda à partir de %qE"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "impossible de déduire %qT à partir de %qE"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "les contraintes sur le type à remplacer ne sont pas satisfaites"
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "l'initialisation déduite ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "le type retourné déduit ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "le type déduit pour l'expression ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "utilisation invalide de %qT dans un argument de patron"
@@ -56502,532 +56566,532 @@ msgstr "%q+#D ne peut pas être déclaré"
 msgid "  since %q+#D declared in base class"
 msgstr "  puisque %q+#D est déclaré dans la classe de base"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%qs est toujours évalué à « vrai » dans %<if constexpr%>"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "des accolades explicites sont suggérées autour du corps vide de l'instruction %<do%>"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr "interception du type polymorphique %q#T par valeur"
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr "interception du type %q#T par valeur"
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr "interception du type %q#T qui n'est pas une référence"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "le type de l'opérande %<asm%> %qE n'a pas pu être déterminé"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "les déclarations %<__label__%> sont uniquement permises à l'intérieur des fonctions"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "utilisation invalide du membre %qD dans une fonction membre statique"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "%qE arguments de patron manquants"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "une expression-instruction est un contexte insuffisant pour la résolution d'une surcharge"
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "impossible d'appeler un concept comme une fonction"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "le destructeur n'accepte pas d'argument"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> n'est pas disponible pour les fonctions membres statiques"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "utilisation invalide de %<this%> dans une fonction non membre"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "utilisation invalide de %<this%> hors de toute fonction"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "étendue de qualification invalide dans le nom du pseudo-destructeur"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne concorde pas avec le nom du destructeur ~%qT"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE n'est pas un type %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "littéral composé du type non objet %qT"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "les paramètres de type du patron doivent utiliser le mot-clé %<class%> ou %<typename%>"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "utilisation invalide du type %qT comme valeur par défaut pour un paramètre de patron qui est lui-même un patron"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argument par défaut invalide pour un paramètre de patron qui est un patron"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "définition de %q#T à l'intérieur d'une liste de paramètres de patron"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "définition invalide du type qualifié %qT"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "spécification de classe de base invalide"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "impossible de capturer le membre %qD d'une union anonyme"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD n'est pas capturé"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "la lambda n'a pas de capture par défaut"
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "la lambda dans la classe locale %q+T ne sait pas capturer des variables du contexte englobant"
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "utilisation d'une variable locale avec un stockage automatique dans la fonction contenante"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "utilisation d'un paramètre dans la fonction contenante"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "utilisation du paramètre en dehors du corps de la fonction"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "arguments de patron manquants"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "le paramètre %qD du patron, du type %qT, n'est pas permis dans une expression constante intégrale parce qu'il n'est pas d'un type intégral ou énuméré"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "utilisation du patron de classe %qT comme expression"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "l'accès au membre %qD est ambigu dans un réseau d'héritages multiples"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD ne peut pas apparaître dans une expression constante"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "le type de %qE est inconnu"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT n'est pas un type énuméré"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "Le paquet de paramètres %<__bases%> est uniquement valable dans la déclaration d'un patron"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "impossible d'appliquer %<offsetof%> au destructeur %<~%T%>"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "impossible d'appliquer %<offsetof%> à la fonction membre %qD"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "impossible d'appliquer %<offsetof%> à la fonction membre"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "impossible d'appliquer %<offsetof%> à un énumérateur %qD"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "l'utilisation de %<offsetof%> à l'intérieur du type %qT (qui ne respecte pas l'agencement standard) est supporté conditionnellement"
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> est autorisé dans OpenMP uniquement dans les clauses %<declare simd%>"
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la recherche de la réduction définie par l'utilisateur est ambiguë"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE dans la clause %<reduction%> est un tableau de taille nulle"
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE a le type const pour %<reduction%>"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "réduction définie par l'utilisateur avec une initialisation du constructeur pour la classe de base %qT"
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "la clause linéaire avec le modificateur %qs est appliquée à la variable non référence ayant le type %qT"
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "clause linéaire appliquée à la variable non entière non pointeur ayant le type %qT"
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "l'expression du pas de « linear » doit être un entier"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<firstprivate%>"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<lastprivate%>"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "l'expression statique %<gang%> doit être un entier"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "la valeur statique de %<gang%> doit être positive"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "l'expression numérique de %<gang%> doit être un entier"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "l'expression de longueur de %<vector%> doit être un entier"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "l'expression numérique de %<worker%> doit être un entier"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "la valeur numérique de %<gang%> doit être positive"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "la valeur de longueur de %<vector%> doit être positive"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "la valeur numérique de %<worker%> doit être positive"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "l'expression de taille des tranches d'ordonnancement doit être un entier"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "l'expression de longueur de %qs doit être un entier"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "l'expression de longueur %qs doit être une expression entière constante positive"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "l'expression de %<async%> doit être un entier"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "l'expression de %<thread_limit%> doit être un entier"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "l'identifiant de %<device%> doit être entier"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "l'expression de la taille des tranches de %<dist_schedule%> doit être un entier"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<aligned%>"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE dans la clause %<aligned%> n'est ni un pointeur ni un tableau ni une référence vers un pointeur ou un tableau"
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<aligned%>"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "l'expression d'alignement de la clause %<aligned%> doit être un entier"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<nontemporal%>"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<nontemporal%>"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%<this%> n'est pas autorisé dans la clause %<allocate%>"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<allocate%>"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<allocate%>"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD n'est pas une expression l-valeur ni une section de tableau dans une clause %<depend%>"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "patron %qE dans la clause %qs"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "nom de fonction surchargée %qE dans la clause %qs"
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "l'expression de %<grainsize%> doit être un entier"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "l'expression de %<priority%> doit être un entier"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "l'expression %<hint%> doit être un nombre entier"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "l'expression %<hint%> doit être une expression entière constante"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "la variable %qs n'est ni un pointeur ni une référence à un pointeur"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau ni une référence à un pointeur ou un tableau"
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "l'argument de %<tile%> doit être de type entier"
 
 # Cette traduction aurait du sens si on pouvait changer l'ordre des %. Je n'arrive pas à savoir si c'est possible.
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%> qualifiant %qE sans membre %<mutable%> ne peut apparaître que dans les clauses %<shared%> ou %<firstprivate%>"
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD n'est pas un fichier, un espace de noms ou une variable déclarée dans un bloc"
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directive %<threadprivate%> %qE n'est pas dans la définition de %qT"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la différence entre %qE et %qD n'est pas un type entier"
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> utilisé avec la variable d'itération de classe %qE"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> utilise deux expressions différentes pour la mémoire"
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "l'assertion statique a échoué: %s"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr "%qE est évalué à « faux »"
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condition non constante pour l'assertion statique"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "l'argument de %<decltype%> doit être une expression"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> ne sait pas résoudre l'adresse d'une fonction surchargée"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "l'opérande de l'expression fold n'a aucun paquet de paramètres non déroulé"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "les deux arguments dans le fold binaire ont des paquets de paramètres non déroulés"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "aucun paquet de paramètres non déroulés dans le fold binaire"
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
@@ -57035,22 +57099,22 @@ msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "%<__builtin_bit_cast%> a le type de destination %qT qui est un type tableau"
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%> a le type de destination %qT qui n'est pas trivialement copiable"
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%> a le type source %qT qui n'est pas trivialement copiable"
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "%<__builtin_bit_cast%> a la taille source %qE qui n'est pas égale à la taille du type destination %qE"
@@ -57060,1052 +57124,1053 @@ msgstr "%<__builtin_bit_cast%> a la taille source %qE qui n'est pas égale à la
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "les qualificatifs %qV ne peuvent pas être appliqués à %qT"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "expression instruction dans une expression constante"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr "%<-fabi-version=13%> (GCC 8.2) corrige la convention d'appel pour %qT qui a changé accidentellement en 8.1"
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr "%<-fabi-version=12%> (GCC 8.1) change accidentellement la convention d'appel pour %qT"
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, gcc-internal-format
 msgid " declared here"
 msgstr " déclaré ici"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "la convention d'appel pour %qT change avec %<-fabi-version=13%> (GCC 8.2)"
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " car tous ses constructeurs par copie et déplacement sont supprimés"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "la classe de base %qT n'est pas publique"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qD n'est pas public"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD n'est pas mutable"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD a un type non structurel"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "l'argument de l'attribut %qE doit être une constante de chaîne de caractères"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "l'attribut %qE peut uniquement être appliqué aux fonctions ou aux classes ou aux types énumérés"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "l'attribut %qE peut uniquement être appliqué aux membres de données non statiques"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "l'attribut %qE ne peut pas être appliqué à un champ de bits"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "l'attribut %qE ne prend pas d'argument"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "l'attribut %qE du C++ ISO ne s'applique pas aux fonctions; il est traité comme %<[[gnu::%E]]%>"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "le %<init_priority%> demandé n'est pas une constante entière"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "l'attribut %qE peut uniquement être utilisé sur les définitions dans la portée du fichier d'objets de type classe"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "le %<init_priority%> %i demandé est hors des limites [0, %i]"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "le %<init_priority%> %i demandé est réservé pour un usage interne"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "l'attribut %qE n'est pas supporté sur cette plate-forme"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "la redéclaration de %qD ajoute l'étiquette d'ABI %qE"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "l'attribut %qE requiert des arguments"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "les arguments de l'attribut %qE doivent être des chaînes littérales étroites"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "les arguments de l'attribut %qE doivent contenir des identificateurs valables"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> n'est pas un premier caractère valable pour un identificateur"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> n'est pas un caractère valable dans un identificateur"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "attribut %qE appliqué au type %qT qui n'est ni une classe ni un enum"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attribut %qE appliqué à %qT après sa définition"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "l'attribut %qE est ignoré car il est appliqué à l'instanciation du patron %qT"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "l'attribut %qE est ignoré car il est appliqué à la spécialisation du patron %qT"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attribut %qE appliqué à %qD qui n'est ni une fonction ni une variable"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribut %qE appliqué à la déclaration extern \"C\" %qD"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "zéro comme constante de pointeur nul"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "vérification de %<lang_*%> : échec dans %s, à %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la comparaison entre des pointeurs de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la conversion entre des pointeurs de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "l'expression conditionnelle entre des pointeurs de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "le C++ ISO interdit la comparaison entre les pointeurs de type %<void *%> et les pointeurs de fonctions"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "le C++ ISO interdit la conversion entre les pointeurs de type %<void *%> et les pointeurs de fonctions"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "le C++ ISO interdit l'expression conditionnelle entre les pointeurs de type %<void *%> et les pointeurs de fonctions"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la comparaison entre des pointeurs vers des membres de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la conversion entre des pointeurs vers des membres de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "l'expression conditionnelle entre des pointeurs vers des membres de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "les types canoniques diffèrent pour les types identiques %qT et %qT"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "nœud de type canonique identique pour les types différents %qT et %qT"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "application invalide de %qs à une fonction membre"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "application invalide de %<sizeof%> sur un champ de bits"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "le C++ ISO interdit l'application de %<sizeof%> à une expression d'un type de fonction"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "application invalide de %<__alignof%> sur un champ de bits"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "le C++ ISO interdit l'application de %<__alignof%> à une expression d'un type de fonction"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "l'argument de %<alignas%> a le type non entier %qT"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "utilisation invalide de la fonction membre non statique de type %qT"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "prise de l'adresse d'un tableau temporaire"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "le C++ ISO interdit la conversion d'une chaîne constante vers %qT"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "conversion obsolète de la chaîne constante vers %qT"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "requête du membre %qD dans %qE, lequel est le type pointeur %qT (vous avez peut-être oublié d'utiliser %<->%> ?)"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "requête du membre %qD dans %qE, lequel est de type non classe %qT"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "utilisation invalide du membre de donnée non statique %qE"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "accès invalide au membre de donnée non statique %qD dans la base virtuelle d'un objet NULL"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "l'objet de type %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "le type devant être détruit est %qT, mais le destructeur réfère à %qT"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "le champ %q#D peut être accessible via %q#D"
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T n'a pas de membre nommé %qE"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %q#D ? (accessible via %q#D)"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %q#D ? (pas accessible depuis ce contexte)"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %qE ?"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> n'est pas un membre de %qT"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT n'est pas une base de %qT"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD n'est pas une fonction patron membre"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT n'est pas un type pointeur vers un objet"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "utilisation invalide de l'indexation de tableau sur un pointeur vers un membre"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "utilisation invalide du %<*%> unaire sur un pointeur vers un membre"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "utilisation invalide de la conversion implicite d'un pointeur vers un membre"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "l'opérande de gauche de %<->*%> doit être un pointeur vers une classe mais il est un pointeur vers un membre du type %qT"
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "indice manquant dans la référence du tableau"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "l'accès indicé du tableau est déclaré %<register%>"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "la valeur indicée n'est ni un tableau ni un pointeur"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objet manquant dans l'usage de %qE"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "le C++ ISO interdit l'appel de %<::main%> depuis l'intérieur du programme"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "il faut utiliser %<.*%> ou %<->*%> pour appeler une fonction via un pointeur vers un membre dans %<%E (...)%>, par ex: %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE ne peut pas être utilisé comme une fonction"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD ne peut pas être utilisé comme une fonction"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "l'expression ne peut pas être utilisée comme une fonction"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "trop d'arguments pour le constructeur %q#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "pas assez d'arguments pour le constructeur %q#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "trop d'arguments pour la fonction membre %q#D"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "trop peu d'arguments pour la fonction membre %q#D"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "trop d'arguments pour la fonction %q#D"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "trop peu d'arguments pour la fonction %q#D"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "trop d'arguments pour la méthode %q#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "pas assez d'arguments pour la méthode %q#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "trop d'arguments pour la fonction"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "trop peu d'arguments pour la fonction"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "le paramètre %P de %qD a un type incomplet %qT"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "le paramètre %P a un type incomplet %qT"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "l'adresse de %qD ne sera jamais NULL"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "le compilateur peut supposer que l'adresse de %qD ne sera jamais NULL"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "l'opération au niveau des bits entre les types énumérés différents %qT et %qT est dépréciée"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "l'arithmétique entre des types énumérés différents %qT et %qT est dépréciée"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr "la comparaison du type énuméré %qT avec le type en virgule flottante %qT est dépréciée"
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "la comparaison du type en virgule flottante %qT avec le type énuméré %qT est dépréciée"
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "l'arithmétique entre le type énuméré %qT et le type en virgule flottante %qT est déprécié"
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "l'arithmétique entre le type en virgule flottante %qT et le type énuméré %qT est déprécié"
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "suppose un transtypage vers le type %qT depuis la fonction surchargée"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL utilisé en arithmétique"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "le C++ ISO interdit la comparaison entre un pointeur et un entier"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "les types des opérandes sont %qT et %qT"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "comparaison à trois voies de vecteurs"
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "comparaison ordonnée d'un pointeur avec un zéro entier (%qT et %qT)"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "comparaison non ordonnée sur un argument n'étant pas en virgule flottante"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "conversion implicite de %qH vers %qI pour correspondre à d'autres opérandes de l'expression binaire"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "les opérandes des types %qT et %qT sont invalides pour le %qO binaire"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur de type %<void *%> dans une soustraction"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur vers une fonction dans une soustraction"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur vers une méthode dans une soustraction"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "utilisation invalide d'un pointeur vers un type incomplet dans un pointeur arithmétique"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "prise de l'adresse du destructeur %qD"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "prise de l'adresse du destructeur %qD"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "utilisation invalide de %qE pour former un pointeur vers une fonction membre"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  un qualified-id est requis"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "les parenthèses autour de %qE ne peuvent pas être utilisées pour former un pointeur vers une fonction membre"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre non statique non qualifié ou entre parenthèses pour former un pointeur vers une fonction membre. Utilisez %<&%T::%D%>"
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre liée pour former un pointeur vers une fonction membre. Utilisez %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "prise de l'adresse d'une r-valeur"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "le C++ ISO interdit de prendre l'adresse de la fonction %<::main%>"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ne peut créer un pointeur vers le membre de référence %qD"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "tentative de prendre l'adresse d'un champ de bits"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "prise de l'adresse d'une fonction immédiate %qD"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> sur une expression de type %<bool%>"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "vouliez-vous utiliser le non logique (%<!%>) ?"
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "le C++ ISO interdit d'incrémenter un enum"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "le C++ ISO interdit de décrémenter un enum"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ne peut incrémenter un pointeur vers le type incomplet %qT"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ne peut décrémenter un pointeur vers le type incomplet %qT"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "le C++ ISO interdit d'incrémenter un pointeur du type %qT"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "le C++ ISO interdit de décrémenter un pointeur du type %qT"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "l'expression %qs du type qualifié avec %<volatile%> est dépréciée"
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator--%> est interdite"
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator++%> est interdite en C++17"
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator++%> est dépréciée"
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "ne peut prendre l'adresse de %<this%> qui est une expression r-valeur"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adresse de la variable registre explicite %qD requise"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse requise pour %qD qui est déclaré %<register%>"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "une initialisation par liste pour un type non classe ne doit pas être entre parenthèses"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "la liste d'expressions est traitée comme une expression composée dans l'initialisation"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "la liste d'expressions est traitée comme une expression composée dans l'initialisation mémoire"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "la liste d'expressions est traitée comme une expression composée dans le transtypage fonctionnel"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "la liste d'expressions dans « %s » est traitée comme une expression composée"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "pas de contexte pour résoudre le type de %qE"
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "le transtypage du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "utiliser %<static_cast%> pour transtyper du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "utiliser %<reinterpret_cast%> pour transtyper du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "transtypage inutile vers le type %q#T"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "les qualificatifs de type sont ignorés sur le type résultant du transtypage"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "%<static_cast%> invalide depuis le type %qT vers le type %qT"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "le type classe %qT est incomplet"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 msgid "converting from %qH to %qI"
 msgstr "conversion de %qH vers %qI"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "transtypage invalide d'une expression r-valeur du type %qT vers le type %qT"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
 msgstr "le transtypage de %qH vers %qI perd en précision"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "transtypage entre types de fonctions incompatibles de %qH vers %qI"
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "transtypage entre des pointeurs incompatibles vers des types membres de %qH vers %qI"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "le transtypage de %qH vers %qI augmente l'alignement requis pour le type ciblé"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "le transtypage entre un pointeur vers une fonction et un pointeur vers un objet est supporté conditionnellement"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "transtypage invalide à partir du type %qT vers le type %qT"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "utilisation invalide de %<const_cast%> avec le type %qT qui n'est pas un pointeur, une référence, ni un type pointeur vers une donnée membre"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "utilisation invalide de %<const_cast%> avec le type %qT qui est un pointeur ou une référence à un type fonction"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "%<const_cast%> invalide d'une r-valeur du type %qT vers le type %qT"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "%<const_cast%> invalide à partir du type %qT vers le type %qT"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "le C++ ISO interdit le transtypage vers un type tableau %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "transtypage invalide vers le type fonction %qT"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr "une affectation composée avec un opérande de gauche qualifié avec %<volatile%> est déprécié"
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  lors de l'évaluation de %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "affectation à un tableau depuis une liste d'initialisation"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "types incompatibles dans l'affectation de %qT vers %qT"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "tableau utilisé comme initialisation"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "affectation de tableau invalide"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dans la conversion d'un pointeur vers une fonction membre"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "conversion d'un pointeur vers un membre via la base virtuelle %qT"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dans la conversion d'un pointeur vers un membre"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversion invalide vers le type %qT à partir du type %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ne peut convertir %qH en %qI dans l'argument par défaut"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ne peut convertir %qH en %qI dans le passage d'argument"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ne peut convertir %qH en %qI dans l'initialisation"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 msgid "cannot convert %qH to %qI in return"
 msgstr "ne peut convertir %qH en %qI dans le retour"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ne peut convertir %qH en %qI dans l'affectation"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "le paramètre %qP de %qD pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "le paramètre pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "la cible de la conversion pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "la cible de l'initialisation pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'affectation pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "dans le passage de l'argument %P de %qD"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "retourne une référence vers un temporaire"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "retourner une %<initializer_list%> temporaire n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "référence vers la variable locale %qD retournée"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "retourner la variable %<initializer_list%> locale %qD n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adresse de l'étiquette %qD retournée"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adresse de la variable locale %qD retournée"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "déplacer un objet local dans une instruction de retour empêche l'élision de la copie"
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "supprime l'appel à %<std::move%>"
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "déplacement redondant dans l'instruction de retour"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "retourne une valeur depuis un destructeur"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "ne peut retourner depuis le gestionnaire d'un try..catch sur tout le constructeur"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "retourne une valeur depuis un constructeur"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "instruction « return » sans valeur dans une fonction retournant %qT"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "liste d'initialisation retournée"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "les types incohérents %qT et %qT sont déduits du type retourné par la lambda"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "déduction incohérente pour le type de retour auto: %qT et puis %qT"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "instruction « return » avec une valeur dans une fonction retournant %qT"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> ne doit pas retourner NULL à moins qu'il soit déclaré %<throw()%> (ou %<-fcheck-new%> est actif)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "utilisation d'une r-valeur comme l-valeur"
@@ -58369,107 +58434,102 @@ msgstr "enlever %<{ }%> autour d'un initialiseur"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "impossible d'initialiser l'agrégat du type %qT avec un littéral composé"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initialisation manquante pour le membre %qD"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "le membre %qD est une référence non initialisée"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "membre %qD avec des champs de référence non initialisés"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "l'ordre du désignateur pour le champ %qD ne correspond pas à l'ordre de la déclaration dans %qT"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "pas de champ %qD trouvé dans l'union initialisée"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valeur d'index au lieu d'un nom de champ dans l'initialisation de l'union"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "délégation de pointeur circulaire détectée"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "l'opérande de base de %<->%> a un type non pointeur %qT"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "le résultat de %<operator->()%> est un non pointeur"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "l'opérande de base de %<->%> n'est pas un pointeur"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE ne peut pas être utilisé comme pointeur de membre puisqu'il est de type %qT"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "ne peut appliquer le pointeur membre %qE à %qE lequel est d'un type non classe %qT"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "le pointeur vers le type membre %qT est incompatible avec le type d'objet %qT"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une r-valeur"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur avant C++20"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "transtypage fonctionnel vers le type tableau %qT"
 
-#: cp/typeck2.c:2213
-#, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "impossible de déduire les arguments du patron pour %qT depuis %<()%>"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "l'initialisation par valeur du type référence est invalide"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "appel à la fonction %qD qui génère une exception du type incomplet %q#T"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "appel à une fonction qui génère une exception du type incomplet %q#T"
@@ -58489,266 +58549,273 @@ msgstr "impossible d'ouvrir le fichier journal %<vtv_set_ptr_data.log%>: %m"
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr "impossible d'ouvrir le fichier journal %<vtv_count_data.log%>: %m"
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr "object.d manquant ou corrompu"
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr "%p n'a pas de routine sémantique"
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr "les symboles externes ne peuvent pas avoir d'initialisations"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "_gshared n'est pas permis dans des fonctions sûrs ; utilisez « shared »"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr "le type %s est inféré de l'initialiseur %s et les variables ne peuvent pas être du type void"
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr "les variables ne peuvent pas être du type void"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, gcc-internal-format
 msgid "cannot be declared to be a function"
 msgstr "ne peut pas être déclaré comme étant une fonction"
 
-#: d/dmd/dsymbolsem.c:416
-#, gcc-internal-format, gfc-internal-format
-msgid "no definition of struct %s"
+#: d/dmd/dsymbolsem.c:418
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "pas de définition de struct %s"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr "la classe de stockage « auto » n'a pas d'effet si le type ne sait pas être inféré, vouliez vous utiliser « scope » ?"
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr "ne peut pas être final, vouliez-vous peut-être utiliser const ?"
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be %s"
 msgstr "ne peut pas être %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
 msgstr "ne peut être « scope » et « %s »"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr "le champ ne peut pas être « scope »"
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr "le champ n'est pas permis dans une interface"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr "ne peut pas être un champ supplémentaire car il changera la taille %s déterminée"
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr "impossible d'utiliser un patron pour ajouter un champ à l'agrégat « %s »"
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr "seuls des paramètres ou des déclarations foreach peuvent être « ref »"
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr "seuls des paramètres ou des variables sur la piles peuvent être « inout »"
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr "les variables « inout » peuvent uniquement être déclarées dans des fonctions « inout »"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr "la construction par défaut est désactivée pour le type %s"
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr "les globaux, statiques, champs, les constantes manifestes et les paramètres ref et out ne peuvent pas être « scope »"
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr "la référence à une classe « scope » doit être « scope »"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "les initialiseurs « void » pour des pointeurs ne sont pas permis dans des fonctions sûrs"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr "les constantes manifestes doivent avoir des initialiseurs"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr "la taille du type %s est invalide"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr "%s n'a pas d'initialiseur par défaut"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr "n'est pas statique et ne peut pas avoir un initialiseur statique"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr "de type struct %s utilise this(this) qui n'est pas permis dans une initialisation statique"
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr "les variables de stockage statique ne peuvent avoir de destructeurs"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, gcc-internal-format
 msgid "string expected for library name"
 msgstr "chaîne attendue pour le nom de la bibliothèque"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr "nom de fonction attendu pour l'adresse de départ"
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr "nom de fonction attendu pour l'adresse de départ, pas « %s »"
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr "chaîne attendue pour le nom décoré"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr "chaîne de longueur nulle pas permise pour le nom décoré"
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr "les caractères du nom décoré peuvent uniquement être du type char"
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr "le caractère 0x%02x n'est pas permis dans le nom décoré"
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr "le caractères 0x%04x n'est pas permis dans le nom décoré"
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "pas d'argument"
+
+#: d/dmd/dsymbolsem.c:1526
 #, gcc-internal-format
 msgid "can only apply to a single declaration"
 msgstr "peut uniquement être appliqué à une déclaration unique"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr "il manque le « ; » de fin du pragma"
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
 msgstr "déclaration mixin incomplète (%s)"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr "le type de base ne peut pas être void"
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr "l'enum %s doit avoir au moins un membre"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, gcc-internal-format
 msgid "circular reference to enum member"
 msgstr "référence circulaire vers le membre de l'enum"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr "l'initialisation avec (%s.%s + 1) provoque un débordement pour le type « %s »"
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr "a une valeur inexacte à cause de la perte de précision"
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr "le paramètre tuple du patron doit être le dernier"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, gcc-internal-format
 msgid "recursive mixin instantiation"
 msgstr "instanciation d'un mixin récursif"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, gcc-internal-format
 msgid "recursive expansion"
 msgstr "expansion récursive"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, gcc-internal-format
 msgid "error instantiating"
 msgstr "erreur d'instanciation"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr "%s doit être une fonction au lieu de %s"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "without `this` cannot be %s"
 msgstr "ne peut être %s sans « this »"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr "la classe de stockage « auto » n'a pas d'effet si le type de retour n'est pas inféré"
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, gcc-internal-format
 msgid "functions cannot be scope"
 msgstr "les fonctions ne peuvent pas être « scope »"
@@ -58756,42 +58823,52 @@ msgstr "les fonctions ne peuvent pas être « scope »"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr "le membre statique n'a pas de « this » auquel « return » peut être appliqué"
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr "les fonctions %s ne peuvent pas être abstraites"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr "la méthode %s n'est pas virtuelle, elle ne peut pas redéfinir"
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr "ne peut redéfinir une fonction non virtuelle"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, gcc-internal-format
 msgid "cannot be both final and abstract"
 msgstr "ne peut être, à la fois, final et abstract"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr "les constructeurs, destructeurs, postblits, invariants ainsi que les fonctions new et delete ne sont pas permis dans l'interface %s"
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr "le corps de la fonction est uniquement permis dans les fonctions finales dans l'interface %s"
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr "les destructeurs, postblits et invariants ne sont pas permis dans l'union %s"
@@ -58799,172 +58876,172 @@ msgstr "les destructeurs, postblits et invariants ne sont pas permis dans l'unio
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr "l'inférence du type de retour n'est pas supportée si la fonction de la classe de base peut être redéfinie"
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr "la fonction finale %s ne peut pas être redéfinie"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr "plusieurs redéfinitions de la même fonction"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr "types covariants %s et %s incompatibles"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr "ne redéfini aucune fonction, vouliez-vous redéfinir « %s%s » ?"
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, gcc-internal-format
 msgid "does not override any function"
 msgstr "ne redéfini aucune fonction"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "ne peut redéfinir la fonction finale %s.%s"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "la redéfinition s'applique uniquement aux fonctions membres de la classe"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr "les contrats in et out peuvent uniquement apparaître sans un corps quand ils sont des fonctions d'interface virtuelle ou abstraites"
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "impossible d'utiliser un patron pour ajouter une fonction virtuelle à la classe « %s »"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr "le constructeur par défaut pour les structures est uniquement autorisé avec @disable, aucun corps et aucun paramètre"
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr "au moins un argument de type size_t attendu"
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr "le premier argument doit être du type size_t, pas %s"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr "un argument de type void* attendu"
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr "un argument de type void* attendu, pas %s"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, gcc-internal-format
 msgid "structs, unions cannot be abstract"
 msgstr "les structures et les unions ne peuvent pas être abstraites"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr "existe déjà à %s. Peut-être dans une autre fonction avec le même nom ?"
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr "la classe de stockage « auto » est invalide en déclarant une classe, vouliez-vous utiliser « scope » ?"
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr "le type de base doit être une classe ou une interface, pas %s"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, gcc-internal-format
 msgid "circular inheritance"
 msgstr "héritage circulaire"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr "le type de base doit être une interface, pas %s"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, gcc-internal-format, gfc-internal-format
 msgid "inherits from duplicate interface %s"
 msgstr "héritages depuis l'interface %s dupliquée"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot inherit from final class %s"
 msgstr "impossible d'hériter depuis la classe finale %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "la classe de base C++ %s a besoin d'au moins une fonction virtuelle"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr "une classe statique ne peut pas hériter de la classe imbriquée %s"
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr "est imbriquée dans %s, mais la super classe %s est imbriquée dans %s"
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr "n'est pas imbriquée, mais la super classe %s est imbriquée dans %s"
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr "impossible de générer implicitement un constructeur par défaut quand la classe de base %s n'a pas de constructeur par défaut"
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr "Les membres de champ d'une classe synchronisée ne peuvent pas être %s"
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr "héritage circulaire de l'interface"
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr "les patrons mixin ne sont pas des patrons normaux"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "l'instanciation du patron %s fait une référence anticipée à la déclaration de patron %s"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, gcc-internal-format
 msgid "cannot resolve"
 msgstr "impossible de résoudre"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr "impossible de créer un alias de l'expression %s"
@@ -58979,22 +59056,22 @@ msgstr "« %.*s »"
 msgid "(%s) is false"
 msgstr "(%s) est faux"
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ": Impossible d'initialiser l'énumération avec une classe ou un pointeur vers une structure. Utilisez plutôt une variable constante statique."
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr "est mutable. Seules des variables constantes ou non mutables locales au thread de la class sont permises, pas %s"
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr "est un pointeur vers une structure mutable. Seuls des pointeurs vers des variables constantes, non mutables ou des structures partagées locales au thread sont permises, pas %s"
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, gcc-internal-format
 msgid "has forward references"
 msgstr "a des références anticipées"
@@ -59054,22 +59131,24 @@ msgstr "pas de correspondance pour l'appel super() implicite dans le constructeu
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr "impossible d'appeler super() implicitement car il est annoté avec @disable"
 
-#: d/dmd/semantic3.c:860
-#, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+#: d/dmd/semantic3.c:862
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr "n'a pas d'instruction de retour mais une valeur de retour de type %s est attendue"
 
-#: d/dmd/semantic3.c:862
-#, gcc-internal-format
-msgid "no return exp; or assert(0); at end of function"
+#: d/dmd/semantic3.c:864
+#, fuzzy, gcc-internal-format
+#| msgid "no return exp; or assert(0); at end of function"
+msgid "no `return exp;` or `assert(0);` at end of function"
 msgstr "pas d'expression de retour ou de assert(0) à la fin de la fonction"
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr "la fonction synchronisée %s doit être un membre ou une classe"
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr "les fonctions assembleur nues avec contrats ne sont pas supportées"
@@ -59605,7 +59684,7 @@ msgstr "La constante littérale BOZ à %L ne peut pas être un argument effectif
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Les arguments de %qs à %L et %L ne peuvent pas être tous les deux des constantes littérales BOZ"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Utilisation invalide de la constant littérale BOZ à %L"
@@ -60698,12 +60777,12 @@ msgstr "Chaîne d'initialisation inutilisée à %L car la variable a une longueu
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "La chaine d'initialisation à %L a été tronquée pour tenir dans la variable (%ld/%ld)"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "L'index de départ de la sous-chaîne à %L est plus petit que un"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "L'index de fin de la sous-chaîne à %L excède la longueur de la chaîne"
@@ -60883,7 +60962,7 @@ msgstr "Mauvaise spécification INTENT à %C"
 msgid "deferred type parameter at %C"
 msgstr "paramètre de type différé à %C"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Expression INTEGER scalaire attendue à %L"
@@ -63366,7 +63445,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Identifiant illégal dans copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63447,7 +63526,7 @@ msgstr "La variable %qs à %L a une valeur non définie à l'intérieur de la bo
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "La variable %qs à %L n'est pas définissable à l'intérieur de la boucle commençant à %L comme argument INTENT(INOUT) de la fonction %qs"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Le code pour réallouer le tableau allouable à %L sera ajouté"
@@ -63582,12 +63661,12 @@ msgstr "Le premier argument de l'affectation définie à %L doit être INTENT(OU
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'affection définie à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le premier argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
@@ -63697,542 +63776,542 @@ msgstr "Rang non concordant entre l'argument effectif à %L et l'argument effect
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Rang non concordant entre l'argument effectif à %L et l'argument effectif à %L (rang %d et rang %d)"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Argument de procédure invalide à %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Interface non concordante dans la procédure muette %qs à %L: %s"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "L'argument effectif au pointeur contigus du muet %qs à %L doit être simplement contigu"
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Désaccord de type entre l'argument effectif à %L et l'argument effectif à %L (%s/%s)."
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Type non concordant dans l'argument %qs à %L; passé %s à %s"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "L'argument effectif du type tacite à %L requiert que l'argument muet %qs soit d'un type tacite"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "L'argument effectif de %qs à %L doit être polymorphique"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "L'argument effectif de %qs à %L doit avoir le même type déclaré"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "L'argument effectif de %qs à %L doit être polymorphique illimité puisque l'argument de format est un pointeur ou une entité polymorphique illimité allouable [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "L'argument effectif de %qs à %L doit être un co-tableau"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Co-rang non concordant dans l'argument %qs à %L (%d et %d)"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "L'argument effectif de %qs à %L doit être simplement contigu ou un élément vers un tel tableau"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Argument effectif vers le muet %qs non INTENT(INOUT) à %L qui est LOCK_TYPE ou a un composant LOCK_TYPE"
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Argument effectif vers le muet %qs non INTENT(INOUT) à %L qui est EVENT_TYPE ou a un composant EVENT_TYPE"
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "L'argument muet %qs doit être un pointeur, un tableau de forme tacite ou de rang tacite sans attribut CONTIGUOUS – car l'argument effectif à %L n'est pas simplement contigu et les deux sont ASYNCHRONOUS ou VOLATILE"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Passage d'un co-tableau à %L pour l'argument %qs allouable, non co-tableau, muet INTENT(OUT)"
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Passage d'un co-tableau à %L pour l'argument %qs allouable, non co-tableau et muet qui est invalide si le statut d'allocation est modifié"
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Scalaire polymorphique passé à l'argument tableau muet %qs à %L"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Un élément d'un tableau de forme tacite ou pointeur comme argument effectif à %L ne peut pas correspondre à l'argument effectif à %L"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Un élément d'un tableau de forme tacite ou pointeur est passé à l'argument tableau muet %qs à %L"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Extension: Argument effectif scalaire du sous-type pas par défaut, du sous-type non C_CHAR avec un argument muet tableau %qs à %L"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Argument effectif scalaire CHARACTER avec un argument muet tableau %qs à %L"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "L'argument mot-clé %qs à %L est invalide dans une fonction instruction"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "L'argument mot-clé %qs à %L n'est pas dans une procédure, vouliez-vous employer %qs ?"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "L'argument mot-clé %qs à %L n'est pas dans une procédure"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "L'argument mot-clé %qs à %L est déjà associé à un autre argument effectif"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Plus d'arguments effectifs que d'arguments formels dans l'appel de la procédure à %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Spécificateur de retour alternatif manquant dans l'appel de la sous-routine à %L"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Spécificateur de retour alternatif inattendu dans l'appel de la sous-routine à %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "NULL() intrinsèque inattendu à %L pour le muet %qs"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Pointeur null à %L pour un muet non pointeur %qs"
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "L'argument effectif à %L pour le muet de type tacite est d'un type dérivé avec une connexion de type ou des procédures FINAL"
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Désaccord dans la longueur de CHARACTER (%ld/%ld) entre l'argument effectif et l'argument muet pointeur ou allouable %qs à %L"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Désaccord dans la longueur de CHARACTER (%ld/%ld) entre l'argument effectif et l'argument muet de forme tacite %qs à %L"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "L'argument effectif à %L pour l'argument muet allouable ou pointeur %qs doit avoir un paramètre de type différé si et uniquement si le muet en a un"
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "La longueur de CHARACTER de l'argument effectif est plus court que celui de l'argument muet %qs (%lu/%lu) à %L"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "L'argument effectif contient trop peu d'éléments pour l'argument muet %qs (%lu/%lu) à %L"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Pointeur de procédure attendu pour l'argument %qs à %L"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Procédure attendue pour l'argument %qs à %L"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "L'argument effectif pour %qs ne peut pas être un tableau de taille tacite à %L"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "L'argument effectif pour %qs doit être un pointeur à %L"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Argument effectif non pointeur à %L vers le muet pointeur %qs"
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Argument effectif co-indexé à %L vers le muet pointeur %qs"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "L'argument effectif co-indexé à %L vers le muet allouable %qs requiert INTENT(IN)"
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "L'argument effectif co-indexé ASYNCHRONOUS ou VOLATILE à %L requiert que le muet %qs n'ait ni ASYNCHRONOUS ni VOLATILE"
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "L'argument effectif co-indexé à %L avec un composant ultimement allouable pour le muet %qs requiert soit VALUE ou INTENT(IN)"
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "L'argument effectif qui est un tableau de CLASS pour %qs doit être un tableau complet à %L"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "L'argument effectif pour %qs doit être ALLOCATABLE à %L"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "L'argument effectif qui est une section de tableau avec des indices de vecteur à %L est incompatible avec l'attribut INTENT(OUT), INTENT(INOUT), VOLATILE ou ASYNCHRONOUS de l'argument muet %qs"
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "L'argument effectif de forme tacite à %L est incompatible avec l'argument muet de forme non tacite %qs à cause de l'attribut VOLATILE"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "L'argument effectif qui est une section de tableau à %L est incompatible avec l'argument muet de forme non tacite %qs à cause de l'attribut VOLATILE"
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "L'argument effectif qui est un tableau de pointeurs à %L requiert un argument muet de forme tacite ou un tableau de pointeurs %qs à cause de l'attribut VOLATILE"
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Spécification de retour alternatif manquant dans l'appel de la sous-routine à %L"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Argument effectif manquant pour l'argument %qs à %L"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Mauvais code de composant"
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Liste non concordante"
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): donnée corrompue"
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Le même argument effectif est associé avec l'argument INTENT(%s) %qs et l'argument INTENT(%s) %qs à %L"
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Liste non concordante"
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "L'argument de procédure à %L est local dans une procédure PURE et a l'attribut POINTER"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "L'argument effectif co-indexé à %L dans une procédure PURE est passé à un argument INTENT(%s)"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "L'argument effectif co-indexé à %L dans une procédure PURE est passé à un argument muet de type POINTER"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "L'argument effectif polymorphique co-indexé à %L est passé à l'argument muet polymorphique %qs"
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "La procédure %qs appelée à %L n'est pas explicitement déclarée, vouliez-vous employer %qs ?"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "La procédure %qs appelée à %L n'est pas explicitement déclarée"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Procédure %qs appelée avec une interface implicite à %L"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "L'objet pointeur %qs à %L doit avoir une interface de fonction explicite ou être déclaré comme un tableau"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "L'objet allouable %qs à %L doit avoir une interface de fonction explicite ou être déclaré comme un tableau"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "La fonction allouable %qs à %L doit avoir une interface de fonction explicite"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Interface explicite requise pour l'argument polymorphique à %L"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "L'argument mot-clé requiert une interface explicite pour la procédure %qs à %L"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "L'argument de type tacite %s à %L requiert une interface explicite"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "L'argument effectif de LOCK_TYPE ou avec un composant LOCK_TYPE à %L requiert une interface explicite pour la procédure %qs"
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "L'argument effectif de EVENT_TYPE ou avec un composant EVENT_TYPE à %L requiert une interface explicite pour la procédure %qs"
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "Argument MOLD requis pour NULL à %L"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Un argument de rang tacite requiert une interface explicite à %L"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Composant pointeur de procédure %qs appelé avec une interface implicite à %L"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "L'argument mot-clé requiert une interface explicite pour le composant pointeur de procédure %qs à %L"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= est requis dans l'argument NULL() à %L: Ambigüité entre les fonctions spécifiées %s et %s"
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Impossible de trouver le symbole %qs"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "L'entité %qs à %L est déjà présente dans l'interface"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Mauvais type d'interface"
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Ne peut écraser GENERIC %qs à %L"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs à %L redéfini une liaison de procédure déclarée NON_OVERRRIDABLE"
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs à %L ne doit pas être DEFERRED car il redéfini une liaison non DEFERRED"
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs à %L redéfini une procédure PURE et doit aussi être PURE"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs à %L redéfini une procédure ELEMENTAL et doit aussi être ELEMENTAL"
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs à %L redéfini une procédure non ELEMENTAL et ne doit pas être ELEMENTAL non plus"
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs à %L redéfini une SUBROUTINE et doit aussi être une SUBROUTINE"
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs à %L redéfini une FUNCTION et doit aussi être une FUNCTION"
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Résultat non concordant pour la redéfinition de la procédure %qs à %L: %s"
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs à %L redéfini une procédure PUBLIC et ne doit pas être PRIVATE"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "L'argument muet %qs de %qs à %L devrait être nommé %qs pour correspondre à l'argument équivalent de la procédure redéfinie"
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Argument non concordant pour la procédure redéfinissante %qs à %L: %s"
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs à %L doit avoir le même nombre d'arguments formels que la procédure redéfinie"
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs à %L redéfini une liaison NOPASS et doit aussi être NOPASS"
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs à %L redéfini une liaison PASS et doit aussi être PASS"
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "L'argument muet %qs de type objet passé à %L doit être à la même position que l'argument muet de type objet passé à la procédure redéfinie"
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "L'argument muet DTIO à %L doit être du type %s"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "L'argument muet DTIO à %L doit avoir KIND = %d"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "L'argument muet DTIO à %L doit être un scalaire"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "L'argument muet DTIO à %L doit être ASSUMED SHAPE ARRAY"
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "L'argument caractère DTIO à %L doit avoir une longueur tacite"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "L'argument muet DTIO à %L doit avoir INTENT %s"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Le retour alternatif à %L n'est pas permis dans une procédure DTIO"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "La procédure DTIO %qs à %L doit être une sous-routine"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Trop peu d'arguments muets dans la procédure DTIO %qs à %L"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Trop d'arguments muets dans la procédure DTIO %qs à %L"
@@ -64377,33 +64456,33 @@ msgstr "La fonction transformationnelle %qs à %L est invalide dans une expressi
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fonction élémentaire comme expression d'initialisation avec des arguments non entiers/non caractères à %L"
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "L'appel de sous-routine à l'intrinsèque %qs dans un bloc DO CONCURRENT à %L n'est pas PURE"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "L'appel de sous-routine à l'intrinsèque %qs à %L n'est pas PURE"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Extension: Conversion de %s vers %s à %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Conversion non standard de %s vers %s à %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Changement possible de valeur dans la conversion de %s vers %s à %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Conversion de %s vers %s à %L"
@@ -64411,22 +64490,22 @@ msgstr "Conversion de %s vers %s à %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Impossible de convertir %s en %s à %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Impossible de convertir %qs en %qs à %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "%qs, déclaré à %L, pourrait masquer l'intrinsèque du même nom. Pour appeler l'intrinsèque, des déclarations INTRINSIC explicites peuvent être nécessaires."
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "%qs, déclaré à %L, est aussi le nom d'un intrinsèque. Il peut uniquement être appelé via une interface explicite ou s'il est déclaré EXTERNAL."
@@ -64962,7 +65041,7 @@ msgstr "NAMELIST %qs dans l'instruction READ à %L contient le symbole %qs qui n
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "L'objet NAMELIST %qs dans la liste de noms %qs à %L est polymorphique et requiert une procédure d'entrée/sortie définie"
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Objet NAMELIST %qs dans la liste de noms %qs à %L avec des composants ALLOCATABLE ou POINTER"
@@ -66135,12 +66214,12 @@ msgstr "match_level_4(): Mauvais opérateur"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr "gfc_basic_typename(): Type non défini"
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "gfc_typename(): Type non défini"
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "gfc_code2string(): Mauvais code"
@@ -66295,149 +66374,149 @@ msgstr "L'opérateur intrinsèque %qs référencé à %L n'est pas trouvé dans
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): mauvais symbole de module %qs"
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbole pas écrit"
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, gcc-internal-format
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "Ne peut ouvrir le fichier module %qs en écriture à %C: %s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Erreur en écrivant dans le fichier module %qs: %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "Impossible d%'effacer le fichier module %qs: %s"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Impossible de renommer le fichier module %qs en %qs: %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "Impossible de supprimer le fichier temporaire du module %qs: %s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Symbole %qs à %C déjà déclaré"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Impossible de créer le symbole pour %s"
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Le symbole %qs, référencé à %L, n'est pas dans le standard sélectionné"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Le symbole %qs référencé à %L n'est pas trouvé dans le module intrinsèque ISO_C_BINDING"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbole %qs déjà déclaré"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "L'utilisation du module intrinsèque %qs à %C est en conflit avec le nom de module non intrinsèque utilisé précédemment"
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "L'utilisation de la constante nommée NUMERIC_STORAGE_SIZE du module intrinsèque ISO_FORTRAN_ENV à %L est incompatible avec l'option %qs"
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "L'utilisation de la constante nommée NUMERIC_STORAGE_SIZE du module intrinsèque ISO_FORTRAN_ENV à %C est incompatible avec l'option %s"
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Le symbole %qs référencé à %L n'a pas été trouvé dans le modèle intrinsèque ISO_FORTRAN_ENV"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "L'instruction USE à %C n'a pas de qualificatif ONLY"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Module intrinsèque ISO_FORTRAN_ENV à %C"
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Module ISO_C_BINDING à %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "Ne peut trouver un module intrinsèque nommé %qs à %C"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "Module IEEE_FEATURES à %C"
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "Module IEEE_EXCEPTIONS à %C"
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "Module IEEE_ARITHMETIC à %C"
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, gcc-internal-format
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Ne peut ouvrir le fichier module %qs en lecture à %C: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Le fichier module %qs n'a pas été généré, soit parce que le module ne contient pas de MODULE PROCEDURE ou il y a une erreur dans le module."
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "L'utilisation du module non intrinsèque %qs à %C est en conflit avec le nom de module intrinsèque utilisé précédemment"
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Le fichier %qs ouvert à %C n'est pas un fichier module GNU Fortran"
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Impossible de lire le fichier module %qs ouvert à %C car il a été créé par une version différente de GNU Fortran"
 
 # %s est « sub » ou rien.
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr "Impossible d'utiliser avec USE un sous-module qui est en cours de construction"
 
 # %s est « sub » ou rien.
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr "Impossible d'utiliser avec USE un module qui est en cours de construction"
@@ -66973,8 +67052,8 @@ msgstr "La sous-routine %s déclarée implicitement est utilisé dans !$OMP DECL
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "Le paramètre de la clause ORDERED est plus petit que COLLAPSE à %L"
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause IF à %L requiert une expression LOGICAL scalaire"
@@ -69007,7 +69086,7 @@ msgstr "L'intrinsèque %qs déclaré INTRINSIC à %L n'est pas disponible avec l
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "La procédure non RECURSIVE %qs à %L semble s'appeler elle-même récursivement. Déclarez là RECURSIVE ou utilisez %<-frecursive%>"
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "L'étiquette %d référencée à %L n'est jamais définie"
@@ -69122,7 +69201,7 @@ msgstr "Impossible de résoudre la fonction spécifique %qs à %L"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT, vouliez-vous employer %qs ?"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT"
@@ -69280,212 +69359,212 @@ msgstr "La fonction impure %qs à %L pourrait ne pas être évaluée"
 msgid "Impure function at %L might not be evaluated"
 msgstr "La fonction impure à %L pourrait ne pas être évaluée"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "La constante littérale BOZ à %L ne peut pas être un opérande de l'opérateur unaire %qs"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr "Les opérandes à %L et %L ne peuvent pas apparaître comme opérandes de l'opérateur binaire %qs"
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "La constante littérale BOZ près de %L ne peut pas apparaître comme opérande d'un opérateur relationnel"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "Comparaison égalitaire pour %s à %L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "Comparaison inégalitaire pour %s à %L"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Mauvais intrinsèque"
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Mauvaise expression"
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la co-dimension %d"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la co-dimension %d"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Pas nul illégal à %L"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence inférieure au tableau à %L est hors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence inférieure au tableau à %L est en dehors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence supérieure au tableau à %L est hors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence supérieure au tableau à %L est hors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Mauvaise référence de tableau"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "La limite supérieure la plus à droite de la section du tableau de taille tacite n'est pas spécifiée à %L"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Désaccord de rang dans la référence au tableau à %L (%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Désaccord du rang du co-index dans la référence au tableau à %L (%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Le co-index de la co-dimension %d doit être un scalaire à %L"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "L'index de tableau à %L doit être scalaire"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "L'index de tableau à %L doit être du type INTEGER, on a trouvé %s"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "Index de tableau REAL à %L"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "L'argument dim à %L doit être scalaire"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "L'argument dim à %L doit être du type INTEGER"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Spec manquante"
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): « as » inutilisé(1)"
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): « as » inutilisé(2)"
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "L'index de tableau à %L est un tableau de rang %d"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "L'index de départ de la sous-chaîne à %L doit être du type INTEGER"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "L'index de départ de la sous-chaîne à %L doit être scalaire"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "L'index de fin de la sous-chaîne à %L doit être du type INTEGER"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "L'index de fin de la sous-chaîne à %L doit être scalaire"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "L'index de fin de la sous-chaîne à %L est trop grand"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Mauvaise référence de tableau"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Le composant à droite d'une référence de partie avec un rang non nul ne doit pas avoir l'attribut POINTER à %L"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Le composant à droite d'une référence de partie avec un rang non nul ne doit pas avoir l'attribut ALLOCATABLE à %L"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Deux références de parties (ou plus) avec un rang non nul ne peuvent pas être spécifiées à %L"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "gfc_expression_rank(): Deux specs de tableau"
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK peut uniquement être utilisée comme argument effectif"
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "La variable de type tacite %s à %L peut uniquement être utilisée comme argument effectif"
@@ -69494,12 +69573,12 @@ msgstr "La variable de type tacite %s à %L peut uniquement être utilisée comm
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "La variable de type tacite %s à %L comme argument effectif à une fonction de requête sera le premier argument"
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "La variable de rang tacite %s à %L peut uniquement être utilisée comme argument effectif"
@@ -69508,296 +69587,296 @@ msgstr "La variable de rang tacite %s à %L peut uniquement être utilisée comm
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "La variable de rang tacite %s à %L comme argument effectif à une fonction intrinsèque sera le premier argument"
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "La variable de type tacite %s à %L n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de rang tacite %s à %L n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs, utilisée dans une expression de spécification, est référencée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs est utilisée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Sous-objet polymorphique d'un objet co-indexé à %L"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objet co-indexé avec un sous-composant allouable polymorphique à %L"
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "L'utilisation de la variable %qs à %L est obsolète"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs à %L est associé à l'hôte à %L dans une procédure contenue avec une procédure interne du même nom"
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Erreur dans l'appel avec type lié à %L"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "L'objet passé à %L doit être scalaire"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de composant pointeur de procédure à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de procédure liée au type à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "L'objet de base pour l'appel de procédure liée au type NOPASS à %L doit être scalaire"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Aucune liaison spécifique correspondante pour l'appel à GENERIC %qs à %L"
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs à %L devrait être une SUBROUTINE"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs à %L devrait être une FUNCTION"
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Mauvais type d'expression"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s à %L doit être un scalaire"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s à %L doit être un entier"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s à %L doit être INTEGER"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "L'expression de pas dans la boucle DO à %L ne peut pas être zéro"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "La boucle DO à %L sera exécutée zéro fois"
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde"
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde vers le bas"
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Le nom d'index FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "L'expression de départ de FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "L'expression de fin de FORALL à %L doit être un INTEGER scalaire"
 
 # %s est toujours « INTEGER » et rien d'autre
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "L'expression de pas de FORALL à %L doit être un %s scalaire"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "L'expression de pas de FORALL à %L ne peut pas être zéro"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "L'index %qs de FORALL ne peut pas apparaître dans une spécification de triplet à %L"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "L'objet allouable à %L doit être ALLOCATABLE ou un POINTER"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objet allouable co-indexé à %L"
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "L'expression source à %L doit être scalaire ou avoir le même rang que l'objet allouable à %L"
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "L'expression source à %L et l'objet allouable à %L doivent avoir la même forme"
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Le type de l'entité à %L a un type incompatible avec l'expression source à %L"
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "L'objet allouable à %L et l'expression source à %L auront le même paramètre de sous-type"
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type LOCK_TYPE ni un composant LOCK_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type EVENT_TYPE ni un composant EVENT_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "L'allocation de %s du type de base ABSTRACT à %L requiert une spécification de type ou une expression source"
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "L'allocation de %s à %L avec la spécification de type requiert la même longueur de caractères dans le paramètre que dans la déclaration"
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spécification de tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Une spécification de tableau ou une expression SOURCE= avec une valeur tableau est requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spécification de co-tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "La co-borne supérieure est plus petite que la co-borne inférieure à %L"
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "La co-borne supérieure est plus petite que la co-borne inférieure 1 à %L"
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs ne doit pas apparaître dans la spécification de tableau à %L dans la même instruction ALLOCATE où il est lui-même alloué"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "« * » attendu dans la spécification du co-index dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de co-tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat à %L doit être une variable INTEGER scalaire"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG à %L est inutile sans la balise STAT"
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "La variable ERRMSG à %L sera une variable CHARACTER du scalaire par défaut"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "L'objet alloué à %L apparaît aussi à %L"
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
@@ -69806,284 +69885,284 @@ msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "L'étiquette CASE à %L chevauche l'étiquette CASE à %L"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "L'expression dans l'instruction CASE à %L doit être du type %s"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "L'expression dans l'instruction CASE à %L doit être du sous-type %d"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "L'expression dans l'instruction CASE à %L doit être scalaire"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "L'expression de sélection dans le GOTO calculé à %L doit être une expression entière scalaire"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "L'argument de l'instruction SELECT à %L ne peut pas être %s"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "L'argument de l'expression SELECT à %L doit être une expression scalaire"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "L'expression dans l'instruction CASE à %L n'est pas dans la plage de %s"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Le DEFAULT CASE à %L ne peut pas être suivi par un second DEFAULT CASE à %L"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Une plage logique n'est pas permise dans l'instruction CASE à %L"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "La valeur logique constante est répétée dans l'instruction CASE à %L"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La spécification d'étendue à %L ne peut jamais correspondre à quoi que ce soit"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Le bloc SELECT CASE logique à %L a plus de deux cas"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "L'entité associante %qs à %L est un pointeur de procédure"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Le type dérivé %qs ne peut pas être utilisé comme une variable à %L"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "L'entité associante %qs à %L est un nom de procédure"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "L'expression de sélecteur associant à %L donne une procédure"
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Le sélecteur à %L ne peut pas NULL()"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Le sélecteur à %L n'a pas de type"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Le nom associé %qs à %L est utilisé comme tableau"
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "Le sélecteur CLASS à %L a besoin d'un temporaire qui n'est pas encore implémenté"
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Le sélecteur sera polymorphique dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Le sélecteur à %L ne doit pas être co-indexé"
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS à %L chevauche TYPE IS à %L"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Le type dérivé %qs à %L doit être extensible"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Le type dérivé %qs à %L doit être une extension de %qs"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Type intrinsèque %qs inattendu à %L"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La spécification de type à %L doit spécifier que chaque paramètre de type de longueur est tacite"
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloc CLASS IS en double dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT à %L est répété à %L"
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) à %L est répété à %L"
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) à %L est répété à %L"
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) à %L ne peut pas être utilisé avec un pointeur ou un sélecteur allouable à %L"
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexte invalide pour l'intrinsèque NULL () à %L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "La procédure DTIO %s à %L doit être récursive"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas être polymorphique à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants POINTER à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants de pointeur de procédure"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants ALLOCATABLE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "L'élément de transfert de données à %L ne peut pas être une référence complète à un tableau de taille tacite"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable verrou à %L doit être un scalaire de type LOCK_TYPE"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable d'événement à %L doit être un scalaire de type EVENT_TYPE"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau ou co-indexé"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau mais pas co-indexé"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "L'argument STAT= à %L doit être une variable INTEGER scalaire"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "L'argument ERRMSG= à %L doit être une variable CHARACTER scalaire"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "L'argument ACQUIRED_LOCK= à %L doit être une variable LOGICAL scalaire"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "L'argument UNTIL_COUNT= à %L doit être une expression INTEGER scalaire"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "L'argument imageset à %L doit être une expression scalaire ou INTEGER de rang 1"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "L'argument imageset à %L doit être entre 1 et num_images()"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "L'instruction à %L n'est pas une instruction cible valable pour l'instruction de branchement à %L"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Le branchement à %L peut conduire à une boucle infinie"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction CRITICAL pour l'étiquette à %L"
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'étiquette à %L"
@@ -70091,192 +70170,192 @@ msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'é
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "L'étiquette à %L n'est pas dans le même bloc que l'instruction GOTO à %L"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Le masque WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "La cible de l'affectation WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Affectation définie par l'utilisateur non ELEMENTAL dans WHERE à %L"
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Instruction non supportée à l'intérieur de WHERE à %L"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Affectation à une variable d'index FORALL à %L"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Le FORALL avec l'index %qs n'est pas utilisé dans le membre de gauche de l'affectation à %L et, par conséquent, pourrait causer de multiples affectations à cet objet"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Construction FORALL à %L"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Le nom d'index de FORALL à %L doit être une variable scalaire de type entier"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Une construction de boucle FORALL extérieure a déjà un index avec ce nom à %L"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "La clause WHERE/ELSEWHERE à %L requiert un tableau LOGICAL"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Mauvais type de bloc"
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "L'expression CHARACTER sera tronquée dans l'affectation (%ld/%ld) à %L"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "L'expression co-indexée à %L est affectée à une variable de type dérivé avec un composant POINTER dans une procédure PURE"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "Dans un sous-programme pure, un argument fictif INTENT(IN) ne sera point utilisé comme l'expression à %L d'une instruction d'affectation intrinsèque dans laquelle la variable est d'un type dérivé si le type dérivé a un composant pointeur à n'importe quel niveau de la sélection du composant."
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Affectation à une variable co-indexée à %L dans une procédure PURE"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "L'affectation à un co-tableau polymorphique à %L n'est pas permise"
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Affectation à une variable polymorphique allouable à %L"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "L'affectation à une variable polymorphique allouable à %L requiert %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "La variable non allouable ne doit pas être polymorphique dans l'affectation intrinsèque à %L – vérifiez qu'il existe une sous-routine spécifique correspondante pour l'opérateur « = »"
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable co-indexée ne doit pas avoir un composant ultimement allouable dans l'affectation à %L"
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "À FAIRE: la/les affectation(s) liée(s) au type à %L n'ont pas été réalisées car des références multiples à des parties de tableaux apparaîtraient dans des expressions intermédiaires."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Affectation à une procédure pointeur à %L"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Le résultat de la fonction dans le membre de gauche de l'affectation à %L doit avoir l'attribut pointeur."
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "L'instruction ASSIGNED GOTO à %L requiert une variable INTEGER scalaire"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Une étiquette cible n'a pas été affectée à la variable %qs à %L"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "L'instruction RETURN alternatif à %L requiert un spécificateur de retour SCALAR-INTEGER"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "L'instruction ASSIGN à %L requiert une variable scalaire INTEGER par défaut"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL invalide à %L"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "L'instruction IF arithmétique à %L requiert une expression scalaire REAL ou INTEGER"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Pas d'expression dans le DO WHILE"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condition de sortie de la boucle DO WHILE à %L doit être une expression LOGICAL scalaire"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause de masque FORALL à %L requiert une expression scalaire LOGICAL"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mauvais code d'instruction"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "L'utilisation du paramètre %qs déclaré à %L est obsolète"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La variable %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L du module %qs"
@@ -70284,966 +70363,966 @@ msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L uti
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La procédure %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longueur de chaîne à %L est trop grande"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le tableau allouable %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "L'objet scalaire %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le pointeur tableau %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Le tableau %qs à %L ne peut pas avoir une forme différée"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Le type %qs de la variable CLASS %qs à %L n'est pas extensible"
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS %qs à %L doit être muette, allouable ou pointeur"
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Le type %qs ne peut pas être associé à un hôte à %L car il est bloqué par un objet incompatible du même nom déclaré à %L"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "SAVE implicite pour la variable module %qs à %L, nécessaire à cause de l'initialisation par défaut"
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "L'entité %qs à %L a un paramètre de type différé et requiert soit l'attribut POINTER ou ALLOCATABLE"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Le tableau %qs à %L du module ou du programme principal doit avoir une forme constante"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "L'entité avec une longueur de caractère tacite à %L doit être un argument muet ou un PARAMETER"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs à %L doit avoir une longueur de caractère constante dans ce contexte"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON %qs à %L doit avoir une longueur de caractère constante"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "L'allouable %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "L'externe %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Le muet %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "L'intrinsèque %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Le résultat de fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Le tableau automatique %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s à %L"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La fonction-instruction %qs avec une valeur de caractère à %L doit avoir une longueur constante"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs est d'un type PRIVATE et ne peut pas être un argument muet de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "La procédure %qs dans l'interface PUBLIC %qs à %L prend des arguments muets de %qs qui est PRIVATE"
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "L'objet externe %qs à %L ne peut pas avoir d'initialisation"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La fonction ELEMENTAL %qs à %L doit avoir un résultat scalaire"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La fonction-instruction %qs à %L ne peut pas avoir l'attribut pointeur ou allouable"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un tableau"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un pointeur"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être pure"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être récursive"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fonction CHARACTER(*) %qs à %L"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Le pointeur de procédure %qs à %L ne sera point élémental"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "La procédure muette %qs à %L ne sera point élémentale"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable résultat %qs de la fonction à %L de la fonction élémentale %qs n'aura point l'attribut ALLOCATABLE ou POINTER"
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut SAVE dans %qs à %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut INTENT dans %qs à %L"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut RESULT dans %qs à %L"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "L'attribut EXTERNAL est en conflit avec l'attribut FUNCTION dans %qs à %L"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Le résultat du pointeur de procédure %qs à %L n'a pas d'attribut pointeur"
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut ELEMENTAL entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut PURE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut RECURSIVE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s entre la déclaration MODULE PROCEDURE dans MODULE %qs et la déclaration à %L dans (SUB)MODULE %qs"
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "La procédure FINAL %qs à %L n'est pas une SUBROUTINE"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "La procédure FINAL à %L doit avoir exactement un argument"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "L'argument de la procédure FINAL à %L doit être du type %qs"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être un POINTER"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être OPTIONAL"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être INTENT(OUT)"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "La procédure FINAL non scalaire à %L devrait avoir un argument de forme tacite"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "La procédure FINAL %qs déclarée à %L a le même rang (%d) que %qs"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Seules des procédures FINAL tableaux déclarées pour le type dérivé %qs à %L, une scalaire est également suggérée"
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs et %qs ne peuvent pas être FUNCTION/SUBROUTINE mixte pour GENERIC %qs à %L"
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs et %qs pour GENERIC %qs à %L sont ambigus"
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Liaison spécifique %qs non définie comme cible du GENERIC %qs à %L"
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs à %L doit cibler une liaison spécifique, %qs est GENERIC aussi"
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs à %L ne peut écraser la liaison spécifique avec le même nom"
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "L'opérateur lié au type à %L ne peut pas être NOPASS"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs doit être une procédure de module ou une procédure externe avec une interface explicite à %L"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "La procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "La procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argument muet passé comme objet non polymorphique de %qs à %L"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "L'argument muet de type objet passé de %qs à %L doit être scalaire"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être POINTER"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant de %qs"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant hérité de %qs"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Le type dérivé %qs déclaré à %L doit être ABSTRACT car %qs est DEFERRED et pas redéfini"
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Le composant co-tableau %qs à %L doit être allouable avec une forme différée"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Le composant %qs à %L ayant TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Le composant %qs à %L avec le composant co-tableau sera un scalaire non pointeur, non allouable"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Le composant %qs à %L a l'attribut CONTIGUOUS mais n'est pas un pointeur de tableau"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Le composant %qs du type BIND(C) à %L doit avoir la longueur un"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Le composant pointeur de procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Le composant pointeur de procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être scalaire"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas avoir l'attribut POINTER"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Le composant %qs de %qs à %L a le même nom qu'une procédure liée au type héritée"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longueur de caractère du composant %qs doit être une expression de spécification constante à %L"
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Le composant caractère %qs de %qs à %L avec une longueur différée doit être POINTER ou ALLOCATABLE"
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "le composant %qs est un type PRIVATE et ne peut pas être un composant de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Le composant polymorphique %s à %L dans le type %s SEQUENCE ou BIND(C)"
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Le composant %s du type SEQUENCE déclaré à %L n'a pas l'attribut SEQUENCE"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initialisations conflictuelles dans l'union à %L et %L"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Puisque l'extension du type %qs à %L a un composant co-tableau, le type parent %qs en aura un aussi"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Le type dérivé non extensible %qs à %L ne peut pas être ABSTRACT"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Le type paramétrisé %qs n'a pas de composant correspondant au paramètre %qs à %L"
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Nom générique %qs de la fonction %qs à %L étant le même nom que le type dérivé à %L"
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Le type dérivé %qs à %L n'a pas été déclaré"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Le tableau de taille tacite %qs dans la liste de noms %qs à %L n'est pas permis"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme tacite dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Objet NAMELIST %qs avec une longueur de caractère non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a été déclaré PRIVATE et ne peut pas être membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE associés à USE et ne peut pas être membre de la liste de noms %qs à %L"
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE et ne peut pas être un membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut NAMELIST dans %qs à %L"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Le tableau paramètre %qs à %L ne peut pas être automatique ou de forme différée"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Le PARAMETER %qs implicitement typé à %L ne concorde pas avec le type IMPLICIT ultérieur"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Type dérivé incompatible dans PARAMETER à %L"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "La variable CLASS %qs à %L ne peut pas avoir l'attribut PARAMETER"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "L'objet %qs à %L a un paramètre LEN différé %qs et n'est ni allouable ni un pointeur"
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "L'objet AUTOMATIC %qs à %L ne doit pas avoir l'attribut SAVE ou être une variable déclarée dans le programme principal, un module ou un sous-module(F08/C513)"
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "L'objet %qs à %L avec des paramètres de type ASSUMED doit être fictif ou un sélecteur SELECT TYPE(F08/4.2)"
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Désolé, les composants allouables/pointeurs dans des co-tableaux de types polymorphiques (CLASS) à %L ne sont pas supportés"
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "L'attribut PROTECTED est en conflit avec l'attribut EXTERNAL à %L"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut PROTECTED à %L"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs à %L a l'attribut CONTIGUOUS mais il n'est pas un pointeur de tableau ou un tableau de forme tacite ou de rang tacite"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Mauvaise spécification pour le tableau de taille tacite à %L"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Le tableau de taille tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Le tableau de forme tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Le tableau de rang tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Le tableau de rang tacite à %L ne peut pas avoir les attributs VALUE ou CODIMENSION"
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Le symbole à %L n'est pas une variable MUETTE"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs à %L ne peut pas avoir l'attribut VALUE car ce n'est pas un argument muet"
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable muette caractère %qs à %L avec l'attribut VALUE doit avoir une longueur constante"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable muette caractère %qs, interopérable avec le C, à %L avec l'attribut VALUE doit avoir la longueur un"
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Le type dérivé %qs à %L est du type %qs qui n'a pas été défini"
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera un argument muet"
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera du type TYPE(*) ou d'un type intrinsèque numérique"
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera soit un scalaire ou un tableau de taille tacite"
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Le type tacite de la variable %s à %L est uniquement permis pour des variables muettes"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de type tacite %s à %L ne sera point un tableau de forme explicite"
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable %qs à %L ne peut pas être BIND(C) car elle n'est ni un bloc COMMON ni déclarée au niveau du module"
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable BIND(C) %qs à %L doit avoir la longueur un"
 
 # %s est soit « parameter » ou « variable » sans traduction
 # voir bug #80195
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs à %L du type dérivé PRIVATE %qs"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s à %L du type LOCK_TYPE ou avec un sous-composant de type LOCK_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s à %L du type EVENT_TYPE ou avec un sous-composant du type EVENT_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "L'argument muet INTENT(OUT) %qs à %L est ASSUMED SIZE et, par conséquent, ne peut pas avoir une initialisation par défaut"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est LOCK_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est EVENT_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Le résultat %qs de la fonction à %L ne sera point un co-tableau et n'aura point un composant co-tableau"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable %qs à %L du TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable %qs à %L avec un composant co-tableau doit être un scalaire non pointeur, non allouable qui n'est pas un co-tableau"
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable %qs à %L est un co-tableau qui n'est pas ALLOCATABLE, SAVE ni un argument muet"
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable co-tableau %qs à %L n'aura pas de co-dimensions avec une forme différée"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable co-tableau allouable %qs à %L doit avoir une forme différée"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable %qs à %L est INTENT(OUT) et ne peut donc pas être un co-tableau allouable ou avoir des composants co-tableaux"
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "La variable muette co-tableau %qs à %L n'est pas permise dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Argument muet LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Variable résultat LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "La liste de noms %qs ne peut pas être un argument de la sous-routine ou de la fonction à %L"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Le threadprivate à %L n'est pas sauvegardé avec SAVE"
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "La variable !$OMP DECLARE TARGET %qs à %L n'est pas sauvegardée avec SAVE"
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Entité définissable attendue près de %L"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "L'élément BLOCK DATA %qs à %L doit être dans COMMON"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Le tableau DATA %qs à %L doit être spécifié dans une déclaration précédente"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir un co-index"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "L'élément DATA %qs à %L est un pointeur et doit donc être un tableau à part entière"
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "L'objet DATA près de %L a l'attribut pointeur et la valeur DATA correspondante n'est pas une cible de donnée initiale valable"
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir l'attribut ALLOCATABLE"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Section de tableau non constante à %L dans l'instruction DATA"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "L'instruction DATA à %L a plus de variables que de valeurs"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le début de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "La fin de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le pas de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "le pas de la boucle DO implicite à %L ne sera point zéro"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "L'instruction DATA à %L a plus de valeurs que de variables"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "L'étiquette %d à %L est définie mais non utilisée"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "L'étiquette %d à %L est définie mais ne peut pas être utilisée"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L doit avoir l'attribut SEQUENCE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L ne peut pas avoir des composants ALLOCATABLE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de type dérivé %qs à %L avec une initialisation par défaut ne peut pas être dans une EQUIVALENCE avec une variable dans COMMON"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L avec un ou des composants pointeurs ne peut pas être dans un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Erreur de syntaxe dans l'instruction EQUIVALENCE à %L"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Soit aucun ou tous les objets dans l'ensemble EQUIVALENCE à %L aura l'attribut PROTECTED"
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Le membre %qs du bloc COMMON à %L ne peut pas être un objet EQUIVALENCE dans la procédure pure %qs"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nommée %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Le tableau %qs à %L avec des limites non constantes ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Le composant de structure %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La sous-chaîne à %L a une longueur zéro"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Référence à elle-même dans l'expression de longueur de caractère pour %qs à %L"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fonction PUBLIC %qs à %L du type PRIVATE %qs"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs à %L n'a pas de type IMPLICIT"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "La procédure opérateur utilisateur %qs à %L doit être une FUNCTION"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "La procédure opérateur utilisateur %qs à %L ne peut pas être une longueur de caractère tacite"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "La procédure opérateur utilisateur %qs à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Le premier argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Le deuxième argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "L'interface opérateur à %L doit avoir, au plus, deux arguments"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "La procédure contenue %qs à %L d'une procédure PURE doit aussi être PURE"
@@ -72109,17 +72188,17 @@ msgstr "Initialisations inégales et se chevauchant dans EQUIVALENCE à %C"
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Le nombre d'éléments dans le constructeur du tableau à %L requiert une augmentation de la limite supérieure permise %d. Voyez l'option %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Création d'un temporaire pour le tableau à %L dans l'argument %qs"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "mauvais type d'expression durant le parcours (%d)"
@@ -72210,107 +72289,107 @@ msgstr "expression d'initialisation non constante à %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr "Le tableau %qs à %L est plus grand que la limite définie par %<-fmax-stack-var-size=%>, il est déplacé de la pile vers la zone de stockage statique. Ceci rend la procédure non sûr lorsqu'elle est appelée récursivement ou simultanément depuis plusieurs threads. Envisagez d'utiliser %<-frecursive%> ou augmentez la limite de %<-fmax-stack-var-size=%> ou changez le code pour utiliser un tableau ALLOCATABLE."
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "variable intrinsèque qui n'est pas une procédure"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "La valeur de retour de la fonction %qs à %L n'est pas définie"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Paramètre de type différé pas encore supporté"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "Le backend decl pour la variable de module %qs existe déjà"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "La variable de module PRIVATE %qs inutilisée est déclarée à %L"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "L'argument muet %qs à %L a été déclaré INTENT(OUT) mais n'a pas reçu de valeur"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "L'argument muet %qs d'un type dérivé à %L a été déclaré INTENT(OUT) mais n'a pas reçu de valeur et n'a pas d'initialisation par défaut"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Argument muet %qs inutilisé à %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "La variable de module %qs est inutilisée mais elle a été importée explicitement à %L"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Variable %qs inutilisée déclarée à %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Paramètre %qs inutilisé déclaré à %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Le paramètre %qs est inutilisé mais il a été importé explicitement à %L"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "La valeur de retour %qs de la fonction %qs est déclarée à %L mais ne reçoit pas de valeur"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Désolé, !$ACC DECLARE à %L n'est pas permis dans une construction BLOCK"
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "Impossible de calculer la longueur du tableau de caractères à %L."
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Du code pour réallouer la variable allouable à %L va être ajouté"
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Désolé, un accès co-indexé à un objet polymorphique illimité à %L n'est pas supporté"
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Désolé, un accès co-indexé à un composant polymorphique illimité à %L n'est pas supporté"
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Op intrinsèque inconnue"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Fonction de liste d'arguments inconnue à %L"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Si le remappage des limites est spécifié à %L, la cible du pointeur ne sera point NULL"
@@ -72461,7 +72540,7 @@ msgstr "gfc_validate_kind(): Mauvais type obtenu"
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr "gfc_validate_kind(): Mauvais sous-type obtenu"
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code(): Mauvais code d'instruction"
@@ -72587,8 +72666,9 @@ msgid "%<-fwpa%> and %<-fltrans%> are mutually exclusive"
 msgstr "%<-fwpa%> et %<-fltrans%> sont mutuellement exclusifs"
 
 #: lto/lto-lang.c:898
-#, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+#, fuzzy, gcc-internal-format
+#| msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "%<-flinker-output=rel%> et %<-fltrans%> sont mutuellement exclusifs"
 
 #: lto/lto-object.c:107
@@ -73690,7 +73770,7 @@ msgstr "Option non reconnue pour la valeur de boutisme : %qs"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "Option non reconnue pour initialiser la valeur en virgule flottante: %qs"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "Option non reconnue : %qs"
@@ -73708,15 +73788,15 @@ msgstr "nom de macro manquant après %qs"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "nom de fichier manquant après %qs"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "cible manquante après %qs"
@@ -73766,7 +73846,7 @@ msgstr "nom de module manquant"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "valeur de visibilité %qs non reconnue dans « ivar_visibility »"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "ordre de stockage des scalaires %qs non reconnu"
@@ -73849,92 +73929,92 @@ msgstr "%qs est obsolète"
 msgid "unknown linker output %qs"
 msgstr "sortie %qs inconnue pour l'éditeur de liens"
 
-#: common.opt:1502
+#: common.opt:1506
 #, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "style de précision excédentaire %qs inconnu"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr "spécification inconnue pour l'ensemble des valeurs de FLT_EVAL_METHOD à permettre %qs"
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "style de contraction en virgule flottante %qs inconnu"
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "Niveau de réutilisation de la pile %qs inconnu"
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "niveau de Control-Flow Protection %qs inconnu"
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "algorithme IRA %qs inconnu"
 
-#: common.opt:1902
+#: common.opt:1906
 #, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "région IRA %qs inconnue"
 
-#: common.opt:1980
+#: common.opt:1984
 #, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "modèle de partitionnement LTO %qs inconnu"
 
-#: common.opt:2082
+#: common.opt:2086
 #, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "options ou cibles manquantes après %qs"
 
-#: common.opt:2090
+#: common.opt:2094
 #, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "ABI de déchargement %qs inconnue"
 
-#: common.opt:2232
+#: common.opt:2236
 #, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "méthode de reproductibilité du profil %qs inconnue"
 
-#: common.opt:2248
+#: common.opt:2252
 #, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "méthode de mise à jour du profil %qs inconnue"
 
-#: common.opt:2350
+#: common.opt:2354
 #, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr "Niveau de correction à chaud %qs inconnu"
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "algorithme de réorganisation des blocs de base %qs inconnu"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "modèle TLS %qs inconnu"
 
-#: common.opt:3026
+#: common.opt:3030
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "modèle de coût de la vectorisation %qs inconnu"
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "valeur de visibilité %qs non reconnue"
 
-#: common.opt:3086
+#: common.opt:3090
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "priorité d'initialisation de la vérification de la vtable %qs inconnue"
@@ -73944,6 +74024,9 @@ msgstr "priorité d'initialisation de la vérification de la vtable %qs inconnue
 msgid "unknown evrp mode %qs"
 msgstr "mode evrp %qs inconnu"
 
+#~ msgid "cannot deduce template arguments for %qT from %<()%>"
+#~ msgstr "impossible de déduire les arguments du patron pour %qT depuis %<()%>"
+
 #~ msgid "%K%qD may write %E or more bytes into a region of size %E the destination"
 #~ msgstr "%K%qD peut écrire %E octets ou plus dans une région de taille %E de destination"
 
@@ -75526,9 +75609,6 @@ msgstr "mode evrp %qs inconnu"
 #~ msgid "-freorder-blocks-and-partition does not work on this architecture"
 #~ msgstr "-freorder-blocks-and-partition ne fonctionne pas sur cette architecture"
 
-#~ msgid "constant argument %d for builtin %qF is out of range ("
-#~ msgstr "l'argument constant %d de la fonction interne %qF est hors limite ("
-
 #~ msgid "bad value (%s) for -mcmodel= switch"
 #~ msgstr "valeur erronée (%s) pour l'option -mcmodel="
 
@@ -76553,9 +76633,6 @@ msgstr "mode evrp %qs inconnu"
 #~ msgid "lambda-expression in unevaluated context"
 #~ msgstr "expression lambda dans un contexte non évalué"
 
-#~ msgid "lambda-expression in template-argument"
-#~ msgstr "expression lambda dans l'argument du patron"
-
 #~ msgid "empty introduction-list"
 #~ msgstr "liste d'instructions vide"
 
diff --git a/gcc/po/hr.po b/gcc/po/hr.po
index 7fba7e6321313..629b33004502f 100644
--- a/gcc/po/hr.po
+++ b/gcc/po/hr.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.7.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2012-07-05 15:49+0200\n"
 "Last-Translator: Tomislav Krznar <tomislav.krznar@gmail.com>\n"
 "Language-Team: Croatian <lokalizacija@linux.hr>\n"
@@ -1292,11 +1292,11 @@ msgstr ""
 msgid "this is the insn:"
 msgstr "ovo je insn:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 msgid "unable to generate reloads for impossible constraints:"
 msgstr ""
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr ""
 
@@ -1468,18 +1468,18 @@ msgstr "neprepoznati insn:"
 msgid "insn does not satisfy its constraints:"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "napravljeno i korišteno s različitim postavkama „%s”"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "napravljeno i korišteno s različitim postavkama -fpic"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1520,7 +1520,7 @@ msgstr ""
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr ""
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1968,86 +1968,86 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, c-format
 msgid "invalid vector constant"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid constant"
 msgstr "neispravni %%-kod"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand"
 msgstr "neispravni izraz kao operand"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 #| msgid "invalid 'asm': "
 msgid "invalid address mode"
 msgstr "neispravni „asm”: "
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2063,18 +2063,18 @@ msgid "invalid %%r value"
 msgstr ""
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr ""
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr ""
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr ""
@@ -2104,7 +2104,7 @@ msgstr ""
 msgid "invalid %%U value"
 msgstr ""
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr ""
@@ -2114,7 +2114,7 @@ msgstr ""
 msgid "invalid %%C value"
 msgstr ""
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr ""
@@ -2127,7 +2127,7 @@ msgstr ""
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr ""
@@ -2216,35 +2216,35 @@ msgstr "neispravni izraz kao operand"
 msgid "unrecognized supposed constant"
 msgstr ""
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr ""
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr ""
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2252,13 +2252,13 @@ msgstr ""
 msgid "invalid operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2380,8 +2380,8 @@ msgstr ""
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2749,7 +2749,7 @@ msgstr ""
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -2803,7 +2803,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr ""
 
@@ -2855,8 +2855,8 @@ msgstr ""
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr ""
@@ -2994,291 +2994,291 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%A value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%e value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%t value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%V value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%z value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr ""
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 msgid "vector argument passed to unprototyped function"
 msgstr ""
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3541,8 +3541,8 @@ msgstr ""
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "očekujem %<;%>"
@@ -3562,7 +3562,7 @@ msgstr "očekujem %<;%>"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "očekujem %<)%>"
@@ -3570,7 +3570,7 @@ msgstr "očekujem %<)%>"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "očekujem %<]%>"
@@ -3588,21 +3588,21 @@ msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "očekujem %<(%>"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "očekujem %<[%>"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "očekujem %<{%>"
@@ -3613,13 +3613,13 @@ msgstr "očekujem %<{%>"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "očekujem %<:%>"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "očekujem %<while%>"
@@ -3628,7 +3628,7 @@ msgstr "očekujem %<while%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "očekujem %<,%>"
@@ -3637,18 +3637,18 @@ msgstr "očekujem %<,%>"
 msgid "expected %<.%>"
 msgstr "očekujem %<.%>"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "očekujem %<>%>"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "očekujem %<,%> ili %<)%>"
@@ -3656,28 +3656,28 @@ msgstr "očekujem %<,%> ili %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "očekujem %<=%>"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "očekujem %<}%>"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -3693,30 +3693,30 @@ msgstr "očekujem %<while%>"
 msgid "candidate:"
 msgstr ""
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr ""
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr ""
 
@@ -3935,27 +3935,27 @@ msgstr ""
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 msgid "%<using enum%> of dependent type %qT"
 msgstr ""
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr ""
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 msgid "%<using enum%> of incomplete type %qT"
 msgstr ""
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr ""
 
@@ -3999,48 +3999,48 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4139,7 +4139,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4269,7 +4269,7 @@ msgstr ""
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr ""
 
@@ -4297,11 +4297,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr ""
 
@@ -4387,154 +4387,154 @@ msgstr ""
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4659,26 +4659,26 @@ msgstr ""
 msgid "Incorrect function return value"
 msgstr ""
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, c-format
 msgid "Error allocating %lu bytes"
 msgstr ""
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr ""
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr ""
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -4891,15 +4891,15 @@ msgstr ""
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr ""
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr ""
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr ""
 
@@ -4915,8 +4915,8 @@ msgstr ""
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr ""
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr ""
 
@@ -5076,10 +5076,10 @@ msgid "Warn about creation of array temporaries."
 msgstr ""
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5554,160 +5554,160 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr ""
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr ""
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr ""
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr ""
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr ""
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr ""
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr ""
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr ""
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr ""
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr ""
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr ""
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr ""
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr ""
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr ""
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr ""
@@ -6386,7 +6386,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7009,8 +7009,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr ""
@@ -7367,468 +7367,463 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr ""
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr ""
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr ""
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr ""
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr ""
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr ""
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr ""
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr ""
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr ""
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr ""
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr ""
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr ""
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, fuzzy, no-c-format
 #| msgid "enabled by default"
 msgid "Make \"char\" signed by default."
 msgstr "uobičajeno omogućeno"
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr ""
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr ""
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr ""
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr ""
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr ""
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr ""
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, fuzzy, no-c-format
 #| msgid "enabled by default"
 msgid "Make \"char\" unsigned by default."
 msgstr "uobičajeno omogućeno"
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr ""
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr ""
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr ""
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr ""
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr ""
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr ""
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr ""
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr ""
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr ""
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr ""
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr ""
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr ""
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr ""
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr ""
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr ""
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr ""
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr ""
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr ""
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr ""
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr ""
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr ""
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr ""
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr ""
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr ""
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr ""
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr ""
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr ""
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr ""
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr ""
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr ""
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr ""
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr ""
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr ""
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr ""
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr ""
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr ""
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr ""
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr ""
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr ""
@@ -8073,6 +8068,11 @@ msgstr ""
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr ""
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9310,143 +9310,155 @@ msgstr ""
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr ""
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr ""
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr ""
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr ""
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr ""
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr ""
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr ""
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr ""
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr ""
@@ -9581,12 +9593,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9607,12 +9613,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -16837,2164 +16837,2164 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, no-c-format
 msgid "Align the start of functions."
 msgstr ""
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, no-c-format
 msgid "Enable static analysis pass."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1073
 #, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr ""
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr ""
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1111
+#: common.opt:1115
 #, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr ""
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr ""
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr ""
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr ""
 
-#: common.opt:1150
+#: common.opt:1154
 #, no-c-format
 msgid "Enable code hoisting."
 msgstr ""
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr ""
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1586
+#: common.opt:1590
 #, no-c-format
 msgid "Place each function into its own section."
 msgstr ""
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr ""
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr ""
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1703
+#: common.opt:1707
 #, no-c-format
 msgid "Process #ident directives."
 msgstr ""
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1743
+#: common.opt:1747
 #, no-c-format
 msgid "Do not generate .size directives."
 msgstr ""
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, no-c-format
 msgid "Discover pure and const functions."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr ""
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1945
+#: common.opt:1949
 #, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr ""
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr ""
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:2020
+#: common.opt:2024
 #, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr ""
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:2104
+#: common.opt:2108
 #, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr ""
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2305
+#: common.opt:2309
 #, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2449
+#: common.opt:2453
 #, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr ""
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr ""
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr ""
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2730
+#: common.opt:2734
 #, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2734
+#: common.opt:2738
 #, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2774
+#: common.opt:2778
 #, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr ""
 
-#: common.opt:2778
+#: common.opt:2782
 #, no-c-format
 msgid "Enable dominator optimizations."
 msgstr ""
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2786
+#: common.opt:2790
 #, no-c-format
 msgid "Enable dead store elimination."
 msgstr ""
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2798
+#: common.opt:2802
 #, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr ""
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr ""
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2835
+#: common.opt:2839
 #, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr ""
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2847
+#: common.opt:2851
 #, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr ""
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:3011
+#: common.opt:3015
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr ""
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3191
+#: common.opt:3195
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 #| msgid "  -o <file>                Place the output into <file>\n"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <datoteka>            Spremi izlaz u <datoteka>\n"
 
-#: common.opt:3324
+#: common.opt:3328
 #, no-c-format
 msgid "Enable function profiling."
 msgstr ""
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr ""
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr ""
 
-#: common.opt:3424
+#: common.opt:3428
 #, fuzzy, no-c-format
 #| msgid "  -shared                  Create a shared library\n"
 msgid "Create a shared library."
 msgstr "  -shared                  Napravi dijeljenu biblioteku\n"
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19137,1111 +19137,1121 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr ""
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr ""
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr ""
 
-#: params.opt:210
+#: params.opt:215
 #, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr ""
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr ""
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr ""
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr ""
 
-#: params.opt:242
+#: params.opt:247
 #, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr ""
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr ""
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr ""
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "Veličina tijela funkcije koja se smatra velikom"
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr ""
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr ""
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr ""
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr ""
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr ""
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr ""
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr ""
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr ""
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr ""
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr ""
 
-#: params.opt:362
+#: params.opt:367
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of function body to be considered large."
 msgstr "Veličina tijela funkcije koja se smatra velikom"
 
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 #| msgid "The size of stack frame to be considered large"
 msgid "The size of stack frame to be considered large."
 msgstr "Veličina okvira stoga koja se smatra velikom"
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr ""
 
-#: params.opt:374
+#: params.opt:379
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of translation unit to be considered large."
 msgstr "Veličina tijela funkcije koja se smatra velikom"
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr ""
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr ""
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr ""
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr ""
 
-#: params.opt:414
+#: params.opt:419
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr ""
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr ""
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr ""
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr ""
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr ""
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr ""
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr ""
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr ""
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr ""
 
-#: params.opt:474
+#: params.opt:479
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE"
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Najveća količina memorije koju će alocirati GCSE"
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr ""
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr ""
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr ""
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr ""
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr ""
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr ""
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE"
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "Najveća količina memorije koju će alocirati GCSE"
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr ""
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr ""
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr ""
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr ""
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr ""
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr ""
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr ""
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr ""
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr ""
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr ""
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr ""
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr ""
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr ""
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr ""
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr ""
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr ""
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr ""
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr ""
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr ""
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr ""
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr ""
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr ""
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr ""
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr ""
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr ""
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr ""
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr ""
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr ""
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr ""
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr ""
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr ""
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr ""
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr ""
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr ""
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr ""
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr ""
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr ""
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr ""
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr ""
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr ""
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr ""
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr ""
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr ""
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr ""
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr ""
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr ""
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr ""
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr ""
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr ""
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr ""
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr ""
 
-#: params.opt:952
+#: params.opt:970
 #, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr ""
 
-#: params.opt:956
+#: params.opt:974
 #, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr ""
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr ""
 
-#: params.opt:964
+#: params.opt:982
 #, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr ""
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr ""
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr ""
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr ""
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr ""
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr ""
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr ""
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr ""
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20272,7 +20282,7 @@ msgid "expected boolean type"
 msgstr ""
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "expected integer"
@@ -20337,7 +20347,7 @@ msgstr ""
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr ""
@@ -20691,7 +20701,7 @@ msgstr ""
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr ""
@@ -20747,7 +20757,7 @@ msgstr ""
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -20776,20 +20786,20 @@ msgstr ""
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -20800,8 +20810,8 @@ msgstr ""
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr ""
@@ -20811,47 +20821,47 @@ msgstr ""
 msgid "ignoring attributes applied to %qT after definition"
 msgstr ""
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr ""
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr ""
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr ""
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr ""
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr ""
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr ""
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr ""
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr ""
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
@@ -20859,12 +20869,12 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, gcc-internal-format
 msgid "%qD target declared here"
 msgstr ""
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -20969,7 +20979,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr ""
@@ -20994,422 +21004,422 @@ msgstr ""
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr ""
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, gcc-internal-format
 msgid "source object declared here"
 msgstr ""
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, gcc-internal-format
 msgid "destination object declared here"
 msgstr ""
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, gcc-internal-format
 msgid "destination object allocated here"
 msgstr ""
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
@@ -21417,7 +21427,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
@@ -21425,291 +21435,291 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr ""
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr ""
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr ""
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr ""
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr ""
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr ""
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr ""
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, gcc-internal-format
 msgid "non-integer argument 1 to %qs"
 msgstr ""
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr ""
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr ""
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr ""
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr ""
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr ""
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr ""
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr ""
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr ""
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, gcc-internal-format
 msgid "returned from %qD"
 msgstr ""
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, gcc-internal-format
 msgid "returned from %qT"
 msgstr ""
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, gcc-internal-format
 msgid "obtained here"
 msgstr ""
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, gcc-internal-format
 msgid "assigned here"
 msgstr ""
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -22473,302 +22483,302 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr ""
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr ""
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr ""
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr ""
@@ -22849,12 +22859,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr ""
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -22924,7 +22934,7 @@ msgstr ""
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr ""
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr ""
@@ -23336,12 +23346,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -23361,7 +23371,7 @@ msgstr ""
 msgid "internal consistency failure"
 msgstr ""
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -23491,42 +23501,42 @@ msgstr ""
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23541,7 +23551,7 @@ msgstr ""
 msgid "total size of local objects exceeds maximum %wu"
 msgstr ""
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -24163,7 +24173,7 @@ msgstr ""
 msgid "function may return address of local variable"
 msgstr "tijelo funkcije nije dostupno"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr ""
@@ -24540,53 +24550,53 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 msgid "%Guse of %<alloca%>"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 msgid "%Gargument to variable-length array may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 msgid "%Gargument to variable-length array is too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 msgid "%Gargument to %<alloca%> is too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 msgid "%Gunbounded use of variable-length array"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 msgid "%Gunbounded use of %<alloca%>"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 msgid "%Gargument to variable-length array is zero"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 msgid "%Gargument to %<alloca%> is zero"
 msgstr ""
 
@@ -24711,7 +24721,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, gcc-internal-format
 msgid "array %qD declared here"
 msgstr ""
@@ -24737,11 +24747,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -24816,308 +24826,308 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr ""
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr ""
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, gcc-internal-format
 msgid "enclosing region"
 msgstr ""
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr ""
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr ""
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -25572,22 +25582,22 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr ""
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr ""
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr ""
@@ -25607,12 +25617,12 @@ msgstr ""
 msgid "unable to find a register to spill"
 msgstr ""
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr ""
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
@@ -26330,12 +26340,12 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr ""
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr ""
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr ""
@@ -26461,7 +26471,7 @@ msgstr ""
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
@@ -26959,22 +26969,22 @@ msgstr ""
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr ""
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr ""
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr ""
@@ -27036,12 +27046,12 @@ msgstr ""
 msgid "impossible register constraint in %<asm%>"
 msgstr ""
 
-#: reload.c:2687
+#: reload.c:2692
 #, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr ""
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr ""
@@ -27071,52 +27081,52 @@ msgstr ""
 msgid "output operand is constant in %<asm%>"
 msgstr ""
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:900
+#: rtl.c:910
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr ""
@@ -27161,22 +27171,22 @@ msgstr ""
 msgid "invalid punctuation %qc in constraint"
 msgstr ""
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr ""
 
-#: stmt.c:524
+#: stmt.c:525
 #, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr ""
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr ""
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr ""
@@ -27858,9 +27868,9 @@ msgstr ""
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr ""
@@ -27898,7 +27908,7 @@ msgstr "neispravni izraz kao operand"
 msgid "invalid clique in %qs"
 msgstr ""
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
@@ -28105,362 +28115,362 @@ msgstr ""
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr ""
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr ""
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr ""
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr ""
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr ""
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr ""
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr ""
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr ""
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr ""
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr ""
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr ""
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr ""
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr ""
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr ""
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr ""
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr ""
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr ""
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr ""
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr ""
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr ""
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr ""
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr ""
@@ -29552,7 +29562,7 @@ msgstr ""
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
@@ -29713,7 +29723,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, gcc-internal-format
 msgid "unsupported record layout"
 msgstr ""
@@ -30317,7 +30327,7 @@ msgstr ""
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -30337,7 +30347,7 @@ msgstr ""
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -30762,12 +30772,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr ""
@@ -30928,13 +30938,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr ""
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr ""
@@ -31868,7 +31878,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -31918,7 +31928,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -31933,17 +31943,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
@@ -31953,7 +31963,7 @@ msgstr ""
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -32018,7 +32028,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -32585,8 +32595,8 @@ msgstr ""
 msgid "wrong type argument to %s"
 msgstr ""
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -33071,17 +33081,17 @@ msgstr ""
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr ""
@@ -33261,8 +33271,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -33339,84 +33349,84 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr ""
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr ""
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
 msgstr ""
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
 msgstr ""
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr ""
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr ""
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr ""
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
@@ -33424,7 +33434,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
@@ -33432,7 +33442,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
@@ -33440,7 +33450,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
@@ -33448,7 +33458,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
@@ -33456,47 +33466,47 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr ""
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
 msgstr ""
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr ""
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -33511,7 +33521,7 @@ msgstr ""
 msgid "too many input files"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr ""
@@ -33542,14 +33552,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr ""
@@ -33700,62 +33710,62 @@ msgstr ""
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
@@ -33917,89 +33927,89 @@ msgstr ""
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr ""
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr ""
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr ""
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr ""
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr ""
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr ""
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr ""
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr ""
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr ""
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr ""
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr ""
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr ""
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr ""
 
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr ""
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34135,364 +34145,364 @@ msgstr ""
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s:unknown function '%u'\n"
 msgid "unknown tuning option (%s)"
 msgstr "%s:nepoznata funkcija „%u”\n"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr ""
@@ -34553,7 +34563,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr ""
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -34673,18 +34683,18 @@ msgstr ""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr ""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -35114,223 +35124,228 @@ msgstr ""
 msgid "target CPU does not support unaligned accesses"
 msgstr ""
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr ""
+
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr ""
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr ""
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr ""
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr ""
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -35338,22 +35353,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr ""
@@ -35432,17 +35447,17 @@ msgstr ""
 msgid "%<-fPIE%> is not supported"
 msgstr ""
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr ""
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr ""
@@ -36191,132 +36206,132 @@ msgstr ""
 msgid "parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr ""
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr ""
@@ -36336,514 +36351,514 @@ msgstr ""
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr ""
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr ""
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -37298,7 +37313,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -38354,57 +38369,57 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr ""
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -38907,239 +38922,239 @@ msgstr ""
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20055
+#: config/rs6000/rs6000.c:20172
 #, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -39318,7 +39333,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -39388,200 +39403,205 @@ msgstr ""
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, gcc-internal-format
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr ""
+
+#: config/s390/s390.c:766
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr ""
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr ""
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr ""
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr ""
@@ -39923,17 +39943,22 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr ""
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr ""
@@ -40000,8 +40025,8 @@ msgstr ""
 msgid "could not read the BRIG file"
 msgstr "ne mogu pisati u privremenu datoteku %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -40061,7 +40086,7 @@ msgstr ""
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
@@ -40283,7 +40308,7 @@ msgstr ""
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -40293,7 +40318,7 @@ msgstr ""
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
@@ -40303,212 +40328,212 @@ msgstr ""
 msgid "nested extern declaration of %qD"
 msgstr ""
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr ""
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr ""
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr ""
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr ""
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr ""
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr ""
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr ""
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr ""
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr ""
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr ""
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr ""
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr ""
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr ""
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr ""
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr ""
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr ""
@@ -40516,28 +40541,28 @@ msgstr ""
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr ""
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr ""
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr ""
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr ""
@@ -40546,267 +40571,267 @@ msgstr ""
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr ""
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr ""
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr ""
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr ""
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr ""
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr ""
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr ""
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, gcc-internal-format
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr ""
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr ""
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr ""
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr ""
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr ""
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr ""
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr ""
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr ""
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr ""
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr ""
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr ""
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -40814,711 +40839,711 @@ msgstr ""
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr ""
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr ""
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr ""
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr ""
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr ""
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr ""
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr ""
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr ""
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr ""
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr ""
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr ""
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr ""
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr ""
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr ""
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr ""
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr ""
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr ""
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr ""
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr ""
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr ""
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr ""
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr ""
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr ""
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr ""
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr ""
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr ""
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr ""
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr ""
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr ""
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr ""
@@ -41526,257 +41551,257 @@ msgstr ""
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr ""
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr ""
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr ""
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr ""
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr ""
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr ""
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr ""
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr ""
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr ""
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr ""
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr ""
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr ""
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -41796,7 +41821,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "očekujem kraj retka"
@@ -41806,7 +41831,7 @@ msgstr "očekujem kraj retka"
 msgid "ISO C forbids an empty translation unit"
 msgstr ""
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr ""
@@ -41842,7 +41867,7 @@ msgid "unknown type name %qE"
 msgstr ""
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -41862,7 +41887,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -41877,7 +41902,7 @@ msgstr ""
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -41915,7 +41940,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -41973,7 +41998,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -42018,14 +42043,14 @@ msgstr ""
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -42110,7 +42135,7 @@ msgstr ""
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr ""
@@ -42170,7 +42195,7 @@ msgstr ""
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -42185,7 +42210,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
@@ -42210,17 +42235,17 @@ msgstr ""
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr ""
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -42240,12 +42265,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -42260,8 +42285,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr ""
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -42289,12 +42314,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -42685,12 +42710,12 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, gcc-internal-format
 msgid "missing property attribute"
 msgstr ""
@@ -42700,52 +42725,52 @@ msgstr ""
 msgid "unknown property attribute %<%s%s%>"
 msgstr ""
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "expected %qE selector name"
 msgstr "očekujem kraj retka"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -42755,18 +42780,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
@@ -42787,56 +42812,56 @@ msgstr "očekujem %<,%> ili %<)%>"
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<data%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -42858,111 +42883,111 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr ""
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr ""
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "unexpected argument"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<concurrent%>"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -42972,17 +42997,17 @@ msgstr ""
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -43002,24 +43027,24 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid depend kind"
 msgstr "neispravni izraz kao operand"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 #| msgid "invalid 'asm': "
 msgid "invalid map kind"
 msgstr "neispravni „asm”: "
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -43035,83 +43060,83 @@ msgstr ""
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -43127,7 +43152,7 @@ msgstr ""
 msgid "expected function name"
 msgstr "očekujem kraj retka"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -43137,27 +43162,27 @@ msgstr ""
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<allocator%>"
@@ -43168,86 +43193,86 @@ msgstr "očekujem %<;%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr ""
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr ""
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr ""
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr ""
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -43257,34 +43282,34 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<#pragma omp scan%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -43294,74 +43319,74 @@ msgstr ""
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<for%> after %qs"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<point%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -43376,57 +43401,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr ""
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr ""
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<match%>"
@@ -43437,12 +43462,12 @@ msgstr "očekujem %<;%>"
 msgid "variant %qD is not a function"
 msgstr ""
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr ""
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43452,34 +43477,34 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<target%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%>"
 msgid "expected %<declare%>"
 msgstr "očekujem %<while%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -43535,44 +43560,44 @@ msgstr "očekujem %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -43587,27 +43612,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -43617,7 +43642,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -43632,7 +43657,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -43673,127 +43698,127 @@ msgstr ""
 msgid "function types not truly compatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr ""
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr ""
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr ""
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr ""
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr ""
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr ""
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr ""
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr ""
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr ""
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr ""
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr ""
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr ""
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr ""
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr ""
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr ""
@@ -43801,1595 +43826,1595 @@ msgstr ""
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr ""
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr ""
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr ""
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr ""
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, gcc-internal-format
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr ""
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, gcc-internal-format
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr ""
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr ""
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr ""
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, gcc-internal-format
 msgid "wrong type argument to absu"
 msgstr ""
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr ""
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr ""
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr ""
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr ""
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr ""
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, gcc-internal-format
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr ""
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr ""
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr ""
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr ""
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr ""
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr ""
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr ""
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr ""
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr ""
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr ""
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT"
 msgstr ""
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr ""
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr ""
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr ""
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr ""
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr ""
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr ""
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr ""
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr ""
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr ""
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr ""
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr ""
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr ""
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr ""
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, gcc-internal-format
 msgid "excess elements in %<char%> array initializer"
 msgstr ""
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr ""
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr ""
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr ""
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr ""
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr ""
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr ""
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr ""
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr ""
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr ""
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "expected pointer in %qs clause"
 msgstr "očekujem kraj retka"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr ""
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr ""
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -45608,7 +45633,7 @@ msgstr ""
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -45718,662 +45743,666 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr ""
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "%s\n"
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr ""
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr ""
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr ""
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr ""
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, gcc-internal-format
 msgid "  declared here"
 msgstr ""
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr ""
+
+#: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -46397,1126 +46426,1126 @@ msgstr ""
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr ""
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr ""
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr ""
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr ""
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr ""
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr ""
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr ""
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr ""
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr ""
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr ""
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr ""
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr ""
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr ""
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr ""
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr ""
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr ""
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr ""
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr ""
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, gcc-internal-format
 msgid "allocation performed here"
 msgstr ""
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr ""
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr ""
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr ""
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, gcc-internal-format
 msgid "allocated here"
 msgstr ""
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr ""
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr ""
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -47526,52 +47555,52 @@ msgstr ""
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr ""
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr ""
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr ""
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "evaluating %qs"
@@ -47613,7 +47642,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -47996,7 +48025,7 @@ msgstr ""
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr ""
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr ""
@@ -48126,8 +48155,8 @@ msgstr ""
 msgid "%q#D previously defined here"
 msgstr ""
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr ""
@@ -48162,52 +48191,52 @@ msgstr ""
 msgid "previous specification in %q#D here"
 msgstr ""
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr ""
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr ""
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr ""
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
 msgstr ""
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr ""
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr ""
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr ""
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr ""
@@ -48220,48 +48249,48 @@ msgstr ""
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr ""
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48269,655 +48298,660 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr ""
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr ""
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr ""
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, gcc-internal-format
+msgid "%qD is a function, not a type"
+msgstr ""
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr ""
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr ""
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr ""
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr ""
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr ""
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -48925,7 +48959,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -48933,7 +48967,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -48941,1632 +48975,1642 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr ""
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr ""
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr ""
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr ""
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr ""
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr ""
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr ""
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr ""
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr ""
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr ""
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr ""
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr ""
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr ""
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr ""
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr ""
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "%qD cannot be %qs"
 msgstr "[ne mogu naći %s]"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr ""
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -50578,105 +50622,105 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr ""
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -50685,77 +50729,77 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr ""
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -50795,7 +50839,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -50805,7 +50849,7 @@ msgstr ""
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -51131,23 +51175,23 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -51252,7 +51296,7 @@ msgstr ""
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
@@ -51262,7 +51306,7 @@ msgstr ""
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
@@ -51448,408 +51492,408 @@ msgstr ""
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr ""
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr ""
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr ""
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr ""
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr ""
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr ""
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr ""
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr ""
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr ""
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -51904,62 +51948,62 @@ msgstr ""
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -52140,216 +52184,216 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr ""
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr ""
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr ""
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 #| msgid "%d constructor found\n"
 #| msgid_plural "%d constructors found\n"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%d konstruktor pronađen\n"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr ""
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr ""
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr ""
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s%s\n"
 msgid "%s %s %p %d"
 msgstr "%s %s%s\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr ""
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -52357,88 +52401,88 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr ""
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr ""
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr ""
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr ""
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -52463,7 +52507,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -52488,7 +52532,7 @@ msgstr ""
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -52568,7 +52612,7 @@ msgstr ""
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -52704,7 +52748,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -52829,7 +52873,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -52881,7 +52925,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -52911,7 +52955,7 @@ msgstr ""
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr ""
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
@@ -52931,12 +52975,12 @@ msgstr ""
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
@@ -52971,7 +53015,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
@@ -52986,7 +53030,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr ""
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr ""
@@ -53001,1116 +53045,1121 @@ msgstr ""
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr ""
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr ""
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr ""
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr ""
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr ""
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr ""
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr ""
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr ""
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr ""
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr ""
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr ""
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr ""
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr ""
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "expected module-name"
 msgstr "očekujem kraj retka"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, gcc-internal-format
 msgid "private module fragment"
 msgstr ""
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr ""
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr ""
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr ""
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr ""
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr ""
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "neispravni izraz kao operand"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr ""
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr ""
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr ""
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr ""
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr ""
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr ""
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr ""
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr ""
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr ""
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr ""
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr ""
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr ""
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, gcc-internal-format
 msgid "parentheses were disambiguated as a function declaration"
 msgstr ""
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
@@ -54119,432 +54168,432 @@ msgstr ""
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr ""
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr ""
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr ""
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected attribute before %<...%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr ""
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr ""
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -54553,758 +54602,758 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr ""
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr ""
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr ""
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<auto%>"
 msgstr "očekujem %<;%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "očekujem %<@end%>"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr ""
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr ""
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr ""
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr ""
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr ""
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr ""
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr ""
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr ""
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr ""
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr ""
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr ""
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr ""
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr ""
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr ""
@@ -55317,142 +55366,142 @@ msgstr ""
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr ""
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr ""
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr ""
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr ""
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -55460,17 +55509,17 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -55479,47 +55528,47 @@ msgstr ""
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -55529,57 +55578,57 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -55587,7 +55636,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -55595,132 +55644,132 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr ""
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -55728,297 +55777,297 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr ""
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
@@ -56036,291 +56085,291 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr ""
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr ""
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -56332,156 +56381,156 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr ""
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr ""
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr ""
@@ -56616,531 +56665,531 @@ msgstr ""
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr ""
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr ""
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr ""
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr ""
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr ""
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr ""
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr ""
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr ""
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -57148,22 +57197,22 @@ msgstr ""
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -57173,1052 +57222,1052 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, gcc-internal-format
 msgid " declared here"
 msgstr ""
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr ""
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr ""
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr ""
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr ""
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr ""
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr ""
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr ""
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr ""
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr ""
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr ""
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr ""
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr ""
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr ""
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr ""
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr ""
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr ""
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr ""
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr ""
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr ""
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7956
+#: cp/typeck.c:7963
 #, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr ""
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr ""
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr ""
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr ""
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr ""
@@ -58483,107 +58532,102 @@ msgstr ""
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2213
-#, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr ""
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -58603,267 +58647,272 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, gcc-internal-format
 msgid "cannot be declared to be a function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, gcc-internal-format, gfc-internal-format
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot be %s"
 msgstr "[ne mogu naći %s]"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, gcc-internal-format
 msgid "string expected for library name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, gcc-internal-format
+msgid "takes no argument"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:1526
 #, gcc-internal-format
 msgid "can only apply to a single declaration"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, gcc-internal-format
 msgid "circular reference to enum member"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, gcc-internal-format
 msgid "recursive mixin instantiation"
 msgstr ""
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, gcc-internal-format
 msgid "recursive expansion"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, gcc-internal-format
 msgid "error instantiating"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "without `this` cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, gcc-internal-format
 msgid "functions cannot be scope"
 msgstr ""
@@ -58871,42 +58920,52 @@ msgstr ""
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, gcc-internal-format
 msgid "cannot be both final and abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -58914,173 +58973,173 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, gcc-internal-format
 msgid "does not override any function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, gcc-internal-format
 msgid "structs, unions cannot be abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, gcc-internal-format
 msgid "circular inheritance"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "zanemarujem direktorij duplikat „%s”\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot inherit from final class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, gcc-internal-format
 msgid "cannot resolve"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr ""
@@ -59095,22 +59154,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, gcc-internal-format
 msgid "has forward references"
 msgstr ""
@@ -59170,22 +59229,22 @@ msgstr ""
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
+#: d/dmd/semantic3.c:864
 #, gcc-internal-format
-msgid "no return exp; or assert(0); at end of function"
+msgid "no `return exp;` or `assert(0);` at end of function"
 msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr ""
@@ -59721,7 +59780,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -60815,12 +60874,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -61000,7 +61059,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -63489,7 +63548,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63571,7 +63630,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -63706,12 +63765,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -63821,542 +63880,542 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr ""
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr ""
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr ""
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr ""
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
@@ -64501,33 +64560,33 @@ msgstr ""
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr ""
@@ -64535,22 +64594,22 @@ msgstr ""
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -65086,7 +65145,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -66259,12 +66318,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -66419,153 +66478,153 @@ msgstr ""
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot open source file %s\n"
 msgid "Cannot delete module file %qs: %s"
 msgstr "Ne mogu otvoriti datoteku koda %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot open source file %s\n"
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Ne mogu otvoriti datoteku koda %s\n"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 #| msgid "could not write to temporary file %s"
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "ne mogu pisati u privremenu datoteku %s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -67102,8 +67161,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -69129,7 +69188,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -69244,7 +69303,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -69400,212 +69459,212 @@ msgstr ""
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -69614,12 +69673,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -69628,293 +69687,293 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -69923,284 +69982,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -70208,192 +70267,192 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -70401,964 +70460,964 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -72225,17 +72284,17 @@ msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -72326,107 +72385,107 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -72579,7 +72638,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr ""
@@ -72708,7 +72767,7 @@ msgstr ""
 
 #: lto/lto-lang.c:898
 #, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr ""
 
 #: lto/lto-object.c:107
@@ -73811,7 +73870,7 @@ msgstr ""
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr ""
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognizable insn:"
 msgid "Unrecognized option: %qs"
@@ -73830,15 +73889,15 @@ msgstr ""
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr ""
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr ""
@@ -73888,7 +73947,7 @@ msgstr ""
 msgid "unrecognized ivar visibility value %qs"
 msgstr ""
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr ""
@@ -73971,92 +74030,92 @@ msgstr ""
 msgid "unknown linker output %qs"
 msgstr ""
 
-#: common.opt:1502
+#: common.opt:1506
 #, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr ""
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr ""
 
-#: common.opt:1902
+#: common.opt:1906
 #, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr ""
 
-#: common.opt:1980
+#: common.opt:1984
 #, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr ""
 
-#: common.opt:2082
+#: common.opt:2086
 #, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr ""
 
-#: common.opt:2090
+#: common.opt:2094
 #, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 #, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr ""
 
-#: common.opt:2248
+#: common.opt:2252
 #, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr ""
 
-#: common.opt:2350
+#: common.opt:2354
 #, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr ""
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr ""
 
-#: common.opt:3026
+#: common.opt:3030
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr ""
 
-#: common.opt:3086
+#: common.opt:3090
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
diff --git a/gcc/po/id.po b/gcc/po/id.po
index ae2078a178254..dd518a6f7418d 100644
--- a/gcc/po/id.po
+++ b/gcc/po/id.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.4.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2009-11-10 09:00+0700\n"
 "Last-Translator: Arif E. Nugroho <arif_endro@yahoo.com>\n"
 "Language-Team: Indonesian <translation-team-id@lists.sourceforge.net>\n"
@@ -1409,13 +1409,13 @@ msgstr "    inlined dari %qs"
 msgid "this is the insn:"
 msgstr "ini adalah insn:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "tidak dapat menghasilkan reloads untuk:"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "tidak dapat menghasilkan reloads untuk:"
 
@@ -1596,18 +1596,18 @@ msgstr "insn tidak dikenal:"
 msgid "insn does not satisfy its constraints:"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "dibuat dan digunakan dengan konfigurasi berbeda dari '%s'"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "dibuat dan digunakan dengan konfigurasi berbeda dari -fpic"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1648,7 +1648,7 @@ msgstr "%s%speringatan: %s versi header %s berbeda dari versi perpustakaan %s.\n
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGCC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2110,18 +2110,18 @@ msgstr "pemodifikasi panjang dalam format strfmon"
 msgid "<command-line>"
 msgstr "<baris-perintah>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, fuzzy, c-format
@@ -2129,78 +2129,78 @@ msgstr "operan tidak valid untuk kode '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
 msgstr "punctuation %qc tidak valid dalam batasan"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "hilang operan"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "insn tidak valid:"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "operan %%d tidak valid"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "alamat tidak valid"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "operan tidak valid dalam operasi binary"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2216,18 +2216,18 @@ msgid "invalid %%r value"
 msgstr "nilai %%r tidak valid"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "nilai %%R tidak valid"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "nilai %%N tidak valid"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "nilai %%P tidak valid"
@@ -2257,7 +2257,7 @@ msgstr "nilai %%M tidak valid"
 msgid "invalid %%U value"
 msgstr "nilai %%U tidak valid"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "nilai %%s tidak valid"
@@ -2267,7 +2267,7 @@ msgstr "nilai %%s tidak valid"
 msgid "invalid %%C value"
 msgstr "nilai %%C tidak valid"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "nilai %%E tidak valid"
@@ -2280,7 +2280,7 @@ msgstr "relokasi unspek tidak diketahui"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "kode %%xn tidak valid"
@@ -2369,36 +2369,36 @@ msgstr "UNSPEC tidak valid sebagai operan"
 msgid "unrecognized supposed constant"
 msgstr "konstanta yang diharapkan tidak dikenal"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "operan shift tidak valid"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruksi Thumb terprediksi"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruksi terprediksi dalam urutan berkondisi"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2406,13 +2406,13 @@ msgstr "operan tidak valid untuk kode '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "instruksi tidak pernah dijalankan"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2549,8 +2549,8 @@ msgstr "operan tidak terduga"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2933,7 +2933,7 @@ msgstr "operasi di %<__fpreg%> tidak valid"
 msgid "invalid %%P operand"
 msgstr "operan %%P tidak valid"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "nilai %%p tidak valid"
@@ -2991,7 +2991,7 @@ msgid "post-increment address is not a register"
 msgstr "alamat post-increment bukan sebuah register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "alamat buruk"
 
@@ -3049,8 +3049,8 @@ msgstr "'%%%c' bukan sebuah awalan operan yang valid"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "penggunaan dari '%%%c' tidak valid"
@@ -3196,333 +3196,333 @@ msgstr "Kehabisan ruang stack.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Mencoba menjalankan '%s' dalam shell untuk meningkatkan batasannya.\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Gunakan piranti keras titik pecahan"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Non-aktifkan pengalamatan terindeks"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "tes buruk"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "nilai %%D tidak valid"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "nilai %%f tidak valid"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "nilai %%F tidak valid"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "nilai %%G tidak valid"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "kode %%j tidak valid"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "kode %%J tidak valid"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "nilai %%k tidak valid"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "nilai %%K tidak valid"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "nilai %%O tidak valid"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "nilai %%q tidak valid"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "nilai %%T tidak valid"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "nilai %%u tidak valid"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "nilai %%v tidak valid"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "nilai %%x tidak valid"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "nilai %%ytidak valid, coba menggunakan batasan 'Z'"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Jangan hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "tidak dapat menghasilkan reloads untuk:"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "konversi ke %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "konversi ke %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "konversi ke %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "konversi ke %<__fpreg%> tidak valid"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "tidak dapat menguraikan alamat"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'O'"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "operan kode keluaran tidak valid"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, fuzzy, c-format
 #| msgid "invalid expression for min lvalue"
 msgid "invalid expression - try using an output modifier"
 msgstr "ekspresi tidak valid untuk minimal lvalue"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "target penunjuk dalam kembali berbeda dalam signedness"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3808,8 +3808,8 @@ msgstr "<anonim>"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "diduga %<,%>"
@@ -3829,7 +3829,7 @@ msgstr "diduga %<,%>"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -3838,7 +3838,7 @@ msgstr "diduga %<{%>"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -3859,13 +3859,13 @@ msgstr "diduga %<,%>, %<,%> atau %<}%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "diduga %<(%>"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -3873,8 +3873,8 @@ msgstr "diduga %<{%>"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "diduga %<{%>"
@@ -3885,14 +3885,14 @@ msgstr "diduga %<{%>"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -3902,7 +3902,7 @@ msgstr "diduga %<{%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -3914,20 +3914,20 @@ msgstr "diduga %<{%>"
 msgid "expected %<.%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -3936,31 +3936,31 @@ msgstr "diduga %<,%> atau %<,%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "diduga %<=%>"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 #, fuzzy
 #| msgid "<anonymous>"
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -3979,13 +3979,13 @@ msgstr "Diduga nama"
 msgid "candidate:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 #| msgid "type %qs has a user-defined constructor"
 msgid "  after user-defined conversion:"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -3993,19 +3993,19 @@ msgid_plural "candidates are:"
 msgstr[0] "kandidat 1:"
 msgstr[1] "kandidat 1:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "lompat ke label %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "lompat ke case label"
 
@@ -4265,35 +4265,35 @@ msgstr "%Hvariabel lokal %qD mungkin tidak muncul dalam konteks ini"
 msgid "local variable %qD may not appear in this context"
 msgstr "%Hvariabel lokal %qD mungkin tidak muncul dalam konteks ini"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 #, fuzzy
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 #| msgid "forming %s to reference type %qT"
 msgid "%<using enum%> of dependent type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 #| msgid "%Jcase value %qs not in enumerated type %qT"
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%J nilai case %qs tidak dalam tipe enumerasi %qT"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "penggunaan tidak valid dari typedef tidak lengkap %qD"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "kandidat adalah:"
 
@@ -4353,54 +4353,54 @@ msgstr "konversi ke %qT mengubah nilai konstanta %qT"
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tipe argumen salah ke unary minus"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "tipe argumen salah ke bit-complement"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "tipe argumen salah ke abs"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "tipe argumen salah ke konjugasi"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 #, fuzzy
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "no pre-increment operator for type"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 #, fuzzy
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "no pre-decrement operator for type"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4502,7 +4502,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Driving:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4638,7 +4638,7 @@ msgstr "Operator buruk"
 msgid "Bad type in constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "Tidak terduga akhir dari modul"
 
@@ -4666,11 +4666,11 @@ msgstr "blok IF"
 msgid "implied END DO"
 msgstr "Diimplikasikan END DO"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "assignment"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "assignmen penunjuk"
 
@@ -4786,177 +4786,177 @@ msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 msgid "bind(c) procedure"
 msgstr "prosedur elemental"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operan dari operator numerik unary '%s' di %%L adalah %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operan binari numerik '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operan dari string operator konkatenasi di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator logikal '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operan dari operator .not. di %%L adalah %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "kuantitas KOMPLEKS tidak dapat dibandingkan di %L"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logikal di %%L harus dibandingkan dengan %s daripada %s"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator perbandingan '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tingkat tidak konsisten untuk operator di %%L dan %%L"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 #, fuzzy
 #| msgid "%qD is not a variable"
 msgid "iterator variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ekspresi sebagai operan tidak valid"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALOKASIKAN "
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALOKASIKAN "
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, fuzzy, c-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Pajang KARAKTER berbeda (%d/%d) dalam konstruktor array di %L"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, fuzzy, c-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, fuzzy, c-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5089,30 +5089,30 @@ msgstr "Referensi array diluar cakupan"
 msgid "Incorrect function return value"
 msgstr "Nilai kembali fungsi tidak benar"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 #| msgid "Memory allocation failed"
 msgid "Error allocating %lu bytes"
 msgstr "Alokasi memori gagal"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, fuzzy, c-format
 #| msgid "Attempting to allocate already allocated array '%s'"
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "Mencoba untuk mengalokasikan array yang telah dialokasikan '%s'"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 #, fuzzy
 #| msgid "Attempting to allocate already allocatedarray"
 msgid "Attempting to allocate already allocated variable"
 msgstr "Mencoba untuk mengalokasikan array yang telah dialokasikan"
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "Mencoba untuk DEALOKASI yang tidak dialokasikan '%s'"
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -5349,17 +5349,17 @@ msgstr "-Xbind-now dan -Xbind-lazy tidak kompatibel"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "tidak boleh menggunakan bersamaan -EB dan -EL"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 #, fuzzy
 #| msgid "-msoft-float and -mhard_float may not be used together"
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-msoft-float dan -mhard_float tidak boleh digunakan bersamaan"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian dan -mlittle-endian tidak boleh digunakan bersamaan"
 
@@ -5379,8 +5379,8 @@ msgstr "tipe prosesor tidak dispesifikasikan untuk penyambungan"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "Jangan spesifikasikan baik -march=... dan -mcpu=..."
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared dan mdll tidak kompatibel"
 
@@ -5563,10 +5563,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Peringatkan mengenai pembuatan dari array sementara"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, fuzzy, no-c-format
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Does nothing. Preserved for backward compatibility."
@@ -6109,177 +6109,177 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "Set default aksesbility dari entity modul ke PRIVATE."
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, fuzzy, no-c-format
 #| msgid "Try to lay out derived types as compactly as possible"
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "Coba untuk lay out tipe turunan secara kompak mungkin"
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 #| msgid "suggest parentheses around %<>>%> expression"
 msgid "Protect parentheses in expressions."
 msgstr "disarankan tanda kurung disekeliling ekspresi %<>>%>"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, fuzzy, no-c-format
 #| msgid "Enable range checking during compilation"
 msgid "Enable range checking during compilation."
 msgstr "Aktifkan pemeriksaan jangkauan selama kompilasi"
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr ""
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, fuzzy, no-c-format
 #| msgid "Use a 4-byte record marker for unformatted files"
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Gunakan sebuah rekaman 4-byte untuk penanda untuk berkas tidak terformat"
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, fuzzy, no-c-format
 #| msgid "Use an 8-byte record marker for unformatted files"
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Gunakan sebuah rekaman 8-byte penanda untuk berkas tidak terformat"
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, fuzzy, no-c-format
 #| msgid "Allocate local variables on the stack to allow indirect recursion"
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr "Alokasikan lokal variabal di stack untuk mengijinkan indirek rekursi"
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, fuzzy, no-c-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "Salin bagian array kedalam sebuah blok kontinu dalam masukan prosedur"
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, fuzzy, no-c-format
 #| msgid "Append a second underscore if the name already contains an underscore"
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "Tambahkan seuah garis bawah kedua jika nama telah berisi sebuah garis bawah"
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, fuzzy, no-c-format
 #| msgid "Apply negative sign to zero values"
 msgid "Apply negative sign to zero values."
 msgstr "Aplikasikan tanda negatif ke nilai nol"
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, fuzzy, no-c-format
 #| msgid "Append underscores to externally visible names"
 msgid "Append underscores to externally visible names."
 msgstr "Tambahkan garis bawah ke nama eksternal yang tampak"
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Tidak melakukan apa-apa. Dijaga untuk kompabilitas versi sebelumnya."
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, fuzzy, no-c-format
 #| msgid "Statically link the GNU Fortran helper library (libgfortran)"
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr "Hubungkan secara statis GNU Fortran helper perpustakaan (libgfortran)"
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Konform ke ISO Fortran 2003 standar"
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Konform ke ISO Fortran 2008 standar"
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Konform ke ISO Fortran 2008 standar"
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Konform ke ISO Fortran 2008 standar"
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 95 standard"
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Konform ke ISO Fortran 95 standar"
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, fuzzy, no-c-format
 #| msgid "Conform to nothing in particular"
 msgid "Conform to nothing in particular."
 msgstr "Konform ke bukan siapa siapa yang berkepentingan"
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, fuzzy, no-c-format
 #| msgid "Accept extensions to support legacy code"
 msgid "Accept extensions to support legacy code."
@@ -7049,7 +7049,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7749,8 +7749,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, fuzzy, no-c-format
 #| msgid "switch %qs is no longer supported"
 msgid "No longer supported."
@@ -8140,550 +8140,545 @@ msgid "Specify default OpenACC compute dimensions."
 msgstr ""
 
 #: c-family/c.opt:1878
-#, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
 #, fuzzy, no-c-format
 #| msgid "Enable OpenMP (implies -frecursive in Fortran)"
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "Aktifkan OpenMP (mengindikasikan -frecursive dalam Fortran)"
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, fuzzy, no-c-format
 #| msgid "Unclassifiable OpenMP directive at %C"
 msgid "Enable OpenMP's SIMD directives."
 msgstr "Direktif OpenMP tidak terklasifikasi di %C"
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, fuzzy, no-c-format
 #| msgid "Recognize C++ keywords like \"compl\" and \"xor\""
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "Kenali kata kunci C++ seperti \"compl\" dan \"xor\""
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, fuzzy, no-c-format
 #| msgid "Look for and use PCH files even when preprocessing"
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "Lihat untuk dan gunakan berkas PCH walaupun ketika preproses"
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, fuzzy, no-c-format
 #| msgid "Downgrade conformance errors to warnings"
 msgid "Downgrade conformance errors to warnings."
 msgstr "Downgrade konformance errors ke peringatan"
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, fuzzy, no-c-format
 #| msgid "Enable linker relaxations"
 msgid "Enable Plan 9 language extensions."
 msgstr "Aktifkan penghubung relaksasi"
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, fuzzy, no-c-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "Treat the input file as already preprocessed."
 msgstr "Perlakukan berkas masukan seperti sudah terproses"
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, fuzzy, no-c-format
 #| msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime"
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "Gunakan dalam mode Fix-and-Continue untuk mengindikasikan bahwa berkas objek mungkin ditukar pada waktu waktu-jalan"
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "Ditinggalkan. Pilihan ini tidak memiliki efek"
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, fuzzy, no-c-format
 #| msgid "Generate run time type descriptor information"
 msgid "Generate run time type descriptor information."
 msgstr "Hasilkan informasi tipe deskripsi waktu jalan"
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, fuzzy, no-c-format
 #| msgid "Use the narrowest integer type possible for enumeration types"
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "Gunakan tipe integer terkecil jika memungkinkan untuk tipe enumerasi"
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\""
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "Paksa tipe underlying untuk \"wchar_t\" untuk menjadi \"unsigned short\""
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "Ketika \"signed\" atau \"unsigned\" tidak diberikan buat bitfield signed"
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, fuzzy, no-c-format
 #| msgid "Make \"char\" signed by default"
 msgid "Make \"char\" signed by default."
 msgstr "Buat \"char\" signed secara baku"
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, fuzzy, no-c-format
 #| msgid "Enable decimal floating point hardware support"
 msgid "Enable C++14 sized deallocation support."
 msgstr "Aktifkan dukungan perangkat keras desimal titik pecahan"
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, fuzzy, no-c-format
 #| msgid "Display statistics accumulated during compilation"
 msgid "Display statistics accumulated during compilation."
 msgstr "Tampilkan statistik yang diakumulasikan selama kompilasi"
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop"
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "Jumlah maksimum dari pembukaan dari sebuah loop tunggal"
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, fuzzy, no-c-format
 #| msgid "Specify maximum template instantiation depth"
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "Spesifikasikan kedalaman maksimum template instantiation"
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, fuzzy, no-c-format
 #| msgid "Do not generate thread-safe code for initializing local statics"
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "Jangan hasilkan kode thread-safe untuk menginisialisasi lokasi statics"
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "Ketika \"signed\" atau \"unsigned\" tidak diberikan buat bitfield unsigned"
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, fuzzy, no-c-format
 #| msgid "Make \"char\" unsigned by default"
 msgid "Make \"char\" unsigned by default."
 msgstr "Buat \"char\" unsigned secara baku"
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, fuzzy, no-c-format
 #| msgid "Use __cxa_atexit to register destructors"
 msgid "Use __cxa_atexit to register destructors."
 msgstr "Gunakan __cxa_atexit untuk register destructors"
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, fuzzy, no-c-format
 #| msgid "Use __cxa_get_exception_ptr in exception handling"
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "Gunakan __cxa_get_exception_ptr dalam penanganan exception"
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, fuzzy, no-c-format
 #| msgid "Marks all inlined methods as having hidden visibility"
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "Tandai seluruh metoda inline sebagai memiliki visibility tersembunyi"
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, fuzzy, no-c-format
 #| msgid "Changes visibility to match Microsoft Visual Studio by default"
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "Perubahan visibility supaya cocok dengan Microsoft Visual Studio secara baku"
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Emit common-like symbols as weak symbols"
 msgid "Emit common-like symbols as weak symbols."
 msgstr "Keluarkan simbol common-like sebagai simbol lemah"
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, fuzzy, no-c-format
 #| msgid "Convert all wide strings and character constants to character set <cset>"
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "Ubah seluruh konstanta string dan karakter lebar ke set karakter <cset>"
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, fuzzy, no-c-format
 #| msgid "Generate a #line directive pointing at the current working directory"
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "Hasilkan sebuah #line direktif menunjuk ke direktori kerja sekarang"
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, fuzzy, no-c-format
 #| msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode"
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "Hasilkan pencarian class malas (melalui objc_getClass()) untuk digunakan dalam mode Zero-Link"
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Dump declarations to a .decl file"
 msgid "Dump declarations to a .decl file."
 msgstr "Dump deklarasi ke sebuah berkas .decl"
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, fuzzy, no-c-format
 #| msgid "Aggressive reduced debug info for structs"
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "Secara agresif reduksi informasi debug untuk structs"
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, fuzzy, no-c-format
 #| msgid "Conservative reduced debug info for structs"
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "Secara konservatif reduksi informasi debug untuk structs"
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, fuzzy, no-c-format
 #| msgid "Detailed reduced debug info for structs"
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "Secara detail reduksi informasi debug untuk struct"
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the system include path"
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "Tambahkan <dir> ke akhir dari jalur include sistem"
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, fuzzy, no-c-format
 #| msgid "Accept definition of macros in <file>"
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "Terima definisi dari makro dalam <berkas>"
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-multilib <dir> Set <dir> untuk menjadi multilib inlude subdirektori"
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, fuzzy, no-c-format
 #| msgid "Include the contents of <file> before other files"
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "Masukan isi dari <berkas> sebelum berkas lainnya"
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, fuzzy, no-c-format
 #| msgid "Specify <path> as a prefix for next two options"
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "Spesifikasikan <jalur> sebagai sebuah prefix untuk dua pilihan berikutnya"
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, fuzzy, no-c-format
 #| msgid "Set <dir> to be the system root directory"
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "Set <dir> untuk menjadi sistem root direktori"
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the start of the system include path"
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "Tambahkan <dir> ke awal dari jalur include sistem"
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the quote include path"
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "Tambahkan <dir> ke akhir dari jalur include quote"
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the system include path"
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "Tambahkan <dir> ke akhir dari jalur include sistem"
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the main include path"
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "Tambahkan <dir> ke akhir dari jalur include utama"
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories (those specified with -isystem will still be used)"
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "Jangan cari standar sistem include direktori (yang dispesifikasikan dengan -isystem akan tetap digunakan)"
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories for C++"
 msgid "Do not search standard system include directories for C++."
 msgstr "Jangan cari standar sistem inlude direktori untuk C++"
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, fuzzy, no-c-format
 #| msgid "Generate C header of platform-specific features"
 msgid "Generate C header of platform-specific features."
 msgstr "Hasilkan C header dari platform-spesifik features"
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, fuzzy, no-c-format
 #| msgid "Remap file names when including files"
 msgid "Remap file names when including files."
 msgstr "Peta ulang nama berkas ketiak memasukan berkas"
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Konform ke standar ISO 1998 C++ dengan ekstensi GNU"
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Konform ke standar ISO 1998 C++"
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Ditinggalkan untuk menghargai -std=c99"
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Ditinggalkan untuk menghargai -std=c99"
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Konform ke standar ISO 1998 C++"
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++17."
 msgstr "Ditinggalkan untuk menghargai -std=c99"
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "Konform ke standar ISO 1998 C++"
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Konform ke standar ISO 1998 C++ dengan ekstensi GNU"
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard, with extensions that are likely to"
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Konform ke standar ISO 1998 C++, dengan ekstensi yang sama sepertinya"
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Konform ke standar ISO 1990 C"
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c11."
 msgstr "Ditinggalkan untuk menghargai -std=c99"
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Konform ke ISO 1990 C standar seperti ditambahkan dalam 1994"
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Konform ke ISO 1990 C standar seperti ditambahkan dalam 1994"
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Konform ke standar ISO 1990 C"
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard"
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Konform ke standar ISO 1999 C"
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c99."
 msgstr "Ditinggalkan untuk menghargai -std=c99"
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Konform ke standar ISO 1998 C++ dengan ekstensi GNU"
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Konform ke standar ISO 1998 C++ dengan ekstensi GNU"
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Ditinggalkan untuk menghargai dari -std=gnu99"
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Ditinggalkan untuk menghargai dari -std=gnu99"
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Konform ke standar ISO 1998 C++ dengan ekstensi GNU"
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "Ditinggalkan untuk menghargai dari -std=gnu99"
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "Konform ke standar ISO 1998 C++ dengan ekstensi GNU"
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard, with GNU extensions and"
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Konform ke standar ISO 1998 C++, dengan ekstensi GNU dan"
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard, with GNU extensions and"
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Konform ke standar ISO 1998 C++, dengan ekstensi GNU dan"
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Konform ke standar ISO 1990 C dengan ekstensi GNU"
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Ditinggalkan untuk menghargai dari -std=gnu99"
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Konform ke standar ISO 1990 C dengan ekstensi GNU"
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard, with GNU extensions and"
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Konform ke standar ISO 1998 C++, dengan ekstensi GNU dan"
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Konform ke standar ISO 1990 C dengan ekstensi GNU"
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard with GNU extensions"
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Konform ke standar ISO 1999 C dengan ekstensi GNU"
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Ditinggalkan untuk menghargai dari -std=gnu99"
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Konform ke ISO 1990 C standar seperti ditambahkan dalam 1994"
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=iso9899:1999"
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Ditinggalkan untuk menghargai -std=iso9899:1999"
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable traditional preprocessing."
 msgstr "Aktifkan preprosesing tradisional"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, fuzzy, no-c-format
 #| msgid "Support ISO C trigraphs"
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "Dukung ISO C trigraphs"
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Do not predefine system-specific and GCC-specific macros"
 msgid "Do not predefine system-specific and GCC-specific macros."
@@ -8946,6 +8941,12 @@ msgstr "Kompile dengan mode 32-bit integer"
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+#| msgid "Emit implicit instantiations of templates"
+msgid "Emit template instantiations as weak symbols."
+msgstr "Keluarkan implisit instantionation dari templates"
+
 #: d/lang.opt:346
 #, fuzzy, no-c-format
 #| msgid "Do not assume that standard C libraries and \"main\" exist"
@@ -10295,156 +10296,170 @@ msgstr "Dukung lebih dari 8192 GOT masukan di ColdFire"
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as big endian"
+msgid "Assume target CPU is configured as big endian."
+msgstr "Asumsikan target CPU dikonfigurasikan sebagai big endian"
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as little endian"
+msgid "Assume target CPU is configured as little endian."
+msgstr "Asumsikan target CPU dikonfigurasikan sebagai little endian"
+
+#: config/riscv/riscv.opt:34
 #, fuzzy, no-c-format
 #| msgid "Set the cost of branches to roughly COST instructions"
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "Set biaya dari percabangan ke seluruh BIAYA instruksi"
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, fuzzy, no-c-format
 #| msgid "When generating -mabicalls code, allow executables to use PLTs and copy relocations"
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr "Ketika menghasilkan kode -mabicalls, ijinkan executables untuk menggunakan PLT dan salin relokasi"
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 #| msgid "Alternate calling convention"
 msgid "Specify integer and floating-point calling convention."
 msgstr "Konvensi pemanggilan alternatif"
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, fuzzy, no-c-format
 #| msgid "Attempt to keep stack aligned to this power of 2"
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Mencoba untuk menyimpan stack aligned ke kelipatan dari 2"
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 #| msgid "Allow the use of hardware floating-point ABI and instructions"
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Ijinkan penggunaan dari ABI dan instruksi perangkat keras titik pecahan"
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 #| msgid "Use trap instructions to check for integer divide by zero"
 msgid "Use hardware instructions for integer division."
 msgstr "Gunakan trap instruksi untuk memeriksa untuk integer dibagi dengan nol"
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, fuzzy, no-c-format
 #| msgid "Optimize the output for PROCESSOR"
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "Optimasi keluaran untuk PROSESOR"
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 #| msgid "Optimize the output for PROCESSOR"
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "Optimasi keluaran untuk PROSESOR"
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, fuzzy, no-c-format
 #| msgid "Put global and static data smaller than <number> bytes into a special section (on some targets)"
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "Letakan global dan statis data lebih kecil dari <jumlah> bytes kedalam sebuah daerah spesial (dalam beberapa targets)"
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "Gunakan subroutines untuk fungsi prolog dan epilog"
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, fuzzy, no-c-format
 #| msgid "Specify the target CPU"
 msgid "Specify the code model."
 msgstr "Spesifikasikan target CPU"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 #| msgid "Do not use unaligned memory references"
 msgid "Do not generate unaligned memory accesses."
 msgstr "Jangan gunakan tidak teralign referensi memori"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, fuzzy, no-c-format
 #| msgid "Do not tune writable data alignment"
 msgid "Use the given data alignment."
 msgstr "Jangan tune writable data alignmen"
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr ""
@@ -10585,13 +10600,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as big endian"
-msgid "Assume target CPU is configured as big endian."
-msgstr "Asumsikan target CPU dikonfigurasikan sebagai big endian"
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 #| msgid "Generate code which uses hardware floating point instructions"
@@ -10613,13 +10621,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as little endian"
-msgid "Assume target CPU is configured as little endian."
-msgstr "Asumsikan target CPU dikonfigurasikan sebagai little endian"
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -18792,2443 +18793,2443 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "Set berkas nama dasar yang akan digunakan untuk dumps"
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "Align awal dari fungsi"
 
-#: common.opt:988
+#: common.opt:992
 #, fuzzy, no-c-format
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "Align labels yang hanya dicapai dengan melompat"
 
-#: common.opt:995
+#: common.opt:999
 #, fuzzy, no-c-format
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "Align seluruh labels"
 
-#: common.opt:1002
+#: common.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "Align awal dari loops"
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable static analysis pass."
 msgstr "Aktifkan preprosesing tradisional"
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, fuzzy, no-c-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Pilihan ini sudah ditinggalkan; lebih baik gunakan -Wextra"
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, fuzzy, no-c-format
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Hasilkan tabel unwind yang tepat di setiap batasan instruksi"
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 #| msgid "Generate auto-inc/dec instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "Hasilkan instruksi auto-inc/dec"
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Hasilkan kode untuk memeriksa batasan sebelum array pengindeksan"
 
-#: common.opt:1091
+#: common.opt:1095
 #, fuzzy, no-c-format
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Gantikan tambah, banding, cabang dengan cabang di jumlah register"
 
-#: common.opt:1095
+#: common.opt:1099
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "Gunakan informasi profiling untuk setiap kemungkinan percabangan"
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 #| msgid "Emit call graph information"
 msgid "Output callgraph information on a per-file basis."
 msgstr "Keluarkan informasi graphik panggilan"
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr ""
 
-#: common.opt:1119
+#: common.opt:1123
 #, fuzzy, no-c-format
 #| msgid "Mark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "Tandai <register> sebagai telah disimpan dalam fungsi"
 
-#: common.opt:1123
+#: common.opt:1127
 #, fuzzy, no-c-format
 #| msgid "Mark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "Tandai <register> sebagai telah terkorupsi oleh pemanggilan fungsi"
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "Simpan register dalam pemanggilan fungsi"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy, no-c-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "Pilihan ini sudah ditinggalkan; lebih baik gunakan -Wextra"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy, no-c-format
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "Periksa nilai kembali dari new"
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, fuzzy, no-c-format
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "kegagalan konsistensi internal"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "Aktifkan profiling fungsi"
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Put uninitialized globals in the common section."
 msgstr "Jangan letakan tidak terinisialisasi global dalam daerah umum"
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Lakukan penghapusan global common subexpression setelah alokasi register"
 
-#: common.opt:1178
+#: common.opt:1182
 #, fuzzy, no-c-format
 #| msgid "Do not perform optimizations increasing noticeably stack usage"
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "Jangan lakukan optimisasi semakin meningkat dapat dinotifikasi penggunaan stack"
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy, no-c-format
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Lakukan sebuah register tahap optimisasi copy-propagation"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy, no-c-format
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "Lakukan optimisasi cross-jumping"
 
-#: common.opt:1190
+#: common.opt:1194
 #, fuzzy, no-c-format
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Ketika menjalankan CSE, ikuti jump ke targetnya"
 
-#: common.opt:1198
+#: common.opt:1202
 #, fuzzy, no-c-format
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "Abaikan tahap reduksi jangkauan ketika menjalankan pembagian kompleks"
 
-#: common.opt:1202
+#: common.opt:1206
 #, fuzzy, no-c-format
 #| msgid "Complex multiplication and division follow Fortran rules"
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Perkalian dan pembagian kompleks mengikuti aturan Fortran"
 
-#: common.opt:1206
+#: common.opt:1210
 #, fuzzy, no-c-format
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "Tempatkan data item kedalam daerah mereka"
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Daftar seluruh debugging counter yang tersedia dengan batasan dan jumlah mereka"
 
-#: common.opt:1214
+#: common.opt:1218
 #, fuzzy, no-c-format
 #| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]    Set the debug counter limit.   "
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]    Set the debug counter batas.   "
 
-#: common.opt:1218
+#: common.opt:1222
 #, fuzzy, no-c-format
 #| msgid "Map one directory name to another in debug information"
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr "Petakan satu nama direktori ke yang lainnya dalam informasi debug"
 
-#: common.opt:1222
+#: common.opt:1226
 #, fuzzy, no-c-format
 #| msgid "Map one directory name to another in debug information"
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr "Petakan satu nama direktori ke yang lainnya dalam informasi debug"
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, fuzzy, no-c-format
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "Defer popping fungsi args dari stack sampai kemudian"
 
-#: common.opt:1236
+#: common.opt:1240
 #, fuzzy, no-c-format
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Coba untuk mengisi delay slot dalam instruksi percabangan"
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, fuzzy, no-c-format
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "Hapus ketidak bergunaan pemeriksaan penunjuk kosong"
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, fuzzy, no-c-format
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization."
 msgstr "Lakukan formasi superblok melalaui duplikasi tail"
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, fuzzy, no-c-format
 #| msgid "How often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "Seberapa sering mengeluarkan sumber lokasi di awal dari baris-wrapped diagnosa"
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, fuzzy, no-c-format
 #| msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Tambahkan pesan diagnosa yang sesuai dengan pilihan baris perintah yang mengontrolnya"
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, fuzzy, no-c-format
 #| msgid "Distance between tab stops for column reporting"
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "Jarak diantara tab stop untuk pelaporan kolom"
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, fuzzy, no-c-format
 #| msgid "Dump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "Dump beberapa kompiler internal ke sebuah berkas"
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, fuzzy, no-c-format
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Tekan keluaran dari alamat dalam dump debugging"
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, fuzzy, no-c-format
 #| msgid "Do the full register move optimization pass"
 msgid "Dump optimization passes."
 msgstr "Lakukan tahap optimisasi register penuh"
 
-#: common.opt:1455
+#: common.opt:1459
 #, fuzzy, no-c-format
 #| msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Tekan keluaran dari jumlah instruksi, catatan nomor baris dan alamat dalam debugging dumps"
 
-#: common.opt:1459
+#: common.opt:1463
 #, fuzzy, no-c-format
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Tekan keluaran dari alamat dalam dump debugging"
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Aktfikan tabel CFI melalui direktif perakit GAS."
 
-#: common.opt:1467
+#: common.opt:1471
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "Lakukan inlining awal"
 
-#: common.opt:1475
+#: common.opt:1479
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1479
+#: common.opt:1483
 #, fuzzy, no-c-format
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Lakukan penghapusan tidak tidak digunakan dalam informasi debug"
 
-#: common.opt:1483
+#: common.opt:1487
 #, fuzzy, no-c-format
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "Lakukan penghapusan tidak tidak digunakan dalam informasi debug"
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "Jangan tekan informasi debug C++ class."
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Aktifkan penanganan eksepsi"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy, no-c-format
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Lakukan beberapa dari minor, ekspensi optimisasi"
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, fuzzy, no-c-format
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Asumsikan tidak ada NaN atau tidak terhingga dihasilkan"
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, fuzzy, no-c-format
 #| msgid "Mark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "Tandai <register> sebagai tidak tersedia ke kompiler"
 
-#: common.opt:1546
+#: common.opt:1550
 #, fuzzy, no-c-format
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Jangan alokasikan float dan double dalam register presisi ekstended"
 
-#: common.opt:1554
+#: common.opt:1558
 #, fuzzy, no-c-format
 #| msgid "Perform a forward propagation pass on RTL"
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Lakukan sebuah tahap propagasi ke depan dalam RTL"
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, fuzzy, no-c-format
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "Ijinkan alamat fungsi untuk disimpan dalam register"
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "Tempatkan setiap fungsi kedalam daerahnya masing-masing"
 
-#: common.opt:1590
+#: common.opt:1594
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "Lakukan penghapusan global comman subexpression"
 
-#: common.opt:1594
+#: common.opt:1598
 #, fuzzy, no-c-format
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Lakukan penghapusan enhanced load motion selama global common subexpression"
 
-#: common.opt:1598
+#: common.opt:1602
 #, fuzzy, no-c-format
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Lakukan store motion setelah penghapusan global common subexpression"
 
-#: common.opt:1602
+#: common.opt:1606
 #, fuzzy, no-c-format
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Lakukan redundansi load setelah penghapusan store dalam global common subexpressionn"
 
-#: common.opt:1607
+#: common.opt:1611
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Lakukan penghapusan global common subexpression setelah alokasi register"
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, fuzzy, no-c-format
 #| msgid "Enable in and out of Graphite representation"
 msgid "Enable in and out of Graphite representation."
 msgstr "Aktifkan in dan keluar dari representasi Graphite"
 
-#: common.opt:1633
+#: common.opt:1637
 #, fuzzy, no-c-format
 #| msgid "Enable Graphite Identity transformation"
 msgid "Enable Graphite Identity transformation."
 msgstr "Aktifkan transformasi Graphite Identify"
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "Aktifkan penyalinan loop header pada pohon"
 
-#: common.opt:1667
+#: common.opt:1671
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "Lakukan penguraian loop untuk semua loops"
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, fuzzy, no-c-format
 #| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "Aktifkan optimisasi label alignmen"
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, fuzzy, no-c-format
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "Aktifkan penerkaan kemungkinan dari percabangan"
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "Proses #ident direktif"
 
-#: common.opt:1707
+#: common.opt:1711
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Lakukan konversi dari kondisional jump ke branchless ekuivalen"
 
-#: common.opt:1711
+#: common.opt:1715
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Lakukan konversi dari kondisional lompat ke kondisional eksekusi"
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Lakukan konversi dari kondisional jump ke branchless ekuivalen"
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "Jangan hasilkan direktif .size"
 
-#: common.opt:1747
+#: common.opt:1751
 #, fuzzy, no-c-format
 #| msgid "Perform indirect inlining"
 msgid "Perform indirect inlining."
 msgstr "Lakukan inlining tidak langsung"
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, fuzzy, no-c-format
 #| msgid "Integrate simple functions into their callers when code size is known to not growth"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Integrasikan fungsi sederhana kedalam pemanggilnya ketika ukuran kode diketahui tidak berkembang"
 
-#: common.opt:1761
+#: common.opt:1765
 #, fuzzy, no-c-format
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Integrasikan fungsi dipanggil sekali dalam pemanggilnya"
 
-#: common.opt:1765
+#: common.opt:1769
 #, fuzzy, no-c-format
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "Integrasikan fungsi dipanggil sekali dalam pemanggilnya"
 
-#: common.opt:1772
+#: common.opt:1776
 #, fuzzy, no-c-format
 #| msgid "Limit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "Batasi ukuran dari fungsi diinline ke <angka>"
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, fuzzy, no-c-format
 #| msgid "Instrument function entry and exit with profiling calls"
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Instrumen fungsi masukan dan keluaran dengan profiling panggilan"
 
-#: common.opt:1810
+#: common.opt:1814
 #, fuzzy, no-c-format
 #| msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "-finstrumen-functions-exclude-function-list=name,... jangan instrumen fungsi yang terdaftar"
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, no-c-format
 #| msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=filename,... Jangan instrumen fungsi yang terdaftar dalam berkas"
 
-#: common.opt:1818
+#: common.opt:1822
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1822
+#: common.opt:1826
 #, fuzzy, no-c-format
 #| msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Lakukan cloning untuk membuat propagasi konstanta lebih kuat antar prosedur"
 
-#: common.opt:1830
+#: common.opt:1834
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1834
+#: common.opt:1838
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform interprocedural modref analysis."
 msgstr "Lakukan analisa interprosedural titik-ke"
 
-#: common.opt:1838
+#: common.opt:1842
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural profile propagation."
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1842
+#: common.opt:1846
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform interprocedural points-to analysis."
 msgstr "Lakukan analisa interprosedural titik-ke"
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "Temukan fungsi pure dan const"
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only and non addressable static variables."
 msgstr "Temukan baca-saja dan variabel statis tidak beralamat"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "Temukan baca-saja dan variabel statis tidak beralamat"
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "Lakukan Propagasi Jangkauan Nilai pada pohon"
 
-#: common.opt:1886
+#: common.opt:1890
 #, fuzzy, no-c-format
 #| msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fire-algorithm=[CB|prioritas] Set penggunaan algoritma IRA"
 
-#: common.opt:1899
+#: common.opt:1903
 #, fuzzy, no-c-format
 #| msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] Set daerah untuk IRA"
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr "Share slots untuk menyimpan register keras berbeda."
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Share stack slots untuk spilled pseudo-register."
 
-#: common.opt:1933
+#: common.opt:1937
 #, fuzzy, no-c-format
 #| msgid "-fira-verbose=<number> Control IRA's level of diagnostic messages."
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<angka>  Kontrol tingkat dari pesan diagnosa IRA."
 
-#: common.opt:1937
+#: common.opt:1941
 #, fuzzy, no-c-format
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "Optimasi variabel induksi dalam pohon"
 
-#: common.opt:1941
+#: common.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Gunakan tabel jump untuk pernyataan secara mencukupi besar switch"
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "Gunakan tabel jump untuk pernyataan secara mencukupi besar switch"
 
-#: common.opt:1949
+#: common.opt:1953
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Hasilkan kode untuk fungsi walaupun jika mereka secara penuh inlined"
 
-#: common.opt:1953
+#: common.opt:1957
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "Hasilkan kode untuk fungsi walaupun jika mereka secara penuh inlined"
 
-#: common.opt:1957
+#: common.opt:1961
 #, fuzzy, no-c-format
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "Keluarkan variabel statis const walapu mereka tidak digunakan"
 
-#: common.opt:1961
+#: common.opt:1965
 #, fuzzy, no-c-format
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "Berikan eksternal simbol sebuah awalan garis bawah"
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Aktifkan optimasi penghubung"
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "Set errno setelah fungsi matematik bawaan"
 
-#: common.opt:2024
+#: common.opt:2028
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "Jumlah maksimum dari error untuk dilaporkan"
 
-#: common.opt:2028
+#: common.opt:2032
 #, fuzzy, no-c-format
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "Laporkan pada alokasi memori permanen"
 
-#: common.opt:2032
+#: common.opt:2036
 #, fuzzy, no-c-format
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Laporkan pada alokasi memori permanen"
 
-#: common.opt:2039
+#: common.opt:2043
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Mencoba menggabungkan konstanta identik dan konstanta variabel"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Mencoba menggabungkan konstanta identik melewati satuan kompilasi"
 
-#: common.opt:2047
+#: common.opt:2051
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical debug strings across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Mencoba untuk menggabungkan debug string identik across satuan kompilasi"
 
-#: common.opt:2051
+#: common.opt:2055
 #, fuzzy, no-c-format
 #| msgid "Limit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "Batasi diagnosa sampai <number> karakter per baris. 0 tekan line-wrapping"
 
-#: common.opt:2055
+#: common.opt:2059
 #, fuzzy, no-c-format
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Lakukan penjadwalan berdasarkan SMS modulo sebelum tahap penjadwalan pertama"
 
-#: common.opt:2059
+#: common.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Lakukan penjadwalan berdasarkan module SMS dengan perpindahan register diperbolehkan"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy, no-c-format
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "Move loop invarian komputasi diluar dari loops"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy, no-c-format
 #| msgid "Use the RTL dead code elimination pass"
 msgid "Use the RTL dead code elimination pass."
 msgstr "Gunaka tahap penghapusan RTL kode mati"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy, no-c-format
 #| msgid "Use the RTL dead store elimination pass"
 msgid "Use the RTL dead store elimination pass."
 msgstr "Gunakan tahap penghapusan RTL dead store"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy, no-c-format
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Aktifkan/Non-aktifkan penjadwalan tradisional dalam loop yang telah dilewatkan penjadwalan modulo"
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "Dukung eksepsi sinkronous bukan panggilan"
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, fuzzy, no-c-format
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "Jika memungkinkan jangan hasilkan stack frames"
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Aktifkan optimasi loop pada tingkat pohon"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, fuzzy, no-c-format
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimisasi sibling dan tail rekursi calls"
 
-#: common.opt:2124
+#: common.opt:2128
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform partial inlining."
 msgstr "Lakukan inlining awal"
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, fuzzy, no-c-format
 #| msgid "Report on memory allocation before interprocedural optimization"
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Laporkan dalam alokasi memori sebelum optimisasi interprosedural"
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy, no-c-format
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "Pack anggota struktur bersama tanpa lubang"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy, no-c-format
 #| msgid "Set initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "Set inisial maksimal alignmen anggota struktur"
 
-#: common.opt:2144
+#: common.opt:2148
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "Kembali agregate kecil dalam memori, bukan register"
 
-#: common.opt:2148
+#: common.opt:2152
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "Lakukan loop peeling"
 
-#: common.opt:2152
+#: common.opt:2156
 #, fuzzy, no-c-format
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "Aktifkan mesin spesifik peephole optimisasi"
 
-#: common.opt:2156
+#: common.opt:2160
 #, fuzzy, no-c-format
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Aktifkan sebuah tahap RTL peephole sebelum sched2"
 
-#: common.opt:2160
+#: common.opt:2164
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Hasilkan kode bebas posisi jika memungkinkan (mode besar)"
 
-#: common.opt:2164
+#: common.opt:2168
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Hasilkan kode bebas posisi untuk executables jika memungkinkan (mode besar)"
 
-#: common.opt:2168
+#: common.opt:2172
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Hasilkan kode bebas posisi jika memungkinkan (mode kecil)"
 
-#: common.opt:2172
+#: common.opt:2176
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Hasilkan kode bebas posisi untuk executables jika memungkinkan (mode kecil)"
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, fuzzy, no-c-format
 #| msgid "Specify options to GNAT"
 msgid "Specify a plugin to load."
 msgstr "Spesifikasikan pilihan ke GNAT"
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr "Jalankan optimisasi prediktif commoning."
 
-#: common.opt:2192
+#: common.opt:2196
 #, fuzzy, no-c-format
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Hasilkan instruksi prefetch, jika tersedia, untuk array dalam loops"
 
-#: common.opt:2196
+#: common.opt:2200
 #, fuzzy, no-c-format
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "Aktifkan aplikasi dasar profiling kode"
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, fuzzy, no-c-format
 #| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "Masukan aplikasi berbasis arc profiling kode"
 
-#: common.opt:2208
+#: common.opt:2212
 #, fuzzy, no-c-format
 #| msgid "Set the top-level directory for storing the profile data."
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Set direktori tingkat atas untuk menyimpan data profile."
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy, no-c-format
 #| msgid "Set the top-level directory for storing the profile data."
 msgid "Select the name for storing the profile note file."
 msgstr "Set direktori tingkat atas untuk menyimpan data profile."
 
-#: common.opt:2217
+#: common.opt:2221
 #, fuzzy, no-c-format
 #| msgid "Enable correction of flow inconsistent profile data input"
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Aktifkan koreksi dari alur profile tidak konsisten masukan data"
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, fuzzy, no-c-format
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Aktifkan pilihan umum untuk menghasilkan informasi profile untuk feedback profile direkted optimisasi"
 
-#: common.opt:2269
+#: common.opt:2273
 #, fuzzy, no-c-format
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Aktifkan pilihan umum untuk menghasilkan informasi profile untuk feedback profile direkted optimisasi, dan set -fprofile-dir="
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, fuzzy, no-c-format
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Aktifkan pilihan umum untuk melakukan profile feedback directed optimisasi"
 
-#: common.opt:2289
+#: common.opt:2293
 #, fuzzy, no-c-format
 #| msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Aktifkan pilihan umum untuk melakukan profile feedback directed optimisasi, dan set -fprofile-dir="
 
-#: common.opt:2293
+#: common.opt:2297
 #, fuzzy, no-c-format
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "Masukan kode untuk profile nilai dari ekspresi"
 
-#: common.opt:2297
+#: common.opt:2301
 #, fuzzy, no-c-format
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile."
 msgstr "kegagalan konsistensi internal"
 
-#: common.opt:2301
+#: common.opt:2305
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "Urutkan kembali fungsi untuk meningkatkan penempatan kode"
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 #| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "Hasilkan instruksi cld dalam fungsi prolog."
 
-#: common.opt:2312
+#: common.opt:2316
 #, fuzzy, no-c-format
 #| msgid "Make compile reproducible using <string>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "Buat kompile reproducible menggunakan <string>"
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr "Rekam pilihan baris perintah gcc dalam berkas objek."
 
-#: common.opt:2326
+#: common.opt:2330
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "Kembali kumpulan kecil dalam registers"
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "Lakukan sebuah tahap optimisasi pengubahan nama register"
 
-#: common.opt:2372
+#: common.opt:2376
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Lakukan sebuah tahap optimisasi pengubahan nama register"
 
-#: common.opt:2376
+#: common.opt:2380
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Urutkan kembali blok dasar untuk meningkatkan penempatan kode"
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks and partition into hot and cold sections"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Urutkan kembali blok dasar dan partisi kedalam daerah panas dan dingin"
 
-#: common.opt:2397
+#: common.opt:2401
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "Urutkan kembali fungsi untuk meningkatkan penempatan kode"
 
-#: common.opt:2401
+#: common.opt:2405
 #, fuzzy, no-c-format
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Tambahkan sebuah tahap penghapusan umum subexpression setelah optimisasi loop"
 
-#: common.opt:2409
+#: common.opt:2413
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Non-aktifkan optimisasi yang mengasumsikan perilaku baku pembulatan titik pecahan"
 
-#: common.opt:2413
+#: common.opt:2417
 #, fuzzy, no-c-format
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "Aktifkan penjadwalan melewati blok dasar"
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "Ijinkan perpindahan spekulasi dari bukan loads"
 
-#: common.opt:2425
+#: common.opt:2429
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "Ijinkan perpindahan spekulasi dari beberapa loads"
 
-#: common.opt:2429
+#: common.opt:2433
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "Ijinkan spekulasi motion dari beberapa loads"
 
-#: common.opt:2433
+#: common.opt:2437
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "Set tingkat verbositas dari penjadwal"
 
-#: common.opt:2437
+#: common.opt:2441
 #, fuzzy, no-c-format
 #| msgid "If scheduling post reload, do superblock scheduling"
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Jika penjadwalan post reload, lakukan penjadwalan superblok"
 
-#: common.opt:2445
+#: common.opt:2449
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "Atur penjadwalan instruksi sebelum alokasi register"
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "Atur penjadwalan instruksi setelah alokasi register"
 
-#: common.opt:2456
+#: common.opt:2460
 #, fuzzy, no-c-format
 #| msgid "Schedule instructions using selective scheduling algorithm"
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Instruksi penjadwalan menggunakan algoritma penjadwalan selektif"
 
-#: common.opt:2460
+#: common.opt:2464
 #, fuzzy, no-c-format
 #| msgid "Run selective scheduling after reload"
 msgid "Run selective scheduling after reload."
 msgstr "Jalankan penjadwalan selektif setelah reload"
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, fuzzy, no-c-format
 #| msgid "Perform software pipelining of inner loops during selective scheduling"
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Lakukan software pipelining dari loops dalam selama penjadwalan selektif"
 
-#: common.opt:2472
+#: common.opt:2476
 #, fuzzy, no-c-format
 #| msgid "Perform software pipelining of outer loops during selective scheduling"
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Lakukan software pipelining dari loops luar selama penjadwalan selektif"
 
-#: common.opt:2476
+#: common.opt:2480
 #, fuzzy, no-c-format
 #| msgid "Reschedule pipelined regions without pipelining"
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Reschedule daerah pipelined tanpa pipelining"
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy, no-c-format
 #| msgid "Allow premature scheduling of queued insns"
 msgid "Allow premature scheduling of queued insns."
 msgstr "Ijinkan premature penjadwalan dari antrian instruksi"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy, no-c-format
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "Set jumlah dari antrian instruksi yang dapat secara permature dijadwalkan"
 
-#: common.opt:2498
+#: common.opt:2502
 #, fuzzy, no-c-format
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Set dependence pemeriksaan jarak dalam premature penjadwalan dari antrian instruksi"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy, no-c-format
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "Set dependence pemeriksaan jarak dalam premature penjadwalan dari antrian instruksi"
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Set tingkat verbositas dari penjadwal"
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 #, fuzzy, no-c-format
 #| msgid "Access data in the same section from shared anchor points"
 msgid "Access data in the same section from shared anchor points."
 msgstr "Akses data dalam daerah sama dari titik achor terbagi"
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy, no-c-format
 #| msgid "Show column numbers in diagnostics, when available.  Default off"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Tampilkan jumlah kolom dalam diagnosa, jika tersedia. Baku tidak aktif"
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Non-aktifkan optimisasi dilihat oleh IEEE pensinyalan NaN"
 
-#: common.opt:2563
+#: common.opt:2567
 #, fuzzy, no-c-format
 #| msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Non-aktifkan optimisasi titik pecahan yang mengabaikan IEEE signedness dari nol"
 
-#: common.opt:2567
+#: common.opt:2571
 #, fuzzy, no-c-format
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "Ubah konstanta titik pecahan ke konstanta presisi tunggal"
 
-#: common.opt:2571
+#: common.opt:2575
 #, fuzzy, no-c-format
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Bagi waktu-hidup dari variabel induksi ketika loops diunroll"
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy, no-c-format
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "Hasilkan APCS konforman stack frames"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy, no-c-format
 #| msgid "Split wide types into independent registers"
 msgid "Split wide types into independent registers."
 msgstr "Bagi tipe lebar kedalam register independent"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy, no-c-format
 #| msgid "Split wide types into independent registers"
 msgid "Split wide types into independent registers earlier."
 msgstr "Bagi tipe lebar kedalam register independent"
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy, no-c-format
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Aplikasikan ekspansi variabel ketika loops diuraikan"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Masukan pemeriksaan kode stack kedalam aplikasi"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Masukan pemeriksaan kode stack kedalam aplikasi. Sama seperti -fstack-check=specific"
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy, no-c-format
 #| msgid "Trap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "Trap jika stact pergi melampaui <register>"
 
-#: common.opt:2623
+#: common.opt:2627
 #, fuzzy, no-c-format
 #| msgid "Trap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "Trap jika stack pergi melampaui simbol <nama>"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy, no-c-format
 #| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "Gunakan propolice sebagai sebuah metode proteksi stack"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "Gunakan sebuah metode proteksi stact untuk setiap fungsi"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Gunakan sebuah metode proteksi stact untuk setiap fungsi"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Gunakan sebuah metode proteksi stact untuk setiap fungsi"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy, no-c-format
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "Reuse r30 di sebuah per fungsi dasar"
 
-#: common.opt:2655
+#: common.opt:2659
 #, fuzzy, no-c-format
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "Asumsikan aturan strict aliasing berjalan"
 
-#: common.opt:2659
+#: common.opt:2663
 #, fuzzy, no-c-format
 #| msgid "Treat signed overflow as undefined"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Perlakukan signed overflow sebagai tidak terdefinisi"
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, fuzzy, no-c-format
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "Periksa untuk sintaks errors kemudian berhenti"
 
-#: common.opt:2671
+#: common.opt:2675
 #, fuzzy, no-c-format
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "Buat sebuah berkas data dibutuhkan oleh \"gcov\""
 
-#: common.opt:2675
+#: common.opt:2679
 #, fuzzy, no-c-format
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "Lakukan optimasi jump threading"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy, no-c-format
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "Laporkan waktu yang diambil oleh setiap tahap kompiler"
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, fuzzy, no-c-format
 #| msgid "Set the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "Set mode baku pembuatan kode TLS"
 
-#: common.opt:2706
+#: common.opt:2710
 #, fuzzy, no-c-format
 #| msgid "Reorder top level functions, variables, and asms"
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Urutkan kembali fungsi tingkat atas, variabel, dan asm"
 
-#: common.opt:2710
+#: common.opt:2714
 #, fuzzy, no-c-format
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "Lakukan formasi superblok melalaui duplikasi tail"
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "Asumsikan operasi titik pecahan dapat trap"
 
-#: common.opt:2726
+#: common.opt:2730
 #, fuzzy, no-c-format
 #| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Trap untuk signed overflow dalam penambahan, pengurangan dan perkalian"
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Aktifkan optimasi SSA-CCP pada pohon"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Aktifkan optimasi SSA-CCP pada pohon"
 
-#: common.opt:2742
+#: common.opt:2746
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "Aktifkan penyalinan loop header pada pohon"
 
-#: common.opt:2750
+#: common.opt:2754
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA coalescing of user variables."
 msgstr "Aktifkan penenggelaman kode SSA pada pohon"
 
-#: common.opt:2758
+#: common.opt:2762
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "Aktifkan salin propagasi pada pohon"
 
-#: common.opt:2766
+#: common.opt:2770
 #, fuzzy, no-c-format
 #| msgid "Transform condition stores into unconditional ones"
 msgid "Transform condition stores into unconditional ones."
 msgstr "Transformasi kondisi stores kedalam tidak terkondisi satu"
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr "Lakukan konversi dari kondisional switch."
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Aktifkan optimasi penghapusan kode mati SSA pada pohon"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Aktifkan optimasi dominator"
 
-#: common.opt:2782
+#: common.opt:2786
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable tail merging on trees."
 msgstr "Aktifkan penyalinan loop header pada pohon"
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "Aktifkan penghapusan dead store"
 
-#: common.opt:2790
+#: common.opt:2794
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation on trees"
 msgid "Enable forward propagation on trees."
 msgstr "Aktifkan salin propagasi pada pohon"
 
-#: common.opt:2794
+#: common.opt:2798
 #, fuzzy, no-c-format
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Aktifkan Penghapusan Redundasi Penuh (FRE) pada pohon"
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable string length optimizations on trees."
 msgstr "Aktifkan optimasi SSA-CCP pada pohon"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 #| msgid "Enable loop distribution on trees"
 msgid "Enable loop distribution on trees."
 msgstr "Aktifkan loop distribusi pada pohon"
 
-#: common.opt:2819
+#: common.opt:2823
 #, fuzzy, no-c-format
 #| msgid "Enable loop distribution on trees"
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Aktifkan loop distribusi pada pohon"
 
-#: common.opt:2823
+#: common.opt:2827
 #, fuzzy, no-c-format
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "Aktifkan loop tidak variant pergerakan pada pohon"
 
-#: common.opt:2831
+#: common.opt:2835
 #, fuzzy, no-c-format
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "Buat variabel induksi kanonikal dalam loops"
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "Aktifkan optimasi loop pada tingkat pohon"
 
-#: common.opt:2839
+#: common.opt:2843
 #, fuzzy, no-c-format
 #| msgid "Enable automatic parallelization of loops"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "Aktifkan paralelisasi otomatis dari loops"
 
-#: common.opt:2843
+#: common.opt:2847
 #, fuzzy, no-c-format
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Aktifkan perpindahan kondisional"
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Aktifkan SSA-PRE optimisasi pada pohon"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Lakukan analisa interprosedural titik-ke"
 
-#: common.opt:2859
+#: common.opt:2863
 #, fuzzy, no-c-format
 #| msgid "Enable reassociation on tree level"
 msgid "Enable reassociation on tree level."
 msgstr "Aktifkan reasosiasi pada tingkat pohon"
 
-#: common.opt:2867
+#: common.opt:2871
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "Aktifkan penenggelaman kode SSA pada pohon"
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, fuzzy, no-c-format
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "Lakukan penggantian skalar dari kumpulan"
 
-#: common.opt:2879
+#: common.opt:2883
 #, fuzzy, no-c-format
 #| msgid "Replace temporary expressions in the SSA->normal pass"
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Gantikan ekspresi sementara dalam tahap SSA->normal"
 
-#: common.opt:2883
+#: common.opt:2887
 #, fuzzy, no-c-format
 #| msgid "Perform live range splitting during the SSA->normal pass"
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Lakukan jangkauan hidup pemisahaan selama tahap SSA->normal"
 
-#: common.opt:2887
+#: common.opt:2891
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "Lakukan Propagasi Jangkauan Nilai pada pohon"
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "Kompile seluruh satuan kompilasi di satu waktu"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Lakukan penguraian loop ketika jumlah iterasi diketahui"
 
-#: common.opt:2908
+#: common.opt:2912
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "Lakukan penguraian loop untuk semua loops"
 
-#: common.opt:2923
+#: common.opt:2927
 #, fuzzy, no-c-format
 #| msgid "Allow optimization for floating-point arithmetic which may change the"
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Ijinkan optimisasi untuk aritmetik titik pecahan dimana mungkin mengubah"
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Sama seperti -fassociative-math untuk ekspresi yang memasukan pembagian."
 
-#: common.opt:2936
+#: common.opt:2940
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Ijinkan optimisasi matematik yang mungkin melanggar standar  IEEE atau ISO"
 
-#: common.opt:2940
+#: common.opt:2944
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "Lakukan loop unswitching"
 
-#: common.opt:2944
+#: common.opt:2948
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "Lakukan loop peeling"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Buat tabel unwind untuk penanganan eksepsi"
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "Lakukan pelacakan variabel"
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Lakukan pelacakan variabel"
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Lakukan pelacakan variabel dan juga variabel tag yang tidak terinisialisasi"
 
-#: common.opt:3003
+#: common.opt:3007
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:3015
+#: common.opt:3019
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, fuzzy, no-c-format
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Tidak melakukan apa-apa. Dijaga untuk kompabilitas versi sebelumnya."
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Aktifkan propagasi penyalinan dari informasi skalar-evolusi."
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Tambahkan ekstra komentar ke keluaran perakit"
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "Gunakan nilai ekspresi profiles dalam optimisasi"
 
-#: common.opt:3111
+#: common.opt:3115
 #, fuzzy, no-c-format
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Konstruksi webs dan pisahkan penggunaan tidak berelasi dari variabel tunggal"
 
-#: common.opt:3115
+#: common.opt:3119
 #, fuzzy, no-c-format
 #| msgid "Enable conditional dead code elimination for builtin calls"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Aktifkan kondisional penghapusan kode mati untuk panggilan bawaan"
 
-#: common.opt:3119
+#: common.opt:3123
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "Lakukan optimisasi seluruh aplikasi"
 
-#: common.opt:3123
+#: common.opt:3127
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "Asumsikan perbaikan signed aritmetik overflow"
 
-#: common.opt:3127
+#: common.opt:3131
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Asumsikan perbaikan signed aritmetik overflow"
 
-#: common.opt:3131
+#: common.opt:3135
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "Tempatkan nol data terinisialisasi dalam daerah bss"
 
-#: common.opt:3135
+#: common.opt:3139
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Clear call-used registers upon function return."
 msgstr "Simpan register dalam pemanggilan fungsi"
 
-#: common.opt:3139
+#: common.opt:3143
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:3175
+#: common.opt:3179
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Hasilkan informasi debug dalam formas DWARF v2"
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "Hasilkan informasi debug dalam format baku extended"
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, fuzzy, no-c-format
 #| msgid "Record gcc command line switches in the object file."
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Rekam pilihan baris perintah gcc dalam berkas objek."
 
-#: common.opt:3219
+#: common.opt:3223
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:3223
+#: common.opt:3227
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "Hasilkan informasi debug dalam format STABS"
 
-#: common.opt:3227
+#: common.opt:3231
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Hasilkan informasi debug dalam formas STABS extended"
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "Hasilkan informasi debug dalam format VMS"
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "Hasilkan informasi debug dalam format VMS"
 
-#: common.opt:3258
+#: common.opt:3262
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "Hasilkan informasi debug dalam format XCOFF"
 
-#: common.opt:3262
+#: common.opt:3266
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Hasilkan informasi debug dalam format XCOFF extended"
 
-#: common.opt:3280
+#: common.opt:3284
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "Hasilkan instruksi isel"
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3291
+#: common.opt:3295
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-multilib <dir> Set <dir> untuk menjadi multilib inlude subdirektori"
 
-#: common.opt:3295
+#: common.opt:3299
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-multilib <dir> Set <dir> untuk menjadi multilib inlude subdirektori"
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "Tempatkan keluaran kedalam <berkas>"
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "Aktifkan profiling fungsi"
 
-#: common.opt:3334
+#: common.opt:3338
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "Seperti -pedantic tetapi menisukannya sebagai errors"
 
-#: common.opt:3374
+#: common.opt:3378
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Jangan tampilkan fungsi yang dikompile atau waktu yang sudah lewat"
 
-#: common.opt:3406
+#: common.opt:3410
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Aktifkan keluaran verbose"
 
-#: common.opt:3410
+#: common.opt:3414
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Tampilkan versi dari kompiler"
 
-#: common.opt:3414
+#: common.opt:3418
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Tekan peringatan"
 
-#: common.opt:3424
+#: common.opt:3428
 #, fuzzy, no-c-format
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "Buat sebuah perpustakaan terbagi"
 
-#: common.opt:3472
+#: common.opt:3476
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:3476
+#: common.opt:3480
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:3480
+#: common.opt:3484
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -21382,1226 +21383,1236 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload"
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "Rasio threshold dari jumlah ujung eksekusi kritis yang diijinkan untuk menjalankan penghapusan redundansi setelah reload"
 
-#: params.opt:178
+#: params.opt:183
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio for performing partial redundancy elimination after reload"
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "Rasio threshold untuk menjalankan penghapusan redundansi bagian setelah reload"
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, fuzzy, no-c-format
 #| msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap"
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "Ekspansi heap minimum untuk mentriger pengoleksi sampah, sebagai sebuah persentasi dari ukuran total dari heap"
 
-#: params.opt:194
+#: params.opt:199
 #, fuzzy, no-c-format
 #| msgid "Minimum heap size before we start collecting garbage, in kilobytes"
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "Ukuran heap minimum sebelum kita mulai mengumpulkan sampah, dalam kilobytes"
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "Maximum number of arrays per SCoP."
 msgstr "Jumlah maksimum dari error untuk dilaporkan"
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 #| msgid "maximum value of parameter %qs is %u"
 msgid "Maximum number of parameters in a SCoP."
 msgstr "nilai maksimal dari parameter %qs adalah %u"
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal count of repetitions of basic block in program given basic block needs to have to be considered hot"
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "Pilih bagian dari jumlah maksimal dari repetisi dari blok dasar dalam aplikasi memberikan blok dasar yang perlu untuk dipertimbangkan sekarang"
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot"
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "Pilih bagian dari frekuensi maksimal dari eksekusi dari blok dasar dalam fungsi yang diberikan blok dasar yang perlu untuk dipertimbangkan sekarang"
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, fuzzy, no-c-format
 #| msgid "how much can given compilation unit grow because of the inlining (in percent)"
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "berapa banyak yang dapat diberikan dalam satuan kompilasi berkembang karena inlining (dalam persentasi)"
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 #| msgid "The upper bound for sharing integer constants"
 msgid "The upper bound for sharing integer constants."
 msgstr "Batasan atas untuk pembagian konstanta integer"
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "Kedalaman maksimum dari inlining rekursif untuk fungsi inline"
 
-#: params.opt:258
+#: params.opt:263
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Inline secara rekursif hanya ketika kemungkinan dari pemanggilan yang sedang dijalankan melebihi parameter"
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, fuzzy, no-c-format
 #| msgid "how much can given compilation unit grow because of the interprocedural constant propagation (in percent)"
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "berapa banyak yang dapat diberikan dalam satuan kompilasi berkembang karena propagasi konstanta interprocedural (dalam persentasi)"
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "Ukuran dari satuan penerjemah yang akan dipertimbangkan terlalu besar"
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr ""
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, fuzzy, no-c-format
 #| msgid "max size of conflict table in MB"
 msgid "Max size of conflict table in MB."
 msgstr "ukuran maksimal dari tabel konflik dalam MB"
 
-#: params.opt:322
+#: params.opt:327
 #, fuzzy, no-c-format
 #| msgid "max loops number for regional RA"
 msgid "Max loops number for regional RA."
 msgstr "jumlah maksimal loops untuk daerah RA"
 
-#: params.opt:326
+#: params.opt:331
 #, fuzzy, no-c-format
 #| msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization"
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "Jika jumlah dari kandidat dalam set lebih kecil, kita selalu mencoba untuk menghapusiv yang tidak digunakan ketika mengoptimisasinya"
 
-#: params.opt:330
+#: params.opt:335
 #, fuzzy, no-c-format
 #| msgid "Bound on number of candidates below that all candidates are considered in iv optimizations"
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "Terikat ke jumlah dari kandidat dibawah yang seluruh kandidat dipertimbangkan dalam optimisasi iv"
 
-#: params.opt:334
+#: params.opt:339
 #, fuzzy, no-c-format
 #| msgid "Bound on number of iv uses in loop optimized in iv optimizations"
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "Terikat ke jumlah dari iv yang digunakan dalam loop yang dioptimisasi dalam optimisasi iv"
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, fuzzy, no-c-format
 #| msgid "The size of L1 cache line"
 msgid "The size of L1 cache line."
 msgstr "Ukuran dari baris L1 cache"
 
-#: params.opt:350
+#: params.opt:355
 #, fuzzy, no-c-format
 #| msgid "The size of L1 cache"
 msgid "The size of L1 cache."
 msgstr "Ukuran dari L1 cache"
 
-#: params.opt:354
+#: params.opt:359
 #, fuzzy, no-c-format
 #| msgid "The size of L2 cache"
 msgid "The size of L2 cache."
 msgstr "Ukuran dari L2 cache"
 
-#: params.opt:358
+#: params.opt:363
 #, fuzzy, no-c-format
 #| msgid "Maximal growth due to inlining of large function (in percent)"
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Perkembangan maksimal karena inlining  dari fungsi besar (dalam persentasi)"
 
-#: params.opt:362
+#: params.opt:367
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of function body to be considered large."
 msgstr "Ukuran dari badan fungsi yang akan dipertimbangkan terlalu besar"
 
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 #| msgid "The size of stack frame to be considered large"
 msgid "The size of stack frame to be considered large."
 msgstr "Ukuran dari frame stack yang akan dipertimbangkan terlalu besar"
 
-#: params.opt:370
+#: params.opt:375
 #, fuzzy, no-c-format
 #| msgid "Maximal stack frame growth due to inlining (in percent)"
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Perkembangan stack frame maksimal karena inlining (dalam persentasi)"
 
-#: params.opt:374
+#: params.opt:379
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit to be considered large."
 msgstr "Ukuran dari satuan penerjemah yang akan dipertimbangkan terlalu besar"
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, fuzzy, no-c-format
 #| msgid "The minimum cost of an expensive expression in the loop invariant motion"
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "Biaya minimum dari sebuah ekspresi ekspensi dalam sebuah pergerakan loop tidak variant"
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "Jumlah maksimum dari instruksi yang dipertimbangkan untuk unrool dalam sebuah loop secara rata rata"
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr ""
 
-#: params.opt:402
+#: params.opt:407
 #, fuzzy, no-c-format
 #| msgid "max basic blocks number in loop for loop invariant motion"
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr "jumlah maksimal blok dasar dalam loop untuk gerakan loop invariant"
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "Jumlah maksimum dari instruksi dalam sebuah fungsi tunggal yang bisa untuk inlining"
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "Jumlah maksimum dari instruksi yang dipertimbangkan untuk unrool dalam sebuah loop"
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "Jumlah maksimum dari instruksi yang dipertimbangkan untuk unrool dalam sebuah loop secara rata rata"
 
-#: params.opt:446
+#: params.opt:451
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of insns combine tries to combine."
 msgstr "Jumlah maksimum dari ujung masukan untuk dipertimbangkan untuk cross jumping"
 
-#: params.opt:450
+#: params.opt:455
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "Jumlah maksimum dari insns dari sebuah loop terbuka penuh"
 
-#: params.opt:454
+#: params.opt:459
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop that is peeled completely"
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Jumlah maksimum dari pembukaan dari sebuah loop tunggal yang dibuka secara lengkap"
 
-#: params.opt:458
+#: params.opt:463
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "Jumlah maksimum dari insns dari sebuah loop terbuka penuh"
 
-#: params.opt:462
+#: params.opt:467
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "Jumlah maksimum dari ujung masukan untuk dipertimbangkan untuk cross jumping"
 
-#: params.opt:466
+#: params.opt:471
 #, fuzzy, no-c-format
 #| msgid "The maximum instructions CSE process before flushing"
 msgid "The maximum instructions CSE process before flushing."
 msgstr "Instruksi maksimum CSE proses sebelum flushing"
 
-#: params.opt:470
+#: params.opt:475
 #, fuzzy, no-c-format
 #| msgid "The maximum length of path considered in cse"
 msgid "The maximum length of path considered in cse."
 msgstr "Panjang maksimum dari jalur yang dipertimbangkan dalam cse"
 
-#: params.opt:474
+#: params.opt:479
 #, fuzzy, no-c-format
 #| msgid "The maximum memory locations recorded by cselib"
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Lokasi memori maksimum terekam oleh cselib"
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to fill a delay slot"
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "Jumlah maksimum dari instruksi yang dipertimbangkan untuk mengisi sebuah slot penundaan"
 
-#: params.opt:486
+#: params.opt:491
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to find accurate live register information"
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "Jumlah maksimum dari instruksi untuk dipertimbangkan untuk menemukan secara tepatinformasi register hidup"
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "Jumlah maksimum dari instruksi dalam sebuah fungsi tunggal yang bisa untuk inlining"
 
-#: params.opt:498
+#: params.opt:503
 #, fuzzy, no-c-format
 #| msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable"
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "Jumlah maksimum dari field dalam sebuah struktur sebelum analisa penunjuk treats struktur sebagai sebuah variabel tunggal"
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, fuzzy, no-c-format
 #| msgid "Maximum number of nops to insert for a hint (Default 2)"
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "Jumlah maksimum dari nops untuk dimasukan untuk sebuah hint (Baku 2)"
 
-#: params.opt:514
+#: params.opt:519
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "Jumlah maksimum dari instruksi yang dipertimbangkan untuk unrool dalam sebuah loop"
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE"
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "Jumlah maksimum memori yang akan dialokasikan oleh GCSE"
 
-#: params.opt:522
+#: params.opt:527
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns to duplicate when unfactoring computed gotos"
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "Jumlah maksimum dari insns untuk duplikasi ketika unfaktoring menghitung gotos"
 
-#: params.opt:526
+#: params.opt:531
 #, fuzzy, no-c-format
 #| msgid "The maximum expansion factor when copying basic blocks"
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "Faktor ekspansi maksimum ketika menyalin blok dasar"
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "Jumlah maksimum dari instruksi ketika secara otomatis inlining"
 
-#: params.opt:538
+#: params.opt:543
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "Jumlah maksimum dari instruksi fungsi inline dapat berkembang melalui inline rekursif"
 
-#: params.opt:542
+#: params.opt:547
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions non-inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "Jumlah maksimum dari instruksi bukan-inline funsi yang dapat berkembang melalui inlining rekursif"
 
-#: params.opt:546
+#: params.opt:551
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "Jumlah maksimum dari instruksi dalam sebuah fungsi tunggal yang bisa untuk inlining"
 
-#: params.opt:550
+#: params.opt:555
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when inlining for size."
 msgstr "Jumlah maksimum dari instruksi ketika secara otomatis inlining"
 
-#: params.opt:554
+#: params.opt:559
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "Jumlah maksimum dari instruksi ketika secara otomatis inlining"
 
-#: params.opt:558
+#: params.opt:563
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "Kedalaman maksimum dari inlining rekursif untuk fungsi inline"
 
-#: params.opt:562
+#: params.opt:567
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for non-inline functions"
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "Kedalaman maksimum dari inlining rekursif untuk fungsi bukan inline"
 
-#: params.opt:566
+#: params.opt:571
 #, fuzzy, no-c-format
 #| msgid "Maximum number of times that an insn could be scheduled"
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Jumlah maksimum dari percobaan dari sebuah insn dapat dijadwalkan"
 
-#: params.opt:570
+#: params.opt:575
 #, fuzzy, no-c-format
 #| msgid "Bound on the cost of an expression to compute the number of iterations"
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "Terikat dengan biaya dari sebuah ekspresi untuk menghitung jumlah dari iterasi"
 
-#: params.opt:574
+#: params.opt:579
 #, fuzzy, no-c-format
 #| msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates"
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "Terikat dengan jumlah dari iterasi brute force # dari interasi analisis algoritma yang dievaluasi"
 
-#: params.opt:578
+#: params.opt:583
 #, fuzzy, no-c-format
 #| msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps"
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "Jumlah maksimum dari statemen yang diperbolehkan dalam sebuah blok yang membutuhkan untuk diduplikasi ketika threading jumps"
 
-#: params.opt:582
+#: params.opt:587
 #, fuzzy, no-c-format
 #| msgid "The maximum number of RTL nodes that can be recorded as combiner's last value"
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "Jumlah maksimum dari titik RTL yang dapat direkam sebagai pemkombinasi nilai terakhir"
 
-#: params.opt:586
+#: params.opt:591
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns to duplicate when unfactoring computed gotos"
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "Jumlah maksimum dari insns untuk duplikasi ketika unfaktoring menghitung gotos"
 
-#: params.opt:590
+#: params.opt:595
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "Jumlah maksimum dari instruksi yang dipertimbangkan untuk unrool dalam sebuah loop"
 
-#: params.opt:594
+#: params.opt:599
 #, fuzzy, no-c-format
 #| msgid "Maximum length of partial antic set when performing tree pre optimization"
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr "Panjang maksimum dari bagian antik diset ketika menjalan pre optimisasi pohon"
 
-#: params.opt:598
+#: params.opt:603
 #, fuzzy, no-c-format
 #| msgid "The maximum number of iterations through CFG to extend regions"
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "Jumlah maksimum dari iterasi melalui CFG ke daerah entensi"
 
-#: params.opt:602
+#: params.opt:607
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop"
 msgid "The maximum number of peelings of a single loop."
 msgstr "Jumlah maksimum dari pembukaan dari sebuah loop tunggal"
 
-#: params.opt:606
+#: params.opt:611
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a peeled loop"
 msgid "The maximum number of insns of a peeled loop."
 msgstr "Jumlah maksimum dari insns dari sebuah loop terbuka"
 
-#: params.opt:610
+#: params.opt:615
 #, fuzzy, no-c-format
 #| msgid "The maximum length of scheduling's pending operations list"
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "Panjang maksimum dari penjadwalan dari daftar operasi tertunda"
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, fuzzy, no-c-format
 #| msgid "The maximum number of blocks in a region to be considered for interblock scheduling"
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "Jumlah maksimum dari blok dalam sebuah daerah yang dipertimbangkan untuk penjadwalan inter-blok"
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "Jumlah maksimum dari insns dalam sebuah daerah untuk dipertimbangkan untuk penjadwalan inter-blok"
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically"
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "Jumlah maksimum dari iterasi loop yang kita prediksi secara statis"
 
-#: params.opt:630
+#: params.opt:635
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to search backward when looking for equivalent reload"
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "Jumlah maksimum dari instruksi untuk pencarian terbalik ketika mencari untuk reload yang sepadan"
 
-#: params.opt:634
+#: params.opt:639
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Jumlah maksimum dari insns dalam sebuah daerah untuk dipertimbangkan untuk penjadwalan inter-blok"
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, fuzzy, no-c-format
 #| msgid "The maximum number of iterations through CFG to extend regions"
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "Jumlah maksimum dari iterasi melalui CFG ke daerah entensi"
 
-#: params.opt:650
+#: params.opt:655
 #, fuzzy, no-c-format
 #| msgid "The maximum conflict delay for an insn to be considered for speculative motion"
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "Waktu tunda maksimum konflik untuk sebuah insn untuk dipertimbangkan untuk spekulasi pergerakan"
 
-#: params.opt:654
+#: params.opt:659
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass"
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "Jumlah maksimum dari instruksi yang siap untuk diberikan untuk dipertimbangkan oleh penjadwalan selam tahap penjadwalan pertama"
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr ""
 
-#: params.opt:682
+#: params.opt:687
 #, fuzzy, no-c-format
 #| msgid "Maximum number of times that an insn could be scheduled"
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "Jumlah maksimum dari percobaan dari sebuah insn dapat dijadwalkan"
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in the ready list that are considered eligible for renaming"
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "Jumlah maksimum dari instruksi dalam daftar siaga yang dipertimbangkan berhak untuk diubah namanya"
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unrollings of a single loop"
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Jumlah maksimum dari unrollings dari sebuah loop tunggal"
 
-#: params.opt:714
+#: params.opt:719
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "Jumlah maksimum dari instruksi yang dipertimbangkan untuk unrool dalam sebuah loop"
 
-#: params.opt:718
+#: params.opt:723
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of an unswitched loop"
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "Jumlah maksimum dari insns dari sebuah loop tidak terswitch"
 
-#: params.opt:722
+#: params.opt:727
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unswitchings in a single loop"
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Jumlah maksimum dari unswitching dalam sebuah loop tunggal"
 
-#: params.opt:726
+#: params.opt:731
 #, fuzzy, no-c-format
 #| msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling"
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "Jika -fvariabel-expansion-in-unroller digunakan, maksimum pengulangan yang sebuah variabel individu akan diekspan ketika loop unrolling"
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, fuzzy, no-c-format
 #| msgid "The minimum number of matching instructions to consider for crossjumping"
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "Jumlah minimum dari instruksi yang cocok untuk dipertimbangkan untuk cross jumping"
 
-#: params.opt:754
+#: params.opt:759
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Inline secara rekursif hanya ketika kemungkinan dari pemanggilan yang sedang dijalankan melebihi parameter"
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, fuzzy, no-c-format
 #| msgid "The minimum probability of reaching a source block for interblock speculative scheduling"
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "Kemungkinan minimum dari pencapaian sebuah sumber blok untuk inter-blok penjadwalan spekulasi"
 
-#: params.opt:778
+#: params.opt:783
 #, fuzzy, no-c-format
 #| msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization"
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "Jika -ftree-vectorize digunakan, minimal loop terikat dari sebuah loop yang akan dipertimbangkan untuk vektorisasi"
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Jumlah maksimum dari instruksi yang dipertimbangkan untuk unrool dalam sebuah loop"
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, fuzzy, no-c-format
 #| msgid "Maximal esitmated outcome of branch considered predictable"
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "Maksimal perkiraan hasil dari pertimbangan cabang yang dapat diprediksi"
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, fuzzy, no-c-format
 #| msgid "The number of insns executed before prefetch is completed"
 msgid "The number of insns executed before prefetch is completed."
 msgstr "Jumlah dari insns yang dijalankan sebelum prefetch selesai"
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr ""
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr ""
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, fuzzy, no-c-format
 #| msgid "Bound on size of expressions used in the scalar evolutions analyzer"
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "Terikat dengan ukuran dari ekspresi digunakan dalam evolusi penanalisa skalar"
 
-#: params.opt:852
+#: params.opt:870
 #, fuzzy, no-c-format
 #| msgid "Bound on size of expressions used in the scalar evolutions analyzer"
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "Terikat dengan ukuran dari ekspresi digunakan dalam evolusi penanalisa skalar"
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, fuzzy, no-c-format
 #| msgid "Minimal distance between possibly conflicting store and load"
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr "Jarak minimal diantara kemungkinan konflik store dan load"
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "Probabilitas minimal dari spekulasi kesuksesan (dalam persentasi), jadi jika spekulasi insn akan dijadwalkan."
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in the ready list that are considered eligible for renaming"
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "Jumlah maksimum dari instruksi dalam daftar siaga yang dipertimbangkan berhak untuk diubah namanya"
 
-#: params.opt:880
+#: params.opt:898
 #, fuzzy, no-c-format
 #| msgid "The maximum size of the lookahead window of selective scheduling"
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr "Ukuran maksimal dari lookahead window dari penjadwalan selektif"
 
-#: params.opt:884
+#: params.opt:902
 #, fuzzy, no-c-format
 #| msgid "Maximum number of times that an insn could be scheduled"
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "Jumlah maksimum dari percobaan dari sebuah insn dapat dijadwalkan"
 
-#: params.opt:888
+#: params.opt:906
 #, fuzzy, no-c-format
 #| msgid "The number of prefetches that can run at the same time"
 msgid "The number of prefetches that can run at the same time."
 msgstr "Jumlah dari prefetches yang dapat berjalan di waktu bersamaan"
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, fuzzy, no-c-format
 #| msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA"
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "Jumlah dari cycles dari swing modulo penjadwalan yang dipertimbangkan ketika memeriksa konflik menggunakan DFA"
 
-#: params.opt:900
+#: params.opt:918
 #, fuzzy, no-c-format
 #| msgid "A threshold on the average loop count considered by the swing modulo scheduler"
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "Sebuah threshold di jumlah loop rata-rata yang dipertimbangkan oleh modulo swingpenjadwal"
 
-#: params.opt:904
+#: params.opt:922
 #, fuzzy, no-c-format
 #| msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop"
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "Sebuah faktor untuk tuning batasan atas yang swing module penjadwalan digunakan untuk penjadwalan sebuah loop"
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 #| msgid "The maximum number of passes to make when doing GCSE"
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "Jumlah maksimum dari tahap yang akan dibuat ketika melakukan GCSE"
 
-#: params.opt:928
+#: params.opt:946
 #, fuzzy, no-c-format
 #| msgid "The lower bound for a buffer to be considered for stack smashing protection"
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "Batas bawah untuk sebuah penyangga untuk dipertimbangkan untuk proteksi stack smashing"
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, fuzzy, no-c-format
 #| msgid "The maximum ratio between array size and switch branches for a switch conversion to take place"
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "Rasio maksimal diantara ukuran array dan cabang switch untuk sebuah konversi switch untuk mengambil tempat"
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "Jumlah maksimum dari error untuk dilaporkan"
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "Maximum number of references stored in each modref base."
 msgstr "Jumlah maksimum dari error untuk dilaporkan"
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr ""
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "Maximum number of tests performed by modref query."
 msgstr "Jumlah maksimum dari error untuk dilaporkan"
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr ""
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "Persentasi dari fungsi, dihitung dengan frekuensi eksekusi, yang harus dilingkupi dengan formasi jejak. Digunakan ketika profile umpan-balik tidak tersedia"
 
-#: params.opt:984
+#: params.opt:1002
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "Persentasi dari fungsi, dihitung dengan frekuensi eksekusi, yang harus dilingkupi dengan formasi jejak. Digunakan ketika profile umpan-balik tersedia"
 
-#: params.opt:988
+#: params.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Maximal code growth caused by tail duplication (in percent)"
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Perkembangan kode maksimal dikarenakan oleh duplikasi tail (dalam persentasi)"
 
-#: params.opt:992
+#: params.opt:1010
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "Stop perkembangan kedepan jika kemungkinan ujung terbaik lebih kecil dari threshold ini (dalam persentasi). Digunakan ketika profile umpan-balik tidak tersedia"
 
-#: params.opt:996
+#: params.opt:1014
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "Stop perkembangan kedepan jik kemungkinan ujung terbaik lebih kecil dari threshold ini (dalam persentasi). Digunakan ketika profile umpan-balik tersedia"
 
-#: params.opt:1000
+#: params.opt:1018
 #, fuzzy, no-c-format
 #| msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)"
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "Stop perkembangan terbalik jika kemungkinan kebalikan dari ujung terbaik lebih kecil dari threshold ini (dalam persentasi)"
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 #| msgid "Emit implicit instantiations of templates"
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "Keluarkan implisit instantionation dari templates"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "Gunakan subroutines untuk fungsi prolog dan epilog"
 
-#: params.opt:1024
+#: params.opt:1042
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "Gunakan subroutines untuk fungsi prolog dan epilog"
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, fuzzy, no-c-format
 #| msgid "Whether to use canonical types"
 msgid "Whether to use canonical types."
 msgstr "Akan menggunakan tipe kanonikal"
 
-#: params.opt:1056
+#: params.opt:1074
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, fuzzy, no-c-format
 #| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check"
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "Terikat dengan jumlah dari pemeriksaan waktu jalan dimasukan dengan loop tervektor dengan versi untuk pemeriksaan alias"
 
-#: params.opt:1068
+#: params.opt:1086
 #, fuzzy, no-c-format
 #| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check"
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Terikat ke jumlah dari pemeriksaan rutinitas yang dimasukan dengan loop tervektor dengan versi untuk pemeriksaan alignment"
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -22642,7 +22653,7 @@ msgid "expected boolean type"
 msgstr "diduga bukan tuple"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -22729,7 +22740,7 @@ msgstr "tidak ada argumen"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments"
@@ -23185,7 +23196,7 @@ msgstr "%qE atribut konflik dengan atribut %s"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -23247,7 +23258,7 @@ msgstr "tipe atribut diabaikan setelah tipe telah didefinisikan"
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -23276,20 +23287,20 @@ msgstr "tipe atribut diabaikan setelah tipe telah didefinisikan"
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -23300,8 +23311,8 @@ msgstr "%qE atribut diabaikan"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -23312,63 +23323,63 @@ msgstr "deklarasi sebelumnya dari %q+D"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D telah dideklarasikan dengan atribut dllexport: dllimport diabaikan"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D redeklarasi tanpa atribut dllimport setelah telah direferensikan dengan dll linkage"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D redeklarasi tanpa atribut dllimport: sebelumnya dllimport diabaikan"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared as  dllimport: attribute ignored"
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "fungsi inline %q+D dideklarasikan sebagai dllimport: atribut diabaikan"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "definisi fungsi %q+D ditandai dllimport"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "definisi variabel %q+D ditandai dllimport"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, fuzzy, gcc-internal-format
 #| msgid "external linkage required for symbol %q+D because of %qs attribute"
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "external linkage dibutuhkan untuk simbol %q+D karena atribut %qs"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, fuzzy, gcc-internal-format
 #| msgid "%qs implies default visibility, but %qD has already been declared with a different visibility"
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qs mengimplikasikan visibility baku, tetapi %qD telah dideklarasikan dengan sebuah visibility berbeda"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD target declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -23474,7 +23485,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr "ofset diluar dari jangkauan dari konstanta string"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -23500,514 +23511,514 @@ msgstr "argumen ketiga ke %<__builtin_prefetch%> harus berupa sebuah konstan"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "argumen ketiga ke %<__builtin_prefetch%> tidak valid; menggunakan nol"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "source object declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "destination object declared here"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, gcc-internal-format
 msgid "destination object allocated here"
 msgstr ""
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "terlalu sedikit argumen ke fungsi %<va_start%>"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid argument to %qD"
 msgstr "tipe argumen tidak valid dari %qs"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported argument to %qD"
@@ -24015,97 +24026,97 @@ msgstr "kombinasi tidak didukung: %s"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "kedua argumen ke %<__builtin___clear_cache%> harus berupa penunjuk"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 #| msgid "-mstackrealign ignored for nested functions"
 msgid "trampoline generated for nested function %qD"
 msgstr "-mstackrealign diabaikan untuk fungsi nested"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD mengubah semantik dalam GCC 4.4"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid memory model argument to builtin"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 1 to %qs"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "non-integer argument 1 to %qs"
 msgstr "hilang argumen ke \"%s\""
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s not supported: ignored"
 msgid "%qs only supported in OpenACC code"
 msgstr "-f%s tidak didukung: diabaikan"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 0 to %qs"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "illegal argument 0 to %qs"
@@ -24113,129 +24124,129 @@ msgstr "hilang argumen ke \"%s\""
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K penggunakan tidak valid dari %<__builtin_va_arg_pack ()%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%K penggunaan tidak valid dari %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> argumen kedua harus berupa 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "format target tidak mendukung infinity"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> digunakan dalam fungsi dengan argumen tetap"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "jumlah dari argumen ke fungsi %<va_start%> salah"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "parameter kedua dari %<va_start%> bukan argumen bernama terakhir"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "perilaku tidak terdefinisi ketika parameter kedua dari %<va_start%> dideklarasikan dengan penyimpanan %<register%>"
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%K argumen terakhir dari %K bukan sebuah konstanta integer diantara 0 dan 3"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, gcc-internal-format
 msgid "returned from %qD"
 msgstr ""
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, gcc-internal-format
 msgid "returned from %qT"
 msgstr ""
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "used here"
 msgid "obtained here"
 msgstr "digunakan disini"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "used here"
 msgid "assigned here"
 msgstr "digunakan disini"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -25057,313 +25068,313 @@ msgstr "blok dasar tidak ditempatkan secara berurutan"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "jumlah dari catatan bb dalam rantai instruksi (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "jumlah ujung pemanggil negatif"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "missing direct call for speculation %i"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use control speculation"
 msgid "missing ref for speculation %i"
 msgstr "Gunakan spekulasi kontrol"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "field tambahan diset untuk ujung  %s->%s"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "elemen penginisialisasi bukan sebuah konstanta"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Asumsikan simbol mungkin tidak valid"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "field tambahan diset untuk ujung  %s->%s"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "PIC code generation is not compatible with fast indirect calls"
 msgid "edge count is not compatible with function count"
 msgstr "Pembuatan kode PIC tidak kompatibel dangan panggilan cepat tidak langsung"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "penunjuk inlined_to salah"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "multiple pemanggil inline"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "penunjuk inlined_to diset untuk pemanggil bukan inline"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "caller edge count does not match BB count"
 msgstr "jumlah ujung masukan tidak cocok dengan jumlah dari argumen PHI"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "indirect call count does not match BB count"
 msgstr "jumlah ujung masukan tidak cocok dengan jumlah dari argumen PHI"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "penunjuk inlined_to diset tetapi tidak ada predecessor ditemukan"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "penunjuk inlined_to mereferensikan ke dirinya sendiri"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "shared call_stmt:"
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "titik ujung ke deklarasi salah:"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "hilang ujung callgraph untuk pemanggilan stmt:"
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "diduga pernyataan"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ujung %s->%s tidak memiliki korespondensi call_stmt"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ujung %s->%s tidak memiliki korespondensi call_stmt"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node gagal"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s.%d is missing"
@@ -25458,12 +25469,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F digunakan tetapi tidak pernah didefinisikan"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
@@ -25543,7 +25554,7 @@ msgstr "ukuran dari nilai kembali dari %q+D adalah %u bytes"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "ukuran dari nilai kembali dari %q+D lebih besar dari %wd bytes"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "titik dengan tidak direlease memori ditemukan"
@@ -25981,12 +25992,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -26006,7 +26017,7 @@ msgstr "shared rtx"
 msgid "internal consistency failure"
 msgstr "kegagalan konsistensi internal"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn digunakan dimana emit_jump_insn dibutuhkan:\n"
@@ -26147,42 +26158,42 @@ msgstr "tidak dapat membuka berkas dump %qs: %s"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "konstanta titik-tetap besar secara implisit dipotong ke tipe titik-tetap"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "perbandingan selalu %d karena lebar dari bit-field"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhanakan pemeriksaan jangkauan"
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "perbandingan selalu %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> dari pemeriksaan tidak cocok tidak-sama selalu 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> dari mutually eksklusif test-sama selalu 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "diasumsikan signed overflow tidak terjadi ketika mereduksi konstanta dalam perbandingan"
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "diasumsikan signed overflow tidak terjadi ketika mengkombinasi konstan diantar sebuah perbandingan"
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "pemeriksaan fold: pohon asal diubah oleh fold"
@@ -26199,7 +26210,7 @@ msgstr "ukuran total dari variabel lokal melebihi batas arsitektur"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "ukuran total dari variabel lokal melebihi batas arsitektur"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "batasan tidak memungkinkan dalam %<asm%>"
@@ -26886,7 +26897,7 @@ msgstr "penunjuk circular delegasi terdeteksi"
 msgid "function may return address of local variable"
 msgstr "fungsi mengembalikan alamat dari variabel lokal"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "fungsi mengembalikan alamat dari variabel lokal"
@@ -27256,67 +27267,67 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "%s dalam format string di %L"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 #| msgid "invalid use of %<auto%>"
 msgid "%Guse of %<alloca%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 #| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array may be too large"
 msgstr "Peringatkan jika sebuah array dengan panjang bervariabel digunakan"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 #| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array is too large"
 msgstr "Peringatkan jika sebuah array dengan panjang bervariabel digunakan"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 #| msgid "value passed to %<-m%s%> is too large"
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "nilai dilewatkan ke %<-m%s%> terlalu besar"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 #| msgid "ISO C90 forbids variable length array"
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C90 melarang array dengan panjang bervariabel"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 #| msgid "invalid use of %<auto%>"
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 #| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array is zero"
 msgstr "Peringatkan jika sebuah array dengan panjang bervariabel digunakan"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 #| msgid "Second argument of MOD at %L is zero"
 msgid "%Gargument to %<alloca%> is zero"
@@ -27432,7 +27443,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "array %qD declared here"
@@ -27459,11 +27470,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -27547,333 +27558,333 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-memory input %d must stay in memory"
 msgid "non-memory output %d must stay in memory"
 msgstr "masukan %d bukan memori harus tetap berada dalam memori"
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "masukan %d bukan memori harus tetap berada dalam memori"
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "masukan memori %d tidak secara langsung dapat dialamatkan"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr ""
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing region"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing target region"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing task"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "error menutup %s: %m"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%H%qE tidak dideklarasikan (pertama digunakan dalam fungsi ini)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing %<target%>"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%H variabel iterasi %qE unsigned"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should be private"
 msgstr "iterasi variabel %qs seharusnya private"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qD should not be firstprivate"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be reduction"
 msgstr "iterasi variabel %qs seharusnya bukan reduksi"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be linear"
 msgstr "iterasi variabel %qs seharusnya bukan reduksi"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %<lastprivate%>"
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "daerah terurut harus secara dekat nested didalam sebuah daerah loop dalam sebuah clause terurut"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gagal"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT dipromosikan ke %qT ketika dilewatkan melalui %<...%>"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(jadi anda harus melewatkan %qT bukan %qT ke %<va_arg%>)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jika kode ini dicapai, aplikasi akan digagalkan"
@@ -28340,24 +28351,24 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s tidak digunakan dalam asm disini"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "as %qD"
 msgid "for %qD"
 msgstr "sebagai %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "ukuran frame terlalu besar untuk pemerikasaan stack yang meyakinkan"
@@ -28378,12 +28389,12 @@ msgstr "operan %<asm%> memiliki batasan tidak memungkinkan"
 msgid "unable to find a register to spill"
 msgstr "tidak dapat menemukan sebuah register untuk spill dalam kelas %qs"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "batasan operan tidak konsisten dalam sebuah %<asm%>"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Maximum number of times that an insn could be scheduled"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
@@ -29145,13 +29156,13 @@ msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 msgid "unrecognized argument in option %qs"
 msgstr "pilihan baris perintah \"%s\" tidak dikenal"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
@@ -29290,7 +29301,7 @@ msgstr "-static-libgfortran tidak didukung dalam konfigurasi ini"
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr "section anchors harus tidak aktif ketika pengurutan kembali tingkat teratas tidak aktif"
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
@@ -29841,25 +29852,25 @@ msgstr "secara implisit popped regs harus dikelompokan di ujung dari stack"
 msgid "output operand %d must use %<&%> constraint"
 msgstr "keluaran operan %d harus menggunakan batasan %<&%>"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "validate_value_data: [%u] Buruk nex_regno untuk rantai kosong (%u)"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: Loop in regno chain (%u)"
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "validate_value_data: Loop dalam rantai regno (%u)"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "validate_value_data: [%u] Buruk oldest_regno (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
@@ -29928,13 +29939,13 @@ msgstr "tidak dapat reload operan konstanta integer dalam %<asm%>"
 msgid "impossible register constraint in %<asm%>"
 msgstr "batasan register tidak memungkinkan dalam %<asm%>"
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "target ini tidak mendukung %qs"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "batasan %<&%> digunakan dengan tidak ada register kelas"
@@ -29965,54 +29976,54 @@ msgstr "batasan operan %<asm%> tidak kompatibel dengan ukuran operan"
 msgid "output operand is constant in %<asm%>"
 msgstr "keluaran operan adalah konstanta dalam %<asm%>"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "pemeriksaan RTL: akses dari elt %d dari '%s' dengan elt akhir %d dalam %s,  di %s:%d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "pemeriksaan RTL: diduga elt %d tipe '%c', memiliki '%c' (rtx %s) dalam %s, di %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "pemeriksaan RTL: diduga elt %d tipe '%c' atau '%c', memiliki '%c' (rtx %s) dalam %s, di %s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "pemeriksaan RTL: diduga kode '%s', memiliki '%s' dalam %s, di %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "pemeriksaan RTL: diduga kode '%s' atau '%s', memiliki '%s'dalam %s, di %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "pemeriksaan RTL: diduga kode '%s' atau '%s', memiliki '%s'dalam %s, di %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "pemeriksaan RTL: mencoba memperlakukan bukan-blok simbol sebagai sebuah blok simbol dalam %s, di %s:%d"
 
-#: rtl.c:937
+#: rtl.c:947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "pemeriksaan RTL: akses dari elt %d dari vektor dengan elt terakhir %d dalam %s, di %s:%d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "pemeriksaan RTL: akses dari elt %d dari vektor dengan elt terakhir %d dalam %s, di %s:%d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "pemeriksaan tanda RTL: %s digunakan dengan kode rtx tidak terduga '%s' dalam %s, di %s:%d"
@@ -30057,23 +30068,23 @@ msgstr "batasan yang cocok mereferensikan jumlah operan yang tidak valid"
 msgid "invalid punctuation %qc in constraint"
 msgstr "punctuation %qc tidak valid dalam batasan"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "batasan yang cocok tidak mengijinkan sebuah register"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate asm operand name %qs"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "duplikasn nama operan asm %qs"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "hilang kurung penutup untuk operan yang bernama"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "operan bernama %qs tidak terdefinisi"
@@ -30815,9 +30826,9 @@ msgstr "operan tidak valid ke %%R"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in not expression"
 msgid "type mismatch in %qs"
@@ -30858,7 +30869,7 @@ msgstr "operan shift tidak valid"
 msgid "invalid clique in %qs"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
@@ -31082,395 +31093,395 @@ msgstr "operan tidak valid dalam operasi binary"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid mask type in %qs"
 msgstr "tipe abstrak tidak valid untuk %q+D"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "'&' not allowed by itself in line %d"
 msgid "not allowed type combination in %qs"
 msgstr "'&' tidak diperboleh dengan sendirinya dalam baris %d"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "invalid position or size in %qs"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial conversion at assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "konversi bukan trivial di penempatan"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "in statement"
 msgid "%qs LHS in clobber statement"
 msgstr "dalam pernyataan"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "operan tidak valid ke %%R"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rhs for gimple memory store"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "rhs tidak valid untuk penyimpanan memori gimple"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect number of vector %qs elements"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, fuzzy, gcc-internal-format
 #| msgid "PHI argument is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "argumen PHI bukan sebuah nilai GIMPLE"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR dengan sebuah kondisi always-false"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "operan tidak valid dalam pernyataan return"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "konversi tidak valid dalam pernyataan return"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "tujuan goto bukan sebuah label ataupun sebuah penunjuk"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "operan tidak valid ke pernyataan switch"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to switch statement"
 msgid "non-integral type switch statement"
 msgstr "operan tidak valid ke pernyataan switch"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "%<default%> label not within a switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "%<default%> label tidak dalam sebuah pernyataan switch"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "invalid case label in switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to switch statement"
 msgid "invalid case range in switch statement"
 msgstr "operan tidak valid ke pernyataan switch"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "nama parameter (tanpa tipe) dalam deklarasi fungsi"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect entry in label_to_block_map.\n"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "masukan tidak benar dalam label_to_block_map.\n"
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, fuzzy, gcc-internal-format
 #| msgid "format string has invalid operand number"
 msgid "incorrect setting of landing pad number"
 msgstr "string format memiliki jumlah operan yang tidak valid"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion in gimple call"
 msgid "invalid comparison code in gimple cond"
 msgstr "konversi tidak valid dalam panggilan gimple"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "invalid labels in gimple cond"
 msgstr "operan tidak valid dalam perbandingan gimple"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "Hasil PHI tidak valid"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "hilang definisi PHI"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "argumen PHI tidak valid"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "Incompatible types in PHI argument"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "tipe tidak kompatibel dalam argumen PHI"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple gagal"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, fuzzy, gcc-internal-format
 #| msgid "Dead STMT in EH table"
 msgid "dead statement in EH table"
 msgstr "STMT dalam tabel EH mati"
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "local declaration from a different function"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) diset ke blok dasar salah"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, fuzzy, gcc-internal-format
 #| msgid "from this location"
 msgid "PHI node with location"
 msgstr "dari lokasi ini"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) diset ke blok dasar yang salah"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "pernyataan ditandai untuk throw, tetapi tidak"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "pernyataan ditandai untuk throw di tengah dari blok"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple gagal"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK memiliki IL diasosiasikan dengannya"
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK memiliki IL diasosiasikan dengannya"
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fallthru ke keluar dari bb %d"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "bukan lokal label "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "label "
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "kontrol aliran di tengah dari blok dasar %d"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "fallthry edge setelah sebuah pernyataan kontrol dalam bb %d"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "benar/salah edge setelah sebuah bukan-COND_COND dalam bb %d"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "tanda edge keluar salah diakhir dari bb %d"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "eksplisit goto di akhir dari bb %d"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "return edge tidak menunjuk ke akhir dalam bb %d"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "ditemukan case baku bukan diawal dari case vektor"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "case label tidak diurutkan: "
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "kelebihan outgoing edge %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "hilang edge %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<noreturn%> function does return"
 msgid "%<noreturn%> function does return"
 msgstr "%H%<noreturn%> fungsi tidak kembali"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "kontrol mencapai akhir dari fungsi bukan void"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -32626,7 +32637,7 @@ msgstr "thread-local COMMON data tidak terimplementasi"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "alignmen yang diminta untuk %q+D lebih besar dari alignmen yang diimplementasikan dari %wu"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
@@ -32800,7 +32811,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported record layout"
@@ -33484,7 +33495,7 @@ msgstr "%qE atribut diabaikan untuk %qE"
 msgid "type was previously declared %qE"
 msgstr "setelah deklarasi sebelumnya %q+D"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -33508,7 +33519,7 @@ msgstr "%qD tidak dideklarasikan dalam %qD"
 msgid "%qE argument is not a function"
 msgstr "membersihkan argumen bukan sebuah fungsi"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
 msgid "deprecated message is not a string"
@@ -33970,12 +33981,12 @@ msgstr "%<@end%> hilang dalam konteks implementasi"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "alamat dari %qD akan selalu dievaluasi sebagai %<true%>"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "disarankan parentheses disekitar assignmen digunakan sebagai nilai kebenaran"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "penggunaan tidak valid dari %<restrict%>"
@@ -34149,13 +34160,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "terlalu banyak argumen ke fungsi %qE"
@@ -35172,7 +35183,7 @@ msgstr "tidak didukung bukan-standar pemotongan dari string literals"
 msgid "traditional C rejects string constant concatenation"
 msgstr "tradisional C menolak pemotongan konstanta string"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -35223,7 +35234,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
@@ -35239,17 +35250,17 @@ msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 msgid "%qE is not initialized"
 msgstr "%qE tidak terinisialisasi"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "hilang predikat pengontrol"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predikat pengontrol tidak valid"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "hilang ekspresi peningkatan"
@@ -35259,7 +35270,7 @@ msgstr "hilang ekspresi peningkatan"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ekspresi peningkatan tidak valid"
@@ -35328,7 +35339,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -35952,8 +35963,8 @@ msgstr ""
 msgid "wrong type argument to %s"
 msgstr "tipe argumen salah ke abs"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow dalam konstanta ekspresi"
@@ -36489,17 +36500,17 @@ msgstr "%s dari fungsi %qD"
 msgid "function %qD used as %<asm%> output"
 msgstr "lokasi baca-saja %qE digunakan sebagai keluaran %<asm%>"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "penempatan dari lokasi baca-saja %qE"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "peningkatan dari lokasi baca-saja %qE"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "pengurangan dari lokasi baca-saja %qE"
@@ -36686,8 +36697,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
@@ -36775,38 +36786,38 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 msgstr[1] "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 #| msgid "used here"
 msgid "defined here"
 msgstr "digunakan disini"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "mismatch in bound %Z of argument %u declared as %s"
@@ -36814,60 +36825,60 @@ msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "Tipe tidak cocok dalam argumen '%s' di %L; dilewatkan %s ke %s"
 msgstr[1] "Tipe tidak cocok dalam argumen '%s' di %L; dilewatkan %s ke %s"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as %s"
 msgstr "deklarasi sebelumnya dari %qs"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr ""
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as a pointer %s"
 msgstr "deklarasi sebelumnya dari %qs"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as an ordinary array %s"
 msgstr "deklarasi sebelumnya dari %qs"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s declared as a pointer"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn if a variable length array is used"
 msgid "previously declared as a variable length array %s"
 msgstr "Peringatkan jika sebuah array dengan panjang bervariabel digunakan"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as an array %s"
 msgstr "deklarasi sebelumnya dari %qs"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %q+D with attribute noinline"
 msgid "previously declared as %s with %u variable bound"
@@ -36875,72 +36886,72 @@ msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "deklarasi sebelumnya dari %q+D dengan atribut noinline"
 msgstr[1] "deklarasi sebelumnya dari %q+D dengan atribut noinline"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "deklarasi sebelumnya dari %qs"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as %s with bound %qs"
 msgstr "deklarasi sebelumnya dari %qs"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s with mismatched bound"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -36956,7 +36967,7 @@ msgstr "\"%s\" bukan sebuah pilihan valid untuk preprosesor"
 msgid "too many input files"
 msgstr "terlalu banyak berkas masukan"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -36990,14 +37001,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s"
@@ -37166,63 +37177,63 @@ msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
@@ -37404,93 +37415,93 @@ msgstr "-mcpu=%s konflik dengan -march=%s"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "could not open temporary response file %s"
 msgid "failed to open temporary file %s for LTO output"
 msgstr "tidak dapat membuka berkas balasan %s sementara"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "%<%s%> 2.95 vtable-compatibility atribut hanya berlaku ketika mengkompile sebuah kext"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "%<%s%> 2.95 vtable-compatibility atribut hanya berlaku ke C++ classes"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "visibility attribute not supported in this configuration; ignored"
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "visibility atribut tidak didukung dalam konfigurasi ini; diabaikan"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "could not open temporary response file %s"
 msgid "failed to open temporary file %s with LTO output"
 msgstr "tidak dapat membuka berkas balasan %s sementara"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 #| msgid "-pg not supported on this platform"
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "-pg tidak didukung dalam platform ini"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, fuzzy, gcc-internal-format
 #| msgid "-mdynamic-no-pic overrides -fpic or -fPIC"
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "-mdynamic-no-pic overrides -fpic atau -fPIC"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD takes one argument only"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, fuzzy, gcc-internal-format
 #| msgid "argument to '-Xlinker' is missing"
 msgid "CFString literal is missing"
 msgstr "argumen ke '-Xlinker' hilang"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "CFString literal expression is not a string constant"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr ""
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "embedded NUL in CFString literal"
@@ -37499,7 +37510,7 @@ msgstr "diduga string literal"
 #: config/host-darwin.c:65
 #, fuzzy, gcc-internal-format
 #| msgid "couldn't unmap pch_address_space: %m"
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "tidak dapat unmap pch_address_space: %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -37645,392 +37656,392 @@ msgstr "%<#pragma GCC optimize%> bukan sebuah string atau angka"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "sampah diakhir dari #pragma GCC java_exceptions"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new tidak dapat diaplikasikan ke sebuah fungsi tipe"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 #| msgid "Link with the fast floating-point library"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "Hubungkan dengan perpustakaan titik pecahan cepat"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code for the counting ISA extension"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Keluarkan kode untuk menghitung ekstensi ISA"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "batasan untuk operan tidak valid"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "nilai %%h tidak valid"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "fungsi spesifikasi '%s' tidak diketahui"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Spesifikasikan pengurutan alokasi register"
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s;"
 msgstr "tipe argumen tidak valid dari %qs"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "pilihan thread pointer tidak valid: -mtp=%s"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "argumen ke %<__builtin_frame_address%> tidak valid"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "argumen ke %<__builtin_frame_address%> tidak valid"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument %qs to -fdebug-prefix-map"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "argumen %qs tidak valid ke -fdebug-prefix-map"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to '%s' option"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "hilang argumen ke pilihan '%s'"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-march%>"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "pilihan thread pointer tidak valid: -mtp=%s"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "pilihan -mcpu=%s konflik dengan pilihan -march="
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s tidak mendukung %s"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "salah bentuk %<#pragma init%>"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argumen bukan sebuah string"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -38100,7 +38111,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "nilai buruk %qs untuk -mmemory-latency"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -38231,18 +38242,18 @@ msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -38699,243 +38710,249 @@ msgstr "target CPU tidak mendukung instruksi THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "target CPU tidak mendukung kode ARM"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "switch -mcpu=%s conflicts with -march= switch"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "pilihan -mcpu=%s konflik dengan pilihan -march="
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check tidak kompatibel dengan -mno-apcs-frame"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic dan -macps-reent tidak kompatibel"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS reentrant kode tidak didukung. Diabaikan"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "ukuran batas struktur hanya dapat diset ke %s"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "ukuran batas struktur hanya dapat diset ke %s"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC tidak kompatibel dengan -msingle-pic-base"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= tidak berguna tanpa -fpic"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "tidak dapat menggunakan '%s' untuk register PIC"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition tidak bekerja dalam arsitektur ini"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable dan -msdata=%s tidak kompatibel"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt membutuhkan sebuah AAPCS kompatibel ABI untuk operasi yang sesuai"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi membutuhkan sebuah iwmmxt kapabel cpu"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "target CPU tidak mendukung kerja-sama"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "target CPU tidak mendukung kerja-sama"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "target CPU tidak mendukung kerja-sama"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "target CPU tidak mendukung instruksi THUMB"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard dan VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE atribut hanya memiliki efek dalam objek publik"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "tidak dapat menghitung lokasi ril dari parameter terstack"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Tidak terduga akhir dari modul"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "tidak ada register bawah yang tersedia unruk popping register atas"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -38944,24 +38961,24 @@ msgstr "tipe vektori tidak valid untuk atribut %qE"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "tipe vektori tidak valid untuk atribut %qE"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "nama register: %s tidak dikenal"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -39053,19 +39070,19 @@ msgstr "-pipe tidak didukung"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe tidak didukung"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G dan -static adalah mutually exclusive"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
@@ -39883,148 +39900,148 @@ msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 msgid "parameter to builtin not valid: %s"
 msgstr "Argumen ke -ffpe-trap tidak valid: %s"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "the third argument must be a 8-bit immediate"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "argumen ketiga harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "argumen selanjutnya ke terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE membutuhkan pilihan isa tidak diketahui"
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE membutuhkan pilihan isa %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 #| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -40047,577 +40064,577 @@ msgstr "ekspresi batas stack tidak didukung"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "model kode %s tidak mendukung kode PIC"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "alias argumen bukan sebuah string"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "atribut SEQUENCE di %C telah dispesifikasikan dalam pernyataan TIPE"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "%s atribut dari '%s' konflik dengan %s atribut di %L"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "terlalu banyak argumen ke fungsi %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "nama register tidak dispesifikasikan untuk %q+D"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= tidak didukung di sistem 32 bit"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mgp64%> used with a 32-bit ABI"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mgp64%> digunakan dengan sebuah ABI 32 bit"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s tidak didukung dalam konfigurasi ini"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bit mode tidak terkompile"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU yang anda pilih tidak mendukung set instruksi x86-64"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "nilai buruk %qs untuk pilihan -mcpu"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "nilai (%s) buruk untuk pilihan %sarch=%s %s"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %<%s%> for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "nilai %<%s%> buruk untuk pilihan -mtune="
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "nilai (%s) buruk untuk %stune=%s %s"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_return_address%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "argumen ke %<__builtin_return_address%> tidak valid"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%sregparm%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-fprefetch-loop-array tidak didukung untuk target ini"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d tidak berada diantara %d dan 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "set instruksi SSE non-aktif, menggunakan 387 aritmetik"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "set instruksi 387 non-aktif, menggunakan aritmetik SSE"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "mengabaikan pilihan tidak dikenal %q.*s dalam %<-fdump-%s%>"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "atribut fastcall dan regparm tidak kompatibel"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "atribut fastcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "atribut ms_abi dan sysv_abi tidak kompatibel"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -41117,7 +41134,7 @@ msgstr "%qs tidak dapat memiliki baik atribut %<mips16%> dan %<nomips16%>"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "%qE attribute requires a string argument"
@@ -42257,62 +42274,62 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -42876,262 +42893,263 @@ msgstr "Gunakan register r2 dan r5"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 membutuhkan arsitektur PowerPC64, mengaktifkan"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires a PowerPC64 cpu"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 membutuhkan sebuah cpu PowerPC64"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "%qs unsupported for this ABI"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power tidak didukung untuk 64 bit Darwin; ini tidak kompatibel dengan perpustakaan C dan C++ yang terpasang"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec tidak didukung dalam target ini"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring tidak didukung di sistem little endian"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-fjni tidak kompatibel dengan -freduced-reflection"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "Using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Menggunakan IEEE ekstended presisi long double"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "Using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Menggunakan IBM ekstended presisi long double"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s tidak mendukung %s"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "unknown vectorization library ABI type (%s) for %sveclibabi=%s %s"
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "perpusatakaan vektorisasi tidak dikenal tipe ABI (%s) untuk pilihan %sveclibabi=%s %s"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "%qs needs a valid base register"
 msgstr "Butuh sebuah call-clobbered target register"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "unknown option for %<%s=%s%>"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "tidak ada profiling dari kode 64 bit untuk ABI ini"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<long double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe boolean dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<complex%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe titik pecahan desimal dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec sudah ditinggalkan; gunakan %<int%>"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<long long%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "tipe abstrak tidak valid %qT untuk %qE"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%<#pragma%> tidak diijinkan disini"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spesifikasi '%s' tidak valid"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -43325,7 +43343,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -43400,217 +43418,223 @@ msgstr "%qs sudah ditinggalkan"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "template argument %d is invalid"
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "template argumen %d tidak valid"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "unresolved overload for Altivec builtin %qF"
 msgid "unresolved overloaded builtin"
 msgstr "tidak teresolf overload untuk Altivec bawaan %qF"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin code"
 msgid "bad builtin icode"
 msgstr "kode bawaan buruk"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "ukuran total dari variabel lokal melebihi batas arsitektur"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "ukuran frame dari %qs adalah "
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs menggunakan alokasi dinamis stack"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia di %s"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Hardware decimal floating point instructions not available on %s"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia di %s"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, fuzzy, gcc-internal-format
 #| msgid "Hardware decimal floating point instructions not available in ESA/390 mode"
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia dalam mode ESA/390"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can't be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp tidak dapat digunakan dalam konjungsi dengan -msoft-float"
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float tidak didukung dalam kombinasi"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "ukuran stack harus lebih besar dari nilai penjaga stack"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "ukuran stack harus lebih besar  dari 64k"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard mengimplikasikan penggunaan dari -mstack-size"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "atribut %qs tidak didukung hanya untuk SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumen ke \"%s\" seharusnya sebuah integer tidak negatif"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -43985,18 +44009,23 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr ""
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "parent subprogram cannot be inlined"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "subprogram %q+F not marked %<Inline%>"
@@ -44074,8 +44103,8 @@ msgstr "%qs atribut hanya berlaku ke variabel"
 msgid "could not read the BRIG file"
 msgstr "tidak dapat menulis ke berkas response %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "nilai void tidak diabaikan karena ini seharusnya"
@@ -44136,7 +44165,7 @@ msgstr "label %q+D didefinisikan tetapi tidak digunakan"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "tipe dari array %q+D dilengkapi secara tidak kompatibel dengan inisialisasi implisit"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "originally defined here"
@@ -44378,7 +44407,7 @@ msgstr "deklarasi dari %q+D membayangi bukan-variabel sebelumnya"
 msgid "declaration of %qD shadows a parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklarasi dari %qD membayangi sebuah deklarasi global"
@@ -44388,7 +44417,7 @@ msgstr "deklarasi dari %qD membayangi sebuah deklarasi global"
 msgid "declaration of %qD shadows a previous local"
 msgstr "deklarasi dari %qD membayangi sebuah lokal sebelumnya"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -44399,232 +44428,232 @@ msgstr "%J membayangi deklarasi ada disini"
 msgid "nested extern declaration of %qD"
 msgstr "deklarasi extern nested dari %qD"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "implisit deklarasi dari fungsi %qE"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "implisit deklarasi dari fungsi %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qE"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "deklarasi implisit tidak kompatibel dari fungsi bawaan %qD"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "deklarasi implisit dari fungsi %qD tidak kompatibel"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function)"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%H%qE tidak dideklarasikan (pertama digunakan dalam fungsi ini)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "%H%qE tidak dideklarasikan (pertama digunakan dalam fungsi ini)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%H(Each undeclared identifier is reported only once"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H (Setiap identifier yang tidak dideklarasikan hanya dilaporkan sekali)"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "label %qE direferensikan diluar dari fungsi apapun"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "melompat kedalam lingkup dari pengidentifikasi dengan tipe variabel dapat dimodifikasi"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "jump skips variable initialization"
 msgstr "  melewati inisialisasi dari %q+#D"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "label %qD defined here"
 msgstr "label %q+D didefinisikan tetapi tidak digunakan"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "melompat kedalam pernyataan ekspresi"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "duplikasi deklarasi label %qE"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "duplikasi label %qD"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, fuzzy, gcc-internal-format
 #| msgid "%Htraditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "%H tradisional C kuran pemisahan ruang nama untuk labels, identifier %qE konflik"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "switch jumps into statement expression"
 msgstr "melompat kedalam pernyataan ekspresi"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE defined as wrong kind of tag"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qE didefinisikan sebagai jenis salah dari tag"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "struct/union tidak bernama yang mendefinisikan no instances"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "deklarasi kosong dengan storage class penspesifikasi tidak redeklarasi tag"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "deklarasi kosong dengan tipe kualifier tidak redeklarasi tag"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration with type qualifier does not redeclare tag"
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "deklarasi kosong dengan tipe kualifier tidak redeklarasi tag"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "nama tipe tidak berguna dalam deklarasi kosong"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> dalam file-scope deklarasi kosong"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> dalam file-scope deklarasi kosong"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "penspesifikasi storage class tidak berguna dalam deklarasi kosong"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "useless type name in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "nama tipe tidak berguna dalam deklarasi kosong"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "tipe kualifier tidak berguna dalam deklarasi kosong"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, fuzzy, gcc-internal-format
 #| msgid "useless %<__thread%> in empty declaration"
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "tidak berguna %<__thread%> dalam deklarasi kosong"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid use of attributes in empty declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "deklarasi kosong"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 tidak mendukung %<static%> atau tipe kualifier dalam parameter array pendeklarasi"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
@@ -44632,29 +44661,29 @@ msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> tidak diijinkan dalam hal lain selain lingkup prototipe fungsi"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D biasanya sebuah fungsi"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD diinisialisasi (lebih baik gunakan __typeof__)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "fungsi %qD diinisialisasi seperti sebuah variabel"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parameter %qD dinisialisasi"
@@ -44663,293 +44692,293 @@ msgstr "parameter %qD dinisialisasi"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "variabel %qD memiliki penginisialisasi tetapi tipe tidak lengkap"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %q+D given attribute %qs"
 msgstr "fungsi inline %q+D memberikan atribut noinline"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "anggota const tidak terinisialisasi %qD"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD should be initialized"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "ukuran array hilang dalam %q+D"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "ukuran array nol atau negatif %q+D"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "ukuran penyimpanan dari %q+D bukan konstant"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "mengabaikan asm-penspesifikasi untuk bukan-statis variabel lokal %q+D"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "tidak dapat meletakan objek dengan bagian volatile kedalam register"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "tidak terinisialisasi const %qD"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C melarang deklarasi parameter kedepan"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "lebar bit-field %qs bukan sebuah konstanta integer"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "lebar bit-field %qs bukan sebuah konstanta integer"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "lebar negatif dalam bit-field %qs"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "lebar nol untuk bit-field %qs"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "tidak dapat mendeklarasikan bit-field %qD dengan tipe fungsi"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "tipe dari bit-field  %qs adalah sebuah ekstensi GCC"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "lebar dari %qs melebihi tipenya"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs lebih kecil dari nilai dari tipenya"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 melarang array %qs yang ukurannya tidak dapat dievaluasi"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 melarang array yang ukurannya tidak dapat dievaluasi"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qs"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 melarang array dengan panjang bervariabel %qs"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 melarang array dengan panjang bervariabel"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified %qE at file scope"
 msgstr "variabel dimodifikasi %qs di lingkup berkas"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified field at file scope"
 msgstr "variabel dimodifikasi %qs di lingkup berkas"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "tipe baku ke %<int%> dalam deklarasi dari %qs"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in type name"
 msgstr "tipe baku ke %<int%> dalam deklarasi dari %qs"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "duplikasi %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "duplikasi %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "duplikasi %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "duplikasi %<restrict%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name %qs"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "konflik nama super class %qs"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "definisi fungsi dideklarasikan %<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "definisi fungsi dideklarasikan %<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "definisi fungsi dideklarasikan %<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "definisi fungsi dideklarasikan %<auto%>"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field %qE"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for parameter %qE"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "class penyimpanan dispesifikasikan untuk nama tipe"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs has both %<extern%> and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<auto%>"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "deklarasi lingkup-berkas dari %qs menspesifikasikan %<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<register%>"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "deklarasi lingkup-berkas dari %qs menspesifikasikan %<register%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested function %qE declared %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -44958,790 +44987,790 @@ msgstr "lingkup-fungsi %qs secara implisit auto dan dideklarasikan %<__thread%>"
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "statis atau tipe kualifier dalam array pendeklarasi bukan parameter"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "ukuran dari array %qs memiliki tipe bukan integer"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "ukuran dari array %qs memiliki tipe bukan integer"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "size of array %qE has incomplete type"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "size of unnamed array has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array %qs"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C melarang array berukuran-nol %qs"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ melarang array berukuran-nol"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE is negative"
 msgstr "ukuran dari array %qs adalah negatif"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "ukuran dari array negatif"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array %qE is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is too large"
 msgid "size of unnamed array is too large"
 msgstr "ukuran dari array terlalu besar"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "tipe array memiliki tipe elemen tidak lengkap"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "definisi fungsi memiliki pengkualifikasi tipe kembali void"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C melarang pengkualifikasi tipe fungsi"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C melarang pengkualifikasi tipe fungsi"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type qualifiers for %q+D"
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "tipe konfliks kualifier untuk %q+D"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%qs specified for auto variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for parameter %qE"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field %qE"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for parameter %qE"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> diaplikasikan ke sebuah bit-field"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C melarang tipe fungsi const atau volatile"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "sebuah anggota dari sebuah struktur atau union tidak dapat memiliki sebuah tipe variabel termodifikasi"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel atau field %qE dideklarasikan void"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "atribut dalam parameter pendeklarasi array diabaikan"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parameter %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parameter %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "field %qE declared as a function"
 msgstr "field %qs dideklarasikan sebagai sebuah fungsi"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "field %qs memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid storage class for function %qE"
 msgstr "class penyimpanan tidak valid untuk fungsi %qs"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "tidak dapat inline fungsi %<main%>"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variabel sebelumnya dideklarasikan %<static%> diredeklarasi %<extern%>"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "melompat kedalam lingkup dari pengidentifikasi dengan tipe variabel dapat dimodifikasi"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "objek dengan tipe variabel termodifikasi harus tidak memiliki hubungan"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "deklarasi fungsi bukan sebuah prototipe"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "nama parameter (tanpa tipe) dalam deklarasi fungsi"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parameter %u (%q+D) memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "%J parameter %u memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parameter %u (%q+D) memiliki tipe void"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has void type"
 msgid "parameter %u has void type"
 msgstr "%J parameter %u memiliki tipe void"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> hanya memiliki parameter tidak boleh dikualifikasikan"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> harus menjadi parameter satu satunya"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parameter %q+D hanya memiliki sebuah deklarasi kedepan"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "enum type defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "struct defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "union defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "redefinisi dari %<union %E%>"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "redefinisi dari %<struct %E%>"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "nested redefinisi dari %<union %E%>"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "nested redefinisi dari %<struct %E%>"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C tidak mendukung structs/unions tidak bernama"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C tidak mendukung structs/unions tidak bernama"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "duplikasi anggota %q+D"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union tidak memiliki anggota bernama"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union tidak memiliki anggota"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct tidak memiliki anggota bernama"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct tidak memiliki anggota"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union tidak dapat dibuat transparan"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "nested redefinisi dari %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeklarasi dari %<enum %E%>"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "mode yang dispesifikasikan terlalu kecil untuk nilai enumerasi"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "nilai enumerasi melebihi jangkauan dari integer terbesar"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "nilai pengenumerasi untuk %qE bukan sebuah konstanta integer"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "nilai pengenumerasi untuk %qE bukan sebuah konstanta integer"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "overflow dalam nilai enumerasi"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C melarang nilai pengenumerasi ke jangkauan dari %<int%>"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "fungsi inline %q+D memberikan atribut noinline"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "tipe kembali adalah sebuah tipe tidak lengkap"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "tipe baku kembali ke %<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "Peringatkan mengenai fungsi global tanpa prototipe"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "tidak ada prototipe sebelumnya untuk %q+D"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
 msgstr "tidak deklarasi sebelumnya untuk %q+D"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D telah digunakan tanpa deklarasi sebelum definisinya"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "tipe kembali dari %q+D bukan %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D secara normal sebuah fungsi bukan-statis"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%J deklarasi parameter gaya lama dalam definisi fungsi prototipe"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%J tradisional C menolak gaya ISO C definisi fungsi"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr ""
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%J definisi fungsi gaya-lama"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%J nama parameter hilang dari daftar parameter"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "multiple parameter bernama %q+D"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "tipe dari %q+D baku ke %<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "parameter %q+D memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "deklarasi untuk parameter %q+D tetapi tidak ada parameter seperti itu"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "jumlah dari argumen tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "jumlah dari argumen tidak cocok prototipe"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "deklarasi prototipe"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "argumen dipromosikan %qD tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "argumen dipromosikan %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -45750,278 +45779,278 @@ msgstr "parameter %qD dinisialisasi"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> deklarasi inisial loop hanya diijinkan dalam mode C99"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "gunakan pilihan -std=c99 atau -std=gnu99 untuk mengkompile kode anda"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel statis %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari bukan-variabel %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dua atau lebih tipe data dalam penspesifikasi deklarasi"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> terlalu panjang untuk GCC"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "duplikasi %qE"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support fixed-point types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support saturating types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C tidak mendukung titik pecahan desimal"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "tipe titik tetap tidak didukung untuk target ini"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE gagal untuk menjadi sebuah typedef atau tipe bawaan"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE tidak berada di awal dari deklarasi"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> digunakan dengan %<auto%>"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> digunakan dengan %<register%>"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> digunakan dengan %<typedef%>"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s tidak mendukung %s"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> sebelum %<extern%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> sebelum %<static%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "multiple class penyimpanan dalam deklarasi penspesifikasi"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> digunakan tanpa %<_Fract%> atau %<_Accum%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C tidak mendukung tipe integer kompleks"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "jumlah geser kiri >= lebar dari tipe"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "jumlah geser kanan >= lebar dari tipe"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "jumlah geser kiri >= lebar dari tipe"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -46043,7 +46072,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -46054,7 +46083,7 @@ msgstr "Tidak terduga akhir dari modul"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C melarang sebuah satuan terjemahan kosong"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
@@ -46093,7 +46122,7 @@ msgid "unknown type name %qE"
 msgstr "nama register: %s tidak dikenal"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "diduga penspesifikasi deklarasi"
@@ -46115,7 +46144,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -46133,7 +46162,7 @@ msgstr "atribut diabaikan di template instantiation"
 msgid "unexpected attribute"
 msgstr "Diduga nama atribut bit"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -46175,7 +46204,7 @@ msgstr "%<auto%> dalam file-scope deklarasi kosong"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "diduga %<,%> atau %<,%>"
@@ -46239,7 +46268,7 @@ msgstr "ekspresi integral %qE bukan konstan"
 msgid "static assertion failed: %E"
 msgstr "static assertion gagal: %E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -46289,14 +46318,14 @@ msgstr "template argumen %d tidak valid"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "diduga pengidentifikasi"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "koma di akhir dari daftar pengenumerasi"
@@ -46384,7 +46413,7 @@ msgstr "diduga deklarasi penspesifikasi atau %<...%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "parameter pack harus berada di akhir dari daftar parameter"
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute does not take any arguments"
@@ -46446,7 +46475,7 @@ msgstr "ISO C90 melarang pencampuran deklarasi dan kode"
 msgid "expected %<}%> before %<else%>"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> tanpa sebuah sebelumnya %<if%>"
@@ -46461,7 +46490,7 @@ msgstr "label diakhir dari pernyataan compound"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "diduga pernyataan"
@@ -46486,17 +46515,17 @@ msgstr "diduga pengidentifikasi atau %<*%>"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr ""
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<if%>"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<else%>"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -46519,12 +46548,12 @@ msgstr "multiple atribut interupsi tidak diijinkan"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "register tidak valid dalam instruksi"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -46541,8 +46570,8 @@ msgstr "hilang sentinel dalam pemanggilan fungsi"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -46573,12 +46602,12 @@ msgstr "ISO C melarang mengabaikan term tengah dari sebuah ekspresi ?:"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -47009,12 +47038,12 @@ msgstr "diduga penspesifikasi deklarasi"
 msgid "no type or storage class may be specified here,"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -47026,56 +47055,56 @@ msgstr "hilang atribut Code"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected %qE selector name"
 msgstr "diduga nama class"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
@@ -47086,19 +47115,19 @@ msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "terlalu banyak %qs clauses"
@@ -47120,59 +47149,59 @@ msgstr "diduga %<,%> atau %<,%>"
 msgid "%qD is not a variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -47195,123 +47224,123 @@ msgstr "%<num_threads%> nilai harus positif"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "diduga ekspresi integer"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Elemen tidak diduga"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta integer"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<concurrent%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "baik %<long%> dan %<void%> dalam penspesifikasi deklarasi"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "jadwal %<runtime%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "penjadwalan %<auto%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "jenis penjadwalan tidak valid"
@@ -47322,19 +47351,19 @@ msgstr "jenis penjadwalan tidak valid"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -47357,25 +47386,25 @@ msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "topeng tidak valid"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -47393,86 +47422,86 @@ msgstr "jenis penjadwalan tidak valid"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -47489,7 +47518,7 @@ msgstr "%H%qE belum pernah dideklarasikan"
 msgid "expected function name"
 msgstr "diduga nama class"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -47500,28 +47529,28 @@ msgstr "%q+D bukan sebuah fungsi,"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<allocator%>"
@@ -47532,92 +47561,92 @@ msgstr "diduga %<{%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable tidak lagi didukung"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "diduga %<:%>, %<,%>, %<,%>, %<}%> atau %<__attribute__%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "diduga %<:%>, %<,%>, %<,%>, %<}%> atau %<__attribute__%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -47627,34 +47656,34 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "diduga iterasi deklarasi atau inisialisasi"
@@ -47664,76 +47693,76 @@ msgstr "diduga iterasi deklarasi atau inisialisasi"
 msgid "not enough perfectly nested loops"
 msgstr "tidak cukup secara sempurna nested loops"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "collapsed loops tidak secara sempurna nested"
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> hanya memiliki parameter tidak boleh dikualifikasikan"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -47749,64 +47778,64 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "expected trait selector name"
 msgstr "Diduga nama atribut bit"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, fuzzy, gcc-internal-format
 #| msgid "constructor not allowed for non-vector types"
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "konstruktor tidak diperbolehkan untuk tipe bukan-vektor"
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be an immediate"
 msgid "score argument must be non-negative"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "diduga string literal"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "property must be constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<match%>"
@@ -47818,13 +47847,13 @@ msgstr "diduga %<{%>"
 msgid "variant %qD is not a function"
 msgstr "%q+D bukan sebuah fungsi,"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -47834,34 +47863,34 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -47920,44 +47949,44 @@ msgstr "diduga pengidentifikasi atau %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "diduga %<=%>, %<,%>, %<,%>, %<asm%> atau %<__attribute__%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -47973,27 +48002,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction%>"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE memiliki tipe tidak lengkap"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -48003,7 +48032,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -48020,7 +48049,7 @@ msgstr "%Hparallel yang melingkupi"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "penggunaan tidak valid dari ekspresi void"
@@ -48064,135 +48093,135 @@ msgstr "atribut `%s' tidak dapat dispesifikasikan untuk variabel lokal"
 msgid "function types not truly compatible in ISO C"
 msgstr "tipe fungsi tidak benar benar kompatibel dalam ISO C"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and vector types"
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "tidak dapat mencampurakan operan dari tipe desimal float dan vektor"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and complex types"
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "tidak dapat mencampurakan operan dari tipe desimal float dan kompleks"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and other float types"
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "tidak dapat mencampurkan operan dari tipe desimal float dan tipe lainnya"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "tipe tidak benar benar kompatibel"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "pointer target types incompatible in C++"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "tipe kembali fungsi tidak kompatibel karena %<volatile%>"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr ""
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "meminta untuk anggota %qE dalam sesuatu bukan sebuah struktur atau union"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscrip bukan sebuah integer"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "nilai subscripted adalah penunjuk ke fungsi"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C melarang subscripting %<register%> array"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C90 melarang subscripting array bukan lvalue"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "called object %qE is not a function or function pointer"
 msgstr "dipanggil objek %qE bukan sebuah fungsi"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "called object %qD is not a function or function pointer"
 msgstr "dipanggil objek %qE bukan sebuah fungsi"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "called object is not a function or function pointer"
@@ -48201,1725 +48230,1725 @@ msgstr "dipanggil objek %qE bukan sebuah fungsi"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "fungsi dipanggil melalui sebuah tipe tidak kompatibel"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "function definition has qualified void return type"
 msgid "function with qualified void return type called"
 msgstr "definisi fungsi memiliki pengkualifikasi tipe kembali void"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "tipe dari parameter format %d tidak lengkap"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai integer daripada pecahan karena ada prototipe"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai integer daripada kompleks kerana ada prototipe"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai kompleks daripada pecahan kerana ada prototipe"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai pecahan daripada integer karena ada prototipe"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai kompleks daripada integer karena ada prototipe"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai pecahan daripada kompleks karena ada prototipe"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai %<float%> daripada %<double%> karena adaprototipe"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai %qT daripada %qT karena ada prototipe"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "melewatkan argumen %d dari %qE dengan lebar berbeda karena ada prototipe"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai unsigned karena ada prototipe"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "melewatkan argumen %d dari %qE sebagai signed karena ada prototipe"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to method %qE"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "perbandingan dengan string literal menghasilkan perilaku yang tidak dispesifikasikan"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "perbandingan diantara penunjuk dan integer"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
 msgstr "casting %qT ke %qT tidak medereferensi penunjuk"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between %q#T and %q#T"
 msgid "comparison between %qT and %qT"
 msgstr "perbandingan antara %q#T dan %q#T"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "tipe dari penunjuk %<void *%> digunakan dalam pengurangan"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "penunjuk ke sebuah fungsi digunakan dalam pengurangan"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from boolean expression"
 msgid "%<~%> on a boolean expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C tidak mendukung %<~%> untuk konjugasi kompleks"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "tipe argumen salah ke abs"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "tipe argumen salah ke unary exclamation mark"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from boolean expression"
 msgid "increment of a boolean expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from boolean expression"
 msgid "decrement of a boolean expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C tidak mendukung %<++%> dan %<--%> di tipe kompleks"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "tipe argumen salah ke peningkatan"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "tipe argumen salah ke pengurangan"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of expression of type %<void%>"
 msgstr "memakai alamat dari sementara"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "tidak dapat mengambil alamat dari bit-field %qD"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "alamat dari variabel register %qD diminta"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "variabel global register %qD digunakan dalam fungsi nested"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "alamat dari variabel global register %qD diminta"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "alamat dari variabel register %qD diminta"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "array bukan lvalue dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C melarang kondisional ekspresi dengan hanya satu sisi void"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "tipe penunjuk tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "tipe penunjuk tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C melarang kondisional ekpsresi diantara %<void *%> dan penunjuk fungsi"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "tipe penunjuk tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "tipe penunjuk tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "tipe penunjuk/integer tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "tipe tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "in call to %qD, declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 #, fuzzy
 #| msgid "cast adds new qualifiers to function type"
 msgid "cast adds %q#v qualifier to function type"
 msgstr "cast menambahkan kualifier baru ke tipe fungsi"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "cast mengabaikan kualifier dari tipe target penunjuk"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "cast menspesifikasikan tipe array"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "cast menspesifikasikan tipe fungsi"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C melarang casting bukan skalar ke tipe yang sama"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO melarang cast ke tipe union"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "cast ke tipe union dari tipe yang tidak ada dalam union"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "cast meningkatkan alignmen yang dibutuhkan dari tipe target"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "cast dari penunjuk ke integer dari ukuran berbeda"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "cast dari panggilan fungsi dari tipe %qT ke tipe yang tidak cocok %qT"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast ke penunjuk dari integer dari ukuran yang berbeda"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C melarang konversi dari fungsi penunjuk ke tipe objek penunjuk"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C melarang konversi dari objek penunjuk ke tipe fungsi penunjuk"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "tidak dapat mengubah dari tipe tidak lengkap %qT ke %qT"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "penekanan penempatan"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(dekat inisialisasi untuk %qs)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "array terinisialisasi dari konstanta string bertanda-petik"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "diduga %qT tetapi argumen memiliki tipe %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "built-in %qD declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "target penunjuk dalam melewatkan argumen %d dari %qE berbeda dalam signedness"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "implicit conversion from %qT to %qT"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 #, fuzzy
 #| msgid "passing argument %d of %qE makes qualified function pointer from unqualified"
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "melewatkan argumen %d dari %qE membuat fungsi penunjuk terkualifikasi dari tidak terkualifikasi"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 #, fuzzy
 #| msgid "assignment makes qualified function pointer from unqualified"
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "penempatan membuat fungsi penunjuk terkualifikasi dari tidak terkualifikasi"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 #, fuzzy
 #| msgid "initialization makes qualified function pointer from unqualified"
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "inisialisasi membuat fungsi penunjuk terkualifikasi dari tidak terkualifikasi"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 #, fuzzy
 #| msgid "return makes qualified function pointer from unqualified"
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "return membuat fungsi penunjuk terkualifikasi dari tidak terkualifikasi"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 #, fuzzy
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 #, fuzzy
 #| msgid "assignment discards qualifiers from pointer target type"
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "penempatan mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 #, fuzzy
 #| msgid "initialization discards qualifiers from pointer target type"
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "inisialisasi mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 #, fuzzy
 #| msgid "return discards qualifiers from pointer target type"
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "return mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C melarang konversi argumen ke tipe union"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "melewatkan argumen %d dari %qE dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "cast dari penunjuk ke integer dari ukuran berbeda"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "inisialisasi dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "inisialisasi sisi tangan kiri mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "melewatkan argumen %d dari %qE dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr ""
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C melarang melewatkan argumen %d dari %qE diantara fungsi penunjuk dan %<void *%>"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C melarang penempatan diantara fungsi penunjuk dan %<void *%>"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C melarang inisialisasi diantara fungsi penunjuk dan %<void *%>"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C melarang kembali diantara fungsi penunjuk dan %<void *%>"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "target penunjuk dalam melewatkan argumen %d dari %qE berbeda dalam signedness"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "target penunjuk dalam assignmen berbeda dalam signedness"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "target penunjuk dalam inisialisasi berbeda dalam signedness"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "target penunjuk dalam melewatkan argumen %d dari %qE berbeda dalam signedness"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "melewatkan argumen %d dari %qE dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "penempatan dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "inisialisasi dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "inisialisasi dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "return from incompatible pointer type"
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "kembali dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "melewatkan argumen %d dari %qE membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "penempatan membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "inisialisasi membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "melewatkan argumen %d dari %qE membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "melewatkan argumen %d dari %qE membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "penempatan membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "inisialisasi membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "melewatkan argumen %d dari %qE membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "tipe tidak kompatibel dalam penempatan ke tipe %qT dari tipe %qT"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "tipe tidak kompatibel ketika menginisialisasi tipe %qT menggunakan tipe %qT"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "tipe tidak kompatibel ketika mengembalikan tipe %qT tetapi %qT telah diduga"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "tradisional C menolak inisialisasi otomatis bersama"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "array dari tipe yang tidak sesuai terinisialisasi dari konstanta string"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "penggunaan tidak valid dari bukan-lvalue array"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "elemen penginisialisasi bukan sebuah konstanta"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "array terinisialisasi dari ekspresi array bukan-konstanta"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer element is not a constant expression"
 msgstr "elemen penginisialisasi bukan sebuah konstanta"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "elemen penginisialisasi tidak dapat dihitung di waktu load"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "penginisialisasi tidak valid"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "kelebihan grup kurung diakhir dari penginisialisasi"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "kurung disekitar penginisialisasi skalar"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inisialisasi dari anggota array fleksibel dalam sebuah konteks bertelur"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "hilang kurung disekitar penginisialisasi"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "missing initializer for field %qD of %qT"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "penginisialisasi skalar kosong"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "kelebihan elemen dalam penginisialisasi skalar"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "indeks array dalam penginisialisasi bukan-array"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "nama bagian tidak dalam rekaman atau union penginisialisasi"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "indeks array dalam penginisialisasi bukan tipe integer"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer not of integer type"
 msgid "array index in initializer is not an integer constant expression"
 msgstr "indeks array dalam penginisialisasi bukan tipe integer"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "indeks array dalam penginisialisasi melebihi batasan array"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "jangkauan indeks kosong dalam penginisialisasi"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "jangkauan indeks array dalam penginisialisasi melebihi batasan array"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "bagian terinisialisasi dengan efek-samping overwritten"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "bagian terinisialisasi overwritten"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, fuzzy, gcc-internal-format
 #| msgid "Perform conversions of switch initializations."
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "Lakukan konversi dari kondisional switch."
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "kelebihan elemen dalam char array penginisialisasi"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "kelebihan elemen dalam struktur penginisialisasi"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "inisialisasi tidak statis dari sebuah anggota array fleksibel"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "kelebihan elemen dalam penginisialisasi union"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "tradisional C menolah inisialisasi dari unions"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "kelebihan elemen dalam array penginisialisasi"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "kelebihan elemen dalam penginisialisasi vektor"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "kelebihan elemen dalam penginisialisasi skalar"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C melarang %<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> dengan tidak ada nilai, dalam fungsi mengembalikan bukan void"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> dengan sebuah nilai, dalam fungsi mengembalikan void"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C melarang %<return%> dengan ekspresi, dalam fungsi mengembalikan void"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "fungsi mengembalikan alamat dari variabel lokal"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch kuantiti bukan sebuah integer"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "pilihan %<long%> ekspresi tidak diubah ke %<int%> dalam ISO C"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "case label is not an integer constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> label tidak dalam sebuah pernyataan switch"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "pernyataan break tidak dalam loop atau switch"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "exit tidak valid dari blok struktur OpenMP"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "pernyataan break digunakan dengan OpenMP untuk loop"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "pernyataan continue tidak dalam sebuah loop"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "pernyataan dengan tidak ada efek"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "Peringatkan mengenai perbandingan dari tipe enum yang berbeda"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "membandingkan titik pecahan dengan == atau != adalah tidak aman"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of distinct pointer types lacks a cast"
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "perbandingan dari tipe penunjuk berbeda kurang sebuah cast"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C melarang perbandingan dari %<void *%> dengan fungsi penunjuk"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "perbandingan dari tipe penunjuk berbeda kurang sebuah cast"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "perbandingan diantara penunjuk dan integer"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "perbandingan dari penunjuk lengkap dan tidak lengkap"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C melarang perbandingan terurut dari penunjuk ke fungsi"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with null pointer"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "menggunakan array yang tidak dapat diubah ke penunjuk dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "menggunakan nilai tipe struct dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "menggunaka nilai tipe union dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, fuzzy, gcc-internal-format
 #| msgid "used struct type value where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "menggunakan nilai tipe struct dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many %qs clauses"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%Hterlalu banyak %qs clauses"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many %qs clauses"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%Hterlalu banyak %qs clauses"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected single pointer in %qs clause"
 msgstr "diduga string literal"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "zero length array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "negative length in array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Salin bagian array kedalam sebuah blok kontinu dalam masukan prosedur"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qE does not have pointer or array type"
 msgstr "%H%qE tidak memiliki tipe kelas"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "melemparkan KOSONG, yang memiliki integral, bukan tipe penunjuk"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "iterator %qD has const qualified type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "bit-field %qD dengan tipe bukan integral"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected pointer in %qs clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "zero sized type %qT in %qs clause"
 msgstr "Ukuran array yang diasumsikan '%s' dalam %s clause di %L"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "variable sized type %qT in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction(%s)%>"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE harus berupa %<threadprivate%> untuk %<copyin%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%qs variable is not a pointer"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "argumen pertama ke %<va_arg%> bukan dari tipe %<va_list%>"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -50159,7 +50188,7 @@ msgstr "  untuk konversi dari %qT ke %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -50282,740 +50311,746 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%D(%A)%> adalah ambigu"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "pointer-ke-anggota fungsi %E tidak dapat dipanggil tanpa sebuah objek; pertimbangkan menggunakan .* atau ->*"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "tidak ada yang cocok untuk panggilan ke %<(%T) (%A)%>"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "panggilan dari %<(%T) (%A)%> adalah ambigu"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "konversi ambigu untuk array subscript"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "operan ke binari %s tidak valid (memiliki %qT dan %qT)"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "operan ke binari %s tidak valid (memiliki %qT dan %qT)"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Operator pengguna:\n"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "%s for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s untuk ternary %<operator?:%> dalam %<%E ? %E : %E%>"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Operator buruk"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s untuk %<operator%s%> dalam %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Operator buruk"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s untuk %<operator[]%> dalam %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%s untuk %qs dalam %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 #| msgid "  or %<operator=(const %T&)%>"
 msgid "%<operator %s%>"
 msgstr "  atau %<operator=(const %T&)%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ melarang mengabaikan term tengah dari sebuah ekspresi ?:"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "enumeral tidak cocok dalam ekspresi kondisional: %qT vs %qT"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "operan kedua ke operator kondisional bertipe %<void%>, tetapi operan ketika bukan sebuah throw-expression ataupun bertipe %<void%>"
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "operan ketiga ke opertor kondisional bertipe %<void%>, tetapi operan kedua bukan sebuah throw-expression ataupun bertipe %<void%>"
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "operan ke ?: memiliki tipe berbeda %qT dan %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "enumeral tidak cocok dalam ekspresi kondisional: %qT vs %qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "tipe kembali dari %q+D bukan %<int%>"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "perbandingan antara %q#T dan %q#T"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%q+D secara normal sebuah fungsi bukan-statis"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "tidak ada dealokasi fungsi yang berhubungan untuk %qD"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "tidak cocok %<operator %s%> untuk %qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D tidak dapat diakses"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "melewatkan koson ke argumen bukan penunjuk %P dari %qD"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "  declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "mengubah ke tipe bukan penunjuk %qT dari KOSONG"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 #| msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  inisialisasi argumen %P dari %qD"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "terlalu banyak kurung diantara penginisialisasi untuk %qT"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "mengubah ke %qT untuk daftar penginisialisasi akan menggunakan konstruktor eksplist %qD"
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+#| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
+
+#: cp/call.c:7911
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "tidak dapat mengikat bitfield %qE ke %qT"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "tidak dapat mengikat packed field %qE ke %qT"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "tidak dapat mengikat rvalue %qE ke %qT"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "tidak dapat melewatkan objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "tidak dapat menerima objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluasi rekursi dari argumen baku untuk %q#D"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumen baku untuk parameter %d dari %qD belum diparse"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "melewatkan %qT sebagai %<this%> argumen dari %q#D mengabaikan kualifier"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dalam panggilan ke %qD"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT bukan sebuah dasar yang bisa diakses dari %qT"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "; use value-initialization instead"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "; use copy-initialization instead"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "mangling function-style cast with more than one argument"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "mangling function-style cast dengan lebih dari satu argumen"
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%s(%A)%> adalah ambigu"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "tidak dapat memanggil anggota fungsi %qD tanpa objek"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "melewatkan %qT memilih %qT diatas %qT"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "memilih %qD diatas %qD"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  karena urutan konversi untuk argumen lebih baik"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "argumen baku tidak cocok dalam kelebihan beban resolusi"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q+#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q+#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ mengatakan bahwa ini adalah ambigu, meskipun melalui konversi terburuk untuk yang pertama lebih baik daripada konversi terburuk untuk yang kedua:"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -51045,1253 +51080,1253 @@ msgstr "tidak dapat mengubah dari dasar %qT ke tipe turunan %qT melalui basis ma
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "tidak dapat mengubah dari dasar %qT ke tipe turunan %qT melalui basis maya %qT"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "tidak dapat mengubah dari dasar %qT ke tipe turunan %qT melalui basis maya %qT"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D konflik dengan deklarasi sebelumnya menggunakan %q#D"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D tidak dapat overloaded"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
 msgstr "deklarasi sebelumnya %q+D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "spesifikasi akses konflik untuk metoda %q+D, diabaikan"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "spesifikasi akses konflik untuk field %qE, diabaikan"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  karena dari metoda lokal %q+#D dengan nama sama"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local method %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  karena dari anggota lokal %q+#D dengan nama sama"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "tidak dapat mengubah dari dasar %qT ke tipe turunan %qT melalui basis maya %qT"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "semua anggota fungsi dalam kelas %qT adalah private"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T hanya mendefinisikan sebuah desktruktor private dan tidak memiliki teman"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T hanya mendefinisikan konstruktor private dan tidak memiliki teman"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "tidak ada unik final overrider untuk %qD dalam %qT"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D tidak dapat overloaded"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D telah disembunyikan"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  oleh %q+D"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous union hanya dapat mempunnya anggota data tidak statis"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bit-field %q+#D dengan tipe bukan integral"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bit-field %q+D lebar bukan sebuah konstanta integer"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "lebar negatif dalam bit-field %q+D"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "lebar nol untuk bit-field %q+D"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "lebar dari %q+D melebihi tipenya"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D terlalu kecil untuk menjaga seluruh nilai dari %q#T"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "anggota %q#D dengan konstruktor tidak diijinkan dalam union"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam union"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "anggota %q+#D dengan penempatan salinan operator tidak diijinkan dalam union"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D mungkin bukan statis karena ini adalah anggota dari sebuah union"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "field %q+D secara tidak valid mendeklarasikan tipe fungsi"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "mengabaikan atribut packed karena dari unpacked non-POD field %q+#D"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "multiple field dalam union %qT tida terinisialisasi"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "field %q+#D dengan nama sama seperti class"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T memiliki anggota data penunjuk"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  tetapi tidak override %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  atau %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  tetapi tidak override %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "penginisialisasi dispesifikasikan untuk metode %q+D bukan virtual"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "Java class %qT tidak dapat memiliki sebuah destruksi"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %qD has volatile type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "referensi bukan-statis %q+#D dalam kelas tanpa sebuah konstruktor"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "anggota const bukan-statis %q+#D dalam kelas tanpa sebuah konstruktor"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direct base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtual base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "ofset dari %q+D adalah bukan ABI komplian dan mungkin berubah dalam versi GCC yang akan datang"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "redefinisi dari %q#T"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinisi dari %q#T"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T memiliki fungsi maya dan dapat diakses bukan virtual desktruktor"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "tipe %qs memiliki anggota fungsi virtual"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#D is marked %<dllimport%>"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "definisi dari %q#D ditandai %<dllimport%>"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "mencoba menyelesaikan struct, tetapi ditendang keluar karena error parse sebelumnya"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "bahasa string %<\"%E\"%> tidak dikenal"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "tidak dapat meresolf fungsi overloaded %qD berdasar dari konversi ke tipe %qT"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "tidak cocok mengubah fungsi %qD ke tipe %q#T"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "mengubah fungsi overloaded %qD ke tipe %q#T adalah ambigu"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "mengasumsikan penunjuk ke anggota %qD"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tidak cukup informasi mengenai tipe"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "tidak dapat mengubah %qE dari tipe %qT ke tipe %qT"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
 msgstr "redeklarasikan disini sebagai %q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr ""
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type %qT"
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "parameter mungkin tidak memiliki tipe variabel termodifikasi %qT"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "tipe kembali dari %q+D bukan %<int%>"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract return type for function %q+#D"
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "tipe kembali abstrak tidak valid untuk fungsi %q+#D"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract return type for function %q+#D"
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "tipe kembali abstrak tidak valid untuk fungsi %q+#D"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#T has virtual base classes"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%J kelas dasar %q#T seharusnya secara eksplisit diinisialisasikan dalam konstruktor salinan"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%q+E is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr ""
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a base type for type %qT"
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "tipe %qT bukan sebuah basis tipe untuk tipe %qT"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr ""
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, gcc-internal-format
 msgid "allocation performed here"
 msgstr ""
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, fuzzy, gcc-internal-format
 #| msgid "Attempting to allocate already allocatedarray"
 msgid "deallocation of already deallocated storage"
 msgstr "Mencoba untuk mengalokasikan array yang telah dialokasikan"
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a previous local"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "deklarasi dari %qD membayangi sebuah lokal sebelumnya"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 #| msgid "PARAMETER '%s' is used at %L before its definition is complete"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "PARAMTER '%s' digunakan di %L sebelum definisinya lengkap"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokol %qs memiliki ketergantungan circular"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini adalah sebuah penunjuk"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "parameter template %qD dari tipe %qT tidak diijinkan dalam sebuah ekspresi konstanta integral karena ini bukan tipe integral atau enumerasi"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%s tidak digunakan dalam asm disini"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "allocated here"
 msgstr "dipanggil dari sini"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not initialized"
 msgid "%qD used in its own initializer"
 msgstr "%qE tidak terinisialisasi"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D adalah private"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD belum pernah dideklarasikan dalam lingkup ini"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "inline assembly is not a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "tipe tidak lengkap %qT tidak diijinkan"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got %qE"
 msgid "unexpected template-id %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 #| msgid "non-function in gimple call"
 msgid "function concept must be called"
 msgstr "bukan fungsi dalam panggilan gimple"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "diduga ekspresi"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow dalam konstanta ekspresi"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "label definition is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -52302,57 +52337,57 @@ msgstr "Tidak terduga akhir dari berkas dalam '%s'"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "alamat dari %qD akan selalu dievaluasi sebagai %<true%>"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT bukan sebuah tipe kelas"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%H%qE tidak memiliki tipe kelas"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qD does not have integral type"
 msgstr "%H%qE tidak memiliki tipe kelas"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -52406,7 +52441,7 @@ msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe s
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "casting %qT ke %qT tidak medereferensi penunjuk"
@@ -52837,7 +52872,7 @@ msgstr "dari deklarasi sebelumnya %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -52990,8 +53025,8 @@ msgstr "deklarasi sebelumnya bukan fungsi %q+#D"
 msgid "%q#D previously defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously declared here"
@@ -53032,60 +53067,60 @@ msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 msgid "previous specification in %q#D here"
 msgstr "setelah spesifikasi sebelumnya dalam %q+#D"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of namespace %qD conflicts with"
 msgid "declaration %qD conflicts with builtin"
 msgstr "deklarasi dari namespace %qD konflik dengan"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of namespace %qD conflicts with"
 msgid "declaration %qD conflicts with import"
 msgstr "deklarasi dari namespace %qD konflik dengan"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "import declared %q#D here"
 msgstr "deklarasi sebelumnya %q+#D disini"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting declaration %qD"
 msgstr "konflik deklarasi %q#D"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %q#D here"
 msgstr "deklarasi sebelumnya %q+#D disini"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "definisi sebelumnya dari %q+D ada disini"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "deklarasi sebelumnya dari %q+D ada disini"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "function declared %<noreturn%> has a %<return%> statement"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "deklarasi redundansi dari %qD dalam lingkup sama"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %qD is not first declaration"
@@ -53099,55 +53134,55 @@ msgstr "definisi terhapus dari %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D: atribut visibility diabaikan karenanya"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "redefinition of %q#D"
 msgstr "redefinisi dari %q#T"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D konflik dengan deklarasi sebelumnya menggunakan %q#D"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%q#D not declared in class"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, fuzzy, gcc-internal-format
 #| msgid "%qs redeclared with conflicting %qs attributes"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, fuzzy, gcc-internal-format
 #| msgid "%qs redeclared with conflicting %qs attributes"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "deduction guide %q+D redeclared"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -53155,720 +53190,726 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "thread-local deklarasi dari %q+D mengikuti deklarasi bukan-thread-lokal"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "non-thread-local deklarasi dari %q+D mengikuti deklarasi thread-local"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "deklarasi dari %q#D"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "deklarasi redundansi dari %qD dalam lingkup sama"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  dari sini"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  keluar OpenMP structured block"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  menyilangi inisialisasi dari %q+#D"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  memasuki blok percobaan"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  mamasuki blok penangkapan"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  memasuki blok terstruktur OpenMP"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  melewati inisialisasi dari %q+#D"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD bukan sebuah template fungsi"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named %q#T in %q#T"
 msgid "no type named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "konversi dari %qT ke %qT adalah ambigu"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah class template"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah tipe"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "parameter template tidak cocok dengan template"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "alignmen yang diminta bukan kelipatan dari 2"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan konstruktor tidak diijinkan dalam kumpulan anonymous"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam kumpulan anoymous"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan operator penempatan salin tidak diperbolehkan dalam kumpulan anonymous"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "atribut untuk %q+#T harus mengikuti kata kunci %qs"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "multiple tipe dalam satu deklarasi"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "hilang nama-tipe dalam typedef-deklarasi"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ menghambat struct anonymous"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> hanya dapat dispesifikasikan didalam sebuah kelas"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> hanya dapat dispesifikasikan untuk konstruktor"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> telah diabaikan dalam deklarasi ini"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qs cannot be used for type declarations"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe kelas %qT diluar dari definisi"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe dependen %qT tanpa sebuah deklarasi yang berasosiasi"
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD diinisialisasi (lebih baik gunakan decltype)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarasi dari %q#D memiliki %<extern%> dan terinisialisasi"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definisi dari %q#D ditandai %<dllimport%>"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "deklarasi anggota template %qD tidak valid"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tidak mengijinkan %<%T::%D%> untuk didefinisikan sebagai %<%T::%D%>"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "duplikasi inisialisasi dari %qD"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabel %q#D memiliki penginisialisasi tetapi tipe tidak lengkap"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "kumpulan %q#D memiliki tipe tidak lengkap dan tidak dapat didefinisikan"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD dideklarasikan sebagai referensi tetapi tidak terinisialisasi"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nama digunakan dalam sebuah gaya GNU diperuntukan penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "bukan trivial designated penginisialisasi tidak didukung"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "ukuran penyimpanan dari %q+D bukan konstant"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  anda dapat memperbaiki ini dengan menghapus penginisialisasi"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "tidak terinisialisasi const %qD"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%J anggota tidak terinisialisasi %qD dengan %<const%> tipe %qT"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipe tidak valid %qT sebagai penginisialisasi untuk sebuah vektor dari tipe %qT"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "terlalu banyak penginisialisasi untuk %qT"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "hilang kurung diantara penginisialisasi untuk %qT"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %P has incomplete type %qT"
 msgid "structured binding has incomplete type %qT"
 msgstr "parameter %P memiliki tipe tidak lengkap %qT"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elemen dari array %q#T memiliki tipe tidak lengkap"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ukuran-variabel compound literals"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "objek skalar %qD membutuhkan satu elemen dalam penginisialisasi"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "dalam C++98 %qD harus diinisialisasi dengan konstruktor, bukan dengan %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "array %qD diinisialisasi dengan tanda kurung string literal %qE"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "penginisialisasi tidak valid untuk anggota statis  dengan konstruktor"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(diluar dari kelas inisialisasi dibutuhkan)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "parameter %qD dinisialisasi"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "membayangi tipe deklarasi sebelumnya dari %q#D"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "fungsi %q#D telah dinisialisasi seperti sebuah variabel"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  tidak dapat menggunakan obsolete binding di %q+D karena ini memiliki sebuah desktruktor"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT adalah sebuah dasar tidak dapat diakses dari %qT"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 melarang array dengan panjang bervariabel %qs"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "%u name provided for structured binding"
@@ -53876,1814 +53917,1825 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "%Hpenginisialisasi disediakan untuk fungsi"
 msgstr[1] "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "tidak dapat menguraikan alamat"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "tidak dapat menjalankan %<offsetof%> ke anggota data statis %qD"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "desktruktor untuk alien kelas %qT tidak dapat berupa sebuah anggota"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktor untuk alien kelas %qT tidak dapt berupa sebuah anggota"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D dideklarasikan dengan spesifikasi eksepsi"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definisi dari %qD tidak dalam namespace melingkupi %qT"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "anggota fungsi statis %q#D dideklarasikan dengan tipe pengkualifikasi"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "metoda Java %qD memiliki tipe kembali %qT bukan Java"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD bukan sebuah fungsi template"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "mendifinisikan eksplisit spesialisasi %qD dalam deklarasi friend"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "penggunaan tidak valid dari template-id %qD dalam deklarasi dari primary template"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi inline"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi statis"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi statis"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, fuzzy, gcc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "literal operator with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> harus kembali %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "bukan %q#D anggota fungsi dideklarasikan dalam kelas %qT"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+#| msgid "strong using only meaningful at namespace scope"
+msgid "concept must be defined at namespace scope"
+msgstr "strong using hanya berarti di lingkup namespace"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ melarang inisialisasi dari anggota constant %qD dari bukan integral tipe %qT"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "ukuran dari array %qD memiliki tipe bukan integral %qT"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ melarang array berukuran-nol"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ melarang array dengan variabel panjang %qD"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ melarang array dengan variabel panjang"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "array dengan panjang bervariabel  %qD digunakan"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "overflow dalam dimensi array"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "spesifikasi tipe kembali untuk konstruktor tidak valid"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "tipe kembali yang dispesifikasikan untuk %<operator %T%>"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "terlalu banyak daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "penspesifikasi konflik dalam deklarasi dari %qs"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variabel tidak bernama atau field dideklarasikan void"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<::%D%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%T::%D%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%D::%D%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "deklarasi dari %qD sebagai bukan anggota"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "id pendeklarasi hilang; menggunaka kata reserved %qD"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "definisi fungsi tidak mendeklarasikan parameter"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 #| msgid "missing type-name in typedef-declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "hilang nama-tipe dalam typedef-deklarasi"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dua atau lebih tipe data dalam deklarasi dari %qs"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "penspesifikasi konflik dalam deklarasi dari %qs"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ melarang deklarasi dari %qs dengan tidak ada tipe"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs tidak didukung oleh target ini"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ 1998 does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> dan %<unsigned%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> dan %<short%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qT"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> digunakan dengan %<typedef%>"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "kompleks tidak valid untuk %qs"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "type deklarasi tidak valid dalam parameter deklarasi"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level deklarasi dari %qs menspesifikasikan %<auto%>"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "lingkup-fungsi %qs secara implisit auto dan dideklarasikan %<__thread%>"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spesifikasi kelas penyimpanan tidak valid dalam deklarasi fungsi friend"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE atribut diabaikan"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Diduga parenthesis kiri"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function uses %<auto%> type specifier without late return type"
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs fungsi menggunakan penspesifikasi tipe %<auto%> tanpa tipe kembali late"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type not declared with %<auto%> type specifier"
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs fungsi dengan tipe kembali late tidak dideklarasikan dengan penspesifikasi tipe %<auto%>"
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> fungsi mengembalikan nilai bukan-void"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "deklarasi friend tidak dalam definisi kelas"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "tidak dapat mendefinisikan fungsi friend %qs dalam sebuah definisi lokal kelas"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktor mungkin tidak memiliki parameter"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T anggota"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T, yang bukan sebuah typedef atau sebuah argumen tipe template"
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD digunakan sebagai sebuah pendeklarasi"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "anggota fungsi secara implisit friends dari kelasnya"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra kualifikasi %<%T::%> di anggota %qs"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendefinisikan anggota fungsi %<%T::%s%> dalam %<%T%>"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member %<%T::%s%> within %qT"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "bukan parameter %qs tidak dapat menjadi parameter pack"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "anggota member tidak boleh memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter mungkin tidak memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "anggota bukan-objek %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "typedef may not be a function definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "typedef may not be a member function definition"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<[*]%> not allowed in other than a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%H%<[*]%> tidak diijinkan selain dalam sebuah deklarasi"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "typedef declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%J typedef nama mungkin berupa sebuah nested-name-specifier"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ melarang tipe nested %qD dengan nama sama seperti kelas yang melingkupi"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> dispesifikan untuk deklarasi kelas friend"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "deklarasi friend membutuhkan kunci kelas, i.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "deklarasi friend membutuhkan class-key, i.e. %<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "mencoba untuk membuat kelas %qT sebuah friend dari lingkup global"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "kualifier tidak valid di tipe fungsi bukan anggota"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "deklarasi abstrak %qT digunakan sebagai deklarasi"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "tidak dapat mendeklarasikan parameter %q+D untuk menjadi tipe abstrak %qT"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlocal variable %qD may not appear in this context"
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "%Hvariabel lokal %qD mungkin tidak muncul dalam konteks ini"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of template-name %qE without an argument list"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "%Hpenggunaan tidak vlaid dari nama template %qE tanpa sebuah daftar argumen"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "penggunaan tidak valid dari %<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "deklarasi dari C fungsi %q#D konflik dengan"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fungsi %qD dideklarasikan virtual didalam sebuah union"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD tidak dapat dideklarasikan virtual, karena itu selalu statis"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "diduga nama yang dikualifikasikan dalam deklarasi friend untuk destruktor %qD"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "a destructor cannot be %qs"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "diduga kualifikasi nama dalam deklarasi friend untuk konstruktor %qD"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "a constructor cannot be %<concept%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "tidak dapat membuka %s"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "field %qD memiliki tipe tidak lengkap"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "kelas penyimpanan %<auto%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "kelas penyimpanan %<register%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> dispesifikasikan tidak valid untuk fungsi %qs dideklarasikan diluar lingkup global"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual bukan kelas fungsi %qs"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 #| msgid "%qs defined in a non-class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "tidak dapat mendeklarasikan anggota fungsi %qD untuk memiliki linkage statis"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "tidak dapat mendeklarasikan fungsi statis didalam fungsi lainnya"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> mungkin tidak digunakan ketika mendefinisikan (terbalik untuk deklarasi) sebuah anggota data statis"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "tidak dapat secara eksplisit mendeklarasikan anggota %q#D untuk memiliki extern linkage"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarasi dari %q#D tidak memiliki penginisialisasi"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "konstruktor tidak valid; anda mungkin bermaksud %<%T (const %T&)%>"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD tidak boleh dideklarasikan sebagai statis"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD harus baik sebuah anggota fungsi tidak statis atau bukan anggota fungsi"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD harus memiliki sebuah argumen dari kelas atau tipe enumerasi"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ melarang overloading operator ?:"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD harus mengambil baik nol atau satu argumen"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD harus mengambil baik satu atau dua argumen"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumennya"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumen keduanya"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD harus mengambil secara tepat satu argumen"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "definisi-pengguna %qD selalu mengevaluasikan kedua argumen"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD seharusnya kembali dengan nilai"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "menggunakan typedef-name %qD setelah %qs"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT direferensikan sebagai enum"
@@ -55695,109 +55747,109 @@ msgstr "%qT direferensikan sebagai enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argumen template dibutuhkan untuk %<%s %T%>"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD memiliki nama sama seperti kelas yang telah dideklarasikan"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT mungkin bukan sebuah template"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "penggunaan dari enum %q#D tanpa deklarasi sebelumnya"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeklarasi dari %qT sebagai bukan-template"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "tidak dapat mendeklarasikan %qD untuk menjadi sebuah tipe bit-field"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union turunan %qT tidak valid"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "tipe base %qT gagal untuk menjadi sebuah struct atau tipe kelas"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipe rekursif %qT tidak terdefinisi"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "duplikasi tipe dasar %qT tidak valid"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%J definisi sebelumnya disini"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -55807,84 +55859,84 @@ msgstr "tipe yang digaris bawahi %<%T%> dari %<%T%> harus berupa sebuah tipe int
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "tidak ada tipe integral yang dapat merepresentasikan seluruh dari nilai enumerasi untuk %qT"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow dalam nilai enumerasi di %qD"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "multiple definisi dari %q#T"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> seharusnya mengembalikan referensi ke %<*this%>"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "tipe kembali fungsi tidak kompatibel karena %<volatile%>"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD telah didefinisikan dalam kelas %qT"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -55925,7 +55977,7 @@ msgstr "tidak dapat menghapus sebuah fungsi. Hanya penunjuk-ke-objek yang valid
 msgid "deleting %qT is undefined"
 msgstr "menghapus %qT tidak terdefinisi"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "template deklarasi dari %q#D"
@@ -55936,7 +55988,7 @@ msgstr "template deklarasi dari %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "daftar parameter template yang disediakan tidak cocok dengan paramter template dari %qD"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destruktor %qD dideklarasikan sebagai anggota template"
@@ -56294,24 +56346,24 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "deleted function %q+D"
 msgid "use of deleted function %qD"
 msgstr "fungsi %q+D terhapus"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -56436,7 +56488,7 @@ msgstr "%Hreferensi ke %<%T::%D%> adalah ambigu"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
@@ -56447,7 +56499,7 @@ msgstr "%qD bukan sebuah anggota dari %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%H%qD bukan sebuah anggota dari %qD"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a member of %qD"
 msgid "%qD is not a member of %qD"
@@ -56650,440 +56702,440 @@ msgstr "nilai-inisialisasi dari referensi"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "evaluasi rekursi dari argumen baku untuk %q#D"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD seharusnya diinisialisasi dalam daftar anggota inisialisasi"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is used uninitialized in this function"
 msgid "%qD is initialized with itself"
 msgstr "%qD digunakan tidak terinisialisasi dalam fungsi ini"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "nilai inisial tidak valid untuk anggota %qs"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "anggota const tidak terinisialisasi %qD"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%J anggota referensi tidak terinisialisasi %qD"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "dasar %qT akan diinisialisasi setelah"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  dasar %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  ketika diinisialisasi disini"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%J multiple penginisialisasi diberikan untuk %qD"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%J multiple penginisialisasi diberikan untuk dasar %qT"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%J inisialisasi untuk multiple anggota dari %qT"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%J kelas dasar %q#T seharusnya secara eksplisit diinisialisasikan dalam konstruktor salinan"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D adalah sebuah anggota data statis; ini hanya dapat diinisialisasikan di definisinya"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "penginisialisasi tidak bernama untuk %qT, yang tidak memiliki kelas dasar"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "penginisialisasi tidak bernama untuk %qT, yang menggunakan turunan multiple"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD keduanya sebuah dasar langsung dan sebuah virtual base tidak langsung"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "tipe %qT bukan sebuah dasar langsung dari %qT"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "array harus diinisialisasi dengan sebuah kurung melingkupi penginisialisasi"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT bukan sebuah tipe kelas"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "tipe tidak lengkap %qT tidak memiliki anggota %qD"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "penunjuk tidak valid ke bit-field %qD"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qD"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%J anggota referensi tidak terinisialisasi %qD"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "at offset %wi from %qD declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr ""
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "integer overflow dalam ekspresi"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' not allowed in expression at %L"
 msgid "variably modified type not allowed in new-expression"
 msgstr "Dummy argumen '%s' tidak diijinkan dalam ekspresi di %L"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "mencoba menghapus tanda kurung disekitar tipe-id"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "tipe %<void%> tidak valid untuk new"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "tidak ada %qD yang sesuai yang ditemukan dalam kelas %qT"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "permintaan untuk anggota %qD adalah ambigu"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new tidak dapat diaplikasikan untuk mereferensikan sebuah tipe"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new tidak dapat diaplikasikan ke sebuah fungsi tipe"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "kemungkinan masalah terdeteksi dalam penggunaan dari operator delete:"
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "penginisialisasi berakhir secara prematur"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukuran array tidak diketahui dalam delete"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "kemungkinan masalah terdeteksi dalam penggunaan dari operator delete:"
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "compound literal memiliki ukuran variabel"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot capture %qE by reference"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "capture by copy of incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> was not captured for this lambda function"
@@ -57143,63 +57195,63 @@ msgstr "tidak ada argumen ke %qD yang tergantung di sebuah parameter template, j
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(jika anda menggunakan %<-fpermissive%>, G++ akan menerima kode anda, tetapi mengijinkan penggunaan dari sebuah nama tidak dideklarasikan sudah ditinggalkan)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, fuzzy, gcc-internal-format
 #| msgid "mangling typeof, use decltype instead"
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr "mangling typeof, lebih baik gunakan decltype"
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "mangling tipe fixed point tidak diketahui"
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "mangling %C"
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "diabaikan operan tengah ke %<?:%> operan tidak dapat mangled"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -57397,335 +57449,335 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn't match"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "deklarasi extern dari %q#D tidak cocok"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected signature: %qD"
 msgstr "diduga pernyataan"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be defaulted"
 msgid "a template cannot be defaulted"
 msgstr "%qD tidak dapat dibakukan"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD tidak dapat dibakukan"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "defaulted function %q+D with default argument"
 msgstr "%Hberkas berakhir dalam argumen baku"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared with %d template parameter(s)"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "redeklarasikan dengan %d parameter template"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D konflik dengan deklarasi sebelumnya menggunakan %q#D"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D menyembunyikan konstruktor untuk %q#T"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "konflik deklarasi %q#D"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "karena perbedaan eksepsi spesifikasi"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "deklarasi dari %q#D membayangi sebuah parameter"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 #| msgid "type %q+D does not have a known size"
 msgid "%q#D does not have external linkage"
 msgstr "tipe %q+D tidak memiliki ukuran yang diketahui"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> names desktruktor"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-declaration untuk bukan-anggota di class scope"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "using-declaration untuk bukan-anggota di class scope"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "tipe %qT bukan sebuah dasar langsung dari %qT"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared in %qD"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD not in a namespace surrounding %qD"
 msgid "using-declaration may not name namespace %qD"
 msgstr "deklarasi dari %qD bukan dalam sebuah lingkup namespace %qD"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklarasi dari %qD bukan dalam sebuah lingkup namespace %qD"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eksplisit kualifikasi dalam deklarasi dari %qD"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD seharusnya telah dideklarasikan didalam %qD"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD atribut tidak berarti karena anggota dari anonymous namespace memperoleh simbol lokal"
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "atribut %qD direktif diabaikan"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> tidak tersedia untuk anggota fungsi static"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "it was later defined here"
 msgstr "%J%qD telah dideklarasikan disini"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "'%s' di %L adalah ambigu"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namespace alias %qD tidak diijinkan disini, diasumsikan %qD"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 #| msgid "address area of %q+D conflicts with previous declaration"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "daerah alamat dari %q+D konflik dengan deklarasi sebelumnya"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "reachable %s definition here"
 msgstr "%J definisi sebelumnya disini"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX memasuki pop_everything ()\n"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -57754,7 +57806,7 @@ msgstr "pengidentifikasi %<%s%> akan menjadi sebuah kata kunci dalam C++0x"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -57783,7 +57835,7 @@ msgstr "%H%<::%E%> belum pernah dideklarasikan"
 msgid "request for member %qE in non-class type %qT"
 msgstr "%Hpermintaan untuk anggota %qE dalam tipe bukan kelas %qT"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -57878,7 +57930,7 @@ msgstr "%Htemplate-id tidak valid"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "sebuah cast ke sebuah tipe selain dari sebuah integral atau tipe enumerasi tidak dapat muncul dalam sebuah ekspresi konstan"
@@ -58038,7 +58090,7 @@ msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -58177,7 +58229,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -58236,7 +58288,7 @@ msgstr "%Hpernyataan ekspresi tidak diijinkan diluar fungsi atau didalam daftar
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
@@ -58271,7 +58323,7 @@ msgstr "%Hlingkup %qT sebelum %<~%> bukan sebuah class-name"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr ""
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
@@ -58295,13 +58347,13 @@ msgstr "%Hdeklarasi dari %<~%T%> sebagai anggota dari %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "%Htypedef-nama %qD digunakan sebagai desktruktor deklarator"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "diduga specifier-qualifier-list"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bukan sebuah template"
@@ -58341,7 +58393,7 @@ msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 msgid "expected nested-name-specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in casts"
@@ -58359,7 +58411,7 @@ msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -58375,1257 +58427,1263 @@ msgstr "ISO C++ melarang compound literals"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, fuzzy, gcc-internal-format
 #| msgid "%<%D::%D%> is not a member of %qT"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> bukan sebuah anggota dari %qT"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %qs expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray bound forbidden after parenthesized type-id"
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "%Harray bound dilarang setelah parenthesized tipe id"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "mencoba menghapus tanda kurung disekitar tipe-id"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "penggunaan dari gaya-lama cast"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> operator will be treated as two right angle brackets in C++0x"
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%H%<>>%> operator akan diperlakukan sebagai dua sudut brackets dalam C++0x"
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "disarankan tanda kurung disekeliling ekspresi %<>>%>"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not allow extra %<;%> outside of a function"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C tidak mengijinkan kelebihan %<;%> diluar dari sebuah fungsi"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+#| msgid "definition of %q#T inside template parameter list"
+msgid "lambda-expression in template parameter type"
+msgstr "definisi dari %q#T didalam daftar parameter template"
+
+#: cp/parser.c:10819
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Tidak terduga akhir dari modul"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in unary expression"
 msgid "already captured %qD in lambda expression"
 msgstr "operan tidak valid dalam ekspresi unary"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a reference type"
 msgid "%<this%> cannot be captured by reference"
 msgstr "new tidak dapat diaplikasikan untuk mereferensikan sebuah tipe"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "peningkatan dari variabel baca-saja %qD"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "default argument specified for lambda parameter"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "duplikasi %<volatile%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcase label %qE not within a switch statement"
 msgid "case label %qE not within a switch statement"
 msgstr "%Hlabel case %qE tidak dalam sebuah pernyataan switch"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "diduga deklarasi atau pernyataan"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "fungsi mengembalikan sebuah array"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "condition declares a function"
 msgstr "field %qs dideklarasikan sebagai sebuah fungsi"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "non-local variable %q#D uses local type %qT"
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "variabel bukan-lokal %q#D menggunakan tipe lokal %qT"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "diduga deklarasi atau pernyataan"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ melarang gotos yang sudah dihitung"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected module-name"
 msgstr "Diduga nama"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "method declaration not in @interface context"
 msgid "module-declaration not permitted in header-unit"
 msgstr "metode deklarasi tidak dalam context @interface"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, gcc-internal-format
 msgid "private module fragment"
 msgstr ""
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "import-declaration must be at global scope"
 msgstr "using-declaration untuk bukan-anggota di class scope"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%qE may only occur once in an export declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "attributes are not permitted in this position"
 msgstr "atribut %qE tidak didukung di platform ini"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr ""
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "kelebihan %<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__label__%> not at the beginning of a block"
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%H%<__label__%> tidak berada diawal dari sebuah blok"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmixing declarations and function-definitions is forbidden"
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "%Hpencampuran deklarasi dan definisi fungsi dilarang"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "deklarasi kosong"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "deklarasi anggota fungsi tidak valid"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<friend%> used outside of class"
 msgid "%<friend%> used outside of class"
 msgstr "%H%<friend%> digunakan diluar dari kelas"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%H%<auto%> akan mengubah arti dalam C++0x; mohon hapus itu"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D tidak valid dalam %q#T"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "type-specifier invalid in lambda"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, fuzzy, gcc-internal-format
 #| msgid "%Hclass definition may not be declared a friend"
 msgid "class definition may not be declared a friend"
 msgstr "%Hdefinisi kelas mungkin tidka dideklarasikan sebagai friend"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in explicit-specifier"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, fuzzy, gcc-internal-format
 #| msgid "%Honly constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "%Hhanya konstruktor yang mengambil penginisialisasi dasar"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "%Htidak dapat mengekspand penginisialisasi untuk anggota %<%D%>"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "deklarasi statis dari %q+D mengikuti deklarasi bukan statis"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anachronistic gaya-lama kelas dasar penginisialisasi"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (sebuah anggota terkualifikasi secara implisit adalah sebuah tipe)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operan tidak valid dalam operasi binary"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
 msgstr "operan tidak terduga"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "kata kunci %<export%> tidak terimplementasi, dan akan diabaikan"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<export%> not implemented, and will be ignored"
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "kata kunci %<export%> tidak terimplementasi, dan akan diabaikan"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "batasan untuk operan tidak valid"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter packs cannot have default arguments"
 msgid "template parameter packs cannot have default arguments"
 msgstr "%Htemplate parameter pack tidak dapat memiliki argumen baku"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> tidak dapat berawal sebuah daftar template argumen"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> adalah sebuah penyebutan alternatif untuk %<[%>. Masukan spasi diantara %<<%> dan %<::%>"
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(jika anda menggunakan %<-fpermissive%> G++ akan menerima kode anda)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid template-argument-list"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 #| msgid "%<<::%> cannot begin a template-argument list"
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<<::%> tidak dapat berawal sebuah daftar template argumen"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, fuzzy, gcc-internal-format
 #| msgid "%Hparse error in template argument list"
 msgid "parse error in template argument list"
 msgstr "%Hparse error dalam daftar argumen template"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
 msgstr "diduga pernyataan"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnon-template %qD used as template"
 msgid "non-template %qD used as template"
 msgstr "%Hbukan-template %qD digunakan sebagai template"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "gunakan %<%T::template %D%> untuk mengindikasikan bahwa ini adalah template"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate specialization with C linkage"
 msgid "template specialization with C linkage"
 msgstr "%Hspesialisasi template dengan C linkage"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Diduga nama"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%H%qE tidak bernama sebuah tipe"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 #| msgid "Recognize GNU-defined keywords"
 msgid "concept defined here"
 msgstr "Kenali kata kunci didefinisikan GNU"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%J typedef nama mungkin berupa sebuah nested-name-specifier"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklarasi %qD tidak mendeklarasikan apapun"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "atribut diabaikan di tipe uninstantiasi"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "atribut diabaikan di elaborated type penspesifikasi yang tidak memforward sebuah deklarasi"
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktifkan instantiation template otomatis"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in namespace %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam namespace %qD yang tidak dilingkupi %qD"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam %qD yang tidak dilingkup %qD"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, fuzzy, gcc-internal-format
 #| msgid "%Hextra qualification not allowed"
 msgid "extra qualification not allowed"
 msgstr "%Hekstra pengkualifikasi diabaikan"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%H%qD bukan sebuah nama namespace"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a namespace-name"
 msgid "%qD is not a namespace-name"
 msgstr "%H%qD bukan sebuah nama namespace"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Peringatkan ketika sebuah fungsi inline tidak dapat diinline"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "penggunaan dari namespace %qD  sebagai ekspresi"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha template-id may not appear in a using-declaration"
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%Hsebuah template-id mungkin tidak muncul dalam sebuah using deklarasi"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "opaque-enum-declaration here"
 msgstr "deklarasi sebelumnya %q+#D disini"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD tidak didefinisikan diluar dari jangkauan fungsi"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT bukan sebuah namespace"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD tidak didefinisikan diluar dari jangkauan fungsi"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "nama parameter (tanpa tipe) dalam deklarasi fungsi"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "nama parameter (tanpa tipe) dalam deklarasi fungsi"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a function-definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "attributes are not allowed on a function-definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "initializer provided for function"
 msgstr "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -59635,496 +59693,496 @@ msgstr "%H%<%T::%E%> bukan sebuah tipe"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of constructor as a template"
 msgid "invalid use of constructor as a template"
 msgstr "%Hpenggunaan tidak valid dari konstruktor sebagai sebuah template"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "penggunaan %<%T::%D%> daripada %<%T::%D%> untuk menamai konstruktor dalam sebuah nama berkualifikasi"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is a namespace"
 msgid "%qD is a namespace"
 msgstr "%H%qD adalah sebuah namespace"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "operan tidak terduga"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate cv-qualifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 #| msgid "multiple inline callers"
 msgid "multiple ref-qualifiers"
 msgstr "multiple pemanggil inline"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "hilang target makefile setelah %qs"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 #| msgid "%Hparse error in template argument list"
 msgid "%qT not permitted in template argument"
 msgstr "%Hparse error dalam daftar argumen template"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdefault arguments are only permitted for function parameters"
 msgid "default arguments are only permitted for function parameters"
 msgstr "%Hargumen baku hanya diijinkan untuk parameter fungsi"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack %qD cannot have a default argument"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%H%s parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack cannot have a default argument"
 msgid "template parameter pack cannot have a default argument"
 msgstr "%Htemplate parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack cannot have a default argument"
 msgid "parameter pack cannot have a default argument"
 msgstr "%H%s parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "tidak dapat menemukan berkas untuk class %s"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid class name in declaration of %qD"
 msgid "invalid class name in declaration of %qD"
 msgstr "%Hnama kelas tidak valid dalam deklarasi dari %qD"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, fuzzy, gcc-internal-format
 #| msgid "%Han explicit specialization must be preceded by %<template <>%>"
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "%Hsebuah eksplisit spesialisasi harus diawali oleh %<template <>%>"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfunction template %qD redeclared as a class template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%Htemplate fungsi %qD redeklarasikan sebagai sebuah template kelas"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprevious definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%Hdefinisi sebelumnya dari %q+#T"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "diduga nama class"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "%Hsebuah class-key harus digunakan ketikan mendeklarasikan sebuah friend"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "friend declaration does not name a class or function"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bit-field %qD dengan tipe bukan integral"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "pure-specifier on function-definition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, fuzzy, gcc-internal-format
 #| msgid "invalid AE type specified (%s)\n"
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "tipe AE yang dispesifikasikan (%s) tidak valid\n"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (kelas dasar  adalah sebuah tipe implisit)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "karena perbedaan eksepsi spesifikasi"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr ""
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "expression must be enclosed in parentheses"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "posisi yang diminta bukan sebuah konstanta integer"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "alignmen yang diminta bukan sebuah konstanta"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo few template-parameter-lists"
 msgid "too few template-parameter-lists"
@@ -60134,695 +60192,695 @@ msgstr "%Hterlalu sedikit template-parameter-list"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many template-parameter-lists"
 msgid "too many template-parameter-lists"
 msgstr "%Hterlalu banyak template-parameter-lists"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "named return values are no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid declaration of member template in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "%Hdeklarasi tidak valid dari anggota template dalam kelas lokal"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "template with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template declaration of %<typedef%>"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexplicit template specialization cannot have a storage class"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Heksplisit template spesialisasi tidak dapat memiliki sebuah kelas penyimpanan"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> seharusnya %<> >%> didalam sebuah daftar argumen template nested"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, fuzzy, gcc-internal-format
 #| msgid "%Hspurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%Hspurious %<>>%>, gunakan %<>%> untuk mengakhiri sebuah daftar argumen template"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of %qD in linkage specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "%Hpenggunaan tidak valid dari %qD dalam spesifikasi linkage"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__thread%> before %qD"
 msgid "%<__thread%> before %qD"
 msgstr "%H%<__thread%> sebelum %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "baik %<_Sat%> dan %<char%> dalam penspesifikasi deklarasi"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "duplikasi %qE"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate %qs"
 msgid "duplicate %qs"
 msgstr "%Hduplikasi %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<auto%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<co_yield%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag digunakan dalam penamaan %q#T"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%q#T was previously declared here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari basenya %qT"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 #| msgid "template class without a name"
 msgid "replace the class-key with %qs"
 msgstr "template kelas tanpa sebuah nama"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qT defined as %qs here"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%J%qD telah dideklarasikan disini"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD redeclared with different access"
 msgid "%qD redeclared with different access"
 msgstr "%H%qD redeklarasi dengan akses berbeda"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%H%<template%> (sebagai sebuah disambiguator) hanya diijinkan dalam templates"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "file ends in default argument"
 msgstr "%Hberkas berakhir dalam argumen baku"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmisplaced %<@%D%> Objective-C++ construct"
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "%Hsalah tempat %<@%D%> Objective-C++ konstruk"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<@encode%> must specify a type as an argument"
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%H%<@encode%> harus menspesifikasikan sebuah tipe sebagai sebuah argumen"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid Objective-C++ selector name"
 msgid "invalid Objective-C++ selector name"
 msgstr "%Hpemilih nama Objective-C++ tidak valid"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, fuzzy, gcc-internal-format
 #| msgid "%Hidentifier expected after %<@protocol%>"
 msgid "identifier expected after %<@protocol%>"
 msgstr "%Hpengidentifikasi diduga setelah %<@protocol%>"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE atribut diabaikan untuk %qE"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "diduga ekspresi integer"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in iterator type"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterasi variabel %qD seharusnya bukan reduksi"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "tidak cukup DO loops untuk kolaps !$OMP DO di %L"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "diduga ekspresi"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 #| msgid "%Hjunk at end of %<#pragma GCC pch_preprocess%>"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "%Hsampah diakhir dari %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC option tidak diijinkan didalam fungsi"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "konversi baku tidak diijinkan dalam konteks ini"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "anggota data %qD tidak dapat berupa sebuah anggota template"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "deklarasi anggota template %qD tidak valid"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "explisit spesialisasi dalam lingkup non-namespace %qD"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "template kelas yang melingkupi tidak secara eksplisit terspesialisasi"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  dari definisi dari %q+#D"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "eksplisit instantiation dari %qD dalam namespace %qD (yang tidak melingkupi namespace %qD)"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "spesialisasi dari %qT setelah instantiation"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -60830,157 +60888,157 @@ msgstr "  dari definisi dari %q+#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "spesialisasi %qT setelah instantiation %qT"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD bukan sebuah variabel"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD untuk %q+D tidak cocok dengan deklarasi template apapun"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "eksplisit instantiation dari %qD dalam namespace %qD (yang tidak melingkupi namespace %qD)"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "hilang atribut Code"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
 msgstr "hilang atribut Code"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "template-id %qD dalam deklarasi dari template utama"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "daftar parameter template digunakan dalam instantiation eksplisit"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definisi disediakan untuk instantiation eksplisit"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "terlalu banyak daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "terlalu sedikit daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "eksplisit spesialisasi dari %qD harus dikenalkan oleh %<template <>%>"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "argumen baku dispesifikasikan dalam spesialisasi eksplisit"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD bukan sebuah fungsi template"
@@ -60993,159 +61051,159 @@ msgstr "%qD bukan sebuah fungsi template"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "tidak ada anggota fungsi %qD dideklarasikan dalam %qT"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "friend declaration here"
 msgstr "%J membayangi deklarasi ada disini"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "ekspansi penginisialisasi dasar %<%T%> berisi parameter packs"
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "pola ekspansi %<%T%> berisi tidak ada argumen packs"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "pola ekspansi %<%E%> berisi tidak ada argumen packs"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameter packs tidak diekspan dengan %<...%>:"
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "tipe parameter template %qT dideklarasikan %<friend%>"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack argumen %qE harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack argumen %qT harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -61153,19 +61211,19 @@ msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "tipe %qT dari template argumen %qE tergantung di parameter template"
 msgstr[1] "tipe %qT dari template argumen %qE tergantung di parameter template"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "tidak ada argumen baku untuk %qD"
@@ -61174,53 +61232,53 @@ msgstr "tidak ada argumen baku untuk %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %qE harus berada di akhir dari daftar parameter template"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumen baku untuk parameter dari tipe %qT memiliki tipe %qT"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parameter %qD dideklarasikan void"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "template kelas tanpa sebuah nama"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -61231,58 +61289,58 @@ msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definisi template dari bukan template %q#D"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "diduga %d tingkat dari parm template untuk %q#D, diperoleh %d"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "diperoleh %d parameter template untuk %q#T"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  tetapi %d dibutuhkan"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "gunakan template<> untuk spesialisasi eksplisit"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bukan sebuah tipe template"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "penspesifikasi template tidak dispesifikasikan dalam deklarasi dari %qD"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redeclared with %d template parameter(s)"
 msgid "redeclared with %d template parameter"
@@ -61290,7 +61348,7 @@ msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redeklarasikan dengan %d parameter template"
 msgstr[1] "redeklarasikan dengan %d parameter template"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter(s)"
 msgid "previous declaration %qD used %d template parameter"
@@ -61298,478 +61356,478 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 msgstr[1] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parameter template %q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeklarasikan disini sebagai %q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinisi dari argumen baku untuk %q#D"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration %q#D with different constraints"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT bukan sebuah anggota dari %qT"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 #| msgid "template arguments to %qD do not match original template %qD"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs tidak valid untuk %qs"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "tipe %qT tidak diturunkan dari tipe %qT"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena string literal tidak dapat digunakan dalam konteks ini"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "in template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena konflik dalam cv kualifikasi"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena ini bukan sebuah ekspresi konstan"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini adalah sebuah penunjuk"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "lebih baik coba gunakan %qE"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini dari tipe %qT"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, fuzzy, gcc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "ignoring attributes on template argument %qT"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "%Hpenggunaan tidak valid dari desktruktor %qD memiliki sebuah tipe"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "merefer ke sebuah anggota tipe dari sebuah parameter template, gunakan %<typename %E%>"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  diduga sebuah konstanta dari tipe %qT, diperoleh %qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  diduga sebuah tipe, diperoleh %qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  diduga sebuah template kelas, diperoleh %qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  diduga sebuah template dari tipe %qD, diperoleh %qD"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "disediakan untuk %q+D"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "tipe bukan template %qT digunakan sebuah sebuah template"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "untuk deklarasi template %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template constraint failure for %qD"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE tidak berada di awal dari deklarasi"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "panjang argumen pack tidak cocok akan diekspan %<%T%>"
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "panjang argumen pack tidak cocok ketika mengekspan %<%E%>"
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "redefinisi dari argumen baku untuk %q#D"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "membuat penunjuk ke anggota fungsi dari tipe bukan kelas %qT"
@@ -61787,308 +61845,308 @@ msgstr "membuat penunjuk ke anggota fungsi dari tipe bukan kelas %qT"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipe parameter %qT tidak valid"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dalam deklarasi %q+D"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fungsi mengembalikan sebuah array"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "membentuk referensi ke void"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "membuat penunjuk ke anggota dari tipe void"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT bukan sebuah tipe class, struct, atau union"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe class"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "dependent-name %qE diparse sebagai sebuah bukan-tipe, tetapi instantiation menghasilkan sebuah tipe"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "katakan %<typename %E%> jika sebuah tipe adalah berarti"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in comparison expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "operan tidak valid dalam ekspresi perbandingan"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "menggunakan field tidak valid %qD"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "penggunaan tidak valid dari ekspresi ekspansi pack"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "gunakan %<...%> untuk mengekspan argumen pack"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT adalah/menggunakan tipe anonymous"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "argumen template untuk %qD menggunakan tipe lokal %qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT adalah sebuah tipe variabel termodifikasi"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  mencoba untuk instantiate %qD"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "tipe %qT untuk instantiation eksplisit %qD tidak cocok dengan tipe yang dideklarasikan %qT"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "duplikasi eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 melarang penggunaan dari %<extern%> di instantiation eksplisit"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "class penyimpanan %qD diaplikasikan ke template instantiation"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplisit instantiation dari %q#T sebelum definisi dari template"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ melarang penggunaan dari %qE di instantiasi eksplisit"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "duplikasi instansiasi eksplisit dari %q#T"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -62101,171 +62159,171 @@ msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplisit instansiasi dari %qD tetapi tidak ada definisi yang tersedia"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "kedalaman template instansiasi melebihi maksimal dari %d instantiating %q+D, kemungkinan dari pembuatan tabel virtual (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "opaque vector types cannot be initialized"
 msgid "a concept cannot be constrained"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT bukan sebuah namespace"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "fungsi tidak dipertimbangkan untuk inlining"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 #| msgid "explicit qualification in declaration of %qD"
 msgid "explicit deduction guide declared here"
 msgstr "eksplisit kualifikasi dalam deklarasi dari %qD"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -62416,585 +62474,585 @@ msgstr "%q+#D tidak dapat dideklarasikan"
 msgid "  since %q+#D declared in base class"
 msgstr "  karena %q+#D dideklarasikan dalam kelas dasar"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr ""
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "disarankan eksplisit tanda kurung disekitar tubuh kosong dalam pernyataan %<do%>"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "catching non-reference type %q#T"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 #| msgid "type of asm operand %qE could not be determined"
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "tipe dari operan asm %qE tidak dapat ditentukan"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "__label__ declarations are only allowed in function scopes"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "deklarasi __label__ hanya diperbolehkan dalam lingkup fungsi"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "penggunaan tidak valid dari anggota %q+D dalam anggota fungsi statis"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "%qE missing template arguments"
 msgstr "argumen tidak cocok"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "argumen ke destruktor tidak diijinkan"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> tidak tersedia untuk anggota fungsi static"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "penggunaan tidak valid dari %<this%> dalam fungsi bukan anggota"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "penggunaan tidak valid ari %<this%> di tingkat paling atas"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "tidak valid pengkualifikasi lingkup dalam nama pseudo-destruktor"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE bukan dari tipe %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "compound literal dari tipe bukan-objek %qT"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "tipe parameter template harus menggunakan kata kunci %<class%> atau %<typename%>"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "penggunaan tidak valid dari tipe %qT sebagai nilai baku untuk sebuah parameter template"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argumen baku tidak valid untuk sebuah parameter template template"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "definisi dari %q#T didalam daftar parameter template"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "definisi tidak valid dari tipe pengkualifikasi %qT"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of parameter from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "use of parameter outside function body"
 msgstr "alloc_size parameter diluar dari jangkauan"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "argumen tidak cocok"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "parameter template %qD dari tipe %qT tidak diijinkan dalam sebuah ekspresi konstanta integral karena ini bukan tipe integral atau enumerasi"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "penggunaan dari template class %qT sebagai ekspresi"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "permintaan untuk anggota %qD adalah ambigu dalam multiple inheritance lattice"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "tipe dari %qE tidak dikenal"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
 msgstr "%qT bukan sebuah tipe template"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke destruktor %<~%T%>"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction%>"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<device%> id must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "reimplementasi dari class %qs"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe pointer"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD bukan berkas, namespace atau blok scope variabel"
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE direktif tidak dalam definisi %qT"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdifference between %qE and %qD does not have integer type"
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%Hperbedaan antara %qE dan %qD tidak memiliki tipe integer"
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "kondisi bukan konstan untuk assertion static"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -63003,22 +63061,22 @@ msgstr "argumen ke %<__builtin_return_address%> tidak didukung"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -63028,1174 +63086,1175 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV kualifier tidak dapat diaplikasikan ke %qT"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid " declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "kelas dasar %qT memiliki cv pengkualifikasi"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not public"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD bukan sebuah variabel"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%qD has a non-structural type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute takes no arguments"
 msgstr "atribut %J%qE berlaku hanya untuk fungsi"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "permintaan init_priority bukan sebuah konstanta integer"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "hanya dapat menggunakan atribut %qE di definisi lingkup-berkas dari objek dari tipe class"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "permintaan init_priority diluar dari jangkauan"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "permintaan init_priority disimpan untuk penggunaan internal"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "atribut %qE tidak didukung di platform ini"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "atribut %J%qE berlaku hanya untuk fungsi"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%s atribut diaplikasikan ke %s %s di %L"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "pemeriksaan lang_*: gagal dalam %s, di %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s diantara tipe penunjuk berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s diantara tipe penunjuk berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s diantara tipe penunjuk berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ melarang %s diantara penunjuk dari tipe %<void *%> dan penunjuk-ke-fungsi"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ melarang %s diantara penunjuk dari tipe %<void *%> dan penunjuk-ke-fungsi"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ melarang %s diantara penunjuk dari tipe %<void *%> dan penunjuk-ke-fungsi"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "canonical types differ for identical types %T and %T"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "tipe kanonikal berbeda untuk tipe identik %T dan %T"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "tipe titik kanonikal sama untuk tipe berbeda %T dan %T"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "aplikasi tidak valid dari %qs ke anggota fungsi"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "aplikasi tidak valid dari %<sizeof%> ke sebuah bit-field"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ melarang mengaplikasikan %<sizeof%> ke sebuah ekspresi dari tipe fungsi"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "aplikasi tidak valid dari %<__alignof%> ke sebuah bit-field"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ melarang mengaplikasikan %<__alignof%> ke sebuah ekspresi dari tipe fungsi"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "konversi sudah ditinggalkan dari konstanta string ke %qT"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "konversi sudah ditinggalkan dari konstanta string ke %qT"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "permintaan untuk anggota %qD dalam %qE, yangg tipe bukan class %qT"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "permintaan untuk anggota %qD dalam %qE, yangg tipe bukan class %qT"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qE"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD  of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "akses tidak valid ke anggota data tidak statis %qD dari objek KOSONG"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "tipe objek %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "tipe yang sedang dihancurkan adalah %qT, tetapi destruktor merefer ke %qT"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> bukan sebuah anggota dari %qT"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT bukan sebuah basis dari %qT"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT bukan sebuah penunjuk-ke-objek tipe"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "subscrip hilang dalam referensi array"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscripting array dideklarasikan %<register%>"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objek hilang dalam penggunaan dari %qE"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ melarang pemanggilan %<::main%> dari dalam aplikasi"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "harus menggunakan %<.*%> atau %<->*%> untuk memanggil penunjuk-ke-anggota fungsi dalam %<%E (...)%>, contoh %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to member function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to member function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "terlalu banyak argumen ke fungsi"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "terlalu sedikit argumen ke fungsi"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P dari %qD memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter %P memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types when returning type %qT but %qT was expected"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "tipe tidak kompatibel ketika mengembalikan tipe %qT tetapi %qT telah diduga"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "%s diantara tipe penunjuk berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "mengasumsikan cast ke tipe %qT dari fungsi overloaded"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL digunakan dalam aritmetik"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ melarang perbandingan diantara penunjuk dan integer"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "operand types are %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "perbandingan tidak berurut di argumen bukan titik pecahan"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operang tidak valid untuk tipe %qT dan %qT ke binari %qO"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk dari tipe %<void *%> dalam pengurangan"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah metoda  dalam pengurangan"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "penggunaan tidak valid dari sebuah penunjuk ke sebuah tipe tidak lengkap dalam aritmetik penunjuk"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "penggunaan tidak valid dari %qE untuk membentuk sebuah penunjuk ke anggota fungsi"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  sebuah kualified-id dibutuhkan"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "tanda kurung disekitar %qE tidak dapat digunakan untuk membentuk sebuah penunjuk-ke-anggota-fungsi"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari tidak terkualifikasi atau bertanda kurun anggota bukan statis fungsi untuk membentuk sebuah penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari sebuah anggota fungsi terikat ke sebuah bentuk penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ melarang mengambil alamat dari fungsi %<::main%>"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "tidak dapat membuat penunjuk ke anggota referensi %qD"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "tidak dapat mengambil alamat dari bit-field %qD"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "taking address of an immediate function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ melarang mengurangi sebuah enum"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ melarang meningkatkan sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ melarang mengurangi sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "alamat dari variabel eksplisit register %qD diminta"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "alamat yang diminta untuk %qD, yang dideklarasikan %<register%>"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away constness"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %q#T"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "tidak valid static_cast dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "mengubah dari %qT ke %qT"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "cast dari %qT ke %qT kehilangan presisi"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "cast dari %qT ke %qT menaikan alignmen yang dibutuhkan dari tipe target"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ melarang casting diantara penunjuk ke fungsi dan penunjuk ke objek"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang bukan sebuah penunjuk, referensi, ataupun sebuah tipe penunjuk-ke-anggota-data"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang merupakan sebuah penunjuk atau referensi ke sebuah tipe fungsi"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "const_cast tidak valid dari sebuah rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "const_cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ melarang casting ke sebuah tipe array %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  dalam evaluasi dari %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipe tidak kompatibel dalam assignmen dari %qT ke %qT"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array digunakan sebagai penginisialisasi"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "assignmen array tidak valid"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dalam penunjuk ke anggota fungsi konversi"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "penunjuk ke anggota konversi melalui basis maya %qT"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dalam penunjuk ke anggota konversi"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "tidak dapat mengubah %qT ke %qT untuk argumen %qP ke %qD"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "dalam melewatkan argumen %P dari %q+D"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "mengembalikan referensi ke sementara"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "referensi ke variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in return statement"
 msgid "redundant move in return statement"
 msgstr "operan tidak valid dalam pernyataan return"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "tidam dapat kembali dari sebuah penanganan dari sebuah fungsi-coba-blok dari sebuah konstruktor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "hilang penginisialisasi"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> harus tidak mengembalikan KOSONG kecuali ini dideklarasikan %<throw()%> (atau ada dalam pengaruh -fcheck-new )"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -64496,114 +64555,108 @@ msgstr "kurung disekitar penginisialisasi skalar"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "tidak dapat menginisialisasi kumpulan dari tipe %qT dengan sebuah kompound literal"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "prototipe untuk %q#D tidak cocok dengan kelas apapun %qT"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "tidak ada field %qD ditemukan dalam union sedang diinisialisasi"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "nilai indeks daripada nama field dalam union penginisialisasi"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "operan dasar dari %<->%> memiliki tipe bukan penunjuk %qT"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "hasil dari %<operator->()%> menghasilkan hasil bukan penunjuk"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "operan dasar dari %<->%> bukan sebuah penunjuk"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE tidak dapat digunakan sebagai sebuah anggota penunjuk, karena ini adalah tipe %qT"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "tidak dapat mengaplikasikan anggota penunjuk %qE ke %qE, yang dari tipe bukan class %qT"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-#| msgid "could not convert template argument %qE to %qT"
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "tidak dapat mengubah argumen template %qE ke %qT"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "invalid value-initialization of reference type"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi %qD yang melemparkan tipe tidak lengkap %q#T"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi yang melemparkan tipe tidak lengkap %q#T"
@@ -64623,292 +64676,298 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "extern symbols cannot have initializers"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be INTENT(IN) at %C"
 msgid "variables cannot be of type void"
 msgstr "Variabel %s tidak dapat berupa INTENT(IN) di %C"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "cannot be declared to be a function"
 msgstr "new tidak dapat diaplikasikan ke sebuah fungsi tipe"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of %<struct %E%>"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "redefinisi dari %<struct %E%>"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be %s"
 msgstr "tidak dapat membuka %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be `scope` and `%s`"
 msgstr "tidak dapat membuka %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "Use the Cygwin interface"
 msgid "field not allowed in interface"
 msgstr "Gunakan antar-muka Cygwin"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "variable-size type declared outside of any function"
 msgid "inout variables can only be declared inside inout functions"
 msgstr "tipe ukuran variabel dideklarasikan diluar dari fungsi apapun"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 #| msgid "%Honly constructors take base initializers"
 msgid "manifest constants must have initializers"
 msgstr "%Hhanya konstruktor yang mengambil penginisialisasi dasar"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "size of type %s is invalid"
 msgstr "spesifikasi '%s' tidak valid"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%s does not have a default initializer"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "is not a static and cannot have static initializer"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "static storage variables cannot have destructors"
 msgstr "Java class %qT tidak dapat memiliki sebuah destruksi"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "string expected for library name"
 msgstr "diduga nama class"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "string expected for mangled name"
 msgstr "operan tidak terduga"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "tidak ada argumen"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "can only apply to a single declaration"
 msgstr "konflik deklarasi %q#D"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "repeated using declaration %q+D"
 msgid "incomplete mixin declaration (%s)"
 msgstr "diulang menggunakan deklarasi %q+D"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Memory partitions should have at least one symbol"
 msgid "enum %s must have at least one member"
 msgstr "Partisi memori seharusnya memiliki paling tidak satu simbol"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "circular reference to enum member"
 msgstr "mengembalikan referensi ke sementara"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgid "template tuple parameter must be last one"
 msgstr "tipe parameter template harus menggunakan kata kunci %<class%> atau %<typename%>"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "rekursif inlining"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "rekursif inlining"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "error instantiating"
 msgstr "error menulis %qs"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%s must be a function instead of %s"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "functions cannot be scope"
@@ -64917,45 +64976,55 @@ msgstr "fungsi virtual tidak dapat menjadi friend"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "%s functions cannot be abstract"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot override a non-virtual function"
 msgstr "Peringatkan mengenai overloaded nama fungsi virtual"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "cannot be both final and abstract"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -64963,189 +65032,189 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot override final function %s"
 msgstr "tidak dapat menon-aktifkan fungsi bawaan %qs"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "multiple overrides of same function"
 msgstr "dipanggil objek %qE bukan sebuah fungsi"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in return"
 msgid "incompatible covariant types %s and %s"
 msgstr "tipe tidak kompatibel dalam kembali"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not allow extra %<;%> outside of a function"
 msgid "does not override any function"
 msgstr "ISO C tidak mengijinkan kelebihan %<;%> diluar dari sebuah fungsi"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot override final function %s.%s"
 msgstr "tidak dapat menon-aktifkan fungsi bawaan %qs"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "override only applies to class member functions"
 msgstr "atribut %qs hanya berlaku ke fungsi"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "Peringatkan mengenai overloaded nama fungsi virtual"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "first argument must be type size_t, not %s"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "one argument of type void* expected, not %s"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "structs, unions cannot be abstract"
 msgstr "union tidak dapat dibuat transparan"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "circular pointer delegation detected"
 msgid "circular inheritance"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "mengabaikan duplikasi direktori \"%s\"\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot inherit from final class %s"
 msgstr "tidak dapat menemukan berkas untuk class %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "mixin templates are not regular templates"
 msgstr "parameter template tidak cocok dengan template"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "template-id %qD untuk %q+D tidak cocok dengan deklarasi template apapun"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot resolve"
 msgstr "tidak dapat membuka %s"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "cannot alias an expression %s"
@@ -65161,22 +65230,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only reference %qD"
 msgid "has forward references"
@@ -65241,23 +65310,22 @@ msgstr ""
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "tipe kembali fungsi tidak dapat berupa fungsi"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "destructor priorities are not supported"
 msgid "naked assembly functions with contracts are not supported"
@@ -65835,7 +65903,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -67067,12 +67135,12 @@ msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Indeks awal substring di %L lebih kecil dari satu"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Indeks akhir substring di %L melebihi panjang string"
@@ -67273,7 +67341,7 @@ msgstr "Spesifikasi INTENT buruk di %C"
 msgid "deferred type parameter at %C"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -69997,7 +70065,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -70088,7 +70156,7 @@ msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -70232,12 +70300,12 @@ msgstr "Argumen pertama dari penempatan yang didefinisikan di %L harus berupa IN
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari penempatan didefinisikan di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen pertama dari antar-muka operator di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari antar-muka operator di %L harus berupa INTENT(IN)"
@@ -70362,616 +70430,616 @@ msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "INTENT(%s) argumen aktual di %L mungkin menginterferensi dengan argumen aktual di %L."
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Tipe tidak cocok dalam argumen '%s' di %L; dilewatkan %s ke %s"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Bentuk-diasumsikan aktual argumen di %L adalah tidak kompatibel dengan bentuk tidak diasumsikan dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "'%s' dan '%s' argumen dari '%s' intrinsik di %L harus memiliki tipe yang sama"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalar KARAKTER aktual argumen dengan array dummy argumen '%s' di %L"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalar KARAKTER aktual argumen dengan array dummy argumen '%s' di %L"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Argumen kata-kunci '%s' di %L telah berasosiasi dengan argumen aktual lain"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Lebih aktual daripada formal argumen dalam pemanggilan prosedur di %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Hilang alternatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Tidak terduga alternaatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Panjang karakter tidak cocok (%ld/%ld) diantara argumen aktual dan penunjuk atau dapat dialokasikan argumen dummy '%s' di %L"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Panjang karakter tidak cocok (%ld/%ld) diantara argumen aktual dan diasumsikan-bentuk argumen dummy '%s' di %L"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Panjang karakter dari argumen aktual lebih pendek dari argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Diduga sebuah prosedur penunjuk untuk argumen '%s' di %L"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Aktual argumen untuk '%s' tidak dapat diasumsikan array berukuran di %L"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Aktual argumen untuk '%s' harus DAPAT DIALOKASIKAN di %L"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT) or VOLATILE attribute of the dummy argument '%s'"
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Daerah array aktual argumen dengan vektor subscript di %L adalah tidak kompatibel dengan INTENT(OUT), INTENT(INOUT) atau VOLATILE atribut dari argumen dummy'%s'"
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Bentuk-diasumsikan aktual argumen di %L adalah tidak kompatibel dengan bentuk tidak diasumsikan dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Daerah array aktual argumen di %L adalah tidak kompatibel dengan tidak-diasumsikanbentuk dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Penunjuk array aktual argumen di %L membutuhkan sebuah bentuk diasumsikan ataupenunjuk array dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Hilang alternatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Hilang aktual argumen untuk argumen '%s' di %L"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Aktual argumen sama berasosiasi dengan INTENT(%s) argumen '%s' dan INTENT(%s) argumen '%s' di %L"
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan memiliki atribut PENUNJUK"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan adalah dilewatkan ke sebuah argumen INTENT(%s)"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan adalah dilewatkan ke sebuah argumen INTENT(%s)"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic character length function '%s' at %L must have an explicit interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Otomatis panjang fungsi karakter '%s' di %L harus memiliki sebuah antar-muka eksplisit"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Simbol '%s' di %L telah memiliki sebuah antar-muka eksplisit"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D teraliasi ke simbol tidak terdefinisi %qs"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entiti '%s' di %C telah ada dalam sebuah antar-muka"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Tidak dapat overwrite GENERIC '%s' di %L"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "'%s' di %L overrides sebuah prosedur binding dideklarasikan NON_OVERRIDABLE"
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "'%s' di %L overrides sebuah prosedur PURE dan juga harus berupa PURE"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "'%s' di %L overrides sebuah prosedur ELEMENTAL dan juga harus berupa ELEMENTAL"
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "'%s' di %L overrides sebuah prosedur bukan ELEMENTAL dan tidak harus berupa ELEMENTAL juga"
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "'%s' di %L overrides sebuah SUBROUTINE dan juga harus berupa sebuah SUBROUTINE"
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "'%s' di %L overrides sebuah FUNGSI dan juga harus berupa sebuah FUNGSI"
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "'%s' di %L overrides sebuah prosedur PUBLIK dah tidak harus berupa PRIVATE"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Argumen dummy '%s' dari '%s' di %L seharusnya bernama '%s' untuk mencocokan dengan argumen yang berhubungan dengan prosedur overridden"
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "'%s' di %L harus memiliki jumlah sama dari argumen formal seperti prosedur overridden"
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "'%s' di %L overrides sebuah binding NOPASS dan juga harus berupa NOPASS"
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "'%s' di %L overrides sebuah pengikatan dengan PASS dan juga harus berupa PASS"
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Argumen dummy objek yang dilewatkan dari '%s' di %L harus berada di posisi yang sama sebagai argumen dumy objek yang dilewatkan dari prosedur overridden"
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s tag di %L harus berupa tipe %s"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "Argumen dim di %L harus berupa tipe INTEGER"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued internal function '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Nilai-karakter fungsi internal '%s' di %L tidak boleh dengan panjang diasumsikan"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "pernyataan DATA di %C tidak diperbolehkan dalam sebuah prosedur PURE"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Terlalu banyak argumen dalam panggilan ke '%s' di %L"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -71135,37 +71203,37 @@ msgstr "intrinsik transformational '%s' di %L tidak diijinkan dalam sebuah ekspr
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fortran 2003: Fungsi elemental sebagai ekspresi inisialisasi dengan bukan integer/bukan-karakter argumen di %L"
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Panggilan subroutine ke intrinsik '%s' di %L tidak PURE"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Panggilan subroutine ke intrinsik '%s' di %L tidak PURE"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Ekstensi: Konversi dari %s ke %s di %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Konversi dari %s ke %s di %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Ekstensi: Konversi dari %s ke %s di %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Konversi dari %s ke %s di %L"
@@ -71173,25 +71241,25 @@ msgstr "Konversi dari %s ke %s di %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "Tidak dapat mengubah %s ke %s di %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Tidak dapat mengubah %s ke %s di %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "'%s' dideklarasikan di %L mungkin bayangan intrinsik dari nama sama. Dengan tujuan untuk memanggil intrinsik, eksplisit deklarasi INTRINSIK mungkin dibutuhkan."
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
@@ -71801,7 +71869,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -73096,12 +73164,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -73272,166 +73340,166 @@ msgstr "Operator intrinsik '%s' direferensikan di %L tidak ditemukan dalam modul
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "Tidak dapat membuka berkas modul '%s' untuk menulis di %C: %s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Error menulis berkas modul '%s' untuk menulis: %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Cannot delete module file %qs: %s"
 msgstr "tidak dapat menghapus berkas modul '%s': %s"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "tidak dapat mengubah nama berkas modul '%s' ke '%s': %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "Tidak dapat menghapus berkas modul sementara '%s': %s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs at %C already declared"
 msgstr "Simbol '%s' telah terdeklarasi"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul intrinsik ISO_C_BINDING"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "Simbol '%s' telah terdeklarasi"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, fuzzy, gcc-internal-format
 #| msgid "Use of intrinsic module '%s' at %C conflicts with non-intrinsic module name used previously"
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Penggunaan daro modul intrinsik '%s' di %C konflik dengan tidak-intrinsik nama modul digunakan sebelumnya"
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Penggunaan dari NUMERIC_STORAGE_SIZE konstanta bernama dari modul intrinsik ISO_FORTRAN_ENV di %L adalah tidak kompatibel dengan pilihan %s"
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Penggunaan dari NUMERIC_STORAGE_SIZE konstanta bernama dari modul intrinsik ISO_FORTRAN_ENV di %C adalah tidak kompatibel dengan pilihan %s"
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul intrinsik ISO_FORTRAN_ENV"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "pernyataan %s di %C tidak dalam jangkauan sebuah loop"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003: ISO_FORTRAN_ENV modul intrinsik di %C"
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_C_BINDING module at %C"
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003: ISO_C_BINDING modul di %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "Tidak dapat menemukan modul intrinsik bernama '%s' di %C"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Tidak dapat membuka berkas modul '%s' untuk pembacaan di %C: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Penggunaan dari modul tidak intrinsik '%s' di %C konflik dengan nama modul intrinsik yang digunakan sebelumnya"
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Berkas '%s' dibuka di %C bukan sebuah berkas modul GFORTRAN"
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -74016,8 +74084,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF clause di %L membutuhkan sebuah ekspresi skalara LOGIKAL"
@@ -76259,7 +76327,7 @@ msgstr "Intrinsik '%s' dideklarasikan INTRINSIC di %L tidak tersedia dalam konfi
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Bukan prosedur REKURSIF '%s' di %L mungkin memanggil dirinya sendiri secara rekursif. Deklarasikan itu secara RECURSIVE atau gunakan -frecursive"
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Label %d direferensikan di %L tidak pernah terdefinisi"
@@ -76391,7 +76459,7 @@ msgstr "Tidak dapat meresolf fungsi spesifik '%s'di %L"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -76571,223 +76639,223 @@ msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Spesifikasi bentuk di %L tidak dapat negatif"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tidak legal stride dari nol di %L"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscrip hilang dalam referensi array"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Jangkauan paling kanan ats dari daerah ukuran array yang diasumsikan tidak dispesifikasikan di %L"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Indeks array di %L harus berupa skalar"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Indeks array di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ekstensi: indeks array RIL di %L"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argumen dim di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Indeks array di %L adalah sebuah array dari tingkat %d"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Indeks awal substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Indeks awal substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Indeks akhir substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut PENUNJUK di %L"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut DAPAT DIALOKASIKAN di %L"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Dua atau lebih referensi bagian dengan tingkat bukan-nol tidak boleh dispesifikasikan di %L"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -76797,12 +76865,12 @@ msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -76812,314 +76880,314 @@ msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s', digunakan dalam sebuah ekspresi spesifikasi, direferensikan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s' digunakan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "instance variabel %qs dideklarasikan %s"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Argumen '%s' dari prosedur elemental di %L harus berupa skalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Tidak ditemukan pengikatan spesifik yang cocok untuk panggilan ke GENERIC '%s' di %L"
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' di %L seharusnya berupa sebuah SUBROUTINE"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' di %L seharusnya berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s di %L harus berupa sebuah skalar"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "%s at %L must be integer"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s di %L harus berupa INTEGER"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL awal ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL akhir ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL stride ekspresi di %L harus berupa sebuah skalar %s"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL stride ekspresi di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL indeks '%s' mungkin tidak muncul dalam spesifikasi triplet di %L"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Ekspresi dalam pernyataan ALOKASI di %L harus berupa DAPAT DIALOKASIKAN atau sebuah PENUNJUK"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' tidak boleh muncul dalam spesifikasi array di %L dalam pernyataan ALOKASI yang sama dimana ini sendiri dialokasikan"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -77128,310 +77196,310 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %d"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa skalar"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "KASUS BAKU di %L tidak dapat diikuti oleh sebuah KASUS BAKU kedua di %L"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Jangkauan logikal dalam pernyataan CASE di %L tidak diperbolehkan"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "nilai logikan konstan dalam pernyataan CASE diulang di %L"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Spesifikasi jangkauan di %L tidak pernah cocok"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logikal SELECT CASE blok di %L memiliki lebih dari dua kasus"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Nama '%s' tidak dapat digunakan sebagai sebuah operator terdefinisi di %C"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "Selector at %L must not be coindexed"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Elemen pemindahan data di %L tidak dapat berupa sebuah referensi lengkap ke sebuah array yang ukurannya diasumsikan"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "NUM_THREADS clause di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Pernyataan di %L bukan sebuah pernyataan pencabangan target yang valid untuk sebuah pernyataan percabangan di %L"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Cabang di %L bisa menyebabkan sebuah loop tak terhingga"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -77439,199 +77507,199 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "DIMANA mask di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "penempatan target WHERE di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "penempatan bukan-ELEMEN didefinisikan-pengguna dalam WHERE di %L"
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Pernyataan didalam WHERE di %L tidak didukung"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL dengan indeks '%s' tidak digunakan di sisi kiri dari penempatan di %L dan jadi mungkin menyebabkan penempatan berulang di objek ini"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Sebuah konstruks FORALL luar telah memiliki sebuah indeks dengan nama ini %L"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE clause di %L membutuhkan sebuah array LOGIKAL"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Ekspresi KARAKTER akan dipotong dalam penempatan (%d/%d) di %L"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "pernyataan GOTO ASSIGNED di %L membutuhkan sebuah variabel INTEGER"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabel '%s' belum pernah ditempatkan sebuah label target di %L"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Pernyataan RETURN alternatif di %L membutuhkan sebuah SKALAR-INTEGER return penspesifikasi"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Pernyataan aritmetik IF di %L membutuhkan sebuah ekspresi numerik"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Kondisi keluar dari loop DO WHILE di %L harus berupa sebuah ekspresi skalar LOGIKAL"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL mask clause di %L membutuhkan sebuah ekspresi LOGIKAL"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -77639,7 +77707,7 @@ msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -77647,1088 +77715,1088 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Objek skalar '%s' di %L mungkin tidak dapat DIALOKASIKAN"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Tipe '%s' tidak dapat host assosiasi di %L karena ini diblok dengan sebuah objek tidak kompatibel dari nama sama yang dideklarasikan di %L"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul atau array aplikasi utama '%s' di %L harus memiliki bentuk konstan"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entity dengan panjang karakter diasumsikan di %L harus berupa sebuah argumen dummy atau sebuah PARAMETER"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Dapat dialokasikan '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsik '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Hasil fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Array otomatis '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "dalam %s, di %s:%d"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Pernyataan fungsi nilai-karakter '%s' di %L harus memiliki panjang konstant"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah argumen dummy dari '%s', yang mana ini adalah PUBLIK di %L"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: Prosedur '%s' dalam antar-muka PUBLIK '%s' di %L memakai argumen dummy dari '%s' dimana ini adalah PRIVATE"
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Fungsi ELEMEN '%s' di %L harus memiliki sebuah hasil skalar"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Pernyataan fungsi '%s' di %L tidak diperbolehkan sebagai argumen aktual"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-array"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat rekursif"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Prosedur dummy '%s' di %C tidak dapat memiliki sebuah antar-muka umum"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut SAVE dalam '%s' di %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "Prosedur FINAL '%s' di %L bukan sebuah SUBROUTINE"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Prosedur FINAL di %L harus memiliki tepat satu argumen"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa tipe '%s'"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "argumen dari prosedur FINAL di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argumen dari prosedur FINAL di %L tidak boleh berupa OPSIONAL"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa INTENT(OUT)"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Prosedur FINAL bukan skalar di %L seharusnya memiliki diasumsikan argumen bentuk"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "prosedur FINAL '%s' dideklarasikan di %L memiliki tingkat yang sama (%d) seperti '%s'"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Hanya array prosedur FINAL dideklarasikan untuk tipe turunan '%s' didefinisikan di %L, disarankan juga skalar satu"
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' dan '%s' tidak dapat dicampurkan FUNCTION/SUBROUTINE untuk GENERIC '%s' di %L"
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' dan '%s' untuk GENERIC '%s' di %L adalah ambigu"
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Tidak terdefinisi pengikatan spesifik '%s' sebagai target dari GENERIC '%s' di %L"
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC '%s' di %L harus target sebuah pengikatan spesifik, '%s' adalah GENERIC, juga"
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC '%s' di %L tidak dapat overwrite pengikatan spesifik dengan nama sama"
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' harus berupa sebuah prosedur modul atau sebuah prosedur eksternal dengan sebuah antar-muka eksplisit di %L"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic entities are not yet implemented, non-polymorphic passed-object dummy argument of '%s' at %L accepted"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "entiti polymorphic belum diimplementasikan, bukan polymorphic objek argumen dummy dilewatkan dari '%s' di %L diterima"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama seperti sebuah komponen turunan dari '%s'"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumen dari ICHAR di %L harus berupa panjang satu"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumen '%s' dari prosedur elemental di %L tidak dapat memiliki atribut POINTER"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponen '%s' dari '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Panjang karakter dari komponen '%s' butuh untuk menjadi sebuah ekspresi spesifikasi konstan di %L"
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: Komponen '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah komponen dari '%s', yang mana adalah PUBLIK di %L"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponen %s dari tipe URUTAN dideklarasikan di %L tidak dapat memiliki atribut URUTAN"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Bukan ekstensible tipe turunan '%s' di %L tidak boleh berupa ABSTRACT"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%H%qE belum pernah dideklarasikan"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must not have assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' tidak boleh memiliki bentuk yang diasumsikan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' telah dideklarasikan PRIVATE dan tidak dapat berupa anggota dari PUBLIK namelist '%s' di %L"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST objek '%s' memiliki use-associated komponen PRIVATE dan tidak dapat berupa anggota dari daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' meemiliki komponen PRIVATE dan tidak dapat berupa anggota dari PUBLIK daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter array '%s' di %L tidak dapat berupa otomatis atau bentuk deferred"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Tipe PARAMETER secara implisit '%s' di %L tidak cocok dengan tipe IMPLISIT kemudian"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipe turunan tidak kompatibel dalam PARAMETER di %L"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Spesifikasi buruk untuk diasumsikan ukuran array di %C"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Ukuran array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Simbol di %L bukan sebuah variabel DUMMY"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' di %L tidak dapat memiliki VALUE atribut karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang konstant"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C interoperable karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang satu"
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Tipe turunana '%s' di %L adalah tipe '%s',  yang mana belum didefinisikan"
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Diasumsikan bentuk array '%s' di %L tidak diijinkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel '%s' di %L tidak dapat berupa BIND(C) karena ini bukan sebuah blok UMUM atau dideklarasikan dalam tingkat cakupan modul"
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIK %s '%s' di %L dari tipe turunan '%s' PRIVATE"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) dummy argumen '%s' di %L adalah UKURAN DIASUMSIKAN dan jadi tidak dapat memiliki sebuah penginisialisasi baku"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Prosedur dummy di %L tidak diperbolehkan dalam prosedur ELEMENTAL"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate di %L bukan SAVEd"
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Diduga daftar dari entiti bernama di %C"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "DATA BLOK elemen '%s' di %L harus berupa dalam COMMON"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA array '%s' di %L harus dispesifikasikan dalam sebuah deklarasi sebelumnya"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Daerah array tidak konstant di %L dalam pernyataan DATA"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "pernyataan DATA di %L memiliki lebih variabel daripada nilai"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "pernyataan DATA di %L memiliki lebih banyak nilai daripada variabel"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Label %d di %L didefinisikan tetapi tidak digunakan"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Label %d di %L didefinisikan tetapi tidak dapat digunakan"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L harus memiliki atribut URUTAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Tipe variabel turunan '%s' di %L dengan inisialisasi baku tidak dapat berada dalam EKUIVALEN dengan sebuah variabel dalam COMMON"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L dengan komponen penunjuk tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Baik semua atau kosong dari objek dalam EKUIVALEN set di %L yang memiliki atribut TERPROTEKSI"
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Anggota blok umum '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN dalam prosedur pure '%s'"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Konstanta bernama '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Array '%s' di %L dengan cakupan tidak-konstan tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Komponen struktur '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring di %L memiliki panjang nol"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Panjang karakter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fungsi PUBLIK '%s' di %L tidak dapat berupa tipe PRIVATE '%s'"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "MASUKAN '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prosedur operator pengguna '%s' di %L tidak dapat berupa panjang karakter diasumsikan"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prosedur operator pengguna '%s' di %L harus memiliki paling tida satu argumen"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Argumen pertama dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Argumen kedua dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Antar-muka operator di %L harus memiliki, paling tidak, dua argumen"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -79666,19 +79734,19 @@ msgstr "Overlapping tidak sama penginisialisasi dalam EKUIVALEN di %L"
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, fuzzy, gcc-internal-format
 #| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Jumlah dari elemen dalam konstruktor array di %L membutuhkan sebuah peningkatan dari batas atas %d yang diijinkan. Lihat pilihan -fmax-array-constructor"
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L for argument '%s'"
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Membuat array sementara di %L untuk argumen '%s'"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipe ekspresi buruk selama walk (%d)"
@@ -79781,119 +79849,119 @@ msgstr "Diduga sebuah ekspresi inisialisasi di %C"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "variabel instrinsic yang bukan sebuah prosedur"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return value of function %qs at %L not set"
 msgstr "Nilai kembali dari fungsi '%s' di %L tidak diset"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Deferred type parameter not yet supported"
 msgstr "Jenis parameter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "backend deklarasi untuk variabel modul %s telah ada"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Variabel '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Dummy argumen '%s' di %L telah dideklarasikan INTENT(OUT) tetapi belum diset"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Dummy argumen '%s' di %L telah dideklarasikan INTENT(OUT) tetapi belum diset"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 #| msgid "Unused dummy argument '%s' at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "Argumen dummy tidak digunakan '%s' di %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Variabel '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused variable %qs declared at %L"
 msgstr "Variabel '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Unused parameter %qs declared at %L"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 #| msgid "Return value '%s' of function '%s' declared at %L not set"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Nilai kembali dari fungsi '%s' dideklarasikan di %L tidak diset"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Instrinsik op tidak diketahui"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Daftar fungsi argumen tidak diketahui di %L"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -80064,7 +80132,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
@@ -80207,7 +80275,7 @@ msgstr "-G dan -static adalah mutually exclusive"
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-G dan -static adalah mutually exclusive"
 
 #: lto/lto-object.c:107
@@ -81435,7 +81503,7 @@ msgstr "Pilihan ke -finit-real: %s tidak dikenal"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "Pilihan ke -finit-real: %s tidak dikenal"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized option '-%s'"
 msgid "Unrecognized option: %qs"
@@ -81454,15 +81522,15 @@ msgstr "nama makro hilang setelah %qs"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "hilang nama berkas setelah %qs"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "hilang jalur setelah %qs"
@@ -81518,7 +81586,7 @@ msgstr "hilang open paren"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "nilai visibility \"%s\" tidak dikenal"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized scalar storage order value %qs"
@@ -81613,106 +81681,106 @@ msgstr "%qs sudah ditinggalkan"
 msgid "unknown linker output %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown excess precision style %qs"
 msgstr "gaya demangling '%s' tidak diketahui"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, fuzzy, gcc-internal-format
 #| msgid "Place floating point constants in TOC"
 msgid "unknown floating point contraction style %qs"
 msgstr "Tempatkan konstanta titik pecahan dalam TOC"
 
-#: common.opt:1718
+#: common.opt:1722
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy, gcc-internal-format
 #| msgid "unknown ira algorithm \"%s\""
 msgid "unknown IRA algorithm %qs"
 msgstr "algoritma ira \"%s\" tidak diketahui"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 #| msgid "unknown ira region \"%s\""
 msgid "unknown IRA region %qs"
 msgstr "daerah ira \"%s\" tidak diketahui"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "assertion hilang setelah %qs"
 
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "tls-model \"%s\" tidak dikenal"
 
-#: common.opt:2232
+#: common.opt:2236
 #, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr ""
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown profile update method %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Live-Patching Level %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown ira algorithm \"%s\""
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "algoritma ira \"%s\" tidak diketahui"
 
-#: common.opt:2690
+#: common.opt:2694
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown TLS model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:3067
+#: common.opt:3071
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "nilai visibility \"%s\" tidak dikenal"
 
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
@@ -84639,9 +84707,6 @@ msgstr "mode mesin %qs tidak dikenal"
 #~ msgid "no members matching %<%T::%D%> in %q#T"
 #~ msgstr "tidak ada anggota yang cocok %<%T::%D%> dalam %q#T"
 
-#~ msgid "strong using only meaningful at namespace scope"
-#~ msgstr "strong using hanya berarti di lingkup namespace"
-
 #~ msgid "current namespace %qD does not enclose strongly used namespace %qD"
 #~ msgstr "namespace %qD sekarang tidak melingkupi secara kuat namespace %qD yang digunakan"
 
diff --git a/gcc/po/ja.po b/gcc/po/ja.po
index 9ce0436f4f589..049450eec1359 100644
--- a/gcc/po/ja.po
+++ b/gcc/po/ja.po
@@ -21,7 +21,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 11.1-b20210207\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2021-02-10 19:45+0900\n"
 "Last-Translator: Hiroshi Takekawa <sian@big.or.jp>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
@@ -1262,12 +1262,12 @@ msgstr ""
 msgid "this is the insn:"
 msgstr ""
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "整列されていない load/store 命令を有効にする"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr ""
 
@@ -1440,16 +1440,16 @@ msgstr "認識できない命令:"
 msgid "insn does not satisfy its constraints:"
 msgstr "命令が制約を満たしません:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "作成時と使用時で '%s' の設定が異なります"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "作成時と使用時で %<-fpic%> の設定が異なります"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "作成時と使用時で %<-fpie%> の設定が異なります"
 
@@ -1487,7 +1487,7 @@ msgstr ""
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr ""
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1934,86 +1934,86 @@ msgstr "strfmon 書式の長さ修飾子"
 msgid "<command-line>"
 msgstr "<コマンドライン>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, c-format
 msgid "invalid vector constant"
 msgstr "無効なベクトル定数です"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "被演算子がありません"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "無効な定数"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "無効な被演算子です"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, c-format
 msgid "invalid address mode"
 msgstr "無効なアドレスモードです"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "無効なバージョン番号形式"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "二進演算内で無効な被演算子です"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "局所動的 TLS 参照無しで '%%&' が使用されました"
@@ -2029,18 +2029,18 @@ msgid "invalid %%r value"
 msgstr "無効な %%r 値"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "無効な %%R 値"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "無効な %%N 値"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "無効な %%P 値"
@@ -2070,7 +2070,7 @@ msgstr "無効な %%M 値"
 msgid "invalid %%U value"
 msgstr "無効な %%U 値"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "無効な %%s 値"
@@ -2080,7 +2080,7 @@ msgstr "無効な %%s 値"
 msgid "invalid %%C value"
 msgstr "無効な %%C 値"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "無効な %%E 値"
@@ -2093,7 +2093,7 @@ msgstr ""
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無効な %%xn コード"
@@ -2175,35 +2175,35 @@ msgstr "被演算子として無効な UNSPEC です"
 msgid "unrecognized supposed constant"
 msgstr "認識できない定数のようなもの"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "無効なシフト被演算子"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "述語付き Thumb 命令"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "条件シーケンスにある述語付き命令"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2211,13 +2211,13 @@ msgstr "コード '%c' に対する無効な被演算子です"
 msgid "invalid operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "命令は決して実行されません"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2341,8 +2341,8 @@ msgstr "サポートされていない演算子"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2705,7 +2705,7 @@ msgstr "%<__fpreg%> に関する無効な操作です"
 msgid "invalid %%P operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "無効な %%p 値です"
@@ -2759,7 +2759,7 @@ msgid "post-increment address is not a register"
 msgstr "後置増分アドレスがレジスタではありません"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "誤ったアドレスです"
 
@@ -2811,8 +2811,8 @@ msgstr "'%%%c' は有効な被演算子接頭辞ではありません"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "'%%%c' の無効な使用法です"
@@ -2948,305 +2948,305 @@ msgstr "スタック空間が足りなくなりました。\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "'%s' をシェル内で実行して制限値を上げてください\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx はハードウェア浮動小数を要求します"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "前処理を無効にする"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx と -mno-altivec は併用できません"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 #, fuzzy
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec は vsx を無効にします"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 #, fuzzy
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 #, fuzzy
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "リトルエンディアンモードでコードを生成する"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr "誤った move です"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr "誤った 128 ビット move"
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 msgid "invalid %%A value"
 msgstr "無効な %%A 値"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "無効な %%D 値です"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "無効な %%e 値"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "無効な %%f 値です"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "無効な %%F 値です"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "無効な %%G 値です"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "無効な %%j コードです"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "無効な %%J コードです"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "無効な %%k 値です"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "無効な %%K 値です"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "無効な %%O 値です"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "無効な %%q 値です"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 msgid "invalid %%t value"
 msgstr "無効な %%t 値"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "無効な %%T 値です"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "無効な %%u 値です"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "無効な %%v 値です"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, c-format
 msgid "invalid %%V value"
 msgstr "無効な %%V 値"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "無効な %%x 値です"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 msgid "invalid %%z value"
 msgstr "無効な %%J 値"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無効な %%y 値です。'Z' 制約を使用してみてください"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 #, fuzzy
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "32 ビット乗算命令を有効にする"
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "各関数で単一の終了点を生成しない"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "整列されていない load/store 命令を有効にする"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "無効なバージョン番号形式"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "%<__fpreg%> への無効な変換です"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "無効なバージョン番号形式"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "%<__fpreg%> への無効な変換です"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "シンボルによるメモリ参照は z10 またはそれ以降でのみサポートされます"
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "'E' 出力修飾子用の無効な比較演算子です"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "'J' 出力修飾子用の無効な参照です"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "'O' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "'R' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "'S' 出力修飾子用にはメモリ参照が予期されます"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "'S' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "'N' 出力修飾子用にはレジスタまたはメモリ式が予期されます"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "'M' 出力修飾子用にはレジスタまたはメモリ式が予期されます"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な定数です"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "無効な定数です - 出力修飾子の使用を試みてください"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な定数です"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "無効な式です - 出力修飾子の使用を試みてください"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な式です"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 msgid "vector argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 #, fuzzy
 msgid "types differ in signedness"
 msgstr "戻りでのポインタの先の符号が異なります"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3514,8 +3514,8 @@ msgstr "({無名})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> が予期されます"
@@ -3535,7 +3535,7 @@ msgstr "%<;%> が予期されます"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> が予期されます"
@@ -3543,7 +3543,7 @@ msgstr "%<)%> が予期されます"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> が予期されます"
@@ -3561,21 +3561,21 @@ msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> が予期されます"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> が予期されます"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> が予期されます"
@@ -3586,13 +3586,13 @@ msgstr "%<{%> が予期されます"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> が予期されます"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> が予期されます"
@@ -3601,7 +3601,7 @@ msgstr "%<while%> が予期されます"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> が予期されます"
@@ -3610,18 +3610,18 @@ msgstr "%<,%> が予期されます"
 msgid "expected %<.%>"
 msgstr "%<.%> が予期されます"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> が予期されます"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> が予期されます"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> または %<)%> が予期されます"
@@ -3629,28 +3629,28 @@ msgstr "%<,%> または %<)%> が予期されます"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> が予期されます"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> が予期されます"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(無名)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> が予期されます"
@@ -3665,29 +3665,29 @@ msgstr "%<__label__%> が予期されます"
 msgid "candidate:"
 msgstr "候補:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "利用者定義命令を有効にする"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "候補:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "候補 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "候補 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "case ラベルにジャンプしています"
 
@@ -3912,31 +3912,31 @@ msgstr "マクロ引数内でディレクトリを使うことはできません
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 #, fuzzy
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 msgid "%<using enum%> of dependent type %qT"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "候補:"
 
@@ -3980,48 +3980,48 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "単項マイナスへの引数の型が間違っています"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "単項プラスへの引数の型が間違っています"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "ビット反転への引数の型が間違っています"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs への引数の型が間違っています"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "複素共役(~)への引数の型が間違っています"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4121,7 +4121,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4263,7 +4263,7 @@ msgstr ""
 msgid "Bad type in constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "予期しない型が `id' (%s) に指定されました"
@@ -4293,11 +4293,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "代入"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 #, fuzzy
 msgid "pointer assignment"
 msgstr "代入"
@@ -4396,154 +4396,154 @@ msgstr ""
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "<不明な演算子>"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE オブジェクト"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr "ALLOCATE オブジェクト"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr "STAT 変数"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr "ERRMSG 変数"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4668,26 +4668,26 @@ msgstr "配列参照が範囲外です"
 msgid "Incorrect function return value"
 msgstr "正しくない関数戻り値です"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 msgid "Error allocating %lu bytes"
 msgstr "メモリ配置に失敗しました"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr ""
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr ""
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -4892,15 +4892,15 @@ msgstr "-Xbind-now と -Xbind-lazy は併用できません"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr "gprof(1) を使うときは `-p' の代わりに `-pg' を使用してください"
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "-EB と -EL の両方を使用することは出来ません"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-mfloat-abi=soft と -mfloat-abi=hard は併用できません"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian と -mlittle-endian は併用できません"
 
@@ -4917,8 +4917,8 @@ msgstr "リンク用のプロセッサ型が指定されていません"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "-march=... と -mcpu=... の両方を指定しないでください"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared と mdll は併用できません"
 
@@ -5085,10 +5085,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "一時配列の生成に関して警告する"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
@@ -5563,160 +5563,160 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr ""
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr ""
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "|| と共に使われる && の周りでは括弧をつけることをお勧めします"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr ""
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr ""
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, fuzzy, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "形式が定められていないファイルではネイティブの形式を使用する"
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, fuzzy, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "形式が定められていないファイルではネイティブの形式を使用する"
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr ""
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr ""
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr ""
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "ISO Fortran 2003 標準に準拠させる"
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "ISO Fortran 2008 標準に準拠させる"
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "ISO Fortran 2008 標準に準拠させる"
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "ISO Fortran 2008 標準に準拠させる"
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "ISO Fortran 95 標準に準拠させる"
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, fuzzy, no-c-format
 msgid "Conform to nothing in particular."
 msgstr "特に何も準拠させない"
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, fuzzy, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr "古いコードをサポートするための拡張を受け付ける"
@@ -6395,7 +6395,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7018,8 +7018,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, fuzzy, no-c-format
 msgid "No longer supported."
 msgstr "既にサポートされていません"
@@ -7375,467 +7375,462 @@ msgid "Specify default OpenACC compute dimensions."
 msgstr ""
 
 #: c-family/c.opt:1878
-#, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
 #, fuzzy, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "OpenMP を有効にする (Fortran では暗黙的に -frecursive が指定される)"
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr ""
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, fuzzy, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "\"compl\" や \"xor\" などの C++ 予約語を認識する"
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, fuzzy, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "前処理時でも PCH ファイルを探して使用する"
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, fuzzy, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr "規格準拠性エラーを警告に格下げする"
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, fuzzy, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr "Plan 9 言語拡張を有効にする"
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, fuzzy, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr "入力ファイルを前処理済として取り扱う"
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr ""
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "廃止されている。このスイッチは効果はない。"
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, fuzzy, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr "実行時型記述子情報を生成する"
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, fuzzy, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "列挙型として可能な限り最小幅の整数型を使用する"
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, fuzzy, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "\"wchar_t\" の元となる型を強制的に \"unsigned short\" とする"
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, fuzzy, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "\"signed\" または \"unsigned\" が与えられない場合、ビットフィールドを符号付きとする"
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, fuzzy, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr "\"char\" をデフォルトで符号付きにする"
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, fuzzy, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "十進浮動小数点ハードウェアのサポートを有効にする"
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, fuzzy, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr "コンパイル中に蓄積された統計情報を表示する"
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, fuzzy, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "列挙型の値は常にその型の範囲内にあるとみなす"
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, fuzzy, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr ""
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr ""
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, fuzzy, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "\"signed\" または \"unsigned\" が与えられていない場合、ビットフィールドを符号無しにする"
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, fuzzy, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "\"char\" をデフォルトで符号無しにする"
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, fuzzy, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr "デストラクタを登録するために __cxa_atexit を使用する"
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, fuzzy, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "例外処理内で __cxa_get_exception_ptr を使用する"
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, fuzzy, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "すべてのインライン化されたメソッドが隠された可視性を持つとマークする"
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, fuzzy, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "デフォルトの可視性を Microsoft Visual Studio に適合するように変更する"
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr ""
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, fuzzy, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-fwide-exec-charset=<cset>\tすべてのワイド文字列と文字定数を文字集合 <cset> に変換する"
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, fuzzy, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "現在の作業ディレクトリを指す #line 指示を生成する"
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr ""
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, fuzzy, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr "宣言を .decl ファイルにダンプする"
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, fuzzy, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "-femit-struct-debug-baseonly\t構造体用のデバッグ情報を積極的に削減する"
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, fuzzy, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "-femit-struct-debug-reduced\t構造体用のデバッグ情報を保守的に削減する"
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, fuzzy, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "-femit-struct-debug-detailed=<spec-list>\t構造体用のデバッグ情報の削減方法を詳細に指定する"
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, fuzzy, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <dir>\tシステムインクルードパスの最後に <dir> を追加する"
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, fuzzy, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "-imacros <file>\t<file>内にあるマクロ定義を受け付ける"
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, fuzzy, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, fuzzy, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "-include <file>\t他のファイルの前に <file> の中身をインクルードする"
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr ""
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, fuzzy, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <dir>\tシステムルートディレクトリを <dir> に設定する"
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, fuzzy, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <dir>\tシステムインクルードパスの先頭に <dir> を追加する"
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, fuzzy, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-idirafter <dir>\tシステムインクルードパスの最後に <dir> を追加する"
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, fuzzy, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <dir>\tシステムインクルードパスの最後に <dir> を追加する"
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, fuzzy, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <dir>\t主インクルードパスの最後に <dir> を追加する"
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, fuzzy, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "標準のシステムインクルードディレクトリを探査しない (-isystem で指定されたディレクトリは使用される)"
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, fuzzy, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr "C++ 用の標準システムインクルードディレクトリを探査しない"
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, fuzzy, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr "プラットフォーム固有機能の C ヘッダを生成する"
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, fuzzy, no-c-format
 msgid "Remap file names when including files."
 msgstr "ファイルをインクルードするときにファイル名を再マップする"
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "ISO 1998 C++ 標準に準拠させる"
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "-std=c99 によって廃止された"
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "-std=c99 によって廃止された"
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "ISO 1998 C++ 標準に準拠させる"
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr "-std=c99 によって廃止された"
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "ISO 1998 C++ 標準に準拠させる"
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に準拠させる (実験的かつ不完全なサポート)"
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に準拠させる (実験的かつ不完全なサポート)"
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr "ISO 1990 C 標準に準拠させる"
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "-std=c99 によって廃止された"
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "ISO 1990 C 標準 (1994年改正) に準拠させる"
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に準拠させる (実験的かつ不完全なサポート)"
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr "ISO 1990 C 標準に準拠させる"
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr "ISO 1999 C 標準に準拠させる"
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr "-std=c99 によって廃止された"
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "-std=gnu99 によって廃止された"
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "-std=gnu99 によって廃止された"
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "-std=gnu99 によって廃止された"
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に GNU 拡張付きで準拠させる (実験的かつ不完全なサポート)"
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に GNU 拡張付きで準拠させる (実験的かつ不完全なサポート)"
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "ISO 1990 C 標準に GNU 拡張付きで準拠させる"
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "-std=gnu99 によって廃止された"
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "ISO 1990 C 標準に GNU 拡張付きで準拠させる"
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に GNU 拡張付きで準拠させる (実験的かつ不完全なサポート)"
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "ISO 1990 C 標準に GNU 拡張付きで準拠させる"
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "ISO 1999 C 標準に GNU 拡張付きで準拠させる"
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "-std=gnu99 によって廃止された"
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "ISO 1990 C 標準 (1994年改正) に準拠させる"
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "-std=iso9899:1999 によって廃止された"
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, fuzzy, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "伝統的な前処理を有効にする"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, fuzzy, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\tISO C トライグラフをサポートする"
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, fuzzy, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr "システムおよび GCC 固有のマクロを事前定義しない"
@@ -8080,6 +8075,11 @@ msgstr "32 ビット整数モードでコンパイルする"
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr "テンプレートの暗黙的なインスタンス化を発行する"
+
 #: d/lang.opt:346
 #, fuzzy, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9317,143 +9317,155 @@ msgstr "ColdFire 上で 8192 個を超える GOT エントリをサポートす
 msgid "Support TLS segment larger than 64K."
 msgstr "64K より大きな TLS セグメントをサポートする"
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, fuzzy, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr "ターゲット CPU がビックエンディアンとして設定されているとみなす"
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, fuzzy, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr "ターゲット CPU がリトルエンディアンとして設定されているとみなす"
+
+#: config/riscv/riscv.opt:34
 #, fuzzy, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "-mbranch-cost=COST\t分岐コストを大体 COST 命令分に設定する"
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "__fp16 浮動小数点形式を指定する"
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, fuzzy, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "できるだけスタックをこの二の累乗に整列する"
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "ハードウェア浮動小数点二乗根命令を使用する"
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr "ColdFire のハードウェア除算命令を使用する"
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, fuzzy, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=PROCESSOR\tPROCESSOR 用に出力を最適化する"
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "-mtune=PROCESSOR\tPROCESSOR 用に出力を最適化する"
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr ""
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, fuzzy, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "関数プロローグとエピローグ用にサブルーチンを使用する"
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, fuzzy, no-c-format
 msgid "Specify the code model."
 msgstr "コードモデルを選択する"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr "整列されていないメモリ参照を使用しない"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, fuzzy, no-c-format
 msgid "Use the given data alignment."
 msgstr "書き込み可能データ整列を調整しない"
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, fuzzy, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, fuzzy, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, fuzzy, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr "ターゲット CPU の名前を指定する"
@@ -9588,12 +9600,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, fuzzy, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr "ターゲット CPU がビックエンディアンとして設定されているとみなす"
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9614,12 +9620,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, fuzzy, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr "ターゲット CPU がリトルエンディアンとして設定されているとみなす"
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -16837,2164 +16837,2164 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <dir>\tダンプ用に使用されるディレクトリ名を設定する"
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 msgid "Align the start of functions."
 msgstr "関数に開始を整列する"
 
-#: common.opt:988
+#: common.opt:992
 #, fuzzy, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr "ジャンプの到達先となるラベルのみ整列する"
 
-#: common.opt:995
+#: common.opt:999
 #, fuzzy, no-c-format
 msgid "Align all labels."
 msgstr "全てのラベルを整列する"
 
-#: common.opt:1002
+#: common.opt:1006
 #, fuzzy, no-c-format
 msgid "Align the start of loops."
 msgstr "ループの開始を整列する"
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 msgid "Enable static analysis pass."
 msgstr "伝統的な前処理を有効にする"
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, fuzzy, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "自動増加/減少命令を生成する"
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "配列の添え字を使用する前に境界検査を行うコードを生成する"
 
-#: common.opt:1091
+#: common.opt:1095
 #, fuzzy, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "加算、比較ブランチの代わりにカウントレジスタのブランチを使う"
 
-#: common.opt:1095
+#: common.opt:1099
 #, fuzzy, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr "分岐経路推測用のプロファイル情報を利用する"
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr "関数単位でスタック使用情報を出力する"
 
-#: common.opt:1115
+#: common.opt:1119
 #, fuzzy, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "関数単位でスタック使用情報を出力する"
 
-#: common.opt:1119
+#: common.opt:1123
 #, fuzzy, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<register>  <register> が関数を通じて保全されるとマークする"
 
-#: common.opt:1123
+#: common.opt:1127
 #, fuzzy, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<register>\t<register> が関数呼び出しによって変更されるとマークする"
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy, no-c-format
 msgid "Save registers around function calls."
 msgstr "関数呼び出しの前後でレジスタを保存する"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "new の戻り値を検査する"
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, fuzzy, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr "内部一貫性がありません"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 msgid "Enable code hoisting."
 msgstr "関数プロファイルを有効にする"
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "スタック調整およびスタック参照を削減する機会を探す"
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr "初期化されない大域変数類を共通セクションに配置しない"
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, fuzzy, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "-fcompare-debug 付きで再コンパイルしています"
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "レジスタは位置が完了した後に比較の除去を行う"
 
-#: common.opt:1178
+#: common.opt:1182
 #, fuzzy, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "スタック使用量を著しく増加させる最適化を行わない"
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "プログラム全体の最適化を実行する"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr "ジャンプをまたがった最適化を行う"
 
-#: common.opt:1190
+#: common.opt:1194
 #, fuzzy, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr "CSE で動作するとき、それらのターゲットへのジャンプに追随する"
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1206
 #, fuzzy, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Fortran 規格に従った複素数の乗除算を行う"
 
-#: common.opt:1206
+#: common.opt:1210
 #, fuzzy, no-c-format
 msgid "Place data items into their own section."
 msgstr "データ項目をそれら自身のセクションに配置する"
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, fuzzy, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tデバッグカウンタ制限を設定する。"
 
-#: common.opt:1218
+#: common.opt:1222
 #, fuzzy, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr "デバッグ情報内のディレクトリー名を他のものにマップする"
 
-#: common.opt:1222
+#: common.opt:1226
 #, fuzzy, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr "デバッグ情報内のディレクトリー名を他のものにマップする"
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, fuzzy, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr "関数引数をスタックから pop するのを呼び出し後まで遅らせる"
 
-#: common.opt:1236
+#: common.opt:1240
 #, fuzzy, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "分岐命令の遅延スロットを使うことを試みる"
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, fuzzy, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr "無意味な null ポインタ検査を削除する"
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, fuzzy, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr "DWARF2 重複削除を行う"
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr "仮想呼び出しを直接呼び出しに変換することを試みる"
 
-#: common.opt:1260
+#: common.opt:1264
 #, fuzzy, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 "  -fdiagnostics-show-location=[once | every-line]  診断メッセージの改行の際に,\n"
 " ソース位置情報が行の最初に表示される頻度を指定する\n"
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, fuzzy, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "-ftabstop=<number>\t列を報告用する時のタブ位置までの距離を <number> にする"
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, fuzzy, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\t様々なコンパイラ内部情報をファイルにダンプする"
 
-#: common.opt:1430
+#: common.opt:1434
 #, fuzzy, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=filename\t翻訳終了時に filename へ命令をダンプする"
 
-#: common.opt:1434
+#: common.opt:1438
 #, fuzzy, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=filename\t全ての宣言を Go コードとしてファイルに書き込む"
 
-#: common.opt:1438
+#: common.opt:1442
 #, fuzzy, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "デバッグダンプ内でアドレスの出力を抑止する"
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1459
 #, fuzzy, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "デバッグダンプ内で命令番号、行番号情報およびアドレスの出力を抑止する"
 
-#: common.opt:1459
+#: common.opt:1463
 #, fuzzy, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "デバッグダンプ内で前と次の命令番号の出力を抑止する"
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "GAS アセンブラ指示を経由して CFI 表を有効にする"
 
-#: common.opt:1467
+#: common.opt:1471
 #, fuzzy, no-c-format
 msgid "Perform early inlining."
 msgstr "部分的なインライン化を行う"
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1483
 #, fuzzy, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr "デバッグ情報内で使用されていない型の除去を行う"
 
-#: common.opt:1483
+#: common.opt:1487
 #, fuzzy, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr "デバッグ情報内で使用されていない型の除去を行う"
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "C++ クラスデバッグ情報を抑止しない。"
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy, no-c-format
 msgid "Enable exception handling."
 msgstr "例外処理を有効にする"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "多くの、目立たないがコストが高い最適化を行う"
 
-#: common.opt:1499
+#: common.opt:1503
 #, fuzzy, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\t余分な浮動小数点精度の取り扱いを指定する"
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, fuzzy, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr "NaN または無限大が生成されないと見なす"
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, fuzzy, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<register>\t<register> がコンパイラでは使用できないとマークする"
 
-#: common.opt:1546
+#: common.opt:1550
 #, fuzzy, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "拡張精度レジスタ内に float と double を配置しない"
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, fuzzy, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr "関数アドレスをレジスタに持たせる事を許可する"
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 msgid "Place each function into its own section."
 msgstr "それぞれの関数をそれ自身のセクションに配置する"
 
-#: common.opt:1590
+#: common.opt:1594
 #, fuzzy, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
-#: common.opt:1594
+#: common.opt:1598
 #, fuzzy, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
-#: common.opt:1598
+#: common.opt:1602
 #, fuzzy, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
-#: common.opt:1602
+#: common.opt:1606
 #, fuzzy, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
-#: common.opt:1607
+#: common.opt:1611
 #, fuzzy, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "レジスタ配置後に大域共通部分式の除去を行う"
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1641
 #, fuzzy, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "条件的 move 命令の利用を有効にする"
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, fuzzy, no-c-format
 msgid "Mark all loops as parallel."
 msgstr "全てのループを並列としてマークする"
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr "並列命令を有効にする"
 
-#: common.opt:1667
+#: common.opt:1671
 #, fuzzy, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, fuzzy, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr "ラベル整列最適化を有効にする"
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, fuzzy, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr "分岐可能性の推測を有効にする"
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 msgid "Process #ident directives."
 msgstr "#ident 指示を処理する"
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1711
+#: common.opt:1715
 #, fuzzy, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "条件付き実行より分岐の生成を優先する"
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 msgid "Do not generate .size directives."
 msgstr ".size 指示を生成しない"
 
-#: common.opt:1747
+#: common.opt:1751
 #, fuzzy, no-c-format
 msgid "Perform indirect inlining."
 msgstr "間接インライン化を実行する"
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, fuzzy, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "コードサイズが増加しないと分かってる場合は単純な関数を呼び出し側に統合する"
 
-#: common.opt:1761
+#: common.opt:1765
 #, fuzzy, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "一回だけ呼び出される関数を呼び出し側に統合する"
 
-#: common.opt:1765
+#: common.opt:1769
 #, fuzzy, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "一回だけ呼び出される関数を呼び出し側に統合する"
 
-#: common.opt:1772
+#: common.opt:1776
 #, fuzzy, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "  -finline-limit=<number> インライン関数のサイズを <number> に制限する"
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, fuzzy, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "関数の入り口/出口でプロファイル呼び出しを生成する"
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 msgid "Discover pure and const functions."
 msgstr "純粋および定数関数を見つける"
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr "読み取り専用およびアドレス付けできない静的変数を見つける"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "読み取り専用およびアドレス付けできない静的変数を見つける"
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1886
+#: common.opt:1890
 #, fuzzy, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority] 使用する IRA アルゴリズムを設定する"
 
-#: common.opt:1899
+#: common.opt:1903
 #, fuzzy, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] IRA 用の範囲を設定する"
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, fuzzy, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr "ループの中の全ての一般誘導変数を強度削減する"
 
-#: common.opt:1941
+#: common.opt:1945
 #, fuzzy, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "十分に大きな switch 文ではジャンプ表を使用する"
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "十分に大きな switch 文ではジャンプ表を使用する"
 
-#: common.opt:1949
+#: common.opt:1953
 #, fuzzy, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "完全にインライン化される場合でも関数用のコードを生成する"
 
-#: common.opt:1953
+#: common.opt:1957
 #, fuzzy, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "完全にインライン化される場合でも関数用のコードを生成する"
 
-#: common.opt:1957
+#: common.opt:1961
 #, fuzzy, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr "使用されない静的定数変数であっても出力する"
 
-#: common.opt:1961
+#: common.opt:1965
 #, fuzzy, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr "外部シンボルの先頭に下線 (_) を付ける"
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr "リンク時最適化を有効にする"
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "様々なリンク時最適化統計情報に関して報告する"
 
-#: common.opt:2016
+#: common.opt:2020
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "様々なリンク時最適化統計情報に関して報告する"
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "組み込み数学関数の後に errno をセットする"
 
-#: common.opt:2024
+#: common.opt:2028
 #, fuzzy, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<number>\tエラー報告する最大数を <number> にする"
 
-#: common.opt:2028
+#: common.opt:2032
 #, fuzzy, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr "永続的なメモリ確保に関して報告する"
 
-#: common.opt:2032
+#: common.opt:2036
 #, fuzzy, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "永続的なメモリ確保に関して報告する"
 
-#: common.opt:2039
+#: common.opt:2043
 #, fuzzy, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "定数と定数変数の併合を試みる"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "コンパイル単位をまたがった同一の定数の併合を試みる"
 
-#: common.opt:2047
+#: common.opt:2051
 #, fuzzy, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "コンパイル単位をまたがった同一のデバッグ文字列の併合を試みる"
 
-#: common.opt:2051
+#: common.opt:2055
 #, fuzzy, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<number>\t一行あたりの診断メッセージ文字数を <number> に制限する。0 の場合は改行しない"
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr "ループの中で変更がない計算をループの外に移動する"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr "RTL 不要なコード (dead code) の除去過程を使用する"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "RTL 不要な記憶域 (dead store) 除去過程を使用する"
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr "同期非呼び出し例外をサポートする"
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, fuzzy, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr "可能な場合、スタックフレームを生成しない"
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, fuzzy, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr "sibling 呼び出しや末尾再帰呼び出しを最適化する"
 
-#: common.opt:2124
+#: common.opt:2128
 #, fuzzy, no-c-format
 msgid "Perform partial inlining."
 msgstr "部分的なインライン化を行う"
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy, no-c-format
 msgid "Pack structure members together without holes."
 msgstr "構造体メンバを穴が開かないようにパックする"
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 #, fuzzy, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr "小さな集合体を (レジスタではなく) メモリで返す"
 
-#: common.opt:2148
+#: common.opt:2152
 #, fuzzy, no-c-format
 msgid "Perform loop peeling."
 msgstr "ループの展開を行う"
 
-#: common.opt:2152
+#: common.opt:2156
 #, fuzzy, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr "入れ子にされた条件付き実行の最適化を有効にする"
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2164
 #, fuzzy, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "可能であれば位置非依存コードを生成する (large モード)"
 
-#: common.opt:2164
+#: common.opt:2168
 #, fuzzy, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "可能であれば実行可能な位置非依存コードを生成する (large モード)"
 
-#: common.opt:2168
+#: common.opt:2172
 #, fuzzy, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "可能であれば胃非値非損コードを生成する (small モード)"
 
-#: common.opt:2172
+#: common.opt:2176
 #, fuzzy, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "可能であれば実行可能な非値非依存コードを生成する (small モード)"
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, fuzzy, no-c-format
 msgid "Specify a plugin to load."
 msgstr "ロードするプラグインを指定する"
 
-#: common.opt:2184
+#: common.opt:2188
 #, fuzzy, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<name>-<key>[=<value>]\tプラグイン <name> 用に引数 <key>=<value> を指定する"
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2192
+#: common.opt:2196
 #, fuzzy, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "ループ内の配列で、可能であればプリフェッチ命令を生成する"
 
-#: common.opt:2196
+#: common.opt:2200
 #, fuzzy, no-c-format
 msgid "Enable basic program profiling code."
 msgstr "基本プログラムプロファイリングコードを有効にする"
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, fuzzy, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr "円弧ベースプログラムプロファイリングコードを挿入する"
 
-#: common.opt:2208
+#: common.opt:2212
 #, fuzzy, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "プロファイルデータ保存用の最上位ディレクリーを設定する"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr "プロファイルデータ保存用の最上位ディレクリーを設定する"
 
-#: common.opt:2217
+#: common.opt:2221
 #, fuzzy, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "フロー一貫性が無いデータ入力の訂正を有効にする"
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2293
+#: common.opt:2297
 #, fuzzy, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr "式の値をプロファイルするためのコードを挿入する"
 
-#: common.opt:2297
+#: common.opt:2301
 #, fuzzy, no-c-format
 msgid "Report on consistency of profile."
 msgstr "内部一貫性がありません"
 
-#: common.opt:2301
+#: common.opt:2305
 #, fuzzy, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr "コード配置を改善するために関数を並べ替える"
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr "関数プロローグ内で cld 命令を生成する"
 
-#: common.opt:2312
+#: common.opt:2316
 #, fuzzy, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<string>\t<string> を使用してコンパイルを再現可能にする"
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr "オブジェクトファイル内に gcc のコマンドラインスイッチを記録する。"
 
-#: common.opt:2326
+#: common.opt:2330
 #, fuzzy, no-c-format
 msgid "Return small aggregates in registers."
 msgstr "小さな集合体をレジスタで返す"
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, fuzzy, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr "プログラム全体の最適化を実行する"
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2376
+#: common.opt:2380
 #, fuzzy, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr "コード配置を改善するために基本ブロックを並べ替える"
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, fuzzy, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "コード配置を改善するために基本ブロックを並べ替える"
 
-#: common.opt:2397
+#: common.opt:2401
 #, fuzzy, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr "コード配置を改善するために関数を並べ替える"
 
-#: common.opt:2401
+#: common.opt:2405
 #, fuzzy, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "ループ最適化後に共通部分式を除去する過程を追加する"
 
-#: common.opt:2409
+#: common.opt:2413
 #, fuzzy, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "デフォルトの浮動小数点丸め動作と見なせる最適化を無効にする"
 
-#: common.opt:2413
+#: common.opt:2417
 #, fuzzy, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr "基本ブロックをまたがるスケジューリングを有効にする"
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, fuzzy, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr "非ロードでの不確実な動作を許可する"
 
-#: common.opt:2425
+#: common.opt:2429
 #, fuzzy, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr "いくつかのロードでの不確実な動作を許可する"
 
-#: common.opt:2429
+#: common.opt:2433
 #, fuzzy, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr "より多くのロードでの不確実な動作を許可する"
 
-#: common.opt:2433
+#: common.opt:2437
 #, fuzzy, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<number>\tスケジューラの冗長レベルを設定する"
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2445
+#: common.opt:2449
 #, fuzzy, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr "レジスタ確保の前に命令を並べ直す"
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr "レジスタ確保の後で命令を並べ直す"
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, fuzzy, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr "再ロード後に選択的スケジューリングを実行する"
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2514
+#: common.opt:2518
 #, fuzzy, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "RX FPU 命令の使用を有効にする (デフォルト)。"
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2522
+#: common.opt:2526
 #, fuzzy, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "RX FPU 命令の使用を有効にする (デフォルト)。"
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "診断内で利用可能な場合に列番号を表示する。デフォルトで有効"
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, fuzzy, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr "浮動小数点定数を単精度定数に変換する"
 
-#: common.opt:2571
+#: common.opt:2575
 #, fuzzy, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "ループを展開したときに変数の展開を行う"
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "不連続なスタックフレームを生成する"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy, no-c-format
 msgid "Split wide types into independent registers."
 msgstr "ワイド型を独立したレジスタに分割する"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr "ワイド型を独立したレジスタに分割する"
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "ループを展開したときに変数の展開を行う"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tプログラム内にスタック検査コードを挿入する"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "プログラム内にスタック検査コードを挿入する。 -fstack-check=specific と同様"
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\tスタックがレジスタ <register> より後に行った場合にトラップする"
 
-#: common.opt:2623
+#: common.opt:2627
 #, fuzzy, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<name>\tスタックがシンボル <name> より後に行った場合にトラップする"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "スタック保護方法としてプロポリス (propolice) を使用する"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr "関数単位でスタック使用情報を出力する"
 
-#: common.opt:2655
+#: common.opt:2659
 #, fuzzy, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr "厳密な別名規則を適用するとみなす"
 
-#: common.opt:2659
+#: common.opt:2663
 #, fuzzy, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "符号のオーバーフローを未定義として取り扱う"
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, fuzzy, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr "構文エラーを検査して、そこで停止する"
 
-#: common.opt:2671
+#: common.opt:2675
 #, fuzzy, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr "\"gcov\" で必要となるデータファイルを作成する"
 
-#: common.opt:2675
+#: common.opt:2679
 #, fuzzy, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr "ジャンプをまたがった最適化を行う"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr "各コンパイル過程で費やした時間を報告する"
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, fuzzy, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tデフォルトのスレッド局所記憶域 (TLS) コード生成モデルを設定する"
 
-#: common.opt:2706
+#: common.opt:2710
 #, fuzzy, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr "トップレベルの関数、変数、アセンブラを並べ替える"
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "浮動小数点操作をトラップできると見なす"
 
-#: common.opt:2726
+#: common.opt:2730
 #, fuzzy, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "加算、減算、乗算内での符号付きのオーバーフローをトラップする"
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2742
+#: common.opt:2746
 #, fuzzy, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2750
+#: common.opt:2754
 #, fuzzy, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2758
+#: common.opt:2762
 #, fuzzy, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2766
+#: common.opt:2770
 #, fuzzy, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr "条件的 move 命令の利用を有効にする"
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 msgid "Enable dominator optimizations."
 msgstr "リンカ最適化を有効にする"
 
-#: common.opt:2782
+#: common.opt:2786
 #, fuzzy, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 msgid "Enable dead store elimination."
 msgstr "不要な記憶域 (dead store) の除去を行う"
 
-#: common.opt:2790
+#: common.opt:2794
 #, fuzzy, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2794
+#: common.opt:2798
 #, fuzzy, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "ループ中に不変な計算をループの外に移動する"
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "並列命令を有効にする"
 
-#: common.opt:2819
+#: common.opt:2823
 #, fuzzy, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "並列命令を有効にする"
 
-#: common.opt:2823
+#: common.opt:2827
 #, fuzzy, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr "ループ中に不変な計算をループの外に移動する"
 
-#: common.opt:2831
+#: common.opt:2835
 #, fuzzy, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr "ループの中の全ての一般誘導変数を強度削減する"
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2839
+#: common.opt:2843
 #, fuzzy, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "ループの自動並列化を有効にする"
 
-#: common.opt:2843
+#: common.opt:2847
 #, fuzzy, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "条件的 move 命令の利用を有効にする"
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2859
+#: common.opt:2863
 #, fuzzy, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2867
+#: common.opt:2871
 #, fuzzy, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr "コンパイル単位全体を一回でコンパイルする"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "反復回数が既知のとき、ループ展開を行なう"
 
-#: common.opt:2908
+#: common.opt:2912
 #, fuzzy, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2940
+#: common.opt:2944
 #, fuzzy, no-c-format
 msgid "Perform loop unswitching."
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:2944
+#: common.opt:2948
 #, fuzzy, no-c-format
 msgid "Perform loop splitting."
 msgstr "ループの展開を行う"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, fuzzy, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "巻き戻しを行なう例外補足用テーブルを生成する"
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, fuzzy, no-c-format
 msgid "Perform variable tracking."
 msgstr "変数追跡を実施する"
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "変数追跡を実施する"
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:3003
+#: common.opt:3007
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:3015
+#: common.opt:3019
 #, fuzzy, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, fuzzy, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "余分なコメントをアセンブラ出力に追加する"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tシンボル可視性のデフォルトを設定する"
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3115
+#: common.opt:3119
 #, fuzzy, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "moves/scc 以外で条件付き実行を有効にする"
 
-#: common.opt:3119
+#: common.opt:3123
 #, fuzzy, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "プログラム全体の最適化を実行する"
 
-#: common.opt:3123
+#: common.opt:3127
 #, fuzzy, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "符号付き計算オーバーフローが丸められると見なす"
 
-#: common.opt:3127
+#: common.opt:3131
 #, fuzzy, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "符号付き計算オーバーフローが丸められると見なす"
 
-#: common.opt:3131
+#: common.opt:3135
 #, fuzzy, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "0 で初期化されるデータを bss セクション内に配置する"
 
-#: common.opt:3135
+#: common.opt:3139
 #, fuzzy, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr "関数呼び出しの前後でレジスタを保存する"
 
-#: common.opt:3139
+#: common.opt:3143
 #, fuzzy, no-c-format
 msgid "Generate debug information in default format."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:3143
+#: common.opt:3147
 #, fuzzy, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
 
-#: common.opt:3147
+#: common.opt:3151
 #, fuzzy, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, fuzzy, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:3175
+#: common.opt:3179
 #, fuzzy, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "DWARF v2 (またはそれ以降) 形式でデバッグ情報を生成する"
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "デフォルト拡張形式でデバッグ情報を生成する"
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr "各関数で単一の終了点を生成する"
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, fuzzy, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "オブジェクトファイル内に gcc のコマンドラインスイッチを記録する。"
 
-#: common.opt:3219
+#: common.opt:3223
 #, fuzzy, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:3223
+#: common.opt:3227
 #, fuzzy, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "STABS 形式でデバッグ情報を生成する"
 
-#: common.opt:3227
+#: common.opt:3231
 #, fuzzy, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "拡張 STABS 形式でデバッグ情報を生成する"
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, fuzzy, no-c-format
 msgid "Toggle debug information generation."
 msgstr "デバッグ情報生成の有効・無効を切り替える"
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, fuzzy, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "VMS 形式でデバッグ情報を生成する"
 
-#: common.opt:3258
+#: common.opt:3262
 #, fuzzy, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "XCOFF 形式でデバッグ情報を生成する"
 
-#: common.opt:3262
+#: common.opt:3266
 #, fuzzy, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "拡張 XCOFF 形式でデバッグ情報を生成する"
 
-#: common.opt:3280
+#: common.opt:3284
 #, fuzzy, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "isel 命令を生成する"
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3291
+#: common.opt:3295
 #, fuzzy, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
-#: common.opt:3295
+#: common.opt:3299
 #, fuzzy, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <file>\t出力を <file> に配置する"
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 msgid "Enable function profiling."
 msgstr "関数プロファイルを有効にする"
 
-#: common.opt:3334
+#: common.opt:3338
 #, fuzzy, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "-pedantic と同様だが、エラーとして出力する"
 
-#: common.opt:3374
+#: common.opt:3378
 #, fuzzy, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "コンパイルされた関数または費やした時間に関して出力しない"
 
-#: common.opt:3406
+#: common.opt:3410
 #, fuzzy, no-c-format
 msgid "Enable verbose output."
 msgstr "冗長な出力を有効にする"
 
-#: common.opt:3410
+#: common.opt:3414
 #, fuzzy, no-c-format
 msgid "Display the compiler's version."
 msgstr "`コンパイラのバージョンを表示する"
 
-#: common.opt:3414
+#: common.opt:3418
 #, fuzzy, no-c-format
 msgid "Suppress warnings."
 msgstr "警告を抑止する"
 
-#: common.opt:3424
+#: common.opt:3428
 #, fuzzy, no-c-format
 msgid "Create a shared library."
 msgstr "共有ライブラリを作成する"
 
-#: common.opt:3472
+#: common.opt:3476
 #, fuzzy, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:3476
+#: common.opt:3480
 #, fuzzy, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:3480
+#: common.opt:3484
 #, fuzzy, no-c-format
 msgid "Create a static position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19136,1105 +19136,1115 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr ""
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr ""
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr "SCoP 内のパラメータの最大数"
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr "SCoP 内のパラメータの最大数"
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr ""
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr ""
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr ""
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "整数定数を共有するための上限値"
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "インライン関数を再帰的にインライン化する時の最大深度"
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr ""
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "大きいと見なされる翻訳単位のサイズ"
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, fuzzy, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr ""
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr ""
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr ""
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr ""
 
-#: params.opt:334
+#: params.opt:339
 #, fuzzy, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "多くの、目立たないがコストが高い最適化を行う"
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, fuzzy, no-c-format
 msgid "The size of L1 cache line."
 msgstr "L1 キャッシュサイズ"
 
-#: params.opt:350
+#: params.opt:355
 #, fuzzy, no-c-format
 msgid "The size of L1 cache."
 msgstr "L1 キャッシュサイズ"
 
-#: params.opt:354
+#: params.opt:359
 #, fuzzy, no-c-format
 msgid "The size of L2 cache."
 msgstr "L2 キャッシュサイズ"
 
-#: params.opt:358
+#: params.opt:363
 #, fuzzy, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "インライン化によって増加するスタックフレームの最大量 (百分率)"
 
-#: params.opt:362
+#: params.opt:367
 #, fuzzy, no-c-format
 msgid "The size of function body to be considered large."
 msgstr "大きいと見なされる関数本体のサイズ"
 
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "大きいと見なされるスタックフレームのサイズ"
 
-#: params.opt:370
+#: params.opt:375
 #, fuzzy, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "インライン化によって増加するスタックフレームの最大量 (百分率)"
 
-#: params.opt:374
+#: params.opt:379
 #, fuzzy, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr "大きいと見なされる翻訳単位のサイズ"
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr ""
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, fuzzy, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:398
+#: params.opt:403
 #, fuzzy, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "RPTS 用の最大反復数を指定する"
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, fuzzy, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr "SCoP 内のパラメータの最大数"
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:446
+#: params.opt:451
 #, fuzzy, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr ""
 
-#: params.opt:454
+#: params.opt:459
 #, fuzzy, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "RPTS 用の最大反復数を指定する"
 
-#: params.opt:458
+#: params.opt:463
 #, fuzzy, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:462
+#: params.opt:467
 #, fuzzy, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr ""
 
-#: params.opt:470
+#: params.opt:475
 #, fuzzy, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr "条件付き実行シーケンスの長さの最大値を変更する"
 
-#: params.opt:474
+#: params.opt:479
 #, fuzzy, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr "GCSE によって配置されるメモリの最大量"
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:486
+#: params.opt:491
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, fuzzy, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr ""
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, fuzzy, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "ヒント用に挿入される nops の最大数 (デフォルト: 2)"
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr ""
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "GCSE によって配置されるメモリの最大量"
 
-#: params.opt:522
+#: params.opt:527
 #, fuzzy, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr ""
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:538
+#: params.opt:543
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:542
+#: params.opt:547
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:546
+#: params.opt:551
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:550
+#: params.opt:555
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:554
+#: params.opt:559
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:558
+#: params.opt:563
 #, fuzzy, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "インライン関数を再帰的にインライン化する時の最大深度"
 
-#: params.opt:562
+#: params.opt:567
 #, fuzzy, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "非インライン関数を再帰的にインライン化する時の最大深度"
 
-#: params.opt:566
+#: params.opt:571
 #, fuzzy, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr ""
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr ""
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr ""
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr ""
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr ""
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr ""
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr ""
 
-#: params.opt:602
+#: params.opt:607
 #, fuzzy, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "RPTS 用の最大反復数を指定する"
 
-#: params.opt:606
+#: params.opt:611
 #, fuzzy, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr ""
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, fuzzy, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, fuzzy, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, fuzzy, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "RPTS 用の最大反復数を指定する"
 
-#: params.opt:630
+#: params.opt:635
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:634
+#: params.opt:639
 #, fuzzy, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, fuzzy, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "RPTS 用の最大反復数を指定する"
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr ""
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr ""
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr ""
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr ""
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, fuzzy, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:714
+#: params.opt:719
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:718
+#: params.opt:723
 #, fuzzy, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "自動インライン化が行われる最大命令数"
 
-#: params.opt:722
+#: params.opt:727
 #, fuzzy, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr ""
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, fuzzy, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr ""
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr ""
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr ""
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr ""
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, fuzzy, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "プリフェッチが完了する前に実行される命令数"
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, fuzzy, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr "関数プロローグ用のスタブを使用する"
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr ""
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr ""
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, fuzzy, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr ""
 
-#: params.opt:888
+#: params.opt:906
 #, fuzzy, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr "同時に実行可能なプリフェッチの数"
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr ""
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr ""
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr ""
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr ""
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr ""
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "SCoP 内のパラメータの最大数"
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr "SCoP 内のパラメータの最大数"
 
-#: params.opt:960
+#: params.opt:978
 #, fuzzy, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "SCoP 内のパラメータの最大数"
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, fuzzy, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "SCoP 内のパラメータの最大数"
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:988
+#: params.opt:1006
 #, fuzzy, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "インライン化によって増加するスタックフレームの最大量 (百分率)"
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr ""
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "テンプレートの暗黙的なインスタンス化を発行する"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, fuzzy, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "関数プロローグとエピローグ用にサブルーチンを使用する"
 
-#: params.opt:1024
+#: params.opt:1042
 #, fuzzy, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "関数プロローグとエピローグ用にサブルーチンを使用する"
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr ""
 
-#: params.opt:1056
+#: params.opt:1074
 #, fuzzy, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "SSA 最適化を有効にする"
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr ""
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20266,7 +20276,7 @@ msgid "expected boolean type"
 msgstr "整数または真偽型が予期されます"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "ポインタが予期されます"
@@ -20335,7 +20345,7 @@ msgstr "十分な引数がありません"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "引数が多すぎます"
@@ -20709,7 +20719,7 @@ msgstr "%qE 属性は %s 属性と競合します"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "前方での `%s' の宣言"
@@ -20764,7 +20774,7 @@ msgstr "型が既に定義されているため型属性が無視されました
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -20793,20 +20803,20 @@ msgstr "型が既に定義されているため型属性が無視されました
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -20817,8 +20827,8 @@ msgstr "%qE 属性は無視されました"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "前方での `%s' の宣言"
@@ -20828,58 +20838,58 @@ msgstr "前方での `%s' の宣言"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D は既に dllexport 属性と宣言されています: dllimport は無視されます"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D は dll からの参照後に dllimport 属性無しで再宣言されました"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D は dllimport 属性無しで再宣言されました: 前の dllimport は無視されます"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "インライン関数 %q+D は dllimport として宣言されました: 属性が無視されました"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "関数 %q+D 定義は dllimport としてマークされています"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "変数 %q+D 定義は dllimport としてマークされています"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "シンボル %q+D 用に外部リンクが要求されます (%qE 属性のため)"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qE は暗黙的にデフォルトの可視性となりますが、%qD は既に異なる可視性として宣言されています"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "%qD はここで定義されています"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -20980,7 +20990,7 @@ msgstr "%qD はここで宣言されています"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "オフセットが定数文字列の境界の外にあります"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qD はここで宣言されています"
@@ -21005,718 +21015,718 @@ msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけ
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "無効な %<__builtin_prefetch%> の第三引数です。0 を使用します"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 msgid "source object declared here"
 msgstr "%qD はここで宣言されています"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, fuzzy, gcc-internal-format
 msgid "source object allocated here"
 msgstr "ここで宣言されています"
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 msgid "destination object declared here"
 msgstr "フィールドの型はここで宣言されました"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 msgid "destination object allocated here"
 msgstr "ここでは関数定義は許可されていません"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, fuzzy, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr "配列 %qE のサイズが負です"
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr "フィールドの型はここで宣言されました"
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr "フィールドの型はここで宣言されました"
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr "フィールドの型はここで宣言されました"
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "関数 %<va_start%> への引数が少なすぎます"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "無効な %qD の使用です"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "%<__builtin___clear_cache%> への両方の引数はポインタでなければいけません"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr ""
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD の意味合いは GCC 4.4 で変更になりました"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "組み込み関数への無効な引数です"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "無効な %<auto%> の使用です"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "無効な %<auto%> の使用です"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 1 to %qs"
 msgstr "%qs への引数がありません"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr "-f%s はサポートされていません: 無視されました"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K %<__builtin_va_arg_pack ()%> の無効な使用法です"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%K %<__builtin_va_arg_pack_len ()%> の無効な使用法です"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけません"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "ターゲット形式は無限大をサポートしません"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> が引数の数が固定の関数内で使用されました"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%> の第二引数が、最後の名前付き引数ではありません"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, fuzzy, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "%<va_start%> の第二引数が %<register%> 記憶域の場合の動作は不定です"
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "ここで宣言されています"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 msgid "returned from %qD"
 msgstr "ここから呼び出されました"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 msgid "returned from %qT"
 msgstr "ここから呼び出されました"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 msgid "obtained here"
 msgstr "共用体がここで定義されています"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 msgid "assigned here"
 msgstr "共用体がここで定義されています"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -22479,302 +22489,302 @@ msgstr "基本ブロックが連続的に番号付けられていません"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "命令連鎖中の bb の数 (%d) が n_basic_blocks (%d) と違います"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, fuzzy, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "左シフト回数が負の数です"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "オーバーロードされた関数 %s への不十分な引数です"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "制御投機を使用する"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "シンボルが有効であると見なす"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "戻り型が void の関数で、`return' に値があります"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "セクションポインタを欠いています"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, fuzzy, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "重複する `virtual' 指定子"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "左シフト回数が負の数です"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "`%s' は宣言よりも先に使用されました"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "文が予期されます"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, fuzzy, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node に失敗しました"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr ""
@@ -22855,12 +22865,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F が使用されましたが定義されていません"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
@@ -22930,7 +22940,7 @@ msgstr "%q+D の戻り値のサイズが %u バイトです"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "%q+D の戻り値のサイズが %wd バイトより大きいです"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "メモリを解放していないノードが見つかりました"
@@ -23334,12 +23344,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -23359,7 +23369,7 @@ msgstr "共有 rtx"
 msgid "internal consistency failure"
 msgstr "内部一貫性がありません"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn が emit_jump_insn が必要な場所で使用されました:\n"
@@ -23489,42 +23499,42 @@ msgstr "最終命令ダンプファイル %qs を閉じられません: %m"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "大きな固定小数定数が暗黙的に固定整数型に切り詰められました"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "ビットフィールド幅のため、比較が常に %d になります"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比較が常に %d となります"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23539,7 +23549,7 @@ msgstr "局所オブジェクトの総サイズが大きすぎます"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "局所オブジェクトの総サイズが大きすぎます"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> 内で制約を行うことは出来ません"
@@ -24155,7 +24165,7 @@ msgstr "NULL ポインタ"
 msgid "function may return address of local variable"
 msgstr "関数が局所変数のアドレスを返します"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "関数が局所変数のアドレスを返します"
@@ -24513,62 +24523,62 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "フォーマット文字列が null です"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 msgid "%Guse of %<alloca%>"
 msgstr "無効な %<auto%> の使用です"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 msgid "%Gargument to variable-length array may be too large"
 msgstr "可変長配列が使用されたときに警告する"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "%<-m%s%> へ渡された値が大きすぎます"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 msgid "%Gargument to variable-length array is too large"
 msgstr "可変長配列が使用されたときに警告する"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "%<-m%s%> へ渡された値が大きすぎます"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C90 は可変長の配列を禁止しています"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "無効な %<auto%> の使用です"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 #, fuzzy
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "無効な %<auto%> の使用です"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 msgid "%Gargument to variable-length array is zero"
 msgstr "可変長配列が使用されたときに警告する"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 msgid "%Gargument to %<alloca%> is zero"
 msgstr "`%s' の第二引数は `char **' とすべきです"
@@ -24672,7 +24682,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "%qD はここで宣言されています"
@@ -24698,11 +24708,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD はここで宣言されています"
@@ -24779,308 +24789,308 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr "%<void%> を返す関数の結果を使用しています"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "無効な型の使用法です"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 msgid "enclosing region"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE が宣言されていません (この関数内での最初の使用)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, fuzzy, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "結果の数が値の数と一致しません"
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification に失敗しました"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "このコードまで到達した場合、プログラムは中止されます"
@@ -25523,22 +25533,22 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr ""
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "フレームサイズが大きすぎて、スタック検査が信頼できなくなります"
@@ -25558,12 +25568,12 @@ msgstr "%<asm%> 被演算子が不可能な制約を持っています"
 msgid "unable to find a register to spill"
 msgstr "PIC レジスタ用に '%s' を使用できません"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "%<asm%> 内の被演算子制約に一貫性がありません"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
@@ -26271,12 +26281,12 @@ msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 msgid "unrecognized argument in option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
@@ -26401,7 +26411,7 @@ msgstr "%s はこのコンフィギュレーションではサポートされま
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上では動作しません"
@@ -26910,22 +26920,22 @@ msgstr ""
 msgid "output operand %d must use %<&%> constraint"
 msgstr "出力被演算子 %d は %<&%> 制約を使用しなければいけません"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr ""
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr ""
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr ""
@@ -26987,12 +26997,12 @@ msgstr "%<asm%> 内で整数定数被演算子を再ロードできません"
 msgid "impossible register constraint in %<asm%>"
 msgstr "%<asm%> 内でレジスタ制約は不可能です"
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "このターゲットでは %qs はサポートされていません"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "%<&%> 制約がレジスタクラス無しで使用されました"
@@ -27022,52 +27032,52 @@ msgstr "%<asm%> 被演算子制約が被演算子サイズと互換性があり
 msgid "output operand is constant in %<asm%>"
 msgstr "出力被演算子が %<asm%> 内の定数です"
 
-#: rtl.c:850
+#: rtl.c:860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "RTL 検査: elt %d(%s) が最後の elt %d(%s 中) と一緒にアクセスします (%s:%d)"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL 検査: elt %d 型は '%c' のはずなのに '%c' (rtx %s, %s 中)です (%s:%d)"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL 検査: elt %d 型は '%c' か '%c' のはずなのに '%c' (rtx %s, %s 中) です (%s:%d)"
 
-#: rtl.c:879
+#: rtl.c:889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL 検査: コード `%s' のはずなのに `%s' (%s 中)です (%s:%d)"
 
-#: rtl.c:889
+#: rtl.c:899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL 検査: コード `%s' か `%s' のはずなのに `%s' (%s 中)です (%s:%d)"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL 検査: コード `%s' か `%s' のはずなのに `%s' (%s 中)です (%s:%d)"
 
-#: rtl.c:927
+#: rtl.c:937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "RTL 検査: elt %d(%s) が最後の elt %d(%s 中) と一緒にアクセスします (%s:%d)"
 
-#: rtl.c:937
+#: rtl.c:947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
-#: rtl.c:958
+#: rtl.c:968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "RTL 検査: コード `%s' のはずなのに `%s' (%s 中)です (%s:%d)"
@@ -27112,22 +27122,22 @@ msgstr "一致制約が無効な被演算子番号を参照しています"
 msgid "invalid punctuation %qc in constraint"
 msgstr "無効な句読点 %qc が制約内にあります"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "一致制約はレジスタでは許可されていません"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "重複した asm 被演算子名 %qs です"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "名前付き非演算子用の閉じる中括弧がありません"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "未定義の名前付き非演算子 %qs です"
@@ -27805,9 +27815,9 @@ msgstr "%%R への無効な被演算子です"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "型が前方の外部宣言と一致しません"
@@ -27842,7 +27852,7 @@ msgstr "MEM_REF 内で無効なオフセット被演算子です"
 msgid "invalid clique in %qs"
 msgstr "無効な %qD の使用です"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr "INDIRECT_REF が gimple IL 内にあります"
@@ -28048,362 +28058,362 @@ msgstr ""
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "整数式が予期されます"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, fuzzy, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "無効な回転 (rotate) 命令です"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "BIT_FIELD_REF への無効な位置またはサイズ被演算子です"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "被演算子が非整数型のシフト演算です"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "無効なバージョン番号 %qs です"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "式内"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "%%R への無効な被演算子です"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, fuzzy, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "関数 %qE へ十分な引数がありません"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, fuzzy, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "PHI 引数が GIMPLE 値ではありません"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, fuzzy, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "return 文内で無効な被演算子です"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "return 文内で無効な変換です"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "goto の先がラベルでもポインタでもありません"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "switch 文への無効な被演算子です"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "switch 文への無効な被演算子です"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "switch 文の外にある %<default%> ラベルです"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "switch 文への無効な被演算子です"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, fuzzy, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "関数宣言中に（型の無い）仮引数名があります"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, fuzzy, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "label_to_block_map 内に間違ったエントリがあります"
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "gimple 条件内で無効な比較コードです"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "gimple 条件内で無効なラベルです"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "無効な PHI 結果です"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "PHI 定義がありません"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "無効な PHI 引数です"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "PHI 引数 %u 内で互換性のない型です"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple に失敗しました"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, fuzzy, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "EH 表内に不要な (dead) STMT があります"
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) が間違った基本ブロックに設定されています"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) が間違った基本ブロックに設定されています"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "文が throw とマークされていますが、 throw しません"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple に失敗しました"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "非局所ラベル "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "ラベル "
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "明示的な goto が基本ブロック %d の末尾にあります"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr ""
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr ""
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> 関数が戻り (return) ます"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "制御が非 void 関数の終りに到達しました"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "warn_unused_result 属性付きで宣言されている関数の戻り値を無視しています"
@@ -29484,7 +29494,7 @@ msgstr "スレッド局所 COMMON データは実装されていません"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "要求された %q+D 用の整列は実装されている整列 %wu より大きいです"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D の記憶域サイズが不明です"
@@ -29645,7 +29655,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 msgid "unsupported record layout"
 msgstr "サポートされていない組み合わせです: %s"
@@ -30249,7 +30259,7 @@ msgstr "%qE 属性は %qE 用としては無視されます"
 msgid "type was previously declared %qE"
 msgstr "前はここで宣言されました"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
@@ -30269,7 +30279,7 @@ msgstr "%qD は %qD 内では宣言されていません"
 msgid "%qE argument is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "廃止された (deprecated) メッセージが文字列ではありません"
@@ -30694,12 +30704,12 @@ msgstr "列挙型定数がここで定義されています"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "真偽値として使われる代入のまわりでは、丸括弧の使用をお勧めします"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "%<restrict%> の誤った使用法です"
@@ -30860,13 +30870,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "関数 %qE へ渡す引数が少なすぎます"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "関数 %qE への引数が多すぎます"
@@ -31802,7 +31812,7 @@ msgstr "サポートされていない非標準の文字列リテラルの連結
 msgid "traditional C rejects string constant concatenation"
 msgstr "伝統的な C では文字列定数の連結を拒否します"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -31852,7 +31862,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -31867,17 +31877,17 @@ msgstr "%qs が自動変数 %qE 用に指定されています"
 msgid "%qE is not initialized"
 msgstr "%qE は初期化されていません"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "増分式がありません"
@@ -31887,7 +31897,7 @@ msgstr "増分式がありません"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無効な増分式です"
@@ -31952,7 +31962,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -32517,8 +32527,8 @@ msgstr "<戻り値>"
 msgid "wrong type argument to %s"
 msgstr "%s への間違った型の引数です"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "定数式内でオーバーフローしました"
@@ -33003,17 +33013,17 @@ msgstr "関数 %qD の減分です"
 msgid "function %qD used as %<asm%> output"
 msgstr "関数 %qD が %<asm%> の出力として使用されています"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "読み取り専用位置 %qE への代入です"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "読み取り専用位置 %qE の増分です"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "読み取り専用位置 %qE の減分です"
@@ -33193,8 +33203,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
@@ -33269,153 +33279,153 @@ msgid "passing argument %i to %qs-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to %qs-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "共用体がここで定義されています"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "引数 %d 個の `%s' を渡します"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr "前はここで宣言されました"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
 msgstr "前はここで宣言されました"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
 msgstr "前はここで宣言されました"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr "前はここで宣言されました"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "前はここで宣言されました"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, fuzzy, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr "前はここで宣言されました"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "前方での `%s' の宣言"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr "前方での `%s' の宣言"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -33430,7 +33440,7 @@ msgstr "%qs は前処理の有効なオプションではありません"
 msgid "too many input files"
 msgstr "入力ファイルが多すぎます"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "-mfpu 用の不明な値 %s です"
@@ -33461,14 +33471,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
@@ -33618,62 +33628,62 @@ msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%> は選択した ABI とは互換性がありません"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%> は選択した ABI とは互換性がありません"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "レジスタ '%c' が不明です"
@@ -33834,89 +33844,89 @@ msgstr "-mcpu=%s が -march=%s と競合しています"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "LTO 出力用一時ファイル %s を開くのに失敗しました"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "%qE 2.95 vtable-compatibility 属性は kext をコンパイルするときのみ適用されます"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "%qE 2.95 vtable-compatibility 属性は C++ クラスへのみ適用されます"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "可視性属性はこの設定ではサポートされていません。無視されました"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "LTO 出力の一時ファイル %s を開くのに失敗しました"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, fuzzy, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "-mdynamic-no-pic は -fpic または -fPIC を上書きします"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "CFString リテラルがありません"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "CFString リテラル式が文字列定数ではありません"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, fuzzy, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr "CFString リテラル内に %s があります"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr "CFString リテラル内に %s があります"
 
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr ""
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34052,362 +34062,362 @@ msgstr "%<#pragma GCC optimize%> が文字列または番号ではありませ
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "不明な #pragma GCC coprocessor %E です"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "関数型に対して new を適用できません"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "%<operator%> が予期されます"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "無効な #pragma %s です"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "無効な %%h 値"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "不明な spec 関数 %qs です"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s スイッチが -march=%s スイッチと競合しています"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "multilib はサポートしません"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, fuzzy, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "間違った形式の %<#pragma init%> です"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "-shared オプションは VAX ELF 用には現在はサポートされていません"
@@ -34468,7 +34478,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "-mmemory-latency 用の間違った値 %qs です"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -34588,18 +34598,18 @@ msgstr "%qE 属性の引数が \"ilink1\" または \"ilink2\" ではありま
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE 属性の引数が \"ilink1\" または \"ilink2\" ではありません"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -35030,224 +35040,229 @@ msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 msgid "target CPU does not support unaligned accesses"
 msgstr "ターゲット CPU は ARM モードをサポートしていません"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "-mcpu=%s スイッチが -march=%s スイッチと競合しています"
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check と -mno-apcs-frame は併用できません"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic と -mapcs-reent は併用できません"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS 再入可能コードはサポートされていません。無視されました"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "構造体サイズ境界は %s にのみ設定できます"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "構造体サイズ境界は %s にのみ設定できます"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC は -msingle-pic-base と併用できません"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= は -fpic をつけないと役に立ちません"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "PIC レジスタ用に '%s' を使用できません"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上ではサポートされていません"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable と -msdata=%s は併用できません"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt は適切な操作用に AAPCS 互換 ABI を必要とします"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt ABI は iwmmxt 機能がある CPU を必要とします"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "ターゲット CPU は ARM/Thumb 相互利用をサポートしていません"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS は -mcaller-super-interworking をサポートしません"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS は -mcallee-super-interworking をサポートしません"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 かつ ldrh 無し"
 
 # 公式な名前は Thumb であり THUMB ではない
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, fuzzy, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr "-mfloat-abi=hard および VFP"
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, fuzzy, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard および VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 ハードウェア浮動小数 VFP ABI"
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qE 属性は名前付き引数があるプロトタイプが必要です"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE 属性はユニット局所関数に関しては効果がありません"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "スタックに積まれた仮引数の実際の位置を計算できません"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高位レジスタを pop する為に使用できる低位レジスタがありません"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "%qs 属性用の無効なベクトル型です"
@@ -35255,22 +35270,22 @@ msgstr "%qs 属性用の無効なベクトル型です"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "%qs 属性用の無効なベクトル型です"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "target 属性または pragma が SPE ABI を変更します"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
@@ -35349,17 +35364,17 @@ msgstr "-fpic はサポートされていません"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIC はサポートされていません"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-pedantic と -traditional とは相互排他的です"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "割り込み関数は引数無しでなければいけません"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "関数が __fp16 型を返しません"
@@ -36099,132 +36114,132 @@ msgstr "%qs への引数は 2 ビット符号無しリテラルでなければ
 msgid "parameter to builtin not valid: %s"
 msgstr "仮引数 %qD が設定されましたが使用されません"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "最後の引数の前の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "正しくない命令:"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "%s は [%d, %d] の範囲内の整数リテラルが予期されます"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE は isa オプション %s が必要です"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後の引数は即値でなければいけません"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "最後の引数の前の引数は 8 ビット即値でなければいけません"
@@ -36244,514 +36259,514 @@ msgstr "静的リンクはサポートされていません"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "コードモデル %s は PIC モードをサポートしません"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "弱い参照属性は別名属性より前に出現しなければいけません"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "レジスタ名が %q+D 用に指定されていません"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs にクラス名が指定されていません"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "不明なレジスタ名です: %s"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-mg でのプロファイルはサポートされていません"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s はこの設定ではサポートされていません"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i ビットモードが使用できるようにコンパイルされていません"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "選択した CPU は x86-64 命令セットをサポートしていません"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%spreferred-stack-boundary%s はこのターゲットではサポートされていません"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d が %d と 12 の間ではありません"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "ret 命令は実装されていません"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, fuzzy, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 命令セットが無効になっています。 387 数値演算を使用します"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 命令セットが無効になっています。SSE 数値演算を使用します"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall と regparm 属性は併用できません"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 属性には整数定数引数が必要です"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall と stdcall 属性は併用できません"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall と fastcall 属性は併用できません"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 属性が非クラスメソッド用に使用されています"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi と sysv_abi 属性は互換性がありません"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
@@ -37205,7 +37220,7 @@ msgstr "%qE は %<mips16%> と %<nomips16%> 属性の両方を持つことは出
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE が競合する %qs 属性付きで再宣言されました"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
@@ -38258,57 +38273,57 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, fuzzy, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "割り込み関数は引数無しでなければいけません"
@@ -38811,239 +38826,240 @@ msgstr "レジスタ r2 と r5 を使用する"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma GCC target はこのマシン用にはサポートされていません"
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, fuzzy, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-maix64 は PowerPC64 アーキテクチャが有効のまま残されていることが必要です"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mas100-syntax と -gdwarf は併用できません"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 は PowerPC64 CPU が必要です"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "-mcmodel は他の toc オプションと互換性がありません"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "FPA は AAPCS 内ではサポートされていません"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power は 64 ビット Darwin ではサポートされていません。インストールされている C および C++ ライブラリと互換性がありません"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring はリトルエンディアンシステム上ではサポートされていません"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-mcmodel は他の toc オプションと互換性がありません"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "target 属性または pragma が long double のサイズを変更します"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, fuzzy, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%s は %s をサポートしません"
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, fuzzy, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "IEEE 拡張精度 long double を使用しています"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, fuzzy, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr "IBM 拡張精度 long double を使用しています"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%s は %s をサポートしません"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "target 属性または pragma が AltiVec ABI を変更します"
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "target 属性または pragma が darwin64 ABI を変更します"
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs を呼び出しで使用されるレジスタとして使用できません"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<long double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec 型内での真偽型 (boolean) の使用は無効です"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<complex%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "AltiVec 型内での十進浮動小数点の使用は無効です"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec 型内での %<long%> の使用は廃止されました。%<int%> を使用してください"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s は無効です"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -39222,7 +39238,7 @@ msgstr "RX FPU 命令は NaNs と無限大をサポートしません"
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -39292,200 +39308,205 @@ msgstr "%qE は廃止されました"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "%qs 用の定数引数が範囲外です"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "間違った組み込みコードです"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局所変数の合計サイズがアーキテクチャの制限を超過しています"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs のフレームサイズ: "
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs は動的スタック割り当てを使用します"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, fuzzy, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "ハードウェア十進浮動小数点命令は ESA/390 モードでは使用出来ません"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, fuzzy, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp は -msoft-float と併用できません"
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float の組み合わせはサポートされていません"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "スタックサイズは 64k より大きくてはいけません"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, fuzzy, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard は -mstack-size を暗黙的に使用します"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE 属性は SH2A 用にのみサポートされています"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%qs への引数は非負整数であるべきです"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
@@ -39827,17 +39848,23 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "insn contains an invalid address !"
+msgid "%s contains too many lines"
+msgstr "命令に無効なアドレスが含まれています!"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
@@ -39903,8 +39930,8 @@ msgstr "%qs 属性は配列型のみに適用できます"
 msgid "could not read the BRIG file"
 msgstr "応答ファイル %s を書き込めませんでした"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void の値が本来の意味通りに無視されませんでした"
@@ -39964,7 +39991,7 @@ msgstr "変数 %qD が設定されましたが使用されていません"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "元々はここで定義されました"
@@ -40186,7 +40213,7 @@ msgstr "%q+D の宣言は前の非変数を隠します"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
@@ -40196,7 +40223,7 @@ msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 msgid "declaration of %qD shadows a previous local"
 msgstr "`%s' の宣言は前方のローカルシンボルを覆い隠します"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "隠された宣言はここです"
@@ -40206,212 +40233,212 @@ msgstr "隠された宣言はここです"
 msgid "nested extern declaration of %qD"
 msgstr "入れ子になった外部宣言 %qD です"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "関数 %qE の暗黙的な宣言です"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "関数 %qE の暗黙的な宣言です"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr "無効な宣言です"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "組み込み関数 %qD の互換性がない暗黙的な宣言です"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "無効な宣言です"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "関数 %qD の互換性がない暗黙的な宣言です"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE が宣言されていません (この関数内での最初の使用)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE が宣言されていません (この関数内での最初の使用)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "未宣言の識別子は出現した各関数内で一回のみ報告されます"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ラベル %qE があらゆる関数の外側から参照されました"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "重複したラベルの宣言 %qE です"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複したラベル %qD です"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "伝統的な C ではラベルを名前空間で分離できません。識別子 %qE が競合します"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch がここから開始します"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr ""
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE が誤った種類のタグとして宣言されました"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "無名構造体/共用体が、そのインスタンスを定義していません"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "宣言 %qD が何も宣言していません"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "空の宣言内に無意味な型名があります"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "ファイルスコープの空の宣言内に %<auto%> があります"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "ファイルスコープの空の宣言内に %<register%> があります"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "空の宣言内に無意味な記憶域クラス指定があります"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "空の宣言内に無意味な型名があります"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "空の宣言内に無意味な型修飾子があります"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "空の宣言内に無意味な %<__thread%> があります"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "空の宣言です"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 は仮引数配列宣言内での %<static%> または型修飾子をサポートしません"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
@@ -40419,28 +40446,28 @@ msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> は関数プロトタイプスコープ以外では許可されていません"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D は通常は関数です"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD が初期化されました (代わりに __typeof__ を使用してください)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "関数 %qD が変数のように初期化されました"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "仮引数 %qD が初期化されます"
@@ -40449,267 +40476,267 @@ msgstr "仮引数 %qD が初期化されます"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "変数 %qD には初期化子がありますが不完全型です"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr "noinline 属性が与えられたインライン関数 %q+D です"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "%qT 内の初期化されない定数メンバは C++ では無効です"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD は初期化されるべきです"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "初期化子が %q+D のサイズ特定に失敗しました"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "%q+D 内に配列のサイズがありません"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "0 または負のサイズの配列 %q+D です"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "%q+D の記憶域サイズが一定ではありません"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "非静的変数 %q+D 用のアセンブラ指定を無視しています"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "volatile フィールドがあるオブジェクトをレジスタに配置できません"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C は前方仮引数宣言を禁じます"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "複合リテラル内での型定義は C++ では無効です"
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "ビットフィールド %qs の幅が整数定数ではありません"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "ビットフィールド %qs の幅が整数定数式ではありません"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "ビットフィールド %qs の幅が負です"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "ビットフィールド %qs の幅が 0 です"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "ビットフィールド %qD を関数型として宣言できません"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "ビットフィールド %qs の型は GCC 拡張です"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs の幅がそのサイズを超えています"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs の幅はその型の値より狭いです"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 はサイズを評価できない配列 %qE を禁止しています"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 はサイズが評価できない配列を禁止しています"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 は可変長の配列を禁止しています"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "ファイルスコープの可変 %qE です"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "型がデフォルトの %<int%> に %qE の宣言内でなります"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "型がデフォルトの %<int%> に型名内でなります"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "重複した %<const%> です"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "重複した %<restrict%> です"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "重複した %<volatile%> です"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "重複した %<restrict%> です"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "名前付きアドレス空間 (%s と %s) が競合しています"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "関数定義が %<auto%> と宣言されています"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "関数定義が %<register%> と宣言されています"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "関数定義が %<typedef%> と宣言されています"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "関数定義が %<auto%> と宣言されています"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "構造体フィールド %qE 用に記憶域クラスが指定されています"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "構造体フィールド用に記憶域クラスが指定されています"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "仮引数 %qE 用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "無名仮引数用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "型名用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE が初期化され、 %<extern%> として宣言されています"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE が %<extern%> と初期化子の両方を持っています"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "%qE のファイルスコープ宣言は %<auto%> を指定します"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "%qE のファイルスコープ宣言は %<register%> を指定します"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "入れ子になった関数 %qE が %<extern%> と宣言されています"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "関数スコープの %qE は暗黙的に auto となり %<__thread%> と宣言されます"
@@ -40717,711 +40744,711 @@ msgstr "関数スコープの %qE は暗黙的に auto となり %<__thread%> 
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "仮引数で無い配列宣言内の静的または型修飾子です"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "void の配列としての %qE の宣言です"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "void の配列としての型名の宣言です"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "関数の配列としての %qE の宣言です"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "関数の配列としての型名の宣言です"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "配列 %qE のサイズが非整数型です"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "無名配列のサイズが非整数型です"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "配列 %qE のサイズが非整数型です"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "無名配列のサイズが非整数型です"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C はサイズが 0 の配列 %qE を禁止しています"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C はサイズが 0 の配列を禁止しています"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "配列 %qE のサイズが負です"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "無名配列のサイズが負です"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "無名配列のサイズが大きすぎます"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr ""
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "配列の型が不完全要素型を持っています"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE は関数を返す関数と宣言されています"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "型名は関数を返す関数として宣言されています"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE は配列を返す関数として宣言されています"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "型名は配列を返す関数として定義されています"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "関数定義が void 戻り型の修飾子を持っています"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs が %<auto%> 修飾子と %qE 用に組み合わされています"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs が %<register%> 修飾子と %qE 用に組み合わされています"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs が自動変数 %qE 用に指定されています"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs が無名仮引数用に指定されました"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs が構造体フィールド %qE 用に指定されています"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs が構造体フィールド用に指定されています"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "%qs が無名仮引数用に指定されました"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "%qs が無名仮引数用に指定されました"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "関数 %qD への代入です"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C は const や volatile の関数型を禁止しています"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "構造体または共用体のメンバは可変型を持つことは出来ません"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "変数またはフィールド %qE が void と宣言されています"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "仮引数配列宣言内の属性が無視されました"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "フィールド %qE が関数として宣言されています"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "フィールド %qE が不完全型を持っています"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "無名フィールドが不完全型を持っています"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "関数 %qE 用の無効な記憶域クラスです"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "関数 %<main%> をインラインに出来ません"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qE が初期化され、 %<extern%> として宣言されています"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 は %<_Static_assert%> をサポートしません"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "前に %<static%> と宣言された変数が %<extern%> と再宣言されています"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "可変型の入れ子になっていない関数です"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "可変型のオブジェクトはリンクされてはいけません"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "関数宣言がプロトタイプではありません"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "関数宣言中に（型の無い）仮引数名があります"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "仮引数 %u (%q+D) が不完全型を持っています"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "仮引数 %u が不完全型を持っています"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "仮引数 %u (%q+D) が void 型を持っています"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> は唯一の仮引数でなければいけません"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "仮引数 %q+D は直前に定義されています"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "列挙型がここで定義されています"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "構造体がここで定義されています"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "共用体がここで定義されています"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> の再定義です"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> の再定義です"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "%<union %E%> の入れ子になった再定義です"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "%<struct %E%> の入れ子になった再定義です"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "%qs 式内での型定義は C++ では無効です"
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "宣言が何も宣言していません"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 は無名構造体/共用体をサポートしません"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 は無名構造体/共用体をサポートしません"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "重複したメンバ %q+D です"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "共用体に名前付きメンバがありません"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "共用体にメンバがありません"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "構造体に名前付きメンバがありません"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "構造体にメンバがありません"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "共用体に可変配列メンバがあります"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "共用体に可変配列メンバがあります"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "共用体を透過的にできません"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "%<enum %E%> の入れ子になった再定義です"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> の再定義です"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "指定したモードは列挙値用には小さすぎます"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "列挙値が整数の範囲の最大値を超えました"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "列挙値がオーバーフローしました"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "戻り値の型が不完全型です"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "戻り値の型をデフォルトの %<int%> にします"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "プロトタイプ無しの大域関数に関して警告する"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "前に %qD 用のプロトタイプがありません"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD がプロトタイプ無しで、定義される前に使用されました"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "前に %qD 用の定義がありません"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD はその定義の前で宣言しないで使用されました"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD の戻り型が %<int%> ではありません"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD は通常は非静的関数です。"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "プロトタイプ関数宣言内で古いスタイルの仮引数宣言です"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "伝統的な C では ISO C スタイルの関数定義は拒否されます"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "ISO C は十進浮動小数点をサポートしません"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "古いスタイルの関数定義です"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "仮引数リストに仮引数名がありません"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "複数の仮引数が %qD という名前です"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD の型をデフォルトの %<int%> にします"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "仮引数 %qD が不完全型を持っています"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "仮引数 %qD 用の宣言がありますが、そのような仮引数はありません"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "引数の数が組み込みプロトタイプと一致しません"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "引数の数がプロトタイプと一致しません"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "プロトタイプ宣言です"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "引数 %qD が組み込みプロトタイプと一致しません"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引数 %qD がプロトタイプと一致しません"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "仮引数 %qD が設定されましたが使用されません"
@@ -41429,257 +41456,257 @@ msgstr "仮引数 %qD が設定されましたが使用されません"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> ループ初期化宣言は C99 モード内でのみ許可されています"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "オプション -std=c99 または -std=gnu99 をコードコンパイル時に使用してください"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "静的変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "非変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "互換性のないアドレス空間修飾子 %qs と %qs です"
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "宣言指定が予期されます"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣言指定内に二個またはそれ以上の型があります"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> は GCC にとって長すぎます"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE が重複しています"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C は十進浮動小数点をサポートしません"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "固定小数点型はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C は固定小数点型をサポートしません"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE は宣言の開始ではありません"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> が %<auto%> と併せて使用されています"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> が %<register%> と併せて使用されています"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "%s は %s をサポートしません"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> が %<extern%> の前にあります"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> が %<static%> の前にあります"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣言指定内に複数の記憶域クラスがあります"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> が %<_Fract%> または %<_Accum%> 無しで使用されています"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C は複素整数型をサポートしません"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, fuzzy, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右シフト回数が負です"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "右シフト回数 >= 型の幅となっています"
@@ -41699,7 +41726,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "行末 (EOL) が予期されます"
@@ -41709,7 +41736,7 @@ msgstr "行末 (EOL) が予期されます"
 msgid "ISO C forbids an empty translation unit"
 msgstr ""
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
@@ -41745,7 +41772,7 @@ msgid "unknown type name %qE"
 msgstr "不明な型名 %qE です"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "宣言指定が予期されます"
@@ -41765,7 +41792,7 @@ msgstr "getter/setter 属性は後に %<=%> が無ければいけません"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>、識別子または %<(%> が予期されます"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -41780,7 +41807,7 @@ msgstr ""
 msgid "unexpected attribute"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "getter/setter 属性は後に %<=%> が無ければいけません"
@@ -41818,7 +41845,7 @@ msgstr "ファイルスコープの空の宣言内に %<auto%> があります"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> または %<;%> が予期されます"
@@ -41876,7 +41903,7 @@ msgstr "静的アサーション内の式が定数ではありません"
 msgid "static assertion failed: %E"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "静的アサーションに失敗しました: %E"
@@ -41921,14 +41948,14 @@ msgstr "マクロ引数 \"%s\" は文字列化されます"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "識別子が予期されます"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列挙型リストの最後にコンマがあります"
@@ -42013,7 +42040,7 @@ msgstr "宣言指定または %<...%> が予期されます"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "%qE 属性は型に適用できません"
@@ -42073,7 +42100,7 @@ msgstr "ISO C90 は宣言とコードの混合を禁止しています"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> が %<else%> の前に予期されます"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> の前に %<if%> がありません"
@@ -42088,7 +42115,7 @@ msgstr "複合文の最後にラベルがあります"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "文が予期されます"
@@ -42113,17 +42140,17 @@ msgstr "識別子または %<*%> が予期されます"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr ""
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%<if%> 文内の空の本体は中括弧で括ることを推奨します"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%<else%> 文内の空の本体は中括弧で括ることを推奨します"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "%<else%> が曖昧になることを避けるために明示的に中括弧で括ることを推奨します"
@@ -42143,12 +42170,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -42163,8 +42190,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "重複した %<volatile%> です"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, fuzzy, gcc-internal-format
 msgid "first seen here"
 msgstr "構造体がここで定義されています"
@@ -42191,12 +42218,12 @@ msgstr "ISO C は中間項が省略された ?: 式を禁じます"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "フィールドの型はここで宣言されました"
@@ -42587,12 +42614,12 @@ msgstr "objective-c メソッド定義が予期されます"
 msgid "no type or storage class may be specified here,"
 msgstr "型または記憶域クラスがここで指定されていません、"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, fuzzy, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "不明な property 属性です"
@@ -42602,51 +42629,51 @@ msgstr "不明な property 属性です"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "Objective-C 文字列の前に連続した %<@%> があります"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "クラス名が予期されます"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, fuzzy, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "setter 名は %<:%> で終端されなければいけません"
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -42656,18 +42683,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%qs 句が多すぎます"
@@ -42687,53 +42714,53 @@ msgstr "%<,%> または %<)%> が予期されます"
 msgid "%qD is not a variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<catch%> が予期されます"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -42755,107 +42782,107 @@ msgstr "%<num_threads%> 値は正でなければいけません"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "整数式が予期されます"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "引数が多すぎます"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<runtime%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<auto%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "`無効なスケジュールの種類です"
@@ -42865,17 +42892,17 @@ msgstr "`無効なスケジュールの種類です"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -42895,22 +42922,22 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "無効なマスクです"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "`無効なスケジュールの種類です"
@@ -42925,82 +42952,82 @@ msgstr "`無効なスケジュールの種類です"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -43015,7 +43042,7 @@ msgstr ""
 msgid "expected function name"
 msgstr "関数が予期されます"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "メンバ関数の名前を欠いています"
@@ -43025,27 +43052,27 @@ msgstr "メンバ関数の名前を欠いています"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 msgid "expected %<allocator%>"
 msgstr "%<operator%> が予期されます"
@@ -43055,82 +43082,82 @@ msgstr "%<operator%> が予期されます"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "--driver は最早サポートされません"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -43140,32 +43167,32 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -43175,72 +43202,72 @@ msgstr ""
 msgid "not enough perfectly nested loops"
 msgstr "ループが完全な入れ子になっていません"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<operator%> が予期されます"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -43255,57 +43282,57 @@ msgstr "%<#pragma align%> は %D の前に現れなければいけません。
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "クラス名が予期されます"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "文字列リテラルが予期されます"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<catch%> が予期されます"
@@ -43315,12 +43342,12 @@ msgstr "%<catch%> が予期されます"
 msgid "variant %qD is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s と -msdata=%s は併用できません"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43330,32 +43357,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<try%> が予期されます"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<decltype%> が予期されます"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
@@ -43410,42 +43437,42 @@ msgstr "関数が予期されます"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -43460,27 +43487,27 @@ msgstr "可変長配列が使用されています"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE は不完全型を持っています"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -43490,7 +43517,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -43505,7 +43532,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD は不完全型を持っています"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void 式の無効な使用法です"
@@ -43546,127 +43573,127 @@ msgstr "%qE 属性は名前付き引数があるプロトタイプが必要で
 msgid "function types not truly compatible in ISO C"
 msgstr "関数型が ISO C と完全互換ではありません"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, fuzzy, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "十進浮動小数型とベクトル型の被演算子を混ぜることは出来ません"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, fuzzy, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "十進浮動小数型と複素数型の被演算子を混ぜることは出来ません"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, fuzzy, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "十進浮動小数型と他の浮動小数型の被演算子を混ぜることは出来ません"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, fuzzy, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "ポインタターゲット型は C++ では互換性がありません"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "型は全く互換がありません"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "ポインタターゲット型は C++ では互換性がありません"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, fuzzy, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "複合リテラル内での型定義は C++ では無効です"
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr ""
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "構造体または共用体ではない何かのメンバ %qE の要求です"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "添字が付けられた値が、配列、ポインタまたはベクトルではありません"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "配列の添字が整数型ではありません"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "添字が付けられた値が関数へのポインタではありません"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C は %<register%> 配列に添字を付けることを禁止しています"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C90 は左が値でない配列に添字を付けることを禁止しています"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr "列挙型定数がここで定義されています"
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
@@ -43674,1594 +43701,1594 @@ msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "関数が互換性のない型を通して呼び出されています"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "修飾子付き void 戻り型の関数が呼び出されています"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "正式な %d 番目の仮引数の型が不完全です"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は浮動小数型ではなく整数型としてです"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は複素数型ではなく整数型としてです"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は浮動小数点型ではなく複素数型としてです"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は整数型ではなく浮動小数型としてです"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は整数型ではなく複素数型としてです"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は複素数型ではなく浮動小数型としてです"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は %<float%> (%<double%> ではなく) としてです"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は %qT (%qT ではなく) としてです"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は異なる幅です"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は符号無しとしてです"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "プロトタイプによると渡している %d 番目の %qE の引数は符号付きとしてです"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "メソッド %qE への引数が多すぎます"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "関数 %qE への引数が多すぎます"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "関数 %qE へ渡す引数が少なすぎます"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "文字列リテラルの比較結果は不定です"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "ポインタと整数との比較を行なっています"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "%qT と %qT の比較です"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, fuzzy, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "`void *' 型のポインタの差を求めようとしています"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "関数ポインタの差を求めようとしています"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "不完全型へのポインタに関する計算です"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "不完全型へのポインタに関する計算です"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "真偽式が予期されます"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C は複素共役用の `~' を受け付けません"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to absu"
 msgstr "abs への引数の型が間違っています"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "単項感嘆符(!)への引数の型が間違っています"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "列挙値の増分は C++ では無効です"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "列挙値の減分は C++ では無効です"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "真偽式が予期されます"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "真偽式が予期されます"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C は複素数型に関する %<++%> と %<--%> をサポートしません"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "増分する引数の型が間違っています"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "減分する引数の型が間違っています"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "不完全型へのポインタに対する演算"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "%<void%> 型の式のアドレスを取得しています"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "ビットフィールド %qD のアドレスを取得できません"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "レジスタ変数 %qD のアドレスが要求されました"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "帯域レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "大域レジスタ変数 %qD のアドレスが要求されました"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "レジスタ変数 %qD のアドレスが要求されました"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C は片側だけが void となる条件式を禁止しています"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "条件式内でポインタ型が一致しません"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C は %<void *%> と関数ポインタ間の比較式を禁止しています"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "条件式内でポインタ型が一致しません"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "条件式内でポインタ型が一致しません"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "条件式内でポインタ型と整数型が適合しません"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "条件式での型の組合わせが適合しません"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, fuzzy, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "キャストが配列型を指定しています"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "キャストは関数型を指定しています"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C は非スカラーから同じ型へのキャストを禁止しています"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C は共用体型へのキャストを禁止しています"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "共用体の中にない型から共用体型へキャストしています"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "ポインタから異なるサイズの整数へのキャストです"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "型 %qT の関数呼び出しから一致しない型 %qT へのキャストです"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "異なるサイズの整数からポインタへのキャストです"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C は関数ポインタからオブジェクトポインタ型への変換を禁止しています"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C はオブジェクトのポインタから関数のポインタ型への変換を禁止しています"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "不完全型 %qT から %qT へ変換できません"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "キャスト内での型定義は C++ 内では無効です"
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, fuzzy, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "代入の抑制"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "代入内での列挙型の変換は C++ 内では無効です"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(%qs 用の初期化付近)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "小括弧で括られた文字列定数で配列が初期化されています"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr "%qD はここで宣言されています"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "%d 番目の %qE の引数を渡すときの列挙型の変換は C++ 内では無効です"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "代入内での列挙型の変換は C++ 内では無効です"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "初期化内での列挙型の変換は C++ では無効です"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "return 内での列挙型の変換は C++ では無効です"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT"
 msgstr "%q#T から %q#T への変換です"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C では引数から共用体への変換を禁止しています"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "%d 番目の %qE の引数は format 属性の候補のようです"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "左辺への代入は format 属性の候補のようです"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "左辺の初期化は format 属性の候補のようです"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "戻り型は format 属性の候補のようです"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "互換性のないポインタ型から %d 番目の %qE の引数に渡しています"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "互換性のないポインタ型からの代入です"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "互換性のないポインタ型からの初期化です"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "互換性のないポインタ型からの戻りです"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C は関数のポインタと %<void *%> 間の代入を禁止しています"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C は関数ポインタと %<void *%> 間の初期化を禁止しています"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C は関数ポインタと %<void *%> の間の戻りを禁止しています"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "%d 番目の %qE の引数を渡すときのポインタの先の符号が異なります"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "代入でのポインタの先の符号が異なります"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "初期化でのポインタの先の符号が異なります"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "%d 番目の %qE の引数を渡すときのポインタの先の符号が異なります"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "互換性のないポインタ型から %d 番目の %qE の引数に渡しています"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "互換性のないポインタ型からの代入です"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "互換性のないポインタ型からの代入です"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "互換性のないポインタ型からの初期化です"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "互換性のないポインタ型からの初期化です"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "互換性のないポインタ型からの戻りです"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "互換性のないポインタ型からの戻りです"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%d 番目の %qE の引数へ渡すときに整数からキャスト無しにポインタを作成しています"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "代入で整数からキャスト無しにポインタを作成しています"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "初期化で整数からキャスト無しにポインタを作成しています"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%d 番目の %qE の引数へ渡すときに整数からキャスト無しにポインタを作成しています"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "代入でポインタからキャスト無しに整数を作成しています"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "初期化でポインタからキャスト無しに整数を作成しています"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "型 %qT への型 %qT からの代入時に互換性のない型です"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "型 %qT を型 %qT を使用して初期化時に互換性のない型です"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "型 %qT を戻すときに互換性のない型です。型 %qT が予期されます"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "伝統的な C では自動集約初期化を拒否します"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "可変配列メンバを初期化しています"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "互換性のないポインタ型からの初期化です"
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "適切でない型の配列が文字列定数で初期化されています"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "非左辺値配列の無効な使用です"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "配列が非定数配列式で初期化されています"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "初期化子の要素がロード時に計算出来ません"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "無効な初期化子です"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "初期化子の終わりに余分なブレースのグループ"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "スカラー初期化子が中括弧で囲まれています"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "入れ子になったコンテキスト内で可変配列メンバを初期化しています"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "初期化子の周りに中括弧がありません"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "初期化子を欠いています"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "空のスカラー初期化子です"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "スカラー初期化子内に余分な要素があります"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "レコードや共用体初期化子にフィールド名がありません"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr ""
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "初期化子内の配列インデックスが配列の境界を超えました"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "初期化子内に空の範囲インデックスがあります"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "初期化子の範囲インデックスが配列の境界を超えました"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "初期化されたフィールドが副作用で上書きされます"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "初期化されたフィールドが上書きされます"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "初期化内での列挙型の変換は C++ では無効です"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 msgid "excess elements in %<char%> array initializer"
 msgstr "char 配列初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "構造体初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "共用体初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "伝統的な C では共用体の初期化を拒否します"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "配列初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "ベクトル初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "スカラー初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C は %<goto *expr;%> を禁止しています"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> と宣言されている関数が %<return%> 文を持っています"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "非 void を戻す関数内に値が無い %<return%> があります"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "void を戻す関数内に値が有る %<return%> があります"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C は void を戻す関数内で、式をがある %<return%> を禁止しています"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 msgid "function returns address of label"
 msgstr "関数が局所変数のアドレスを返します"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch の内容が整数ではありません"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "ISO C では %<long%> による switch 文は %<int%> による switch に変換されます"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case ラベルは整数定数式に出来ません"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "switch 文の外にある %<default%> ラベルです"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "ループまたは switch 文の外にある break 文です"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP のループ用に break 文が使用されています"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "ループの外にある continue 文です"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "効果がない文です"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "結果の数が異なります"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "浮動小数点の比較で == や != を使うのは安全ではありません"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C は %<void *%> と関数ポインタの比較を禁止しています"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "ポインタと整数との比較を行なっています"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "完全なポインタと不完全なポインタとの比較です"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C 関数ポインタの順序比較を禁じます"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "NULL ポインタがあるポインタの順序比較です"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "スカラーが必要な場所にポインタに変換できない配列が使用されています"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "スカラーが必要な場所で共用体型の値が使用されています"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, fuzzy, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "メンバ関数の名前を欠いています"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "参照を参照として宣言できません"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "代入として無効な左辺値です"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, fuzzy, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "仮引数 %qD が不完全型を持っています"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "非整数型のビットフィールド %qD です"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "ポインタが予期されます"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr "可変長配列 %qE が使用されています"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE は %<reduction(%s)%> 用の無効な型を持っています"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, fuzzy, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE は %<threadprivate%> (%<copyin%> 用として) でなければいけません"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE は %<firstprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE は %<lastprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, fuzzy, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "ソースはポインタではありません"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%> の第一引数が %<va_list%> 型ではありません"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -45469,7 +45496,7 @@ msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -45580,670 +45607,675 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "オーバーロードされている %<%D(%A)%> の呼び出しが曖昧です"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "%<(%T) (%A)%> への呼び出しが適合しません"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> の呼び出しが曖昧です"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "%qs 用の %<%s %E%> 内にあるオーバーロードが曖昧です"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E ? %E : %E%> 内にある三項演算子 %<operator?:%> が適合しません "
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> で %<%E%s%> 内にあるものが適合しません"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E[%E]%> 内の %<operator[]%> が適合しません"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator%s%> で %<%s%E%> 内にあるものが適合しません"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> で %<%E %s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> で %<%s%E%> 内にあるものが適合しません"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ は中間項が省略された ?: 式を禁止しています"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "%d 番目の引数が `%s' の型と互換性がありません"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "条件式での型の組合わせが適合しません"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "条件式内でポインタ型と整数型が適合しません"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "%qD の戻り型が %<int%> ではありません"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T と %q#T の間での比較です"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD は通常は非静的関数です。"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD は通常は非静的関数です。"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%<operator %s%> は %qT 用としては適切ではありません"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "ここで宣言されています"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "ここで宣言されています"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D はアクセス出来ません"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "ここで宣言されています"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL から非ポインタ型 %qT へ変換しています"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL から非ポインタ型へ変換しています"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT 用の初期化子の周りに中括弧が多すぎます"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, fuzzy, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "参照を参照として宣言できません"
+
+#: cp/call.c:7911
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ビットフィールド %qD を関数型として宣言できません"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "関数呼び出しの引数が format 属性の候補であるようです"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, fuzzy, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "代わりに #include を使用してください"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, fuzzy, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, fuzzy, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "代わりに #include を使用してください"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "定数が自身を参照しています"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "コンストラクタ %<%T::%D%> を直接呼び出すことは出来ません"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "オーバーロードされた %<%s(%A)%> の呼び出しは曖昧です"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "デストラクタから値を返そうとしています"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "%q#T から %q#T への変換です"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " 候補 1: %q+#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " 候補 2: %q+#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "無効なバージョン番号形式"
@@ -46268,1126 +46300,1126 @@ msgstr ""
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr ""
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "`%s' のセクションは前方でに宣言されたものと衝突します"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "メソッド %q+D 用のアクセス指定が競合しています。無視されました"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "フィールド %qE 用のアクセス指定が競合しています。無視されました"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "クラス %qT 内の全てのメンバ関数が非公開です"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T はフレンドが無い非公開デストラクタのみ定義しています"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T はフレンドが無い非公開コンストラクタのみ定義しています"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, fuzzy, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%q+D は隠されています"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "        %qD"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "ビットフィールド %q+#D が非整数型です"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ビットフィールド %q+D の幅が整数定数ではありません"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "ビットフィールド %q+D の幅が負です"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "ビットフィールド %q+D の幅が 0 です"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "%q+D の幅が型の大きさを超えています"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D は %q#T の全ての値を持つには小さすぎます"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "コンストラクタを持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "デストラクタを持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "コピー代入演算子を持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D は共用体のメンバのため静的ではありません"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "フィールド %q+D はが関数型として無効な宣言をされました"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "共用体 %qT 内の複数のフィールドが初期化されました"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "フィールド %q+#D がクラス名と同じです"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T がポインタデータメンバを持っています"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "非仮想関数 %q+D 用の初期化子が指定されています"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "関数を inline にできません"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, fuzzy, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的参照 %q+#D があります"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "直接の基底 %qT は曖昧なため %qT 内でアクセスできません"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "仮想基底 %qT は曖昧なため %qT 内ではアクセスできません"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, fuzzy, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D のオフセットは ABI に適合していないため将来のバージョンの GCC では変更になるかもしれません"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "可変配列メンバの無効な使用法です"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "%q#T が再定義されています"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T が再定義されています"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T は仮想関数を持っており非仮想デストラクタからアクセス可能です"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "%q#D 用のプロトタイプがクラス %qT 内のどれとも一致しません"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "メンバ関数の名前を欠いています"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "言語文字列 %<\"%E\"%> は認識できません"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "関数 %qD から型 %q#T への変換が適合しません"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "オーバーロードされた関数 %qD から型 %q#T への変換は曖昧です"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "メンバ %qD へのポインタと見なしています"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "型情報が不十分です"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE を型 %qT から型 %qT へ変換できません"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "ここで %q#D として再宣言されています"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr ""
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, fuzzy, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr ""
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr "元々はここで定義されました"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 msgid "allocation performed here"
 msgstr "ここで宣言されています"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr "`%s' の宣言は前方のローカルシンボルを覆い隠します"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "`%s' はその定義の前にプロトタイプなしで使われました"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "右シフト回数が負です"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "右シフト回数が負です"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, fuzzy, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "ここで宣言されています"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qE は初期化されていません"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D は const ではありません"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D は volatile です"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "NaN から整数への変換です"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "%<template%> が予期されます"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "`%s' はその定義の前にプロトタイプなしで使われました"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "仮想関数は friend にできません"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "ファイル \"%s\" に戻るはずでした"
@@ -47397,52 +47429,52 @@ msgstr "ファイル \"%s\" に戻るはずでした"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, fuzzy, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
@@ -47487,7 +47519,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -47874,7 +47906,7 @@ msgstr "前方での `%s' の宣言"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "使用している宣言 %q+D は前に使用している宣言と競合しています"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "前方での `%s' の宣言"
@@ -48004,8 +48036,8 @@ msgstr "前方での `%s' の暗黙的な宣言"
 msgid "%q#D previously defined here"
 msgstr "前はここで定義されました"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "前はここで宣言されました"
@@ -48040,52 +48072,52 @@ msgstr ""
 msgid "previous specification in %q#D here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "%q+D が再定義されました"
@@ -48098,48 +48130,48 @@ msgstr "%q+D が再定義されました"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48147,2297 +48179,2313 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "%q+D の冗長な再宣言です"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  ここから"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  catch ブロックに入ります"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "文が予期されます"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD は関数テンプレートではありません"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "不明な型名 %qE です"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "仮引数 `%s' の型が宣言されていません"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "要求された整列が 2 の累乗ではありません"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一つの宣言に複数の型があります"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typdef 宣言で型名を欠いています"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "`%s' の宣言で型がデフォルトの `int' とされました"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef `%s' が初期化されました"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D のテンプレート宣言です"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ポインタ宣言子に不適切な型修飾子"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "重複した初期化子"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "変数 `%s' には初期化子がありますが、不完全型です"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "仮引数 `%s' は不完全型です"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "自明でないラベルのついた初期化子です"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "初期化された変数 %q+D は dllimport とマークされています"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無効なビット列初期化子です"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "無効な初期化子です"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "入力ファイルが多すぎます"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "初期化子のまわりのブレースを欠いています"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C89 は複合リテラルを禁じます"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "`%s' は不完全型です"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "共用体初期化子内の要素が多すぎます"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pramga が括弧で囲まれた文字列リテラルを受け取りました"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "コンストラクタの静的メンバ初期化子は無効です"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(クラス外での初期化を必要とします)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "仮引数 %qD が初期化されます"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "関数 `%s' が変数であるかのように初期化されました"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs が構造体フィールド用に指定されています"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%<offsetof%> を静的データメンバ %qD へ適用できません"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java メソッド %qD が非 Java 戻り型 %qT を持ちます"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "共用体を透過的にできません"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "%qD はテンプレート関数ではありません"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "`::main' を inline としては宣言できません"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' は `int' を返さなければなりません"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "typedef %q+D が再定義されました"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr "%s=%s は数値ではありません"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "可変長配列が使用されています"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "配列の次元がオーバーフローしました"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "大きさゼロの配列を作ろうとしています"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, fuzzy, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名変数やフィールドが void と宣言されました"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "変数またはフィールドが void と宣言されました"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "関数の定義が `register' と宣言されました"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ では型の無い %qs の宣言を禁止しています"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ は %<__int128%> を %qs に対してはサポートしていません"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> と %<unsigned%> が %qs に対して両方指定されています"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> および %<short%> が %qs に対して両方指定されています"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex は %qs に対しては無効です"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "仮引数宣言の中の typedef 宣言は無効です"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "仮引数 %qs に対して記憶域クラスタ指定されています"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, fuzzy, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "ネストした関数 `%s' は `extern' に宣言されました"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "`%s' のトップレベルの宣言が `auto' を指定します"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "%qE 属性は無視されました"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "%<restrict%> の誤った使用法です"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "`%s' は配列を返す関数として宣言されています"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, fuzzy, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "デストラクタは仮引数を取りません"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "メンバ関数は暗黙的にそのクラスの friend です"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static `%s' を mutable として宣言できません"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const `%s' を `mutable' として宣言できません"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "クラス宣言の外側で virtual 指定しています"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, fuzzy, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "クラス `%s' を大域スコープの friend にしようとしています"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "無効な用法の of %%d, %%x, 又は %%X"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%s: 関数 `%s' の宣言が変換されていません\n"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%s を開けません"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "変数 %qD が関数として再宣言されました"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "元の型はここで宣言されました"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "領域 `%s' は不完全な型です"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "仮引数が不完全型です"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "関数を inline にできません"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `register' は無効です"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual な非クラス関数 `%s'"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "他の関数内で static 関数を宣言できません"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, fuzzy, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "`%s' が初期化されるところで、`extern' 宣言されました"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, fuzzy, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -50449,105 +50497,105 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "事前の宣言なしの大域関数に関して警告する"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "%qD をビットフィールド型として宣言できません"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "型修飾子 `%s' は struct や class の後には使えません"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複した case の値"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "作成時と使用時でエンディアンが異なります"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "述語は識別子でなければなりません"
@@ -50556,77 +50604,77 @@ msgstr "述語は識別子でなければなりません"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "列挙値がオーバーフロー"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T が複数定義されています"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD の型をデフォルトの %<int%> にします"
@@ -50666,7 +50714,7 @@ msgstr "関数を削除 (delete) できません。%<delete%> の有効な引数
 msgid "deleting %qT is undefined"
 msgstr "%qT の削除は定義されていません"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D のテンプレート宣言です"
@@ -50676,7 +50724,7 @@ msgstr "%q#D のテンプレート宣言です"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "デストラクタ %qD がメンバテンプレートとして宣言されています"
@@ -51001,22 +51049,22 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -51121,7 +51169,7 @@ msgstr ""
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
@@ -51131,7 +51179,7 @@ msgstr "%s に `%s' という名前のメンバはありません"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
@@ -51317,408 +51365,408 @@ msgstr "可変配列メンバを初期化しています"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD はこの関数内で初期化されずに使用されています"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%qD は初期化されるべきです"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, fuzzy, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD は初期化されるべきです"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "無効な初期化子"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, fuzzy, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "基底クラスを持つクラスのオブジェクト用の初期化子リストです"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "無効な参照型です"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "%qT 内の初期化されない定数メンバは C++ では無効です"
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, fuzzy, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "式内で整数がオーバーフローしました"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "new に対して無効な型である `void'"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "フィールド '%s' がクラス内に見つかりません"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "関数型に対して new を適用できません"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初期設定子の末尾が本来より早く出現しました"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete での配列サイズが不明です"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, fuzzy, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "複合リテラルが可変サイズを持っています"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "%s を参照として宣言できません"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -51773,62 +51821,62 @@ msgstr ""
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "警告: "
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -52009,300 +52057,300 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "キャストによる関数の型が適合しません"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "キャストによる関数の型が適合しません"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "`%s' のセクションは前方でに宣言されたものと衝突します"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%d 個のコンストラクタが見つかりました\n"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, fuzzy, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "%q#D のテンプレート宣言です"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "%q#D が宣言されています"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "`%s' 属性の疑似命令が無視されました"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "`this' は静的メンバ関数から使用できません"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "弱い %q+D は %qE として定義できません"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "構造体がここで定義されています"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "メソッド属性を指定するのは最後のみでなければいけません"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%q+D  のアドレス領域は前の宣言と競合しています"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -52327,7 +52375,7 @@ msgstr "識別子 %qE は C++ 予約語と競合しています"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
@@ -52352,7 +52400,7 @@ msgstr ""
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -52432,7 +52480,7 @@ msgstr "無効な型: `void &'"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -52568,7 +52616,7 @@ msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
@@ -52693,7 +52741,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -52743,7 +52791,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -52773,7 +52821,7 @@ msgstr ""
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
@@ -52793,12 +52841,12 @@ msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
@@ -52833,7 +52881,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
@@ -52848,7 +52896,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
@@ -52863,1113 +52911,1118 @@ msgstr "ISO C++ は複合リテラルを禁じます"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "無効な %qD の使用です"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "非スカラー型"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "式が予期されます"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "古いスタイルのキャストを使用しています"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "|| と共に使われる && の周りでは括弧をつけることをお勧めします"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr "`%s' の宣言は仮引数リストのシンボルを覆い隠します"
+
+#: cp/parser.c:10819
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "単項演算式内で無効な被演算子です"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "%s を参照として宣言できません"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, fuzzy, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, fuzzy, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "%qs 句が多すぎます"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "重複した %<volatile%> です"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "仮引数配列宣言内の属性が無視されました"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ラベル付き文が予期されます"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case ラベル %qE が switch 文の中にありません"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 msgid "condition declares an array"
 msgstr "関数が集合体を返しています"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 msgid "condition declares a function"
 msgstr "フィールド %qE が関数として宣言されています"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "sizeof が関数型に適用されました"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ は計算型 goto を禁じます"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 msgid "expected module-name"
 msgstr "テンプレート名が予期されます"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 msgid "private module fragment"
 msgstr "引数がありません"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "無効なリンク指定です"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr "%qE 属性は無視されました"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "空の宣言です"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "メンバ関数 %qD 用の無効な初期化子です"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> がクラスの外側で使用されています"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> は C++0x で意味が変更になります。削除してください"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%q+D は %q#T 内では無効です"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "%q+D は %q#T 内では無効です"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, fuzzy, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無効なリンク指定です"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "メンバ `%s' に対する無効な初期値"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D は静的宣言の後に非静的宣言が続いています"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "前時代的な古いスタイルの基底クラス初期化子です"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "識別子が予期されます"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "二進演算内で無効な被演算子です"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "演算子が予期されます"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr ""
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr "-ms2600 が -ms 無しで使用されています"
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "無効なパラメータ %qs です"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "無効な型: `void &'"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "テンプレート引数が予期されます"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "マクロ引数リストにあり得ないトークン"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "テンプレート名が予期されます"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "テンプレート引数が予期されます"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "型指定が予期されます"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "型名が予期されます"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 msgid "concept defined here"
 msgstr "共用体がここで定義されています"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣言 %qD が何も宣言していません"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> または %<{%> が予期されます"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD は名前空間名ではありません"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, fuzzy, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "重複した %<volatile%> です"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD は関数スコープの外側で定義されていません"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "alloc_size パラメータが範囲外です"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "関数宣言中に（型の無い）仮引数名があります"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "関数宣言中に（型の無い）仮引数名があります"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr "関数 %qD が変数として再宣言されました"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "ここでは関数定義は許可されていません"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "friend 関数 `%s' を初期化できません"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
@@ -53978,430 +54031,430 @@ msgstr ""
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無効な宣言子です"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "宣言子が予期されます"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD は名前空間です"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ポインタ演算子が予期されます"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "重複する `virtual' 指定子"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr "合っていない引数です"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> または %<...%> が予期されます"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "メソッドは関数ポインタに変換できません"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "構造体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> または %<:%> が予期されます"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "クラス %s 用のファイルを見つけられません。"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD の宣言内に無効なクラス名です"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "%q+#T の前の定義"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "ビットフィールドの幅が %qD 非整数型 %qT です"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "識別子または %<(%> が予期されます"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr "%qE 属性は R8C ターゲット用にはサポートされていません"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "%<:%> または %<...%> が予期されます"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "要求された整列が定数ではありません"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求された整列が定数ではありません"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -54410,756 +54463,756 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver は最早サポートされません"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "宣言が何も宣言していません"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "`>>' はテンプレートクラス名は `> >' とすべきです"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "テンプレート型統一中 `%s' が使用されました"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> が %qD の前にあります"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ は `long long' を受け入れません"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "%qE が重複しています"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "`%s' が重複しています"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> が予期されます"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> が予期されます"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> が予期されます"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> が予期されます"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> が予期されます"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> が予期されます"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> が予期されます"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> が予期されます"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> が予期されます"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> が予期されます"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> が予期されます"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> が予期されます"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> が予期されます"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> が予期されます"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> が予期されます"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<@end%> が予期されます"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> が予期されます"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> が予期されます"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> が予期されます"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> が予期されます"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> または %<::%> が予期されます"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "前はここで宣言されました"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "名前無しテンプレートクラスです"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "デフォルト引数内でファイルが終了しています"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c メソッド定義が予期されます"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "識別子が必要です"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "不明な property 属性です"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "整数式が予期されます"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不十分な型情報"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "式が予期されます"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "メンバ関数の名前を欠いています"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC java_exceptions の末尾にゴミ"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC option は関数内では許可されていません"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "ret 命令は実装されていません"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "#if 式の中では文字列定数が使えません"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "ポインタ宣言子に不適切な型修飾子"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "`%s' が再定義されました"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "`%s' が再定義されました"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD は変数ではありません"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "Code 属性を欠いています"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "Code 属性を欠いています"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "`operator delete' の宣言内に多すぎる引数"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, fuzzy, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD の宣言内でテンプレート仮引数リストが少なすぎます"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD はテンプレート関数ではありません"
@@ -55172,158 +55225,158 @@ msgstr "%qD はテンプレート関数ではありません"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "メンバ関数 %qD は %qT 内では宣言されていません"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "隠された宣言はここです"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "前はここで宣言されました"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "関数 %qE への引数が多すぎます"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "重複したラベル %qD です"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 用のデフォルト引数がありません"
@@ -55332,47 +55385,47 @@ msgstr "%qD 用のデフォルト引数がありません"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "仮引数リスト中の `void' はリスト全体を占めなければなりません"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "名前無しテンプレートクラスです"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -55382,490 +55435,490 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "非テンプレート %q#D のテンプレート定義です"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ここで %q#D として再宣言されています"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引数が与えられています"
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "型 %qT の引数が %qT と一致しません"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "空の宣言です"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "内部一貫性がありません"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "共用体に可変配列メンバがあります"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE は宣言の開始ではありません"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
@@ -55883,292 +55936,292 @@ msgstr "メンバ関数へのポインタが呼ばれましたが、クラスス
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "sizeof が関数型に適用されました"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "無効な宣言です"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "関数が集合体を返しています"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "static フィールド `%s' を欠いています"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void 式の不適切な使用"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "不正な文字列定数です"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%s: `%s' の初期化:\n"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -56180,153 +56233,153 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "inline に出来ると見なされていない関数です"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "間接関数 %q+D は弱い参照として宣言できません"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "不完全な typedef `%s' の使用は不適切です"
@@ -56461,531 +56514,531 @@ msgstr "const `%s' を `mutable' として宣言できません"
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "論理演算子が常に true または false と評価されるように思われる場合に警告する"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "%<for%> ループ初期化宣言は C99 モード内でのみ許可されています"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "合っていない引数です"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "引数が構造体です"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "`this' は静的メンバ関数から使用できません"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, fuzzy, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "テンプレート型仮引数には `class' や `typename' 予約語を使わねばなりません"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "`%s' の宣言は仮引数リストのシンボルを覆い隠します"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "無効な宣言です"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "alloc_size パラメータが範囲外です"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "合っていない引数です"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "レジスタ '%c' が不明です"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT はテンプレート型ではありません"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE は %<reduction%> 用の無効な型を持っています"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, fuzzy, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "%qs 句が多すぎます"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> がポインタ型として定義されていません"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけません"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "%<__builtin_return_address%> へのサポートされていない引数です"
@@ -56993,22 +57046,22 @@ msgstr "%<__builtin_return_address%> へのサポートされていない引数
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -57018,1062 +57071,1062 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 msgid " declared here"
 msgstr "ここで宣言されています"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD は変数ではありません"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "`java_interface' 属性は Java クラス定義に対してのみ用いる事ができます"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qE 属性は型に適用できません"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "要求された init_priority は整数型の定数ではありません"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, fuzzy, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "init_priority 属性はクラス型オブジェクトのファイルスコープ定義でのみ使えます"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "要求された init_priority が範囲外です"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "要求された init_priority は内部で使用するために予約されています"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "init_priority 属性はこのプラットフォームではサポートされていません"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "`%s' 属性は関数に対してのみ適用されます"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "Tree 検査: %s があるべき所に %s があります(%s 内, %s:%d)"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ は `void *' 型ポインタと関数ポインタとの %s を禁じます"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ は `void *' 型ポインタと関数ポインタとの %s を禁じます"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ は `void *' 型ポインタと関数ポインタとの %s を禁じます"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ビットフィールドに `__alignof' が適用されました"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ は関数型の式への `sizeof' の適用を禁じます"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ は関数型の式への `sizeof' の適用を禁じます"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "文字列定数中の \\r エスケープ"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "文字列定数中の \\r エスケープ"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "メンバ関数の名前を欠いています"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "`register' と宣言された配列に添字をつけようとしています"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "添字をつけられた値が配列でもポインタでもありません"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "メンバへのポインタ構築の使用でオブジェクトを欠いています"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ はプログラムの中から `::main' を呼び出すことを禁じます"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "関数に対する引数が多すぎます"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "関数への引数が少なすぎます"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "関数ポインタが計算で使われました"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ はポインタと整数との比較を禁じます"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "%qT と %qT の比較です"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮動小数点引数での順序付けられない比較です"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ポインタ演算で不完全型へのポインタを使うことは無効です"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取ることを禁じます"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ は `::main' 関数のアドレスを取ることを禁じます"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "ビットフィールド %qD のアドレスを取得できません"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<void%> 型の式のアドレスを取得しています"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "不完全型へのポインタに対する演算"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "register 変数 `%s' のアドレスが要求されました"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "初期化子リストは複合式として取り扱われました"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "NaN から整数への変換です"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
-msgstr ""
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
+msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 msgid "cast from %qH to %qI loses precision"
 msgstr "%s: 全体的な精度の低下"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "キャストによってポインタが示す型の要求アラインメントが増加します"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ は関数ポインタとオブジェクトポインタの間でのキャストを禁じます"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C は共用体型へのキャストを禁じます"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%d 番目の引数が `%s' の型と互換性がありません"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "配列の不正な初期化"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "代入として無効な左辺値です"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   ポインタからメンバ関数への変換で"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "無効なバージョン番号形式"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "format 属性をの候補となりそうな関数について警告する"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "引数 %d 個の `%s' を渡します"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "非左辺値への参照が返されました"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "return 文に十分な値がありません"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "デストラクタから値を返そうとしています"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "コンストラクタの関数 try ブロックのハンドラからは return できません"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "初期化子がありません"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "無効な %%s 値"
@@ -58339,107 +58392,102 @@ msgstr "スカラー初期化子が中括弧で囲まれています"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD の型は元の宣言と一致しません"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "レコードや共用体にフィールド名がない初期化子です"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "union 初期化子がフィールド名ではなくインデックス値になっています"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "循環ポインタの代表を検出しました"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, fuzzy, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "`operator->()'の結果が非ポインタの結果をもたらします"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "`%s' の引数として無効な型"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
@@ -58459,275 +58507,281 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "cannot be declared to be a function"
 msgstr "関数型に対して new を適用できません"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of %<struct %E%>"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "%<struct %E%> の再定義です"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be %s"
 msgstr "%s を開けません"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be `scope` and `%s`"
 msgstr "%s を開けません"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, fuzzy, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr "%s を開けません"
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr "#if 式の中では文字列定数が使えません"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, fuzzy, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr "文が予期されます"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "0 で初期化されるデータを bss セクション内に配置する"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr "引数は複素数型でなければいけません"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "braced spec body %qs is invalid"
 msgid "size of type %s is invalid"
 msgstr "忠括弧で括られた spec 本体 %qs は無効です"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "string expected for library name"
 msgstr "クラス名が予期されます"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, fuzzy, gcc-internal-format
 msgid "function name expected for start address"
 msgstr "アドレス内の予期しない副作用"
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr "関数が予期されます"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "引数がありません"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 msgid "can only apply to a single declaration"
 msgstr "空の宣言です"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
 msgstr "無効な宣言です"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "circular reference to enum member"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr "テンプレート型仮引数には `class' や `typename' 予約語を使わねばなりません"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, gcc-internal-format
 msgid "recursive mixin instantiation"
 msgstr ""
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, gcc-internal-format
 msgid "recursive expansion"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "error instantiating"
 msgstr "%qs へ書き込み中にエラーが発生しました"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "仮想関数は friend にできません"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "functions cannot be scope"
@@ -58736,42 +58790,52 @@ msgstr "仮想関数は friend にできません"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr "割り込み関数は引数無しでなければいけません"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr "オーバーロードされた仮想関数名について警告する"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 msgid "cannot be both final and abstract"
 msgstr "%qE は %<mips16%> と %<nomips16%> 属性の両方を持つことは出来ません"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -58779,176 +58843,176 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot override final function %s"
 msgstr "組み込み関数 %qs を無効に出来ません"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr "関数 %qE へ十分な引数がありません"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 msgid "does not override any function"
 msgstr "メンバ関数の名前を欠いています"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "関数 %qD の減分です"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "%qE 属性は関数へのみ適用されます"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "オーバーロードされた仮想関数名について警告する"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr "最後の引数は即値でなければいけません"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr "整数式が予期されます"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "structs, unions cannot be abstract"
 msgstr "共用体を透過的にできません"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr "述語は識別子でなければなりません"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "circular pointer delegation detected"
 msgid "circular inheritance"
 msgstr "循環ポインタの代表を検出しました"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr "述語は識別子でなければなりません"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "重複したディレクトリ \"%s\" を無視します\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot inherit from final class %s"
 msgstr "クラス `%s' が見つかりません"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "メンバ関数の名前を欠いています"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr "仮引数 `%s' の型が宣言されていません"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve"
 msgstr "%s を開けません"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr "ビットフィールド %qD のアドレスを取得できません"
@@ -58963,22 +59027,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr "atexit に失敗しました"
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 msgid "has forward references"
 msgstr "配列参照での添字を欠いています"
@@ -59038,23 +59102,22 @@ msgstr "コンストラクタの静的メンバ初期化子は無効です"
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "関数の返す型が関数であってはなりません"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
@@ -59590,7 +59653,7 @@ msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "無効なビット列初期化子です"
@@ -60683,12 +60746,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -60868,7 +60931,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr "引数の型が異なります"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -63351,7 +63414,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63432,7 +63495,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -63567,12 +63630,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -63682,542 +63745,542 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "コンストラクタを静的メンバ関数とすることはできません"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "%q+D が未定義シンボル %qE の別名となっています"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "引数は定数でなければいけません"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "関数 `%s' に対する引数が多すぎます"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "関数 `%s' に対する引数が多すぎます"
@@ -64362,33 +64425,33 @@ msgstr ""
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "NaN から整数への変換です"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "NaN から整数への変換です"
@@ -64396,22 +64459,22 @@ msgstr "NaN から整数への変換です"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -64947,7 +65010,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -66119,12 +66182,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -66279,147 +66342,147 @@ msgstr ""
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "%s: 読み込み用にファイル `%s' を開くことができません: %s\n"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: ファイル `%s' に書き込み中にエラー: %s\n"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "%s: ファイル `%s' を削除できません: %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "%s: 警告: ファイル `%s' を `%s' 名前変更できません: %s\n"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "%s: 副 info ファイル `%s' を削除できません: %s\n"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "%s: 読み込み用にファイル `%s' を開くことができません: %s\n"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -66955,8 +67018,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -68979,7 +69042,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
@@ -69094,7 +69157,7 @@ msgstr "spec 関数 %qs の引数内でエラーが発生しました"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -69250,212 +69313,212 @@ msgstr "関数を inline にできません"
 msgid "Impure function at %L might not be evaluated"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "要求されたアラインメントが大きすぎます"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -69464,12 +69527,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -69478,293 +69541,293 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qE は廃止されました"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "添え字は整数でなければいけません"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -69773,284 +69836,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "数値型が予期されます"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -70058,192 +70121,192 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "コンストラクタ %qs 内"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -70251,964 +70314,964 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "配列 `%s' の大きさが大きすぎます"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s 内、位置 %s:%d"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qD は既に定義されています"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%s に互換性のない型"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "式文が無効です"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -72072,17 +72135,17 @@ msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -72173,107 +72236,107 @@ msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "フォーマットへの引数が多すぎます"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -72425,7 +72488,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr ""
@@ -72552,7 +72615,7 @@ msgstr "-pedantic と -traditional とは相互排他的です"
 
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-pedantic と -traditional とは相互排他的です"
 
 #: lto/lto-object.c:107
@@ -73653,7 +73716,7 @@ msgstr "認識不能なオプション `%s'"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "認識不能なオプション `%s'"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "認識できないオプション %<-%s%> です"
@@ -73671,15 +73734,15 @@ msgstr "%qs の後にマクロ名がありません"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "%qs の後にファイル名がありません"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "%qs の後にパスがありません"
@@ -73729,7 +73792,7 @@ msgstr "数値がありません"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "認識できない可視性の値 %qs です"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "認識できないレジスタ名 %qs です"
@@ -73812,92 +73875,92 @@ msgstr "%qE は廃止されました"
 msgid "unknown linker output %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: common.opt:1502
+#: common.opt:1506
 #, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "不明な余分な精度スタイル %qs です"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "不明な浮動小数短縮形 %qs です"
 
-#: common.opt:1718
+#: common.opt:1722
 #, fuzzy, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: common.opt:1902
+#: common.opt:1906
 #, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "不明な IRA 範囲 %qs です"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "%qs の後にアサーションがありません"
 
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "不明な型名 %qE です"
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "不明な型名 %qE です"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "認識できない可視性の値 %qs です"
 
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs 用の初期化付近)"
@@ -73926,3 +73989,7 @@ msgstr "不明な TLS モデル %qs です"
 #, fuzzy
 #~ msgid "conversion of %qT null pointer to %qT is not a constant expression"
 #~ msgstr "初期化子の要素が定数式ではありません"
+
+#, fuzzy
+#~ msgid "cannot deduce template arguments for %qT from %<()%>"
+#~ msgstr "`%s' の引数として無効な型"
diff --git a/gcc/po/nl.po b/gcc/po/nl.po
index c919763e19a4a..72f7b7e117468 100644
--- a/gcc/po/nl.po
+++ b/gcc/po/nl.po
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.9-b20140202\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2014-02-05 12:25+0100\n"
 "Last-Translator: Benno Schulenberg <benno@vertaalt.nl>\n"
 "Language-Team: Dutch <vertaling@vrijschrift.org>\n"
@@ -1234,12 +1234,12 @@ msgstr "    inline gemaakt vanuit %qs"
 msgid "this is the insn:"
 msgstr "dit is de insn:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "'B' operand is geen constante"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr ""
 
@@ -1420,20 +1420,20 @@ msgstr "onherkenbare insn:"
 msgid "insn does not satisfy its constraints:"
 msgstr ""
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr ""
 
 # Vertaling voor "endianness"? Of niet nodig?
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different endianness"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "aangemaakt en gebruikt met verschillende \"endianness\""
 
 # Vertaling voor "endianness"? Of niet nodig?
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different endianness"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1474,7 +1474,7 @@ msgstr "%s%slet op: %s headerversie %s verschilt van bibliotheekversie %s.\n"
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC heuristieken: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1932,91 +1932,91 @@ msgstr "lengte-modifier in strfmon-formaat"
 msgid "<command-line>"
 msgstr "<opdrachtregel>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ongeldige operand voor '%%%c'"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "ongeldige constante"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 #| msgid "invalid operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "ongeldige operand voor '%%%c'"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "operand ontbreekt"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "ongeldige constante"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "ongeldige operand"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ongeldige operandprefix '%%%c'"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "ongeldige adresseringsmodus"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ongeldige registernaam voor %qs"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ongeldige operanden in binaire bewerking"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2032,18 +2032,18 @@ msgid "invalid %%r value"
 msgstr "ongeldige waarde voor %%r"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "ongeldige waarde voor %%R"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "ongeldige waarde voor %%N"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "ongeldige waarde voor %%P"
@@ -2073,7 +2073,7 @@ msgstr "ongeldige waarde voor %%M"
 msgid "invalid %%U value"
 msgstr "ongeldige waarde voor %%U"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "ongeldige waarde voor %%s"
@@ -2083,7 +2083,7 @@ msgstr "ongeldige waarde voor %%s"
 msgid "invalid %%C value"
 msgstr "ongeldige waarde voor %%C"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "ongeldige waarde voor %%E"
@@ -2097,7 +2097,7 @@ msgstr "onbekende 'unspec' relocatie"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ongeldige code voor %%xn"
@@ -2181,36 +2181,36 @@ msgstr "ongeldige UNSPEC als operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "vermoedelijke constante niet herkend"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "ongeldige shift-operand"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "Thumb-instructie met predicaat"
 
 # mja. snappen wie snappen kan ^^
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2218,13 +2218,13 @@ msgstr "ongeldige operand voor code '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "instructie wordt nooit uitgevoerd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2355,8 +2355,8 @@ msgstr "onverwachte operand"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2725,7 +2725,7 @@ msgstr "ongeldige bewerking met %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "ongeldige waarde voor %%p"
@@ -2783,7 +2783,7 @@ msgid "post-increment address is not a register"
 msgstr "post-increment adres is geen register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "slecht adres"
 
@@ -2836,8 +2836,8 @@ msgstr "'%%%c' is geen geldige operand-prefix"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ongeldig gebruik van '%%%c'"
@@ -2978,320 +2978,320 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "lege declaratie"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Schakel geïndexeerde adressering uit"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx en -mno-altivec zijn incompatibel"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 #, fuzzy
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "case-label niet in een switch-statement"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 #, fuzzy
 msgid "bad move"
 msgstr "slechte test"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "ongeldige waarde voor %%D"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "ongeldige waarde voor %%K"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "ongeldige waarde voor %%O"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "ongeldige waarde voor %%q"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "ongeldige waarde voor %%x"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "twee %<u%>s in integerconstante"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ongeldige conversie naar %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ongeldige conversie naar %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "ongeldige conversie naar %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "ongeldige conversie naar %<__fpreg%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
 # Betere vertaling voor 'decompose'?
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "kan adres niet ontleden"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ongeldige operand voor 'O' modifier"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ongeldige code voor operanduitvoer"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ongeldige expressie als operand"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
 # 'signedness' = 'signed-heid'?
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 #, fuzzy
 msgid "types differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3562,8 +3562,8 @@ msgstr "{{anoniem}}"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ongeldige operand van %s"
@@ -3583,7 +3583,7 @@ msgstr "ongeldige operand van %s"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ongeldige operand van %s"
@@ -3591,7 +3591,7 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ongeldige operand van %s"
@@ -3610,21 +3610,21 @@ msgstr "ongeldige operand van %s"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ongeldige operand van %s"
@@ -3635,13 +3635,13 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ongeldige operand van %s"
@@ -3650,7 +3650,7 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ongeldige operand van %s"
@@ -3660,18 +3660,18 @@ msgstr "ongeldige operand van %s"
 msgid "expected %<.%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ongeldige operand van %s"
@@ -3679,28 +3679,28 @@ msgstr "ongeldige operand van %s"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(anoniem)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ongeldige operand van %s"
@@ -3717,32 +3717,32 @@ msgstr "ongeldige operand van %s"
 msgid "candidate:"
 msgstr "kandidaat 1:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidaat 1:"
 msgstr[1] "kandidaat 1:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "kandidaat 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "kandidaat 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 #, fuzzy
 msgid "jump to label %qD"
 msgstr "herhaald label %qs"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr ""
 
@@ -3976,30 +3976,30 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 msgid "%<using enum%> of dependent type %qT"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "kandidaten zijn:"
 
@@ -4050,54 +4050,54 @@ msgstr "conversie gooit constantheid weg"
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argument van verkeerd type voor unaire min"
 
 # 'unary' = 'unair'?
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argument van verkeerd type voor bit-complement"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argument van verkeerd type voor abs"
 
 # OK, ik geef het op: wat is hier een goede vertaling voor 'conjugation'?
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argument van verkeerd type voor vervoeging"
 
 # 'unary' = 'unair'?
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4198,7 +4198,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4335,7 +4335,7 @@ msgstr "ongeldige operand voor %P"
 msgid "Bad type in constant expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "ongeldige operand van %s"
@@ -4367,12 +4367,12 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 #, fuzzy
 msgid "assignment"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 #, fuzzy
 msgid "pointer assignment"
 msgstr "ongeldige lvalue in toewijzing"
@@ -4471,156 +4471,156 @@ msgstr ""
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 #, fuzzy
 msgid "iterator variable"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4748,26 +4748,26 @@ msgstr ""
 msgid "Incorrect function return value"
 msgstr "%<noreturn%> functie geeft niet-void waarde terug"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, c-format
 msgid "Error allocating %lu bytes"
 msgstr ""
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr ""
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr ""
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -4983,15 +4983,15 @@ msgstr "-Xbind-now en -Xbind-lazy zijn incompatibel"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "-EB en -EL gaan niet samen"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-mfloat-abi=soft en -mfloat-abi=hard gaan niet samen"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian en -mlittle-endian gaan niet samen"
 
@@ -5009,8 +5009,8 @@ msgstr "specbestand heeft geen spec voor het linken"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "-march=... en -mcpu=... gaan niet samen"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "-shared en -mdll zijn niet compatibel"
 
@@ -5182,10 +5182,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "pointer naar functie gebruikt in rekensom"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5662,160 +5662,160 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr ""
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr ""
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "gebruik liefst haakjes rond && binnen ||"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, fuzzy, no-c-format
 msgid "Enable range checking during compilation."
 msgstr "lege declaratie"
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr ""
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr ""
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr ""
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr ""
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Volg de ISO 1990 C standaard"
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Volg de ISO 1990 C standaard"
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Volg de ISO 1990 C standaard"
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Volg de ISO 1990 C standaard"
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Volg de ISO 1990 C standaard"
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr ""
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr ""
@@ -6499,7 +6499,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7129,8 +7129,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, fuzzy, no-c-format
 msgid "No longer supported."
 msgstr "-pipe wordt niet ondersteund"
@@ -7488,486 +7488,481 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, fuzzy, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "ongeldige beginwaarde"
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr ""
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr ""
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr ""
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, fuzzy, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr "lege declaratie"
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr ""
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr ""
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr ""
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, fuzzy, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, fuzzy, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr ""
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr ""
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr ""
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, fuzzy, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "Geef de naam op van hardware/formaat voor floating-point getallen op het doelplatform"
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr ""
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr ""
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr ""
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr ""
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr ""
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr ""
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr ""
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr ""
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr ""
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr ""
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr ""
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr ""
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr ""
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr ""
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr ""
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr ""
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr ""
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr ""
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr ""
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr ""
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr ""
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr ""
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr ""
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr ""
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr ""
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Volg de ISO 1998 C++ standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Volg de ISO 1998 C++ standaard"
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Verouderd; gebruik liever -std=c99"
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Verouderd; gebruik liever -std=c99"
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Volg de ISO 1998 C++ standaard"
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr "Verouderd; gebruik liever -std=c99"
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "Volg de ISO 1998 C++ standaard"
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Volg de ISO 1998 C++ standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Volg de ISO 1998 C++ standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Volg de ISO 1990 C standaard"
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "Verouderd; gebruik liever -std=c99"
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Volg de ISO 1990 C standaard zoals aangepast in 1994"
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Volg de ISO 1990 C standaard zoals aangepast in 1994"
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Volg de ISO 1990 C standaard"
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard"
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Volg de ISO 1999 C standaard"
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c99."
 msgstr "Verouderd; gebruik liever -std=c99"
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Volg de ISO 1998 C++ standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Volg de ISO 1990 C standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Verouderd; gebruik liever -std=gnu99"
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Verouderd; gebruik liever -std=gnu99"
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Volg de ISO 1990 C standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "Verouderd; gebruik liever -std=gnu99"
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "Volg de ISO 1990 C standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Volg de ISO 1998 C++ standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Volg de ISO 1998 C++ standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Volg de ISO 1990 C standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Verouderd; gebruik liever -std=gnu99"
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Volg de ISO 1990 C standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Volg de ISO 1998 C++ standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Volg de ISO 1990 C standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard with GNU extensions"
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Volg de ISO 1999 C standaard met GNU uitbreidingen"
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Verouderd; gebruik liever -std=gnu99"
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Volg de ISO 1990 C standaard zoals aangepast in 1994"
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=iso9899:1999"
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Verouderd; gebruik liever -std=iso9899:1999"
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
 # of "preprocessing" behouden?
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable traditional preprocessing."
 msgstr "Schakel traditionele voorverwerking in"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, fuzzy, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\tOndersteun ISO C trigraphs"
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Do not predefine system-specific and GCC-specific macros"
 msgid "Do not predefine system-specific and GCC-specific macros."
@@ -8213,6 +8208,11 @@ msgstr ""
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr "impliciete declaratie van functie %qs"
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9453,143 +9453,155 @@ msgstr ""
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:34
 #, fuzzy, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "Geef de naam op van hardware/formaat voor floating-point getallen op het doelplatform"
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, fuzzy, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Startadressen van functies worden uiteglijnd op deze macht van 2"
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr ""
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr ""
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr ""
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr ""
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, fuzzy, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Pngeldige optie %<-%s%>"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr ""
@@ -9724,12 +9736,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9750,12 +9756,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -17017,2170 +17017,2170 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "Geef het register op dat voor PIC-adressering gebruikt moet worden"
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 msgid "Align the start of functions."
 msgstr "impliciete declaratie van functie %qs"
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:1002
+#: common.opt:1006
 #, fuzzy, no-c-format
 msgid "Align the start of loops."
 msgstr "impliciete declaratie van functie %qs"
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
 # of "preprocessing" behouden?
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable static analysis pass."
 msgstr "Schakel traditionele voorverwerking in"
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1111
+#: common.opt:1115
 #, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr ""
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr ""
 
-#: common.opt:1119
+#: common.opt:1123
 #, fuzzy, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: common.opt:1123
+#: common.opt:1127
 #, fuzzy, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr ""
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr ""
 
 # of "preprocessing" behouden?
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 msgid "Enable code hoisting."
 msgstr "Schakel traditionele voorverwerking in"
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst worden."
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "lege declaratie"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr "lege declaratie"
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, fuzzy, no-c-format
 msgid "Place data items into their own section."
 msgstr "keer vermeld voor elke functie waarin hij staat.)"
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr ""
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, fuzzy, no-c-format
 msgid "Dump optimization passes."
 msgstr "meegegeven opties: "
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1471
 #, fuzzy, no-c-format
 msgid "Perform early inlining."
 msgstr "recursieve inlining"
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, fuzzy, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1558
 #, fuzzy, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr "lege declaratie"
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 msgid "Place each function into its own section."
 msgstr "keer vermeld voor elke functie waarin hij staat.)"
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, fuzzy, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr "lege declaratie"
 
-#: common.opt:1633
+#: common.opt:1637
 #, fuzzy, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr "lege declaratie"
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr "lege declaratie"
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, fuzzy, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr "lege declaratie"
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 msgid "Process #ident directives."
 msgstr "ongeldig preprocessing-commando"
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1711
+#: common.opt:1715
 #, fuzzy, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 msgid "Do not generate .size directives."
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: common.opt:1747
+#: common.opt:1751
 #, fuzzy, no-c-format
 msgid "Perform indirect inlining."
 msgstr "recursieve inlining"
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, fuzzy, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: common.opt:1761
+#: common.opt:1765
 #, fuzzy, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: common.opt:1765
+#: common.opt:1769
 #, fuzzy, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 msgid "Discover pure and const functions."
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr ""
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1941
+#: common.opt:1945
 #, fuzzy, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:1949
+#: common.opt:1953
 #, fuzzy, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: common.opt:1953
+#: common.opt:1957
 #, fuzzy, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, fuzzy, no-c-format
 msgid "Enable link-time optimization."
 msgstr "lege declaratie"
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "lege declaratie"
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr "lege declaratie"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "lege declaratie"
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "lege declaratie"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:2124
+#: common.opt:2128
 #, fuzzy, no-c-format
 msgid "Perform partial inlining."
 msgstr "recursieve inlining"
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:2148
+#: common.opt:2152
 #, fuzzy, no-c-format
 msgid "Perform loop peeling."
 msgstr "recursieve inlining"
 
-#: common.opt:2152
+#: common.opt:2156
 #, fuzzy, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2164
 #, fuzzy, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:2164
+#: common.opt:2168
 #, fuzzy, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:2168
+#: common.opt:2172
 #, fuzzy, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:2172
+#: common.opt:2176
 #, fuzzy, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, fuzzy, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr "lege declaratie"
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2506
+#: common.opt:2510
 #, fuzzy, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr "lege declaratie"
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2514
+#: common.opt:2518
 #, fuzzy, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "lege declaratie"
 
-#: common.opt:2522
+#: common.opt:2526
 #, fuzzy, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, fuzzy, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr "floating-point fout bij het uitschrijven van een constante"
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, fuzzy, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "lege declaratie"
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "ISO C verbiedt geneste functies"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr "ISO C verbiedt geneste functies"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "ISO C verbiedt geneste functies"
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr ""
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2675
+#: common.opt:2679
 #, fuzzy, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "floating-point constante buiten bereik"
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2742
+#: common.opt:2746
 #, fuzzy, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2750
+#: common.opt:2754
 #, fuzzy, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "lege declaratie"
 
-#: common.opt:2758
+#: common.opt:2762
 #, fuzzy, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2766
+#: common.opt:2770
 #, fuzzy, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 msgid "Enable dominator optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:2782
+#: common.opt:2786
 #, fuzzy, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 msgid "Enable dead store elimination."
 msgstr "lege declaratie"
 
-#: common.opt:2790
+#: common.opt:2794
 #, fuzzy, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2794
+#: common.opt:2798
 #, fuzzy, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2819
+#: common.opt:2823
 #, fuzzy, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "lege declaratie"
 
-#: common.opt:2823
+#: common.opt:2827
 #, fuzzy, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr "lege declaratie"
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2859
+#: common.opt:2863
 #, fuzzy, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr "lege declaratie"
 
-#: common.opt:2867
+#: common.opt:2871
 #, fuzzy, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2887
+#: common.opt:2891
 #, fuzzy, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2940
+#: common.opt:2944
 #, fuzzy, no-c-format
 msgid "Perform loop unswitching."
 msgstr "recursieve inlining"
 
-#: common.opt:2944
+#: common.opt:2948
 #, fuzzy, no-c-format
 msgid "Perform loop splitting."
 msgstr "recursieve inlining"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, fuzzy, no-c-format
 msgid "Perform variable tracking."
 msgstr "recursieve inlining"
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:3003
+#: common.opt:3007
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:3015
+#: common.opt:3019
 #, fuzzy, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "lege declaratie"
 
-#: common.opt:3019
+#: common.opt:3023
 #, fuzzy, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:3050
+#: common.opt:3054
 #, fuzzy, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "lege declaratie"
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3115
+#: common.opt:3119
 #, fuzzy, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "ongeldig register in de move-instructie"
 
-#: common.opt:3119
+#: common.opt:3123
 #, fuzzy, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3127
+#: common.opt:3131
 #, fuzzy, no-c-format
 #| msgid "Arithmetic overflow at %L"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Arithmetische overflow op %L"
 
-#: common.opt:3131
+#: common.opt:3135
 #, fuzzy, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr ""
 
-#: common.opt:3139
+#: common.opt:3143
 #, fuzzy, no-c-format
 msgid "Generate debug information in default format."
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3191
+#: common.opt:3195
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, fuzzy, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, fuzzy, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3280
+#: common.opt:3284
 #, fuzzy, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3320
+#: common.opt:3324
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr ""
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 msgid "Enable function profiling."
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: common.opt:3334
+#: common.opt:3338
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "Zoals -pedantic, maar beschouw problemen als fouten"
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
 # kan beter
-#: common.opt:3406
+#: common.opt:3410
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Schakel uitgebreide boodschappen in"
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3414
+#: common.opt:3418
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Onderdruk waarschuwingen"
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr ""
 
-#: common.opt:3472
+#: common.opt:3476
 #, fuzzy, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:3476
+#: common.opt:3480
 #, fuzzy, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:3480
+#: common.opt:3484
 #, fuzzy, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19322,1105 +19322,1115 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr ""
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr ""
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr ""
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr ""
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr ""
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "array subscript is geen integer"
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr ""
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr ""
 
-#: params.opt:274
+#: params.opt:279
 #, no-c-format
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr ""
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr ""
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr ""
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr ""
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr ""
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr ""
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr ""
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr ""
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr ""
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr ""
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr ""
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr ""
 
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "bestand %qs is te groot"
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr ""
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr ""
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr ""
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr ""
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr ""
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr ""
 
-#: params.opt:414
+#: params.opt:419
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr ""
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr ""
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr ""
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr ""
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr ""
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr ""
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr ""
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr ""
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr ""
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr ""
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr ""
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr ""
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr ""
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr ""
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr ""
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr ""
 
-#: params.opt:518
+#: params.opt:523
 #, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr ""
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr ""
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr ""
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr ""
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr ""
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr ""
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr ""
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr ""
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr ""
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr ""
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr ""
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr ""
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr ""
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr ""
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr ""
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr ""
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr ""
 
-#: params.opt:602
+#: params.opt:607
 #, fuzzy, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr ""
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr ""
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr ""
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr ""
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr ""
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr ""
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr ""
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr ""
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr ""
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr ""
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr ""
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr ""
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr ""
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr ""
 
-#: params.opt:722
+#: params.opt:727
 #, fuzzy, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr ""
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr ""
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr ""
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr ""
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr ""
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr ""
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr ""
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr ""
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr ""
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr ""
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr ""
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr ""
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr ""
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr ""
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr ""
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr ""
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr ""
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr ""
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr ""
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr ""
 
-#: params.opt:964
+#: params.opt:982
 #, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr ""
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr ""
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr ""
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr ""
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "impliciete declaratie van functie %qs"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr ""
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr ""
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr ""
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20456,7 +20466,7 @@ msgid "expected boolean type"
 msgstr "ongeldige operand van %s"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "ongeldige operand van %s"
@@ -20530,7 +20540,7 @@ msgstr "geen argumenten"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, fuzzy, gcc-internal-format
 msgid "too many arguments"
 msgstr "te veel argumenten voor formaat"
@@ -20921,7 +20931,7 @@ msgstr "attribuut %qE botst met attribuut %s"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "eerdere declaratie van %qs"
@@ -20976,7 +20986,7 @@ msgstr ""
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -21005,20 +21015,20 @@ msgstr ""
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21029,8 +21039,8 @@ msgstr "attribuut %qE wordt genegeerd"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "eerdere declaratie van %qs"
@@ -21040,59 +21050,59 @@ msgstr "eerdere declaratie van %qs"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr ""
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr ""
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr ""
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr ""
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "%Jgeneste functie %qD gedeclareerd maar niet gedefinieerd"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, fuzzy, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr ""
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, fuzzy, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -21196,7 +21206,7 @@ msgstr "ongeldige beginwaarde"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "offset buiten de grenzen van een constante string"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -21221,599 +21231,599 @@ msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "ongeldig derde argument voor __builtin_prefetch; zal nul gebruiken"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 msgid "source object declared here"
 msgstr "%Jeerder hier gebruikt"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 msgid "destination object declared here"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 msgid "destination object allocated here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "ongeldige waarde voor %%C"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, fuzzy, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "ISO C verbiedt geneste functies"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "onbekende machine-modus %qs"
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to %qs"
 msgid "non-integer argument 1 to %qs"
 msgstr "ontbrekend argument bij %qs"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr "-pipe wordt niet ondersteund"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to %qs"
 msgid "illegal argument 0 to %qs"
@@ -21821,123 +21831,123 @@ msgstr "ontbrekend argument bij %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "tweede argument van %<__builtin_longjmp%> moet 1 zijn"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "doelformaat ondersteunt geen oneindige waarde"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> gebruikt in functie met vaste argumenten"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 msgid "returned from %qD"
 msgstr "eerdere grant voor %qs"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 msgid "returned from %qT"
 msgstr "eerdere grant voor %qs"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 msgid "obtained here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 msgid "assigned here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -22706,304 +22716,304 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, fuzzy, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "beginwaarde ontbreekt"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "beginwaarde-element is niet constant"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "case-selector niet compatibel met label"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "dit is een eerdere declaratie"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "ongeldige beginwaarde"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of register to a different size"
 msgid "origin points to a different parent"
 msgstr "conversie van register naar een andere grootte"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "het argument van '-%s' ontbreekt"
@@ -23087,12 +23097,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -23162,7 +23172,7 @@ msgstr "grootte van teruggeefwaarde van %qs is %u bytes"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "grootte van teruggeefwaarde van %qs is %u bytes"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr ""
@@ -23577,12 +23587,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -23602,7 +23612,7 @@ msgstr ""
 msgid "internal consistency failure"
 msgstr ""
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -23732,42 +23742,42 @@ msgstr "kan bestand '%s' niet openen"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "grote integer impliciet afgekapt naar 'unsigned' type"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vergelijking is altijd %d vanwege breedte van bit-veld"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23782,7 +23792,7 @@ msgstr "variabele %qs is te groot"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "variabele %qs is te groot"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -24408,7 +24418,7 @@ msgstr "herhaald lid %qs"
 msgid "function may return address of local variable"
 msgstr "functie geeft adres van lokale variabele terug"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "functie geeft adres van lokale variabele terug"
@@ -24776,62 +24786,62 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "formaatstring niet beëindigd"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 msgid "%Guse of %<alloca%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 msgid "%Gargument to variable-length array may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 #| msgid "argument to %qs is too large (max. %d)"
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "argument van %qs is te groot (max. %d)"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 msgid "%Gargument to variable-length array is too large"
 msgstr "variabele %qs is te groot"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 #| msgid "argument to %qs is too large (max. %d)"
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "argument van %qs is te groot (max. %d)"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 msgid "%Gargument to variable-length array is zero"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 msgid "%Gargument to %<alloca%> is zero"
 msgstr ""
 
@@ -24945,7 +24955,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -24971,11 +24981,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -25053,309 +25063,309 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, gcc-internal-format
 msgid "enclosing region"
 msgstr ""
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D not declared in class"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%q#D is niet gedeclareerd in class"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "#error %s"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr "ongeldige operand van %s"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "ongeldige operand van %s"
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "herhaalde label-declaratie %qs"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT wordt tot %qT gepromoveerd indien het via %<...%> wordt doorgegeven"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(dus U zou %qT, en niet %qT, moeten doorgeven aan %<va_arg%>)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "indien deze code bereikt wordt, zal het programma afgebroken worden"
@@ -25806,22 +25816,22 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, fuzzy, gcc-internal-format
 msgid "for %qD"
 msgstr "%s voor %qs"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr ""
@@ -25841,12 +25851,12 @@ msgstr "'B' operand is geen constante"
 msgid "unable to find a register to spill"
 msgstr ""
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr ""
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
@@ -26563,13 +26573,13 @@ msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 msgid "unrecognized argument in option %qs"
 msgstr "niet-herkend argument bij optie %qs"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
@@ -26699,7 +26709,7 @@ msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
@@ -27208,22 +27218,22 @@ msgstr ""
 msgid "output operand %d must use %<&%> constraint"
 msgstr "operand %<%d%> is geen register"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr ""
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr ""
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr ""
@@ -27285,12 +27295,12 @@ msgstr ""
 msgid "impossible register constraint in %<asm%>"
 msgstr ""
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "%s ondersteunt %s niet"
 
-#: reload.c:3720
+#: reload.c:3726
 #, fuzzy, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "numerieke constante zonder cijfers"
@@ -27320,52 +27330,52 @@ msgstr ""
 msgid "output operand is constant in %<asm%>"
 msgstr "operand %<%d%> is geen register"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:900
+#: rtl.c:910
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr ""
@@ -27410,22 +27420,22 @@ msgstr ""
 msgid "invalid punctuation %qc in constraint"
 msgstr "twee %<u%>s in integerconstante"
 
-#: stmt.c:430
+#: stmt.c:431
 #, fuzzy, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "numerieke constante zonder cijfers"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "herhaald lid %qs"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr ""
 
-#: stmt.c:650
+#: stmt.c:651
 #, fuzzy, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "ongeldige operand van %s"
@@ -28108,9 +28118,9 @@ msgstr "ongeldige operand voor %%R"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in shift expression"
 msgid "type mismatch in %qs"
@@ -28148,7 +28158,7 @@ msgstr "ongeldige shift-operand"
 msgid "invalid clique in %qs"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
@@ -28359,368 +28369,368 @@ msgstr "ongeldige operanden voor binaire %s-operator"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "ongeldige waarheidsexpressie"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "ongeldige registernaam voor %qs"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "niet-ondersteunde versie"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid position or size in %qs"
 msgstr "%qs is geen geldige pointer-modus"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qs is geen iterator"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "ongeldige beginwaarde"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "ongeldige operand voor %%R"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "ongeldig vector-type voor attribuut %qs"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, fuzzy, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "default-label niet in een switch-statement"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, fuzzy, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "ongeldige operand in de instructie"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, fuzzy, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "Ongeldig token in expressie"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "ongeldig adres"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "beginwaarde ontbreekt"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "ongeldige waarde voor %%C"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "incompatibel type voor argument %d van %qE"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr ""
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "local declaration from a different function"
 msgstr "impliciete declaratie van functie %qE"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "-pipe wordt niet ondersteund"
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "beginwaarde ontbreekt"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, fuzzy, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> functie keert terug"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, fuzzy, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "%Hde returnwaarde van een functie, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
@@ -29816,7 +29826,7 @@ msgstr ""
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "het gevraagde alignment voor %s is groter dan het geïmplementeerde aligment van %d."
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
@@ -29980,7 +29990,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 msgid "unsupported record layout"
 msgstr "niet-ondersteunde versie"
@@ -30628,7 +30638,7 @@ msgstr "attribuut %qE volgt na %qE"
 msgid "type was previously declared %qE"
 msgstr "eerdere declaratie van %qs"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
@@ -30648,7 +30658,7 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "%qE argument is not a function"
 msgstr "het argument van %<cleanup%> is geen functie"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -31091,12 +31101,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gebruik liefst haakjes rond toewijzingen die als waarheid gebruikt worden"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -31259,13 +31269,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "argumenten aan macro %qs gegeven"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "te weinig argumenten voor functie %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "te veel argumenten voor functie %qE"
@@ -32215,7 +32225,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionele C verwerpt het aaneenplakken van stringconstantes"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -32265,7 +32275,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ongeldig type voor iteratie-variabele %qE"
@@ -32281,17 +32291,17 @@ msgstr "ongeldig type voor iteratie-variabele %qE"
 msgid "%qE is not initialized"
 msgstr "parameter %qD krijgt beginwaarde"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "toewijzingsonderdrukking"
@@ -32301,7 +32311,7 @@ msgstr "toewijzingsonderdrukking"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Ongeldig token in expressie"
@@ -32368,7 +32378,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -32945,8 +32955,8 @@ msgstr ""
 msgid "wrong type argument to %s"
 msgstr "argument van verkeerd type voor abs"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow in constante expressie"
@@ -33439,17 +33449,17 @@ msgstr "kan functie %<main%> niet inline maken"
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "%s van alleen-lezen locatie"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "%s van alleen-lezen locatie"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "%s van alleen-lezen locatie"
@@ -33629,8 +33639,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
@@ -33712,91 +33722,91 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "cast laat qualifiers van doeltype van pointer vallen"
 msgstr[1] "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "doorgeven van argument %d van %qs"
 msgstr[1] "doorgeven van argument %d van %qs"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr "%Jeerder hier gebruikt"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr ""
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
 msgstr "%Jeerder hier gebruikt"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
 msgstr "%Jeerder hier gebruikt"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr ""
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr "%Jeerder hier gebruikt"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qD with attribute noinline"
 msgid "previously declared as %s with %u variable bound"
@@ -33804,68 +33814,68 @@ msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "eerdere declaratie van %qD met attribuut 'noinline'"
 msgstr[1] "eerdere declaratie van %qD met attribuut 'noinline'"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr ""
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr "%Jeerder hier gebruikt"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "eerdere declaratie van %qs"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr "eerdere declaratie van %qs"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -33880,7 +33890,7 @@ msgstr "-fPIC is niet geldig met -mcoff"
 msgid "too many input files"
 msgstr "te veel invoerbestanden"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "slechte waarde (%s) voor optie -mcpu"
@@ -33912,15 +33922,15 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -34080,62 +34090,62 @@ msgstr "-mregparm=%d ligt niet tussen 0 en %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "case-selector niet compatibel met label"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "opslaggrootte van %qs is onbekend"
@@ -34300,90 +34310,90 @@ msgstr "optie -mcpu=%s geeft conflicten met optie -mtune="
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "kon tijdelijk antwoordbestand %s niet openen"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr ""
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr ""
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "kon tijdelijk antwoordbestand %s niet openen"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 #| msgid "-pg not supported on this platform"
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "-pg wordt op dit platform niet ondersteund"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr ""
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr ""
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr ""
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr ""
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr ""
 
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr ""
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34522,371 +34532,371 @@ msgstr "%<#pragma GCC optimize%> is geen string of getal"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "misvormde #pragma pack"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "ongeldige operand van %s"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "case-selector niet compatibel met label"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "case-selector niet compatibel met label"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, fuzzy, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "ongeldige constraints voor operand"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "ongeldige waarde voor %%h"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Ongeldige optie voor floating-point emulatie: -mfpe-%s"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "onbekende spec-functie '%s'"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s;"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "ongeldig type-argument %qs"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument in %<__builtin_args_info%>"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "argument ontbreekt in %<__builtin_args_info%>"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "beginwaarde ontbreekt"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "optie -mcpu=%s geeft conflicten met optie -mtune="
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "ondersteunt geen multilib"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "misvormde #pragma pack"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "misvormde #pragma weak"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "operandnummer buiten bereik"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "operandnummer buiten bereik"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "niet-ondersteunde versie"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "De -shared optie wordt op het ogenblik niet ondersteund voor VAX ELF."
@@ -34949,7 +34959,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "slechte waarde %qs voor -mmeroy-latency"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -35070,18 +35080,18 @@ msgstr "het argument van %<asm%> is geen constante string"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "het argument van %<asm%> is geen constante string"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -35518,231 +35528,236 @@ msgstr "doel-CPU ondersteunt geen interworking"
 msgid "target CPU does not support unaligned accesses"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "optie -mcpu=%s geeft conflicten met optie -mtune="
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check is niet compatibel met -mno-apcs-frame"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic en -mapcs-reent zijn incompatibel"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS reentrant code wordt niet ondersteund.  Genegeerd"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "Grens voor structure-grootte kan enkel op 8 of 32 insgesteld worden"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "Grens voor structure-grootte kan enkel op 8 of 32 insgesteld worden"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "case-selector niet compatibel met label"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "kan %qs niet nabootsen"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable en -msdata=%s zijn incompatibel"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "attribuut %qE wordt genegeerd voor non-class-types"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applies only to initialized variables with external linkage"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "attribuut %qE is enkel van toepassing op geïnitialiseerde variabelen die extern gelinkt zijn"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "ongeldige operand van %s"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ongeldig type-argument %qs"
@@ -35750,24 +35765,24 @@ msgstr "ongeldig type-argument %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ongeldig vector-type voor attribuut %qs"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "rommel aan einde van #pragma %s"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
@@ -35846,17 +35861,17 @@ msgstr "-pipe wordt niet ondersteund"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G en -static sluiten elkaar uit"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "functie %qs kan geen waarde teruggeven"
@@ -36613,133 +36628,133 @@ msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 msgid "parameter to builtin not valid: %s"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
@@ -36759,527 +36774,527 @@ msgstr "-pipe wordt niet ondersteund"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "Bestandsnaam voor uitvoer twee keer opgegeven"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d ligt niet tussen 0 en %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, fuzzy, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, fuzzy, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument van attribuut %qE is groter dan %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, fuzzy, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, fuzzy, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, fuzzy, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, fuzzy, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
 # XXX FIXME, ERROR:  s/none /non-/
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "attribuut %qE is gebruikt voor non-class-methode"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attribuut %qE vereist een string-constante als argument"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "de '-%c' moet een argument hebben"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
@@ -37733,7 +37748,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -38810,57 +38825,57 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "het argument van %<asm%> is geen constante string"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
@@ -39376,241 +39391,241 @@ msgstr "%<__thread%> samen met %<register%> gebruikt"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "Ongeldige modus voor gen_tst_reg"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mapcs-stack-check is niet compatibel met -mno-apcs-frame"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "SH2a does not support little-endian"
 msgid "%qs is not supported on little endian systems"
 msgstr "SH2a ondersteunt little-endian niet"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s ondersteunt %s niet"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
-msgstr ""
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+msgid "use of decimal floating-point types in AltiVec types is invalid"
+msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ongeldig gebruik van '%%%c'"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -39795,7 +39810,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -39865,203 +39880,208 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "argument %d is alleen-lezen"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "slechte conditiecode"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, fuzzy, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argument van %qs moet een niet-negatieve integer zijn"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argument van %qs is te groot (max. %d)"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
@@ -40406,17 +40426,22 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr "ongeldig adres"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
@@ -40487,8 +40512,8 @@ msgstr "attribuut %qs is enkel van toepassing op array-types"
 msgid "could not read the BRIG file"
 msgstr "kan niet schrijven naar antwoordbestand %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-waarde niet genegeerd zoals het hoort"
@@ -40549,7 +40574,7 @@ msgstr "label %qs gedefinieerd maar niet gebruikt"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
@@ -40777,7 +40802,7 @@ msgstr "%Jdeclaratie van %qD verbergt een eerdere niet-variabele"
 msgid "declaration of %qD shadows a parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
@@ -40787,7 +40812,7 @@ msgstr "de declaratie van %qs verbergt een parameter"
 msgid "declaration of %qD shadows a previous local"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "%Jde verborgen declaratie is hier"
@@ -40797,217 +40822,217 @@ msgstr "%Jde verborgen declaratie is hier"
 msgid "nested extern declaration of %qD"
 msgstr "geneste declaratie van %qD als extern"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "impliciete declaratie van functie %qE"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "impliciete declaratie van functie %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "onverenigbare impliciete declaratie van ingebouwde functie %qD"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "onverenigbare impliciete declaratie van functie %qD"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE is hier niet gedeclareerd (niet in een functie)"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE is hier niet gedeclareerd (niet in een functie)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, fuzzy, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Elke niet-gedeclareerde naam wordt slechts één"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, fuzzy, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "naar label %s gerefereerd buiten enige functie"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, fuzzy, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, fuzzy, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, fuzzy, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, fuzzy, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "overflow in constante expressie"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, fuzzy, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "herhaalde label-declaratie %qs"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "herhaald label %qs"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, fuzzy, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "overflow in constante expressie"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "naamloze struct/union die geen instanties definieert"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "declaratie declareert niets"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "nutteloze typenaam in lege declaratie"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> bij lege declaratie"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%> bij lege declaratie"
 
 # betere vertaling voor "file-scope"?
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> in lege declaratie op bestandsniveau"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
 # vertaling voor "storage class specifier"?
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "nutteloze storage class specifier in lege declaratie"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "nutteloze typenaam in lege declaratie"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "nutteloze %<__thread%> in lege declaratie"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr "lege declaratie"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "lege declaratie"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 ondersteunt geen %<static%> of type-qualificaties in declaratoren van parameter arrays"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 ondersteunt geen %<[*]%> declaratoren van arrays"
@@ -41015,29 +41040,29 @@ msgstr "ISO C90 ondersteunt geen %<[*]%> declaratoren van arrays"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, fuzzy, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%J%qD is meestal een functie"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD krijgt beginwaarde (gebruik beter __typeof__)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "functie %qD krijgt beginwaarde alsof het een variabele is"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parameter %qD krijgt beginwaarde"
@@ -41046,269 +41071,269 @@ msgstr "parameter %qD krijgt beginwaarde"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "variabele %qD heeft beginwaarde, maar een onvolledig type"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr "%J%<noinline%> attribuut gegeven aan ingebouwde functie %qD"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, fuzzy, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "%Jarray %qD heeft grootte die negatief of nul is"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "opslaggrootte van %qs is niet constant"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "%Jasm-specificatie wordt genegeerd voor niet-static locale variabele %qD"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "een object met een volatile veld kan niet in een register geplaatst worden"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD is invalid in C++"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "ongeïnitialiseerde const %qD is ongeldig in C++"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "bitveld %qs heeft breedte 0"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "cast geeft functie-type op"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "het type van bitveld %qs is een uitbreiding van GCC"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "breedte van %qs overschrijdt zijn type"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 verbiedt array %qs, wiens grootte niet geëvalueerd kan worden"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 verbiedt array %qs, wiens grootte niet geëvalueerd kan worden"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "herhaalde %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "herhaalde %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "herhaalde %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "herhaalde %<restrict%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "conflicterende declaraties van %qs"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "opslagklasse opgegeven voor typenaam"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "declaratie van %qs op bestandsniveau specifieert %<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "declaratie van %qs op bestandsniveau specifieert %<auto%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
@@ -41316,714 +41341,714 @@ msgstr "functie-definitie als %<auto%> gedeclareerd"
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ongeldig gebruik van strcture met flexibel array-lid"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C verbiedt array %qs met grootte 0"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "arraytype heeft onvolledig elementtype"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, fuzzy, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
 # misschien toch houden op type-qualifiers?
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%J onverenigbare typekwalificaties voor %qD"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> toegepast op bitveld"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C verbiedt %<const%> of %<volatile%> functie-types"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, fuzzy, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "kan functie %<main%> niet %<inline%> maken"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "eerder als %<static%> gedeclareerde variabele als %<extern%> geherdeclareerd"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "functie-declaratie is geen prototype"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "%Jparameter %u (%qD) heeft een onvolledig type"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "%Jparameter %u (%qD) heeft %<void%> als type"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> als enige parameter mag niet gekwalificeerd worden"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> moet de enige parameter zijn"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "%Jparameter %qD heeft enkel een voorwaartse declaratie"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "herdefinitie van %<union %s%>"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "geneste herdefinitie van %<union %s%>"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "geneste herdefinitie van %<struct %s%>"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "declaratie declareert niets"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ondersteunt geen naamloze structs/unions"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ondersteunt geen naamloze structs/unions"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, fuzzy, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "%Jherhaald lid %qD"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union heeft geen benoemde leden"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union heeft geen leden"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct heeft geen benoemde leden"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct heeft geen leden"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "%Jflexibel array-lid in union"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "%Jflexibel array-lid in union"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kan niet transparant gemaakt worden"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "geneste herdefinitie van %<enum %qs%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "herdeclaratie van %<enum %qs%>"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "opgegeven modus is te klein voor enumeratiewaarden"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "enumeratiewaarden overschrijden het bereik van de grootste integer"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "overflow in enumeratiewaarden"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "%J%<noinline%> attribuut gegeven aan ingebouwde functie %qD"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "teruggeeftype is onvolledig"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "teruggeeftype krijgt standaardwaarde %<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%Jgeen eerder prototype voor %qD"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%Jgeen eerdere declaratie voor %qD"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder declaratie"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%Jteruggeeftype van %qD is niet %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%J%qD is gewoonlijk een niet-static funtie"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jparameterdeclaraties in oude stijl gebruikt in de definitie van een functie die een prototype heeft"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jtraditionele C verwerpt functiedefinities in de stijl van ISO C"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr ""
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "%Jparameternaam ontbreekt in parameterlijst"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "%Jmeerdere parameters hebben de naam %qD"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%Jtype van %qD krijgt standaardtype %<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "%Jdeclaratie voor parameter %qD maar er is zo geen parameter"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "%Hdeclaratie van prototype"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "gepromoveerd argument %qD komt niet overeen met prototype"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "gepromoveerd argument %qD komt niet overeen met prototype"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parameter %qD krijgt beginwaarde"
@@ -42031,262 +42056,262 @@ msgstr "parameter %qD krijgt beginwaarde"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "initiële declaratie voor %<for%> lus gebruikt buiten C99 modus"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 ondersteunt geen %<[*]%> declaratoren van arrays"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "twee of meer data types opgegeven bij declaratie"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> is te lang voor GCC"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "herhaalde %qs"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
 # is letterlijke vertaling maar klinkt zo vreemd...
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, fuzzy, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qs slaagt er niet in een typedef of ingebouwd type te zijn"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "%s ondersteunt %s niet"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vóór %<static%> gebruikt"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "teller van rechtse shift is negatief"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "teller van rechtse shift is >= breedte van het type"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -42307,7 +42332,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "ongeldige operand van %s"
@@ -42317,7 +42342,7 @@ msgstr "ongeldige operand van %s"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C verbiedt een leeg bronbestand"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr ""
@@ -42353,7 +42378,7 @@ msgid "unknown type name %qE"
 msgstr "onbekende machine-modus %qs"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
@@ -42373,7 +42398,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -42388,7 +42413,7 @@ msgstr "herhaalde definitie %qs"
 msgid "unexpected attribute"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -42428,7 +42453,7 @@ msgstr "%<auto%> in lege declaratie op bestandsniveau"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -42486,7 +42511,7 @@ msgstr "beginwaarde-element is niet constant"
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "pex_init mislukt"
@@ -42531,14 +42556,14 @@ msgstr "argument %d is alleen-lezen"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma aan het einde van enumerator-lijst"
@@ -42623,7 +42648,7 @@ msgstr "top-level declaratie van %qs specifieert %<auto%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to types"
 msgid "%qE attribute does not take any arguments"
@@ -42685,7 +42710,7 @@ msgstr "ISO C90 verbiedt labeldeclaraties"
 msgid "expected %<}%> before %<else%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -42700,7 +42725,7 @@ msgstr "ISO C verbiedt een label aan het einde van een samengesteld statement"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "ongeldige beginwaarde"
@@ -42725,17 +42750,17 @@ msgstr ""
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr ""
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "leeg body in een else-statement"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "leeg body in een else-statement"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -42755,12 +42780,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ongeldig register in de instructie"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -42776,8 +42801,8 @@ msgstr "sentinel ontbreekt in functie-oproep"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "herhaalde case-waarde"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -42804,12 +42829,12 @@ msgstr "ISO C verbiedt het weglaten van de middelste term van een ?: expresie"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -43210,12 +43235,12 @@ msgstr "meerdere opslagklassen in declaratie van %qs"
 msgid "no type or storage class may be specified here,"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "beginwaarde ontbreekt"
@@ -43225,51 +43250,51 @@ msgstr "beginwaarde ontbreekt"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "misvormde #pragma pack(pop[,id])"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -43279,18 +43304,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "misvormde #pragma pack(pop[,id])"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "te veel invoerbestanden"
@@ -43310,53 +43335,53 @@ msgstr "ongeldige operand van %s"
 msgid "%qD is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -43378,108 +43403,108 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "te veel argumenten voor formaat"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "zowel %<long%> als %<void%> opgegeven bij declaratie"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ongeldige const_double operand"
@@ -43489,17 +43514,17 @@ msgstr "ongeldige const_double operand"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -43519,22 +43544,22 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "case-selector niet compatibel met label"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ongeldige const_double operand"
@@ -43549,82 +43574,82 @@ msgstr "ongeldige const_double operand"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "lege declaratie"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ongeldige linker operand van %s"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -43639,7 +43664,7 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "expected function name"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qs is meestal een functie"
@@ -43649,27 +43674,27 @@ msgstr "%qs is meestal een functie"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 msgid "expected %<allocator%>"
 msgstr "ongeldige operand van %s"
@@ -43679,82 +43704,82 @@ msgstr "ongeldige operand van %s"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -43764,32 +43789,32 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "herdeclaratie van %qs"
@@ -43799,73 +43824,73 @@ msgstr "herdeclaratie van %qs"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> als enige parameter mag niet gekwalificeerd worden"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -43880,57 +43905,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "ongeldige operand van %s"
@@ -43940,12 +43965,12 @@ msgstr "ongeldige operand van %s"
 msgid "variant %qD is not a function"
 msgstr "%qs is meestal een functie"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43955,32 +43980,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -44035,42 +44060,42 @@ msgstr "ongeldige operand van %s"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -44085,27 +44110,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -44115,7 +44140,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -44130,7 +44155,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "%qs heeft een onvolledig type"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ongeldig gebruik van een void-expressie"
@@ -44172,127 +44197,127 @@ msgstr "attribuut %qE kan niet opgegeven worden voor lokale variabelen"
 msgid "function types not truly compatible in ISO C"
 msgstr "functie-types zijn niet echt compatibel in ISO C"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr ""
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr ""
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr ""
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, fuzzy, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "types zijn niet helemaal compatibel"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "types zijn niet helemaal compatibel"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, fuzzy, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "types zijn niet helemaal compatibel"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, fuzzy, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, fuzzy, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, fuzzy, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "vraag naar lid %qs in iets dat geen structure of union is"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, fuzzy, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, fuzzy, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscript is geen integer"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, fuzzy, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "doorgeven van argument %d van pointer naar functie"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C verbiedt het gebruik van subscripts bij een %<register%> array"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C90 verbiedt het gebruik van subscripts bij een array die geen lvalue is"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "opgeroepen object is geen functie"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "opgeroepen object is geen functie"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "opgeroepen object is geen functie"
@@ -44300,1627 +44325,1627 @@ msgstr "opgeroepen object is geen functie"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr ""
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, fuzzy, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "het type van formele parameter %d is onvolledig"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "%s als integer in plaats van floating-point ten gevolge van een prototype"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "%s als floating-point in plaats van complex ten gevolge van een prototype"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "%s als complex in plaats van floating-point ten gevolge van een prototype"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "%s als floating-point in plaats van integer ten gevolge van een prototype"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "%s als complex in plaats van floating-point ten gevolge van een prototype"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "%s als floating-point in plaats van complex ten gevolge van een prototype"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "%s als %<float%> in plaats van %<double%> ten gevolge van een prototype"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "%s als floating-point in plaats van complex ten gevolge van een prototype"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "%s met andere breedte ten gevolge van prototype"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "%s als unsigned ten gevolge van prototype"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "%s als signed ten gevolge van prototype"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "te veel argumenten voor functie %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "te veel argumenten voor functie %qE"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "vergelijking tussen pointer en integer"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "vergelijking tussen %qT en %qT"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, fuzzy, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "rekensom met pointer naar onvolledig type"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C ondersteunt het %<%c%> formaat niet"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "argument van verkeerd type voor abs"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "argument van verkeerd type voor unair uitroepingsteken"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C ondersteunt het %<%c%> formaat niet"
 
 # Wat is beter: 'incrementeren', 'incrementering', of 'increment'?
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "argument van verkeerd type voor incrementeren"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "argument van verkeerd type voor decrementeren"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "adres van registervariabele %qs gevraagd"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, fuzzy, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "globale registervariabele %qs gebruikt in geneste functie"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, fuzzy, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, fuzzy, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, fuzzy, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "adres van registervariabele %qs gevraagd"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, fuzzy, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C verbiedt voorwaardelijke expressies met maar één void-zijde"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, fuzzy, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "pointertypes in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "pointertypes in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C verbiedt voorwaardelijke expressies tussen %<void *%> en een functiepointer"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "pointertypes in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "pointertypes in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen (pointer/integer)"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, fuzzy, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 #, fuzzy
 msgid "cast adds %q#v qualifier to function type"
 msgstr "cast geeft functie-type op"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 #, fuzzy
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "cast geeft array-type op"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "cast geeft functie-type op"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C verbiedt het casten van een niet-scalair naar hetzelfde type"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C verbiedt casts naar een union-type"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "cast naar union-type van een type dat geen deel uitmaakt van de union"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "cast verhoogt het benodigde alignment van het doeltype"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "cast van pointer naar integer met andere grootte"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast naar pointer van integer met andere grootte"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C verbiedt een vergelijking van %<void *%> met een functie-pointer"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C verbiedt een vergelijking van %<void *%> met een functie-pointer"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, fuzzy, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "toewijzingsonderdrukking"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, fuzzy, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(dicht bij initialisatie van %qs)"
 
 # moet beter kunnen - "... waar haakjes rond staan" klinkt ook al niet geweldig
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "array heeft stringconstante tussen haakjes als beginwaarde"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, fuzzy, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, fuzzy, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "%s maakt gekwalificeerde functiepointer van een niet gekwalificeerde"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 #, fuzzy
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "%s maakt gekwalificeerde functiepointer van een niet gekwalificeerde"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "%s maakt gekwalificeerde functiepointer van een niet gekwalificeerde"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 #, fuzzy
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "%s maakt gekwalificeerde functiepointer van een niet gekwalificeerde"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 #, fuzzy
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 #, fuzzy
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, fuzzy, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C verbiedt conversie van argumenten naar union type"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, fuzzy, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, fuzzy, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "cast van pointer naar integer met andere grootte"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "%s als complex in plaats van floating-point ten gevolge van een prototype"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr ""
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C verbiedt %s tussen functiepointer en %<void *%>"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C verbiedt %s tussen functiepointer en %<void *%>"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C verbiedt %s tussen functiepointer en %<void *%>"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C verbiedt %s tussen functiepointer en %<void *%>"
 
 # 'signedness' = 'signed-heid'?
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
 # 'signedness' = 'signed-heid'?
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
 # 'signedness' = 'signed-heid'?
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
 # 'signedness' = 'signed-heid'?
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "toewijzing vanuit incompatibel pointertype"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "initialisatie vanuit incompatibel pointertype"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "initialisatie vanuit incompatibel pointertype"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "%s maakt integer van pointer zonder een cast"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "%s maakt integer van pointer zonder een cast"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "%s maakt integer van pointer zonder een cast"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "%s maakt integer van pointer zonder een cast"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "incompatibel type voor argument %d van %qE"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisatie van flexibel array-lid"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "array van ongeschikt type heeft stringconstante als beginwaarde"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "array krijgt niet-constante array-expressie als beginwaarde"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "beginwaarde-element kan niet berekend worden tijdens het laden"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "ongeldige beginwaarde"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "extra accolade-groep aan einde van beginwaarde"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisatie van flexibel array-lid in een geneste context"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "lege scalaire beginwaarde"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "extra elementen in scalaire beginwaarde"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
 # of gewoon "veldnaam niet in beginwaarde van record of union"?
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "veldnaam in beginwaarde van iets anders dan record of union"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "array-index in beginwaarde is niet van een integer type"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "array-index in beginwaarde is niet van een integer type"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "niet-constante array-index in beginwaarde"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "array-index in beginwaarde overschrijdt de grenzen van de array"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "leeg indexbereik in beginwaarde"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "array-indexbereik in beginwaarde overschrijdt de grenzen van de array"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "geïnitialiseerd veld met neveneffecten wordt overschreven"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "geïnitialiseerd veld wordt overschreven"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "overtollige elementen in beginwaarde van char array"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "overtollige elementen in beginwaarde van struct"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "niet-statische initialisatie van flexibel array-lid"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "overtollige elementen in beginwaarde van array"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "overtollige elementen in beginwaarde van vector"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "overtollige elementen in beginwaarde van scalair"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C verbiedt %<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, fuzzy, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, fuzzy, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, fuzzy, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "functie geeft adres van lokale variabele terug"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-waarde is geen integer"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, fuzzy, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "%<long%> switch-expressie wordt in ISO C niet naar %<int%> geconverteerd"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, fuzzy, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, fuzzy, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "default-label niet in een switch-statement"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-statement niet in een lus"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "statement zonder effect"
 
 # vertaling voor 'statement'?
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, fuzzy, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C verbiedt een vergelijking van %<void *%> met een functie-pointer"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "vergelijking tussen pointer en integer"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "vergelijking van volledige en onvolledige pointers"
 
 # 'ordered' -> 'bevolen' of 'geordend'? Waarschijnlijk het laatste.
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C verbiedt geordende vergelijkingen tussen pointers naar functies"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "geordende vergelijking van pointer met null-pointer"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordende vergelijking van pointer met integer nul"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, fuzzy, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "waarde van array-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, fuzzy, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "waarde van struct-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, fuzzy, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "waarde van union-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, fuzzy, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "waarde van struct-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "ongeldige operand van %s"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qs is meestal een functie"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "grootte van %qs is %u bytes"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, fuzzy, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, fuzzy, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qs is geen static veld"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
 # Of misschien beter "... niet van het %<va_list%> type"?
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "het eerste argument van %<va_arg%> is geen %<va_list%>"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -46133,7 +46158,7 @@ msgstr "ongeldige registernaam voor %qs"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -46245,674 +46270,679 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "conversie naar niet-scalair type gevraagd"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ verbiedt het weglaten van de middelste term van een ?: expresie"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "%Jteruggeeftype van %qD is niet %<int%>"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "vergelijking tussen %q#T en %q#T"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "impliciete declaratie van functie %qE"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%s is niet addresseerbaar"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "ongeldige registernaam voor %qs"
+
+#: cp/call.c:7911
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "kan oproep van %qs niet inline maken"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "herhaald lid %qs"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is too large"
 msgid "; use assignment instead"
 msgstr "gevraagd alignment is te groot"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "dubbele beginwaarde"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "herhaald lid %qs"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "dubbele beginwaarde"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, fuzzy, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ongeldige registernaam voor %qs"
@@ -46937,1129 +46967,1129 @@ msgstr ""
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr ""
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, fuzzy, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, fuzzy, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "%s voor %qs"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bitveld %qs heeft breedte 0"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "breedte van %qs overschrijdt zijn type"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, fuzzy, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "%qs is geen iterator"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, fuzzy, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%s heeft geen benoemde leden"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "geen beginwaarde voor variant-veld %qs"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%qs is geen iterator"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "omvang van array %qs is te groot"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ongeldig gebruik van strcture met flexibel array-lid"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jflexibel array-lid in overigens lege struct"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jflexibel array-lid in overigens lege struct"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "taal-string %<\"%E\"%> wordt niet herkend"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "herhaald lid %qs"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "ongeldige naam %qs"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, fuzzy, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, fuzzy, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%qs is geen iterator"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%J%qD is gewoonlijk een niet-static funtie"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 msgid "allocation performed here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "array subscript is geen integer"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "array subscript is geen integer"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%qs is geen iterator"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 #| msgid "Empty array constructor at %C is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "ongeldige beginwaarde"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "functie kan niet inline gemaakt worden"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "niet-constante array-index in beginwaarde"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "onverwachte operand"
@@ -48070,52 +48100,52 @@ msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qs is geen iterator"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "evaluating %qs"
@@ -48161,7 +48191,7 @@ msgstr "ongeldige registernaam voor %qs"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "kan niet derefereren, is geen pointer."
@@ -48546,7 +48576,7 @@ msgstr "eerdere declaratie van %qs"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "eerdere declaratie van %qs"
@@ -48677,8 +48707,8 @@ msgstr "eerdere declaratie van %qs"
 msgid "%q#D previously defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%qs tevoren hier gedefinieerd"
@@ -48713,52 +48743,52 @@ msgstr "argumenten aan macro %qs gegeven"
 msgid "previous specification in %q#D here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "%Jeerdere definitie van %qD was hier"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "%Jeerdere declaratie van %qD was hier"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "%Jherdefinitie van %qD"
@@ -48771,48 +48801,48 @@ msgstr "%Jherdefinitie van %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "herdefinitie van %q#D"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD botst met gebruikte functie"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D is niet gedeclareerd in class"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48820,2311 +48850,2326 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%Jdeclaratie van %qD als thread-local volgt declaratie als niet-thread-local"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%Jdeclaratie van %qD als niet-thread-local volgt declaratie als thread-local"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, fuzzy, gcc-internal-format
 msgid "  from here"
 msgstr "van hieruit opgeroepen"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "ongeldige operand van %s"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+msgid "%qD is a function, not a type"
+msgstr "%qs is geen iterator"
+
+#: cp/decl.c:4072
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nutteloos sleutelwoord of typenaam in lege declaratie"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD krijgt beginwaarde (gebruik beter __typeof__)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qE is hier niet gedeclareerd (niet in een functie)"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabele %qs heeft beginwaarde, maar een onvolledig type"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "opslaggrootte van %qs is niet constant"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "ongeïnitialiseerde const %qD"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ongeldige beginwaarde"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "ongeldige beginwaarde voor veld %qs"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C90 verbiedt het gebruik van samengestelde expressies als lvalues"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%Jherdeclaratie van enum %qD"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "typedef %qs krijgt beginwaarde alsof het een variabele is"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "dereferentie van pointer naar onvolledig type"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "opslagklasse opgegeven voor structure-veld %qs"
 msgstr[1] "opslagklasse opgegeven voor structure-veld %qs"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "herhaald lid %qs"
 
 # Betere vertaling voor 'decompose'?
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan adres niet ontleden"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "teruggeeftype is onvolledig"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, fuzzy, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "a function concept cannot be constrained"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "%qs is meestal een functie"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Ongeldige optie %qs"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ verbiedt lid-declaraties zonder leden"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit doelsysteem"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "zowel 'signed' als 'unsigned' opgegeven voor %qs"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "zowel 'long' als 'short' opgegeven voor %qs"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuut wordt genegeerd"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> functie geeft niet-void waarde terug"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> bij lege declaratie"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "cast geeft functie-type op"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "In functie %qs"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "open %s"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "ongeldig type-argument %qs"
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -51136,105 +51181,105 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "cast geeft functie-type op"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qs is geen typedef of ingebouwd type"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "herhaalde case-waarde"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
@@ -51243,78 +51288,78 @@ msgstr "grootte van array %qs is van een niet-integer type"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow in enumeratiewaarden"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -51354,7 +51399,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "herdeclaratie van %qs"
@@ -51364,7 +51409,7 @@ msgstr "herdeclaratie van %qs"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "%<%s %s%> binnen parameterlijst gedeclareerd"
@@ -51690,22 +51735,22 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -51811,7 +51856,7 @@ msgstr "grootte van %qs is %u bytes"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -51821,7 +51866,7 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -52007,408 +52052,408 @@ msgstr "dubbele beginwaarde"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "ongeldige beginwaarde"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, fuzzy, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, fuzzy, gcc-internal-format
 msgid "  %q#D"
 msgstr "%s voor %qs"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 msgid "  base %qT"
 msgstr "%s voor %qs"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%qs is geen static veld"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qs is geen iterator"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr ""
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "integer overflow in expressie"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
@@ -52463,62 +52508,62 @@ msgstr ""
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -52702,304 +52747,304 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "externe declaratie van %qs komt niet overeen met de globale declaratie"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "ongeldige operand van %s"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "%Jsectie van %qD geeft een conflict met een eerdere declaratie"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%J%s %<%c%s%>"
 
 # XXX FIXME:  useless gettextization
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s%s\n"
 msgid "%s %s %p %d"
 msgstr "%s %s%s\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%qs is geen iterator"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qs is geen iterator"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attribuut-commando %qD wordt genegeerd"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%s voor %qs"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 #| msgid "%qD conflicts with used function"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD botst met gebruikte functie"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -53024,7 +53069,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
@@ -53049,7 +53094,7 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "request for member %qE in non-class type %qT"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -53129,7 +53174,7 @@ msgstr "ongeldig karakter in naam van macro-parameter"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -53265,7 +53310,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -53390,7 +53435,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "lege declaratie"
@@ -53442,7 +53487,7 @@ msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "ongeldige waarheidsexpressie"
@@ -53472,7 +53517,7 @@ msgstr "%qs is geen iterator"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
@@ -53492,12 +53537,12 @@ msgstr "de declaratie van %qs verbergt een parameter"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qs is geen iterator"
@@ -53532,7 +53577,7 @@ msgstr "meerdere opslagklassen in declaratie van %qs"
 msgid "expected nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -53547,7 +53592,7 @@ msgstr "types in voorwaardelijke expressie komen niet overeen"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
@@ -53562,1122 +53607,1127 @@ msgstr "ISO C++ verbiedt het gebruik van samengestelde expressies als lvalues"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "gebruik liefst haakjes rond && binnen ||"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr "overflow in constante expressie"
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "herhaalde %<volatile%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, fuzzy, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 msgid "condition declares an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 msgid "condition declares a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ verbiedt geneste functies"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 msgid "expected module-name"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 msgid "private module fragment"
 msgstr "geen argumenten"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored"
 msgid "attributes may be inserted here"
 msgstr "attribuut wordt genegeerd"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "lege declaratie"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%Jdeclaratie van %qD als static volgt declaratie als niet-static"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ongeldige const_double operand"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "onverwachte operand"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "%qs is geen iterator"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "ongeldige beginwaarde"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 msgid "concept defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "geen eerdere declaratie voor %qs"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "herhaalde case-waarde"
 
 # betere vertaling voor 'function scope'?
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD is niet gedefinieerd buiten een functie"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qs is geen iterator"
 
 # betere vertaling voor 'function scope'?
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD is niet gedefinieerd buiten een functie"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%qs is geen iterator"
@@ -54686,431 +54736,431 @@ msgstr "%qs is geen iterator"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "onverwachte operand"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "[kan %s niet vinden]"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "eerdere definitie van %qs"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "%<__alignof%> toegepast op bitveld"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr ""
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "gevraagd alignment is geen constante"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "twee of meer data types in de declaratie van %qs"
@@ -55119,761 +55169,761 @@ msgstr "twee of meer data types in de declaratie van %qs"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "zowel %<short%> als %<char%> opgegeven bij declaratie"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefix-attributen worden genegeerd vóór %<@%D%>"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ongeldige operand voor 'p' modifier"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "onbekende machine-modus %qs"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qs is meestal een functie"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "misvormde #pragma weak"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "herdefinitie van %qs"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "herdefinitie van %qs"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "%s %qs"
 msgid "%s %#qD"
 msgstr "%s %qs"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "impliciete declaratie van functie %qs"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "misvormde #pragma pack"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qs is meestal een functie"
@@ -55886,159 +55936,159 @@ msgstr "%qs is meestal een functie"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, fuzzy, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "%qs impliciet als functie gedeclareerd"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "%Jsectie van %qD geeft een conflict met een eerdere declaratie"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "<anoniem>"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "herhaald label %qs"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "argument %d is alleen-lezen"
 msgstr[1] "argument %d is alleen-lezen"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "ongeldig type-argument %qs"
@@ -56047,47 +56097,47 @@ msgstr "ongeldig type-argument %qs"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
@@ -56097,495 +56147,495 @@ msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "macro %qs gebruikt zonder argumenten"
 msgstr[1] "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "eerdere declaratie van %qs"
 msgstr[1] "eerdere declaratie van %qs"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ongeldige naam %qs"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "%Jherdefinitie van typedef %qD"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "iterator %qs is van een afgeleid type"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d or more)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "verkeerd aantal sjabloonargumenten (%d, moet %d of meer zijn)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "gegeven voor %q+D"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D is geen functiesjabloon"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "lege declaratie"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "%Jflexibel array-lid in union"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
@@ -56603,294 +56653,294 @@ msgstr "pointer naar lid-functie gebruikt in rekensom"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ongeldige operand voor %p-code"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "herhaalde definitie %qs"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 #| msgid "%s %qs"
 msgid "%s %#qS"
 msgstr "%s %qs"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qs is geen static veld"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "impliciete declaratie van functie %qs"
@@ -56902,155 +56952,155 @@ msgstr "impliciete declaratie van functie %qs"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "functie wordt niet als kandidaat voor inlining beschouwd"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "%Jeerder hier gebruikt"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan %qs niet nabootsen"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ongeldig type-argument %qs"
@@ -57185,536 +57235,536 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "  since %q+#D declared in base class"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr "herhaald lid %qs"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "type van parameter %qs is niet gedeclareerd"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "initiële declaratie voor %<for%> lus gebruikt buiten C99 modus"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
 # Betere term voor "mismatched"?
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "%qE missing template arguments"
 msgstr "slechte combinatie van argumenten"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%<%c%> optie gebruikt bij type %<%c%>"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "de declaratie van %qs verbergt een symbool uit de parameterlijst"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "kan functie %<main%> niet inline maken"
 
 # Betere term voor "mismatched"?
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "slechte combinatie van argumenten"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "modi in %s expressie komen niet overeen"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qs is geen iterator"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "%<vector%> length expression must be integral"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, fuzzy, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "te veel invoerbestanden"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "%Jdeclaratie van %qD als niet-static volgt declaratie als static"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -57723,22 +57773,22 @@ msgstr "niet-ondersteund argument voor %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -57748,1081 +57798,1081 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 msgid " declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qs is geen iterator"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qs heeft een onvolledig type"
 
 # XXX FIXME:  duplicate
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "het argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute has no effect"
 msgid "%qE attribute takes no arguments"
 msgstr "attribuut %qE heeft geen effect"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to types"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "attribuut %qE heeft geen betekenis voor types"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "herdeclaratie van %qs"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "'%%%c' is not a valid operand prefix"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%%%c' is geen geldige operand-prefix"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "herhaalde definitie %qs"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr ""
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ verbiedt casts naar een union-type"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qs is meestal een functie"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qs is geen iterator"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ verbiedt accolade-groepen in expressies"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "te veel argumenten voor functie"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "te weinig argumenten voor functie"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, fuzzy, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ verbiedt een vergelijking tussen pointer en integer"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operand-types zijn %qT en %qT"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "geordende vergelijking van pointer met integer nul"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with null pointer"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "geordende vergelijking van pointer met null-pointer"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, fuzzy, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adres van registervariabele %qs gevraagd"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:7956
+#: cp/typeck.c:7963
 #, fuzzy, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "cast verhoogt het benodigde alignment van het doeltype"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ verbiedt voorwaardelijke expressies tussen 0 en een functiepointer"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ verbiedt casts naar een union-type"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "ongeldige lvalue in asm-statement"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -59091,107 +59141,102 @@ msgstr "accolades rond scalaire beginwaarde"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "onbekend veld %qs opgegeven in beginwaarde"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "kon 0x%l.8x niet naar een regio omzetten"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "dubbele beginwaarde"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
@@ -59211,268 +59256,274 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, fuzzy, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 msgid "cannot be declared to be a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot be %s"
 msgstr "open %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
 msgstr "open %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, fuzzy, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr "ongeldige beginwaarde"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "Genereer directe aftakkingen naar locale functies"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr "het argument van %<cleanup%> is geen naam"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 msgid "string expected for library name"
 msgstr "ongeldige operand van %s"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr "ongeldige operand van %s"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "geen argumenten"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 msgid "can only apply to a single declaration"
 msgstr "lege declaratie"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
 msgstr "lege declaratie"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 msgid "circular reference to enum member"
 msgstr "ongeldige beginwaarde"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "recursieve inlining"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "recursieve inlining"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 msgid "error instantiating"
 msgstr "#error %s"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "without `this` cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "functions cannot be scope"
@@ -59481,43 +59532,53 @@ msgstr "union kan niet transparant gemaakt worden"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify both -C and -o"
 msgid "cannot be both final and abstract"
 msgstr "-C en -o gaan niet samen"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -59525,176 +59586,176 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr "bibliotheekfunctie %qs wordt verborgen"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "incompatible covariant types %s and %s"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 msgid "does not override any function"
 msgstr "ISO C staat geen extra %<;%> buiten een functie toe"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "bibliotheekfunctie %qs wordt verborgen"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions"
 msgid "override only applies to class member functions"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr "%<defined%> zonder een naam"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "structs, unions cannot be abstract"
 msgstr "union kan niet transparant gemaakt worden"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, gcc-internal-format
 msgid "circular inheritance"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "dubbele map \"%s\" wordt genegeerd\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot inherit from final class %s"
 msgstr "[kan %s niet vinden]"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "impliciete declaratie van functie %qs"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve"
 msgstr "open %s"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
@@ -59709,22 +59770,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 msgid "has forward references"
 msgstr "doorgeven van argument %d van %qs"
@@ -59785,23 +59846,22 @@ msgstr ""
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr "-pipe wordt niet ondersteund"
@@ -60341,7 +60401,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "%s voor %qs"
@@ -61514,12 +61574,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -61703,7 +61763,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -64195,7 +64255,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -64276,7 +64336,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -64412,12 +64472,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -64527,542 +64587,542 @@ msgstr "Te veel argumenten voor %s op %L"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "kan klasse '%s' niet vinden"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "te veel argumenten voor %s %q+#D"
@@ -65207,33 +65267,33 @@ msgstr "overflow in constante expressie"
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "ongeldige registernaam voor %qs"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "ongeldige registernaam voor %qs"
@@ -65241,22 +65301,22 @@ msgstr "ongeldige registernaam voor %qs"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -65796,7 +65856,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -66971,12 +67031,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -67131,147 +67191,147 @@ msgstr ""
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "%s: kan bestand '%s' niet openen om te lezen: %s\n"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: fout bij schrijven van bestand '%s': %s\n"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "%s: kan aux-infobestand '%s' niet verwijderen: %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "%s: waarschuwing: kan naam van bestand '%s' niet wijzigen in '%s': %s\n"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "%s: kan aux-infobestand '%s' niet verwijderen: %s\n"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "%s: kan bestand '%s' niet openen om te lezen: %s\n"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -67810,8 +67870,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -69838,7 +69898,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "naar label %s gerefereerd buiten enige functie"
@@ -69953,7 +70013,7 @@ msgstr "fout in argumenten voor spec-functie '%s'"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -70109,217 +70169,217 @@ msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 msgid "Impure function at %L might not be evaluated"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
 # Ongeldig soort wat?
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
 # Ongeldig soort wat?
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -70328,12 +70388,12 @@ msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -70342,293 +70402,293 @@ msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -70637,287 +70697,287 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "expressie-statement heeft onvolledig type"
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%<defined%> zonder een naam"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -70925,194 +70985,194 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "In functie %qs"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
 # Ongeldig soort wat?
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -71120,969 +71180,969 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "String-lengte bij %L is te groot"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring bij %L heeft lengte nul"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -72951,17 +73011,17 @@ msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -73053,107 +73113,107 @@ msgstr "ongeldige waarheidsexpressie"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "onbekende machine-modus %qs"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -73306,7 +73366,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr ""
@@ -73437,7 +73497,7 @@ msgstr "-G en -static sluiten elkaar uit"
 
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-G en -static sluiten elkaar uit"
 
 #: lto/lto-object.c:107
@@ -74545,7 +74605,7 @@ msgstr "niet-herkende optie -fdisable"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "niet-herkende zichtbaarheidswaarde %qs"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized option -fdisable"
 msgid "Unrecognized option: %qs"
@@ -74565,15 +74625,15 @@ msgstr "Macro-naam ontbreekt na -U optie"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, fuzzy, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "beginwaarde ontbreekt"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, fuzzy, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "ontbrekende witruimte na getal %qs"
@@ -74625,7 +74685,7 @@ msgstr "beginwaarde ontbreekt"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "niet-herkende zichtbaarheidswaarde %qs"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized register name %qs"
 msgid "unrecognized scalar storage order value %qs"
@@ -74709,93 +74769,93 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "unknown linker output %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, fuzzy, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: common.opt:1718
+#: common.opt:1722
 #, fuzzy, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "onbekende 'unspec' relocatie"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "onbekende machine-modus %qs"
 
 # Assertie? Dat moet beter kunnen!
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "Assertie ontbreekt na -A optie"
 
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2690
+#: common.opt:2694
 #, fuzzy, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "niet-herkende zichtbaarheidswaarde %qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(dicht bij initialisatie van %qs)"
diff --git a/gcc/po/ru.po b/gcc/po/ru.po
index 4ebaf24c7cc48..f2c85fb8b948a 100644
--- a/gcc/po/ru.po
+++ b/gcc/po/ru.po
@@ -12,7 +12,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 9.1-b20190414\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2019-05-04 12:10+0300\n"
 "Last-Translator: Pavel Maryanov <acid@jack.kiev.ua>\n"
 "Language-Team: Russian <gnu@d07.ru>\n"
@@ -1410,13 +1410,13 @@ msgstr "    включённом из %qs"
 msgid "this is the insn:"
 msgstr "это insn:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "ошибка при генерации загрузок операндов на регистры для:"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "ошибка при генерации загрузок операндов на регистры для:"
 
@@ -1600,18 +1600,18 @@ msgstr "некорректная RTL-инструкция"
 msgid "insn does not satisfy its constraints:"
 msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "создан с одним значением '%s', а используется с другим"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "создан с одним значением -fpic, а используется с другим"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1653,7 +1653,7 @@ msgstr "%s%sпредупреждение: версия заголовка %s %s
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sэвристики GGC: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2101,90 +2101,90 @@ msgstr "модификатор размера в формате strfmon"
 msgid "<command-line>"
 msgstr "<command-line>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "недопустимый операнд для кода '%%%c'"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, c-format
 msgid "invalid vector constant"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "недопустимый операнд - плавающий или векторный регистр для кода '%%%c'"
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 #| msgid "incompatible floating point / vector register operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "недопустимый операнд - плавающий или векторный регистр для кода '%%%c'"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "отсутствует операнд"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "недопустимая константа"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "некорректный операнд"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "некорректный префикс операнда '%%%c'"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, c-format
 msgid "invalid address mode"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "неверные операнды в бинарной операции"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' использовано без локальной динамической TLS ссылки"
@@ -2200,18 +2200,18 @@ msgid "invalid %%r value"
 msgstr "некорректное значение %%r"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "некорректное значение %%R"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "некорректное значение %%N"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "некорректное значение %%P"
@@ -2241,7 +2241,7 @@ msgstr "некорректное значение %%M"
 msgid "invalid %%U value"
 msgstr "некорректное значение %%U"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "некорректное значение %%s"
@@ -2251,7 +2251,7 @@ msgstr "некорректное значение %%s"
 msgid "invalid %%C value"
 msgstr "некорректное значение %%C"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "некорректное значение %%E"
@@ -2264,7 +2264,7 @@ msgstr "некорректное unspec-перемещение"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "некорректный код %%xn"
@@ -2346,35 +2346,35 @@ msgstr "некорректный операнд UNSPEC: %d"
 msgid "unrecognized supposed constant"
 msgstr "неопознанная константа"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "некорректный оператор сдвига"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикативная инструкция для архитектуры Thumb"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикативная инструкция в условной последовательности"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Неподдерживаемый операнд для кода '%c'"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2382,13 +2382,13 @@ msgstr "Неподдерживаемый операнд для кода '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "недопустимый операнд для кода '%c'"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "инструкция никогда не выполняется"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "устаревший код формата Maverick '%c'"
@@ -2515,8 +2515,8 @@ msgstr "некорректный операнд"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2885,7 +2885,7 @@ msgstr "некорректный операнд для %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "неверный операнд для кода %%P"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "неверное значение для кода %%p"
@@ -2939,7 +2939,7 @@ msgid "post-increment address is not a register"
 msgstr "постинкрементный адрес - не регистр"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "некорректный адрес"
 
@@ -2991,8 +2991,8 @@ msgstr "'%%%c' не является корректным префиксом о
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "недопустимое использование '%%%c'"
@@ -3139,322 +3139,322 @@ msgstr "Выход за границу стека.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Попробуйте выполнить '%s' в командной строке, чтобы увеличить его размер.\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 #| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx требует аппаратной реализации плавающей арифметики"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 #| msgid "-mvsx needs indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "для -mvsx требуется индексная адресация"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "ключи -mvsx и -mno-altivec несовместимы"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 #, fuzzy
 #| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec отменяет vsx"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "ключ -mquad-memory требует 64-битного режима"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 #, fuzzy
 #| msgid "-mquad-memory-atomic requires 64-bit mode"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "ключ -mquad-memory-atomic требует 64-битного режима"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 #, fuzzy
 #| msgid "-mquad-memory is not available in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "ключ -mquad-memory не поддерживается для обратного (little endian) порядка байт"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr "некорректная пересылка"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr "некорректная 128-битная пересылка"
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "неверное значение для кода %%D"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, c-format
 msgid "invalid %%e value"
 msgstr "некорректное %%e значение"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "недопустимое значение для кода %%f"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "недопустимое значение для кода %%F"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "недопустимое значение для кода %%G"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "недопустимое значение для кода %%j"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "недопустимое значение для кода %%J"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "недопустимое значение для кода %%k"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "недопустимое значение для кода %%K"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "недопустимое значение для кода %%O"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "недопустимое значение для кода %%q"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "недопустимое значение для кода %%T"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "недопустимое значение для кода %%u"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "недопустимое значение для кода %%v"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "неверное значение для кода %%x"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "некорректное значение %%y, попробуйте использовать ограничитель 'Z'"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 #, fuzzy
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Включить использование инструкций IEEE 128-битной плавающей точки."
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 msgid "Could not generate addis value for fusion"
 msgstr "Не удалось сгенерировать дополнительное значение для синтеза"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Не удалось сгенерировать смещение загрузки/сохранения для синтеза"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr "Некорректный GPR синтез"
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "некорректное преобразование к %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "некорректное преобразование к %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "некорректное преобразование к %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "некорректное преобразование к %<__fpreg%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "символьные ссылки на память поддерживаются только для z10 или более поздних версий"
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "ошибка при декомпозиции адреса"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "некорректный оператор сравнения для 'E' модификатора вывода"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "некорректная ссылка для 'J' модификатора вывода"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "некорректный адрес для 'O' модификатора вывода"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "некорректный адрес для 'R' модификатора вывода"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "ожидалась ссылка на память для 'S' модификатора вывода"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "некорректный адрес для 'S' модификатора вывода"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "ожидалось выражении из регистров и памяти для 'N' модификатора вывода"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "ожидался регистр или выражение памяти для модификатора вывода 'M'"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "некорректная константа для модификатора вывода '%c'"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "некорректная константа - попытайтесь использовать модификатор вывода"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "некорректная константный вектор для модификатора вывода '%c'"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "некорректное выражение - попытайтесь использовать модификатор вывода"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "некорректное выражение для модификатора вывода '%c'"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 msgid "vector argument passed to unprototyped function"
 msgstr "векторный аргумент передан в функцию без прототипа"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr "типы различаются знаковостью"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr "бинарный оператор не поддерживает два операнда-вектора с булевыми компонентами"
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr "бинарный оператор не поддерживает операнд - вектор с булевыми компонентами"
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "бинарный оператор не поддерживает сочетание операндов вектор с булевыми компонентами и вектор с плавающими компонентами"
 
@@ -3717,8 +3717,8 @@ msgstr "({anonymous})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ожидалось %<;%>"
@@ -3738,7 +3738,7 @@ msgstr "ожидалось %<;%>"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ожидалась %<)%>"
@@ -3746,7 +3746,7 @@ msgstr "ожидалась %<)%>"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ожидалась %<]%>"
@@ -3764,21 +3764,21 @@ msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ожидалась %<(%>"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ожидалось %<[%>"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ожидалась %<{%>"
@@ -3789,13 +3789,13 @@ msgstr "ожидалась %<{%>"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ожидалось %<:%>"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ожидалось %<while%>"
@@ -3804,7 +3804,7 @@ msgstr "ожидалось %<while%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ожидалась %<,%>"
@@ -3813,18 +3813,18 @@ msgstr "ожидалась %<,%>"
 msgid "expected %<.%>"
 msgstr "ожидалась %<.%>"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ожидалось %<@end%>"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ожидалось %<>%>"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ожидалась %<,%> или %<)%>"
@@ -3832,28 +3832,28 @@ msgstr "ожидалась %<,%> или %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ожидалось %<=%>"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ожидалась %<}%>"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(anonymous)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ожидалось %<<%>"
@@ -3870,32 +3870,32 @@ msgstr "ожидалась метка"
 msgid "candidate:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 #| msgid "Enable user-defined instructions."
 msgid "  after user-defined conversion:"
 msgstr "Включить определяемые пользователем инструкции."
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "кандидат"
 msgstr[1] "претенденты:"
 msgstr[2] "претенденты:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "переход по метке %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "переход по case-метке"
 
@@ -4116,35 +4116,35 @@ msgstr "локальная переменная %qD недопустима в д
 msgid "local variable %qD may not appear in this context"
 msgstr "локальная переменная %qD недопустима в данном контексте"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 #, fuzzy
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 #| msgid "invalid use of dependent type %qT"
 msgid "%<using enum%> of dependent type %qT"
 msgstr "некорректное использование зависимого типа %qT"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 #| msgid "%qT is not an enumeration type"
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%qT не имеет перечислимый тип"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 #| msgid "invalid use of incomplete type %q#T"
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "некорректное использование неполного типа %q#T"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "претенденты:"
 
@@ -4188,48 +4188,48 @@ msgstr "преобразование типа отбрасывает конст
 msgid "source type is not polymorphic"
 msgstr "тип источника не является полиморфным"
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "неверный тип аргумента для унарного минуса"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "неверный тип аргумента для унарного плюса"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "неверный тип аргумента для побитового дополнения"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "неверный тип аргумента для abs"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "неверный тип аргумента для сопряжения"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr "в аргументе унарного !"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr "нет преинкрементного оператора для типа"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr "нет постинкрементного оператора для типа"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr "нет предекрементного оператора для типа"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr "нет постдекрементного оператора для типа"
 
@@ -4328,7 +4328,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Движущий:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "фактический аргумент для INTENT = OUT/INOUT"
 
@@ -4472,7 +4472,7 @@ msgstr "Некорректный оператор"
 msgid "Bad type in constant expression"
 msgstr "Некорректный тип в константном выражении"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "Неожиданный конец модуля"
 
@@ -4500,11 +4500,11 @@ msgstr "блочный IF"
 msgid "implied END DO"
 msgstr "предписанный END DO"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "присваивание"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "присваивание указателя"
 
@@ -4590,154 +4590,154 @@ msgstr "результат с неконстантной character длиной"
 msgid "bind(c) procedure"
 msgstr "процедура bind(c)"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Некорректный контекст для NULL() указателя в %%L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Операнд унарного числового оператора %%<%s%%> в %%L есть %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды бинарного числового оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Операнды оператора конкатенации строк в %%L есть %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды логического оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX величины не могут сравниваться в %L"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Логические в %%L должны сравниваться посредством %s вместо %s"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды оператора сравнения %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Неизвестный оператор %%<%s%%> в %%L"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Операнд пользовательского оператора %%<%s%%> в %%L есть %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды пользовательского оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Противоречивые ранги для оператора в %%L и %%L"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr "Переменная цикла"
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr "Переменная итератора"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr "Начальное выражение в DO цикле"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr "Конечное выражение в DO цикле"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr "Шаговое выражение в DO цикле"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE объект"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr "ALLOCATE объект"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr "STAT переменная"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr "ERRMSG переменная"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr "элемент в READ"
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK переменная"
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Разные CHARACTER длины (%ld/%ld) в конструкторе массива"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Целочисленное переполнение при вычислении объема памяти для размещения"
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Фактическая длина строки не соответствует декларированной для формального аргумента '%s' (%ld/%ld)"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Фактическая длина строки меньше декларированной для формального аргумента '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Цель переотображения ранга слишком мала (%ld < %ld)"
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr "Присваивание скаляра неразмещенному массиву"
 
@@ -4864,27 +4864,27 @@ msgstr "Ссылка на массив выходит за границы"
 msgid "Incorrect function return value"
 msgstr "Некорректной результат функции"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 #| msgid "Memory allocation failed"
 msgid "Error allocating %lu bytes"
 msgstr "Ошибка выделения памяти"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "Попытка разместить уже размещенную переменную '%s'"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr "Попытка разместить уже размещенную переменную"
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "Попытка DEALLOCATE неразмещенную '%s'"
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -5085,15 +5085,15 @@ msgstr "ключи -Xbind-now и -Xbind-lazy несовместимы"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr "попробуйте `-pg' вместо `-p' для gprof(1)"
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "-EB и -EL несовместимы"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-mfloat-abi=soft и -mfloat-abi=hard несовместимы"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "ключи -mbig-endian и -mlittle-endian несовместимы"
 
@@ -5109,8 +5109,8 @@ msgstr "не задан тип процессора для линковки"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "не задавайте одновременно -march=... и -mcpu=..."
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared и mdll несовместимы"
 
@@ -5280,10 +5280,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Предупреждать о создании временных массивов."
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Ничего не делает. Сохранён для обратной совместимости."
@@ -5763,160 +5763,160 @@ msgstr "Размещать все локальные массивы в стек
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "Установить PRIVATE как умолчание для атрибута доступности элементов модуля."
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "Использовать наиболее компактное представление производных типов."
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "Защитить скобки в выражениях."
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr "Включить проверку диапазонов при компиляции."
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr "Трактовать REAL(4) как REAL(8)."
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr "Трактовать REAL(4) как REAL(10)."
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr "Трактовать REAL(4) как REAL(16)."
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr "Трактовать REAL(8) как REAL(4)."
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr "Трактовать REAL(8) как REAL(10)."
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr "Трактовать REAL(8) как REAL(16)."
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr "Выделять память заново для левых частей присваиваний."
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Использовать 4-байтный маркер записей в неформатированных файлах."
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Использовать 8-байтный маркер записей в неформатированных файлах."
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr "Размещать локальные переменные в стеке для поддержки неявной рекурсии."
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "При входе в процедуру копировать секции массивов в последовательный блок."
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr "-fcoarray=<none|single|lib>\tЗадать, какое распараллеливание комассивов должно использоваться."
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr "-fcheck=[...]\tЗадать набор runtime-проверок."
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "Добавлять второй символ подчеркивания к именам, уже содержащим подчеркивание."
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr "Применять знак минус к нулевым значениям."
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr "Добавлять подчёркивания к доступным извне именам."
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Ничего не делает.  Сохранён для обратной совместимости."
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr "Выполнить статическую компоновку с библиотекой GNU Fortran (libgfortran)."
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Компилировать в соответствии со стандартом ISO Fortran 2003."
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Компилировать в соответствии со стандартом ISO Fortran 2008."
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Компилировать в соответствии со стандартом ISO Fortran 2008, включая TS 29113."
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Компилировать в соответствии со стандартом ISO Fortran 2018."
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Компилировать в соответствии со стандартом ISO Fortran 95."
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr "Не соответствует ничему конкретному."
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr "Принимать расширения для поддержки унаследованного кода."
@@ -6611,7 +6611,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7241,8 +7241,8 @@ msgstr "-faligned-new=<N> Использовать размещение типо
 msgid "Allow variadic functions without named parameter."
 msgstr "Разрешить функции с переменным числом аргументов без именованных параметров."
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr "Больше не поддерживается."
@@ -7607,477 +7607,472 @@ msgstr "Задает измерения вычислений OpenACC по умо
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "Включить OpenMP (для Фортрана подразумевает -frecursive)."
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "Включить SIMD-директивы OpenMP."
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "Распознавать ключевые слова C++, такие как \"compl\" и \"xor\"."
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "Использовать и искать файлы PCH даже во время препроцессирования."
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr "Ошибки соответствия трактовать как предупреждения."
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr "Включить расширения языка Plan 9."
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr "Считать, что входной файл уже препроцессирован."
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, fuzzy, no-c-format
 #| msgid "-ftrack-macro-expansion=<0|1|2>  Track locations of tokens coming from macro expansion and display them in error messages."
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr "-ftrack-macro-expansion=<0|1|2>  Отслеживать позиции элементов из макроподстановок и показывать их в сообщениях об ошибках."
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, fuzzy, no-c-format
 #| msgid "-fno-pretty-templates Do not pretty-print template specializations as the template signature followed by the arguments."
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr "-fno-pretty-templates Не использовать красивую печать специализаций шаблонов в виде сигнатуры шаблона с последующими аргументами."
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr "Трактовать известные возвращаемые значений sprintf как константы."
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "Используется в режиме Fix-and-Continue для указания о том, что возможна подкачка объектных файлов во время выполнения."
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 #| msgid "Deprecated in GCC 8.  This switch has no effect."
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "Deprecated in GCC 8.  Ничего не делает."
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr "Генерировать информацию о типах, доступную во время выполнения."
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "Использовать для перечислимых типов минимальный целочисленный тип."
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "Установить для \"wchar_t\" тип \"unsigned short\"."
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "По умолчанию считать битовые поля знаковыми."
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr "По умолчанию считать тип \"char\" знаковым."
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "Включить поддержку деаллокации по размеру C++14."
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr "-fsso-struct=[big-endian|little-endian|native]\tУстановить порядок байт для хранения скалярных объектов в памяти."
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr "Показать статистику компиляции."
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "Предполагать, что значения перечислимого типа всегда находятся в минимальном диапазоне этого типа."
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr "Следовать порядку вычислений C++17 для выражений присваивания, сдвигов, вызовов функций-членов и т.д."
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "Задать максимальное число замечаний о подстановке шаблона для одного предупреждения или сообщения об ошибке."
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "-ftemplate-depth=<number>\tМаксимальная глубина конкретизации шаблонов."
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "-fno-threadsafe-statics\tНе генерировать поточно-безопасный код для инициализации локальных статических переменных."
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "По умолчанию считать битовые поля беззнаковыми."
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "По умолчанию считать тип char беззнаковым."
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr "Использовать __cxa_atexit для регистрации деструкторов."
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "Использовать __cxa_get_exception_ptr для обработки исключений."
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "Отметить область видимости всех inline-подставленных функций и методов как hidden."
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "Изменить атрибуты видимости в соответствии с правилами Microsoft Visual Studio."
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr "common-символы считать слабыми (weak)."
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-fwide-exec-charset=<кодировка>\tКонстантные широкие символы и строки широких символов конвертировать в заданную <кодировку>."
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "Генерировать директиву #строка, указывающую на текущий рабочий каталог."
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "Генерировать ленивый поиск классов (при помощи objc_getClass()) для использования в режиме Zero-Link."
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr "Вывести декларации в файл .decl."
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "-femit-struct-debug-baseonly\tСильно сокращать отладочную информацию для структур."
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "-femit-struct-debug-reduced\tУмеренно сокращать отладочную информацию для структур."
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "-femit-struct-debug-detailed=<spec-list>\tЗадает детальные инструкции по сокращению отладочной информации для структур."
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr "Интерпретировать суффиксы GNU для мнимой части, чисел с фиксированной точкой или другие суффиксы GNU для чисел как соответствующий числовой литерал, а не как пользовательский числовой литерал."
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <каталог>\tДобавить <каталог> в конец пути поиска системных заголовков."
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "-imacros <файл>\tИспользовать макроопределения из <файла>."
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-imultilib <каталог>\tУстановить <каталог> как подкаталог мультибиблиотеки заголовков."
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "-include <файл>\tВключить содержимое <файла> перед компиляцией других файлов."
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "-iprefix <префикс>\tЗадает <префикс> для следующих двух ключей."
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <каталог>\tСчитать <каталог> корневым каталогом системы."
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <каталог>\tДобавить <каталог> в начало пути поиска системных заголовков."
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-iquote <каталог>\tДобавить <каталог> в конец пути поиска заголовков \"в кавычках\"."
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <каталог>\tДобавить <каталог> в конец пути поиска системных заголовков."
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <каталог>\tДобавить <каталог> в конец основного пути поиска заголовков."
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "Не искать системные заголовки в стандартных каталогах поиска (но искать в каталогах, заданных при помощи -isystem)."
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr "Не искать системные заголовки C++ в стандартных каталогах."
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr "Сгенерировать C-заголовок описаний, специфических для целевой платформы."
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr "Преобразовывать имена файлов при включении."
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Компилировать в соответствии с ISO 1998 C++ с учетом технических поправок 2003 года."
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Компилировать в соответствии с ISO 2011 C++."
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Не рекомендуется; используйте -std=c++11."
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Не рекомендуется; используйте -std=c++14."
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Компилировать в соответствии с ISO 2014 C++."
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr ""
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard (experimental and incomplete support)"
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Компилировать в соответствии со стандартом ISO 2011 C (неполная экспериментальная поддержка)"
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard (experimental and incomplete support)"
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Компилировать в соответствии со стандартом ISO 2011 C (неполная экспериментальная поддержка)"
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Компилировать в соответствии с ISO 2011 C."
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "Не рекомендуется; используйте -std=c11."
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard."
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Компилировать в соответствии с ISO 2011 C."
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard (experimental and incomplete support)"
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Компилировать в соответствии со стандартом ISO 2011 C (неполная экспериментальная поддержка)"
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Компилировать в соответствии с ISO 1990 C."
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Компилировать в соответствии с ISO 1999 C."
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr "Не рекомендуется; используйте -std=c99."
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Компилировать в соответствии с ISO 1998 C++ с учетом технических поправок 2003 года, с расширениями GNU."
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Компилировать в соответствии с ISO 2011 C++ с расширениями GNU."
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Устаревший ключ, используйте -std=gnu++11."
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Устаревший ключ, используйте -std=gnu++14."
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Компилировать в соответствии с ISO 2014 C++ с расширениями GNU."
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr ""
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard with GNU extensions (experimental and incomplete support)"
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Компилировать в соответствии с ISO 2011 C с расширениями GNU (неполная экспериментальная поддержка)"
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard with GNU extensions (experimental and incomplete support)"
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Компилировать в соответствии с ISO 2011 C с расширениями GNU (неполная экспериментальная поддержка)"
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Компилировать в соответствии с ISO 2011 C с расширениями GNU."
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Устаревший ключ, используйте -std=gnu11."
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Компилировать в соответствии с ISO 2011 C с расширениями GNU."
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard with GNU extensions (experimental and incomplete support)"
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Компилировать в соответствии с ISO 2011 C с расширениями GNU (неполная экспериментальная поддержка)"
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Компилировать в соответствии с ISO 1990 C с расширениями GNU."
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Компилировать в соответствии с ISO 1999 C с расширениями GNU."
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Устаревший ключ, теперь следует использовать -std=gnu99."
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Компилировать в соответствии с ISO 1990 C с дополнениями от 1994."
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Устаревший ключ; используйте -std=iso9899:1999."
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "Традиционное препроцессирование."
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\tПоддержка триграфов, предусмотренных ISO C."
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr "Не предопределять системные макросы и макросы GCC."
@@ -8341,6 +8336,12 @@ msgstr "Компилировать в режиме 32-битных целых"
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+#| msgid "Emit implicit instantiations of templates."
+msgid "Emit template instantiations as weak symbols."
+msgstr "Генерировать неявные конкретизации шаблонов."
+
 #: d/lang.opt:346
 #, fuzzy, no-c-format
 #| msgid "Do not assume that standard C libraries and \"main\" exist."
@@ -9607,145 +9608,157 @@ msgstr "Поддерживать более чем 8192 GOT входов на Co
 msgid "Support TLS segment larger than 64K."
 msgstr "Поддерживать TLS сегмент больше чем 64K."
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr "Считать, что процессор имеет прямой порядок байт (big endian)."
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr "Считать, что процессор имеет обратный порядок байт (little endian)."
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "Задать соглашения о связях для целочисленных и плавающих значений."
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Пытаться сохранять выравнивание стека по адресам, кратным указанной степени числа 2."
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "Допустимые ABI (возможные аргументы ключа -mabi=):"
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Использовать машинные команды для деления и извлечения квадратного корня с плавающей арифметики."
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr "Использовать машинные команды для целочисленного деления."
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr "-march=\tГенерировать код для заданного RISC-V ISA (например, RV64IM).  ISA задается строчными буквами."
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=ПРОЦЕССОР\tОптимизировать код для указанного ПРОЦЕССОРа."
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 #| msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "-mtune=ПРОЦЕССОР\tОптимизировать код для указанного ПРОЦЕССОРа."
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "-msmall-data-limit=N\tРазмещать глобальные и статические данные размером не более N в специальных секциях (для некоторых платформ)"
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "Использовать более короткие, но менее быстрые прологи и эпилоги функций."
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr "Выбрать модель кода"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr ""
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr "Известные модели кода (значения ключа -mcmodel= ):"
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr "Использовать операторы %reloc() а не макросы ассемблера для загрузки адресов."
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr "Использовать заданное выравнивание данных."
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr "Допустимые значения выравнивания (для ключа -malign-data=):"
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr "Использовать заданную защиту стека"
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Корректные аргументы ключа -mstack-protector-guard=:"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Использовать заданный базовый регистр для адресации защиты стека."
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Использовать заданное смещение для адресации защиты стека."
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, fuzzy, no-c-format
 #| msgid "Supported ABIs (for use with the -mabi= option):"
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "Допустимые ABI (возможные аргументы ключа -mabi=):"
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, fuzzy, no-c-format
 #| msgid "The version of the C++ ABI in use."
 msgid "Set the version of RISC-V ISA spec."
@@ -9881,12 +9894,6 @@ msgstr "Возможные диалекты TLS:"
 msgid "The code model option names for -mcmodel:"
 msgstr "Имена опций для различных моделей кода для -mcmodel:"
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr "Считать, что процессор имеет прямой порядок байт (big endian)."
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9908,12 +9915,6 @@ msgstr "Генерировать код для обхода аппаратной
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr "Генерировать код для обхода аппаратной ошибки ARM Cortex-A53 номер 843419."
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr "Считать, что процессор имеет обратный порядок байт (little endian)."
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -17255,2191 +17256,2191 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <каталог>\tУказать <каталог> для выдачи дампов."
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr "Используемая версия C++ ABI."
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr "Агрессивно оптимизировать циклы используя ограничения языка."
 
-#: common.opt:978
+#: common.opt:982
 #, no-c-format
 msgid "Align the start of functions."
 msgstr "Выравнивать начало функций."
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr "Выравнивать метки, доступные только по командам переходов."
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr "Выравнивать все метки."
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr "Выравнивать начало циклов."
 
-#: common.opt:1009
+#: common.opt:1013
 #, fuzzy, no-c-format
 #| msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr "Разрешить проходу слияния записей в память генерировать невыровненные записи, если это допустимо."
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing."
 msgid "Enable static analysis pass."
 msgstr "Традиционное препроцессирование."
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr "Выбрать, что санировать."
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr "-fasan-shadow-offset=<number>\tИспользовать специальное смещение теневой памяти."
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr "-fsanitize-sections=<sec1,sec2,...>\tСанировать глобальные переменные в определенных пользователем секциях."
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr "После диагностирования неопределенного поведения пытаться продолжить выполнение."
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Этот ключ устарел; используйте -fsanitize-recover= взамен."
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr "Использовать trap вместо библиотечной функции для санирования неопределенного поведения."
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Генерировать unwind-таблицы, корректные на начало каждой команды."
 
-#: common.opt:1069
+#: common.opt:1073
 #, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "Генерировать команды автоинкрементации/автодекрементации."
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Генерировать код для проверки выхода за границы массивов."
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Заменить сложение, сравнение, ветвление на ветвление по регистру счетчика."
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr "Оценивать вероятность переходов на основе данных профилирования."
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 #| msgid "Output stack usage information on a per-function basis."
 msgid "Output callgraph information on a per-file basis."
 msgstr "Выводить информацию об использовании стека для каждой функции."
 
-#: common.opt:1115
+#: common.opt:1119
 #, fuzzy, no-c-format
 #| msgid "Output stack usage information on a per-function basis."
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "Выводить информацию об использовании стека для каждой функции."
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<регистр>\tСчитать, что <регистр> сохраняется при вызовах функций."
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<регистр>\tСчитать, что <регистр> портится при вызовах функций."
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr "Сохранять/восстанавливать регистры до/после вызовов функций."
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "Этот ключ устарел; не используйте."
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "Проверять результат new в C++."
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr "Произвести проверки внутренней непротиворечивости."
 
-#: common.opt:1150
+#: common.opt:1154
 #, no-c-format
 msgid "Enable code hoisting."
 msgstr "Включить поднятие кода."
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "По возможности сокращать число операций со стеком и обращений к стеку"
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 #| msgid "Do not put uninitialized globals in the common section."
 msgid "Put uninitialized globals in the common section."
 msgstr "Не размещать неинициализированные глобальные данные в общих блоках."
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<opts>]\tКомпилировать с ключом, например, -gtoggle, и сравнивать финальные дампы инструкций."
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "Выполнять только вторую компиляцию по -fcompare-debug."
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Выполнить исключение лишних сравнений после распределения регистров."
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "Не выполнять оптимизации, существенно увеличивающие использование стека."
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Выполнить оптимизацию распространения копий регистров."
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr "Выполнить оптимизацию кода вокруг команд передачи управления."
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr "При экономии общих подвыражений прослеживать код, доступный по переходам."
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr "Отбрасывать шаг редукции отрезка при выполнении комплексного деления."
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Использовать правила Фортрана для комплексного умножения и деления."
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr "Размещать элементы данных в отдельных секциях."
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Перечислить все отладочные счетчики с их границами и значениями."
 
-#: common.opt:1214
+#: common.opt:1218
 #, fuzzy, no-c-format
 #| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tЗадать лимит отладочных счетчиков."
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "Выдать секцию .debug_types, если используется формат DWARF v4"
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr "Откладывать \"на потом\" выталкивание аргументов из стека после вызовов функций."
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Заполнять гнезда задержки команд перехода."
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr "Удалять мертвые вычисления, которые могут вызвать исключительные ситуации."
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr "Удалять ненужные сравнения указателей с нулем."
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr "Подать дополнительные данные для поддержки более агрессивной девиртуализации LTO режиме локального преобразования."
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr "Производить спекулятивную девиртуализацию."
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Пытаться преобразовать виртуальные классы в обычные"
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\tВыдавать местоположение источника сообщения один раз или для каждой строки многострочных сообщений."
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr "Показывать исходную строку с указателем позиции."
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tПодкрашивать диагностику."
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy, no-c-format
 #| msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tПодкрашивать диагностику."
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr "Печатать исправляющие подсказки в стандартный протокол в унифицированном diff формате."
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Дополнять диагностические сообщения ключом, который контролирует это сообщение."
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, fuzzy, no-c-format
 #| msgid "-ftabstop=<number>\tDistance between tab stops for column reporting."
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "-ftabstop=<number>\tИнтервал табуляции для правильного определения номера колонки в диагностике."
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, fuzzy, no-c-format
 #| msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 отменяет проход оптимизации."
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, no-c-format
 #| msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 включает проход оптимизации."
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\tВыдать внутреннюю информацию о компиляции в файл."
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=файл\tВывести в файл дамп инструкций в конце компиляции."
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=файл\tЗаписать в файл все декларации в виде кода Go."
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Подавлять вывод адресов в отладочных дампах."
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr "Собрать и выдать отладочную информацию во временный файл, если произошла внутренняя ошибка в C/C++ компиляторе."
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr "Выдать детальную информацию о внутреннем представлении GCC мест исходного кода."
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr "Выдать дампы проходов оптимизации."
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Подавлять вывод номеров инструкций и номеров строк и адресов в отладочных дампах."
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Подавлять вывод номеров предыдущей и следующей инструкций в отладочных дампах."
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Выдавать таблицы DWARF CFI в виде ассемблерных директив .cfi_*"
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr "Выполнять ранние inline-подстановки."
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Выполнить межпроцедурную редукцию агрегатных данных."
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Исключить отладочную информацию о неиспользуемых типах."
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr "Исключить отладочную информацию о неиспользуемых типах."
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "Не подавлять отладочную информацию о классах C++"
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr "Активировать обработку исключительных ситуаций."
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Выполнить некоторые дополнительные дорогостоящие оптимизации."
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tЗадать способ обработки данных с плавающей точкой повышенной точности."
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tЗадать, какие значения FLT_EVAL_METHOD допустимы."
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Выводить в объектные файлы lto и промежуточное, и бинарное представление"
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Предполагать, что результаты вычислений конечны и не NaN."
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<register>\tНе использовать <регистр> при генерации кода."
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Не выделять для значений типа float и double регистры повышенной точности."
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Выполнить оптимизацию распространения на представлении RTL."
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast]\tВыполнить сокращение выражений с плавающей точкой."
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr "Разрешить встроенным функциям ceil, floor, round, trunc возбуждать \"inexact\" исключительные ситуации."
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr "Разрешить хранение адресов функций на регистрах."
 
-#: common.opt:1586
+#: common.opt:1590
 #, no-c-format
 msgid "Place each function into its own section."
 msgstr "Помещать каждую функцию в отдельную секцию."
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr "Выполнить глобальную экономию общих подвыражений."
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "В рамках глобальной экономии общих подвыражений выполнить расширенный перенос чтений из памяти между блоками."
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "В рамках глобальной экономии общих подвыражений выполнить перенос записей в память между блоками."
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "В рамках глобальной экономии общих подвыражений исключать лишние чтения из памяти после записей по тем же адресам."
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Выполнить глобальную экономию общих подвыражений после распределения регистров."
 
-#: common.opt:1624
+#: common.opt:1628
 #, fuzzy, no-c-format
 #| msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr "-fgnat-encodings=[all|gdb|minimal]\tВыбрать баланс между GNAT кодированием и стандартным DWARF порождаемым в отладочной информации."
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr "Разрешить ввод и вывод представления Graphite."
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr "Разрешить трансформации Graphite."
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Выполнять поднятие соседних загрузок для поддержки генерации условных move инструкций."
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr "Пометить все циклы как параллельные."
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr ""
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr "Включить поддержку транзакционной памяти GNU."
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "Использовать STB_GNU_UNIQUE, если поддерживается ассемблером."
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr "Включить оптимизатор гнезд циклов."
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr "Генерировать доступ к битовым полям в соответствии с шириной их типа."
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr "Сливать смежные сохранения."
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr "Оценивать вероятности переходов."
 
-#: common.opt:1703
+#: common.opt:1707
 #, no-c-format
 msgid "Process #ident directives."
 msgstr "Обрабатывать директивы #ident."
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Преобразовывать условные переходы в эквивалентный код без переходов."
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Преобразовывать условные переходы в условно выполняемый код."
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none]\tУстановить уровень переиспользования стека для локальных переменных."
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Преобразовывать условные переходы во внутренних циклах в эквивалентный код без переходов."
 
-#: common.opt:1743
+#: common.opt:1747
 #, no-c-format
 msgid "Do not generate .size directives."
 msgstr "Не генерировать директивы .size."
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr "Выполнить inline-подстановки косвенных вызовов."
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "Включить inline-подстановки функций со спецификатором \"inline\", отмена отключает все inline-подстановки."
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Подставлять тела функций в места вызовов, когда это не увеличивает размер кода."
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Подставлять тела функций без спецификатора \"inline\" в места вызова, когда это выгодно."
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "Подставлять в места вызовов тела функций, вызываемых только один раз."
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<размер>\tМаксимальный <размер> функций для inline-подстановки."
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Делать подстановку операций __atomic, если имеется соответствующая неблокирующая последовательность инструкций"
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "При входе и выходе из функции генерировать вызовы профилирования."
 
-#: common.opt:1810
+#: common.opt:1814
 #, fuzzy, no-c-format
 #| msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=name,...  Не инструментировать перечисленные функции."
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, no-c-format
 #| msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=filename,...  Не инструментировать функции, перечисленные в указанных файлах."
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr "Выполнить межпроцедурное распространение констант."
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Выполнить клонирование для усиления межпроцедурного распространения констант."
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Выполнить межпроцедурное побитное распространение констант."
 
-#: common.opt:1834
+#: common.opt:1838
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis."
 msgid "Perform interprocedural modref analysis."
 msgstr "Выполнить межпроцедурный анализ указателей."
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr "Выполнить межпроцедурное распространение профиля."
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr "Выполнить межпроцедурный анализ указателей."
 
-#: common.opt:1846
+#: common.opt:1850
 #, no-c-format
 msgid "Discover pure and const functions."
 msgstr "Выявлять pure и const функции."
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Выполнять сжатие идентичного кода для функций и read-only переменных."
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr "Выполнять сжатие идентичного кода для функций."
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr "Выполнять сжатие идентичного кода для переменных."
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables."
 msgid "Discover read-only and non addressable static variables."
 msgstr "Выявлять неадресуемые статические переменные, доступные только для чтения."
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables."
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "Выявлять неадресуемые статические переменные, доступные только для чтения."
 
-#: common.opt:1870
+#: common.opt:1874
 #, fuzzy, no-c-format
 #| msgid "Use caller save register across calls if possible."
 msgid "Reduce stack alignment on call sites if possible."
 msgstr "Использовать сохранение регистров вызывающей стороной при всех возможных вызовах."
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr "Выполнять IPA распространение диапазонов значений."
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority] Задать алгоритм раскраски для распределения регистров."
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] Задать регионы для IRA."
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "Использовать IRA для оценки регистрового давления в RTL-оптимизациях циклов."
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "Использовать IRA для оценки регистрового давления в RTL-оптимизациях циклов."
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr "Использовать общие слоты стека для сохранения разных аппаратных регистров"
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Использовать общие слоты стека для сохранения вытолкнутых псевдорегистров"
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<уровень>\tЗадать <уровень> диагностики IRA."
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr "Оптимизировать индуктивные переменные в древовидном представлении."
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Использовать таблицы переходов для достаточно больших операторов switch."
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements."
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "Использовать таблицы переходов для достаточно больших операторов switch."
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Генерировать код для функций даже при 100%% inline-подстановке."
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "Генерировать код для статических функций, даже если они никогда не вызываются."
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr "Не удалять даже неиспользуемые статические константные переменные."
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr "Добавлять в начало внешних символов подчеркивание."
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr "Выполнить CFG-зависимую рематериализацию в LRA."
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr "Включить оптимизации времени компоновки."
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Включить оптимизации времени компоновки с заданным числом параллельных задач или с использованием сервера задач."
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr "Задать алгоритм разделения символов и переменных при компоновке."
 
-#: common.opt:2004
+#: common.opt:2008
 #, fuzzy, no-c-format
 #| msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr "-flto-compression-level=<number>\tИспользовать заданный уровень сжатия <number> zlib для IL."
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "Выдать статистику оптимизации при компоновке."
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Выдать статистику оптимизации при компоновке только для WPA."
 
-#: common.opt:2020
+#: common.opt:2024
 #, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "Устанавливать errno после вызовов встроенных мат. функций."
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<number>\tМаксимальное число сообщений об ошибках."
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr "Выдать информацию о распределении постоянной памяти."
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Выдать информацию о распределении постоянной памяти только для WPA."
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Слить идентичные константы и константные переменные."
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Слить идентичные константы по всем единицам компиляции."
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Попытаться слить одинаковые строки в отладочной информации для всех единиц компиляции."
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Выполнять планирование циклов по модулю методом SMS перед первым проходом планирования команд."
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Выполнять планирование циклов по модулю методом SMS перед первым проходом планирования команд."
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr "Выносить инвариантные вычисления за пределы циклов."
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr "Выполнить оптимизацию удаления мертвых команд в RTL-представлении."
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "Выполнить оптимизацию удаления мертвых команд записи в память в RTL-представлении."
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Включить/отменить обычное планирование для конвейеризованных циклов."
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr "Поддерживать синхронные исключения вне вызовов."
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy, no-c-format
 #| msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr "-foffload=<targets>=<options>  Задать разгружаемые цели и опции для них."
 
-#: common.opt:2087
+#: common.opt:2091
 #, fuzzy, no-c-format
 #| msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr "-foffload-abi=[lp64|ilp32]     Установить ABI используемый в компиляторе разгрузки."
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr "По возможности не создавать кадры стека."
 
-#: common.opt:2104
+#: common.opt:2108
 #, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Включить вывод всей оптимизационной информации в stderr."
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<type>=filename]\tВыдать детали компиляторной оптимизации."
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Оптимизировать парные вызовы и хвостовую рекурсию."
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr "Выполнить частичные inline-подстановки."
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Выдать отчет о распределении памяти перед межпроцедурными оптимизациями."
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr "Паковать поля структур без дыр."
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<number>\tУстановить начальное максимальное выравнивание для элементов структур."
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr "Возвращать короткие агрегатные значения в памяти, а не в регистрах."
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr "Выполнить раскатку циклов."
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr "Выполнить машинно-зависимые оптимизации."
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Выполнить машинно-зависимые оптимизации перед вторым планированием."
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Генерировать позиционно-независимый код, если возможно (режим large)."
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Генерировать позиционно-независимый код для выполняемых модулей, если возможно (режим large)."
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Генерировать позиционно-независимый код, если возможно (режим small)."
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Генерировать позиционно-независимый код для выполняемых модулей, если возможно (режим small)."
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr "Использовать PLT для PIC вызовов (-fno-plt: загрузить адрес из GOT при вызове)."
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr "Задать подгружаемый модуль."
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<name>-<key>[=<value>]\tЗадать аргумент <key>=<value> для подгружаемого модуля <name>."
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr "Выполнить оптимизацию переиспользования вычислений"
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Генерировать команды предвыборки элементов массивов, если они поддерживаются."
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr "Включить генерацию базового кода для профилирования."
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr "Вставлять код для профилирования по дугам управляющего графа программы."
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Включить коррекцию несовместимых с потоком управления данных профилирования."
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tУстановить метод изменения профиля."
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Активировать ключи генерации данных профилирования для выполнения соответствующих оптимизаций."
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Активировать ключи генерации данных профилирования для выполнения соответствующих оптимизаций и установить -fprofile-dir=."
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Активировать ключи оптимизаций, основанных на данных профилирования."
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Активировать ключи оптимизаций, основанных на данных профилирования и установить -fprofile-dir=."
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr "Вставлять код для профилирования значений выражений."
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr "Выдавать отчет о непротиворечивости профиля."
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr "Включить переупорядочение функций улучшающее размещение кода."
 
-#: common.opt:2305
+#: common.opt:2309
 #, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<строка>\tКомпилировать воспроизводимым образом, используя <строку> для генерации случайных чисел."
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr "Записать ключи командной строки gcc в объектный файл"
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr "Возвращать короткие агрегатные значения в регистрах."
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr "Сообщить DSE, что память для C++ объекта мертва, когда конструктор стартует и когда деструктор финиширует."
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Облегчение регистрового давления путем сокращения действующих интервалов."
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr "Выполнить оптимизацию переименования регистров."
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Выполнить оптимизационный проход слияния зависящих от цели инструкций."
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Переупорядочить блоки для улучшения размещения кода."
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr "-freorder-blocks-algorithm=[simple|stc]\tУстановить используемый алгоритм переупорядочения базового блока."
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Переупорядочить блоки и партиции в hot и cold разделы."
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr "Переупорядочить функции для улучшения размещения кода."
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Выполнить экономию общих подвыражений еще и после оптимизации циклов."
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Отменить оптимизации, предполагающие стандартное округление вещественных значений."
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr "Планировать команды в рамках нескольких блоков."
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Использовать планирование команд с учетом регистрового давления."
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr "Разрешить спекулятивный перенос команд, кроме чтения."
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr "Разрешить спекулятивный перенос некоторых команд чтения."
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr "Разрешить более активный спекулятивный перенос команд чтения."
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<уровень>\tУстановить <уровень> подробности сообщений от планировщика."
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "При планировании после распределения регистров, использовать метод суперблоков."
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr "Планировать код перед распределением регистров."
 
-#: common.opt:2449
+#: common.opt:2453
 #, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr "Планировать код после распределения регистров."
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Использовать алгоритм селективного планирования команд."
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr "Выполнить селективное планирование после прохода перегрузки регистров."
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr "Запускать тесты самопроверки, используя заданный маршрут для нахождения тестовых файлов."
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Выполнить программную конвейеризацию внутренних циклов во время селективного планирования."
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Выполнить программную конвейеризацию внешних циклов во время селективного планирования."
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Перепланировать конвейеризованные области без конвейеризации."
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr "Разрешить динамическому компоновщике вставлять функцию (или переменные) с другой семантикой (или инициализатором) соответственно."
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr "Разрешить предварительное планирование отложенных команд."
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<число>\tЗадать <число> отложенных команд, подлежащих предварительному планированию."
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Включить проверку дальности зависимостей при предварительном планировании отложенных команд."
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<number>\tВключить проверку дистанции зависимостей при предварительном планировании отложенных команд."
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Установить групповую эвристику для планировщика."
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Установить эвристику критического пути для планировщика."
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Установить эвристику спекулятивного выполнения команд для планировщика."
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Установить эвристику ранжирования для планировщика."
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Установить эвристику \"последней команды\" для планировщика."
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Установить эвристику по числу зависимых команд для планировщика."
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr "Использовать доступ к данным из одной секции по общим опорным точкам."
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Включить проход исключения избыточных расширений данных."
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Порождать прологи функции только перед частями функции, которым они нужны, а не в начале функции."
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "Упаковать части пролога и эпилога отдельно."
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Отменить оптимизации, влияющие на поведение сигнализирующих NaN по IEEE."
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Отменить оптимизации вычислений с плавающей точкой и игнорировать знак нуля по IEEE."
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr "Преобразовывать вещественные константы к значениям одинарной точности."
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Разбивать диапазоны жизни индуктивных переменных при развертке циклов."
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "Генерировать не непрерывные кадры стека."
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr "Использовать независимые регистры для широких типов."
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy, no-c-format
 #| msgid "Split wide types into independent registers."
 msgid "Split wide types into independent registers earlier."
 msgstr "Использовать независимые регистры для широких типов."
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Включить обратное распространение свойств использования на SSA уровне."
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr "Оптимизировать условные шаблона используя SSA PHI узлы."
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Оптимизировать количество stdarg регистров сохраняемых в стеке в начале функции."
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Выполнять расширение переменных при развертке циклов."
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tГенерировать код для проверки стека."
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<регистр>\tПрерывание при переполнении стека, <регистр> задает границу стека."
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<символ>\tПрерывание при переполнении стека, <символ> задает границу стека."
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "Использовать propolice как метод защиты стека."
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr "Использовать защиту стека для каждой функции."
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Использовать интеллектуальный метод защиты стека для определенных функций."
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Использовать метод защиты стека только для функций со stack_protect атрибутом."
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr "Выводить информацию об использовании стека для каждой функции."
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr "Предполагать строгое соблюдение правил перекрытия данных в памяти."
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Трактовать знаковое переполнение как неопределенное поведение.  Negated as -fwrapv -fwrapv-pointer."
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr "Реализовать __atomic операции посредством библиотечных вызовов унаследованных __sync функций."
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr "Проверить код на наличие синтаксических ошибок и завершить работу."
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr "Создать файлы данных для \"gcov\"."
 
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr "Выполнить протягивание переходов."
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr "Показать время, затраченное каждым проходом компилятора."
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr "Показать время, затраченное подфазами, отдельно."
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tМодель генерации кода для данных, локальных для потов, по умолчанию."
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Переупорядочивать функции, переменные и операторы asm верхнего уровня."
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr "Формировать суперблоки методом дублирования хвостов."
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr "Для целей, которые обычно нуждаются в трамолинах для вложенных функций, всегда генерировать их вместо использования дескрипторов."
 
-#: common.opt:2722
+#: common.opt:2726
 #, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "Предполагать возможность прерываний при плавающих операциях."
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Прерывания при знаковых переполнениях в сложении, вычитании и умножении."
 
-#: common.opt:2730
+#: common.opt:2734
 #, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Включить SSA-оптимизацию  распространения констант на древовидном представлении."
 
-#: common.opt:2734
+#: common.opt:2738
 #, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Включить SSA-BIT-CCP оптимизацию на древовидном представлении."
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr "Включить копирование заголовков циклов в древовидном представлении."
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "Включить SSA соединение пользовательских переменных."
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr "Выполнять распространение копий в древовидном представлении."
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr "Преобразовывать условные записи в безусловные."
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr "Выполнять преобразования в инициализации переключателей."
 
-#: common.opt:2774
+#: common.opt:2778
 #, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Выполнить удаление мертвого SSA-кода на древовидном представлении."
 
-#: common.opt:2778
+#: common.opt:2782
 #, no-c-format
 msgid "Enable dominator optimizations."
 msgstr "Включить оптимизации доминаторов."
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "Включить слияние хвостов в древовидном представлении."
 
-#: common.opt:2786
+#: common.opt:2790
 #, no-c-format
 msgid "Enable dead store elimination."
 msgstr "Выполнить оптимизацию удаления мертвых команд записи в память."
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "Выполнять распространение вперед в древовидном представлении."
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Выполнить полный набор оптимизаций удаления избыточного кода на древовидном  представлении."
 
-#: common.opt:2798
+#: common.opt:2802
 #, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "Включить оптимизацию вычисления длин строк на древовидном представлении."
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "Выполнить распределение циклов на древовидном представлении."
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Выполнить распределение циклов для шаблонов, преобразованных в библиотечные вызовы."
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr "Выполнить вынесение инвариантных вычислений за пределы циклов на древовидном представлении."
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr "Создавать канонические индуктивные переменные в циклах."
 
-#: common.opt:2835
+#: common.opt:2839
 #, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr "Включить оптимизации циклов на древовидном представлении."
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "-ftree-parallelize-loops=<число>\tВключить автоматическое распараллеливание циклов."
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Выполнять поднятие загрузок по условным указателям"
 
-#: common.opt:2847
+#: common.opt:2851
 #, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Включить оптимизации SSA-PRE на древовидном представлении."
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr "В SSA-PRE оптимизации на древовидном представлении включить устранение избыточности часть-часть."
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Выполнить анализ указателей внутри функций на древовидном представлении"
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr "Включить оптимизацию ассоциативных операций на древовидном представлении."
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr "Выполнить погружение SSA-кода на древовидном представлении."
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr "Выполнить прямолинейное понижение силы операций."
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr "Выполнить замену скаляров для агрегатных значений."
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Выполнить замену временных выражений на проходе SSA->normal."
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Выполнить разбиение диапазонов жизни значений на проходе SSA->normal."
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr "Выполнить распространение диапазонов значений на древовидном представлении."
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr "Расщепить маршруты ведущие к обратным ссылкам цикла."
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr "Считать, что common декларации могут быть переопределены другими с большим хвостовым массивом."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr "Компилировать весь модуль за раз."
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Выполнить развертку циклов с известным числом итераций."
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr "Выполнить развертку всех циклов."
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Разрешить оптимизации плавающей арифметики, которые могут изменить результат операции из-за округления."
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "То же, что -fassociative-math для выражений, включающих деление."
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Разрешить оптимизации плавающих вычислений, которые могут противоречить стандартам IEEE или ISO."
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Выполнить декомпозицию циклов, содержащих условные ветвления."
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Выполнить расщепление циклов"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Генерировать unwind-таблицы только для обработки исключений."
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Использовать bfd компоновщик вместо подразумеваемого."
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Использовать gold компоновщик вместо подразумеваемого."
 
-#: common.opt:2964
+#: common.opt:2968
 #, fuzzy, no-c-format
 #| msgid "Use the gold linker instead of the default linker."
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Использовать gold компоновщик вместо подразумеваемого."
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Выполнить отслеживание переменных."
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Выполнить отслеживание переменных путем аннотирования присваиваний."
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Переключить -fvar-tracking-assignments."
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Выполнить отслеживание переменных и пометить неинициализированные переменные."
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Выполнить векторизацию циклов на древовидном представлении."
 
-#: common.opt:3011
+#: common.opt:3015
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Выполнить векторизацию циклов на древовидном представлении."
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Выполнить векторизацию базовых блоков (SLP) на древовидном представлении."
 
-#: common.opt:3019
+#: common.opt:3023
 #, fuzzy, no-c-format
 #| msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tЗадает ценовую модель для векторизации."
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, no-c-format
 #| msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tЗадает ценовую модель для кода помеченного simd директивой."
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Enables the dynamic vectorizer cost model.  Сохранён для обратной совместимости."
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Выполнять распространение копий по информации об эволюции скалярных значений."
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Добавить комментарии к ассемблерному коду."
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tУстановить атрибут видимости символов по умолчанию."
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "Проверяйте vtable указатели до их использования."
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Выдать vtable верификационные счетчики."
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Выдать информацию о множествах vtable верификационных указателей."
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Использовать данные профилирования значений при оптимизациях."
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Снять зависимости между различными использованиями одной и той же переменной."
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Выполнить удаление условного мертвого кода для вызовов встроенных функций."
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Выполнить оптимизации на уровне всей программы."
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Предполагать циклический перенос при арифметических переполнениях."
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Помещать данные, инициализированные нулями, в секцию bss."
 
-#: common.opt:3135
+#: common.opt:3139
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls."
 msgid "Clear call-used registers upon function return."
 msgstr "Сохранять/восстанавливать регистры до/после вызовов функций."
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Генерировать отладочную информацию в формате по умолчанию."
 
-#: common.opt:3143
+#: common.opt:3147
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> требует поддержку ассемблера для CFI директив"
 
-#: common.opt:3147
+#: common.opt:3151
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> требует поддержку ассемблера для CFI директив"
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Записывать DW_AT_decl_column и DW_AT_call_column в DWARF."
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Генерировать отладочную информацию в подразумеваемой версии DWARF формата."
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Генерировать отладочную информацию в формате DWARF версии 2 (или более поздней)."
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Генерировать отладочную информацию в расширенном формате по умолчанию."
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function."
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Генерировать одну выходную точку для каждой функции."
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Не генерировать DWARF pubnames и pubtypes секции."
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Генерировать DWARF pubnames и pubtypes секции."
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Генерировать DWARF pubnames и pubtypes секции с GNU расширениями."
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Записывать ключи командной строки gcc в DWARF DW_AT_producer."
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Генерировать отладочную информацию в отдельных .dwo файлах."
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Генерировать отладочную информацию в формате STABS."
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Генерировать отладочную информацию в расширенном формате STABS."
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Не генерировать дополнения DWARF, не входящие в выбранную версию."
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Переключить генерацию отладочной информации."
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Генерировать отладочную информацию в формате VMS."
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Генерировать отладочную информацию в формате XCOFF."
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Генерировать отладочную информацию в расширенном формате XCOFF."
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Генерировать сжатые debug секции."
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<format>\tГенерировать сжатые отладочные секции в формате <format>."
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<каталог>\tУстановить <каталог> подгружаемых модулей по умолчанию."
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <каталог>\tУстановить <каталог> заголовочных файлов для мультиархитектуры."
 
-#: common.opt:3320
+#: common.opt:3324
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <файл>\tЗаписать результат в <файл>."
 
-#: common.opt:3324
+#: common.opt:3328
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Включить профилирование функций."
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Как -pedantic, но выдавать ошибки, а не предупреждения."
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Не отображать время компиляции функций."
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Включить подробную выдачу."
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Показать версию компилятора."
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Подавить выдачу предупреждений."
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Создать разделяемую библиотеку."
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Использовать сохранение регистров вызывающей стороной при всех возможных вызовах."
@@ -19587,1147 +19588,1157 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr "Максимальное число аргументов PHI, при котором FSM не будет пытаться протягивать переходы через соответствующий блок."
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr "Масштабирующий множитель, применяемый к числу блоков на проходе протягивания переходов при сравнении с (масштабированным) числом операторов."
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr "Масштабный множитель для применения к числу операторов в потоковом маршруте при сравнении с числом (масштабированных) блоков."
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "Пороговое соотношение счётчиков выполнения критических дуг, при котором после прохода reload может выполняться частичное удаление избыточных операций."
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "Пороговое отношение для выполнения частичного удаления избыточных операций после прохода reload."
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr "Масштабирующий множитель при вычислении максимального расстояния, на которое выражение может быть смещено при GCSE."
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr "Стоимость, при которой в GCSE не будет ограничиваться расстояние перемещения выражений."
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "Минимальный объем кучи, при котором включается сбора мусора, в процентах от общего размера памяти, выделенного под кучу."
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "Минимальный размер кучи в килобайтах, при котором включается сбор мусора, в килобайтах."
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 #| msgid "maximum number of arrays per scop."
 msgid "Maximum number of arrays per SCoP."
 msgstr "максимальное число массивов на один scop."
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP."
 msgid "Maximum number of parameters in a SCoP."
 msgstr "максимальное число параметров в SCoP."
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal count of repetitions of basic block in program given basic block needs to have to be considered hot"
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "Относительное максимальное число повторений блока в программе, при превышении которого блок должен считаться критическим"
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot."
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "Относительная максимальная частота повторений блока в программе, при превышении которой блок должен считаться критическим."
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr "Минимальная оценка ускорения, при которой допускается игнорирование параметров inline-insns-single и inline-insns-auto."
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "Максимальный рост объема кода для единицы компиляции в результате inline-подстановок (в процентах)."
 
-#: params.opt:242
+#: params.opt:247
 #, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "Максимальное число небольших целочисленных констант, для которых в компиляторе будут использованы разделяемые структуры."
 
-#: params.opt:246
+#: params.opt:251
 #, fuzzy, no-c-format
 #| msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone.."
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr "Пороговое значение оценки целесообразности клонирования при выполнении межпроцедурного распространения констант."
 
-#: params.opt:250
+#: params.opt:255
 #, fuzzy, no-c-format
 #| msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known.."
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr "Бонус времени компиляции, назначаемый IPA-CP тем кандидатам, которые позволяют определить границы или шаг цикла."
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions."
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "Максимальная глубина рекурсивных inline-подстановок для inline функций."
 
-#: params.opt:258
+#: params.opt:263
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Выполнять рекурсивную inline-подстановку, только если вероятность данного вызова превышает значение этого параметра."
 
-#: params.opt:262
+#: params.opt:267
 #, fuzzy, no-c-format
 #| msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning.."
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr "Штрафная наценка в процентах для рекурсивных функций при их оценке для клонирования."
 
-#: params.opt:266
+#: params.opt:271
 #, fuzzy, no-c-format
 #| msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning.."
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr "Штрафная наценка в процентах для функций с единственным вызовом другой функции при их оценке для клонирования."
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "Максимальный рост объема кода для единицы компиляции в результате межпроцедурного распространения констант (в процентах)."
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large."
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "Размер тела \"большой\" функции."
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr "Максимальный размер списка значений, ассоциированных с каждым параметром, при межпроцедурном распространении констант."
 
-#: params.opt:282
+#: params.opt:287
 #, fuzzy, no-c-format
 #| msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr "Максимальное число элементов совокупного содержимого для параметра в функциях перехода и решетках."
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr "Максимальное число операторов, исследуемых IPA при анализе формальных параметров на основе анализа алиасов в данной функции."
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr "Максимальное число элементов совокупного содержимого для параметра в функциях перехода и решетках."
 
-#: params.opt:294
+#: params.opt:299
 #, fuzzy, no-c-format
 #| msgid "Maximum number of conditional store pairs that can be sunk."
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "Число отложенных пар условной записи, которые могут быть \"утоплены\"."
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr "Максимальный допустимый размер новых параметров, при котором выполняется замена указателя на агрегат при ipa-sra."
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr "Число регистров в каждом классе, оставляемых неиспользуемыми при вынесении инвариантов цикла."
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr "Максимальный размер таблицы конфликтов в мегабайтах."
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr "Максимальное число циклов для использования распределения регистров по регионам."
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "Если число кандидатов в множестве меньше этого значения, то при оптимизации множества всегда делается попытка удалить неиспользуемые независимые переменные."
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "Если число кандидатов менее данного значения, при оптимизации индуктивных переменных рассматриваются все кандидаты."
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "Если число использований индуктивных переменных больше данного параметра, то их оптимизация не производится."
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr "Размер строки кэша L1."
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr "Размер кэша L1."
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr "Размер кэша L2."
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Максимальный рост объема \"большой\" функции в результате inline-подстановок (в процентах)."
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr "Размер тела \"большой\" функции."
 
-#: params.opt:366
+#: params.opt:371
 #, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "Размер кадра стека, считающийся большим."
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Максимальный рост кадра стека из-за inline-подстановок функций (в процентах)."
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr "Размер тела \"большой\" функции."
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "При вынесении инвариантов цикла - минимальная цена выражения, рассматриваемого как дорогостоящее."
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, fuzzy, no-c-format
 #| msgid "size of tiles for loop blocking."
 msgid "Size of tiles for loop blocking."
 msgstr "размер полос для блочной трансформации циклов."
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "Максимальное среднее число реально выполняемых инструкций в развёрнутом цикле"
 
-#: params.opt:398
+#: params.opt:403
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically."
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "Максимальное число итераций цикла для статического предсказания."
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr "максимальное число базовых блоков в цикле для вынесения инвариантов цикла."
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr "максимальное число ссылок на данные для построения циклических зависимостей по данным."
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in basic block to be considered for SLP vectorization."
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "Максимальное число инструкций в базовом блоке для его векторизации."
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop."
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "Максимальное число инструкций в развернутом цикле."
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr "Минимальная вероятность сквозного перехода в процентах, чтобы добавить блок к EBB наследования при локальном распределении регистров (LRA)"
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr "Максимальное число reload-псевдорегистров, рассматриваемых при спиллинге не-reload псевдорегистра"
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr "Минимальный размер (число инструкций в) партиции при разбиении программы во время LTO."
 
-#: params.opt:430
+#: params.opt:435
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP."
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr "максимальное число параметров в SCoP."
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr "Минимальный размер (число инструкций в) партиции при разбиении программы во время LTO."
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr "Число партиций для разбиения программы."
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "Максимальное среднее число реально выполняемых инструкций в развернутом цикле."
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr "Максимальное число инструкций, для которых на проходе combine рассматривается возможность комбинирования."
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "Максимальная глубина гнезда циклов, которое может быть полностью раскатано."
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Максимальный коэффициент, допустимый для полной раскатки цикла."
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "Максимальное число инструкций в полностью раскатанном цикле."
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "Максимальное число входящих дуг, рассматриваемых при перекрестных переходах."
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr "Максимальное число инструкций, обрабатываемых CSE между сбросами хеш-таблицы."
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr "Максимальная длина пути, рассматриваемого при экономии общих подвыражений."
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Максимальное число позиций в памяти, записываемых cselib."
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr "Макс. count of debug markers to expand or inline."
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "Максимальное число команд, рассматриваемых при заполнении гнезд задержки."
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "Максимальное число команд, рассматриваемых при вычислении областей жизни значений на регистрах."
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr "Максимальное число активных локальных записей при исключении мертвых записей на RTL-представлении."
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "Максимальное число вложенных косвенных inline-подстановок, выполняемых при первом проходе подстановок."
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "Если число  полей в структуре больше данного параметра, то при анализе указателей вся структура рассматривается как одна переменная."
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr "Максимальное число базовых блоков в конечном автомате, используемом на проходе протягивания переходов."
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr "Максимальное число копируемых инструкций при дублировании блоков конечного автомата на проходе протягивания переходов."
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "Максимальное число новых путей протягивания переходов, которые могут быть созданы в конечном автомате."
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "Максимальное отношение числа вставок к числу удалений выражений при глобальном исключении общих подвыражений (GCSE)."
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE."
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "Максимальный объем памяти для работы GCSE."
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "Максимальное число дублируемых инструкций при факторизации вычисляемых goto."
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "Максимальный коэффициент увеличения размера кода при копировании базовых блоков."
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr "Максимальная глубина поиска в дереве доминаторов для поднятия выражения."
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "Максимальное число команд при автоматической inline-подстановке."
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "Максимальное число команд, на которое может увеличиться inline-функция в результате рекурсивной подстановки."
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "Максимальное число инструкций, на которое может увеличится не-inline функция в результате рекурсивных inline-подстановок."
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "Максимальное число команд в функции, пригодной для inline-подстановки."
 
-#: params.opt:550
+#: params.opt:555
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining."
 msgid "The maximum number of instructions when inlining for size."
 msgstr "Максимальное число команд при автоматической inline-подстановке."
 
-#: params.opt:554
+#: params.opt:559
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining."
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "Максимальное число команд при автоматической inline-подстановке."
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "Максимальная глубина рекурсивных inline-подстановок для inline функций."
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "Максимальная глубина рекурсивных inline-подстановок для не-inline функций."
 
-#: params.opt:566
+#: params.opt:571
 #, fuzzy, no-c-format
 #| msgid "maximum number of isl operations, 0 means unlimited"
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Максимальное число isl-операций, 0 означает отсутствие ограничений"
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "Граница цены выражения для вычисления числа итераций."
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "Максимальное число итераций, при вычислении которого будет применен метод \"грубой силы\"."
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "Максимальное число инструкций в блоке, который необходимо дублировать при протягивании переходов."
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "Максимальный размер выражения (число RTL-узлов), которое может быть записано как последнее известное значение псевдорегистра."
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "Максимальное число инструкций в заголовке цикла, дублируемых в проходе копирования заголовков цикла."
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "Максимальное число попыток возврата при программной конвейеризации (планировании по модулю) цикла."
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr "Максимальная длина частичного antic-множества при выполнении предоптимизации древовидного представления."
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "Максимальное число ветвлений на пути вдоль раскатанной последовательности."
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "Максимальный коэффициент раскатки цикла."
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr "Максимальное число инструкций в раскатанном цикле."
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "Максимальный размер списка ждущих операций при планировании."
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "Максимальное число блоков в отрезке для междублочночного планирования."
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "Максимальное число инструкций в отрезке для межблочного планирования."
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr "Максимальная глубина цепочек sqrt при вычислении экспоненты вещественной константы."
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "Максимальное число итераций цикла для статического предсказания."
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "Максимальное число инструкций для обратного просмотра при поиске эквивалентной загрузки в регистр."
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Максимальное число инструкций в базовом блоке, пригодном для if-конверсии."
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr "Максимальная допустимая стоимость последовательности, генерируемой при if-конверсии для перехода, который считается предсказуемым."
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr "Максимальная допустимая стоимость последовательности, генерируемой при if-конверсии для перехода, который считается непредсказуемым."
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "Максимальное число итераций по CFG для расширения регионов."
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "Максимальная отсрочка конфликта для команды, рассматриваемой как кандидат для спекулятивного перемещения."
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "Максимальное число готовых к исполнению инструкций, рассматриваемых планировщиком на первом проходе планирования."
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr "Максимальная длина сканирования кандидатов для прямого понижения мощности операций."
 
-#: params.opt:670
+#: params.opt:675
 #, fuzzy, no-c-format
 #| msgid "Maximum number of may-defs visited when devirtualizing speculatively"
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr "Максимальное число may-defs, просматриваемых при спекулятивной девиртуализации"
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr "Максимальная глубина рекурсии, допустимая при запросах свойств SSA-имен."
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "Максимальное число активных локальных записей при исключении мертвых записей на RTL-представлении."
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "Число отложенных пар условной записи, которые могут быть \"утоплены\"."
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 #| msgid "Maximum number of constant stores to merge in the store merging pass."
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "Максимальное число активных локальных записей при исключении мертвых записей на RTL-представлении."
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr "Максимальное число похожих базовых блоков, с которыми сравнивается данный блок."
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr "Максимальное число итераций обработки каждой функции."
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr "Максимальное число строк, для которых проход оптимизации strlen будет отслеживать длины."
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr "Максимальное число аргументов PHI, поддерживаемое if-конверсией на древовидном представлении, если цикл не помечен прагмой simd."
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Максимальный коэффициент развертки цикла."
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "Максимальное число инструкций в развернутом цикле."
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "Максимальное число инструкций в разомкнутом (unswitched) цикле."
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Максимальный число размыканий одного цикла."
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "При использовании -fvariable-expansion-in-unroller - максимальное число копий каждой переменной, которое может быть создано при развертке цикла."
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr "Макс. глубина рекурсии в раскрытии выражений при отслеживании переменных."
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr "Макс. размер списка позиций, для которых должны добавляться обратные операции."
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr "Макс. размер хеш-таблиц для отслеживания переменных."
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, fuzzy, no-c-format
 #| msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP"
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr "Максимальное число утверждений (assertions), добавляемых вдоль default-дуги оператора switch во время VPR"
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "Минимальное число совпадающих инструкций, при котором применяется оптимизация перекрестных переходов."
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Выполнять рекурсивную inline-подстановку, только если вероятность данного вызова превышает значение этого параметра."
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr "Мин. отношение числа инструкций к числу предвыборок для включения предвыборок в циклах с неизвестным числом итераций."
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr "Минимальный идентификатор (UID), используемый для неотладочных инструкций."
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr "Минимальный размер переменных, которые могут разделять позицию в стеке в отсутствие оптимизации."
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "Минимальная вероятность достижения блока для спекулятивного межблочного планирования."
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "При включенном -ftree-vectorize, минимальное число итераций цикла, пригодного для векторизации."
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr "Размер чанка в OMP-расписании для автоматически распараллеливаемых циклов."
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Минимальное число инструкций итераций на поток в развёрнутом цикле"
 
-#: params.opt:790
+#: params.opt:808
 #, fuzzy, no-c-format
 #| msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr "Размер чанка в OMP-расписании для автоматически распараллеливаемых циклов."
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr "Максимальная вероятность входного базового блока разбиваемого региона (в процентах по отношению к входному блоку функции) для выполнения частичной inline-подстановки."
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "Максимальная оценка перехода по ветвлению, которое считается предсказанным."
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "Число инструкций, выполненных до завершения предвыборки."
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr "Мин. отношение числа инструкций к числу операций с памятью для включения предвыборок в цикле."
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, fuzzy, no-c-format
 #| msgid "use internal function id in profile lookup."
 msgid "Use internal function id in profile lookup."
 msgstr "использовать внутренний идентификатор функции при поиске в профиле."
 
-#: params.opt:840
+#: params.opt:858
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of a loop nest we completely peel."
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "Максимальная глубина гнезда циклов, которое может быть полностью раскатано."
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr "Максимальное число разрешений неоднозначности при выполнении доступа к памяти."
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "Верхняя граница сложности выражений при анализе эволюции скалярных значений в циклах."
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "Верхняя граница размера выражений при анализе эволюции скалярных значений в циклах."
 
-#: params.opt:856
+#: params.opt:874
 #, fuzzy, no-c-format
 #| msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into; at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr "Флаг модели планирования для аппаратной предвыборки.  Количество циклов, на которые ведётся планирование; при 0 используется только эвристика сортировки инструкций.  По умолчанию эта опция отключена."
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr "Минимальная дистанция между возможно конфликтующими записью и чтением."
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr "Алгоритм для -fsched-pressure."
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "Минимальная вероятность успеха при спекулятивном доступе (в процентах) для планирования спекулятивной команды"
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr "Минимальная вероятность, которую должно иметь ребро, чтобы планировщик сохранил свое состояние после прохождения ребра."
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "Максимальное число команд в списке готовых, которые могут рассматриваться как кандидаты на переименование."
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr "Максимальный размер окна при селективном планировании."
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "Максимальное возможное количество планируемых выполнений команды."
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr "Число предвыборок, которые могут выполняться одновременно."
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr "Относительная частота выполнения целевого блока (в процентах), необходимая для погружения инструкции."
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "Число тактов, учитываемых алгоритмом swing modulo scheduling при проверке конфликтов по ресурсам."
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "Пороговое значение среднего числа итераций цикла для применения конвейеризации методом swing modulo scheduling."
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "Множитель для настройки верхней границы числа тактов при конвейеризации циклов методом swing modulo scheduling."
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr "Минимальное число стадий в конвейеризованном цикле при планировании методом swing modulo scheduling."
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr "Максимальный размер агрегатных объектов (в единицах памяти), для которых при оптимизации по размеру может выполняться скаляризация."
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr "Максимальный размер агрегатных объектов (в единицах памяти), для которых при оптимизации по скорости может выполняться скаляризация."
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 #| msgid "The maximum number of stmts in loop nest for loop interchange."
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "Максимальное среднее число реально выполняемых инструкций в развёрнутом цикле"
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "Ограничение снизу на буфер для защиты от разрушения стека."
 
-#: params.opt:932
+#: params.opt:950
 #, fuzzy, no-c-format
 #| msgid "Size of the stack guard expressed as a power of two."
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr "Size of the stack guard expressed as a power of two."
 
-#: params.opt:936
+#: params.opt:954
 #, fuzzy, no-c-format
 #| msgid "Size of the stack guard expressed as a power of two."
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr "Size of the stack guard expressed as a power of two."
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr "Разрешить проходу слияния записей в память генерировать невыровненные записи, если это допустимо."
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "Максимальное отношение между размером массива и числом веток в переключателе, при котором будет выполнена трансформация переключателя в таблицу."
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP."
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "максимальное число параметров в SCoP."
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP."
 msgid "Maximum number of references stored in each modref base."
 msgstr "максимальное число параметров в SCoP."
 
-#: params.opt:960
+#: params.opt:978
 #, fuzzy, no-c-format
 #| msgid "Maximum number of constant stores to merge in the store merging pass."
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "Максимальное число активных локальных записей при исключении мертвых записей на RTL-представлении."
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 #| msgid "Maximum number of disambiguations to perform per memory access."
 msgid "Maximum number of tests performed by modref query."
 msgstr "Максимальное число разрешений неоднозначности при выполнении доступа к памяти."
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, fuzzy, no-c-format
 #| msgid "Maximum number of times that an insn could be scheduled."
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "Максимальное возможное количество планируемых выполнений команды."
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr "Размер в байтах, при превышении которого локальные для потоков агрегаты будут инструментированы функциями журналирования вместо команд сохранения/восстановления."
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "Процент объёма кода функции, взвешенный по частоте выполнения, который должен быть охвачен при формировании трасс планирования. Используется, когда имеются данные профилирования."
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "Процент объёма кода функции, взвешенный по частоте выполнения, который должен быть охвачен при формировании трасс планирования. Используется, когда имеются данные профилирования."
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Максимальный рост кода за счёт дублирования хвостов (в процентах)."
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "Прекратить просмотр, если вероятность лучшей дуги меньше заданного порогового значения (в процентах). Используется, когда имеются данные профилирования."
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "Прекратить просмотр, если вероятность лучшей дуги меньше заданного порогового значения (в процентах). Используется, когда имеются данные профилирования."
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "Прекратить обратный просмотр, если обратная вероятность лучшей дуги меньше заданного порогового значения (в процентах)."
 
-#: params.opt:1004
+#: params.opt:1022
 #, fuzzy, no-c-format
 #| msgid "Set the maximum number of instructions executed in parallel in reassociated tree. If 0, use the target dependent heuristic.."
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr "Максимальное число параллельно выполняемых инструкций в дереве при реассоциировании ассоциативных операций. При 0 использовать эвристику данной целевой платформы."
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 #| msgid "Emit implicit instantiations of templates."
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "Генерировать неявные конкретизации шаблонов."
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr "Максимальное вложенных вызовов для поиска зависимостей по управлению при анализе неинизиализированных имён."
 
-#: params.opt:1020
+#: params.opt:1038
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues."
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "Использовать подпрограммы для прологов/эпилогов функций."
 
-#: params.opt:1024
+#: params.opt:1042
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues."
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "Использовать подпрограммы для прологов/эпилогов функций."
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, fuzzy, no-c-format
 #| msgid "The minimum fraction of profile runs a given basic block execution count must be not to be considered unlikely."
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr "Минимальная доля профиля, такая, что если счётчик блока ее превышает, то он не считается маловероятным"
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr "Использовать явно инструкции poison/unpoison для теневой памяти для переменных, размер которых не превышает указанного."
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr "Использовать ли канонические типы."
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "Выполнить векторизацию эпилогов циклов, используя меньший размер векторов."
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr "Максимальное число начальных итераций цикла, которые могут быть раскатаны для выравнивания данных в цикле."
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "Максимальное число проверок времени выполнения, добавляемых в код при векторизации циклов для проверки алиасов."
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Максимальное число проверок времени выполнения, добавляемых в код при векторизации циклов для проверки выравнивания."
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20758,7 +20769,7 @@ msgid "expected boolean type"
 msgstr "ожидался булевый тип"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "ожидалось целое"
@@ -20824,7 +20835,7 @@ msgstr "недостаточно аргументов"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "слишком много аргументов"
@@ -21179,7 +21190,7 @@ msgstr ""
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "предыдущая декларация здесь"
@@ -21235,7 +21246,7 @@ msgstr "атрибуты типов игнорируются, если тип у
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -21264,20 +21275,20 @@ msgstr "атрибуты типов игнорируются, если тип у
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21288,8 +21299,8 @@ msgstr "атрибут %qE проигнорирован"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "предыдущая декларация %qD"
@@ -21299,48 +21310,48 @@ msgstr "предыдущая декларация %qD"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "проигнорированы атрибуты, примененные к %qT после определения"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D уже декларирован(а) с атрибутом dllexport: dllimport игнорируется"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D повторно декларирован(а) без атрибута dllimport после ссылок с dll привязкой"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D повторно декларирован(а) без атрибута dllimport: предшествующая декларация с dllimport игнорируется"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared as  dllimport: attribute ignored"
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "inline функция %q+D декларирована как dllimport: атрибут игнорируется"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "определение функции %q+D помечено dllimport"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "определение переменной %q+D помечено dllimport"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "символ %q+D должен быть внешним, поскольку задан атрибут %qE"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qE предполагает видимость по умолчанию, но %qD уже был декларирован с другим атрибутом видимости"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
@@ -21348,13 +21359,13 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "%qD target declared here"
 msgstr "%qD было объявлено здесь"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -21468,7 +21479,7 @@ msgstr "параметр шаблона %qD декларирован здесь"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "смещение %qwi вне границ константной строки"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -21494,509 +21505,509 @@ msgstr "третий аргумент %<__builtin_prefetch%> должен быт
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "вместо неверного третьего аргумента %<__builtin_prefetch%> используется ноль"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 #| msgid " declared here"
 msgid "source object declared here"
 msgstr " объявлено здесь"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 #| msgid "in call to %qD, declared here"
 msgid "destination object declared here"
 msgstr "в вызове %qD, декларированной здесь"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 #| msgid "a function-definition is not allowed here"
 msgid "destination object allocated here"
 msgstr "function-definition здесь не допускается"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu bytes into a destination of size %wu"
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr "%qE вывод %wu байт в приемник размера %wu"
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu bytes into a destination of size %wu"
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr "%qE вывод %wu байт в приемник размера %wu"
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "%qE writing a terminating nul past the end of the destination"
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr "%qE запись завершающего nul после конца приемника"
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, fuzzy, gcc-internal-format
 #| msgid "%qE writing a terminating nul past the end of the destination"
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr "%qE запись завершающего nul после конца приемника"
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, fuzzy, gcc-internal-format
 #| msgid "%qE writing a terminating nul past the end of the destination"
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr "%qE запись завершающего nul после конца приемника"
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu bytes into a destination of size %wu"
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr "%qE вывод %wu байт в приемник размера %wu"
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kreading %E byte from a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu bytes into a destination of size %wu"
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr "%qE вывод %wu байт в приемник размера %wu"
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -22006,7 +22017,7 @@ msgstr[0] "%<%.*s%> директивная запись %wu байт в обла
 msgstr[1] "%<%.*s%> директивная запись %wu байт в область размера %wu"
 msgstr[2] "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -22016,180 +22027,180 @@ msgstr[0] "%<%.*s%> директивная запись %wu байт в обла
 msgstr[1] "%<%.*s%> директивная запись %wu байт в область размера %wu"
 msgstr[2] "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu bytes into a destination of size %wu"
 msgid "at offset %s into destination object %qE of size %s"
 msgstr "%qE вывод %wu байт в приемник размера %wu"
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "слишком мало аргументов в вызове функции %<va_start%>"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "некорректный аргумент для %qD"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "неподдерживаемый аргумент для %qD"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr "вызов %qD с ненулевым аргументом небезопасен"
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "оба аргумента %<__builtin___clear_cache%> должны быть указателями"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "сгенерирован трамплин для вложенной функции %qD"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "семантика %qD изменилась в GCC 4.4"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "неизвестный спецификатор архитектуры в модели памяти встроенной функции"
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "некорректный аргумент модели памяти в вызове встроенной функции"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "модель памяти для случая отказа не может быть сильнее, чем для случая успеха в вызове %<__atomic_compare_exchange%>"
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "задан некорректный аргумент модели памяти для случая отказа в вызове %<__atomic_compare_exchange%>"
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "недопустимая модель памяти в вызове %<__atomic_load%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "недопустимая модель памяти в вызове %<__atomic_store%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 1 to %qs"
 msgstr "константный аргумент для %qs вне диапазона"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-integer argument 1 to %qs"
 msgstr "константный аргумент для %qs вне диапазона"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_thread_pointer is not supported on this target"
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_thread_pointer не поддерживается для этой платформы"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_set_thread_pointer is not supported on this target"
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_set_thread_pointer не поддерживается для этой платформы"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "-mll64 is only supported for ARC HS cores"
 msgid "%qs only supported in OpenACC code"
 msgstr "-mrelax поддерживается только для RTP PIC"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 0 to %qs"
 msgstr "константный аргумент для %qs вне диапазона"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to %qs"
 msgid "illegal argument 0 to %qs"
@@ -22197,127 +22208,127 @@ msgstr "отсутствует аргумент для %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kнекорректное использование %<__builtin_va_arg_pack ()%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kнекорректное использование %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "второй аргумент %<__builtin_longjmp%> должен быть 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "целевой формат не поддерживает бесконечные значения"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> в функции с фиксированным числом аргументов"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "неверное число аргументов в вызове функции %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "вызов %<__builtin_next_arg%> без аргумента"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "неверное число аргументов в вызове функции %<__builtin_next_arg%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "второй аргумент %<va_start%> не является последним явным аргументом"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "неопределенное поведение, если второй параметр %<va_start%> продекларирован с классом памяти %<register%>"
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "объявлено здесь"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 #| msgid "required from %q#D\n"
 msgid "returned from %qD"
 msgstr "требуемый из %q#D\n"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 #| msgid "required from %q#D\n"
 msgid "returned from %qT"
 msgstr "требуемый из %q#D\n"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "obtained here"
 msgstr "объединение определено здесь"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "assigned here"
 msgstr "структура определена здесь"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -23099,309 +23110,309 @@ msgstr "блоки не были размещены последовательн
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "число меток блоков в списке RTL-инструкций (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "missing direct call for speculation %i"
 msgstr "Отсутствует спецификатор измерения в %C"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "отсутствует барьер после блока %i"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "для дуги %s->%s установлено вспомогательное поле"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "подставляемый клон в том же списке comdat группы"
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "inline clone is forced to output"
 msgid "inline clone count is not compatible"
 msgstr "inline клон принудительно выводится"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "%<priority%> value must be non-negative"
 msgid "tp_first_run must be non-negative"
 msgstr "значение %<priority%> должен быть неотрицательным"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "локальные символы должны быть определены"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "видимый извне inline клон"
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "взятие inline клона с адресом"
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "inline клон принудительно выводится"
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 #| msgid "returns_nonnull attribute on a function not returning a pointer"
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "returns_nonnull атрибут для функции не возвращающей указатель"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux поле установлено для косвенной дуги из %s"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "edge count is not compatible with function count"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Косвенная дуга из %s не помечена как косвенная или имеет ассоциированную indirect_info, соответствующий оператор есть: "
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "comdat-local функция вызвана из %s вне ее comdat"
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "некорректный указатель inlined_to"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "множественные inline-вызовы"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "указатель inlined_to установлен для не inline вызова"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "указатель inlined_to установлен, но не найдено ни одного предшественника"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "указатель inlined_to ссылается на себя"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node имеет некорректный clone_of"
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node имеет некорректный список клонов"
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "cgraph_node в списке клонов, но он не клон"
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "cgraph_node имеет некорректный prev_clone указатель"
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "испорчен двусвязный список клонов"
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias имеет дуги вызовов"
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias имеет не-alias ссылку"
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias имеет более одной alias ссылки"
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Проанализированный alias не имеет ссылки"
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Нет дуги из thunk-узла"
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Более одной дуги исходит из thunk-узла"
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Thunk не должен иметь тела"
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "разделяемый call_stmt:"
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "дуга указывает на неверную декларацию:"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "косвенная дуга с неизвестной вызываемой функцией, соответствующая call_stmt, в известной декларации"
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "отсутствует дуга callgraph для инструкции вызова:"
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "ссылка на мертвый оператор"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "отсутствует call_stmt, соответствующий дуге %s->%s"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "косвенная дуга из %s не имеет соответствующего call_stmt"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of register to a different size"
 msgid "origin points to a different parent"
 msgstr "преобразование регистра к другому размеру"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "процедура verify_cgraph_node выявила ошибки"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: section %s is missing"
 msgid "%s: section %s.%d is missing"
@@ -23493,12 +23504,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "атрибут %<weakref%> игнорируется, поскольку переменная инициализирована"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F используется, но нигде не определена"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
@@ -23569,7 +23580,7 @@ msgstr "размер возвращаемого значение %q+D равен
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "размер возвращаемого значение %q+D превышает %wd байт"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "обнаружены узлы с неосвобожденной памятью"
@@ -24004,12 +24015,12 @@ msgstr "игнорирование возможно конфликтующих 
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr "множественные программы индивидуальности для EH поддерживаются, только если ассемблер поддерживает директиву .cfi_personality"
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) найден в расположении переменной"
@@ -24029,7 +24040,7 @@ msgstr "разделяемый rtx"
 msgid "internal consistency failure"
 msgstr "обнаружена несогласованность внутреннего представления gcc"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "Внутренняя ошибка: использование emit_insn вместо emit_jump_insn:\n"
@@ -24167,42 +24178,42 @@ msgstr "ошибка закрытия дамп-файла прохода final %
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "большая константа с фиксированной точкой неявно урезана к типу с фиксированной точкой"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "при данной ширине битового поля результат сравнения - всегда %d"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "предполагается, что при упрощении проверки диапазона не произошло переполнение"
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "результат сравнения - всегда %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> от двух сравнений на неравенство с разными величинами - всегда 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> от двух взаимно исключающих сравнений на равенство - всегда 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "предполагается, что при редукции константы в сравнении не произошло переполнение"
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "предполагается, что при комбинировании констант вокруг сравнения не произошло переполнение"
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "проверка fold: исходное дерево изменено функцией fold"
@@ -24219,7 +24230,7 @@ msgstr "общий размер локальных объектов слишко
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "общий размер локальных объектов слишком велик"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "некорректное ограничение в %<asm%>"
@@ -24873,7 +24884,7 @@ msgstr "переход по пустому указателю"
 msgid "function may return address of local variable"
 msgstr "функция может возвращать адрес локальной переменной"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "функция возвращает адрес локальной переменной"
@@ -25267,73 +25278,73 @@ msgstr "заданная граница %wu превышает размер %wu
 msgid "%Gnull format string"
 msgstr "пустая форматная строка"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 #| msgid "use of %<alloca%>"
 msgid "%Guse of %<alloca%>"
 msgstr "использование %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 #| msgid "argument to variable-length array may be too large"
 msgid "%Gargument to variable-length array may be too large"
 msgstr "аргумент для массива переменной длины может оказаться слишком большим"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 #| msgid "argument to %<alloca%> may be too large"
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "аргумент для %<alloca%> может оказаться слишком большим"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, fuzzy, gcc-internal-format
 #| msgid "limit is %u bytes, but argument may be as large as %s"
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr "лимит %u байт, но аргумент может достигать размера %s"
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 #| msgid "argument to variable-length array is too large"
 msgid "%Gargument to variable-length array is too large"
 msgstr "аргумент для массива переменной длины слишком большой"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 #| msgid "argument to %<alloca%> is too large"
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "аргумент для %<alloca%> слишком большой"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, fuzzy, gcc-internal-format
 #| msgid "limit is %u bytes, but argument is %s"
 msgid "limit is %wu bytes, but argument is %s"
 msgstr "лимит %u байт, но аргумент %s"
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 #| msgid "unbounded use of variable-length array"
 msgid "%Gunbounded use of variable-length array"
 msgstr "неограниченное использование массива переменной длины"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 #| msgid "unbounded use of %<alloca%>"
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "некорректное использование %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 #, fuzzy
 #| msgid "use of %<alloca%> within a loop"
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "использование %<alloca%> в цикле"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 #| msgid "argument to variable-length array is zero"
 msgid "%Gargument to variable-length array is zero"
 msgstr "аргумент для массива переменной длины нулевой"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 #| msgid "argument to %<alloca%> is zero"
 msgid "%Gargument to %<alloca%> is zero"
@@ -25464,7 +25475,7 @@ msgstr "заданная граница %wu превышает максимал
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, gcc-internal-format
 msgid "array %qD declared here"
 msgstr ""
@@ -25490,11 +25501,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD объявлено здесь"
@@ -25570,330 +25581,330 @@ msgstr "атрибут %<fallthrough%> без предшествующей case
 msgid "using result of function returning %<void%>"
 msgstr "использование результат функции, возвращающей %<void%>"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-memory input %d must stay in memory"
 msgid "non-memory output %d must stay in memory"
 msgstr "входное значение %d должно быть в памяти"
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "неверное lvalue-выражение в выходном операторе %d оператора asm"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "входное значение %d должно быть в памяти"
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "невозможна прямая адресация к входной позиции памяти %d"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variable %qE used in target region"
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "частная переменная потока %qE использована в целевой области"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing target region"
 msgid "enclosing region"
 msgstr "объемлющая целевая область"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "частная переменная потока %qE использована в целевой области"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "объемлющая целевая область"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "частная переменная потока %qE использована в безымянной задаче"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "объемлющая задача"
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE не задано в объемлющей %qs"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "объемлющая %qs"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE не задано в объемлющей OpenACC %qs конструкции"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "объемлющая OpenACC %qs конструкция"
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE с %<link%> предложением использовано в %<routine%> функции"
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE требует %<declare%> директиву для использования в %<routine%> функции"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 #| msgid "%qE not specified in enclosing %qs"
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "%qE не задано в объемлющей %qs"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing target region"
 msgid "enclosing %<target%>"
 msgstr "объемлющая целевая область"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "переменная %qE декларирована в объемлющей %<host_data%> области"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD со ссылкой из целевой области не имеет отображаемый тип"
 
 #
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "итерационная переменная %qE предопределенно линейна"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "итерационная переменная %qE должна быть private"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "итерационная переменная %qE не должна быть firstprivate"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "итерационная переменная %qE не должна быть редукцией"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "итерационная переменная %qE не должна быть линейной"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr "%<_Atomic%> %qD в %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %<lastprivate%>"
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "%qD не есть переменная в клаузуле %<lastprivate%>"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
 #
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, fuzzy, gcc-internal-format
 #| msgid "using parameters for %<linear%> step is not supported yet"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "модель кода %<large%> пока не поддерживается"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%> клаузула для переменной отличной от итератора цикла заданного в конструкции, скомбинированной с %<distribute%>"
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "отображение поля %qE структуры переменной длины"
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE встречается более одного раза в map клаузуле"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "copyprivate переменная %qE не является threadprivate или private во внешнем контексте"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s переменная %qE является частной для внешнего контекста"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "ожидался %qs %<if%> модификатор клаузулы а не %qs"
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD в неявной %<map%> клаузуле"
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD в неявной %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD в %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "та же переменная использована в %<firstprivate%> и %<lastprivate%> клаузулах %<distribute%> конструкции"
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "несовместимая клаузула данных с редукцией %qE; преобразовано в present_or_copy"
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "некорректная private редукция на %qE"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, fuzzy, gcc-internal-format
 #| msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "%<linear%> клаузула не может задаваться вместе с %<ordered%> клаузулой с параметром"
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "%<_Atomic%> %qD в %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "%<_Atomic%> %qD в %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, fuzzy, gcc-internal-format
 #| msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "%<teams%> конструкция не вложена замкнуто в %<target%> конструкции"
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, fuzzy, gcc-internal-format
 #| msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "%<distribute%> область должна быть строго вложена в %<teams%> конструкции"
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, fuzzy, gcc-internal-format
 #| msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "только %<distribute%> или %<parallel%> области могут быть строго вложены в %<teams%> области"
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "%<#pragma omp declare reduction%> объединитель ссылается на переменную %qD, которая не %<omp_out%> и не %<omp_in%>"
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%> конструкция с %<depend%> клаузулой должна быть замкнуто вложена внутри цикла с %<ordered%> клаузулой с параметром"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "переменная %qE не есть итерация самого внешнего цикла %d, ожидалось %qE"
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "число переменных в %<depend(sink)%> клаузуле не соответствует числу итерационных переменных"
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, fuzzy, gcc-internal-format
 #| msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "более одной %<depend(source)%> клаузулы %<ordered%> конструкции"
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, fuzzy, gcc-internal-format
 #| msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "%<depend(source)%> клаузула задана вместе с %<depend(sink:)%> клаузулами в той же конструкции"
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "преобразование в gimple завершилось неуспешно"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT преобразован к %qT при передаче через %<...%>"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(поэтому %<va_arg%> нужно передать %qT, а не %qT)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "при достижении этого кода выполнение программы завершится аварийно"
@@ -26367,23 +26378,23 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s нельзя использовать в asm в таком контексте"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr "указатель кадра требуется, но зарезервирован"
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr "для %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "кадр слишком велик для надежного контроля стека"
@@ -26404,12 +26415,12 @@ msgstr "для операнда %<asm%> заданы недопустимые о
 msgid "unable to find a register to spill"
 msgstr "не найден регистр для выталкивания в память"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "некорректные ограничители операндов в операторе %<asm%>"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
@@ -27164,12 +27175,12 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr "некорректный аргумент ключа %qs"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %qs: %s; имелось в виду %qs?"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "допустимые аргументы %qs: %s"
@@ -27303,7 +27314,7 @@ msgstr "транзакционная память не поддерживает
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr "опорные точки секций нельзя использовать, если не включено переупорядочение на верхнем уровне"
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
@@ -27866,25 +27877,25 @@ msgstr "явно использованные регистры должны бы
 msgid "output operand %d must use %<&%> constraint"
 msgstr "выходной операнд %d должен содержать ограничитель %<&%>"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "validate_value_data: [%u] Некорректный next_regno для пустого списка (%u)"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: Loop in regno chain (%u)"
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "validate_value_data: цикл в списке номеров регистров (%u)"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "validate_value_data: : [%u] Некорректный oldest_regno (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
@@ -27950,13 +27961,13 @@ msgstr "невозможно загрузить целый константны
 msgid "impossible register constraint in %<asm%>"
 msgstr "недопустимый ограничитель для регистра в операторе %<asm%>"
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "для этой целевой платформы не поддерживается %qs"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "ограничитель %<&%> без указания класса регистров"
@@ -27987,53 +27998,53 @@ msgstr "ограничитель операнда %<asm%> не согласуе
 msgid "output operand is constant in %<asm%>"
 msgstr "выходной операнд %<asm%> - константа"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "RTL: доступ к эл-ту %d '%s' последним элементом %d; функция %s, в %s:%d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL: ожидался эл-т %d типа '%c', имеется '%c' (rtx %s); функция %s, в %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL: ожидался эл-т %d типа '%c' или '%c', имеется '%c' (rtx %s); функция %s, в %s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL: ожидался код '%s', обнаружено '%s'; функция %s, в %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL: ожидался код '%s' или '%s', обнаружено '%s'; функция %s, в %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL: ожидался код '%s' или '%s', обнаружено '%s'; функция %s, в %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "RTL: попытка трактовать не блочный символ как блочный в %s, в %s:%d"
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL проверка: доступ к hwi эл-ту %d вектора с последним эл-том %d в %s, в %s:%d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL: доступ к эл-ту %d вектора с числом эл-тов %d; функция %s, в %s:%d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "RTL флаги: %s использован с неподходящим rtx-кодом '%s' в %s, в %s:%d"
@@ -28078,23 +28089,23 @@ msgstr "ограничитель ссылается на неверный ном
 msgid "invalid punctuation %qc in constraint"
 msgstr "некорректный знак %qc в ограничителе"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "ограничитель не допускает использование регистра"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate asm operand name %qs"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "дублирование имени операнда asm %qs"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "отсутствует закрывающая скобка для именованного операнда"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "неопределенный именованный операнд %qs"
@@ -28820,9 +28831,9 @@ msgstr "некорректный операнд для %%R"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in parameter %i"
 msgid "type mismatch in %qs"
@@ -28864,7 +28875,7 @@ msgstr "некорректный операнд отступа в MEM_REF"
 msgid "invalid clique in %qs"
 msgstr "некорректное использование %qD"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
@@ -29081,392 +29092,392 @@ msgstr "неверные операнды тернарной операции"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "первый аргумент VEC_COND_EXPR должен быть boolean векторного типа с тем же числом элементов, что и результат"
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "vector types expected in sad expression"
 msgid "vector types expected in %qs"
 msgstr "ожидались векторные типы в sad выражении"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, fuzzy, gcc-internal-format
 #| msgid "vectors with different element number found in vector permute expression"
 msgid "vectors with different element number found in %qs"
 msgstr "в векторном выражении перестановки обнаружены векторы с разным числом элементов"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offload table in %s"
 msgid "invalid mask type in %qs"
 msgstr "некорректная таблица разгрузки в %s"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "not allowed type combination in BIT_INSERT_EXPR"
 msgid "not allowed type combination in %qs"
 msgstr "недопустимая комбинация типов в BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size in BIT_INSERT_EXPR"
 msgid "invalid position or size in %qs"
 msgstr "некорректная позиция или размер в BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 #| msgid "'h' applied to non-register operand"
 msgid "%qs into non-mode-precision operand"
 msgstr "'h' применено к нерегистровому операнду"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 #| msgid "insertion out of range in BIT_INSERT_EXPR"
 msgid "insertion out of range in %qs"
 msgstr "вставка вне диапазона в BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 #| msgid "vector insertion not at element boundary"
 msgid "%qs not at element boundary"
 msgstr "векторная вставка не на границе элемента"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial conversion at assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "нетривиальное преобразование в присваивании"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "non-decl/MEM_REF LHS in clobber statement"
 msgid "%qs LHS in clobber statement"
 msgstr "non-decl/MEM_REF LHS в затирающем операторе"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "некорректный операнд для %%R"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rhs for gimple memory store"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "Некорректная правая часть в gimple операции записи в память"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect type of vector CONSTRUCTOR elements"
 msgid "incorrect type of vector %qs elements"
 msgstr "некорректный тип элементов векторного CONSTRUCTOR"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect number of vector CONSTRUCTOR elements"
 msgid "incorrect number of vector %qs elements"
 msgstr "некорректное число элементов векторного CONSTRUCTOR"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "некорректный тип элементов векторного CONSTRUCTOR"
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "vector CONSTRUCTOR with non-NULL element index"
 msgid "vector %qs with non-NULL element index"
 msgstr "векторный CONSTRUCTOR с non-NULL индексом элемента"
 
 #
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, fuzzy, gcc-internal-format
 #| msgid "vector CONSTRUCTOR element is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "элемент векторного CONSTRUCTOR не есть GIMPLE-значение"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "non-vector CONSTRUCTOR with elements"
 msgid "non-vector %qs with elements"
 msgstr "non-vector CONSTRUCTOR с элементами"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR с тождественно ложным условием"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "некорректный операнд в операторе return"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "некорректное преобразование в операторе return"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "цель оператора goto не является ни меткой, ни указателем"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "некорректный операнд для оператора switch"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "оператор switch с нецелочисленным типом"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "некорректная default case метка в операторе switch"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, fuzzy, gcc-internal-format
 #| msgid "invalid CASE_CHAIN"
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "некорректная CASE_CHAIN"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "некорректная case метка в операторе switch"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "некорректный case диапазон в операторе switch"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "несоответствие точности типов в операторе switch"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "несоответствие типов для case метки в операторе switch"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case метки не отсортированы в операторе switch"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "label's context is not the current function decl"
 msgid "label context is not the current function declaration"
 msgstr "контекст метки не есть декларация текущей функции"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect entry in label_to_block_map"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "некорректный элемент в label_to_block_map"
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "некорректная установка номера landing pad"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "некорректный код сравнения в gimple условном выражении"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "некорректные метки в gimple условном выражении"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "некорректный результат PHI"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "отсутствует определение PHI"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "некорректный аргумент PHI"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in PHI argument %u"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "несовместимые типы в аргументе PHI %u"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "процедура verify_gimple выявила ошибки"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, fuzzy, gcc-internal-format
 #| msgid "dead STMT in EH table"
 msgid "dead statement in EH table"
 msgstr "мертвый оператор в таблице EH"
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "расположения блока ссылок не в дереве блоков"
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "Local declaration from a different function"
 msgid "local declaration from a different function"
 msgstr "Локальная декларация из другой функции"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) указывает не на тот блок"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "PHI узел с расположением"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "недопустимое разделение узлов дерева"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "виртуальный PHI с расположениями аргументов"
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) указывает не на тот блок"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "оператор помечен как throw, но не является таковым"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "оператор помечен как throw в середине блока"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "процедура verify_gimple выявила ошибки"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "с ENTRY_BLOCK ассоциирован IL"
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "с EXIT_BLOCK ассоциирован IL"
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "сквозной выход из блока %d"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "нелокальная метка "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH landing pad метка "
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "метка "
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "инструкция управления потоком выполнения внутри блока %d"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "сквозная дуга после оператора управления в блоке %d"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "дуга true/false после не GIMPLE_COND в блоке %d"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "некорректные флаги выходной дуги в конце блока %d"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "явный переход goto в конце блока %d"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "дуга return не указывает на конец блока %d"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "случай default - не в начале case-вектора"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "case-метки не отсортированы: "
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "лишняя исходящая дуга %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "отсутствует дуга %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "выход из функции с атрибутом %<noreturn%>"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "управление достигает конца не-void функции"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "результат %qD, декларированной с атрибутом warn_unused_result, игнорируется"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -30666,7 +30677,7 @@ msgstr "поддержка локально-поточных COMMON-данных
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "запрошенное выравнивание для %q+D превышает поддерживаемое выравнивание для %wu"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "размер %q+D в памяти неизвестен"
@@ -30832,7 +30843,7 @@ msgstr "поток байткода: ожидался тег %s, а не %s"
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "поток байткода: тег %s вне ожидаемого диапазона [%s, %s]"
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "Unsupported value for mmpy-option"
 msgid "unsupported record layout"
@@ -31501,7 +31512,7 @@ msgstr "атрибут %qE следует после %qE"
 msgid "type was previously declared %qE"
 msgstr "тип был ранее декларирован как %qE"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> может задаваться только для виртуальной функции"
@@ -31521,7 +31532,7 @@ msgstr "%qD не совместим с %qD"
 msgid "%qE argument is not a function"
 msgstr "аргумент %qE не функция"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "сообщение для атрибута deprecated не является строковой константой"
@@ -31991,12 +32002,12 @@ msgstr "?: использование целых констант в булев
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "компилятор может предполагать, что адрес %qD всегда будет давать значение %<true%>"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "присваивание, используемое как логическое выражение, рекомендуется "
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "неверное употребление спецификатора %<restrict%>"
@@ -32161,13 +32172,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "%<fallthrough%> атрибут задан с параметром"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "слишком мало аргументов в вызове функции %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "слишком много аргументов в вызове функции %qE"
@@ -33155,7 +33166,7 @@ msgstr "неподдерживаемая нестандартная конкат
 msgid "traditional C rejects string constant concatenation"
 msgstr "традиционный Си не поддерживает конкатенацию строковых констант"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -33208,7 +33219,7 @@ msgstr "%<depend(source)%> клаузула задана вместе с %<depen
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "некорректный тип итерационной переменной %qE"
@@ -33223,17 +33234,17 @@ msgstr "%<_Atomic%> итерационная переменная %qE"
 msgid "%qE is not initialized"
 msgstr "%qE не инициализирован"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "отсутствует управляющий предикат"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "некорректный управляющий предикат"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "отсутствует инкрементальное выражение"
@@ -33243,7 +33254,7 @@ msgstr "отсутствует инкрементальное выражение
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "некорректное инкрементальное выражение"
@@ -33312,7 +33323,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -33923,8 +33934,8 @@ msgstr "<return-значение>"
 msgid "wrong type argument to %s"
 msgstr "неверный аргумент типа для %s"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "переполнение при вычислении константного выражения"
@@ -34410,17 +34421,17 @@ msgstr "декрементация функции %qD"
 msgid "function %qD used as %<asm%> output"
 msgstr "функция %qD использована как выходной операнд %<asm%>"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "присваивание позиции в памяти %qE, доступной только на чтение"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "инкрементация позиции в памяти %qE, доступной только на чтение"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "декрементация позиции в памяти %qE, доступной только на чтение"
@@ -34601,8 +34612,8 @@ msgstr "%<memset%> использовано с константным нулев
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr "%<memset%> использовано с длиной равной числу элементов без умножения на размер элемента"
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "сравнение между типами %qT и %qT"
@@ -34687,37 +34698,37 @@ msgstr[0] "передача аргумента %i в restrict-квалифици
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "это условие имеет идентичные ветвления"
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 #| msgid "size mismatch in argument %d of %qE"
 msgid "mismatch in bound %Z of argument %u declared as %s"
@@ -34726,54 +34737,54 @@ msgstr[0] "несоответствие размера в аргументе %d
 msgstr[1] "несоответствие размера в аргументе %d для %qE"
 msgstr[2] "несоответствие размера в аргументе %d для %qE"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as %s"
 msgstr "предыдущая декларация здесь"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to variable-length array is zero"
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "аргумент для массива переменной длины нулевой"
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as a pointer %s"
 msgstr "предыдущая декларация здесь"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as an ordinary array %s"
 msgstr "предыдущая декларация здесь"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument %d of %qE must be a pointer type"
 msgid "argument %u of type %s declared as a pointer"
 msgstr "аргумент %d для %qE должен быть указателем"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unbounded use of variable-length array"
 msgid "previously declared as a variable length array %s"
 msgstr "неограниченное использование массива переменной длины"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as an array %s"
 msgstr "предыдущая декларация здесь"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgid "argument %u of type %s declared with %u variable bound"
@@ -34782,7 +34793,7 @@ msgstr[0] "игнорирование возвращаемого значени
 msgstr[1] "игнорирование возвращаемого значения типа %qT, декларированного с атрибутом nodiscard"
 msgstr[2] "игнорирование возвращаемого значения типа %qT, декларированного с атрибутом nodiscard"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qD with attribute noinline"
 msgid "previously declared as %s with %u variable bound"
@@ -34791,7 +34802,7 @@ msgstr[0] "предыдущая декларация %q+D с атрибутом
 msgstr[1] "предыдущая декларация %q+D с атрибутом noinline"
 msgstr[2] "предыдущая декларация %q+D с атрибутом noinline"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
@@ -34799,7 +34810,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
@@ -34807,7 +34818,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
@@ -34815,53 +34826,53 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "аргумент типа %qT не соответствует типу %qT"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as %s with bound argument %E"
 msgstr "предыдущая декларация здесь"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %<%c%s%>"
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "предыдущая декларация %<%c%s%>"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %qD"
 msgid "previously declared as %s with bound %qs"
 msgstr "предыдущая декларация %qD"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s with mismatched bound"
 msgstr "аргумент типа %qT не соответствует типу %qT"
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, fuzzy, gcc-internal-format
 #| msgid "add parentheses around left hand side expression to silence this warning"
 msgid "add parentheses around %qE to silence this warning"
 msgstr "добавьте скобки вокруг выражения в левой части, чтобы устранить это предупреждение"
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, fuzzy, gcc-internal-format
 #| msgid "add parentheses around left hand side expression to silence this warning"
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
@@ -34878,7 +34889,7 @@ msgid "too many input files"
 msgstr "слишком много входных файлов"
 
 #
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -34912,14 +34923,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "допустимые аргументы: %s; имелось в виду %qs?"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr ""
@@ -35084,70 +35095,70 @@ msgstr "-mregparm=%d не между 0 и %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr "для опции -mcache-block-size=X допустимый X должен быть: 4, 8, 16, 32, 64, 128, 256 или 512"
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> requires %<-mfp32%>"
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "%<-march=%s%> требует %<-mfp32%>"
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: invalid ISA string"
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "-march=%s: некорректная ISA цепочка"
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: unsupported ISA substring %qs"
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr "-march=%s: неподдерживаемая ISA подцепочка %qs"
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr "-march=%s: ISA цепочка должна начинаться с rv32 или rv64"
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "ключ %<-march=%s%> несовместим с выбранным ABI"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "ключ %<-march=%s%> несовместим с выбранным ABI"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "-march=%s: ISA цепочка должна начинаться с rv32 или rv64"
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: unsupported ISA substring %qs"
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr "-march=%s: неподдерживаемая ISA подцепочка %qs"
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
@@ -35325,86 +35336,86 @@ msgstr "%s конфликтует с ppc (arch флаги проигнориро
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr "%s конфликтует с ppc64 (arch флаги проигнорированы)"
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "не удалось открыть временный файл %s для LTO вывода"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "атрибут %qE 2.95 vtable-совместимости применим только при компиляции kext"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "атрибут %qE 2.95 vtable-совместимости применим только к классам C++"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "protected visibility атрибут не поддерживается в данной конфигурации; проигнорирован"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "не удалось открыть временный файл %s с LTO выводом"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fobjc-abi-version%> >= 2 must be used for %<-m64%> targets with %<-fnext-runtime%>"
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> >= 2 следует использовать для %<-m64%> целевых платформ с %<-fnext-runtime%>"
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fobjc-abi-version%> >= 2 is not supported on %<-m32%> targets with %<-fnext-runtime%>"
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> >= 2 не поддерживается на %<-m32%> целевых платформах с %<-fnext-runtime%>"
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "%<__int%d%> не поддерживается для этой целевой машины"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "%<-mdynamic-no-pic%> перебивает %<-fpic%>, %<-fPIC%>, %<-fpie%> или %<-fPIE%>"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "внутренняя функция %qD требует флаг %<-mconstant-cfstrings%>"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "внутренняя функция %qD принимает только один аргумент"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "пропущен литерал CFString"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "литеральное выражение CFString не является строковой константой"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, fuzzy, gcc-internal-format
 #| msgid "%s in CFString literal"
 msgid "non-ASCII character in CFString literal"
 msgstr "%s в CFString литерале"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "%s in CFString literal"
 msgid "embedded NUL in CFString literal"
@@ -35413,7 +35424,7 @@ msgstr "%s в CFString литерале"
 #: config/host-darwin.c:65
 #, fuzzy, gcc-internal-format
 #| msgid "couldn%'t unmap pch_address_space: %m"
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "невозможно сделать unmap pch_address_space: %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -35558,401 +35569,401 @@ msgstr "%<#pragma GCC optimize%> не строка и не число"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "неизвестный #pragma GCC intrinsic %E"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new нельзя применять к типу функции"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<for%> after %qs"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "ожидался %<for%> после %qs"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "модификатор %qs возможности несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "модификатор %qs возможности несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the SPE ABI extensions."
 msgid "this operation requires the SVE ISA extension"
 msgstr "Не использовать расширения SPE ABI."
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "аргумент decltype должен быть выражением"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%qE requires the SVE ISA extension"
 msgstr "Использовать расширения SPE ABI."
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, fuzzy, gcc-internal-format
 #| msgid "unknown flag passed in -moverride=%s (%s)"
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "неизвестный флаг переданный в -moverride=%s (%s)"
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid format of %s"
 msgid "invalid format for sve_width"
 msgstr "некорректный формат %s"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "некорректное значение %%h"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "строка настройки отсутствует в опции (%s)"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "неизвестная опция настройки (%s)"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Порядок выделения регистров"
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s;"
 msgstr "допустимые аргументы %qs: %s"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "отсутствует имя процессора в %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "некорректный модификатор возможности в %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "%qs некорректный аргумент для -mcpu="
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr "%<-mmsa%> должно использоваться с %<-mfp64%> и %<-mhard-float%>"
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function %s"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "некорректный аргумент встроенной функции %s"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function %s"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "некорректный аргумент встроенной функции %s"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "отсутствует имя архитектуры в %<-march=%s%>"
 
 #
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -march"
 msgid "unknown value %qs for %<-march%>"
 msgstr "неизвестное значение %qs для -march"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-march=%s%>"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "некорректный модификатор возможности в %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "отсутствует имя процессора в %<-mtune=%s%>"
 
 #
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "неизвестное значение %qs для -mtune"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "ключ -mcpu=%s несовместим с ключом -march=%s"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support %<-mfp32%>"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "архитектура %qs не поддерживает %<-mfp32%>"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %<-f%s%>"
 msgstr "модель кода %qs с -f%s"
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент атрибута %<target%> не строка"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Kпроход %wd вне диапазона %wd - %wd"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "проход %wd вне диапазона %wd - %wd"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported simdlen %d"
 msgid "unsupported simdlen %wd"
 msgstr "неподдерживаемая simdlen %d"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -36022,7 +36033,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "некорректное значение %qs для -mmemory-latency"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -36153,18 +36164,18 @@ msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr ""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -36614,238 +36625,244 @@ msgstr "целевой процессор не поддерживает кома
 msgid "target CPU does not support unaligned accesses"
 msgstr "целевой процессор не поддерживает невыровненные доступы"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "switch -mcpu=%s conflicts with -march=%s switch"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "ключ -mcpu=%s несовместим с ключом -march=%s"
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "ключ -mapcs-stack-check несовместим с -mno-apcs-frame"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "ключи -fpic и -mapcs-reent несовместимы"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "граница размера структуры может быть только 8, 32 или 64"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "граница размера структуры может быть только 8 или 32"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "позиционно-независимый RTP несовместим с -msingle-pic-base"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= не имеет смысла без -fpic"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "использование '%s' как PIC-регистра невозможно"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition не поддерживается на этой архитектуре"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "выбранные fp16 опции несовместимы"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt требует AAPCS совместимого ABI для правильной работы"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "для работы с iwmmxt ABI требуется процессор с поддержкой iwmmxt"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "целевой процессор не поддерживает interworking"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS не поддерживает -mcaller-super-interworking"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS не поддерживает -mcaller-super-interworking"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 и нет ldrh"
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "целевой процессор не поддерживает ARMv8-M Security Extensions"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard: selected processor lacks an FPU"
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr "-mfloat-abi=hard: в выбранном процессоре нет FPU"
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mflat-abi=hard и VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "non-AAPCS производный PCS вариант"
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "вариантные функции должны использовать базовый AAPCS вариант"
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS вариант"
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 аппаратный плавающий VFP ABI"
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "атрибут %qE не доступен для функций с аргументами переданными на стеке"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "атрибут %qE не доступен для функций с переменным числом аргументов"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "атрибут %qE не доступен для функций, которые возвращают значение на стеке"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored without -mcmse option."
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "атрибут %qE игнорируется без -mcmse опции."
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "атрибут %qE не действует на функции со статической компоновкой"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "атрибут %qE применим только к базовому типу указателя на функцию"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, fuzzy, gcc-internal-format
 #| msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "доступ к локальной памяти потока в настоящее время не поддерживается с -mpure-code или -mslow-flash-data"
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd вне диапазона %wd - %wd"
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd вне диапазона %wd - %wd"
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "невозможно вычислить фактическое положение параметра в стеке"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Неожиданный thumb1 далекий переход"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нет свободных low-регистров для выталкивания high-регистров"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific для Thumb-1"
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -36853,22 +36870,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "auto fpu выбор в настоящее время здесь не допускается"
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -36952,17 +36969,17 @@ msgstr "-fpie не поддерживается"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIE не поддерживается"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs функция не может иметь аргументы"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs функция не может возвращать значение"
@@ -37754,134 +37771,134 @@ msgstr "Параметр для внутренней функции должен
 msgid "parameter to builtin not valid: %s"
 msgstr "Параметр для внутренней функции некорректен: %s"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't be called directly"
 msgid "interrupt service routine cannot be called directly"
 msgstr "программа обслуживания прерываний не может вызываться напрямую"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "последний аргумент должен быть 2-битным непосредственным"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "пятый аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "третий аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "последний аргумент должен быть 3-битным непосредственным"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "последний аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "последний аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "следующий за последним аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "последний аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "третий аргумент должен быть константой сравнения"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "некорректный режим сравнения"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "некорректный операнд округления"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "непосредственный аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "непосредственный аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "непосредственный аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE требует неизвестную isa опцию"
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE требует isa опцию %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "последний аргумент должен быть 32-битным непосредственным"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "последний аргумент должен быть непосредственным"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "последний аргумент должен быть масштабом 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "четвертый аргумент должен быть масштабом 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "некорректный операнд подсказки"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 #| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -37906,547 +37923,547 @@ msgstr "мультиверсионность виртуальной функци
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "мультиверсионность требует ifunc, что не поддерживается на этой платформе"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "модель кода %s не поддерживает PIC режим"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "аргумент атрибута %qE не является строковой константой"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "attribute(target(\"%s\")) неизвестен"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "SEQUENCE атрибут в %C уже специфицирован в TYPE операторе"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "Атрибут %s %qs конфликтует с атрибутом %s в %L"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "некорректный аргумент %qs для опции %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "диапазоны размера в опции %qs следует увеличить"
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "некорректное имя стратегии %qs задано для опции %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "имя стратегии %qs заданное для опции %qs не поддерживается для 32-битного кода"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "неизвестное выравнивание %qs задано для опции %qs"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "максимальное значение для диапазона последнего размера должно быть -1 для опции %qs"
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "слишком много диапазонов размера задано в опции %qs"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel MCU psABI не поддерживается в %s режиме"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> устарело; используйте вместо этого соответственно %<-mtune=k8%> или %<-mtune=generic%>"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> устарело; используйте вместо этого соответственно %<target(\"tune=k8\")%> или %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "адресный режим %qs не поддерживается в %s-битном режиме"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-Wabi=1%> не поддерживается, используется =2"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "транзакционная память не поддерживается с %<-fsanitize=address%>"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "транзакционная память не поддерживается с %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fcheck-pointer-bounds%> is not supported with %<-fsanitize=bounds%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-fcheck-pointer-bounds%> не поддерживается с %<-fsanitize=bounds%>"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel не поддерживается в этой конфигурации"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битный режим не компилируется в"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<generic%> процессор может использоваться только для %<-mtune=%> ключа"
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<generic%> процессор может использоваться только для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<intel%> процессор может использоваться только для %<-mtune=%> ключа"
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<intel%> процессор может использоваться только для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "заданный процессор не поддерживает набор команд x86-64"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "некорректное значение (%qs) для ключа %<-march=%>"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "некорректное значение (%qs) для %<target(\"arch=\")%> атрибута"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<-march=%> ключа: %s; имелось в виду %qs?"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s; вы имели в виду %qs?"
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "допустимые аргументы для %<-march=%> ключа: %s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "некорректное значение (%qs) для ключа %<-mtune=%>"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "некорректное значение (%qs) для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<-mtune=%> ключа: %s; имелось в виду %qs?"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<target(\"tune=\")%> атрибута: %s; вы имели в виду %qs?"
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "допустимые аргументы для %<-mtune=%> ключа: %s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "допустимые аргументы для %<target(\"tune=\")%> атрибута: %s"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mregparm игнорируется в 64-битном режиме"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored for Intel MCU psABI"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "-mregparm игнорируется для Intel MCU psABI"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d не между 0 и %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> игнорируется в 64-битном режиме"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> игнорируется в 64-битном режиме"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-mpreferred-stack-boundary не поддерживается для этой целевой платформы"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d не между %d и 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "-mnop-mcount не реализовано для -fPIC"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> используется без SSE включения"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> используется без SSE включения"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "набор команд SSE отменен, используется арифметика 387"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "набор команд 387 отменен, используется арифметика SSE"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "опробование стека требует %<-maccumulate-outgoing-args%> для корректной работы"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "опробование стека требует %<target(\"accumulate-outgoing-args\")%> для корректной работы"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "фиксированный ebp регистр требует %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "фиксированный ebp регистр требует %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry не поддерживается для 32 бит в комбинации с -fpic"
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry несовместимо с SEH"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "неизвестная опция для -mrecip=%s"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs не есть допустимое число в -mstack-protector-guard-offset"
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs не есть допустимое смещение в -mstack-protector-guard-offset="
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs не есть допустимый базовый регистр в -mstack-protector-guard-reg"
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, fuzzy, gcc-internal-format
 #| msgid "Only DWARF debug format is supported for interrupt service routine."
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "Только отладочный формат DWARF поддерживается для программы обслуживания прерываний."
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s инструкции не допускаются в %s сервисной программе"
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s инструкции не допускаются в %s сервисной программе"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s инструкции не допускаются в функции с no_caller_saved_registers атрибутом"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибуты fastcall и regparm несовместимы"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибуты regparam и thiscall несовместимы"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE атрибут требует целый константный аргумент"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент для %qE атрибута больше чем %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибуты fastcall и cdecl несовместимы"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибуты fastcall и thiscall несовместимы"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибуты stdcall и cdecl несовместимы"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибуты stdcall и thiscall несовместимы"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибуты cdecl и thiscall несовместимы"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE используется для неклассового метода"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "несовместимый атрибут %qE игнорируется"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qE допустим только для 32 бит"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "атрибуты ms_abi и sysv_abi несовместимы"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргументом атрибута %qE должна быть строковая константа"
 
 #
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "программа обслуживания прерываний должна иметь указатель первым аргументом"
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "программа обслуживания прерываний должна иметь беззнаковый %sint вторым аргументом"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "программа обслуживания прерываний может иметь только указательный аргумент и необязательный целочисленный аргумент"
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't have non-void return value"
 msgid "interrupt service routine must return %<void%>"
@@ -38934,7 +38951,7 @@ msgstr "%qE не может иметь оба атрибута: %qs и %qs"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "повторная декларация %qE с конфликтующими атрибутами %qs"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE атрибут требует строковый аргумент"
@@ -40063,63 +40080,63 @@ msgstr "__delay_cycles ограничено 32-битными счетчикам
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "неизвестный процессор %qs для -mtune"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, fuzzy, gcc-internal-format
 #| msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "-mdiv требует -march, чтобы понять %<M%> расширение"
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, fuzzy, gcc-internal-format
 #| msgid "requested ABI requires -march to subsume the %qc extension"
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "запрошенный ABI требует -march, чтобы понять %qc расширение"
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "ABI requires -march=rv%d"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI требует -march=rv%d"
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
@@ -40665,248 +40682,249 @@ msgstr ""
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Кадр стека больше 2G не поддерживается для -fsplit-stack"
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 #| msgid "-mcall-aixdesc incompatible with -mabi=elfv2"
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mcall-aixdesc несовместим с -mabi=elfv2"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires a PowerPC64 cpu"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "для -m64 требуется процессор PowerPC64"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "ключ -mcmodel несовместим с другими опциями toc"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 #| msgid "FPA is unsupported in the AAPCS"
 msgid "%qs unsupported for this ABI"
 msgstr "FPA не поддерживается в AAPCS"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec не поддерживается на этой целевой платформе"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes long double size"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "target attribute или pragma изменяет размер long double"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "-mfloat128-hardware требует полной ISA 3.0 поддержки"
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "использование IEEE extended precision long double"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "использование IBM extended precision long double"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "target attribute или pragma изменяет AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "target attribute или pragma изменяет darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "расположение агрегатов содержащих векторы с %d-байтным выравниванием изменилось в GCC 5"
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "отсутствует профилирование 64-битного кода для этого ABI"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "использование %<long double%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "использование типов boolean в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "использование %<complex%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "использование типов decimal floating point в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "использование %<long%> в типах AltiVec не рекомендуется; используйте %<int%>"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "мультиверсионность требует ifunc, что не поддерживается на этой платформе"
 
 #
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "мультиверсионность виртуальной функции не поддерживается"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -41093,7 +41111,7 @@ msgstr "инструкции RX FPU не поддерживают NaNs и бес
 msgid "builtin vec_step can only be used on vector types."
 msgstr "встроенная функция vec_step может использоваться только для векторных типов"
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "константное значение требуется для встроенной функции %qF (аргумент %d)"
@@ -41166,213 +41184,219 @@ msgstr "%qs соответствующий вариант устарел."
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "константный аргумент %d для внутренней функции %qF вне диапазона для целевого типа"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "constant argument %d for builtin %qF is out of range ("
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "константный аргумент %d для внутренней функции %qF вне диапазона ("
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range (0.."
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "константный аргумент %d для внутренней функции %qF вне диапазона (0.."
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range (0.."
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "константный аргумент %d для внутренней функции %qF вне диапазона (0.."
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr "встроенная функция %qF не поддерживается без -mhtm (по умолчанию с -march=zEC12 и выше)."
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr "встроенная функция %qF требует -mvx (по умолчанию с -march=z13 и выше)."
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr "Встроенная функция %qF требует z14 или выше."
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin %qF requires z14 or higher."
 msgid "Builtin %qF requires z15 or higher."
 msgstr "Встроенная функция %qF требует z14 или выше."
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin %qF requires z14 or higher."
 msgid "Builtin %qF requires arch14 or higher."
 msgstr "Встроенная функция %qF требует z14 или выше."
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "неразрешенная перегрузка внутренней функции"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "некорректный встроенный icode"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "некорректный аргумент %d для встроенной функции %qF"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
 #
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "суммарный размер локальных переменных превышает архитектурный предел"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "размер кадра %qs равен %wd байт"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs использует динамическое размещение стека"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "%<__RTL%> function cannot be compiled with %<-flto%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "%<__RTL%> функция не может компилироваться с %<-flto%>"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битный ABI в режиме ESA/390 не поддерживается"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "аппаратная поддержка векторов отсутствует на %s"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, fuzzy, gcc-internal-format
 #| msgid "hardware vector support not available with -msoft-float"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "аппаратная поддержка векторов недоступна с -msoft-float"
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют на %s"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют в режиме ESA/390"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "ключ -mhard-dfp не может быть использован вместе с -msoft-float"
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "сочетание ключей -mbackchain -mpacked-stack -mhard-float не поддерживается"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "размер стека должен быть больше чем охраняющее значение стека"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "размер стека должен быть больше чем 64k"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "ключ -mstack-guard влечет использование ключа -mstack-size"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "атрибут %qE поддерживается только для SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргументы для %qs должны быть неотрицательными целыми числами"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) неизвестен"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "значение %qs не поддерживается атрибутом %<target%>"
@@ -41731,18 +41755,24 @@ msgstr "-fexcess-precision=standard для Ada"
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr "STABS отладочная информация для Ada устарела и больше не поддерживается"
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "STOP code at %C contains too many digits"
+msgid "%s contains too many lines"
+msgstr "STOP код в %C содержит слишком много цифр"
+
+#: ada/gcc-interface/trans.c:1642
 #, fuzzy, gcc-internal-format
 #| msgid "subprogram %q+F not marked Inline_Always"
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr "подпрограмма %q+F не помечена Inline_Always"
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "подстановка родительской подпрограммы невозможна"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 #| msgid "subprogram %q+F not marked Inline"
 msgid "subprogram %q+F not marked %<Inline%>"
@@ -41813,8 +41843,8 @@ msgstr "атрибут %qs применим только к массивным 
 msgid "could not read the BRIG file"
 msgstr "не удалось прочитать BRIG файл"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "использование пустого (void) значения"
@@ -41874,7 +41904,7 @@ msgstr "переменная %qD определена, но не использ
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "тип массива %q+D завершен несовместимым с неявной инициализацией образом"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "исходное определение находится здесь"
@@ -42108,7 +42138,7 @@ msgstr "декларация %q+D перекрывает предшествую
 msgid "declaration of %qD shadows a parameter"
 msgstr "декларация %qD перекрывает параметр"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларация %qD перекрывает глобальную декларацию"
@@ -42118,7 +42148,7 @@ msgstr "декларация %qD перекрывает глобальную д
 msgid "declaration of %qD shadows a previous local"
 msgstr "декларация %qD перекрывает декларированную ранее локальную переменную"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "перекрытая декларация находится здесь"
@@ -42128,216 +42158,216 @@ msgstr "перекрытая декларация находится здесь"
 msgid "nested extern declaration of %qD"
 msgstr "вложенная extern-декларация %qD"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "неявная декларация функции %qE; имелось в виду %qs?"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "неявная декларация функции %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "include %qs or provide a declaration of %qD"
 msgid "include %qs or provide a declaration of %qE"
 msgstr "включите %qs или предоставьте декларацию для %qD"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "несовместимая неявная декларация внутренней функции %qD"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "включите %qs или предоставьте декларацию для %qD"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "несовместимая неявная декларация функции %qD"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE не описан здесь (не в функции); имелось в виду %qs?"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE не описан здесь (не в функции)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE не описан (первое использование в этой функции); имелось в виду %qs?"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE не описан (первое использование в этой функции)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "сообщение о каждом неописанном идентификаторе выдается один раз в каждой функции, где он встречается"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ссылка на метку %qE вне функции"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "переход в область идентификатора с переменно модифицируемым типом"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "при переходе пропускаются инициализации переменной"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "метка %qD определена здесь"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "переход в выражение-оператор"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "повторная декларация метки %qE"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "дублирование метки %qD"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "в традиционном C нет отдельного пространства имён для меток, конфликт по идентификатору %qE"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "при переходе по переключателю пропускаются инициализации переменных"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "начало переключателя здесь"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "по переключателю происходит переход в выражение-оператор"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE: определение с некорректным видом тега"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE атрибут применен к %qD с void типом возврата"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "%qE атрибут может применяться только к функциям или к классовым или перечислимым типам"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "struct/union без имени и без описания переменных этого типа"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "пустая декларация со спецификатором класса хранения не переопределяет тег"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "пустая декларация с квалификатором типа не переопределяет тег"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "пустая декларация с %<_Alignas%> не переопределяет тег"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "бесполезное имя типа в пустой декларации"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> в пустой декларации"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> в пустой декларации"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> в пустой декларации на уровне файла"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> в пустой декларации на уровне файла"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "бесполезный спецификатор класса хранения в пустой декларации"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "бесполезное %qs в пустой декларации"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "бесполезный квалификатор типа в пустой декларации"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "бесполезное %<_Alignas%> в пустой декларации"
 
 #
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of type %<void%> in parameter declaration"
 msgid "invalid use of attributes in empty declaration"
 msgstr "некорректное использование типа %<void%> в декларации параметра"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "пустая декларация"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 не поддерживает квалификаторы типов и спецификатор %<static%> в деклараторах параметров-массивов"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 не поддерживает конструкцию %<[*]%> в декларациях массивов"
@@ -42345,29 +42375,29 @@ msgstr "ISO C90 не поддерживает конструкцию %<[*]%> в
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> не допускается нигде кроме прототипа функции"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D обычно является функцией"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef-декларация %qD с инициализацией (используйте конструкцию __typeof__)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "функция %qD инициализирована как переменная"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "параметр %qD инициализирован"
@@ -42376,272 +42406,272 @@ msgstr "параметр %qD инициализирован"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "объект переменного размера нельзя инициализировать"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "переменная %qD инициализирована, хотя имеет неполный тип"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %q+D given attribute %qs"
 msgstr "inline функция %q+D с атрибутом noinline"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "не инициализированный константный элемент в %qT недопустим в C++"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD должен быть инициализирован"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "при инициализации не удалось определить размер %q+D"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "не задан размер массива для %q+D"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "размер массива %q+D нулевой или отрицательный"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "размер %q+D в памяти не является константой"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "asm-спецификация в описании локальной нестатической переменной %q+D игнорируется"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "некорректная попытка разместить в регистре объект с volatile-полем"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD is invalid in C++"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "неинициализированная константа %qD не допускается в C++"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D в declare target директиве не имеет отображаемого типа"
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "в ISO C упреждающие декларации параметров запрещены"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "определение типа в составном литерале не допускается в C++"
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "размер битового поля %qs не является целочисленной константой"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "размер битового поля %qs не является целочисленным константным выражением"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "битовое поле %qs имеет отрицательный размер"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "битовое поле %qs имеет нулевой размер"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "неверный тип битового поля %qs"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr ""
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "тип для битового поля %qs является расширением GCC"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "размер поля %qs превышает размер указанного типа"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "ширина поля %qs не достаточна для значений указанного типа"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 не поддерживает массив %qE, размер которого нельзя определить"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 не поддерживает массив, размер которого нельзя определить"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 не поддерживает массив %qE переменного размера"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 не поддерживает массив переменного размера"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "переменно модифицированный %qE на уровне файла"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "переменно модифицированное поле на уровне файла"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "в декларации %qE по умолчанию установлен тип %<int%>"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "в имени типа по умолчанию установлен тип %<int%>"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "повторное употребление %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "повторное употребление %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "повторное употребление %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "повторный %<_Atomic%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "конфликтующие именованные адресные пространства (%s и %s)"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "%<_Atomic%>-квалифицированный массивный тип"
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "определение функции с классом хранения %<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "определение функции с классом хранения %<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "определение функции с классом хранения %<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "определение функции декларировано %qs"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "класс хранения в декларации поля структуры %qE"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "класс хранения в декларации поля структуры"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "класс хранения в декларации параметра %qE"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "класс хранения задан для неименованного параметра"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "класс хранения задан для имени типа"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qE с инициализацией"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "для %qE задан спецификатор %<extern%> и инициализатор"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "в декларации %qE на уровне файла задан класс хранения %<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "в декларации %qE на уровне файла задан класс хранения %<register%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "вложенная функция %qE объявлена %<extern%>"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "%qE из контекста функции неявно auto и декларировано %qs"
@@ -42649,714 +42679,714 @@ msgstr "%qE из контекста функции неявно auto и декл
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static или квалификаторы типа в деклараторе массива, не являющегося "
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "имя %qE описано как массив элементов типа void"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "имя типа описано как массив элементов типа void"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "имя %qE описано как массив функций"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "имя типа описано как массив функций"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "неверное употребление структуры с регулируемым элементом-массивом"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "размер массива %qE имеет не целочисленный тип"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "размер безымянного массива имеет не целочисленный тип"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "размер массива %qE имеет неполный тип"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "размер безымянного массива имеет неполный тип"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "в ISO C массив %qE нулевой длины недопустим"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C запрещает массивы нулевого размера"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "размер массива %qE отрицательный"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "размер безымянного массива отрицательный"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "размер массива %qE слишком велик"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "размер безымянного массива слишком велик"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 не поддерживает регулируемые элементы-массивы"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "тип массива имеет неполный тип элементов %qT"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларация %qE как многомерного массива должна иметь границы для всех размерностей, кроме первой"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларация многомерного массива должна иметь границы для всех размерностей, кроме первой"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE объявлена как функция, возвращающая функцию"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "имя типа объявлено как функция, возвращающая функцию"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE объявлена как функция, возвращающая массив"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "имя типа объявлено как функция, возвращающая массив"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "в определении функции задан квалифицированный void-тип возвращаемого значения"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "%<_Atomic%>-квалифицированный тип функции"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "в ISO C употребление квалификаторов в описании типа функции запрещено"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs в сочетании с квалификатором %<auto%> для %qE"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs в сочетании с квалификатором %<register%> для %qE"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs задано для автоматической переменной %qE"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs задано для параметра %qE"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs задано для безымянного параметра"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs задано для поля структуры %qE"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs задано для поля структуры"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "битовое поле %qE имеет atomic тип"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "битовое поле имеет atomic тип"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "выравнивание задано в определении типа %qE"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "выравнивание задано для объекта %<register%> %qE"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "выравнивание задано для параметра %qE"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "выравнивание задано для безымянного параметра"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "выравнивание задано для битового поля %qE"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "выравнивание задано для безымянного битового поля"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "выравнивание задано для функции %qE"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "спецификатор %<_Alignas%> не должен уменьшать выравнивание %qE"
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "спецификатор %<_Alignas%> не должен уменьшать выравнивание безымянного поля"
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D декларирован %<inline%>"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D декларирован как %<_Noreturn%>"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "в ISO C функции с квалификаторами const и volatile запрещены"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "элемент структуры или объединения не может иметь переменно модифицируемый тип"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "переменная или поле %qE объявлено void"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "атрибуты в деклараторе массива-параметра проигнорированы"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "параметр %q+D объявлен %<inline%>"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "параметр %q+D объявлен %<_Noreturn%>"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "поле %qE описано как функция"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "поле %qE имеет неполный тип"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "безымянное поле имеет неполный тип"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "для функции %qE задан неверный класс хранения"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "inline-подстановка функции %<main%> невозможна"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "функция %<main%> декларирована как %<_Noreturn%>"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 не поддерживает %<_Noreturn%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 не поддерживает %<_Noreturn%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "переменная декларирована сначала как %<static%>, а затем как %<extern%>"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "переменная %q+D декларирована со спецификатором %<inline%>"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "переменная %q+D декларирована со спецификатором %<_Noreturn%>"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "не вложенная функция с переменно модифицируемым типом"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "объект с переменно модифицируемым типом не должен иметь привязки"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "декларация функции не является прототипом"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "в декларации функции указаны имена параметров без типов"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "параметр %u (%q+D) имеет неполный тип"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "параметр %u имеет неполный тип"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "параметр %u (%q+D) имеет тип void"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "параметр %u имеет тип void"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%>, как единственный параметры не может содержать квалификаторы"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> должен быть единственным параметром"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "для параметра %q+D есть только упреждающая декларация"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "%<%s %E%> декларированное внутри списка параметров не будет видно вне этого определения или декларации"
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "анонимное %s декларированное внутри списка параметров не будет видно вне этого определения или декларации"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "перечислимый тип определён здесь"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "структура определена здесь"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "объединение определено здесь"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "повторное определение %<union %E%>"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "повторное определение %<struct %E%>"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "вложенное переопределение %<union %E%>"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "вложенное переопределение %<struct %E%>"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "определение типа в выражении %qs некорректно в C++"
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларация ничего не описывает"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 не поддерживает безымянные структуры и объединения"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 не поддерживает безымянные структуры и объединения"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "повторное описание члена %q+D"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr "пустая структура имеет размер 0 в C, размер 1 в C++"
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "пустое объединение имеет размер 0 в C, размер 1 в C++"
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "объединение не содержит именованных элементов"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "объединение без элементов"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "структура не содержит именованных элементов"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "структура не содержит элементов"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "регулируемый элемент-массив в объединении"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "регулируемый элемент-массив - не последний элемент структуры"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "регулируемый элемент-массив в структуре без именованных элементов"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "тип %qT слишком велик"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "трактовка данного объединения как прозрачного невозможна"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "вложенное переопределение %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "повторная декларация %<enum %E%>"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "заданный режим слишком мал для значений перечислимого типа"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "перечислимый тип превышает диапазон максимального целочисленного типа"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "значение перечислимого типа для %qE не является константой целого типа"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "значение перечислимого типа для %qE не является целочисленным константным выражением"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "переполнение значений перечислимого типа"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "в ISO C значения перечислимого типа ограничены диапазоном типа %<int%>"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "inline функция %qD с атрибутом noinline"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "тип возвращаемого значения не полный"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "по умолчанию возвращаемый тип функции - %<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D определена как variadic функциях без прототипа"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "прототип для %qD не был предварительно определен"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD использована без прототипа, до её определению"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "отсутствует предварительная декларация %qD"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "функция %qD использована до определения без предварительной декларации"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "возвращаемое значение функции %qD - не %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%>-квалифицированный возвращаемый тип в %qD"
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "обычно %qD является нестатической функцией"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "старый стиль деклараций параметров в определении функции с прототипом"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "в традиционном С не поддерживаются определения функций в стиле ISO C"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "ISO C99 не поддерживает %<_Static_assert%>"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "определение функции в старом стиле"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "в списке параметров пропущено имя параметра"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD декларирован как не параметр"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "более одного параметра с именем %qD"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "параметр %qD объявлен с типом void"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "по умолчанию для %qD принят тип %<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "параметр %qD имеет неполный тип"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "декларация параметра %q+D, не заданного в списке параметров"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "число аргументов не соответствует встроенному прототипу"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "число аргументов не соответствует прототипу"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "декларация прототипа"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD после приведения типа не соответствует встроенному прототипу"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD после приведения типа не соответствует прототипу"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD не соответствует встроенному прототипу"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не соответствует прототипу"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "параметру %qD присвоено значение, но он не использован"
@@ -43364,259 +43394,259 @@ msgstr "параметру %qD присвоено значение, но он н
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "декларации в заголовке %<for%>-цикла допускаются только в C99 или C11 режиме"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "используйте опцию -std=c99, -std=gnu99,-std=c11 или -std=gnu11 для компиляции вашей программы"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 не поддерживает конструкцию %<for%> в декларациях циклов"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларация статической переменной %qD в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %<extern%> переменной %qD в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<struct %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<union %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<enum %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %qD, не являющегося переменной, в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "несовместимые квалификаторы адресного пространства %qs и %qs"
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "повторный %qE  спецификатор декларации"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или более типа в декларации"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "GCC не поддерживает тип %<long long long%>"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 не поддерживает комплексные типы"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не поддерживает типы с насыщением"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "дублирование %qE"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не поддерживает типы %<__int%d%>"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> не поддерживается для этой целевой машины"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 не поддерживает булевы типы"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C не поддерживает тип %<_Float%d%s%>"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> не поддерживается для этой целевой машины"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C не поддерживает десятичный тип с плавающей точкой"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "типы с фиксированной точкой не поддерживаются для этой целевой платформы"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не поддерживает типы с фиксированной точкой"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "в C++ результатом поиска %qD будет поле, а не тип"
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE не является встроенным типом или typedef-типом"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE - не в начале декларации"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE использован с %<auto%>"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE использован с %<register%>"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE использован с %<typedef%>"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 не поддерживает %qE"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 не поддерживает %qE"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> перед %<extern%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> перед %<static%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "повторение %<_Thread_local%> или %<__thread%>"
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "в декларации задано более одного класса хранения"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs использован с %qE"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> использован без %<_Fract%> или %<_Accum%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не поддерживает %<complex%> как эквивалент %<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%> объединитель ссылается на переменную %qD, которая не %<omp_out%> и не %<omp_in%>"
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%> инициализатор ссылается на переменную %qD, которая не %<omp_priv%> и не %<omp_orig%>"
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "сдвиг влево отрицательного значения"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "сдвиг влево на отрицательное число позиций"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "сдвиг вправо на отрицательное число позиций"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "величина сдвига влево больше или равна ширине данного типа"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "величина сдвига вправо больше или равна ширине данного типа"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "счетчик сдвига влево >= ширине элемента вектора"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "счетчик сдвига вправо >= ширине элемента вектора"
@@ -43637,7 +43667,7 @@ msgstr "противоречивый маркер управления верс
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "ожидался конец строки"
@@ -43647,7 +43677,7 @@ msgstr "ожидался конец строки"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C не допускает пустых единиц трансляции"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
@@ -43684,7 +43714,7 @@ msgid "unknown type name %qE"
 msgstr "неизвестное имя типа %qE"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "ожидались спецификаторы декларации"
@@ -43705,7 +43735,7 @@ msgstr "за атрибутом %<fallthrough%> не следует %<;%>"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ожидалось %<;%>, идентификатор или %<(%>"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "префиксные атрибуты для методов игнорируются"
@@ -43720,7 +43750,7 @@ msgstr "префиксные атрибуты для реализаций игн
 msgid "unexpected attribute"
 msgstr "неожиданный атрибут"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "за атрибутом %<fallthrough%> не следует %<;%>"
@@ -43758,7 +43788,7 @@ msgstr "%<__auto_type%> требует инициализированной де
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> может использоваться только с одним декларатором"
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "ожидалось %<,%> или %<;%>"
@@ -43817,7 +43847,7 @@ msgstr "выражение в статическом утверждении не
 msgid "static assertion failed: %E"
 msgstr "не выполнено статическое утверждение: %E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "нарушено статическое утверждение"
@@ -43863,14 +43893,14 @@ msgstr "пустое перечисление некорректно"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "ожидался идентификатор"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "запятая в конце списка значений перечислимого типа"
@@ -43957,7 +43987,7 @@ msgstr "ожидались спецификаторы декларации ил
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "parameter packs должны быть в конце списка параметров"
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 #| msgid "the %qE attribute requires arguments"
 msgid "%qE attribute does not take any arguments"
@@ -44019,7 +44049,7 @@ msgstr "ISO C90 запрещает смешение деклараций и ко
 msgid "expected %<}%> before %<else%>"
 msgstr "ожидалось %<}%> перед %<else%>"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> без предшествующего %<if%>"
@@ -44034,7 +44064,7 @@ msgstr "метка в конце составного оператора"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "ожидался оператор"
@@ -44059,17 +44089,17 @@ msgstr "ожидался идентификатор или %<*%>"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "только атрибут %<fallthrough%> может применяться к пустому оператору"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<if%>"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<else%>"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "используйте фигурные скобки во избежание неоднозначной трактовки %<else%>"
@@ -44089,12 +44119,12 @@ msgstr "несколько переменных-итераторов в быст
 msgid "invalid iterating variable in fast enumeration"
 msgstr "некорректная переменная-итератор в быстром перечислении"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "отсутствует условие цикла в цикле с %<GCC ivdep%> pragma"
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -44110,8 +44140,8 @@ msgstr "отсутствует составной объект в быстром
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "повторный cv-qualifier"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -44140,12 +44170,12 @@ msgstr "ISO C не поддерживает выражения ?: с пусты
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -44539,13 +44569,13 @@ msgstr "ожидалась декларация метода objective-c"
 msgid "no type or storage class may be specified here,"
 msgstr "в этом месте не может указываться ни тип, ни класс хранения,"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "empty property attribute list"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -44557,55 +44587,55 @@ msgstr "отсутствует атрибут Code"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%> before %qE"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "ожидалось %<=%> перед %qE"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected %qE selector name"
 msgstr "ожидался selection-statement"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, fuzzy, gcc-internal-format
 #| msgid "setter name must terminate with %<:%>"
 msgid "setter method names must terminate with %<:%>"
 msgstr "имя setter должно заканчиваться %<:%>"
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> может использоваться только в составных операторах"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> должна быть в контексте файла"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
@@ -44616,18 +44646,18 @@ msgstr "%<#pragma omp section%> может использоваться толь
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for, while или do оператор ожидался"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "слишком много конструкций %qs"
@@ -44647,53 +44677,53 @@ msgstr "ожидалась %<)%> или %<,%>"
 msgid "%qD is not a variable"
 msgstr "%qD не переменная"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD не указательная переменная"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "ожидалось %<none%> или %<shared%>"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ожидалось %<data%>, %<update%>, %<enter%> или %<exit%>"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "ожидалось %<data%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "слишком много %<if%> клаузул"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "слишком много %<if%> клаузул без модификатора"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "если какая-либо %<if%> клаузула имеет модификатор, то все %<if%> должны использовать модификатор"
@@ -44715,114 +44745,114 @@ msgstr "значение %<num_threads%> должно быть положите
 msgid "%<num_tasks%> value must be positive"
 msgstr "значение %<num_tasks%> должно быть положительным"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "значение %<grainsize%> должно быть положительным"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "значение %<priority%> должен быть неотрицательным"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "ожидалось целочисленное выражение"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%> before %<decltype%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "ожидалось %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%> перед %<decltype%>"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs выражение должно быть целочисленным"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "значение %qs должно быть положительным"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "слишком много %<static%> аргументов"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "неожиданный аргумент"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%<tile%> аргумент требует положительной целочисленной константы"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%>"
 msgid "expected %<concurrent%>"
 msgstr "ожидалось %<new%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "ordered аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> или идентификатор"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "заданы оба модификатора %<monotonic%> и %<nonmonotonic%>"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<runtime%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<auto%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "значение размера чанка должно быть положительным"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "некорректный тип планирования"
@@ -44832,17 +44862,17 @@ msgstr "некорректный тип планирования"
 msgid "%<num_teams%> value must be positive"
 msgstr "значение %<num_teams%> должно быть положительным"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "значение %<thread_limit%> должно быть положительным"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%<aligned%> клаузула выражения выравнивания должна быть положительным константным целочисленным выражением"
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -44862,23 +44892,23 @@ msgstr "%<safelen%> клаузула выражения должна быть п
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%> клаузула выражения должна быть положительным константным целочисленным выражением"
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "модификатор %qs возможности несовместим с %s %s"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "некорректный depend вид"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "некорректный map вид"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "некорректный dist_schedule вид"
@@ -44894,86 +44924,86 @@ msgstr "некорректный proc_bind вид"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "ожидалась %<#pragma acc%> клаузула"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs не является корректным для %qs"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs должна быть первой клаузулой %qs"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "нет допустимых клаузул заданных в %<#pragma acc declare%>"
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "секция массива в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD должна быть глобальной переменной в %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "некорректная OpenACC клаузула в контексте файла"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "некорректное использование %<extern%> переменной %qD в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "некорректное использование %<global%> переменной %qD в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD должна быть глобальной переменной в %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "переменная %qD использована более одного раза с %<#pragma acc declare%>"
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ожидалось %<data%> после %<#pragma acc %s%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> не содержит клаузулу перемещения данных"
@@ -44988,7 +45018,7 @@ msgstr "%qE не был декларирован"
 msgid "expected function name"
 msgstr "ожидалось имя функции"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD не ссылается на функцию"
@@ -44998,27 +45028,27 @@ msgstr "%qD не ссылается на функцию"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "за %<#pragma acc routine%> не следует немедленно декларация или определение функции"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "за %<#pragma acc routine%> не следует немедленно декларация или определение одиночной функции"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> должна быть применена до использования"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> должна быть применена до определения"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> должна содержать по крайней мере одну %<device%>, %<host%> или %<self%>клаузулу"
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<allocator%>"
@@ -45029,93 +45059,93 @@ msgstr "ожидалось %<operator%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable больше не поддерживается"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "ожидалась клаузула %<depend%>, %<destroy%> или %<update%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> или идентификатор"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "некорректный формат %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "некорректный оператор для %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> использует два различных выражения для памяти"
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant expression"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "ожидалось %<data%>, %<update%>, %<enter%> или %<exit%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "ожидалась клаузула %<depend%>, %<destroy%> или %<update%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, fuzzy, gcc-internal-format
 #| msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgid "%<flush%> list specified together with memory order clause"
@@ -45126,34 +45156,34 @@ msgstr "%<nonmonotonic%> модификатор планирования зад
 msgid "expected %<(%> or end of line"
 msgstr "ожидалось %<(%> или конец строки"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%> before %<decltype%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "ожидалось %<while%> перед %<decltype%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%> параметр клаузулы меньше чем %<collapse%>"
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "%<linear%> клаузула не может задаваться вместе с %<ordered%> клаузулой с параметром"
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "ожидался оператор for"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "ожидалась декларация итерации или инициализация"
@@ -45163,73 +45193,73 @@ msgstr "ожидалась декларация итерации или иниц
 msgid "not enough perfectly nested loops"
 msgstr "недостаточно аккуратно вложенные циклы"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "сливаемые циклы не являются идеально вложенными"
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "итерационная переменная %qD не должна быть firstprivate"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> с %<depend%> клаузулой может использоваться только в составных операторах"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ожидался %<for%> после %qs"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ожидалось %<point%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> с map-type отличном от %<to%>, %<from%>, %<tofrom%> или %<alloc%> на %<map%> клаузуле"
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> с map-type отличном от %<to%> или %<alloc%> на %<map%> клаузуле"
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> с map-type отличном от %<from%>, %<release%> или %<delete%> на %<map%> клаузуле"
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> с map-type отличном от %<to%>, %<from%>, %<tofrom%> или %<alloc%> на %<map%> клаузуле"
@@ -45246,66 +45276,66 @@ msgstr "за %<#pragma omp declare simd%> должна следовать дек
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "за %<#pragma omp declare simd%> должна следовать декларация или определение функции"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "ожидался selection-statement"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%<no-custom-%s%> не принимает аргументы"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "ordered аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L must be nonnegative"
 msgid "score argument must be non-negative"
 msgstr "%qs в %L должен быть неотрицательным"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 #| msgid "%qs length expression must be positive constant integer expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "ожидался строковый литерал"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "ожидалось целочисленное выражение"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, fuzzy, gcc-internal-format
 #| msgid "property %qs already specified in %<@synthesize%>"
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "свойство %qs уже специфицировано в %<@synthesize%>"
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "ожидалось %<data%>, %<update%>, %<enter%> или %<exit%>"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -45317,13 +45347,13 @@ msgstr "ожидалось %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "%qs в %L не есть функция"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 #| msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "  типы %qT и %qT имеют несовместимые cv-qualifiers"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -45334,33 +45364,33 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%>, за которой не следует немедленно декларация функции или определение"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%>, за которой не следует немедленно одиночная декларация функции или определение"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD задан и в declare target %<link%> и в %<to%> клаузулах"
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ожидалось %<target%>"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "ожидалось %<declare%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> без соответствующей %<#pragma omp declare target%>"
@@ -45415,46 +45445,46 @@ msgstr "ожидалось имя функции %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "одним из аргументов вызова инициализатора должен быть %<&omp_priv%>"
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "ожидалось %<simd%> или %<reduction%> или %<target%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
 #
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 #| msgid "using parameters for %<linear%> step is not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "модель кода %<large%> пока не поддерживается"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<pragma omp requires%> requires at least one clause"
@@ -45472,27 +45502,27 @@ msgstr "%<_Atomic%> %qE в %<reduction%> клаузуле"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "тип элемента переменой длины в предложении массива %<reduction%>"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE объявлена %<threadprivate%> после первого использования"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "автоматическая переменная %qE не может быть %<threadprivate%>"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE имеет неполный тип"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> без включения транзакционной памяти"
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> внутри %<__transaction_relaxed%>"
@@ -45503,7 +45533,7 @@ msgstr "%<__transaction_cancel%> внутри %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> вызов функции не внутри внешней транзакции или %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> не внутри %<__transaction_atomic%>"
@@ -45518,7 +45548,7 @@ msgstr "нет закрывающей скобки"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD имеет неполный тип %qT"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неправильное использование void-выражения"
@@ -45560,130 +45590,130 @@ msgstr "атрибут %qE не доступен для функций с пер
 msgid "function types not truly compatible in ISO C"
 msgstr "с точки зрения ISO C типы функций не являются строго совместимыми"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and vector types"
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "недопустимо смешивание операндов плавающего десятичного и векторного типа"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and complex types"
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "недопустимо смешивание операндов плавающего десятичного и комплексного типа"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and other float types"
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "недопустимо смешивание операндов плавающего десятичного и другого плавающего типа"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "указатели на массивы с разными квалификаторами не совместимы в ISO C"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "типы не вполне совместимы"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "указуемые типы несовместимы в C++"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "типы возвращаемых значений функции несовместимы из-за %<volatile%>"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "конвертация составного литерала-массива в указатель не годится в C++"
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT не содержит элемент с именем %qE; имелось в виду %qE?"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT не содержит элемента с именем %qE"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr "доступ к элементу %qE атомарной структуры %qE"
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "доступ к элементу %qE атомарного объединения %qE"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr "%qE указатель; имелось в виду использовать %<->%>?"
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "выборка элемента %qE из объекта, не являющегося структурой или объединением"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "доступ по указателю %<void *%>"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексируемый объект не является ни массивом, ни указателем, ни вектором"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс массива не является целым значением"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "индексируемый элемент является указателем на функцию"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "в ISO C индексирование %<register%>-массивов запрещено"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "в ISO C индексирование не-lvalue массива запрещено"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr "константа перечислимого типа определена здесь"
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> от массивного параметра функции %qE вернет размер от %qT"
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "вызываемый объект %qE не является функцией или указателем на функцию"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "вызываемый объект %qD не является функцией или указателем на функцию"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "вызываемый объект не является функцией или указателем на функцию"
@@ -45691,1642 +45721,1642 @@ msgstr "вызываемый объект не является функцией
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "вызов функции через несовместимый тип"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "вызов функции, имеющей квалифицированный void-тип возвращаемого значения"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "формальный параметр %d имеет неполный тип"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как целое, а не плавающее"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как целое, а не комплексное"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как комплексное, а не плавающее"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как плавающее, а не целое"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как комплексное, а не целое"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как плавающее, а не комплексное"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как %<float%>, а не %<double%>"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "передан аргумент %d функции %qE как %qT, а не %qT согласно прототипу"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан с другой шириной"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как unsigned"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "аргумент %d %qE согласно прототипу будет передан как signed"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "слишком много аргументов в вызове метода %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "слишком много аргументов в вызове функции %qE"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "неявная конверсия из %qT в %qT при передаче аргумента функции"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "слишком мало аргументов в вызове функции %qE"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "сравнение со строковым литералом приводит к неопределенному поведению"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "сравнение указателя и нулевой символьной константы"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "вы хотели перейти по указателю?"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "сравнение между %qT и %qT"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "указатель %<void *%> в операции вычитания"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "указатель на функцию в операции вычитания"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "арифметическая операция над указателем на неполный тип"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "арифметическая операция над указателем на пустой агрегат"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> над булевым выражением"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "имелось в виду использовать логическое not?"
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "в ISO C не поддерживается использование %<~%> для обозначения операции комплексного сопряжения"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "неверный тип аргумента для abs"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "неверный тип аргумента для унарного `!'"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "инкрементация значения перечислимого типа некорректна в C++"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "декрементация значения перечислимого типа некорректна в C++"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "инкремент булева выражения"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "декремент булева выражения"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "в ISO C операции %<++%> и %<--%> для комплексных типов не поддерживаются"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "неверный тип аргумента инкрементации"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "неверный тип аргумента декрементации"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "инкремент указателя на неполный тип %qT"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "декремент указателя на неполный тип %qT"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "взятие адреса от выражения типа %<void%>"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "некорректная попытка взять адрес битового поля %qD"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "нельзя взять адрес от скаляра с обратным порядком памяти"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "адрес массива с обратным порядком скалярной памяти"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "глобальная регистровая переменная %qD использована во вложенной функции"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "регистровая переменная %qD использована во вложенной функции"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "запрошен адрес глобальной регистровой переменной %qD"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "запрошен адрес регистровой переменной %qD"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "не lvalue-массив в условном выражении"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "неявная конверсия из %qT в %qT для совместимости с другим результатом условного выражения"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "в ISO C запрещены условные выражения, где только одна из альтернатив имеет тип void"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "указатели на не связанные адресные пространства в условном выражении"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "указатель на массив теряет квалификатор в условном выражении"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "в ISO C запрещены условные выражения, с альтернативами типа %<void *%> и указатель на функцию"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "несоответствие указательных типов в условном выражении"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "несоответствие указательных типов в условном выражении"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "несоответствие типов указатель/целое в условном выражении"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "несоответствие типов в условном выражении"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "игнорирование возвращаемого значения от %qD, декларированной с атрибутом nodiscard"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "игнорирование возвращаемого значения от %qD, декларированной с атрибутом nodiscard"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "игнорирование возвращаемого значения типа %qT, декларированного с атрибутом nodiscard"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "игнорирование возвращаемого значения типа %qT, декларированного с атрибутом nodiscard"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "в вызове %qD, декларированной здесь"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "правый операнд comma выражения не имеет эффекта"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr "приведение типа добавляет квалификатор %q#v к типу функции"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "приведение типа отбрасывает квалификатор типа цели указателя"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "для надежности все промежуточные указатели в приведении типа от %qT к %qT должны быть снабжены квалификатором %<const%>"
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "тип массива в операции приведения типов"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "тип функции в операции приведения типов"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "в ISO C приведение нескалярного типа к тому же типу запрещено"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "в ISO C приведение к типу объединения запрещено"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "приведение к типу объединения от типа, отсутствующего в объединении"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "приведение типа к указателю на адресное пространство %s от указателя на не связанное общее адресное пространство"
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "приведение типа к указателю на общее адресное пространство от указателя на не связанное адресное пространство %s"
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "приведение типа к указателю на адресное пространство %s от указателя на не связанное адресное пространство %s"
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "приведение типа требует большего выравнивания, чем исходный тип"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "приведение указателя к целому другого размера"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "приведение вызова функции типа %qT к несоответствующему типу %qT"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "приведение к типу указателя от целого другого размера"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C запрещает преобразование указателя на функцию к указателю на объект"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C запрещает преобразование указателя на объект к указателю на функцию "
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr ""
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "определение типа в приведении типа некорректно в C++"
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "присваивание выражению с массивным типом"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "преобразование перечислимого типа в присваивании некорректно в C++"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(где-то рядом с инициализацией для %qs)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "инициализация символьного массива строкой в скобках"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "ожидался тип %qT, но аргумент имеет тип %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "built-in %qD declared here"
 msgstr "программа %qD декларирована здесь"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "преобразование перечислимого типа при передаче аргумента %d %qE недопустимо в C++"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %q#T to %q#T"
 msgid "implicit conversion from %qT to %qT"
 msgstr "преобразование из %q#T в %q#T"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "передача аргумента %d функции %qE добавляет квалификатор %q#v к указателю на функцию без квалификаторов"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "присваивание добавляет квалификатор %q#v к указателю на функцию без квалификаторов"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "инициализация добавляет квалификатор %q#v к указателю на функцию без квалификаторов"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "возврат значения добавляет квалификатор %q#v к указателю на функцию без квалификаторов"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "присваивание отменяет квалификатор %qv указуемого типа"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "инициализация отменяет квалификатор %qv указуемого типа"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "возврат результата отменяет квалификатор %qv указуемого типа"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "в ISO C преобразование аргумента к типу объединения запрещено"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "неявная конверсия из %qT в %qT, запрещенная в C++"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "передача аргумента %d %qE по указателю на не замкнутое адресное пространство"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "присваивание по указателю на не замкнутое адресное пространство"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "инициализация по указателю на не замкнутое адресное пространство"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "возврат значения по указателю на не замкнутое адресное пространство"
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "аргументу %d %qE, вероятно, можно назначить атрибут format"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "левой части присваивания, вероятно, можно назначить атрибут format"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "левой части инициализации, вероятно, можно задать атрибут format"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "тип результата, вероятно, может быть задан с атрибутом format"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "в передаче аргумента %d %qE: несовместимый тип указателя"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, fuzzy, gcc-internal-format
 #| msgid "increment of pointer to an incomplete type %qT"
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "инкремент указателя на неполный тип %qT"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT"
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "некорректное применение %qs к неполному типу %qT"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, fuzzy, gcc-internal-format
 #| msgid "increment of pointer to an incomplete type %qT"
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "инкремент указателя на неполный тип %qT"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "в ISO C передача аргумента %d функции %qE с преобразованием указателя на функцию в тип %<void *%> запрещена"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "в ISO C присваивание с преобразованием указателя на функцию в тип %<void *%> запрещено"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "в ISO C инициализация с преобразованием указателя на функцию в тип %<void *%> запрещена"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "в ISO C возврат результата с преобразованием указателя на функцию в тип %<void *%> запрещен"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "при передаче аргумента %d %qE: указуемые типы различаются знаковостью"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "в передаче аргумента %d %qE: несовместимый тип указателя"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "increment of pointer to an incomplete type %qT"
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "инкремент указателя на неполный тип %qT"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "некорректное применение %qs к неполному типу %qT"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "указатель на элементный тип %qT несовместим с объектным типом %qT"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "при передаче аргумента %d %qE целое преобразуется в указатель без приведения типа"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "при передаче аргумента %d %qE указатель преобразуется в целое без приведения типа"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "несовместимый тип аргумента %d функции %qE"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "несовместимые типы в присваивании типу %qT значения типа %qT"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "несовместимые типы при инициализации типа %qT, используя тип %qT"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "несовместимые типы при возврате значения типа %qT вместо ожидаемого типа %qT"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "в традиционном C инициализация автоматических агрегатных переменных запрещена"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "инициализация регулируемого элемента-массива"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "инициализация массива несоответствующего типа строковой константой"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "некорректное использование массива, не являющегося левой частью присваивания"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "элемент инициализатора не является константой"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "инициализация массива неконстантным выражением"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "инициализирующий элемент не может быть вычислен во время компоновки"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "неверный инициализатор"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "вектор скрытого типа не может быть инициализирован"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "избыточные фигурные скобки в конце инициализатора"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "фигурные скобки вокруг скалярного инициализатора"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "инициализация элемента регулируемого элемента-массива во вложенном контексте"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "отсутствует инициализатор для поля %qD из %qT"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "пустой скалярный инициализатор"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "избыточные элементы в скалярном инициализаторе"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "индекс массива в инициализаторе не для массива"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "имя поля в инициализаторе не для структуры или объединения"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "индекс массива в инициализации не целого типа"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "индекс массива в инициализации не является целочисленным константным выражением"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "неконстантный индекс массива в инициализаторе"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "индекс массива в инициализаторе - за границами массива"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "пустой диапазон индексов в инициализаторе"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "диапазон индексов массива в инициализаторе - за границами массива"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "повторная инициализация поля с побочными эффектами"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "инициализированное поле перезаписано"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "преобразование типов в инициализаторе недопустимо в C++"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "избыточные элементы в инициализаторе символьного массива"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "избыточные элементы в инициализаторе структуры"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "позиционная инициализация поля в %<struct%> декларированной с %<designated_init%> атрибутом"
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "не статическая инициализация регулируемого элемента-массива в структуре"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "избыточные элементы в инициализаторе объединения"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "в традиционном C инициализация объединений запрещена"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "избыточные элементы в инициализаторе массива"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "избыточные элементы в инициализаторе вектора"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "избыточные элементы в инициализаторе скаляра"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "в ISO C операторы вида %<goto *expr;%> запрещены"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функция декларированная с атрибутом %<noreturn%> содержит оператор %<return%>"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "оператор %<return%> без значения в функции, возвращающей не void-значение"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "оператор %<return%> <значение> в функции возвращающей void"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "в ISO C запрещен оператор %<return%> с выражением в функции, возвращающей void"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "функция возвращает адрес метки"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "в операторе switch задано не целое"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "в ISO C %<long%>-выражение в операторе switch не преобразуется в %<int%>"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case-метка не является целочисленным константным выражением"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-метка вне оператора switch"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "метка %<default%> вне оператора switch"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "некорректный выход из OpenMP структурного блока"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "оператор break использован с OpenMP для цикла"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "оператор continue вне цикла"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "оператор без побочного эффекта"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "сравнение векторов с разными типами элементов"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "сравнение векторов с разным числом элементов"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "невозможно найти целый тип того же размера, что и %qT"
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "сравнение плавающих значений при помощи == или != не надежно"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "результат сравнения всегда %<false%>, поскольку адрес %qD не может быть NULL"
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "результат сравнения всегда %<true%>, поскольку адрес %qD не может быть NULL"
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "сравнение указателей на несвязанные адресные пространства"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "в ISO C сравнение указателя на функцию с указателем %<void *%> запрещено"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "сравнение различных указательных типов без приведения типов"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "сравнение указателя и целого"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "сравнение указателей на полный и неполный типы"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C разрешает сравнение указателей на функции только на равенство/неравенство"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "упорядоченное сравнение указателя с нулевым указателем"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "упорядоченное сравнение указателя с целочисленным нулем"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "неявная конверсия из %qT в %qT для совместимости с другим операндом бинарного выражения"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "массив, не приводимый к указателю, употреблен в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "структурное значение употреблено в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "объединение употреблено в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "векторный тип использован в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> должна задавать одну из %<parallel%>, %<for%>, %<sections%> или %<taskgroup%> клаузул"
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<parallel%> or %<target%> %<if%> clause modifier"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "ожидался %<parallel%> или %<target%> модификатор %<if%> клаузулы"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> должна задавать одну из %<parallel%>, %<for%>, %<sections%> или %<taskgroup%> клаузул"
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE в %qs клаузуле"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "битовое поле %qE в %qs клаузуле"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE является элементом объединения"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qE in %qs clause"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "битовое поле %qE в %qs клаузуле"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD не есть переменная в %qs клаузуле"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE не есть переменная в %qs клаузуле"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD в %qs клаузуле"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD есть threadprivate переменная в %qs клаузуле"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "нижняя граница %qE секции массива не имеет целочисленный тип"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "длина %qE секции массива не имеет целочисленный тип"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer %qs in %s clause at %L"
 msgid "expected single pointer in %qs clause"
 msgstr "Указатель на процедуру %qs в %s клаузуле в %L"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "секция массива нулевой длины в %qs клаузуле"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "для массивного типа с неизвестной границей должно быть задано выражение для длины"
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "отрицательная нижняя граница в секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "отрицательная длина в секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "нижняя граница %qE выше размера секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "длина %qE выше размера секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "верхняя граница %qE выше размера секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, fuzzy, gcc-internal-format
 #| msgid "for unknown bound array type length expression must be specified"
 msgid "for array function parameter length expression must be specified"
 msgstr "для массивного типа с неизвестной границей должно быть задано выражение для длины"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "для типа указателя должно быть задано выражение длины"
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "секция массив не непрерывна в %qs клаузуле"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE не имеет тип указателя или массива"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "исключительная ситуация NULL имеет целый тип, а не тип указателя"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified array type"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "%<_Atomic%>-квалифицированный массивный тип"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "параметр %qD имеет неполный тип"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "битовое поле %qD не целочисленного типа"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "condition expression refers to iteration variable %qD"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "выражение условия ссылается на итерационную переменную %qD"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "condition expression refers to iteration variable %qD"
 msgid "end expression refers to outer iterator %qD"
 msgstr "выражение условия ссылается на итерационную переменную %qD"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 #| msgid "initializer expression refers to iteration variable %qD"
 msgid "step expression refers to outer iterator %qD"
 msgstr "выражение инициализатора ссылается на итерационную переменную %qD"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected pointer in %qs clause"
 msgstr "ожидался указатель"
 
 #
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, fuzzy, gcc-internal-format
 #| msgid "using parameters for %<linear%> step is not supported yet"
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "модель кода %<large%> пока не поддерживается"
 
 #
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, fuzzy, gcc-internal-format
 #| msgid "using parameters for %<linear%> step is not supported yet"
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "модель кода %<large%> пока не поддерживается"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD в %<reduction%> клаузуле есть массив нулевой длины"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE в %<reduction%> клаузуле"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qE in %qs clause"
 msgid "zero sized type %qT in %qs clause"
 msgstr "битовое поле %qE в %qs клаузуле"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qE in %qs clause"
 msgid "variable sized type %qT in %qs clause"
 msgstr "битовое поле %qE в %qs клаузуле"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE имеет недопустимый тип для %<reduction(%s)%>"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "определенная пользователем редукция не найдена для %qE"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "тип элемента переменой длины в предложении массива %<reduction%>"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE должно быть %<threadprivate%> для %<copyin%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "модификатор не должен задаваться в предложении %<linear%> для конструкций %<simd%> или %<for%>"
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "линейное предложение применено к нецелой переменной без указателя с типом %qT"
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD в предложении %<linear%>"
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "шаг предложения %<linear%> %qE не является ни константой, ни параметром"
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE не является переменной в предложении %qs"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD многократно встречается в предложениях сокращения"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE многократно встречается в предложениях данных"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD многократно встречается в предложениях данных"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD встречается в предложениях данных и сопоставления"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE не является переменной в предложении %<firstprivate%>"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE не является переменной в предложении %<lastprivate%>"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE не является переменной в предложении %<aligned%>"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "%qE в предложении %<aligned%> не является ни указателем, ни массивом"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%<_Atomic%> %qD в предложении %<aligned%>"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE многократно встречается в предложении %<aligned%>"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE не является переменной в предложении %<depend%>"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in %<aligned%> clauses"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE многократно встречается в предложении %<aligned%>"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE не является переменной в предложении %<aligned%>"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in %<aligned%> clauses"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE многократно встречается в предложении %<aligned%>"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE не является переменной в предложении %<depend%>"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "секция массива не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD многократно встречается в предложениях движения"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD многократно встречается в предложениях сопоставления"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE не является ни переменной, ни именем функции в предложении %qs"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE многократно встречается в одной директиве %<declare target%><)%>"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD не является аргументом в %<uniform%> предложении"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE не является аргументом в %<uniform%> предложении"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "источник не есть указатель"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "%qs переменная не является ни указателем, ни массивом"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "предложение %<inbranch%> несовместимо с %<notinbranch%>"
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE является предопределённым %qs для %qs"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "значение предложения %<simdlen%> больше значения %<safelen%> предложения"
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%> модификатор планирования задан вместе с %<ordered%> предложением"
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "шаг %<linear%> предложения является параметром %qD, который не указан в %<uniform%> предложении"
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "нельзя использовать %<va_arg%> с обратным порядком хранения"
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "второй аргумент %<va_arg%> имеет неполный тип %qT"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "в C++ требуется расширенный тип, а не перечислимый тип в %<va_arg%>"
@@ -47551,7 +47581,7 @@ msgstr ""
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -47662,680 +47692,686 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%D(%A)%>"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "вызов перегруженной функции %<%D(%A)%> неоднозначен"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "не найден метод для преобразования в %<(%T) (%A)%>"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "вызов %<(%T) (%A)%> неоднозначен"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "тернарный %<operator?:%>"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> в %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> в %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs в %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%>"
 msgid "%<operator %s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator%s%> в %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> в %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> в %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ запрещает опускать средний операнд выражения ?:"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, fuzzy, gcc-internal-format
 #| msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "выведенный скалярный тип %qT не есть целый или плавающий тип того же размера, что и %qT"
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "несовместимые векторные типы в условном выражении: %qT, %qT и %qT"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "второй операнд условного оператора имеет тип %<void%>, но третий операнд не является ни throw-expression, ни элементом типа %<void%>"
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "третий операнд условного оператора имеет тип %<void%>, но второй операнд не является ни throw-expression, ни элементом типа %<void%>"
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "операнды для ?: имеют разные типы %qT и %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "несоответствие перечислимых типов в условном выражении: %qT vs %qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "условное выражение между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "условное выражение между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "перечислимый и неперечислимый тип в условном выражении"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "нет %<%D(int)%> декларированного для постфиксного %qs, пробуем применить префиксный оператор"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "нет %<%D(int)%> декларированного для постфиксного %qs"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "возвращаемое значение функции %qD - не %<int%>"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "сравнение между %q#T и %q#T"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, fuzzy, gcc-internal-format
 #| msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "очистка исключений для этого размещения new выбирает неразмещенный оператор delete"
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD есть обычная (неразмещенная) функция освобождения в C++14 (или с -fsized-deallocation)"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD есть обычная (неразмещенная) функция освобождения"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "нет соответствующей функции освобождения для %qD"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нет подходящего %<operator %s%> для %qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D private в данном контексте"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "декларировано private здесь"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D protected в данном контексте"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "декларировано protected здесь"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D недоступно в данном контексте"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "передача NULL в неуказательный аргумент %P в %qD"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid " declared here"
 msgid "  declared here"
 msgstr " объявлено здесь"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "преобразование в неуказательный тип %qT из NULL"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "преобразование %<false%> в указательный тип для аргумента %P в %qD"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "преобразование %<false%> в указательный тип %qT"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  при инициализации %P -го аргумента %qD"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, fuzzy, gcc-internal-format
 #| msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "явные операции преобразования доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "слишком много фигурных скобок вокруг инициализатора для %qT"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "преобразование в %qT из списка инициализации будет использовать явный конструктор %qD"
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "в C++11 и выше подразумеваемый конструктор может быть явным"
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+#| msgid "conversion to non-const reference type %q#T from rvalue of type %qT"
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "преобразование к неконстантной ссылки типа %qT из rvalue типа %qT"
+
+#: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "недопустимое связывание битового поля %qE с %qT"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "недопустимое связывание упакованного  поля %qE с %qT"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "недопустимое связывание rvalue %qE с %qT"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, fuzzy, gcc-internal-format
 #| msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "scoped enum %qT передан дальше ... как %qT перед fabi-version=6, %qT после"
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "передача объектов нетривиально копируемого типа %q#T через %<...%> условно поддерживается"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "невозможно принять ссылочный тип %q#T через %<...%>"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "прием объектов нетривиально копируемого типа %q#T через %<...%> условно поддерживается"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "рекурсивное вычисление подразумеваемого аргумента для %q#D"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "вызов %qD использует подразумеваемый аргумент для параметра %P, который еще не определен"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент вызова функции мог быть кандидатом для атрибута формата"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "использование мультиверсионной функции без подразумеваемой"
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "передача %qT как аргумент %<this%> отбрасывает квалификаторы"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  в вызове %qD"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "передача аргументов в многоточие унаследованного конструктора %qD"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "конструктор делегирует к себе"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нет подходящей функции для вызова %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "вызов не функции %qD"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "невозможно вызвать конструктор %<%T::%D%> непосредственно"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "для приведения типов в функциональном стиле удалите избыточные %<::%D%>"
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%s(%A)%>"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "вызов перегруженной %<%s(%A)%> имеет неоднозначную трактовку"
 
 #
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "чисто виртуальная %q#D вызвана из инициализатора нестатического элемента данных"
 
 #
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "чисто виртуальная %q#D вызвана из конструктора"
 
 #
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "чисто виртуальная %q#D вызвана из деструктора"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "некорректный вызов элемента-функции %qD без объекта"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "при передаче %qT предпочтение отдается %qT, а не %qT"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "предпочтение отдается %qD (а не %qD)"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  поскольку это дает лучшую последовательность преобразований аргумента"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "несоответствие подразумеваемого аргумента при разрешении перегрузки"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ говорит здесь о неоднозначности, хотя худшее преобразование для первого лучше, чем худшее преобразование для второго:"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "временная граница %qD сохраняется, пока существует конструктор"
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -48359,1187 +48395,1187 @@ msgstr "невозможно преобразовать из указателя
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "невозможно преобразовать из базового класса %qT в производный класс %qT посредством виртуальной базы %qT"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base class %qT to derived class %qT because the base is virtual"
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "невозможно преобразовать из базового класса %qT в производный класс %qT, так как база является виртуальной"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr ""
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "предыдущая декларация %q#D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "противоречивые спецификации доступа для метода %q+D, игнорируются"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "противоречивые спецификации доступа для поля %qE, игнорируются"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD наследует %E ABI тэг, который имеет %qT (использованный в его типе возврата)"
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT декларировано здесь"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD наследует %E ABI тэг, который имеет %qT (использованный в его типе)"
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qT не имеет %E ABI тэг, который имеет базовый %qT"
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qT не имеет %E ABI тэг, который имеет %qT (использованный в типе %qD)"
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "ошибка вывода из %<final%> base %qT в производном типе %qT"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "все элементы-функции в классе %qT - частные (private)"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "в %q#T определен только private деструктор и нет друзей"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "в %q#T определен только private конструктор и нет друзей"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "отсутствует уникальное переопределение %qD в %qT"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%q#D может быть помечен override"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D помечен %<override%>, но не делается override"
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D помечен %<final%>, но не является virtual"
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD было скрыто"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "многоточие в %qD не наследуется"
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "битовое поле %q+#D с нецелым типом"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ширина битового поля %q+D не является целой константой"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "отрицательная ширина битового поля %q+D"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "нулевая ширина битового поля %q+D"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "ширина %qD превышает его тип"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD слишком мало для хранения всех значений %q#T"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "элемент %q+#D с конструктором не допускается в объединении"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "элемент %q+#D с деструктором не допускается в объединении"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "элемент %q+#D с операцией присваивания путем копирования не допускается в объединении"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "в C++98 %q+D может не быть статическим, поскольку это элемент объединения"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "нестатический элемент данных %q+D в объединении может не иметь ссылочный тип %qT"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "поле %q+D ошибочно декларировано с типом функции"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "атрибут packed проигнорирован из-за неупакованного не-POD поля %q#D"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "элемент %q+D не может быть декларирован как %<mutable%> ссылка"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "элемент %q+D не может быть декларирован и как %<const%>, и как %<mutable%>"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "инициализация нескольких полей в объединении %qT"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "next member %q#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "следующий элемент %q#D объявлен здесь"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "поле %q#D с тем же именем, что и класс"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q+#T содержит элементы данных типа указатель"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  но не переопределяет %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  но не переопределяет %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "next member %q#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "следующий элемент %q#D объявлен здесь"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "выравнивание %qD увеличено в -fabi-version=9 (GCC 5.2)"
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD will increase in -fabi-version=9"
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "выравнивание %qD увеличится в -fabi-version=9"
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "инициализатор задан для невиртуального метода %q+D"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "метод перебивает оба метода %<transaction_pure%> и %qE"
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "описанный метод %qE перебивает метод %qE"
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T не является литералом, поскольку:"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T имеет нетривиальный деструктор"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T имеет нетривиальный деструктор"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  базовый класс %qT %q+T не литерал"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "базовый класс %q#T имеет доступный невиртуальный деструктор"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "нестатическая ссылка %q#D в классе без конструктора"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "нестатический константный элемент %q#D в классе без конструктора"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредственная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуальная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "смещение %qD несовместимо с ABI и может измениться в будущих версиях GCC"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "размер типа %qT слишком велик (%qE байт)"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "некорректное использование %q#T с массивом нулевого размера в %q#D"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "недопустимое использование %q#T с элементом регулируемого массива в %q#T"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "элемент массива %q#D объявлен здесь"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "элемент массива нулевого размера %qD не в конце %q#T"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "элемент массива нулевого размера %qD в другом пустом %q#T"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "в определении %q#T"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "элемент регулируемого массива %qD не в конце %q#T"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "элемент регулируемого массива %qD в другом пустом %q#T"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "следующий элемент %q#D объявлен здесь"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T содержит виртуальные функции и доступный невиртуальный деструктор"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "тип transparent %q#T не имеет полей"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "type transparent класс %qT имеет базовые классы"
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "в типе прозрачного класса %qT есть виртуальные функции"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "type transparent %q#T не может быть сделан прозрачным, так как тип первого поля имеет ABI, отличный от класса в целом"
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "определение %qD не соответствует %<#include <initializer_list>%>"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "не удалось завершить структуру из-за предыдущих грамматических ошибок"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "некорректная строка %<\"%E\"%>, задающая язык"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ошибка при выборе перегруженной функции %qD при преобразовании к типу %qT"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нет способа для преобразования функции %qD к типу %q#T"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "преобразование перегруженной функции %qD к типу %q#T неоднозначно"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "предполагается указатель на элемент %qD"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(указатель на элемент можно получить только при помощи %<&%E%>)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "недостаточная информация о типе"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "ошибка преобразования %qE из типа %qT в тип %qT"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
 msgstr "редекларирован здесь как %q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr ""
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "переменная %qD нелитерального типа %qT в %<constexpr%> функции"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr ""
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr ""
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr ""
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T имеет виртуальные базовые классы"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%> конструктор для объединения %qT должен инициализировать в точности один нестатический элемент данных"
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "элемент %qD должен инициализироваться посредством mem-initializer в %<constexpr%> конструкторе"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E не есть константное выражение"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "вызов внутренней функции %qE"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 #| msgid "modification of %qE is not a constant expression"
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "модификация %qE не есть константное выражение"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 #| msgid "originally defined here"
 msgid "originally declared %<const%> here"
 msgstr "исходное определение находится здесь"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a base type for type %qT"
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "тип %qT не является базовым для типа %qT"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 #| msgid "variable %D of type %<io%> must be uninitialized"
 msgid "virtual table pointer is used uninitialized"
 msgstr "переменная %D типа %<io%> должна быть инициализирована"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 #| msgid "  %qT is an ambiguous base class of %qT"
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "  %qT является неоднозначным базовым классом %qT"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, fuzzy, gcc-internal-format
 #| msgid "braced list index is not allowed with array notation"
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr "-client_name нельзя использовать с -dynamiclib"
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 #| msgid "original declaration appeared here"
 msgid "allocation performed here"
 msgstr "исходная декларация находится здесь"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, fuzzy, gcc-internal-format
 #| msgid "braced list index is not allowed with array notation"
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr "-client_name нельзя использовать с -dynamiclib"
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, fuzzy, gcc-internal-format
 #| msgid "Attempting to allocate already allocated variable"
 msgid "deallocation of already deallocated storage"
 msgstr "Попытка разместить уже размещенную переменную"
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a previous local"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "декларация %qD перекрывает декларированную ранее локальную переменную"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD вызвана в константном выражении до завершения ее определения"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD вызвана в константном выражении"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD использована до своего определения"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "вызов имеет циклическую зависимость"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "правый операнд выражения сдвига %q+E отрицателен"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "правый операнд выражения сдвига %q+E >= точности левого операнда"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "левый операнд выражения сдвига %q+E отрицателен"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "переполнение выражения сдвига %q+E"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "вычисления включающие пустой указатель в %qE"
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "значение индекса массива %qE вне границ массива %qD типа %qT"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "значение индекса массива %qE вне границ массива %qD типа %qT"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "значение индекс массива %qE вне границ типа массива %qT"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "значение индекса массива %qE вне границ массива %qD типа %qT"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "доступ к неинициализированному элементу массива"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "доступ по пустому указателю в %qE"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "mutable %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "доступ к неинициализированному элементу %qD"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "обращение к элементу %qD вместо инициализированного элемента %qD в константном выражении"
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "вложенные функции не поддерживаются для этой платформы"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "accessing uninitialized member %qD"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "доступ к неинициализированному элементу %qD"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "доступ по пустому указателю"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "обращение к значению %qE через %qT glvalue в константном выражении"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 #| msgid "the value of %qD is not usable in a constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "значение %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "объявлено здесь"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "use of the value of the object being constructed in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "использование значения конструируемого объекта в константном выражении"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "значение %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD использована в своем собственном инициализаторе"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D не есть const"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D переменная"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD не была инициализирована константным выражением"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD не была декларирована %<constexpr%>"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "модификация %qE не есть константное выражение"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "Изменение значения в преобразовании из %qs в %qs в %L"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Изменение значения в преобразовании из %qs в %qs в %L"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "оператор не является константным выражением"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "значение %qE типа %qT не есть константное выражение"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "a reinterpret_cast is not a constant expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "reinterpret_cast не является константным выражением"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "преобразование из указательного типа %qT в арифметический тип %qT в константном выражении"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "%s\"%s\"%s не допускается"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не является константным выражением"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "ожидался template-id"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE must be directly called"
 msgid "function concept must be called"
 msgstr "внутренняя функция %qE должна вызываться напрямую"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "неожиданное выражение %qE вида %s"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на не полностью инициализированную переменную"
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from integer to pointer"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast из целого в указатель"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of объекта %qE с поточно-локальным или автоматическим хранением не есть константное выражение"
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "использование %<this%> в константном выражении"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "приведение к нецелочисленному типу %qT в константном выражении"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не есть константное выражение"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "неконстантная инициализация массива"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не есть константное выражение"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 #| msgid "statement is not a constant expression"
 msgid "label definition is not a constant expression"
 msgstr "оператор не является константным выражением"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "неожиданное AST вида %s"
@@ -49549,59 +49585,59 @@ msgstr "неожиданное AST вида %s"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "throw will always call terminate()"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "throw будет всегда вызывать terminate()"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "in C++11 destructors default to noexcept"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "в C++11 деструкторы подразумевают noexcept"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, fuzzy, gcc-internal-format
 #| msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "в C++11 это throw терминируется, поскольку деструкторы подразумевают noexcept"
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes in template argument %qE"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "игнорирование атрибутов аргумента шаблона %qE"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD не является типом"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT не является классовым типом"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE не имеет тип указателя или массива"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not have integral type"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -49645,7 +49681,7 @@ msgstr "преобразование к неконстантной ссылки
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "преобразование %qT в %qT не снимает указатель"
@@ -50038,7 +50074,7 @@ msgstr "из предыдущей декларации %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "редекларация %qD отличается в %<constexpr%> от предыдущей декларации"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "предыдущая декларация %qD"
@@ -50178,8 +50214,8 @@ msgstr "предыдущая декларация %<pragma omp declare reduction
 msgid "%q#D previously defined here"
 msgstr "%q#D ранее определено здесь"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D ранее декларировано здесь"
@@ -50215,60 +50251,60 @@ msgstr "подразумеваемый аргумент задан для пар
 msgid "previous specification in %q#D here"
 msgstr "предыдущая спецификации в %q#D здесь"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgid "declaration %qD conflicts with builtin"
 msgstr "декларация %q+#D конфликтует с внутренней декларацией %q#D"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of namespace %qD conflicts with"
 msgid "declaration %qD conflicts with import"
 msgstr "декларация namespace %qD противоречит"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 #| msgid " declared here"
 msgid "import declared %q#D here"
 msgstr " объявлено здесь"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "conflicting exporting declaration %qD"
 msgstr "конфликтующая декларация %q+#D"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %qD was here"
 msgid "previous declaration %q#D here"
 msgstr "предыдущая декларация %qD была здесь"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %qD was here"
 msgid "previous definition of %qD here"
 msgstr "предыдущее определение %qD было здесь"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %qD was here"
 msgid "previous declaration of %qD here"
 msgstr "предыдущая декларация %qD была здесь"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared %<virtual%> inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "функция %qD декларирована %<virtual%> внутри объединения"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "избыточная повторная декларация %qD в той же области видимости"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %q+D"
 msgid "deleted definition of %qD is not first declaration"
@@ -50282,49 +50318,49 @@ msgstr "удаленное определение %q+D"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "явная специализация %qD после первого использования"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: атрибут видимости проигнорирован, так как он конфликтует с предыдущей декларацией"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "переопределение %q#D"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD противоречит использованной функции"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D не декларировано в классе"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D переопределен inline с %<gnu_inline%> атрибутом"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D переопределен inline без %<gnu_inline%> атрибута"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "deduction guide %qD must be declared at namespace scope"
 msgid "deduction guide %q+D redeclared"
 msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -50332,672 +50368,678 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "редекларация friend %q#D не может иметь подразумеваемые аргументы шаблона"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "локальная для потока декларация %q#D следует за не локальной для потока декларацией"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "не локальная для потока декларация %q#D следует за локальной для потока декларацией"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "редекларация %q#D"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "избыточное переопределение %<constexpr%> элемента статических данных %qD"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "локальная метка %qE конфликтует с существующей меткой"
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr "предыдущая метка"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  отсюда"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  покидает OpenMP структурный блок"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  пересекает инициализацию %q#D"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  входит в контекст %q#D, имеющий нетривиальный деструктор"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  входит в try-блок"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  входит в catch-блок"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  входит в OpenMP структурный блок"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  входит в синхронизируемый или атомарный оператор"
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "  enters %<constexpr%> if statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "  входит в %<constexpr%> оператор if"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  пропускает инициализацию %q#D"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  входит в контекст %q#D, имеющий нетривиальный деструктор"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "использование %qD без параметров шаблона"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD не является шаблоном функции"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T не является классом"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "шаблон класса с именем %q#T' отсутствует в %q#T"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нет имени типа %q#T в %q#T"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "просмотр %qT в %qT неоднозначен"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именует %q#T, который не является шаблоном класса"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> именует %q#T, который не является типом"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "параметры шаблона не соответствуют шаблону %qD"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "-faligned-new=%d is not a power of two"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-faligned-new=%d не есть степень двойки"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с конструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с деструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с операцией присваивания-копирования недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибуты проигнорированы в декларации %q#T"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут для %q#T должен следовать за %qs ключевым словом"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "несколько типов в одной декларации"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "повторная декларация внутреннего типа C++ %qT"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> можно задавать только для переменных или деклараций функций"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "отсутствует имя типа в typedef-декларации"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "в ISO C++ анонимные структуры запрещены"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> может задаваться только для функций"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> может задаваться только для функций"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> может быть задан только внутри класса"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> может быть задан только для конструкторов"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "класс хранения может быть задан только для объектов и функций"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> может задаваться только для объектов и функций"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> может задаваться только для объектов и функций"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> может задаваться только для объектов и функций"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> может задаваться только для объектов и функций"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> в этой декларации отброшен"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> не может использоваться для деклараций типов"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут игнорируется в явной конкретизации %q#T"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "никакой атрибут не может применяться к явной конкретизации"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "игнорирование атрибутов примененных к классу %qT вне определения"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "игнорирование атрибутов примененных к зависимому типу %qT без ассоциированной декларации"
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD инициализирован (используйте decltype взамен)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларация %q#D содержит %<extern%> и инициализирована"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "определение функции %q#D помечено %<dllimport%>"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D не есть статический элемент данных %q#T"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "non-member-template декларация %qD"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "не соответствует декларации элемента шаблона здесь"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ не разрешает определять %<%T::%D%> как %<%T::%D%>"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "повторная инициализация %qD"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qD декларирована %<thread_local%> я %<constexpr%> функции"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<static%> in %<constexpr%> function"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qD декларирована %<static%> я %<constexpr%> функции"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "переменная %q#D инициализирована, хотя имеет неполный тип"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "элементы массива %q#D имеют неполный тип"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "агрегатный тип %q#D неполон и не может быть определён"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "переменная %qD декларирована как ссылка, но не инициализирована"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "имя использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "имя %qD использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривиально определенные инициализаторы не поддерживаются"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99 обозначение %qE не является целочисленным константным выражением"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "при инициализации не удалось определить размер %qD"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "не задан размер массива для %qD"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "массив %qD имеет нулевой размер"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "размер памяти %qD неизвестен"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "размер памяти %qD не константа"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: семантики inline переменной %q#D являются неверными (запутаетесь с несколькими копиями)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: семантики статических данных inline функции %q#D являются неверными (запутаетесь с несколькими копиями)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "это можно обойти, удалив инициализатор"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "неинициализированная константа %qD"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "неинициализированная переменная %qD в %<constexpr%> функции"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T не имеет предоставленный пользователем подразумеваемый конструктор"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "конструктор не является предоставленным пользователем, поскольку он явно подразумевался в теле класса"
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "и неявно определенный конструктор не инициализирует %q#D"
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "некорректный тип %qT является инициализатором для вектора типа %qT"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "инициализатор для %qT должен быт заключен в фигурные скобки"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> использовано в определенном в GNU-стиле инициализаторе для класса %qT"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT не имеет нестатического элемента данных с именем %qD"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "некорректный инициализатор для %q#D"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 обозначение %qE вне инициализатора агрегата"
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "избыточные элементы в инициализаторе для %qT"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора %qT"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type %qT"
 msgid "structured binding has incomplete type %qT"
 msgstr "поле %qD имеет неполный тип %qT"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "элементы массива %q#T имеют неполный тип"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "составной литерал переменного размера"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D имеет неполный тип"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "в инициализаторе скалярного объекта %qD должен быть только один элемент"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "в C++98 %qD следует инициализировать при помощи конструктора, а не %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "массив %qD инициализируется строковой константой %qE, заключённой в скобки"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "инициализатор недопустим для статического элемента с конструктором"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для статического элемента %qD"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для non-inline статического элемента %qD"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(запрошена инициализация вне класса)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "ссылка %qD инициализируется собой"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to constructor %q#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "слишком мало аргументов для конструктора %q#D"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "повторная декларация перечислимого типа %q+D"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "использован %<register%> спецификатор класса хранения"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "инициализатор для %<decltype(auto) %D%> имеет тип функции (вы забыли %<()%> ?)"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "переменная concept не имеет инициализатора"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "перекрытие предыдущей декларации %q#D"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "атрибут %qE применим только к переменным в статической памяти"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функция %q#D инициализирована как переменная"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "невозможна декомпозиция типа класса %qT, так как он содержит анонимный элемент структуры"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "невозможна декомпозиция типа класса %qT, так как он имеет анонимный элемент объединения"
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT: и он и его базовый класс %qT имеют нестатические элементы данных"
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT: его базовые классы %qT и %qT имеют нестатические элементы данных"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "невозможна декомпозиция массива переменной длины %qT"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -51005,7 +51047,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -51013,7 +51055,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -51021,1687 +51063,1698 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не является целочисленным константным выражением"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "невозможна декомпозиция типа объединения %qT"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "невозможна декомпозиция non-array non-class типа %qT"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "невозможна декомпозиция типа lambda замыкания %qT"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT без нестатических элементов данных"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "нелокальная переменная %qD декларированная %<__thread%> требует динамической инициализации"
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "нелокальная переменная %qD декларированная %<__thread%> имеет нетривиальный деструктор"
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> допускает динамическую инициализацию и уничтожение"
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "при инициализации не удалось определить размер %qT"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "не задан размер массива в %qT"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "нулевой размер массива %qT"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларирована как %<virtual%> переменная"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации переменной"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларирован как %<virtual%> параметр"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларирован как %<inline%> параметр"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации параметра"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларирован как %<virtual%> тип"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларирован как %<inline%> тип"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации типа"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларирован как %<virtual%> поле"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларирован как %<inline%> поле"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации поля"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларировано как friend"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларировано со спецификацией исключений"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "определение %qD вне пространства имён, объемлющего %qT"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статическая функция-член %q#D объявлена с квалификаторами типа"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "concept %q#D декларирован с параметрами функциями"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "concept %q#D декларирован с выведенным типом возврата"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "concept %q#D с non-%<bool%> типом возврата %qT"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "concept %qD не имеет определения"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "a function concept cannot be constrained"
 msgstr "функция не может быть инструментирована"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD не является функцией шаблоном"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "определение явной специализации %qD в friend-декларации"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "некорректное использование идентификатора шаблона %qD в декларации первичного шаблона"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "не допускается использовать %<inline%> в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "недопустимая декларация %<::main%> как шаблона"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "недопустимая декларация %<::main%> как inline-функции"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "недопустимая декларация %<::main%> как статической функции"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "недопустимая декларация %<::main%> как статической функции"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "не-элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь ref-квалификатор"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "non-member функция %qD не может иметь ref-квалификатор"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, fuzzy, gcc-internal-format
 #| msgid "deduction guide %qD must be declared at namespace scope"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "руководство вывода %qD не должно иметь тело функции"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "литеральный оператор с C-привязкой"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD имеет некорректный список аргументов"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "целый суффикс %qs перекрыт реализацией"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, fuzzy, gcc-internal-format
 #| msgid "floating point suffix %qs shadowed by implementation"
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "суффикс плавающей точки %qs перекрыт реализацией"
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "суффиксы литеральных операторов без предшествующего %<_%> зарезервированы для будущей стандартизации"
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD должен быть не-элемент-функцией"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> должна возвращать %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "определение неявно декларированного %qD"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "определение явно подразумеваемого %q+D"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D явно подразумевается здесь"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "нет элемента-функции %q#D в классе %qT"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "невозможно декларировать %<::main%> как глобальную переменную"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "non-template переменная не может быть %<concept%>"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+#| msgid "deduction guide %qD must be declared at namespace scope"
+msgid "concept must be defined at namespace scope"
+msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "concept должен иметь тип %<bool%>"
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "variable concept has no initializer"
 msgid "a variable concept cannot be constrained"
 msgstr "переменная concept не имеет инициализатора"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "инициализация внутри класса статического элемента данных %q#D неполного типа"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> требуется для инициализации внутри класса статического элемента данных %q#D нецелого типа"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "инициализация внутри класса статического элемента данных %q#D нелитерального типа"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ запрещает инициализацию внутри класса неконстантного статического элемента %qD"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ запрещает инициализацию элемента-константы %qD нецелочисленного типа %qT"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "размер массива %qD имеет нецелочисленный тип %qT"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "размер массива имеет нецелочисленный тип %qT"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ запрещает массив нулевого размера %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ запрещает массивы нулевого размера"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ запрещает массив переменного размера %qD"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ запрещает массивы переменного размера"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "используется массив переменного размера %qD"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "используется массив переменного размера"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "переполнение в размерности массива"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD декларировано как массив %qT"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "декларация %qD как массива void"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "создание массива void"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "декларация %qD как массива функций"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "создание массива функций"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "декларация %qD как массива ссылок"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "создание массива ссылок"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "декларация %qD как массива элементов-функций"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "создание массива элементов-функций"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларация многомерного массива %qD должна определять границы для всех размерностей, кроме первой"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "в многомерном массиве должны быть определены границы для всех размерностей, кроме первой"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в конструкторе"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "квалификаторы не допускаются в декларации конструктора"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в деструкторе"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "квалификаторы не допускаются в декларации деструктора"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "тип результата задан для %<operator %T%>"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "возвращаемый тип задан для руководства вывода"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "квалификаторы не допускаются в декларации руководства вывода"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier in declaration of deduction guide"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "decl-спецификатор в декларации руководства вывода"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "декларация безымянной переменной или поля с типом void"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "декларация переменной или поля с типом void"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> спецификатор некорректен для переменной %qD декларированной в контексте блока"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<::%D%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%T::%D%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%D::%D%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "декларация %qD как не-элемента"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "декларатор отсутствует; используется зарезервированное слово %qD"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "определение функции не объявляет параметры"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларация %qD как %<typedef%>"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "декларация %qD как параметра"
 
 #
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "нет специфицированных классов"
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%> не может встречаться в typedef декларации"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или более типа в декларации имени %qs"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "конфликтующие спецификаторы в декларации %qs"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ не поддерживает плоские %<complex%> означающие %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ запрещает декларации %qs без типа"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> не поддерживается этой целевой платформой"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не поддерживает %<__int%d%> для %qs"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> и %<unsigned%> одновременно заданы для %qs"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> и %<short%> одновременно заданы для %qs"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qT"
 msgstr "%qs использован с %qE"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs указан с %<decltype%>"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs указан с %<typeof%>"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "спецификатор complex для %qs недопустим"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "за типом заполнителя шаблона %qT должен следовать простой declarator-id"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "элемент %qD не может быть декларирован и как %<virtual%> и как %<static%>"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "элемент %qD не может быть декларирован и как %<virtual%> и как %<constexpr%>"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-декларация не допускается в декларации параметров"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "класс хранения задан для параметра шаблона %qs"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> вне декларации класса"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for structured binding declaration"
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "некорректный инициализатор для структурированной связывающей декларации"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "тип должен быть cv-qualified %<auto%> или ссылкой на cv-qualified %<auto%>"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "в декларации %qs задано более одного класса хранения"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "для %qs задан класс хранения"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "вложенная функция %qs объявлена %<extern%>"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "имя %qs описано на верхнем уровне с классом хранения %<auto%>"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "имя %qs на уровне функции неявно имеет класс auto и объявлено %<__thread%>"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "класс хранения не допускается в декларации friend-функции"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "атрибут проигнорирован"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "атрибут, относящийся к спецификатору типа, игнорируется"
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Ожидалась открывающая скобка"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-клаузула для типа возврата"
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs функция использует %<auto%> спецификатор типа без завершающего типа возврата"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "выведенный тип возврата доступен только с -std=c++14 или -std=gnu++14"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуальная функция не может иметь выведенный тип возврата"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "неверное употребление спецификатора %<restrict%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "руководство вывода для %qT должно иметь завершающий тип возврата"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "хвостовой тип возврата %qT руководства вывода не есть специализация %qT"
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "завершающий тип возврата доступен только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs функция с завершающим типом возврата не декларирована с %<auto%> спецификатором типа"
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified return type of %qD"
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<_Atomic%>-квалифицированный возвращаемый тип в %qD"
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs объявлена как функция, возвращающая массив"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "функция с атрибутом noreturn возвращает не-void значение"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT как тип а не плоский %<decltype(auto)%>"
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "деструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "конструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "конструкторы не могут быть декларированы %<virtual%>"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-декларация вне определения класса"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "невозможно определить friend-функцию %qs в определении локального класса"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "функция преобразования не может иметь завершающий тип возврата"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструкторы не могут иметь параметров"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "недопустимая декларация указателя на %q#T"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "недопустимая декларация указателя на элемент %q#T"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "невозможно декларировать ссылку на квалифицированный тип функции %qT"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Недопустимо определять ссылку на %q#T, которая не будет определением типа или аргументом шаблона"
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "идентификатор шаблона %qD использован как декларатор"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "элементы-функции неявно считаются friend-функциями своего класса"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "избыточная квалификация %<%T::%> элемента %qs"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "недопустимая декларация элемента %<%T::%s%> внутри %qT"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "элемент данных не может иметь тип %qT модифицируемого размера"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметр не может иметь модифицированный тип `%T"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> вне декларации класса"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> в friend декларации"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "только декларации конструкторов и операторов преобразования могут быть %<explicit%>"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не объектного элемента %qs как %<mutable%>"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация функции %qs как %<mutable%>"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация статического %qs как %<mutable%>"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация константного %qs как %<mutable%>"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "ссылка %qs не может быть декларирована %<mutable%>"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef декларирован %<auto%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-клаузула для typedef"
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef имя не может быть вложенным спецификатором имени"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ запрещает определять вложенный тип %qD с тем же именем, что и объемлющий класс"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "в декларации friend-класса использован квалификатор %<inline%>"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "в friend-декларации требуется указание класса: %<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "в friend-декларации требуется указание класса: %<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "попытка сделать класс %qT \"другом\" глобальной области видимости"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "некорректные квалификаторы для типа функции, не являющейся элементом"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-клаузула для идентификатора типа"
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "абстрактный декларатор %qT использован в качестве декларатора"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-клаузула в декларации нефункционального типа %qT"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "недопустимое использование %<::%> в декларации параметра"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "невозможно декларировать параметр с абстрактным типом %qT"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 #| msgid "%<auto%> parameter not permitted in this context"
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "%<auto%> параметр недопустим в данном контексте"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD не является шаблоном функции"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%> параметр недопустим в данном контексте"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "параметр декларирован %<auto%>"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "некорректное использование имени шаблона %qE без списка аргументов"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "нестатический элемент данных декларирован с заполнителем %qT"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ запрещает элемент регулируемый массив %qs"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ запрещает элементы регулируемые массивы"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "недопустимое использование %<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "декларация функции %qD в неверном контексте"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функция %qD декларирована %<virtual%> внутри объединения"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не может быть декларирована %<virtual%>, поскольку она всегда статическая"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для деструктора %qD"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для конструктора %qD"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "конструктор не может быть %<concept%>"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "concept не может быть элементом-функцией"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "ошибка открытия %s"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "специализация переменного шаблона %qD декларирована как функция"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "переменный шаблон декларирован здесь"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "поле %qD имеет неполный тип %qT"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "имя %qT имеет неполный тип"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 #| msgid "static data member %qE declared %<concept%>"
 msgid "static data member %qE declared %qs"
 msgstr "статический элемент данных %qE декларирован %<concept%>"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "некорректный класс хранения %<auto%> для функции %qs"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "некорректный класс хранения %<register%> для функции %qs"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "класс хранения %<thread_local%> недопустим для функции %qs"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-спецификаторы в %qs не допускаются вне определения класса"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> спецификатор некорректен для функции %qs декларированной вне глобального контекста"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "некорректно указано %<inline%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуальная функция %qs не является элементом класса"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs определен не в контексте класса"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs декларирован не в контексте класса"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "недопустимая декларация статического элемента-функции %qD"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "недопустимая декларация статической функции внутри другой функции"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "слово %<static%> недопустимо при определении (в отличие от объявления) статического элемента данных в классе"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статический элемент %qD объявлен как %<register%>"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "недопустимая явная extern-декларация элемента %q#D"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "декларация %q#D не имеет инициализатора"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qs с инициализацией"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "для %qs задан спецификатор %<extern%> и инициализатор"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "аргумент по умолчанию %qE использует %qD"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "аргумент по умолчанию %qE использует локальную переменную %qD"
 
 #
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "некорректное использование cv-квалифицированного типа %qT в декларации параметра"
 
 #
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "некорректное использование типа %<void%> в декларации параметра"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<_Atomic%>-квалифицированный параметр типа %qT для %q+D"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметр %qD включает указатель на массив с неизвестной границей %qT"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметр %qD включает ссылку на массив с неизвестной границей %qT"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "некорректный конструктор; возможно, вы имели в виду %<%T (const %T&)%>"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "декларация %qD может не действовать в пространстве имён"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD можно не определять статической"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD должен быть нестатической элементом-функцией"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD должен быть либо нестатическим элементом-функцией или функцией-не-элементом"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD должен иметь аргумент типа класс или перечислимого типа"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ не поддерживает перегрузку операции ?:"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не может иметь переменное число аргументов"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "преобразование к void никогда не использует операцию преобразования типа"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "преобразование к ссылке на тот же тип никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "преобразование к тому же типу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "преобразование к ссылке на базовый класс никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "преобразование к базовому классу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD должен возвращать результат по значению"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "использование параметра шаблона %qT после %qs"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "использование синонима специализации шаблона %qT после %qs"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "использование typedef-имени %qD после %qs"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD ранее декларирован здесь"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "ссылка на %qT как на %qs"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT ранее декларирован здесь"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "ссылка на %qT как на enum"
@@ -52713,107 +52766,107 @@ msgstr "ссылка на %qT как на enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "для %<%s %T%> нужен аргумент-шаблон"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD имеет то же имя, что и класс, в котором он(а) декларируется"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT не является шаблоном"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "возможно вы хотите явно добавить %<%T::%>"
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "использование перечисления %q#D без предыдущей декларации"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "повторная декларация %qT как не-шаблона"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "недопустимая декларация %qD как битового поля"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "некорректный производный тип union %qT"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT определен с многими непосредственными базами"
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT определен с непосредственной виртуальной базой"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "базовый тип %qT не является ни структурой, ни классом"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "рекурсивный тип %qT не определён"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "некорректное дублирование базового типа %qT"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "scoped/unscoped рассогласование в enum %q#T"
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "предыдущее определение здесь"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "рассогласование основного типа в enum %q#T"
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "отличающийся основной тип в enum %q#T"
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "специализация %qD в другой namespace-области"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -52822,78 +52875,78 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ни один целочисленный тип не годится для представления всех значений перечислимого типа %qT"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "значение перечислимого типа для %qD должно иметь целочисленный или unscoped перечислимый тип"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "значение перечислимого типа для %qD не является константой целого типа"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<unsigned long%>"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<long%>"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "переполнение в перечисляемых значениях для %qD"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> должен возвращать ссылку на %<*this%>"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "нет операторов возврата в функции возвращающей %qT"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "только плоский %<auto%> тип возврата может быть приведен к %<void%>"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD уже определена в классе %qT"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "использование %qD до приведения %<auto%>"
@@ -52933,7 +52986,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "удаление %qT не определено"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "шаблонная декларация %q#D"
@@ -52943,7 +52996,7 @@ msgstr "шаблонная декларация %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "предоставленные списки параметров шаблона не соответствуют параметрам шаблона %qD"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD объявлен как шаблон элемента"
@@ -53280,23 +53333,23 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "использование удаленной функции %qD"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %q#D with different constraints"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -53417,7 +53470,7 @@ msgstr "ссылка на %<%T::%D%> неоднозначна"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT не содержит элемент с именем %qE; имелось в виду %qE?"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD не является элементом %qT"
@@ -53428,7 +53481,7 @@ msgstr "%qD не является элементом %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT не содержит элемент с именем %qE; имелось в виду %qE?"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD не является элементом %qD"
@@ -53622,419 +53675,419 @@ msgstr "инициализация значения ссылочного тип
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "инициализатор для элемента регулируемого массива %q#D"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD следует инициализировать в списке инициализации элементов"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD инициализируется самим собой"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "некорректный инициализатор для элемента массива %q#D"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "неинициализированный const элемент в %q#T"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D должен быть инициализирован"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "неинициализированный ссылочный элемент в %q#T"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD будет инициализирован после"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "базовый класс %qT будет инициализирован после"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  базового класса %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  если инициализирован здесь"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "повторные инициализации заданы для %qD"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "повторные инициализации заданы для базового класса %qT"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "инициализации для нескольких элементов %qT"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "базовый класс %q#T должен быть явно инициализирован в копирующем конструкторе"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "в классе %qT нет поля с именем %qD"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D есть статический элемент данных; он может быть инициализирован только при своем определении"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D не есть нестатический элемент данных %qT"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "безымянный инициализатор для %qT, не имеющего базовых классов"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "безымянный инициализатор для %qT, имеющего множественное наследование"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD - непосредственный базовый тип, а также косвенный виртуальный базовый тип"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "тип %qT не является непосредственной или виртуальной базой %qT"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT не является непосредственной базой %qT"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "массив должен быть инициализирован инициализатором в фигурных скобках"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT не является классовым типом"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "неполный тип %qT не имеет элемента %qD"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "некорректный указатель на битовое поле %qD"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "некорректное использование нестатического элемента %qD"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный ссылочный элемент в %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный ссылочный элемент в базе %q#T от %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "неинициализированный ссылочный элемент в базе %q#T от %q#T"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный const элемент в %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный ссылочный элемент в базе %q#T от %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "неинициализированный const элемент в базе %q#T от %q#T"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "размещение new создает объект типа %<%T [%wu]%> и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, fuzzy, gcc-internal-format
 #| msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "размещение new создает объект типа %<%T [%wu]%> и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "размещение new создает массив объектов типа %qT и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, fuzzy, gcc-internal-format
 #| msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "размещение new создает массив объектов типа %qT и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "размещение new создает объект типа %qT и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, fuzzy, gcc-internal-format
 #| msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "размещение new создает объект типа %qT и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "at offset %wi from %qD declared here"
 msgstr "программа %qD декларирована здесь"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "программа %qD декларирована здесь"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "целочисленное переполнение в размере массива"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "размер массива в new-выражении должно быть константным"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "переменно модифицированный тип не допускается в new-выражении"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant array new length must be specified directly, not by typedef"
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "неконстантная длина массива new должна быть задана непосредственно, не с помощью typedef"
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "неконстантная длина new массива должна быть задана без скобок вокруг идентификатора типа"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "некорректный тип %<void%> задан для new"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "непроинициализированная константа в %<new%> от %q#T"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "не найдено подходящего %qD в классе %qT"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "запрос элемента %qD неоднозначен"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> типа %qT с расширенным выравниванием %d"
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "использует %qD, который не имеет параметра выравнивания"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "используйте %<-faligned-new%>, чтобы включить C++17 поддержку over-aligned new"
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "инициализатор со скобками в new массива"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new нельзя применять к ссылочному типу"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new нельзя применять к типу функции"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "в вызове оператора delete обнаружена возможная проблема:"
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни специфический для класса оператор delete [] не будут вызваны, даже если они декларированы в определении класса"
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "преждевременное завершение инициализатора"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "неизвестный размер массива в операторе delete"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "в вызове оператора delete обнаружена возможная проблема:"
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни специфический для класса оператор delete не будут вызваны, даже если они декларированы в определении класса"
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "удаление объекта абстрактного типа класса %qT, имеющего невиртуальный деструктор, вызовет неопределенное поведение"
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "удаление объекта полиморфного типа класса %qT, имеющего невиртуальный деструктор, может вызвать неопределенное поведение"
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr "массив с границей времени выполнения не может захватываться копированием, только по ссылке"
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "так как тип элементов массива %qT имеет переменный размер"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "невозможно захватить %qE по ссылке"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "захват копированием неполного типа %qT"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> не было захвачено для этой lambda функции"
@@ -54093,66 +54146,66 @@ msgstr "%qD не имеет аргументов, зависящих от пар
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(с ключом %<-fpermissive%>, G++ примет данный код, но разрешение использовать недекларированные имена будет отменено в дальнейших версиях)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, fuzzy, gcc-internal-format
 #| msgid "mangling typeof, use decltype instead"
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr "разборка typeof, используйте decltype взамен"
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "mangling __underlying_type"
 msgid "mangling %<__underlying_type%>"
 msgstr "разборка __underlying_type"
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "разборка неизвестного типа с фиксированной точкой"
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "использование встроенной особенности %qE в сигнатуре функции; используйте библиотечные особенности взамен"
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "разборка %C"
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "опущен средний операнд %<?:%> операнд не может быть разобран"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "скорректированное имя для %qD изменится в C++17, так как спецификация исключительных ситуаций есть часть типа функции"
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "скорректированное имя thunk для %qD изменяется между -fabi-version=%d и -fabi-version=%d"
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "скорректированное имя для %qD изменяется между -fabi-version=%d и -fabi-version=%d"
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
@@ -54349,227 +54402,227 @@ msgstr "%q#D неявно удален, поскольку подразумев
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F неявно удалено, так как его спецификация исключительных ситуаций не соответствует неявной спецификации исключительных ситуаций %qX"
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr ""
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "шаблон не может быть подразумеваемым"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD не может быть подразумеваемым"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "подразумеваемая функция %q+D с подразумеваемым аргументом"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+#D shadows template parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "декларация %q+#D перекрывает параметр шаблона"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D конфликтует с предыдущей декларацией"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr ""
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "из-за различных спецификаций исключений"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "декларация %q#D перекрывает параметр"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "декларация %qD перекрывает элемент %qT"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%q#D does not have external linkage"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D декларировано здесь"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> обозначает деструктор"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-декларация для не-элемента внутри класса"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE не класс, пространство имен или перечисление"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "non-member-template declaration of %qD"
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "non-member-template декларация %qD"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "using-декларация для не-элемента внутри класса"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "тип %qT не является непосредственной базой %qT"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "did you mean to use logical not (%<!%>)?"
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "имелось в виду использовать логическое отрицание (%<!%>)?"
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qE не был декларирован"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration of namespace %q+D"
 msgid "using-declaration may not name namespace %qD"
 msgstr "противоречивая декларация %q#D"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> обозначает конструктор в %qT"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларация %qD вне пространства имён, объемлющего %qD"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "явные квалификаторы в декларации %qD"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD следовало объявить внутри %qD"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD атрибут требует единственный NTBS аргумент"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD атрибут не имеет смысла, поскольку элементы анонимного пространства имен получают локальные символы"
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "игнорирование %qD атрибута в анонимном пространстве имен"
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "игнорирование %qD атрибута в non-inline пространстве имен"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибут %qD игнорируется"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "максимальное число %d пространств имен просмотрено для %qE"
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -54577,94 +54630,94 @@ msgstr[0] "предлагаемый вариант:"
 msgstr[1] "предлагаемые варианты:"
 msgstr[2] "предлагаемые варианты:"
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "определение %qD не соответствует %<#include <initializer_list>%>"
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fabi-version=1%> is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%<-fabi-version=1%> больше не поддерживается"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%qs в %L неоднозначно"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "использование пространства имён %qD здесь недопустимо; предполагается %qD"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr ""
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 #| msgid "%qD conflicts with used function"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD противоречит использованной функции"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "предыдущее определение здесь"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX вход в pop_everything ()\n"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -54692,7 +54745,7 @@ msgstr "идентификатор %qE является ключевым сло
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P не установлено в true"
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -54718,7 +54771,7 @@ msgstr "%<::%E%> не был декларирован"
 msgid "request for member %qE in non-class type %qT"
 msgstr "запрос элемента %qE в неклассовом типе %qT"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> не был декларирован"
@@ -54798,7 +54851,7 @@ msgstr "некорректный идентификатор шаблона"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ запрещает использование литералов с плавающей точкой в константном выражении"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "приведение к типу, отличному от целого или перечисления, не может появляться в константном выражении"
@@ -54942,7 +54995,7 @@ msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> доступно только с -fconcepts"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, fuzzy, gcc-internal-format
 #| msgid "%<requires%> only available with -fconcepts"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -55070,7 +55123,7 @@ msgstr "невозможно найти оператор строкового л
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "ожидалась декларация"
@@ -55121,7 +55174,7 @@ msgstr "операторы-выражения не допустимы вне ф
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "ожидалось primary-expression"
@@ -55152,7 +55205,7 @@ msgstr "область видимости %qT до %<~%> не является 
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "%<auto%> параметр недопустим в данном контексте"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
@@ -55174,12 +55227,12 @@ msgstr "декларация %<~%T%> как элемента %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-имя %qD использовано как декларатор деструктора"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ожидался unqualified-id"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD не является шаблоном"
@@ -55216,7 +55269,7 @@ msgstr "идентификатор переменного шаблона %qD в
 msgid "expected nested-name-specifier"
 msgstr "ожидался вложенный спецификатор имени"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "типы нельзя определять в приведении типов"
@@ -55231,7 +55284,7 @@ msgstr "типы нельзя определять в %<typeid%> выражен
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неверное число аргументов для %<__builtin_addressof%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неверное число аргументов для %<__builtin_launder%>"
@@ -55246,1185 +55299,1191 @@ msgstr "в ISO C++ составные литеральные конструкц
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "два последовательных %<[%> только введут атрибут"
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "некорректное использование %qD"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> не является элементом класса"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "нескалярный тип"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ не допускает %<alignof%> с не-типом"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "типы не могут быть определены в %<noexcept%> выражениях"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-expression"
 msgid "types may not be defined in %qs expressions"
 msgstr "типы не могут быть определены в new-выражении"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_thread_pointer is not supported on this target"
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr "__builtin_thread_pointer не поддерживается для этой платформы"
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "типы не могут быть определены в new-выражении"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "граница массива не допускается после идентификатора типа в скобках"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "попробуйте убрать скобки вокруг идентификатора типа"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "инициализация new-выражения для типа %<auto%> требует ровно один элемент"
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "ожидался список выражений или идентификатор типа"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "типы не могут быть определены в new-type-id"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "выражение в деклараторе new должно иметь целый или перечислимый тип"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "оператор %<>>%> трактуется в C++11 как две правые угловые скобки"
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "рекомендуется окружать скобками выражение %<>>%>"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ не допускает ?: с опущенным средним операндом"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+#| msgid "lambda-expression in template-argument"
+msgid "lambda-expression in template parameter type"
+msgstr "lambda-выражение в аргументе шаблона"
+
+#: cp/parser.c:10819
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, fuzzy, gcc-internal-format
 #| msgid "the lambda has no capture-default"
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "lambda не имеет подразумеваемого захвата"
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "ожидался конец capture-list"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "явное by-copy capture %<this%> избыточно с by-copy capture умолчанием"
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "уже захваченное %qD в lambda выражении"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 #| msgid "cannot capture %qE by reference"
 msgid "%<this%> cannot be captured by reference"
 msgstr "невозможно захватить %qE по ссылке"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambda-захватывающие инициализаторы доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "пустой инициализатор для lambda init-capture"
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "capture переменной  %qD с неавтоматическим сроком хранения"
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "слишком много %<if%> клаузул"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "явное by-copy capture %qD избыточно с by-copy capture умолчанием"
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "явное by-reference capture %qD избыточно с by-reference capture умолчанием"
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "задан аргумент по умолчанию для lambda-параметра"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "повторное %<mutable%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, fuzzy, gcc-internal-format
 #| msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "диапазонные %<for%> циклы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "завершающий тип возврата доступен только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "атрибуты в начале оператора игнорируются"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ожидался помеченный оператор"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-метка %qE вне оператора switch"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "требуется %<typename%> перед %qE, поскольку %qT зависимый контекст"
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> обозначает конструктор, а не тип"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, fuzzy, gcc-internal-format
 #| msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "наследуемые конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "ожидался selection-statement"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "функция возвращает массив"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "поле %qE описано как функция"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "типы нельзя определять в условиях"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "ожидался инициализатор"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "non-local variable %q#D uses local type %qT"
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "нелокальная переменная %q#D использует локальный тип %qT"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "range-based %<for%> выражение типа %qT имеет неполный тип"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "противоречивые begin/end типы в range-based %<for%> операторе: %qT и %qT"
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "ожидался iteration-statement"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "диапазонные %<for%> циклы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "диапазонные %<for%> циклы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> в %<constexpr%> функции"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ не поддерживает вычисляемые goto"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ожидался оператор перехода"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-name"
 msgid "expected module-name"
 msgstr "ожидалось template-name"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "method declaration not in @interface context"
 msgid "module-declaration not permitted in header-unit"
 msgstr "декларация метода вне контекста @interface"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 #| msgid "volatile argument"
 msgid "private module fragment"
 msgstr "volatile аргумент"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "import-declaration must be at global scope"
 msgstr "using-декларация для не-элемента внутри класса"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 #| msgid "invalid linkage-specification"
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "некорректная linkage-specification"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "%qE may only occur once in an export declaration"
 msgstr "типы нельзя определять в exception-declarations"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 #| msgid "%<auto%> parameter not permitted in this context"
 msgid "attributes are not permitted in this position"
 msgstr "%<auto%> параметр недопустим в данном контексте"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored"
 msgid "attributes may be inserted here"
 msgstr "атрибут проигнорирован"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "избыточная %<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> не в начале блока"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "непеременная %qD в декларации с более чем одним декларатором с типом заполнителем"
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "противоречивый вывод для %qT: %qT и затем %qT"
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "смешивание деклараций и определений функций запрещено"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "типы нельзя определять в декларации for-диапазона"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "инициализатор в диапазонном %<for%> цикле"
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "несколько деклараций в диапазонном %<for%> цикле"
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "некорректный инициализатор для структурированной связывающей декларации"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> использовано вне класса"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "Атрибут в %L не допускается в TYPE определении"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> меняет смысл в C++11; пожалуйста удалите его"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier invalid in condition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "decl-specifier некорректен в условии"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD некорректно в lambda"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier invalid in condition"
 msgid "type-specifier invalid in lambda"
 msgstr "decl-specifier некорректен в условии"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "определение класса не должно содержать friend"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in an exception-specification"
 msgid "types may not be defined in explicit-specifier"
 msgstr "типы нельзя определять в exception-specification"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "некорректная linkage-specification"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "типы нельзя определять в %<decltype%> выражениях"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "типы не могут быть определены в conversion-type-id"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "некорректное использование %<auto%> в операторе преобразования"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "использование %<auto%> в операторе преобразования элемента шаблона не может быть приведено"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "только конструкторы берут инициализаторы элементов"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer для %qD следует за constructor delegation"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "constructor delegation следует за mem-initializer для %qD"
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "устаревший стиль инициализатора базового класса"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (инициализатор квалифицированного элемента неявно является типом)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "неожиданное ключевое слово; удалите пробел между кавычками и суффикс идентификатором"
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ожидался суффикс-идентификатор"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "ожидалась пустая строка после ключевого слова %<operator%>"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "некорректный префикс кодировки в литеральном операторе"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "ожидался оператор"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "ключевое слово %<export%> не реализовано; игнорируется"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<export%> not implemented, and will be ignored"
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "ключевое слово %<export%> не реализовано; игнорируется"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, fuzzy, gcc-internal-format
 #| msgid "-mexr is used without -ms"
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr "-mexr использовано без -ms"
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "некорректный constrained type параметр"
 
 #
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-qualified type параметр"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "некорректное использование %<auto%> в подразумеваемом аргументе шаблона"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "pack параметр шаблона %qD не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "pack параметры шаблона не могут иметь аргументы по умолчанию"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "ожидался template-id"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "список аргументов шаблона не должен начинаться с %<<::%>"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(если вы используете %<-fpermissive%> или %<-std=c++11%> или %<-std=gnu++11%> G++ примет ваш код)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-type template argument"
 msgid "invalid template-argument-list"
 msgstr "некорректный нетиповый аргумент шаблона"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "ожидался template-argument"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "ошибка разбора в списке аргументов шаблона"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "ожидалось template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "не шаблон %qD использован как шаблон"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "используйте нотацию %<%T::template %D%> для указания о том, что это шаблон"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ожидался pack параметр перед %<...%>"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ожидался template-argument"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "некорректный нетиповый аргумент шаблона"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "явная конкретизация не должна использовать %<inline%> спецификатор"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "явная конкретизация не должна использовать %<constexpr%> спецификатор"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "явная конкретизация не должна использовать %<constexpr%> спецификатор"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специализация шаблона с привязкой C"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "ожидался спецификатор типа"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "использование %<auto%> в декларации lambda параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "использование %<auto%> в декларации параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "использование %<auto%> в декларации параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "ожидался template-id для типа"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "ожидалось имя типа"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE не является именем типа"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "concept defined here"
 msgstr "объединение определено здесь"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%> after %qE"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "ожидалась %<,%> или %<)%> перед %qE"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, fuzzy, gcc-internal-format
 #| msgid "placeholder constraints not satisfied"
 msgid "unexpected placeholder in constrained result type"
 msgstr "ограничения заполнителя не удовлетворены"
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 #| msgid "typedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "typedef имя не может быть вложенным спецификатором имени"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "декларация %qD ничего не декларирует"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибуты игнорируются для неконкретизированного типа"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибуты игнорируются для конкретизации шаблона"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибуты игнорируются для elaborated-type-specifier, который не является forward декларацией"
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD является шаблоном перечисления"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD не именует перечисление в %qT"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "неименованный scoped enum не допускается"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ожидалось %<;%> или %<{%>"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "невозможно добавить enumerator список к конкретизации шаблона"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "вложенный спецификатор имени %qT для enum декларации не именует класс или пространство имен"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларация %qD в пространстве имен %qD, которое не включает %qD"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларация %qD в %qD, который не объемлет %qD"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "избыточная квалификация не допускается"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ запрещает пустой неименованный enum"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier без имени"
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier должен использовать простой идентификатор"
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type; did you mean %qs?"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qE не является именем типа; имелось в виду %qs?"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD не есть namespace-name"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ожидалось namespace-name"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "определение вложенного пространства имен не может иметь атрибуты"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "определение вложенного пространства имен не может быть inline"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "вход в пространство имен %qD"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> определение здесь не допускается"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "использование %<auto%> в декларации параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "идентификатор шаблона недопустим в using-декларации"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "использование %<auto%> в декларации параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "декларациям доступа следует предпочесть using-declarations; предлагается: добавьте ключевое слово %<using%>"
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration here"
 msgid "opaque-enum-declaration here"
 msgstr "предыдущая декларация здесь"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "типы нельзя определять в алиасных декларациях шаблонов"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "повторный cv-qualifier"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT не является пространством имён"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter outside function body"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "использование параметра вне тела функции"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "в декларации функции указаны имена параметров без типов"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesized initializer in array new"
 msgid "remove parentheses to default-initialize a variable"
 msgstr "инициализатор со скобками в new массива"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "в декларации функции указаны имена параметров без типов"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD redeclared as variable"
 msgid "add parentheses to declare a variable"
 msgstr "функция %qD повторно декларирована как переменная"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition здесь не допускается"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "ожидался конструктор, деструктор или преобразование типа"
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "инициализатор задан для функции"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "атрибуты после инициализатора в скобках проигнорированы"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "не-функция %qD декларирована как неявный шаблон"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница массива не является целой константой"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "невозможно определить элемент зависимого typedef %qT"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не является типом"
@@ -56433,442 +56492,442 @@ msgstr "%<%T::%E%> не является типом"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "некорректная декларация"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "некорректное использование конструктора как шаблона"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "используйте %<%T::%D%> вместо %<%T::%D%> для именования конструктора в имени с квалификатором"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "квалифицированный идентификатор в декларации"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "ожидалась декларация"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD является пространством имён"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "невозможно сформировать указатель на элемент не класса %q#T"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ожидался ptr-operator"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "повторный cv-qualifier"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "несколько ref-квалификаторов"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "повторный virt-specifier"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "отсутствуют аргументы шаблона после %qT"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments"
 msgid "%qT not permitted in template argument"
 msgstr "отсутствуют аргументы шаблона"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "некорректное использование %qT"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "типы нельзя определять в аргументах шаблона"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "некорректное использование %<auto%> в аргументе шаблона"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ожидался type-specifier"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ожидалось %<,%> или %<...%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "типы нельзя определять в типах параметров"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "аргументы по умолчанию разрешены только для параметров функций"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameter pack %qD не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "pack параметр шаблона не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameter pack не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 #| msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "наследуемые конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ не поддерживает C99 назначенные инициализаторы"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "ожидалось class-name"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "ожидалось %<;%> после определения класса"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "ожидалось %<;%> после определения структуры"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "ожидалось %<;%> после определения объединения"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ожидалось %<{%> или %<:%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "невозможно задать %<override%> для класса"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "global квалификация имени класса некорректна"
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "квалифицированное имя не именует класс"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "некорректное имя класса в декларации %qD"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "перед явной специализацией должно быть %<template <>%>"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "шаблон функции %qD редекларирован как шаблон класса"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "невозможно разрешить typename type"
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "предыдущее определение %q#T"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "ожидалось class-key"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "ожидалось %<class%> или %<typename%>"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "в C++03 class-key должен использоваться при декларировании friend"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "класс хранения для анонимного агрегата в контексте класса недопустим"
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "битовое поле %qD не целочисленного типа"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "спецификатор pure в определении функции"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "случайная %<,%> в конце декларации элемента"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ожидалось %<;%> в конце декларации элемента"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "некорректный спецификатор pure (только %<= 0%> допускается)"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "инициализатор в фигурных скобках здесь не допускается"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> задано более одного раза в base-спецификаторе"
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "более одного спецификатора access в base-спецификаторе"
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "ключевое слово %<typename%> не допускается вне шаблонов"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (базовый класс неявно является типом)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "типы нельзя определять в exception-specification"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr ""
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "динамические спецификации исключительных ситуаций считаются устаревшими в C++11"
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "некорректное использование %<auto%> в спецификации исключительной ситуации"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "типы нельзя определять в exception-declarations"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "атрибутный using префикс использован вместе с scoped attribute token"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "ожидался идентификатор для имени атрибута"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, fuzzy, gcc-internal-format
 #| msgid "%<fallthrough%> attribute specified multiple times"
 msgid "attribute %qs specified multiple times"
 msgstr "%<fallthrough%> атрибут задан несколько раз"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "ожидался атрибут перед %<...%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, fuzzy, gcc-internal-format
 #| msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 атрибуты доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 #| msgid "expression must be integral"
 msgid "expression must be enclosed in parentheses"
 msgstr "выражение должно быть целочисленным"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "заданная позиция не является целой константой"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not an integer constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "запрошенное выравнивание не является целочисленной константой"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "специализация элемента %<%T::%E%> требует %<template<>%> синтаксис"
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "некорректная декларация %<%T::%E%>"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "недостаточно списков параметров шаблонов"
@@ -56877,632 +56936,632 @@ msgstr "недостаточно списков параметров шабло
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "слишком много списков параметров шаблонов"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именованные возвращаемые значения больше не поддерживаются"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "нет подходящего concept для template-introduction"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "некорректная декларация шаблона элемента в локальном классе"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон с привязкой C"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "некорректная явная специализация"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "шаблонная декларация %<typedef%>"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "декларация шаблона класса не должна декларирован ничего иного"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "явная специализация шаблона не может иметь класс хранения"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> должно быть %<> >%> внутри списка аргументов вложенного шаблона"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "ошибочное использование %<>>%>, используйте %<>%> для завершения списка аргументов шаблона"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "аргумент %<sizeof...%> должен быть окружен скобками"
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "некорректное использование %qD в спецификации привязки"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> перед %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 не поддерживает %<long long%>"
 
 #
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "заданы и %<__thread%> и %<thread_local%>"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "дублирование %qD"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублирование %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ожидалось %<new%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ожидалось %<delete%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ожидалось %<return%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ожидалось %<extern%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ожидалось %<static_assert%>"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ожидалось %<decltype%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ожидалось %<operator%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ожидалось %<class%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ожидалось %<template%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ожидалось %<namespace%>"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ожидалось %<using%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ожидалось %<asm%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ожидалось %<try%>"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ожидалось %<catch%>"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ожидалось %<throw%>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>"
 msgid "expected %<auto%>"
 msgstr "ожидалось %<data%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ожидалось %<__label__%>"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ожидалось %<@try%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ожидалось %<@synchronized%>"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ожидалось %<@throw%>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "ожидалось %<__transaction_atomic%>"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "ожидалось %<__transaction_relaxed%>"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "ожидалось %<@end%>"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ожидалось %<::%>"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ожидалось %<...%>"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ожидалось %<*%>"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ожидалось %<~%>"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ожидалось %<:%> или %<::%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag использован в именовании %q#T"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T был ранее декларирован здесь"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT объявлен с большей областью видимости, чем родитель %qT"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 #| msgid "expected class-key"
 msgid "replace the class-key with %qs"
 msgstr "ожидалось class-key"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "метка %qD определена здесь"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%qT декларировано здесь"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD редекларирован с другим доступом"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "в C++98 %<template%> (для снятия неоднозначности) допускается только внутри шаблонов"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "конец файла в аргументе по умолчанию"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "неверное положение %<@%D%> конструкции Objective-C++"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ получатель сообщения ожидался"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "ожидались objective-c++ аргумент(ы) сообщения"
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "в конструкции %<@encode%> в качестве аргумента должен быть задан тип"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "некорректное Objective-C++ имя селектора"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "ожидалась objective-c++ декларация метода"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "атрибуты метода должны задаваться в конце"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "случайное %qs между Objective-C++ методами"
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "некорректный тип для instance переменной"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "ожидался идентификатор после %<@protocol%>"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "атрибуты нельзя задавать до %<@%D%> Objective-C++ ключевого слова"
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "префиксные атрибуты игнорируются до %<@%D%>"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "некорректный тип для property"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown property attribute %qE"
 msgstr "неизвестный атрибут свойства"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "ожидалось целочисленное выражение"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%> выражение должно быть целочисленным"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "некорректный reduction-инициализатор"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in parameter types"
 msgid "types may not be defined in iterator type"
 msgstr "типы нельзя определять в типах параметров"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "скобочная инициализация не допускается в OpenMP %<for%> цикле"
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, fuzzy, gcc-internal-format
 #| msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "итерационная переменная %qD не должна быть reduction"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "недостаточно для сжатия циклов"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp end declare target%> без соответствующей %<#pragma omp declare target%>"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "некорректная клаузула инициализатора"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ожидалось id-выражение (аргументы)"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "один из аргументов вызова инициализатора должен быть %<omp_priv%> или %<&omp_priv%>"
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "типы не могут определяться в declare reduction списке типов"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "предекларированный арифметический тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "функциональный или массивный тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "тип ссылки %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, fuzzy, gcc-internal-format
 #| msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const, volatile или __restrict квалифицированный тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> именует множество перегрузок"
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD не ссылается на функцию в контексте пространства имен"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, fuzzy, gcc-internal-format
 #| msgid "atomic_cancel"
 msgid "%<atomic_cancel%>"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "внешний %<__transaction_cancel%> не внутри внешнего %<__transaction_atomic%>"
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  либо %<transaction_may_cancel_outer%> функция"
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC coprocessor"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "некорректный синтаксис #pragma GCC coprocessor"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> должна быть внутри функций"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "межмодульные оптимизации не реализованы для C++"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "стандартные преобразования в данном контексте недопустимы"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "неявные шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "элемент данных %qD не должен быть членом шаблона"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "некорректная декларация элемента-шаблона %qD"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "явная специализация в не-namespace области %qD"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "объемлющие шаблоны классов не были явно специализированы"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "специализация %qD должна появляться в пределах пространства имен"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "специализация %qD в другой namespace-области"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr ""
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "явная конкретизация %qD в пространстве имен %qD (которое не включает пространство имен %qD)"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "имя класса затеняет шаблон параметра шаблона %qD"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "специализация алиасного шаблона %qD"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "явная специализация не-шаблона %qT"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "специализация %qT после конкретизации"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#D"
 msgid "from definition of %q#D"
@@ -57510,147 +57569,147 @@ msgstr "переопределение %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "специализация %qT после конкретизации %qT"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "специализация шаблона %qD не допускается ISO C++"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "специализация %qD после конкретизации"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD не является шаблоном функции"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD не есть переменный шаблон"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "идентификатор шаблона %qD для %q+D не соответствует никакой декларации шаблона"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "разбор %d %<template<>%>, требуется %d для специализации шаблона элемента-функции"
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "неоднозначная конкретизация шаблона %qD для %q+D"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, fuzzy, gcc-internal-format
 #| msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "переменные шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "элементы явно специализированного класса определяются без заголовка шаблона"
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "явная специализация %qD вне своего пространства имен должна использовать nested-name-specifier"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "явная конкретизация %qD вне своего пространства имен должна использовать nested-name-specifier"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr ""
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr ""
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "template-id %qD в декларации первичного шаблона"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "список параметров шаблона использован в явной конкретизации"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "определение представленное для явной конкретизации"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "слишком много списков параметров шаблона в декларации %qD"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "слишком мало списков параметров шаблона в декларации %qD"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "перед явной специализацией %qD должно быть %<template <>%>"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "явная специализация декларированного %<concept%>"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "non-type partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "нетиповая частичная специализация %qD не допускается"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, fuzzy, gcc-internal-format
 #| msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "неклассовая, непеременная частичная специализация %qD не допускается"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "задан подразумеваемый аргумент в явной специализации"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD не является функцией шаблоном"
@@ -57663,147 +57722,147 @@ msgstr "%qD не является функцией шаблоном"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "специализация неявно декларированного специального элемента-функции"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "никакая элемент-функция %qD не декларирована в %qT"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend декларация %qD не видна для явной специализации"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "friend декларация здесь"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "явная специализация function concept %qD"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "Аргумент ACOS в %L должен быть между -1 и 1"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "non-parameter %qs cannot be a parameter pack"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "non-parameter %qs cannot be a parameter pack"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "packs параметров не расширены с %<...%>:"
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "декларация параметра шаблона %q+D перекрывает параметр шаблона"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "декларация %q+#D перекрывает параметр шаблона"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "параметр шаблона %qD декларирован здесь"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "специализация variable concept %q#D"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "параметры шаблона не выводимы в частичной специализации:"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "первичный шаблон здесь"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "частичная специализация не более специальна чем первичный шаблон, так как она замещает несколько параметров пакетным расширением"
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "слишком много аргументов в вызове функции %qE"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "частичная специализация %qD не более специальна чем"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "первичный шаблон %qD"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qE должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qT должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "аргумент шаблона %qE включает параметр(ы) шаблона"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -57811,17 +57870,17 @@ msgstr[0] "тип %qT аргумента шаблона %qE зависит от
 msgstr[1] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 msgstr[2] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "декларация %qD делает неоднозначной более раннюю конкретизацию шаблона для %qD"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "частичная специализация %qD после конкретизации %qD"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нет подразумеваемого аргумента для %qD"
@@ -57830,48 +57889,48 @@ msgstr "нет подразумеваемого аргумента для %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %q+D должен быть в конце списка параметров шаблона"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в редекларации friend шаблона функции"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в шаблонах функций без -std=c++11 или -std=gnu++11"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в частичных специализациях"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "шаблон %qD декларирован"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблон класса без имени"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "элемент-шаблон %qD не может иметь virt-спецификаторы"
@@ -57881,57 +57940,57 @@ msgstr "элемент-шаблон %qD не может иметь virt-спец
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "некорректная template-декларация %qD"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "определение шаблона для не-шаблона %q#D"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "ожидалось %d уровней параметров шаблона для %q#D, дано %d"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "дано %d параметров шаблона для %q#D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "дано %d параметров шаблона для %q#T"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  вместо требуемых %d"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "аргументы шаблона для %qD не соответствуют первоначальному шаблону %qD"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "используйте %<template<>%> для явной специализации"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT не является шаблонным типом"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "спецификаторы шаблона не заданы в декларации %qD"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -57939,7 +57998,7 @@ msgstr[0] "редекларировано с %d параметром шабло
 msgstr[1] "редекларировано с %d параметрами шаблона"
 msgstr[2] "редекларировано с %d параметрами шаблона"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -57947,134 +58006,134 @@ msgstr[0] "предыдущая декларация %qD использовал
 msgstr[1] "предыдущая декларация %qD использовала %d параметра шаблона"
 msgstr[2] "предыдущая декларация %qD использовала %d параметра шаблона"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "параметр шаблона %q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "редекларирован здесь как %q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %q#D with different constraints"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "исходная декларация находится здесь"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "редекларация аргумента по умолчанию для %q#D"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "исходное определение находится здесь"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%E не является корректным аргументом шаблона для типа %qT"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "это должно быть адресом функции с внешней привязкой"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "это должно быть именем функции с внешней привязкой"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%E не является корректным аргументом шаблона для типа %qT, поскольку %qD не имеет привязки"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%E не является корректным аргументом шаблона для типа %qT, поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "это должно быть указателем на элемент вида %<&X::Y%>"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  невозможно вывести параметр шаблона %qD"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  типы %qT и %qT имеют несовместимые cv-qualifiers"
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  несоответствие типов %qT и %qT"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  параметр шаблона %qD не есть parameter pack, но аргумент %qD таковым является"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  аргумент шаблона %qE не соответствует указателю на элемент константе %qE"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE не эквивалентно %qE"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  противоречивый вывод parameter pack с %qT и %qT"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  выведены конфликтующие типы для параметра %qT (%qT и %qT)"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  выведены конфликтующие значения для нетипового параметра %qE (%qE и %qE)"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  тип элемента-функции %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -58082,305 +58141,305 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  невозможно преобразовать %qE (типа %qT) к типу %qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT является неоднозначным базовым классом %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT не является производным от %qT"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  параметры шаблона для шаблона аргумента шаблона несовместимы с другими выведенными аргументами шаблона"
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "  can't deduce a template for %qT from non-template type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  невозможно вывести шаблон для %qT из нешаблонного типа %qT"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qE не переменная"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qD не имеет привязки"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "адрес %qD не есть корректный аргумент шаблона"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "адрес %qT подобъекта %qD не есть корректный аргумент шаблона"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "адрес %qD не есть корректный аргумент шаблона, так как он не имеет статический срок хранения"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD не есть корректный аргумент шаблона, поскольку %qD переменная, а не адрес переменной"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE не есть корректный аргумент шаблона для %qT, поскольку не является адресом переменной"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку строковые литералы не могут быть использованы в этом контексте"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "  аргумент шаблона %qE не соответствует указателю на элемент константе %qE"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT из-за конфликтов в cv-qualification"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он не есть lvalue"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D не есть корректный аргумент шаблона для типа %qT, поскольку ссылочная переменная не имеет постоянного адреса"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он является указателем"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "попробуйте задать %qE"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он имеет тип %qT"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "игнорирование атрибутов аргумента шаблона %qE"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD использовано как шаблон аргумента шаблона"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "некорректное использование деструктора %qE в качестве типа"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "для того чтобы сослаться на тип параметра шаблона, используйте конструкцию %<typename %E%>"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  ожидалась константа типа %qT, а обнаружено %qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  ожидался шаблон класса, а обнаружено %qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  ожидался тип, обнаружено %qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  ожидался тип, обнаружено %qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  ожидался шаблон класса, обнаружено %qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ожидался шаблон типа %qD, обнаружено %qT"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствие ограничений в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "ошибка при преобразовании аргумента шаблона %qE из %qT в %qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "некорректный аргумент шаблона %d"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть по крайней мере %d)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "предоставлено для %qD"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack expansion аргумент для non-pack параметра %qD алиасного шаблона %qD"
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "pack expansion аргумент для non-pack параметра %qD concept %qD"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "так что любая конкретизация с непустым пакетом параметров была бы синтаксически некорректной"
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D не является шаблоном функции"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "не-шаблонный тип %qT использован как шаблон"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "для декларации шаблона %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 #| msgid "template constraint failure"
 msgid "template constraint failure for %qD"
 msgstr "нарушение ограничения шаблона"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "использование некорректного переменного шаблона %qE"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "свертка пустого расширения над %O"
 
 #
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a potential constant expression"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE не есть потенциальное константное выражение"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "создание указателя на элемент-функцию не классового типа %qT"
@@ -58398,296 +58457,296 @@ msgstr "создание указателя на элемент-функцию 
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "переменная %qD имеет тип функции"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "некорректный тип параметра %qT"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "в декларации %q+D"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функция возвращает массив"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функция возвращает функцию"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "создание ссылки на void"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "формирование указателя на ссылочный тип %qT"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "формирование ссылки на ссылочный тип %qT"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "формирование указателя на квалифицированный тип функции %qT"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "формирование ссылки на квалифицированный тип функции %qT"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "создание указателя на элемент типа void"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT не является типом class, struct или union"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT разрешается в %qT, который не является перечислимым типом"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT разрешается в %qT, который не является классовым типом"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "использование %qs в шаблоне"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависимое имя %qE разбирается как не тип, но конкретизация дает тип"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "задайте %<typename %E%>, если подразумевается тип"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "использование некорректного поля %qD"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "некорректное использование pack expansion expression"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "используйте %<...%> для расширения argument pack"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "пустой инициализатор в lambda init-capture"
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD не декларирован в этом контексте, и не было найдено деклараций при зависимом от аргументов поиске в точке конкретизации"
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "декларации в зависимой базе %qT не найдены при неквалифицированном поиске"
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "используйте %<this->%D%>"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "используйте %<%T::%D%>"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD декларировано здесь, позднее в единице трансляции"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "неверное число аргументов в вызове %<__builtin_choose_expr%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не является классом или пространством имён"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT есть/использует неименованный тип"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "аргумент шаблона для %qD использует локальный тип %qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT есть переменно модифицированный тип"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  при конкретизации %qD"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "неоднозначная конкретизация шаблона для %q#T"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "неоднозначная конкретизация шаблона класса для %q#D"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "явная конкретизация нешаблона %q#D"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of variable concept %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "специализация variable concept %q#D"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of function concept %qD"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "явная специализация function concept %qD"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD не является статическим элементом данных шаблона класса"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "тип %qT для явной конкретизации %qD не соответствует декларированному типу %qT"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "явная конкретизация %q#D"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "повторная явная конкретизация %q#D"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 запрещает использование %<extern%> в явной конкретизации"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "явная конкретизация неклассового шаблона %qD"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "явная конкретизация типа %qT, не являющегося шаблоном"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "явная конкретизация %q#T до определения шаблона"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ запрещает использование %qE в явных конкретизациях"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "повторная явная конкретизация %q#T"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -58699,163 +58758,163 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "явная конкретизация %qD без определения"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d при конкретизации %q+D, возможно при генерации виртуальной таблицы (задайте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template non-type parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некорректный нетиповый параметр шаблона"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "a concept cannot be constrained"
 msgstr "concept не может быть элементом-функцией"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace or unscoped enum"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT не является пространством имен или unscoped enum"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "неклассовый шаблон %qT использован без аргументов шаблона"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "невозможно вывести аргументы шаблона для инициализации копированием %qT, поскольку он имеет неявное руководство вывода или декларированные пользователем конструкторы"
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "вывод аргумента шаблона класса потерпел неудачу:"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "явные руководства вывода не рассматриваются для copy-инициализации"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "explicit deduction guide declared here"
 msgstr "в вызове функции %qD определенной здесь"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, fuzzy, gcc-internal-format
 #| msgid "class template argument deduction failed:"
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "вывод аргумента шаблона класса потерпел неудачу:"
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization %<auto%> требует ровно один элемент"
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "для вывода к %<std::initializer_list%> используйте copy-list-initialization (то есть добавьте %<=%> перед %<{%>)"
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "не удается вывести возвращаемый тип lambda из %qE"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "невозможно вывести %qT из %qE"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "ограничения заполнителя не удовлетворены"
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "выведенный инициализатор не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "выведенный тип возврата не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "выведенный тип выражения не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr ""
@@ -58997,549 +59056,549 @@ msgstr "декларация %q+#D недопустима,"
 msgid "  since %q+#D declared in base class"
 msgstr "  поскольку %q+#D объявлена в базовом классе"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared %<constexpr%>"
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%qD не была декларирована %<constexpr%>"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "используйте явные фигурные скобки вокруг пустого тела цикла %<do%>"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr ""
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 #| msgid "type of asm operand %qE could not be determined"
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "невозможно определить тип операнда %qE для оператора asm"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "__label__ declarations are only allowed in function scopes"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "__label__ декларации допускаются только в контекстах функций"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "некорректное использование элемента %qD в статическом элементе-функции"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments"
 msgid "%qE missing template arguments"
 msgstr "отсутствуют аргументы шаблона"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "аргументы к деструктору не допускаются"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "имя %<this%> недоступно для статических элементов-функций"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "некорректное использование %<this%> в функции, не являющейся элементом"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "некорректное использование %<this%> на внешнем уровне"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "некорректный квалифицированный контекст в имени псевдодеструктора"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE не имеет тип %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "составной литерал необъектного типа %qT"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "параметры шаблона, являющиеся типами, должны задаваться при помощи ключевых слов %<class%> или %<typename%>"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "некорректное использование типа %qT как подразумеваемого значения для шаблона параметра шаблона"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "некорректный подразумеваемый аргумент для шаблона параметра шаблона"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "определение %q#T внутри списка параметров шаблона"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "некорректное определение квалифицированного типа %qT"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "некорректная спецификация базового класса"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "невозможно захватить элемент %qD анонимного объединения"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD не захватывается"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "lambda не имеет подразумеваемого захвата"
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "lambda в локальном классе %q+T не может захватывать переменные из объемлющего контекста"
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "использование локальной переменной с автоматическим хранением из объемлющей функции"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "использование параметра из внутренней функции"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "использование параметра вне тела функции"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "отсутствуют аргументы шаблона"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "параметр шаблона %qD типа %qT не допускается в целочисленном константном выражении, поскольку он не целого или перечислимого типа"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "использование шаблона класса %qT в качестве выражения"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "запрос элемента %qD неоднозначен в сетке множественного наследования"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD не может появляться в константном выражении"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип %qE неизвестен"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT не имеет перечислимый тип"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter pack __bases only valid in template declaration"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "Parameter pack __bases допустим только в декларации шаблона"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "невозможно применить %<offsetof%> к деструктору %<~%T%>"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "невозможно применить %<offsetof%> к элементу-функции %qD"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> допускается в OpenMP только в %<declare simd%> клаузулах"
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "определенный пользователем reduction поиск неоднозначен"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE в %<reduction%> клаузуле есть массив нулевого размера"
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE имеет const тип для %<reduction%>"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "определенная пользователем редукция в конструкторским инициализатором для базового класса %qT"
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "linear клаузула с %qs модификатором применена к нессылочной переменной с %qT типом"
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "linear клаузула применена к нецелой, неуказательной переменной с %qT типом"
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "выражение линейного шага должно быть целочисленным"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<firstprivate%>"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<lastprivate%>"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "%<gang%> статическое выражение должно быть целочисленным"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<gang%> статическое значение должно быть положительным"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "%<gang%> числовое выражение должно быть целочисленным"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "%<vector%> выражение длины должно быть целочисленным"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "%<worker%> числовое выражение должно быть целочисленным"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%> числовое значение должно быть положительным"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<vector%> значение длины должно быть положительным"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%> числовое значение должно быть положительным"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk size выражение должно быть целочисленным"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "%qs выражение длины должно быть целочисленным"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%> идентификатор должен быть целочисленным"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "%<dist_schedule%> выражение размера чанка должно быть целочисленным"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD не есть переменная в %<aligned%> клаузуле"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE в %<aligned%> клаузуле не указатель, не массив и не ссылка на указатель или массив"
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD появляется более одного раза в %<aligned%> клаузулах"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "%<aligned%> клаузула выражения выравнивания должна быть целочисленной"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<depend%> clause"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD не есть переменная в %<depend%> клаузуле"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in %<aligned%> clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD появляется более одного раза в %<aligned%> клаузулах"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE не является переменной в предложении %<aligned%>"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<aligned%> clause"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD не есть переменная в %<aligned%> клаузуле"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in %<aligned%> clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD появляется более одного раза в %<aligned%> клаузулах"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<depend%> clause"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD не есть переменная в %<depend%> клаузуле"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "шаблон %qE в клаузуле %qs"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "перегрузка имени функции %qE в клаузуле %qs"
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<grainsize%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "%<priority%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "%<wait%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 #| msgid "%qs length expression must be positive constant integer expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "%qs переменная не является ни указателем, ни массивом, ни ссылкой на указатель или массив"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "%qs переменная не является ни указателем, ни массивом, ни ссылкой на указатель или массив"
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tile%> аргумент требует целочисленный тип"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD не есть переменная файла, пространства имен или контекста блока"
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE директива не в %qT определении"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "разность между %qE и %qD не имеет целый тип"
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> использована с итерационной переменной класса %qE"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> использует два различных выражения для памяти"
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "неудача static assertion: %s"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, fuzzy, gcc-internal-format
 #| msgid "self-comparison always evaluates to false"
 msgid "%qE evaluates to false"
 msgstr "самосравнение всегда дает false"
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "неконстантное условие для static assertion"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "аргумент decltype должен быть выражением"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 #| msgid "decltype cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "decltype не может разрешить адрес перегруженной функции"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "операнд выражения свертки не имеет нерасширенных пакетов параметров"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "оба аргумента в бинарной свертке имеют нерасширенные пакеты параметров"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "нет нерасширенных пакетов параметров в бинарной свертке"
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "неуказательный аргумент для %<__builtin_launder%>"
@@ -59547,22 +59606,22 @@ msgstr "неуказательный аргумент для %<__builtin_launder
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -59572,1088 +59631,1089 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "квалификаторы %qV не могут быть применены к %qT"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, gcc-internal-format
 msgid " declared here"
 msgstr " объявлено здесь"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "выравнивание %qD увеличено в -fabi-version=9 (GCC 5.2)"
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "базовый класс %qT имеет квалификаторы cv"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not captured"
 msgid "%qD is not public"
 msgstr "%qD не захватывается"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD не переменная"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD has a non-structural type"
 msgstr "%qD не является типом"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "аргумент атрибута %qE не строковая константа"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE атрибут может применяться только к функциям или к классовым или перечислимым типам"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to Java class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "%qE атрибут может применяться только к определениям Java классов"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to Java class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%qE атрибут может применяться только к определениям Java классов"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 #| msgid "the %qE attribute requires arguments"
 msgid "%qE attribute takes no arguments"
 msgstr "%qE атрибуту требуются аргументы"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute doesn't apply to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qE атрибут не применим к функциям"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "заданный init_priority не является целой константой"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "%qE атрибут может использоваться только для определений объектов типа class на уровне файла"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "заданный init_priority вне диапазона"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "заданный init_priority зарезервировано для внутреннего использования"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE атрибут не поддерживается на данной платформе"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr ""
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE атрибуту требуются аргументы"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргументы для %qE атрибута должны быть узкими строковыми литералами"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргументы для %qE атрибута должны содержать корректные идентификаторы"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> не является корректным символом для идентификатора"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> не является корректным символом в идентификаторе"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE применен к неклассовому, неперечислимому типу %qT"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "атрибут %qE применен к %qT после его определения"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "игнорирование %qE атрибута, примененного к конкретизации шаблона %qT"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "игнорирование %qE атрибута, примененного к специализации шаблона %qT"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "атрибут %qE применен к нефункции, непеременной %qD"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "атрибут %qE применен к extern \"C\" декларации %qD"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "ноль как константа пустой указатель"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* check: ошибка в %s, в %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "сравнение между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "преобразование между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "условное выражение между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ запрещает сравнение между указателем типа %<void *%> и указателем не функцию"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ запрещает преобразование между указателем типа %<void *%> и указателем не функцию"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ запрещает условное выражение между указателем типа %<void *%> и указателем не функцию"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "сравнение между различными pointer-to-member типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "преобразование между различными pointer-to-member типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "условное выражение между различными pointer-to-member типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "некорректное применение %qs к элементу-функции"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "недопустимое применение %<sizeof%> к битовому полю"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ запрещает применение %<sizeof%> к выражению функционального типа"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "недопустимое применение %<__alignof%> к битовому полю"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ запрещает применение %<__alignof%> к выражению функционального типа"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "%<alignas%> аргумент имеет нецелочисленный тип %qT"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "некорректное использование нестатической функции-элемента типа %qT"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "взятие адреса от временного массива"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ запрещает преобразование строковой константы в %qT"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "устаревшее преобразование из строковой константы в %qT"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "запрос на элемент %qD в %qE, который имеет указательный тип %qT (возможно вы хотели использовать %<->%> ?)"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "запрос элемента %qD в %qE, имеющего не классовый тип %qT"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "некорректное использование нестатического элемента данных %qE"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "недопустимый доступ к нестатическому элементу данных в %qD в виртуальной базе NULL объекта"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "объектный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "разрушаемый тип %qT, а деструктор относится к %qT"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "поле %q#D доступно через %q#D"
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T не содержит элемента с именем %qE"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> не является элементом %qT"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD не является шаблонным элементом-функцией"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT не является типом указателя на объект"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "некорректное использование индексирования массива к указателю на элемент"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "некорректное использование унарной %<*%> к указателю на элемент"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "некорректное использование неявного преобразования к указателю на элемент"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "левый операнд %<->*%> должен быть указателем на класс, но является указателем на элемент типа %qT"
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "отсутствует индекс массива"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексируемый массив объявлен как %<register%>"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексируемый объект не является ни массивом, ни указателем"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "не задан объект при использовании %qE"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ запрещает использование %<::main%> из программы"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "необходимо использовать %<.*%> или %<->*%> для вызова pointer-to-member функции в %<%E (...)%>, например %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD нельзя использовать как функцию"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "выражение нельзя использовать как функцию"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "слишком много аргументов для конструктора %q#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "слишком мало аргументов для конструктора %q#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "слишком много аргументов для элемента-функции %q#D"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "слишком мало аргументов для элемента-функции %q#D"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "слишком много аргументов для функции %q#D"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "слишком мало аргументов для функции %q#D"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "слишком много аргументов для метода %q#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "слишком мало аргументов для метода %q#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "для функции задано слишком много аргументов"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "слишком мало аргументов функции"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметр %P %qD имеет неполный тип %qT"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметр %P имеет неполный тип %qT"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адрес %qD никогда не будет NULL"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "компилятор может предположить, что адрес %qD не может быть NULL"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "преобразование между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "сравнение между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "преобразование из указательного типа %qT в арифметический тип %qT в константном выражении"
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "предполагается приведение к типу %qT из перегруженной функции"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL в арифметическом выражении"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ не поддерживает сравнение между указателем и целым"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "типы операндов %qT и %qT"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "упорядоченное сравнение указателя с целочисленным нулем"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "аргумент неупорядоченного сравнения - не плавающее значение"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "некорректные операнды типов %qT и %qT для бинарной операции %qO"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя %<void *%> в вычитании"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на функцию в вычитании"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на метод в вычитании"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "некорректное использование указателя на неполный тип в вычислениях с указателями"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "некорректное использование %qE для образования указателя на элемент-функцию"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  qualified-id требуется"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "нельзя использовать скобки вокруг %qE для образования указателя на элемент-функцию"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "адрес от временной переменной"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ не поддерживает взятие адреса от функции %<::main%>"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "нельзя создать указатель на элемент-ссылку %qD"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "попытка взять адрес битового поля"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to member function %q#D"
 msgid "taking address of an immediate function %qD"
 msgstr "слишком много аргументов для элемента-функции %q#D"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, fuzzy, gcc-internal-format
 #| msgid "%<~%> on an expression of type bool"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> от выражения типа bool"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "имелось в виду использовать логическое отрицание (%<!%>)?"
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ запрещает инкрементирование enum"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ запрещает декрементирование enum"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "невозможно инкрементировать указатель на неполный тип %qT"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "невозможно декрементировать указатель на неполный тип %qT"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ запрещает инкрементирование указателя типа %qT"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ запрещает декрементирование указателя типа %qT"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "использование операнда типа %qT в %<operator--%> запрещено"
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "использование операнда типа %qT в %<operator++%> устарело"
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "нельзя взять адрес от %<this%>, поскольку это rvalue-выражение"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "запрошен адрес явной регистровой переменной %qD"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "запрошен адрес для %qD, которая декларирована как %<register%>"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "list-initializer для неклассового типа не должен быть заключен в скобки"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "список выражений рассматривается как составное выражение в инициализаторе"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "список выражений рассматривается как составное выражение в mem-initializer"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "список выражений рассматривается как составное выражение в функциональном приведении типов"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s - список выражений рассматривается как составное выражение"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "нет контекста для разрешения типа %qE"
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "приведение от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
 #
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "некорректное применение static_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "тип класса %qT неполный"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "приведение указателя на функцию к указателю на объект условно поддерживается"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "некорректное приведение из типа %qT к типу %qT"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "некорректное применение const_cast с типом %qT, не являющимся ни указателем, ни ссылкой, ни  указателем на элемент данных"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "некорректное применение const_cast с типом %qT, являющимся указателем или ссылкой на функцию"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "некорректное применение const_cast от rvalue-выражения типа %qT к типу %qT"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "некорректное применение const_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ не поддерживает приведение к типу массива %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "некорректное приведение к типу функции %qT"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  в вычислении %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "присваивание массиву из списка инициализатора"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несовместимые типы в присваивании %qT -> %qT"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "массив использован как инициализатор"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "некорректное присваивание массива"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   в преобразовании указателя на элемент-функцию"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "преобразование указателя к элементу через виртуальную базу %qT"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   в преобразовании указателя на элемент"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "параметр %qP %qD мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "параметр мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "цель преобразования могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "цель инициализации могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "левая часть присваивания могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "при передаче аргумента %P от %qD"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "возврат ссылки на временную переменную"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "возвращена ссылка на локальную переменную %qD"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "возвращен адрес метки %qD"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "возвращен адрес локальной переменной %qD"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
 #
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "not enough values in return statement"
 msgid "redundant move in return statement"
 msgstr "недостаточно значений в операторе возврата"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "возвращен результат деструктора"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "возврат в обработчике try-блока конструктора"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "возврат результата конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return без значения в функции, возвращающей %qT"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "возврат списка инициализатора"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "противоречивые типы %qT и %qT выведены для возвращаемого типа lambda"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "противоречивый вывод для auto return type: %qT и затем %qT"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> не должен возвращать NULL, если только он не декларирован %<throw()%> (или задан ключ -fcheck-new)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 #| msgid "using temporary as lvalue"
 msgid "using rvalue as lvalue"
@@ -60928,109 +60988,103 @@ msgstr "фигурные скобки вокруг скалярного иниц
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "невозможно инициализировать агрегат типа %qT составным литералом"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "элемент %qD - неинициализированная ссылка"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "элемент %qD с неинициализированными ссылочными полями"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поле %qD не найдено в инициализируемом объединении"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "значение индекса вместо имени поля в инициализаторе объединения"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "обнаружено циклическое делегирование указателей"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "базовый операнд %<->%> имеет неуказательный тип %qT"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "результат %<operator->()%> не является указателем"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "базовый операнд %<->%> не является указателем"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE не может использоваться как элемент, поскольку имеет тип %qT"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "невозможно применить элементный указатель %qE к %qE, который имеет неклассовый тип %qT"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "указатель на элементный тип %qT несовместим с объектным типом %qT"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "тип указатель на элемент-функцию %qT требует rvalue"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "тип указатель на элемент-функцию %qT требует lvalue"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member-function type %qT requires an lvalue"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "тип указатель на элемент-функцию %qT требует lvalue"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "функциональное приведение к массивному типу %qT"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-#| msgid "cannot deduce template arguments for %qT from ()"
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "невозможно вывести аргументы шаблона для %qT из ()"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "некорректная инициализация значения ссылочного типа"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "вызов функции %qD, которая вызывает исключение неполного типа %q#T"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "вызов функции, которая вызывает исключение неполного типа %q#T"
@@ -61050,296 +61104,302 @@ msgstr "не удается открыть файл протокола %<vtv_set
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr "не удается открыть файл протокола %<vtv_count_data.log%>: %m"
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 #| msgid "External %qs at %L cannot have an initializer"
 msgid "extern symbols cannot have initializers"
 msgstr "Внешняя %qs в %L не может иметь инициализатор"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, fuzzy, gcc-internal-format
 #| msgid "asm not allowed in %<transaction_safe%> function"
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "asm не допускается в %<transaction_safe%> функции"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable cannot be volatile"
 msgid "variables cannot be of type void"
 msgstr "итерационная переменная %qE должна быть private"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "cannot be declared to be a function"
 msgstr "new нельзя применять к типу функции"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of %<struct %E%>"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "повторное определение %<struct %E%>"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be %s"
 msgstr "ошибка открытия %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be `scope` and `%s`"
 msgstr "ошибка открытия %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "Use the Cygwin interface"
 msgid "field not allowed in interface"
 msgstr "Использовать интерфейс Cygwin"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "variable-size type declared outside of any function"
 msgid "inout variables can only be declared inside inout functions"
 msgstr "тип переменного размера декларирован вне функции"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "reference to dead statement"
 msgid "reference to scope class must be scope"
 msgstr "ссылка на мертвый оператор"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 #| msgid "only zero initializers are allowed in section %qs"
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "только нулевые инициализаторы допускаются в секции %qs"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take member initializers"
 msgid "manifest constants must have initializers"
 msgstr "только конструкторы берут инициализаторы элементов"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "braced spec body %qs is invalid"
 msgid "size of type %s is invalid"
 msgstr "ошибка в спецификации %qs в скобках"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C++ does not allow C99 designated initializers"
 msgid "%s does not have a default initializer"
 msgstr "ISO C++ не поддерживает C99 назначенные инициализаторы"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 #| msgid "External %qs at %L cannot have an initializer"
 msgid "is not a static and cannot have static initializer"
 msgstr "Внешняя %qs в %L не может иметь инициализатор"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "static storage variables cannot have destructors"
 msgstr "Java-класс %qT не может иметь деструктор"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "string expected for library name"
 msgstr "ожидалось имя класса"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 #| msgid "expected function name"
 msgid "string expected for mangled name"
 msgstr "ожидалось имя функции"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "отсутствуют аргументы"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on primary template declaration."
 msgid "can only apply to a single declaration"
 msgstr "Предупреждать о первичной декларации шаблона."
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
 #
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "repeated using declaration %q+D"
 msgid "incomplete mixin declaration (%s)"
 msgstr "повторное использование декларации %q+D"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, fuzzy, gcc-internal-format
 #| msgid "Selector at %L must not be coindexed"
 msgid "base type must not be void"
 msgstr "Селектор в %L не должен быть коиндексирован"
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgid "enum %s must have at least one member"
 msgstr "Процедура %qs с PASS в %L должна иметь по крайней мере один аргумент"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "circular reference to enum member"
 msgstr "возврат ссылки на временную переменную"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgid "template tuple parameter must be last one"
 msgstr "параметры шаблона, являющиеся типами, должны задаваться при помощи ключевых слов %<class%> или %<typename%>"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "рекурсивная inline-подстановка"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "рекурсивная inline-подстановка"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "error instantiating"
 msgstr "ошибка записи %qs"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs must be the first clause of %qs"
 msgid "%s must be a function instead of %s"
 msgstr "%qs должна быть первой клаузулой %qs"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "functions cannot be scope"
@@ -61348,46 +61408,56 @@ msgstr "функция не может быть инструментирован
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
 #
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s method can't be abstract"
 msgid "%s functions cannot be abstract"
 msgstr "%s метод не может быть абстрактным"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about overloaded virtual function names."
 msgid "cannot override a non-virtual function"
 msgstr "Предупреждать о перегруженных именах виртуальных функций."
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify both -C and -o"
 msgid "cannot be both final and abstract"
 msgstr "не допускается задание одновременно -C и -o"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -61395,193 +61465,193 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overriding final function %q+D"
 msgid "cannot override final function %s"
 msgstr "перебивание финальной функции %q+D"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "multiple save reg attributes to function %qD"
 msgid "multiple overrides of same function"
 msgstr "несколько save reg атрибутов для функции %qD"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+D has incompatible attributes %qs and %qs"
 msgid "incompatible covariant types %s and %s"
 msgstr "%q+D имеет несовместимые атрибуты %qs и %qs"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not refer to a function"
 msgid "does not override any function"
 msgstr "%qD не ссылается на функцию"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overriding final function %q+D"
 msgid "cannot override final function %s.%s"
 msgstr "перебивание финальной функции %q+D"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "naked attribute only applies to functions"
 msgid "override only applies to class member functions"
 msgstr "naked атрибут применим только к функциям"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn about overloaded virtual function names."
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "Предупреждать о перегруженных именах виртуальных функций."
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "first argument must be []byte"
 msgid "first argument must be type size_t, not %s"
 msgstr "первый аргумент должен быть []byte"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "one argument of type void* expected, not %s"
 msgstr "аргумент типа %qT не соответствует типу %qT"
 
 #
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "%s method can't be abstract"
 msgid "structs, unions cannot be abstract"
 msgstr "%s метод не может быть абстрактным"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Repeat spec must be an integer at %C"
 msgid "base type must be class or interface, not %s"
 msgstr "Repeat spec должна быть integer в %C"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on direct virtual inheritance."
 msgid "circular inheritance"
 msgstr "Предупреждать о прямом виртуальном наследовании."
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Repeat spec must be an integer at %C"
 msgid "base type must be interface, not %s"
 msgstr "Repeat spec должна быть integer в %C"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "повторное задание каталога \"%s\" проигнорировано\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot inherit from final class %s"
 msgstr "нет файла для класса %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type transparent class %qT has virtual functions"
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "в типе прозрачного класса %qT есть виртуальные функции"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template %qD"
 msgid "mixin templates are not regular templates"
 msgstr "параметры шаблона не соответствуют шаблону %qD"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "идентификатор шаблона %qD для %q+D не соответствует никакой декларации шаблона"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot read %s"
 msgid "cannot resolve"
 msgstr "Ошибка чтения %s"
 
 #
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rank mismatch in expression %qE"
 msgid "cannot alias an expression %s"
@@ -61597,22 +61667,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "Alias has non-alias reference"
 msgid "has forward references"
@@ -61681,23 +61751,22 @@ msgstr "инициализатор недопустим для статичес
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "результат функции не может иметь тип функции"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "destructor priorities are not supported"
 msgid "naked assembly functions with contracts are not supported"
@@ -62244,7 +62313,7 @@ msgstr "Список имен %qs не может быть аргументом
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "%<I%> в %L и %<J%> в %L не могут обе быть BOZ литеральными константами"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid exponent-letter %<q%> in real-literal-constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -63354,12 +63423,12 @@ msgstr "Неиспользуемая инициализационная цепо
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Начальный индекс подстроки в %L меньше единицы"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Конечный индекс подстроки в %L превышает длину строки"
@@ -63542,7 +63611,7 @@ msgstr "Некорректная INTENT спецификация в %C"
 msgid "deferred type parameter at %C"
 msgstr "отложенный параметр типа в %C"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Скалярное INTEGER выражение ожидалось в %L"
@@ -66076,7 +66145,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Некорректный идентификатор в copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -66162,7 +66231,7 @@ msgstr "Переменная %qs в %L установлена в неопред
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Переменная %qs в %L не определяется внутри цикла, начинающегося в %L, как INTENT(OUT) аргумент для функции %qs"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Код для переразмещения размещаемого массива в %L будет добавлен"
@@ -66299,12 +66368,12 @@ msgstr "Первый аргумент определенного присваи
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Второй аргумент определенного присваивания в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Первый аргумент интерфейса оператора в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Второй аргумент интерфейса оператора в %L должен быть INTENT(IN)"
@@ -66417,549 +66486,549 @@ msgstr "Несоответствие рангов в аргументе %qs в %
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Несоответствие рангов в аргументе %qs в %L (ранг-%d и ранг-%d)"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Некорректный аргумент процедуры в %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Несоответствие интерфейса в формальной процедуре %qs в %L: %s"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Фактический аргумент для непрерывного указательного формального параметра %qs в %L должен быть просто непрерывным"
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "INTENT(%s) фактические аргументы в %L могут противоречить фактическим аргументам в %L."
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Несоответствие типа в аргументе %qs в %L; передано %s в %s"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Фактический аргумент предполагаемого типа в %L требует, чтобы формальный аргумент %qs был предполагаемого типа"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Фактический аргумент для %qs в %L должен быть полиморфным"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Фактический аргумент для %qs в %L должен иметь тот же декларированный тип"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Фактический аргумент для %qs в %L должен быть неограниченно полиморфным, так как формальный аргумент есть указатель или размещаемая неограниченно полиморфная сущность [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Фактический аргумент для %qs в %L должен быть комассивом"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Несоответствие корангов в аргументе %qs в %L (%d и %d)"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "Фактический аргумент для %qs в %L должен быть просто непрерывным или элементом такого массива"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Фактический аргумент для не-INTENT(INOUT) формального параметра %qs в %L, который есть LOCK_TYPE или имеет LOCK_TYPE компонент"
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Фактический аргумент для не-INTENT(INOUT) формального параметра %qs в %L, который есть EVENT_TYPE или имеет EVENT_TYPE компонент"
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Формальный аргумент %qs должен быть указателем или массивом предполагаемой формы или ранга без CONTIGUOUS атрибута - поскольку фактический аргумент в %L не является просто непрерывным и оба являются ASYNCHRONOUS или VOLATILE"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Передача комассива в %L в allocatable, noncoarray, INTENT(OUT) формальный аргумент %qs"
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Передача комассива в %L в allocatable, noncoarray формальный аргумент %qs, что некорректно, если статус размещения модифицирован"
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Полиморфный скаляр передан в формальный аргумент массив %qs в %L"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Элемент массива предполагаемой формы или указательного передан в формальный аргумент массив %qs в %L"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Элемент массива предполагаемой формы или указательного передан в формальный аргумент массив %qs в %L"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Расширение: Скалярный неподразумеваемого вида, не-C_CHAR-вида CHARACTER фактический аргумент с формальным аргументом массивом %qs в %L"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Скалярный CHARACTER фактический аргумент с формальным аргументом массивом %qs в %L"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Аргумент с ключевым словом %qs в %L не в процедуре"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Аргумент с ключевым словом %qs в %L уже ассоциирован с другим фактическим аргументом"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Больше фактических чем формальных аргументов в вызове процедуры в %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Отсутствует спецификация альтернативного возврата в вызове подпрограммы в %L"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Неожиданная спецификация альтернативного возврата в вызове подпрограммы в %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Неожиданная NULL() встроенная функция в %L для формального параметра %qs"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Пустой указатель в %L в неуказательный формальный параметр %qs"
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "Фактический аргумент в %L для формального параметра предполагаемого типа имеет производный тип с type-bound или FINAL процедурами"
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и указательным или размещаемым формальным аргументом %qs в %L"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и формальным аргументом предполагаемой формы %qs в %L"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Фактический аргумент в %L в размещаемый или указательный формальный аргумент %qs должен иметь типовый параметр отложенной длины тогда и только тогда, когда таковой имеется у формального"
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Character длина фактического аргумента короче чем у формального аргумента %qs (%lu/%lu) в %L"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Фактический аргумент содержит слишком мало элементов для формального аргумента %qs (%lu/%lu) в %L"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Ожидался указатель на процедуру для аргумента %qs в %L"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Ожидалась процедура для аргумента %qs в %L"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Фактический аргумент для %qs не может быть массивом предполагаемого размера в %L"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Фактический аргумент для %qs должен быть указателем в %L"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Неуказательный фактический аргумент в %L в указательный формальный параметр %qs"
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Коиндексированный фактический аргумент в %L в указательный формальный параметр %qs"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Коиндексированный фактический аргумент в %L в размещаемый формальный параметр %qs требует INTENT(IN)"
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Коиндексированный ASYNCHRONOUS или VOLATILE фактический аргумент в %L требует, чтобы формальный параметр %qs не имел ни ASYNCHRONOUS ни VOLATILE"
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Коиндексированный фактический аргумент в %L с размещаемым окончательным компонентом для формального параметра %qs требует либо VALUE либо INTENT(IN)"
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Фактический аргумент CLASS массив для %qs должен быть полным массивом в %L"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Фактический аргумент для %qs должен быть ALLOCATABLE в %L"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Фактический аргумент секция массива с векторными индексами в %L несовместим с INTENT(OUT), INTENT(INOUT), VOLATILE или ASYNCHRONOUS атрибутом формального аргумента %qs"
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Фактический аргумент предполагаемой формы в %L несовместим с non-assumed-shape формальным аргументом %qs из-за VOLATILE атрибута"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Фактический аргумент секция массива в %L несовместим с non-assumed-shape формальным аргументом %qs из-за VOLATILE атрибута"
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Фактический аргумент pointer-array в %L требует assumed-shape или pointer-array формальный аргумент %qs из-за VOLATILE атрибута"
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Отсутствует спецификация альтернативного возврата в вызове подпрограммы в %L"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Отсутствует фактический аргумент для аргумента %qs в %L"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Некорректный код компонента"
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Несоответствие списка"
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): поврежденные данные"
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Один и тот же фактический аргумент ассоциирован с INTENT(%s) аргументом %qs и INTENT(%s) аргументом %qs в %L"
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Несоответствие списка"
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Аргумент процедуры в %L локален в PURE процедуре и имеет POINTER атрибут"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Коиндексированный фактический аргумент в %L в процедуре PURE передан в аргумент INTENT(%s)"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Коиндексированный фактический аргумент в %L в PURE процедуре передан в POINTER формальный аргумент"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Коиндексированный полиморфный фактический аргумент в %L передан в полиморфный формальный аргумент %qs"
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Процедура %qs вызванная в %L не декларирована явно"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Процедура %qs вызвана с неявным интерфейсом в %L"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Указательный объект %qs в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Размещаемый объект %qs в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Размещаемая функция %qs в %L должна иметь явный функциональный интерфейс"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Explicit interface required for component %qs at %L: %s"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Явный интерфейс требуются для компонента %qs в %L: %s"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Аргумент с ключевым словом требует явный интерфейс для процедуры %qs в %L"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Аргумент предполагаемого типа %s в %L требует явный интерфейс"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Фактический аргумент LOCK_TYPE или с LOCK_TYPE компонентом в %L требует явный интерфейс для процедуры %qs"
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Фактический аргумент EVENT_TYPE или с EVENT_TYPE компонентом в %L требует явный интерфейс для процедуры %qs"
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD аргумент в NULL требуется в %L"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Аргумент предполагаемого ранга требует явный интерфейс в %L"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Компонент указатель на процедуру %qs вызван с неявным интерфейсом в %L"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Аргумент с ключевым словом требует явный интерфейс для компонента указателя на процедуру %qs в %L"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= требуется в NULL() аргументе в %L: Неоднозначность между конкретными функциями %s и %s"
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Не удается найти символ %qs"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Сущность %qs в %L уже присутствует в интерфейсе"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Некорректный тип интерфейса"
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC %qs at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Не удалось перебить GENERIC %qs в %L"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs в %L перебивает связывание процедуры декларированной NON_OVERRIDABLE"
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs в %L не должно быть DEFERRED, поскольку это перебивает не-DEFERRED связывание"
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs в %L перебивает PURE процедуру и должна также быть PURE"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs в %L перебивает ELEMENTAL процедуру и должна также быть ELEMENTAL"
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs в %L перебивает не-ELEMENTAL процедуру и не должна быть ELEMENTAL, также"
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs в %L перебивает SUBROUTINE и должна также быть SUBROUTINE"
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs в %L перебивает FUNCTION и должна также быть FUNCTION"
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Несоответствие результатов для перебивающей процедуры %qs в %L: %s"
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs в %L перебивает PUBLIC процедуру и не должна быть PRIVATE"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Формальный аргумент %qs от %qs в %L должен именоваться %qs, чтобы подходить соответствующему аргументу перебиваемой процедуры"
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Несоответствие аргументов для перебивающей процедуры %qs в %L: %s"
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs в %L должен иметь то же число формальных аргументов, что и перебиваемая процедура"
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs в %L перебивает NOPASS связывание и должен также быть NOPASS"
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs в %L перебивает связывание с PASS и должен также быть PASS"
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Passed-object формальный аргумент от %qs в %L должен быть на той же позиции, что и passed-object формальный аргумент перебиваемой процедуры"
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "DTIO формальный аргумент в %L должен быть типа %s"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "DTIO формальный аргумент в %L должен быть KIND = %d"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "DTIO формальный аргумент в %L должен быть скаляром"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "DTIO формальный аргумент в %L должен быть ASSUMED SHAPE ARRAY"
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "DTIO формальный аргумент в %L должен иметь INTENT %s"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Альтернативный возврат в %L не допускается в DTIO процедуре"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "DTIO процедура %qs в %L должна быть подпрограммой"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Слишком мало формальных аргументов в DTIO процедуре %qs в %L"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Слишком много формальных аргументов в DTIO процедуре %qs в %L"
@@ -67112,34 +67181,34 @@ msgstr "трансформационная встроенная функция %
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Элементная функция как инициализационное выражение с non-integer/non-character аргументами в %L"
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Вызов подпрограммы во встроенную функцию %qs в DO CONCURRENT блоке в %L не есть PURE"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Вызов подпрограммы во встроенную функцию %qs в %L не есть PURE"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Расширение: Преобразование из %s в %s в %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Преобразование из %s в %s в %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Возможное изменение значения в преобразовании из %s в %s в %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Преобразование из %s в %s в %L"
@@ -67147,24 +67216,24 @@ msgstr "Преобразование из %s в %s в %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "Не удалось преобразовать %s в %s в %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %qs to %qs at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Не удалось преобразовать %qs в %qs в %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -67737,7 +67806,7 @@ msgstr "NAMELIST %qs в READ операторе в %L содержит симв
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST объект %qs в списке имен %qs в %L является полиморфным и требует определенную процедуру ввода/вывода"
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST объект %qs в списке имен %qs в %L с ALLOCATABLE или POINTER компонентами"
@@ -68946,12 +69015,12 @@ msgstr "match_level_4(): Некорректный оператор"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr "gfc_basic_typename(): Неопределенный тип"
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "gfc_typename(): Неопределенный тип"
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "gfc_code2string(): Некорректный код"
@@ -69108,153 +69177,153 @@ msgstr "Встроенный оператор %qs, на который ссыл
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): некорректный символ модуля %qs"
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Символ не записан"
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file %qs for writing at %C: %s"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "Не удалось открыть файл модуля %qs для записи в %C: %s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Ошибка записи файла модуля %qs для записи: %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file %qs: %s"
 msgid "Cannot delete module file %qs: %s"
 msgstr "Не удалось удалить файл модуля %qs: %s"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file %qs to %qs: %s"
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Не удалось переименовать файл модуля %qs в %qs: %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file %qs: %s"
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "Не удалось удалить временный файл модуля %qs: %s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Символ %qs в %C уже декларирован"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): невозможно создать символ для %s"
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Символ %qs, на который ссылаются в %L, не содержится в выбранном стандарте"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Символ %qs, на который ссылаются в %L не найден во встроенном модуле ISO_C_BINDING"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Символ %qs уже декларирован"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Использование встроенного модуля %qs в %C конфликтует с именем невстроенного модуля использованного ранее"
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Использование NUMERIC_STORAGE_SIZE именованной константы из встроенного модуля ISO_FORTRAN_ENV в %L несовместимо с опцией %qs"
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Использование NUMERIC_STORAGE_SIZE именованной константы из встроенного модуля ISO_FORTRAN_ENV в %C несовместимо с опцией %s"
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Символ %qs, на который ссылаются в %L не найден во встроенном модуле ISO_FORTRAN_ENV"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "USE оператор в %C не имеет ONLY квалификатора"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "ISO_FORTRAN_ENV встроенный модуль в %C"
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "ISO_C_BINDING модуль в %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named %qs at %C"
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "Не удалось найти встроенный модуль названный %qs в %C"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "IEEE_FEATURES модуль в %C"
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "IEEE_EXCEPTIONS модуль в %C"
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "IEEE_ARITHMETIC модуль в %C"
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file %qs for reading at %C: %s"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Ошибка открытия файла модуля %qs на чтение в %C: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Файл модуля %qs не сгенерирован, так как модуль или не содержит MODULE PROCEDURE или в модуле есть ошибки."
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Использование невстроенного модуля %qs в %C конфликтует с именем встроенного модуля использованного ранее"
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Файл %qs открытый в %C не есть файл GNU Fortran модуля"
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Не читается файл модуля %qs открытый в %C, так как от был создан другой версией GNU Fortran"
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -69811,8 +69880,8 @@ msgstr "Неявно декларированная подпрограмма %s
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "параметр ORDERED клаузулы меньше чем COLLAPSE в %L"
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF клаузула в %L требует скалярное LOGICAL выражение"
@@ -71888,7 +71957,7 @@ msgstr "Встроенная %qs декларированная INTRINSIC в %L
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Не-RECURSIVE процедура %qs в %L возможно вызывает себя рекурсивно.  Объявите её RECURSIVE или используйте %<-frecursive%>"
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Метка %d используемая в %L нигде не определяется"
@@ -72005,7 +72074,7 @@ msgstr "Не удается разрешить конкретную функци
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функция %qs в %L не имеет IMPLICIT тип. Может имелось в виду %qs?"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Функция %qs в %L не имеет IMPLICIT тип"
@@ -72166,216 +72235,216 @@ msgstr "CHARACTER(*) функция %qs в %L не может иметь зна
 msgid "Impure function at %L might not be evaluated"
 msgstr "always_inline функция, возможно, не годится для подстановки"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "Аргумент по значению в %L не может быть массивом или секцией массива"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "Некорректный вид для %s в %L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Некорректный вид для %s в %L"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Некорректная встроенная функция"
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Некорректное выражение"
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в коизмерении %d"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в коизмерении %d"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Некорректный нулевой шаг в %L"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Нижняя ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Нижняя ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Верхняя ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Верхняя ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Некорректная ссылка на массив"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Самая правая верхняя граница секции массива предполагаемой формы не задана в %L"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Несоответствие рангов в ссылке на массив в %L (%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Несоответствие коиндексных рангов в ссылке на массив в %L (%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Коиндекс коразмерности %d должен быть скаляром в %L"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Индекс массива в %L должен быть скаляром"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Индекс массива в %L должен быть INTEGER типа, найдено %s"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL индекс массива в %L"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Аргумент dim в %L должен быть скаляром"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Аргумент dim в %L должен быть INTEGER типа"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Отсутствует спецификация"
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): неиспользуемый as(1)"
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): неиспользуемый as(2)"
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Индекс массива в %L является массивом ранга %d"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Начальный индекс подстроки в %L должен быть типа INTEGER"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Начальный индекс подстроки в %L должен быть скаляром"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Конечный индекс подстроки в %L должен быть типа INTEGER"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Конечный индекс подстроки в %L должен быть скаляром"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Конечный индекс подстроки в %L слишком велик"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Некорректная ссылка на массив"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Компонент справа от частичной ссылки с ненулевым рангом не должен иметь POINTER атрибут в %L"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Компонент справа от частичной ссылки с ненулевым рангом не должен иметь ALLOCATABLE атрибут в %L"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Две или больше частичные ссылки с ненулевым рангом не должны быть заданы в %L"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, fuzzy, gcc-internal-format
 #| msgid "expression_rank(): Two array specs"
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "expression_rank(): Две спецификации массива"
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом может использоваться только как фактический аргумент"
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Переменная предполагаемого типа %s в %L может использоваться только как фактический аргумент"
@@ -72384,12 +72453,12 @@ msgstr "Переменная предполагаемого типа %s в %L м
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Переменная предполагаемого типа %s в %L как фактический аргумент для inquiry функции должна быть первым аргументом"
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Переменная предполагаемого ранга %s в %L может использоваться только как фактический аргумент"
@@ -72398,295 +72467,295 @@ msgstr "Переменная предполагаемого ранга %s в %L
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Переменная предполагаемого ранга %s в %L как фактический аргумент для inquiry функции должна быть первым аргументом"
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Переменная предполагаемого типа %s в %L не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Переменная предполагаемого ранга %s в %L не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Переменная %qs, использованная в спецификационном выражении, фигурирует в %L до ENTRY оператора, в котором она является параметром"
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Переменная %qs используется в %L до оператора ENTRY, в котором она является параметром"
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Полиморфный подобъект коиндексированного объекта в %L"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Коиндексированный объект с полиморфным размещаемым подкомпонентом в %L"
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "%qs matching variant is deprecated."
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qs соответствующий вариант устарел."
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Ошибка в спецификации типа в %L"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Передаваемый объект в %L должен быть скаляром"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова компонента указателя на процедуру в %L имеет ABSTRACT тип %qs'"
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова type-bound процедуры в %L имеет ABSTRACT тип %qs"
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Базовый объект для вызова NOPASS type-bound процедуры в %L должен быть скаляром"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Не найдено подходящего конкретного связывания для вызова GENERIC %qs в %L"
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs в %L должна быть SUBROUTINE"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Некорректный тип выражения"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "'%s' в %L должна быть скаляром"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s в %L должен быть integer"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s в %L должна быть INTEGER"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Шаговое выражение в DO цикле в %L не может быть нулевым"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO цикл в %L будет выполнен ноль раз"
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO цикл в %L является неопределенным, так как он переполняется"
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO цикл в %L является неопределенным, так как он теряет значимость"
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL индекс-имя в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL стартовое выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL конечное выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL шаговое выражение в %L должно быть скаляром %s"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL шаговое выражение в %L не может быть нулевым"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL индекс %qs не может появляться в спецификации триплета в %L"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object в %L должен быть ALLOCATABLE или POINTER"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Коиндексированный размещаемый объект в %L"
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr в %L должно быть скалярным или иметь тот же ранг, что и allocate-object в %L"
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr в %L и allocate-object в %L должны иметь одинаковую форму"
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Тип сущности в %L есть тип несовместимый с source-expr в %L"
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allocate-object в %L и source-expr в %L должны иметь одинаковый вид параметра типа"
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа LOCK_TYPE и не должно иметь LOCK_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа EVENT_TYPE и не должно иметь EVENT_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Размещение %s ABSTRACT базового типа в %L требует type-spec или source-expr"
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Размещение %s в %L с type-spec требует того же character-length параметра, что и в декларации"
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Спецификация массива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Спецификация массива или SOURCE= выражение со значением массивом требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Спецификация комассива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация массива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs не должно появляться в спецификации массива в %L в том же ALLOCATE операторе где оно само размещается"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Ожидалась '*' в спецификации коиндекса в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация комассива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable в %L не должна быть %sd в том же %s операторе"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG в %L бесполезно без STAT тега"
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG переменная в %L должна быть стандартной скалярной CHARACTER переменной"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Переменная Errmsg в %L не должна быть %sd в том же операторе %s"
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object в %L также появляется в %L"
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object в %L есть подобъект объекта в %L"
@@ -72695,287 +72764,287 @@ msgstr "Allocate-object в %L есть подобъект объекта в %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE метка в %L перекрывается с CASE меткой в %L"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Выражение в CASE операторе в %L должно быть типа %s"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Выражение в CASE операторе в %L должно быть вида %d"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Выражение в CASE операторе в %L должно быть скаляром"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Выражение выбора в вычисляемом GOTO операторе в %L должно быть скалярным integer выражением"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент SELECT оператора в %L не может быть %s"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент SELECT оператора в %L не может быть скалярным выражением"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Выражение в CASE операторе в %L не находится в диапазоне %s"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "За DEFAULT CASE в %L не может следовать второй DEFAULT CASE в %L"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логический диапазон в CASE операторе в %L не допускается"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Константное логическое значение в CASE операторе повторяется в %L"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Спецификации диапазона в %L невозможно найти соответствие"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Логический SELECT CASE блок в %L имеет более двух случаев"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Встроенная функция %qs в %L некорректна в присваивании указателя на процедуру"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type %qs cannot be used as a variable at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Производный тип %qs не может быть использован как переменная в %C"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name %qs at %L is used as array"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Имя ассоциации %qs в %L используется как массив"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Селектор в %L не может быть NULL()"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Селектор в %L не имеет типа"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Имя ассоциации %qs в %L используется как массив"
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS селектор в %L требует временной переменной, которая пока не реализована"
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Селектор должен быть полиморфным в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Селектор в %L не должен быть коиндексирован"
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS в %L перекрывается с TYPE IS в %L"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Производный тип %qs в %L должен быть расширяемым"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Производный тип %qs в %L должен быть расширением %qs"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неожиданный встроенный тип %qs в %L"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Спецификация типа в %L должна специфицировать, что каждый параметр длины типа является предполагаемым"
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Двойной CLASS IS блок в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Некорректный контекст для NULL () встроенной в %L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s процедура в %L должна быть рекурсивной"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может быть полиморфным, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь POINTER компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Элемент передачи данных в %L не может иметь компоненты указатели на процедуру"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь ALLOCATABLE компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Элемент передачи данных в %L не может быть полной ссылкой на массив предполагаемого размера"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock переменная в %L должна быть скаляром типа LOCK_TYPE"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Event переменная в %L должна быть скаляром типа EVENT_TYPE"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент event переменная в %L должен быть комассивом или коиндексированным"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент event переменная в %L должен быть комассивом, но не коиндексированным"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG= аргумент в %L должна быть скалярной CHARACTER переменной"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK= аргумент в %L должна быть скалярной LOGICAL переменной"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT= аргумент в %L должен быть скалярным INTEGER выражением"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset аргумент в %L должен быть скалярным или ранга 1 INTEGER выражением"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset аргумент в %L должен быть между 1 и num_images()"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Оператор в %L не есть корректный оператор цели перехода для оператора перехода в %L"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Переход в %L может вызвать зацикливание"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO оператор в %L покидает CRITICAL конструкцию для метки в %L"
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO оператор в %L покидает DO CONCURRENT конструкцию для метки в %L"
@@ -72983,195 +73052,195 @@ msgstr "GOTO оператор в %L покидает DO CONCURRENT констр
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Метка в %L не находится в том же блоке, что GOTO оператор в %L"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE маска в %L имеет противоречивую форму"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE цель присваивания в %L имеет противоречивую форму"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL определенное пользователем присваивание в WHERE в %L"
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподдерживаемый оператор внутри WHERE в %L"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Присваивание FORALL индексной переменной в %L"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL с индексом %qs не используется в левой части присваивания в %L и поэтому может вызвать множественное присваивание этому объекту"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "BLOCK конструкция в %C"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL имя индекса в %L должно быть скалярной переменной типа integer"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Внешняя FORALL конструкция уже имеет индекс с этим именем %L"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE клаузула в %L требует LOGICAL массив"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Некорректный тип блока"
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER выражение будет усечено в присваивании (%ld/%ld) в %L"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Коиндексированное выражение в %L присваивается переменной производного типа с POINTER компонентом в PURE процедуре"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Присваивание коиндексированной переменной в %L в PURE процедуре"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Присваивание полиморфному комассиву в %L не допускается"
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Присваивание размещаемой полиморфной переменной в %L"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Присваивание размещаемой полиморфной переменной в %L требует %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Неразмещаемая переменная не должна быть полиморфной во встроенном присваивании в %L - проверьте, что имеется соответствующая конкретная подпрограмма для '=' оператора"
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Коиндексированная переменная не должна иметь размещаемых окончательных компонентов в присваивании в %L"
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: type-bound определенные присваивания в %L не выполнены, так как несколько ссылок на части массива появятся в промежуточных выражениях."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Присваивание указателя на процедуру в %L"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Результат функции в левой части присваивания в %L должен иметь pointer атрибут."
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO оператор в %L требует INTEGER переменной"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Переменной %qs не присвоили целевую метку в %L"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternate RETURN оператор в %L требует SCALAR-INTEGER спецификатор возврата"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN оператор в %L требует скалярную подразумеваемого INTEGER переменную"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Некорректный NULL в %L"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Оператор арифметического IF в %L требует скалярное REAL или INTEGER выражение"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Нет выражения в DO WHILE"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Условие выхода из DO WHILE цикла в %L должно быть скалярным LOGICAL выражением"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL клаузула маски в %L требует скалярное LOGICAL выражение"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Некорректный код оператора"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %qs declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Неиспользуемый параметр %qs декларирован в %L"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Переменная %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Переменная %qs из модуля %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L из модуля %qs"
@@ -73179,972 +73248,972 @@ msgstr "Переменная %qs из модуля %qs со связывающе
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Процедура %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Длина строки в %L слишком велика"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Размещаемый массив %qs в %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скалярный объект %qs в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Указатель на массив %qs at %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Массив %qs at %L не может иметь отложенную форму"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Тип %qs CLASS переменной %qs at %L не является расширяемым"
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS переменная %qs в %L должна быть формальным параметром, размещаемой или указателем"
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %qs не может быть host ассоциированным в %L, поскольку он блокирован несовместимым объектом с тем же именем декларированным в %L"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Выведенный SAVE для переменной модуля %qs в %L необходим из-за подразумеваемой инициализации"
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Сущность %qs в %L имеет параметр отложенного типа и требует либо POINTER либо ALLOCATABLE атрибут"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Массив из модуля или главной программы %qs в %L должен иметь константную форму"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Сущность с предполагаемой character длиной в %L должна быть формальным аргументом или PARAMETER"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs в %L должна иметь константную character длину в этом контексте"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON переменная %qs в %L должна иметь константную character длину"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Размещаемая %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Внешняя %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Формальный параметр %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Встроенная %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Результат функции %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Автоматический массив %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s в %L"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Оператор функция с character значением %qs в %L должна иметь константную длину"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs имеет PRIVATE тип и не может быть формальным аргументом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Процедура %qs в PUBLIC интерфейсе %qs в %L берет формальные аргументы %qs, который PRIVATE"
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Функция %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Внешний объект %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL функция %qs в %L должна иметь скалярный результат"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Оператор функция %qs в %L не может иметь pointer или allocatable атрибут"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение массив"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение указатель"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) функция %qs в %L не может быть pure"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) функция %qs в %L не может быть рекурсивной"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) функция %qs в %L"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Указатель на процедуру %qs в %L не должен быть элементным"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Формальная процедура %qs в %L не должна быть элементной"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Переменная результата функции %s в %L элементной функции %qs не должна иметь атрибут ALLOCATABLE или POINTER"
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с SAVE атрибутом в %qs в %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с INTENT атрибутом в %qs в %L"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с RESULT атрибутом в %qs в %L"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL атрибут конфликтует с FUNCTION атрибутом в %qs в %L"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Результат указатель на процедуру %qs в %L оказался без pointer атрибута"
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в ELEMENTAL атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в PURE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в RECURSIVE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s между MODULE PROCEDURE декларацией в MODULE %qs и декларацией в %L в (SUB)MODULE %qs"
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL процедура %qs в %L не есть SUBROUTINE"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL процедура в %L должна иметь ровно один аргумент"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент FINAL процедуры в %L должен быть типа %qs"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент FINAL процедуры в %L не должен быть POINTER"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент FINAL процедуры в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент FINAL процедуры в %L не должен быть OPTIONAL"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Аргумент FINAL процедуры в %L не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Нескалярная FINAL процедура в %L должна иметь аргумент предполагаемой формы"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL процедура %qs декларированная в %L имеет тот же ранг (%d), что и %qs"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Только массивные FINAL процедуры декларированные для производного типа %qs определенного в %L, предлагают также скалярный тип"
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, fuzzy, gcc-internal-format
 #| msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs и %qs не могут быть смешанными FUNCTION/SUBROUTINE для GENERIC %qs в %L"
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs и %qs для GENERIC %qs в %L неоднозначны"
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Неопределенное конкретное связывание %qs как цели GENERIC %qs в %L"
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs в %L должен нацеливаться на конкретное связывание, %qs также GENERIC"
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs в %L не может перебить конкретное связывание с тем же именем"
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Type-bound оператор в %L не может быть NOPASS"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs должна быть процедурой модуля или внешней процедурой с явным интерфейсом в %L"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Процедура %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура %qs с PASS в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Неполиморфный passed-object формальный аргумент %qs в %L"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object формальный аргумент %qs в %L должен быть скаляром"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object формальный аргумент %qs в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object формальный аргумент %qs в %L не должен быть POINTER"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура %qs в %L имеет то же имя, что и компонент %qs"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура %qs в %L имеет то же имя, что и унаследованный компонент %qs"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Производный тип %qs декларированный в %L должен быть ABSTRACT, поскольку %qs есть DEFERRED и не перебивается"
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Комассивный компонент %qs в %L должен быть размещаемым с отложенной формой"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Компонент %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должен быть комассивом"
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Компонент %qs в %L с комассивным компонентом должен быть неуказательным, неразмещаемым скаляром"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Компонент %qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Компонент %qs типа BIND(C) в %L должен иметь единичную длину"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Компонент указателя на процедуру %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Компонент указателя на процедуру %qs с PASS в %L должен иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть скаляром"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может иметь POINTER атрибут"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Компонент %qs от %qs в %L имеет то же имя, что и унаследованная type-bound процедура"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Character длина компонента %qs должна быть константным спецификационным выражением в %L"
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Character компонент %qs от %qs в %L с отложенной длиной должен быть POINTER или ALLOCATABLE"
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "компонент %qs имеет PRIVATE тип и не может быть компонентом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Полиморфный компонент %s в %L в SEQUENCE или BIND(C) типе %s"
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонент %s SEQUENCE типа декларированный в %L не имеет SEQUENCE атрибут"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Конфликтующие инициализаторы в объединении в %L и %L"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Поскольку расширяющий тип %qs в %L имеет комассивный компонент, родительский тип %qs должен также иметь его"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Нерасширяемый производный тип %qs в %L не должен быть ABSTRACT"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Generic имя %qs функции %qs в %L то же, что и имя производного типа в %L"
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type %qs at %L must be extensible"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Производный тип %qs в %L должен быть расширяемым"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Массив предполагаемого размера %qs в списке имен %qs в %L не допускается"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST массивный объект %qs с предполагаемой формой в списке имен %qs в %L"
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST массивный объект %qs с неконстантной формой в списке имен %qs в %L"
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST объект %qs с неконстантной character длиной в списке имен %qs в %L"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект %qs был декларирован PRIVATE и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST объект %qs имеет use-associated PRIVATE компоненты и не может быть членом списка имен %qs в %L"
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект %qs имеет PRIVATE компоненты и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с NAMELIST атрибутом в %qs в %L"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter массив %qs at %L не может быть автоматическим или отложенной формы"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Неявно типизированный PARAMETER %qs в %L не соответствует более позднему IMPLICIT типу"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несовместимый производный тип в PARAMETER в %L"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS переменная %qs в %L не может иметь PARAMETER атрибут"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Простите, размещаемые/указательные компоненты в комассивах полиморфных (CLASS) типов в %L не поддерживаются"
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROTECTED атрибут конфликтует с EXTERNAL атрибутом в %L"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE атрибут конфликтует с PROTECTED атрибутом в %L"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив или массивом предполагаемой формы или предполагаемого ранга"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Массив предполагаемого размера в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Массив предполагаемого ранга в %L не может иметь VALUE или CODIMENSION атрибут"
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Символ в %L не является DUMMY переменной"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs в %L не может иметь VALUE атрибут, поскольку он не является формальным аргументом"
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Character формальная переменная %qs в %L с VALUE атрибутом должна иметь константную длину"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C совместимая character формальная переменная %qs в %L с VALUE атрибутом должна иметь длину один"
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Производный тип %qs в %L имеет тип %qs, который не был определен"
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутов должна быть формальным аргументом"
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть типа TYPE(*) или числового встроенного типа"
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть или скаляром или массивом предполагаемого размера"
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Предполагаемый тип переменной %s в %L разрешен только для формальных переменных"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная предполагаемого типа %s в %L не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Переменная предполагаемого типа %s в %L не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Переменная предполагаемого типа %s в %L не должна быть массивом явной формы"
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Переменная %qs at %L не может быть BIND(C), поскольку она не COMMON блок и не декларирована на уровне модуля"
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs в %L PRIVATE производного типа %qs"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) формальный аргумент %qs в %L имеет ASSUMED SIZE и поэтому не может иметь подразумеваемый инициализатор"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент %qs в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент %qs в %L типа EVENT_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Результат функции %qs в %L не должен быть комассивом или иметь комассивный компонент"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Переменная %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должна быть комассивом"
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Переменная %qs в %L с комассивным компонентом должна быть неуказательным, неразмещаемым скаляром, который не есть комассив"
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Переменная %qs в %L является комассивом и не является ни ALLOCATABLE, ни SAVE, ни формальным аргументом"
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Комассивная переменная %qs в %L не должна иметь коизмерения с отложенной формой"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Размещаемая комассивная переменная %qs в %L должна иметь отложенную форму"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Переменная %qs в %L является INTENT(OUT) и может поэтому не быть размещаемым комассивом или иметь комассивные компоненты"
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная %qs в %L не допускается в BIND(C) процедуре %qs"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL формальная переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL результирующая переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Список имен %qs не может быть аргументом для подпрограммы или функции в %L"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate в %L не является SAVEd"
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET переменная %qs в %L не есть SAVEd"
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Ожидается список именованных сущностей в %C"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA элемент %qs в %L должен быть в COMMON"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA массив %qs в %L должен быть указан в предыдущей декларации"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA элемент %qs в %L не может иметь коиндекс"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA элемент %qs в %L является указателем и поэтому должен быть полным массивом"
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 #| msgid "Argument %qs of elemental procedure at %L cannot have the ALLOCATABLE attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Аргумент %qs элементной процедуры в %L не может иметь ALLOCATABLE атрибут"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантная секция массива в %L в DATA операторе"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA оператор в %L имеет больше переменных чем значений"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "начало implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "окончание implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA оператор в %L имеет больше значений чем переменных"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Метка %d в %L определена, но не используется"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Метка %d в %L определена, но не может быть использована"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L должна иметь SEQUENCE атрибут, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L не может иметь ALLOCATABLE компоненты, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Переменная производного типа %qs в %L с подразумеваемой инициализацией не может быть в EQUIVALENCE с переменной в COMMON"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L с указательным(и) компонент(ами) не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксическая ошибка в EQUIVALENCE операторе в %L"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Все или никакие объекты в EQUIVALENCE установленной в %L должны иметь PROTECTED атрибут"
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именованная константа %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Массив %qs at %L с неконстантными границами не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонент структуры %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подстрока в %L имеет нулевую длину"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC функция %qs в %L PRIVATE типа %qs"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs в %L не имеет IMPLICIT тип"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура пользовательского оператора %qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура пользовательского оператора %qs в %L не может быть предполагаемой character длиной"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура пользовательского оператора %qs в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Первый аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Второй аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Интерфейс оператора в %L должен иметь не более двух аргументов"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Внутренняя процедура %qs в %L PURE процедуры должна также быть PURE"
@@ -75019,17 +75088,17 @@ msgstr "Перекрывающиеся неравные инициализато
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Создание временного массива в %L для аргумента %qs"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Некорректный тип выражения при проходе (%d)"
@@ -75122,108 +75191,108 @@ msgstr "неконстантное инициализационное выраж
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "встроенная переменная, которая не является процедурой"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Возвращаемое значение функции %qs в %L не установлено"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Параметр отложенного типа пока не поддерживается"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "backend декларация для переменной модуля %qs уже существует"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Неиспользуемая PRIVATE переменная модуля %qs декларирована в %L"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Формальный аргумент %qs в %L был декларирован INTENT(OUT), но не был установлен"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Формальный аргумент производного типа %qs в %L был декларирован INTENT(OUT), но не был установлен и не имеет подразумеваемого инициализатора"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Неиспользуемый формальный аргумент %qs в %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Неиспользуемая переменная модуля %qs, которая была явно импортирована в %L"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Неиспользуемая переменная %qs декларирована в %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Неиспользуемый параметр %qs декларирован в %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Неиспользуемый параметр %qs, который был явно импортирован в %L"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Возвращаемое значение %qs функции %qs декларированное в %L не установлено"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Извините, !$ACC DECLARE в %L не допускается в конструкции BLOCK"
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't compute the length of the char array at %L."
 msgid "Cannot compute the length of the char array at %L."
 msgstr "Не могу вычислить длину char массива в %L."
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Код для переразмещения размещаемой переменной в %L будет добавлен"
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Простите, коиндексированный доступ к неограниченному полиморфному объекту в %L не поддерживается"
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Простите, коиндексированный доступ к неограниченному полиморфному компоненту в %L не поддерживается"
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Неизвестная встроенная операция"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Неизвестная функция списка аргументов в %L"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -75377,7 +75446,7 @@ msgstr "gfc_validate_kind(): Получен некорректный тип"
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr "gfc_validate_kind(): Получен некорректный вид"
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code(): Некорректный код оператора"
@@ -75509,7 +75578,7 @@ msgstr "-fwpa и -fltrans являются взаимоисключающими"
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
 #| msgid "-fwpa and -fltrans are mutually exclusive"
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-fwpa и -fltrans являются взаимоисключающими"
 
 #: lto/lto-object.c:107
@@ -76643,7 +76712,7 @@ msgstr "Неопознанная опция для порядка байт: %qs"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "Неопознанная опция для начального значения с плавающей точкой: %qs"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "неопознанный ключ: %qs"
@@ -76661,15 +76730,15 @@ msgstr "не задано имя макроса после %qs"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "не задано имя файла после %qs"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "не задан маршрут после %qs"
@@ -76723,7 +76792,7 @@ msgstr "отсутствует открывающая скобка"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "некорректный тип видимости ivar %qs"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "некорректное значение порядка байт для хранения скаляров в памяти %qs"
@@ -76807,94 +76876,94 @@ msgstr "%qs устарело"
 msgid "unknown linker output %qs"
 msgstr "неизвестный вывод компоновщика %qs"
 
-#: common.opt:1502
+#: common.opt:1506
 #, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "неизвестный стиль способ обработки данных повышенной точности %qs"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr "неизвестная спецификация для множества FLT_EVAL_METHOD значений, чтобы разрешить %qs"
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "некорректный аргумент %qs ключа -ffp-contract"
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "неизвестный Stack Reuse Level %qs"
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "неизвестный алгоритм раскраски %qs"
 
-#: common.opt:1902
+#: common.opt:1906
 #, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "неизвестный регион %qs для распределения регистров"
 
-#: common.opt:1980
+#: common.opt:1984
 #, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "неизвестная LTO модель разбиения %qs"
 
-#: common.opt:2082
+#: common.opt:2086
 #, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "опции или цели отсутствуют после %qs"
 
-#: common.opt:2090
+#: common.opt:2094
 #, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "неизвестный ABI выгрузки %qs"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 #| msgid "unknown profile update method %qs"
 msgid "unknown profile reproducibility method %qs"
 msgstr "неизвестный метод изменения профиля %qs"
 
-#: common.opt:2248
+#: common.opt:2252
 #, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "неизвестный метод изменения профиля %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 #| msgid "unknown Stack Reuse Level %qs"
 msgid "unknown Live-Patching Level %qs"
 msgstr "неизвестный Stack Reuse Level %qs"
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "неизвестный алгоритм переупорядочения базовых блоков %qs"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "неизвестная модель генерации кода TLS %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "неизвестная ценовая модель векторизатора %qs"
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "некорректный тип видимости %qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "неизвестный vtable verify приоритет инициализации %qs"
@@ -77727,6 +77796,9 @@ msgstr "неизвестная модель генерации кода TLS %qs"
 #~ msgid "right rotate count >= width of type"
 #~ msgstr "счетчик циклического сдвига вправо >= ширины типа"
 
+#~ msgid "cannot deduce template arguments for %qT from ()"
+#~ msgstr "невозможно вывести аргументы шаблона для %qT из ()"
+
 #~ msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 #~ msgstr "Скалярная переменная %qs в %L с POINTER или ALLOCATABLE в процедуре %qs с BIND(C) пока не поддерживается"
 
@@ -78622,9 +78694,6 @@ msgstr "неизвестная модель генерации кода TLS %qs"
 #~ msgid "-m%s not supported in this configuration"
 #~ msgstr "-m%s в данной конфигурации не поддерживается"
 
-#~ msgid "constant argument %d for builtin %qF is out of range ("
-#~ msgstr "константный аргумент %d для внутренней функции %qF вне диапазона ("
-
 #~ msgid "CPUs older than z900 are not supported for -fsplit-stack"
 #~ msgstr "CPUs старше чем z900 не поддерживаются для -fsplit-stack"
 
@@ -78754,9 +78823,6 @@ msgstr "неизвестная модель генерации кода TLS %qs"
 #~ msgid "lambda-expression in unevaluated context"
 #~ msgstr "lambda-expression в необрабатываемом контексте"
 
-#~ msgid "lambda-expression in template-argument"
-#~ msgstr "lambda-выражение в аргументе шаблона"
-
 #
 #~ msgid "%<try%> in %<constexpr%> function"
 #~ msgstr "%<try%> в %<constexpr%> функции"
diff --git a/gcc/po/sr.po b/gcc/po/sr.po
index f258091feeb08..58ad8a4b6ea4b 100644
--- a/gcc/po/sr.po
+++ b/gcc/po/sr.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.2.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2007-08-19 12:00+0200\n"
 "Last-Translator: Caslav Ilic <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <gnu@prevod.org>\n"
@@ -1418,13 +1418,13 @@ msgstr "complex неисправно за %qs"
 msgid "this is the insn:"
 msgstr "ово је ија:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "не могу да створим поновљена учитавања за:"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "не могу да створим поновљена учитавања за:"
 
@@ -1626,18 +1626,18 @@ msgstr "непрепознатљива ија:"
 msgid "insn does not satisfy its constraints:"
 msgstr "ија не задовољава своја ограничења:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "направљено и употребљено са различитим поставкама за ‘%s’"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "направљено и употребљено са различитим поставкама за -fpic"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1686,7 +1686,7 @@ msgstr ""
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sГГЦова хеуристика: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2162,18 +2162,18 @@ msgstr "модификатор дужине у формату strfmon"
 msgid "<command-line>"
 msgstr "<командна-линија>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, fuzzy, c-format
@@ -2181,76 +2181,76 @@ msgstr "неисправан операнд за кôд ‘%c’"
 msgid "invalid operand for '%%%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "недостаје операнд"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "неисправна ија:"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "неисправан %%d операнд"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "неисправна адреса"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2266,18 +2266,18 @@ msgid "invalid %%r value"
 msgstr "неисправна %%r вредност"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "неисправна %%R вредност"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "неисправна %%N вредност"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "неисправна %%P вредност"
@@ -2307,7 +2307,7 @@ msgstr "неисправна %%M вредност"
 msgid "invalid %%U value"
 msgstr "неисправна %%U вредност"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "неисправна %%s вредност"
@@ -2317,7 +2317,7 @@ msgstr "неисправна %%s вредност"
 msgid "invalid %%C value"
 msgstr "неисправна %%C вредност"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "неисправна %%E вредност"
@@ -2330,7 +2330,7 @@ msgstr "непознато unspec релокације"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "неисправан %%xn кôд"
@@ -2419,36 +2419,36 @@ msgstr "неисправан УНСПЕЦ као операнд"
 msgid "unrecognized supposed constant"
 msgstr "непрепозната претпостављена константа"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "неисправан операнд помака"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикатна инструкција Тамба"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикатна инструкција у условном редоследу"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2456,14 +2456,14 @@ msgstr "неисправан операнд за кôд ‘%c’"
 msgid "invalid operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
 msgstr "инструкција се никад не извршава"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2600,8 +2600,8 @@ msgstr "неочекиван операнд"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2985,7 +2985,7 @@ msgstr "неисправна операција на %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "неисправан %%P операнд"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "неисправна %%p вредност"
@@ -3043,7 +3043,7 @@ msgid "post-increment address is not a register"
 msgstr "адреса постувећања није регистар"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "лоша адреса"
 
@@ -3100,8 +3100,8 @@ msgstr "‘%s’ није исправно име класе"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, fuzzy, c-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of '%%%c'"
@@ -3249,334 +3249,334 @@ msgstr "Нема места на стеку.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Покушајте да покренете ‘%s’ у шкољци да повећате ограничење.\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Користи хардверски покретан зарез"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Искључи индексно адресирање"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "лоша проба"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "неисправна %%D вредност"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "неисправна %%f вредност"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "неисправна %%F вредност"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "неисправна %%G вредност"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "неисправан %%j кôд"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "неисправан %%J кôд"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "неисправна %%k вредност"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "неисправна %%K вредност"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "неисправна %%O вредност"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "неисправна %%q вредност"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "неисправна %%T вредност"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "неисправна %%u вредност"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "неисправна %%v вредност"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "неисправна %%x вредност"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не стварај јединствену излазну тачку за сваку функцију"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "не могу да створим поновљена учитавања за:"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "не могу да разложим адресу"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "неисправан операнд за модификатор ‘O’"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "неисправан кôд излаза операнада"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression - try using an output modifier"
 msgstr "неисправан израз као операнд"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "циљеви показивача у повратку разликују се у означености"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3861,8 +3861,8 @@ msgstr "<анонимно>"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "очекивано је %<;%>"
@@ -3882,7 +3882,7 @@ msgstr "очекивано је %<;%>"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -3891,7 +3891,7 @@ msgstr "очекивано је %<{%>"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -3912,13 +3912,13 @@ msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "очекивано је %<(%>"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -3926,8 +3926,8 @@ msgstr "очекивано је %<{%>"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "очекивано је %<{%>"
@@ -3938,14 +3938,14 @@ msgstr "очекивано је %<{%>"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -3955,7 +3955,7 @@ msgstr "очекивано је %<{%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -3967,20 +3967,20 @@ msgstr "очекивано је %<{%>"
 msgid "expected %<.%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -3989,31 +3989,31 @@ msgstr "очекивано је %<,%> или %<;%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "очекивано је %<=%>"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 #, fuzzy
 #| msgid "<anonymous>"
 msgid "(anonymous)"
 msgstr "<анонимно>"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -4032,13 +4032,13 @@ msgstr "Очекивано је име"
 msgid "candidate:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 #| msgid "type %qs has a user-defined constructor"
 msgid "  after user-defined conversion:"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -4048,19 +4048,19 @@ msgstr[1] "кандидат 1:"
 msgstr[2] "кандидат 1:"
 msgstr[3] "кандидат 1:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "скок на етикету %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "скок на етикету случаја"
 
@@ -4320,33 +4320,33 @@ msgstr "локална променљива %qD не може се појави
 msgid "local variable %qD may not appear in this context"
 msgstr "локална променљива %qD не може се појавити у овом контексту"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 #| msgid "forming %s to reference type %qT"
 msgid "%<using enum%> of dependent type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 #| msgid "%Jcase value %qs not in enumerated type %qT"
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%Jвредност случаја %qs није у набројивом типу %qT"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "неисправна употреба непотпуног typedef %qD"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "кандидати су:"
 
@@ -4404,50 +4404,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "погрешан тип аргумента уз унарно минус"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "погрешан тип аргумента уз битски комплемент"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "погрешан тип аргумента за abs"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "погрешан тип аргумента за конјугацију"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4553,7 +4553,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Погон:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 #, fuzzy
 #| msgid "Actual argument at %L must be definable to match dummy INTENT = OUT/INOUT"
 msgid "actual argument to INTENT = OUT/INOUT"
@@ -4691,7 +4691,7 @@ msgstr "Лош оператор"
 msgid "Bad type in constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "Неочекиван крај модула"
 
@@ -4719,11 +4719,11 @@ msgstr "блоковско IF"
 msgid "implied END DO"
 msgstr "имплицитно END DO"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "додела"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "додела показивача"
 
@@ -4839,175 +4839,175 @@ msgstr "‘%s’ код %L мора имати константну знаков
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, fuzzy, c-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Операнд унарног бројевног оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди бинарног бројевног оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Операнди оператора надовезивања ниски код %%L су %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди логичког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Операнд оператора .NOT. код %%L је %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Комплексне величине се не могу поредити код %L"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Логичке код %%L морају бити поређене са %s уместо %s"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди оператора поређења ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Операнд корисничког оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди корисничког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Изврши праћење променљивих"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "неисправан израз као операнд"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE "
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALLOCATE "
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 #, fuzzy
 #| msgid "assignment of read-only location"
 msgid "Assignment of scalar to unallocated array"
@@ -5141,26 +5141,26 @@ msgstr "Упућивач низа ван граница"
 msgid "Incorrect function return value"
 msgstr "Нетачна вредност повратка из функције"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, c-format
 msgid "Error allocating %lu bytes"
 msgstr ""
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr ""
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr ""
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -5393,17 +5393,17 @@ msgstr "-Xbind-now и -Xbind-lazy нису сагласни"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "не могу се навести и -EB и -EL"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 #, fuzzy
 #| msgid "-msoft-float and -mhard_float may not be used together"
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-msoft-float и -mhard_float не могу се користити заједно"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian и -mlittle-endian не могу се користити заједно"
 
@@ -5425,8 +5425,8 @@ msgstr "датотека навода нема навод за повезива
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "не могу се задати и -C и -o"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared и mdll нису сагласни"
 
@@ -5610,10 +5610,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Упозори на аритметику са функцијским показивачима"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, fuzzy, no-c-format
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Does nothing. Preserved for backward compatibility."
@@ -6140,175 +6140,175 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr ""
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, fuzzy, no-c-format
 #| msgid "Try to layout derived types as compact as possible"
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "Покушај да распоредиш изведене типове што збијеније"
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 #| msgid "Expected a right parenthesis in expression at %C"
 msgid "Protect parentheses in expressions."
 msgstr "Очекивана је десна заграда у изразу код %C"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, fuzzy, no-c-format
 #| msgid "Enable range checking during compilation"
 msgid "Enable range checking during compilation."
 msgstr "Укључи проверу опсега током компилације"
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, fuzzy, no-c-format
 #| msgid "incompatible types in assignment"
 msgid "Reallocate the LHS in assignments."
 msgstr "несагласни типови у додели"
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, fuzzy, no-c-format
 #| msgid "Use a 4-byte record marker for unformatted files"
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Користи 4-бајтни обележивач слога за неформатиране датотеке"
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, fuzzy, no-c-format
 #| msgid "Use an 8-byte record marker for unformatted files"
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Користи 8-бајтни обележивач слога за неформатиране датотеке"
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, fuzzy, no-c-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "Копирај одељке низа у непрекидан блок при улазу у процедуру"
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, fuzzy, no-c-format
 #| msgid "Append a second underscore if the name already contains an underscore"
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "Додај другу подвлаку ако име већ садржи подвлаку"
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, fuzzy, no-c-format
 #| msgid "Append underscores to externally visible names"
 msgid "Append underscores to externally visible names."
 msgstr "Додај подвлаке споља видљивим именима"
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Не ради ништа. Остављено ради сагласности уназад."
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Поштуј ИСО стандард фортрана 2003"
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Поштуј ИСО стандард фортрана 2003"
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Поштуј ИСО стандард фортрана 2003"
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Поштуј ИСО стандард фортрана 2003"
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 95 standard"
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Поштуј ИСО стандард фортрана 95"
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, fuzzy, no-c-format
 #| msgid "Conform nothing in particular"
 msgid "Conform to nothing in particular."
 msgstr "Не поштуј ништа посебно"
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, fuzzy, no-c-format
 #| msgid "Accept extensions to support legacy code"
 msgid "Accept extensions to support legacy code."
@@ -7074,7 +7074,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7768,8 +7768,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, fuzzy, no-c-format
 #| msgid "switch %qs is no longer supported"
 msgid "No longer supported."
@@ -8160,543 +8160,538 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, fuzzy, no-c-format
 #| msgid "Unclassifiable OpenMP directive at %C"
 msgid "Enable OpenMP's SIMD directives."
 msgstr "Неразврстљива ОпенМП директива код %C"
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, fuzzy, no-c-format
 #| msgid "Recognize C++ kewords like \"compl\" and \"xor\""
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "Препознај кључне речи Ц++а као „compl“ и „xor“"
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, fuzzy, no-c-format
 #| msgid "Look for and use PCH files even when preprocessing"
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "Тражи и користи ПЦХ датотеке чак и током предобраде"
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, fuzzy, no-c-format
 #| msgid "Downgrade conformance errors to warnings"
 msgid "Downgrade conformance errors to warnings."
 msgstr "Ражалуј грешке у поштовању на упозорења"
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, fuzzy, no-c-format
 #| msgid "Enable linker relaxations"
 msgid "Enable Plan 9 language extensions."
 msgstr "Укључи релаксације повезивача"
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, fuzzy, no-c-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "Treat the input file as already preprocessed."
 msgstr "Сматрај улазну датотеку већ предобрађеном"
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, fuzzy, no-c-format
 #| msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime"
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "Користи се у режиму фиксирај-и-настави за указивање да се објектне датотеке могу размењивати при извршавању"
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "Превазиђено.  Овај прекидач нема ефекта"
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, fuzzy, no-c-format
 #| msgid "Generate run time type descriptor information"
 msgid "Generate run time type descriptor information."
 msgstr "Стварај описе типова при извршавању"
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, fuzzy, no-c-format
 #| msgid "Use the narrowest integer type possible for enumeration types"
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "За набројиве типове користи најужи целобројни тип могућ"
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\""
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "Спроведи да „unsigned short“ буде подметнут за „wchar_t“"
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "Нека битско поље буде означено када није дато ни „signed“ ни „unsigned“"
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, fuzzy, no-c-format
 #| msgid "Make \"char\" signed by default"
 msgid "Make \"char\" signed by default."
 msgstr "Нека „char“ подразумевано буде означен"
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr ""
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, fuzzy, no-c-format
 #| msgid "Display statistics accumulated during compilation"
 msgid "Display statistics accumulated during compilation."
 msgstr "Прикажи статистику срачунату током компилације"
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, fuzzy, no-c-format
 #| msgid "Set the maximum number of iterations for RPTS to N"
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "Постави највећи број итерација за RPTS на N"
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, fuzzy, no-c-format
 #| msgid "Specify maximum template instantiation depth"
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "Одредите највећу дубину извођења шаблона"
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, fuzzy, no-c-format
 #| msgid "Do not generate thread-safe code for initializing local statics"
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "Не стварај нитно-безбедан кôд за успостављање локалних статика"
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "Нека битско поље буде неозначено када није дато ни „signed“ ни „unsigned“"
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, fuzzy, no-c-format
 #| msgid "Make \"char\" unsigned by default"
 msgid "Make \"char\" unsigned by default."
 msgstr "Нека „char“ подразумевано буде неозначен"
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, fuzzy, no-c-format
 #| msgid "Use __cxa_atexit to register destructors"
 msgid "Use __cxa_atexit to register destructors."
 msgstr "Користи __cxa_atexit за регистрацију деструкторâ"
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, fuzzy, no-c-format
 #| msgid "Use __cxa_get_exception_ptr in exception handling"
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "Користи __cxa_get_exception_ptr у руковању изузецима"
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, fuzzy, no-c-format
 #| msgid "Marks all inlined methods as having hidden visibility"
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "Означи скривање видљивости свим утканим методима"
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Emit common-like symbols as weak symbols"
 msgid "Emit common-like symbols as weak symbols."
 msgstr "Емитуј наизглед заједничке симболе као слабе симболе"
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, fuzzy, no-c-format
 #| msgid "Convert all wide strings and character constants to character set <cset>"
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "Претвори све широке ниске и знаковне константе у скуп знакова <cset>"
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, fuzzy, no-c-format
 #| msgid "Generate a #line directive pointing at the current working directory"
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "Створи директиву #line која показује на текући радни директоријум"
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, fuzzy, no-c-format
 #| msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode"
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "Стварај лењу потрагу класа (преко objc_getClass()) за употребу у режиму Зиро-Линка"
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Dump declarations to a .decl file"
 msgid "Dump declarations to a .decl file."
 msgstr "Попиши декларације у .decl датотеку"
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the system include path"
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "Додај <dir> на крај системске путање укључивања"
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, fuzzy, no-c-format
 #| msgid "Accept definition of macros in <file>"
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "Прихвати дефиниције макроа из <file>"
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-imultilib <дир> Постави <дир> као поддиректоријум укључивања за вишебиба"
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, fuzzy, no-c-format
 #| msgid "Include the contents of <file> before other files"
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "Укључи садржај <file> пре других датотека"
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, fuzzy, no-c-format
 #| msgid "Specify <path> as a prefix for next two options"
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "Одреди <path> као префикс за следеће две опције"
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, fuzzy, no-c-format
 #| msgid "Set <dir> to be the system root directory"
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "Постави да <dir> буде корени директоријум система"
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the start of the system include path"
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "Додај <dir> на почетак системске путање укључивања"
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the quote include path"
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "Додај <dir> на крај цитиране путање укључивања"
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the system include path"
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "Додај <dir> на крај системске путање укључивања"
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the main include path"
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "Додај <dir> на крај главне путање укључивања"
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories (those specified with -isystem will still be used)"
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "Не тражи стандардне системске директоријуме укључивања (што је наведено помоћу -isystem ће и даље бити коришћено)"
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories for C++"
 msgid "Do not search standard system include directories for C++."
 msgstr "Не тражи стандардне системске директоријуме укључивања за Ц++"
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, fuzzy, no-c-format
 #| msgid "Generate C header of platform-specific features"
 msgid "Generate C header of platform-specific features."
 msgstr "Створи Ц заглавље са особинама посебним за платформу"
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, fuzzy, no-c-format
 #| msgid "Remap file names when including files"
 msgid "Remap file names when including files."
 msgstr "Премапирај имена датотека при укључивању датотека"
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Поштуј стандард Ц++а ИСО 1998, са Гнуовим проширењима"
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Поштуј стандард Ц++а ИСО 1998"
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Превазиђено, боље -std=c99"
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Превазиђено, боље -std=c99"
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Поштуј стандард Ц++а ИСО 1998"
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++17."
 msgstr "Превазиђено, боље -std=c99"
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "Поштуј стандард Ц++а ИСО 1998"
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Поштуј стандард Ц++а ИСО 1998, са Гнуовим проширењима"
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Поштуј стандард Ц++а ИСО 1998, са Гнуовим проширењима"
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Поштуј стандард Ц-а ИСО 1990"
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c11."
 msgstr "Превазиђено, боље -std=c99"
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Поштуј стандард Ц-а ИСО 1990, са допунама из 1994."
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Поштуј стандард Ц-а ИСО 1990, са допунама из 1994."
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Поштуј стандард Ц-а ИСО 1990"
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard"
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Поштуј стандард Ц-а ИСО 1999"
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c99."
 msgstr "Превазиђено, боље -std=c99"
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Поштуј стандард Ц++а ИСО 1998, са Гнуовим проширењима"
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Поштуј стандард Ц++а ИСО 1998, са Гнуовим проширењима"
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Превазиђено, боље -std=gnu99"
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Превазиђено, боље -std=gnu99"
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Поштуј стандард Ц++а ИСО 1998, са Гнуовим проширењима"
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "Превазиђено, боље -std=gnu99"
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "Поштуј стандард Ц++а ИСО 1998, са Гнуовим проширењима"
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Поштуј стандард Ц++а ИСО 1998, са Гнуовим проширењима"
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Поштуј стандард Ц++а ИСО 1998, са Гнуовим проширењима"
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Поштуј стандард Ц-а ИСО 1990, са Гнуовим проширењима"
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Превазиђено, боље -std=gnu99"
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Поштуј стандард Ц-а ИСО 1990, са Гнуовим проширењима"
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Поштуј стандард Ц-а ИСО 1990, са Гнуовим проширењима"
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Поштуј стандард Ц-а ИСО 1990, са Гнуовим проширењима"
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard with GNU extensions"
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Поштуј стандард Ц-а ИСО 1999, са Гнуовим проширењима"
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Превазиђено, боље -std=gnu99"
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Поштуј стандард Ц-а ИСО 1990, са допунама из 1994."
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=iso9899:1999"
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Превазиђено, боље -std=iso9899:1999"
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable traditional preprocessing."
 msgstr "Укључи традиционалну предобраду"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, fuzzy, no-c-format
 #| msgid "Support ISO C trigraphs"
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "Подржи триграфе ИСО Ц-а"
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Do not predefine system-specific and GCC-specific macros"
 msgid "Do not predefine system-specific and GCC-specific macros."
@@ -8959,6 +8954,12 @@ msgstr "Компилуј са 32-битним целобројним режим
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+#| msgid "Emit implicit instantiations of templates"
+msgid "Emit template instantiations as weak symbols."
+msgstr "Емитуј имплицитна извођења шаблона"
+
 #: d/lang.opt:346
 #, fuzzy, no-c-format
 #| msgid "Do not assume that standard C libraries and \"main\" exist"
@@ -10299,154 +10300,168 @@ msgstr ""
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as big endian"
+msgid "Assume target CPU is configured as big endian."
+msgstr "Претпостави да је циљни ЦПУ постављен на велику крајност"
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as little endian"
+msgid "Assume target CPU is configured as little endian."
+msgstr "Претпостави да је циљни ЦПУ постављен на малу крајност"
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 #| msgid "Alternate calling convention"
 msgid "Specify integer and floating-point calling convention."
 msgstr "Алтернативна конвенција позивања"
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, fuzzy, no-c-format
 #| msgid "Attempt to keep stack aligned to this power of 2"
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Покушај да одржиш стек поравнат на овом степену двојке"
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 #| msgid "Allow the use of hardware floating-point instructions"
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Дозволи употребу хардверских инструкција покретног зареза"
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 #| msgid "Use trap instructions to check for integer divide by zero"
 msgid "Use hardware instructions for integer division."
 msgstr "Користи инструкције клопки ради провере целобројног дељења нулом"
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, fuzzy, no-c-format
 #| msgid "Optimize the output for PROCESSOR"
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "Оптимизуј излаз за дати процесор"
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 #| msgid "Optimize the output for PROCESSOR"
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "Оптимизуј излаз за дати процесор"
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, fuzzy, no-c-format
 #| msgid "Put global and static data smaller than <number> bytes into a special section (on some targets)"
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "Стави глобалне и статичке податке мање од <number> бајтова у посебан одељак (на неким циљевима)"
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "Користи потпрограме за прологе и епилоге функција"
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, fuzzy, no-c-format
 #| msgid "Specify the register allocation order"
 msgid "Specify the code model."
 msgstr "Одредите редослед резервисања регистара"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 #| msgid "Do not use unaligned memory references"
 msgid "Do not generate unaligned memory accesses."
 msgstr "Не користи непоравнате меморијске упућиваче"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, fuzzy, no-c-format
 #| msgid "Do not tune writable data alignment"
 msgid "Use the given data alignment."
 msgstr "Не подешавај равнање уписивих података"
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr ""
@@ -10587,13 +10602,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as big endian"
-msgid "Assume target CPU is configured as big endian."
-msgstr "Претпостави да је циљни ЦПУ постављен на велику крајност"
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 #| msgid "Generate code without GP reg"
@@ -10615,13 +10623,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as little endian"
-msgid "Assume target CPU is configured as little endian."
-msgstr "Претпостави да је циљни ЦПУ постављен на малу крајност"
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -18748,2415 +18749,2415 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "Постави основно име датотека за пописе"
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "Поравнај почетке функција"
 
-#: common.opt:988
+#: common.opt:992
 #, fuzzy, no-c-format
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "Поравнај етикете које се достижу једино скакањем"
 
-#: common.opt:995
+#: common.opt:999
 #, fuzzy, no-c-format
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "Поравнај све етикете"
 
-#: common.opt:1002
+#: common.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "Поравнај почетке петљи"
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable static analysis pass."
 msgstr "Укључи традиционалну предобраду"
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, fuzzy, no-c-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Овај прекидач је превазиђен; користите -Wextra"
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, fuzzy, no-c-format
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Стварај табеле одмотавања које су тачне на свакој граници инструкција"
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "Стварај инструкције isel"
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Стварај кôд за проверу граница пре индексирања низова"
 
-#: common.opt:1091
+#: common.opt:1095
 #, fuzzy, no-c-format
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Замени додавање-упоређивање-гранање регистром за гранање-на-збир"
 
-#: common.opt:1095
+#: common.opt:1099
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "Користи профилишуће информације за вероватноће гранања"
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 #| msgid "Emit call graph information"
 msgid "Output callgraph information on a per-file basis."
 msgstr "Емитуј информације за граф позива"
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr ""
 
-#: common.opt:1119
+#: common.opt:1123
 #, fuzzy, no-c-format
 #| msgid "Mark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "Означи да се <register> очувава преко функција"
 
-#: common.opt:1123
+#: common.opt:1127
 #, fuzzy, no-c-format
 #| msgid "Mark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "Означи да се <register> квари позивима функција"
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "Сачувавај регистре око позива функција"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy, no-c-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "Овај прекидач је превазиђен; користите -Wextra"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy, no-c-format
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "Провери повратни тип за new"
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, fuzzy, no-c-format
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "Укључи профилисање функција"
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Put uninitialized globals in the common section."
 msgstr "Не стављај неуспостављене глобалне у заједнички одељак"
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Елиминиши глобалне заједничке подизразе после резервисања регистара"
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy, no-c-format
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Изврши оптимизацију за распростирање копирања преко регистара"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy, no-c-format
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "Изврши оптимизацију за укрштање скокова"
 
-#: common.opt:1190
+#: common.opt:1194
 #, fuzzy, no-c-format
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "При извршавању ЦСЕа прати скокове до њихових циљева"
 
-#: common.opt:1198
+#: common.opt:1202
 #, fuzzy, no-c-format
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "Изостави корак свођења опсега при комплексним дељењима"
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, fuzzy, no-c-format
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "Стављај податке у њихов сопствени одељак"
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, fuzzy, no-c-format
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "Одложи за касније подизање аргумената са стека"
 
-#: common.opt:1236
+#: common.opt:1240
 #, fuzzy, no-c-format
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Покушај да испуниш жлебове застоја за инструкције гранања"
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, fuzzy, no-c-format
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "Обриши бескорисне провере нултог показивача"
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, fuzzy, no-c-format
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization."
 msgstr "Формирај суперблокове преко умножавања репа"
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, fuzzy, no-c-format
 #| msgid "How often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "Колико често емитовати локацију у извору на почетку дијагностике преломљене у више линија"
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, fuzzy, no-c-format
 #| msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Допуни одговарајуће дијагностичке поруке опцијом командне линије које их контролишу"
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, fuzzy, no-c-format
 #| msgid "Distance between tab stops for column reporting"
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "Величина табулатора за пријављивање колона"
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, fuzzy, no-c-format
 #| msgid "Dump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "Попиши разне унутрашње ствари компилатора у датотеку"
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, fuzzy, no-c-format
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Сузбиј испис адреса у исправљачким пописима"
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, fuzzy, no-c-format
 #| msgid "Do the full register move optimization pass"
 msgid "Dump optimization passes."
 msgstr "Изврши потпуни пролаз оптимизације померањем регистара"
 
-#: common.opt:1455
+#: common.opt:1459
 #, fuzzy, no-c-format
 #| msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Сузбиј испис бројева инструкција, бројева линија и адреса у исправљачким пописима"
 
-#: common.opt:1459
+#: common.opt:1463
 #, fuzzy, no-c-format
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Сузбиј испис адреса у исправљачким пописима"
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1471
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "Изврши рано уткивање"
 
-#: common.opt:1475
+#: common.opt:1479
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1479
+#: common.opt:1483
 #, fuzzy, no-c-format
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Елиминиши неупотребље типове у исправљачким информацијама"
 
-#: common.opt:1483
+#: common.opt:1487
 #, fuzzy, no-c-format
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "Елиминиши неупотребље типове у исправљачким информацијама"
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "Не сузбијај исправљачке податке Ц++ класа."
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Укључи руковање изузецима"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy, no-c-format
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Изврши и неке мање, а скупе оптимизације"
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, fuzzy, no-c-format
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Претпостави да се не стварају ни НаНи ни бесконачности"
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, fuzzy, no-c-format
 #| msgid "Mark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "Означи да <register> није доступан компилатору"
 
-#: common.opt:1546
+#: common.opt:1550
 #, fuzzy, no-c-format
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Не резервиши једноструке и двоструке у регистрима проширене тачности"
 
-#: common.opt:1554
+#: common.opt:1558
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Изврши распростирање опсега вредности на стаблима"
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, fuzzy, no-c-format
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "Дозволи држање адреса функција у регистрима"
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "Стави сваку функцију у њен сопствени одељак"
 
-#: common.opt:1590
+#: common.opt:1594
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "Елиминиши глобалне заједничке подизразе"
 
-#: common.opt:1594
+#: common.opt:1598
 #, fuzzy, no-c-format
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Изврши побољшано кретање учитавања током елиминације глобалних заједничких подизраза"
 
-#: common.opt:1598
+#: common.opt:1602
 #, fuzzy, no-c-format
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Изврши кретање складиштења током елиминације глобалних заједничких подизраза"
 
-#: common.opt:1602
+#: common.opt:1606
 #, fuzzy, no-c-format
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Елиминиши непотребно учитавање после складиштења у глобалном заједничком подизразу"
 
-#: common.opt:1607
+#: common.opt:1611
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Елиминиши глобалне заједничке подизразе после резервисања регистара"
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "Укључи копирање заглавља петље на стаблима"
 
-#: common.opt:1667
+#: common.opt:1671
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "Одмотај све петље"
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, fuzzy, no-c-format
 #| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "Укључи оптимизацију равнања етикета"
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, fuzzy, no-c-format
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "Укључи погађање вероватноћа гранања"
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "Обради директиве #ident"
 
-#: common.opt:1707
+#: common.opt:1711
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Претвори условне скокове у безгране еквиваленте"
 
-#: common.opt:1711
+#: common.opt:1715
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Претвори условне скокове у условно извршавање"
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Претвори условне скокове у безгране еквиваленте"
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "Не стварај директиве .size"
 
-#: common.opt:1747
+#: common.opt:1751
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform indirect inlining."
 msgstr "Изврши рано уткивање"
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, fuzzy, no-c-format
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Интегриши једноставне функције у њихове позиваче"
 
-#: common.opt:1761
+#: common.opt:1765
 #, fuzzy, no-c-format
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Интегриши функције једном позване у њихове позиваче"
 
-#: common.opt:1765
+#: common.opt:1769
 #, fuzzy, no-c-format
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "Интегриши функције једном позване у њихове позиваче"
 
-#: common.opt:1772
+#: common.opt:1776
 #, fuzzy, no-c-format
 #| msgid "Limit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "Ограничи број утканих функција на <number>"
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, fuzzy, no-c-format
 #| msgid "Instrument function entry and exit with profiling calls"
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Опреми улаз и излаз функција профилишућим позивима"
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1822
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1822
+#: common.opt:1826
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1830
+#: common.opt:1834
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1834
+#: common.opt:1838
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform interprocedural modref analysis."
 msgstr "Изврши међупроцедуралну анализу показује-на"
 
-#: common.opt:1838
+#: common.opt:1842
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural profile propagation."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1842
+#: common.opt:1846
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform interprocedural points-to analysis."
 msgstr "Изврши међупроцедуралну анализу показује-на"
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "Откривај чисте и константне функције"
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only and non addressable static variables."
 msgstr "Откривај статичке променљиве које су само за читање и не могу се адресирати"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "Откривај статичке променљиве које су само за читање и не могу се адресирати"
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "Изврши распростирање опсега вредности на стаблима"
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, fuzzy, no-c-format
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "Оптимизуј индукционе променљиве на стаблима"
 
-#: common.opt:1941
+#: common.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Користи табеле скокова за довољно велике наредбе прекидача"
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "Користи табеле скокова за довољно велике наредбе прекидача"
 
-#: common.opt:1949
+#: common.opt:1953
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Стварај кôд за функције чак и ако су потпуно уткане"
 
-#: common.opt:1953
+#: common.opt:1957
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "Стварај кôд за функције чак и ако су потпуно уткане"
 
-#: common.opt:1957
+#: common.opt:1961
 #, fuzzy, no-c-format
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "Емитуј статичке константне променљиве чак и ако се не користе"
 
-#: common.opt:1961
+#: common.opt:1965
 #, fuzzy, no-c-format
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "Додај спољашњим симболима водећу подвлаку"
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Укључи оптимизације повезивача"
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "Постави errno после уграђених математичких фја"
 
-#: common.opt:2024
+#: common.opt:2028
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "Највећи број грешака за пријављивање"
 
-#: common.opt:2028
+#: common.opt:2032
 #, fuzzy, no-c-format
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "Извештавај о трајном резервисању меморије"
 
-#: common.opt:2032
+#: common.opt:2036
 #, fuzzy, no-c-format
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Извештавај о трајном резервисању меморије"
 
-#: common.opt:2039
+#: common.opt:2043
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Покушај да стопиш истоветне константе и константне променљиве"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Покушај да стопиш истоветне константе преко компилационих јединица"
 
-#: common.opt:2047
+#: common.opt:2051
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Покушај да стопиш истоветне константе преко компилационих јединица"
 
-#: common.opt:2051
+#: common.opt:2055
 #, fuzzy, no-c-format
 #| msgid "Limit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "Ограничи дијагностику на <number> знакова по линији.  0 сузбија преламање линија"
 
-#: common.opt:2055
+#: common.opt:2059
 #, fuzzy, no-c-format
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Изврши окретно модуло-распоређивање на основу СМСа пре првог распоређивачког пролаза"
 
-#: common.opt:2059
+#: common.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Изврши окретно модуло-распоређивање на основу СМСа пре првог распоређивачког пролаза"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy, no-c-format
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "Премести инваријантна рачунања изван петљи"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead code elimination pass."
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead store elimination pass."
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy, no-c-format
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Укључи/искључи традиционално распоређивање у петљама које су већ прошле кроз модуло-распоређивање"
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "Подржи синхроне непозивне изузетке"
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, fuzzy, no-c-format
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "Када је могуће не стварај оквире стека"
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Укључи оптимизације петљи на нивоу стабла"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, fuzzy, no-c-format
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Оптимизуј сродничке и репно рекурзивне позиве"
 
-#: common.opt:2124
+#: common.opt:2128
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform partial inlining."
 msgstr "Изврши рано уткивање"
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy, no-c-format
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "Пакуј чланове структура заједно без рупа"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy, no-c-format
 #| msgid "Set initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "Постави почетно највеће равнање чланова структуре"
 
-#: common.opt:2144
+#: common.opt:2148
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "Враћај мале скупине у меморији, не у регистрима"
 
-#: common.opt:2148
+#: common.opt:2152
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "Изврши љушћење петљи"
 
-#: common.opt:2152
+#: common.opt:2156
 #, fuzzy, no-c-format
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "Укључи машински-зависне окнасте оптимизације"
 
-#: common.opt:2156
+#: common.opt:2160
 #, fuzzy, no-c-format
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Укључи окнасти РТЛ пролаз пре sched2"
 
-#: common.opt:2160
+#: common.opt:2164
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Стварај положајно-независни кôд ако је могуће (велики режим)"
 
-#: common.opt:2164
+#: common.opt:2168
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Стварај положајно-независни кôд за извршне ако је могуће (велики режим)"
 
-#: common.opt:2168
+#: common.opt:2172
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Стварај положајно-независни кôд ако је могуће (мали режим)"
 
-#: common.opt:2172
+#: common.opt:2176
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Стварај положајно-независни кôд за извршне ако је могуће (мали режим)"
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, fuzzy, no-c-format
 #| msgid "Specify options to GNAT"
 msgid "Specify a plugin to load."
 msgstr "Наведите опције ГНАТу"
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, fuzzy, no-c-format
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Укључи оптимизацију померањем регистара"
 
-#: common.opt:2192
+#: common.opt:2196
 #, fuzzy, no-c-format
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Стварај инструкције предохватања, ако су доступне, за низове у петљама"
 
-#: common.opt:2196
+#: common.opt:2200
 #, fuzzy, no-c-format
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "Укључи основни кôд за профилисање програма"
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, fuzzy, no-c-format
 #| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "Убаци кôд за профилисање програма на основу лукова"
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, fuzzy, no-c-format
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Укључи уобичајене опције за стварање профилних информација, ради оптимизација на основу одзива профилисања"
 
-#: common.opt:2269
+#: common.opt:2273
 #, fuzzy, no-c-format
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Укључи уобичајене опције за стварање профилних информација, ради оптимизација на основу одзива профилисања"
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, fuzzy, no-c-format
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Укључи уобичајене опције за оптимизације на основу одзива профилисања"
 
-#: common.opt:2289
+#: common.opt:2293
 #, fuzzy, no-c-format
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Укључи уобичајене опције за оптимизације на основу одзива профилисања"
 
-#: common.opt:2293
+#: common.opt:2297
 #, fuzzy, no-c-format
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "Умећи кôд за профилисање вредности израза"
 
-#: common.opt:2297
+#: common.opt:2301
 #, fuzzy, no-c-format
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile."
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: common.opt:2301
+#: common.opt:2305
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "Прераспореди функције ради побољшања постављења кôда"
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 #| msgid "Use push instructions to save outgoing arguments"
 msgid "Insert NOP instructions at each function entry."
 msgstr "Користи инструкције гурања за чување одлазећих аргумената"
 
-#: common.opt:2312
+#: common.opt:2316
 #, fuzzy, no-c-format
 #| msgid "Make compile reproducible using <string>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "Учини компилацију поновљивом користећи <string>"
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "Враћај мале скупине у регистрима"
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "Изврши пролаз оптимизације преименовањем регистара"
 
-#: common.opt:2372
+#: common.opt:2376
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Изврши пролаз оптимизације преименовањем регистара"
 
-#: common.opt:2376
+#: common.opt:2380
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Прераспореди основне блокове ради побољшања постављења кôда"
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks and partition into hot and cold sections"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Прераспореди основне блокове и подели на вруће и хладне одељке"
 
-#: common.opt:2397
+#: common.opt:2401
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "Прераспореди функције ради побољшања постављења кôда"
 
-#: common.opt:2401
+#: common.opt:2405
 #, fuzzy, no-c-format
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Додај пролаз елиминације заједничких подизраза после оптимизација петље"
 
-#: common.opt:2409
+#: common.opt:2413
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Искључи оптимизације које претпостављају подразумевано понашање ФП заокруживања"
 
-#: common.opt:2413
+#: common.opt:2417
 #, fuzzy, no-c-format
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "Укључи распоређивање преко основних блокова"
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "Дозволи спекулативно кретање не-учитавања"
 
-#: common.opt:2425
+#: common.opt:2429
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "Дозволи спекулативно кретање неких учитавања"
 
-#: common.opt:2429
+#: common.opt:2433
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "Дозволи спекулативно кретање више учитавања"
 
-#: common.opt:2433
+#: common.opt:2437
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "Постави ниво опширности распоређивача"
 
-#: common.opt:2437
+#: common.opt:2441
 #, fuzzy, no-c-format
 #| msgid "If scheduling post reload, do superblock scheduling"
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Ако се распоређује после поновљеног учитавања, изврши суперблоковско распоређивање"
 
-#: common.opt:2445
+#: common.opt:2449
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "Прераспореди инструкције пре резервисања регистара"
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "Прераспореди инструкције после резервисања регистара"
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, fuzzy, no-c-format
 #| msgid "Use data speculation after reload"
 msgid "Run selective scheduling after reload."
 msgstr "Користи спекулацију података после поновног учитавања"
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy, no-c-format
 #| msgid "Allow premature scheduling of queued insns"
 msgid "Allow premature scheduling of queued insns."
 msgstr "Дозволи прерано распоређивање ија у реду"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy, no-c-format
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "Број ија у реду које се могу прерано распоређивати"
 
-#: common.opt:2498
+#: common.opt:2502
 #, fuzzy, no-c-format
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Провера растојања зависности у прераном распоређивању ија у реду"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy, no-c-format
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "Провера растојања зависности у прераном распоређивању ија у реду"
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Постави ниво опширности распоређивача"
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 #, fuzzy, no-c-format
 #| msgid "Access data in the same section from shared anchor points"
 msgid "Access data in the same section from shared anchor points."
 msgstr "Приступај подацима у истом одељку из дељених сидришних тачака"
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy, no-c-format
 #| msgid "Show column numbers in diagnostics, when available.  Default on"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Приказуј бројеве колона у дијагностици, ако су доступни.  Подразумевано укључено."
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Искључи оптимизације приметне при ИЕЕЕ издавању НаНа"
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, fuzzy, no-c-format
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "Претвори константе у покретном зарезу у једноструку прецизност"
 
-#: common.opt:2571
+#: common.opt:2575
 #, fuzzy, no-c-format
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Подели времена живота индукционих променљивих када се петље одмотавају"
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy, no-c-format
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "Стварај оквире стека сагласне са АПЦСом"
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy, no-c-format
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Примени ширење променљивих када се петље одмотавају"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Уметни кôд за проверу стека у програм"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Уметни кôд за проверу стека у програм"
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy, no-c-format
 #| msgid "Trap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "Хватај ако стек прође поред <register>"
 
-#: common.opt:2623
+#: common.opt:2627
 #, fuzzy, no-c-format
 #| msgid "Trap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "Хватај ако стек прође поред симбола <name>"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy, no-c-format
 #| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "Користи propolice као метод заштите стека"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "Користи метод заштите стека за сваку функцију"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Користи метод заштите стека за сваку функцију"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Користи метод заштите стека за сваку функцију"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy, no-c-format
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "Поново користи r30 од функције до функције"
 
-#: common.opt:2655
+#: common.opt:2659
 #, fuzzy, no-c-format
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "Претпостави правила строге дволичности"
 
-#: common.opt:2659
+#: common.opt:2663
 #, fuzzy, no-c-format
 #| msgid "Treat signed overflow as undefined"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Сматрај означено преливање за недефинисано"
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, fuzzy, no-c-format
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "Провери синтаксне грешке, па стани"
 
-#: common.opt:2671
+#: common.opt:2675
 #, fuzzy, no-c-format
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "Створи датотеке потребне за „gcov“"
 
-#: common.opt:2675
+#: common.opt:2679
 #, fuzzy, no-c-format
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "Изврши оптимизације плетења скокова"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy, no-c-format
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "Извести о времену потрошеном у сваком компилаторском пролазу"
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, fuzzy, no-c-format
 #| msgid "Set the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "Подразумевани модел стварања кôда за нитно-локално складиштење"
 
-#: common.opt:2706
+#: common.opt:2710
 #, fuzzy, no-c-format
 #| msgid "Reorder top level functions, variables, and asms"
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Преуреди редослед функција, променљива и асмова највишег нивоа"
 
-#: common.opt:2710
+#: common.opt:2714
 #, fuzzy, no-c-format
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "Формирај суперблокове преко умножавања репа"
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "Претпостави да операције у покретном зарезу могу да хватају"
 
-#: common.opt:2726
+#: common.opt:2730
 #, fuzzy, no-c-format
 #| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Хватај преливање означених при додавању, одузимању и множењу"
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Укључи ССА-ЦЦП оптимизацију над стаблима"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Укључи ССА-ЦЦП оптимизацију над стаблима"
 
-#: common.opt:2742
+#: common.opt:2746
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "Укључи копирање заглавља петље на стаблима"
 
-#: common.opt:2750
+#: common.opt:2754
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA coalescing of user variables."
 msgstr "Укључи ССА потапање кôда на стаблима"
 
-#: common.opt:2758
+#: common.opt:2762
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "Укључи распростирање копирања на стаблима"
 
-#: common.opt:2766
+#: common.opt:2770
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones."
 msgstr "Претвори условне скокове у условно извршавање"
 
-#: common.opt:2770
+#: common.opt:2774
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Претвори условне скокове у условно извршавање"
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Укључи ССА оптимизацију елиминације мртвог кôда на стаблима"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Укључи доминаторске оптимизације"
 
-#: common.opt:2782
+#: common.opt:2786
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable tail merging on trees."
 msgstr "Укључи копирање заглавља петље на стаблима"
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:2790
+#: common.opt:2794
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation on trees"
 msgid "Enable forward propagation on trees."
 msgstr "Укључи распростирање копирања на стаблима"
 
-#: common.opt:2794
+#: common.opt:2798
 #, fuzzy, no-c-format
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Укључи пуну елиминацију сувишности (ФРЕ) на стаблима"
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable string length optimizations on trees."
 msgstr "Укључи ССА-ЦЦП оптимизацију над стаблима"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop distribution on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2823
+#: common.opt:2827
 #, fuzzy, no-c-format
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "Укључи кретање инваријанти петље на стаблима"
 
-#: common.opt:2831
+#: common.opt:2835
 #, fuzzy, no-c-format
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "Стварај каноничке индукционе променљиве у петљама"
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "Укључи оптимизације петљи на нивоу стабла"
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2843
+#: common.opt:2847
 #, fuzzy, no-c-format
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Укључи условна померања"
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Укључи ССА-ПРЕ оптимизацију на стаблима"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Изврши међупроцедуралну анализу показује-на"
 
-#: common.opt:2859
+#: common.opt:2863
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable reassociation on tree level."
 msgstr "Укључи оптимизације петљи на нивоу стабла"
 
-#: common.opt:2867
+#: common.opt:2871
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "Укључи ССА потапање кôда на стаблима"
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, fuzzy, no-c-format
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "Изврши скаларну замену скупина"
 
-#: common.opt:2879
+#: common.opt:2883
 #, fuzzy, no-c-format
 #| msgid "Replace temporary expressions in the SSA->normal pass"
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Замени привремене изразе у пролазу ССА->нормално"
 
-#: common.opt:2883
+#: common.opt:2887
 #, fuzzy, no-c-format
 #| msgid "Perform live range splitting during the SSA->normal pass"
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Изврши поделу опсега уживо током пролаза ССА->нормално"
 
-#: common.opt:2887
+#: common.opt:2891
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "Изврши распростирање опсега вредности на стаблима"
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "Компилуј целу компилациону јединицу у једном тренутку"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Одмотај петљу када се зна број итерација"
 
-#: common.opt:2908
+#: common.opt:2912
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "Одмотај све петље"
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Дозволи математичке оптимизације које могу прекршити ИЕЕЕ или ИСО стандарде"
 
-#: common.opt:2940
+#: common.opt:2944
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "Изврши одусловљавање петљи"
 
-#: common.opt:2944
+#: common.opt:2948
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "Изврши љушћење петљи"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Само створи табеле одмотавања за руковање изузецима"
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "Изврши праћење променљивих"
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Изврши праћење променљивих"
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:3003
+#: common.opt:3007
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:3015
+#: common.opt:3019
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, fuzzy, no-c-format
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Не ради ништа. Остављено ради сагласности уназад."
 
-#: common.opt:3050
+#: common.opt:3054
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation for stores and loads"
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Укључи распростирање копирања за складиштења и учитавања"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Додај допунске коментаре у испису асемблера"
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "Користи профиле вредности израза у оптимизацијама"
 
-#: common.opt:3111
+#: common.opt:3115
 #, fuzzy, no-c-format
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Конструиши мреже и подели неповезане употребе једне променљиве"
 
-#: common.opt:3115
+#: common.opt:3119
 #, fuzzy, no-c-format
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Укључи ССА оптимизацију елиминације мртвог кôда на стаблима"
 
-#: common.opt:3119
+#: common.opt:3123
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "Изврши оптимизације целог програма"
 
-#: common.opt:3123
+#: common.opt:3127
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "Претпостави да се преливање означене аритметике омотава"
 
-#: common.opt:3127
+#: common.opt:3131
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Претпостави да се преливање означене аритметике омотава"
 
-#: common.opt:3131
+#: common.opt:3135
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "Стави податке успостављене на нулу у одељак bss"
 
-#: common.opt:3135
+#: common.opt:3139
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Clear call-used registers upon function return."
 msgstr "Сачувавај регистре око позива функција"
 
-#: common.opt:3139
+#: common.opt:3143
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:3175
+#: common.opt:3179
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Стварај исправљачке информације у формату ДВАРФа 2"
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "Стварај исправљачке информације у подразумеваном проширеном формату"
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Створи јединствену излазну тачку за сваку функцију"
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:3223
+#: common.opt:3227
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "Стварај исправљачке информације у формату СТАБСа"
 
-#: common.opt:3227
+#: common.opt:3231
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Стварај исправљачке информације у проширеном формату СТАБСа"
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "Стварај исправљачке информације у формату ВМСа"
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "Стварај исправљачке информације у формату ВМСа"
 
-#: common.opt:3258
+#: common.opt:3262
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "Стварај исправљачке информације у формату ИксКОФФа"
 
-#: common.opt:3262
+#: common.opt:3266
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Стварај исправљачке информације у проширеном формату ИксКОФФа"
 
-#: common.opt:3280
+#: common.opt:3284
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "Стварај инструкције isel"
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3291
+#: common.opt:3295
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-imultilib <дир> Постави <дир> као поддиректоријум укључивања за вишебиба"
 
-#: common.opt:3295
+#: common.opt:3299
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <дир> Постави <дир> као поддиректоријум укључивања за вишебиба"
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "Стави излаз у <file>"
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "Укључи профилисање функција"
 
-#: common.opt:3334
+#: common.opt:3338
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "Као -pedantic али их издај као грешке"
 
-#: common.opt:3374
+#: common.opt:3378
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Не приказуј компиловане функције или протекло време"
 
-#: common.opt:3406
+#: common.opt:3410
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Укључи опширан излаз"
 
-#: common.opt:3410
+#: common.opt:3414
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Прикажи верзију компилатора"
 
-#: common.opt:3414
+#: common.opt:3418
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Сузбиј упозорења"
 
-#: common.opt:3424
+#: common.opt:3428
 #, fuzzy, no-c-format
 #| msgid "Enable ID based shared library"
 msgid "Create a shared library."
 msgstr "Укључи дељене библиотеке на основу ИДа"
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -21308,1208 +21309,1218 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload"
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "Праг односа броја извршавања критичних потега који дозвољава делимичну елиминацију редунданси после поновљеног учитавања"
 
-#: params.opt:178
+#: params.opt:183
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio for performing partial redundancy elimination after reload"
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "Праг односа за делимичну елиминацију редунданси после поновљеног учитавања"
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, fuzzy, no-c-format
 #| msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap"
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "Најмање ширење хрпе које окида сакупљање смећа, као проценат укупне величине хрпе"
 
-#: params.opt:194
+#: params.opt:199
 #, fuzzy, no-c-format
 #| msgid "Minimum heap size before we start collecting garbage, in kilobytes"
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "Најмања величина хрпе пре покретања сакупљања смећа, у килобајтима"
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "Maximum number of arrays per SCoP."
 msgstr "Највећи број грешака за пријављивање"
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 #| msgid "maximum value of parameter %qs is %u"
 msgid "Maximum number of parameters in a SCoP."
 msgstr "највећа вредност параметра %qs је %u"
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal count of repetitions of basic block in program given basic block needs to have to be considered hot"
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "Део највећег броја понављања основног блока у програму које дати основни блок мора да има да би био сматран врућим"
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot"
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "Део највеће учестаности извршавања основног блока у функцији које дати основни блок мора да има да би био сматран врућим"
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, fuzzy, no-c-format
 #| msgid "how much can given compilation unit grow because of the inlining (in percent)"
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "колико дата јединица компиловања може расти услед уткивања (у процентима)"
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 #| msgid "The upper bound for sharing integer constants"
 msgid "The upper bound for sharing integer constants."
 msgstr "Горња граница за дељење целобројних константи"
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "Највећа дубина рекурзивног уткивања за уткане функције"
 
-#: params.opt:258
+#: params.opt:263
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Уткивај рекурзивно само када вероватноћа извршавања позива премашује параметар"
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, fuzzy, no-c-format
 #| msgid "how much can given compilation unit grow because of the inlining (in percent)"
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "колико дата јединица компиловања може расти услед уткивања (у процентима)"
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "Величина преводилачке јединице која се сматра великом"
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr ""
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr ""
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr ""
 
-#: params.opt:326
+#: params.opt:331
 #, fuzzy, no-c-format
 #| msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization"
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "Ако је број кандидата у скупу мањи, увек покушавамо да уклонимо неискоришћене нп. током оптимизације"
 
-#: params.opt:330
+#: params.opt:335
 #, fuzzy, no-c-format
 #| msgid "Bound on number of candidates below that all candidates are considered in iv optimizations"
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "Граница броја кандидата испод које се сви кандидати разматрају у нп. оптимизацијама"
 
-#: params.opt:334
+#: params.opt:339
 #, fuzzy, no-c-format
 #| msgid "Bound on number of iv uses in loop optimized in iv optimizations"
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "Граница броја употреба нп. у нп. оптимизацији петљи"
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr ""
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr ""
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr ""
 
-#: params.opt:358
+#: params.opt:363
 #, fuzzy, no-c-format
 #| msgid "Maximal growth due to inlining of large function (in percent)"
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Највећи раст услед уткивања велике функције (у процентима)"
 
-#: params.opt:362
+#: params.opt:367
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of function body to be considered large."
 msgstr "Величина тела функције која се сматра великом"
 
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of stack frame to be considered large."
 msgstr "Величина тела функције која се сматра великом"
 
-#: params.opt:370
+#: params.opt:375
 #, fuzzy, no-c-format
 #| msgid "Maximal growth due to inlining of large function (in percent)"
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Највећи раст услед уткивања велике функције (у процентима)"
 
-#: params.opt:374
+#: params.opt:379
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit to be considered large."
 msgstr "Величина преводилачке јединице која се сматра великом"
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, fuzzy, no-c-format
 #| msgid "The minimum cost of an expensive expression in the loop invariant motion"
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "Најмања цена скупог израза у кретању инваријанте петље"
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "Највећи број инструкција за разматрање при одмотавању петље, у просеку"
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr ""
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "Највећи број инструкција у једној функцији подесној за уткивање"
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "Највећи број инструкција за разматрање при одмотавању петље"
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "Највећи број инструкција за разматрање при одмотавању петље, у просеку"
 
-#: params.opt:446
+#: params.opt:451
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of insns combine tries to combine."
 msgstr "Највећи број долазећих потега за разматрање унакрсног скакања"
 
-#: params.opt:450
+#: params.opt:455
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "Највећи број ија потпуно сљушћене петље"
 
-#: params.opt:454
+#: params.opt:459
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop that is peeled completely"
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Највећи број љушћења једне петље која се потпуно љушти"
 
-#: params.opt:458
+#: params.opt:463
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "Највећи број ија потпуно сљушћене петље"
 
-#: params.opt:462
+#: params.opt:467
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "Највећи број долазећих потега за разматрање унакрсног скакања"
 
-#: params.opt:466
+#: params.opt:471
 #, fuzzy, no-c-format
 #| msgid "The maximum instructions CSE process before flushing"
 msgid "The maximum instructions CSE process before flushing."
 msgstr "Највише инструкција у процесу ЦСЕа пре испирања"
 
-#: params.opt:470
+#: params.opt:475
 #, fuzzy, no-c-format
 #| msgid "The maximum length of path considered in cse"
 msgid "The maximum length of path considered in cse."
 msgstr "Највећа дужина путање које се разматра у ЦСЕу"
 
-#: params.opt:474
+#: params.opt:479
 #, fuzzy, no-c-format
 #| msgid "The maximum memory locations recorded by cselib"
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Највећи број меморијских локација које снима cselib"
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to fill a delay slot"
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "Највећи број инструкција за разматрање при попуњавању жлеба застоја"
 
-#: params.opt:486
+#: params.opt:491
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to find accurate live register information"
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "Највећи број инструкција за разматрање при тражењу прецизних података о живим регистрима"
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "Највећи број инструкција у једној функцији подесној за уткивање"
 
-#: params.opt:498
+#: params.opt:503
 #, fuzzy, no-c-format
 #| msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable"
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "Највећи број поља у структури пре него што анализа показивача сматра структуру као једну променљиву"
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr ""
 
-#: params.opt:514
+#: params.opt:519
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "Највећи број инструкција за разматрање при одмотавању петље"
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE"
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "Највећа количина меморије коју ГЦСЕ може да резервише"
 
-#: params.opt:522
+#: params.opt:527
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns to duplicate when unfactoring computed gotos"
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "Највећи број ија за умножавање при дефакторисању рачунске goto"
 
-#: params.opt:526
+#: params.opt:531
 #, fuzzy, no-c-format
 #| msgid "The maximum expansion factor when copying basic blocks"
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "Највећи фактор ширења при копирању основних блокова"
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "Највећи број инструкција при аутоматском уткивању"
 
-#: params.opt:538
+#: params.opt:543
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "Највећи број инструкција до којег уткана функција може нарасти путем рекурзивног уткивања"
 
-#: params.opt:542
+#: params.opt:547
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions non-inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "Највећи број инструкција до којег неуткана функција може нарасти путем рекурзивног уткивања"
 
-#: params.opt:546
+#: params.opt:551
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "Највећи број инструкција у једној функцији подесној за уткивање"
 
-#: params.opt:550
+#: params.opt:555
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when inlining for size."
 msgstr "Највећи број инструкција при аутоматском уткивању"
 
-#: params.opt:554
+#: params.opt:559
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "Највећи број инструкција при аутоматском уткивању"
 
-#: params.opt:558
+#: params.opt:563
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "Највећа дубина рекурзивног уткивања за уткане функције"
 
-#: params.opt:562
+#: params.opt:567
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for non-inline functions"
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "Највећа дубина рекурзивног уткивања за неуткане функције"
 
-#: params.opt:566
+#: params.opt:571
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of an unswitched loop"
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Највећи број ија непребачене петље"
 
-#: params.opt:570
+#: params.opt:575
 #, fuzzy, no-c-format
 #| msgid "Bound on the cost of an expression to compute the number of iterations"
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "Ограничење цене израза за израчунавање броја итерација"
 
-#: params.opt:574
+#: params.opt:579
 #, fuzzy, no-c-format
 #| msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates"
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "Граница броја итерација које срачунава алгоритам за анализу броја итерација сировом силом"
 
-#: params.opt:578
+#: params.opt:583
 #, fuzzy, no-c-format
 #| msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps"
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "Највећи број наредби дозвољен у блоку којем је потребно умножавање при уплитању скокова"
 
-#: params.opt:582
+#: params.opt:587
 #, fuzzy, no-c-format
 #| msgid "The maximum number of RTL nodes that can be recorded as combiner's last value"
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "Највећи број РТЛ чворова који се може снимити као последња вредност комбинатора"
 
-#: params.opt:586
+#: params.opt:591
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns to duplicate when unfactoring computed gotos"
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "Највећи број ија за умножавање при дефакторисању рачунске goto"
 
-#: params.opt:590
+#: params.opt:595
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "Највећи број инструкција за разматрање при одмотавању петље"
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, fuzzy, no-c-format
 #| msgid "The maximum number of iterations through CFG to extend regions"
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "Највећи број итерација кроз ЦФГ за проширивање области"
 
-#: params.opt:602
+#: params.opt:607
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop"
 msgid "The maximum number of peelings of a single loop."
 msgstr "Највећи број љушћења једне петље"
 
-#: params.opt:606
+#: params.opt:611
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a peeled loop"
 msgid "The maximum number of insns of a peeled loop."
 msgstr "Највећи број ија сљушћене петље"
 
-#: params.opt:610
+#: params.opt:615
 #, fuzzy, no-c-format
 #| msgid "The maximum length of scheduling's pending operations list"
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "Највећа дужина листе наступајућих операција у распоређивању"
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, fuzzy, no-c-format
 #| msgid "The maximum number of blocks in a region to be considered for interblock scheduling"
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "Највећи број блокова у области која се разматра за мећублоковско распоређивање"
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "Највећи број ија у области која се разматра за мећублоковско распоређивање"
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically"
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "Највећи број итерација петље које предвиђамо статички"
 
-#: params.opt:630
+#: params.opt:635
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to search backward when looking for equivalent reload"
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "Највећи број инструкција које треба претражити уназад када се тражи еквивалентно поновљено учитавање"
 
-#: params.opt:634
+#: params.opt:639
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Највећи број ија у области која се разматра за мећублоковско распоређивање"
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, fuzzy, no-c-format
 #| msgid "The maximum number of iterations through CFG to extend regions"
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "Највећи број итерација кроз ЦФГ за проширивање области"
 
-#: params.opt:650
+#: params.opt:655
 #, fuzzy, no-c-format
 #| msgid "The maximum conflict delay for an insn to be considered for speculative motion"
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "Највећи број ија у области која се разматра за мећублоковско распоређивање"
 
-#: params.opt:654
+#: params.opt:659
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass"
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "Највећи број инструкција спремних за издавање који распоређивач узима у обзир током првог пролаза"
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr ""
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr ""
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr ""
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unrollings of a single loop"
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Највећи број одмотавања једне петље"
 
-#: params.opt:714
+#: params.opt:719
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "Највећи број инструкција за разматрање при одмотавању петље"
 
-#: params.opt:718
+#: params.opt:723
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of an unswitched loop"
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "Највећи број ија непребачене петље"
 
-#: params.opt:722
+#: params.opt:727
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unswitchings in a single loop"
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Највећи број непребацивања у једној петљи"
 
-#: params.opt:726
+#: params.opt:731
 #, fuzzy, no-c-format
 #| msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling"
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "Ако се користи -fvariable-expansion-in-unroller, највећи број пута који ће поједина променљива бити раширена током одмотавања петље"
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, fuzzy, no-c-format
 #| msgid "The minimum number of matching instructions to consider for crossjumping"
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "Најмањи број поклапајућих инструкција за разматрање унакрсног скакања"
 
-#: params.opt:754
+#: params.opt:759
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Уткивај рекурзивно само када вероватноћа извршавања позива премашује параметар"
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, fuzzy, no-c-format
 #| msgid "The minimum probability of reaching a source block for interblock speculative scheduling"
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "Најмања вероватноћа достизања изворног блока за међублоковско спекулативно распоређивање"
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr ""
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Највећи број инструкција за разматрање при одмотавању петље"
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr ""
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr ""
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr ""
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr ""
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, fuzzy, no-c-format
 #| msgid "Bound on size of expressions used in the scalar evolutions analyzer"
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "Граница величине израза који се користе у анализатору скаларних еволуција"
 
-#: params.opt:852
+#: params.opt:870
 #, fuzzy, no-c-format
 #| msgid "Bound on size of expressions used in the scalar evolutions analyzer"
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "Граница величине израза који се користе у анализатору скаларних еволуција"
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "Најмања вероватноћа успеха спекулације (у процентима), при којој ће се распоређивати спекулативне ије."
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "Највећи број инструкција у једној функцији подесној за уткивање"
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, fuzzy, no-c-format
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "Број ија у реду које се могу прерано распоређивати"
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr ""
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, fuzzy, no-c-format
 #| msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA"
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "Број циклуса које окретни модуло-распоређивач разматра при провери сукоба ДФАом"
 
-#: params.opt:900
+#: params.opt:918
 #, fuzzy, no-c-format
 #| msgid "A threshold on the average loop count considered by the swing modulo scheduler"
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "Праг за просечан број петљи који окретни модуло-распоређивач разматра"
 
-#: params.opt:904
+#: params.opt:922
 #, fuzzy, no-c-format
 #| msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop"
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "Фактор за штеловање горње границе коју окретни модуло-распоређивач користи за распоређивање петље"
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 #| msgid "The maximum number of passes to make when doing GCSE"
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "Највећи број пролаза при извршавању ГЦСЕа"
 
-#: params.opt:928
+#: params.opt:946
 #, fuzzy, no-c-format
 #| msgid "The lower bound for a buffer to be considered for stack smashing protection"
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "Доња граница за бафер да би се размотрила заштита разбијања стека"
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr ""
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "Највећи број грешака за пријављивање"
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "Maximum number of references stored in each modref base."
 msgstr "Највећи број грешака за пријављивање"
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr ""
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 #| msgid "Maximum number of errors to report"
 msgid "Maximum number of tests performed by modref query."
 msgstr "Највећи број грешака за пријављивање"
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr ""
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "Проценат функције, одмерен учестаношћу извршавања, који мора бити покривен формирањем трага. Користи се кад није доступан одзивни профил"
 
-#: params.opt:984
+#: params.opt:1002
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "Проценат функције, одмерен учестаношћу извршавања, који мора бити покривен формирањем трага. Користи се кад је доступан одзивни профил"
 
-#: params.opt:988
+#: params.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Maximal code growth caused by tail duplication (in percent)"
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Највећи раст кôда услед умножавања репа (у процентима)"
 
-#: params.opt:992
+#: params.opt:1010
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "Заустави чеони раст ако је вероватноћа најбољег потега мања од овог прага (у процентима). Користи се када није доступан одзивни профил"
 
-#: params.opt:996
+#: params.opt:1014
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "Заустави чеони раст ако је вероватноћа најбољег потега мања од овог прага (у процентима). Користи се када је доступан одзивни профил"
 
-#: params.opt:1000
+#: params.opt:1018
 #, fuzzy, no-c-format
 #| msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)"
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "Заустави повратни раст ако је повратна вероватноћа најбољег потега мања од овог прага (у процентима)"
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 #| msgid "Emit implicit instantiations of templates"
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "Емитуј имплицитна извођења шаблона"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "Користи потпрограме за прологе и епилоге функција"
 
-#: params.opt:1024
+#: params.opt:1042
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "Користи потпрограме за прологе и епилоге функција"
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr ""
 
-#: params.opt:1056
+#: params.opt:1074
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, fuzzy, no-c-format
 #| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning"
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "Граница броја провера током извршавања које умеће векторизаторово верзионисање петљи"
 
-#: params.opt:1068
+#: params.opt:1086
 #, fuzzy, no-c-format
 #| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning"
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Граница броја провера током извршавања које умеће векторизаторово верзионисање петљи"
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -22550,7 +22561,7 @@ msgid "expected boolean type"
 msgstr "Очекиван је тип израза"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -22637,7 +22648,7 @@ msgstr "без аргумената"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments"
@@ -23093,7 +23104,7 @@ msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -23155,7 +23166,7 @@ msgstr "атрибути типа игноришу се пошто је тип 
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -23184,20 +23195,20 @@ msgstr "атрибути типа игноришу се пошто је тип 
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -23208,8 +23219,8 @@ msgstr "атрибут %qE се игнорише"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -23221,50 +23232,50 @@ msgstr "претходна декларација %q+D"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D већ декларисано са атрибутом dllexport: dllimport се игнорише"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D поново декларисано без атрибута dllimport пошто је на њ упућено ДЛЛ повезивошћу"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D поново декларисано без атрибута dllimport: претходно dllimport се игнорише"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared as  dllimport: attribute ignored"
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "уткана функција %q+D поново декларисана као dllimport: атрибут се игнорише"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "дефиниција функције %q+D означена као dllimport"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "дефиниција променљиве %q+D означена као dllimport"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, fuzzy, gcc-internal-format
 #| msgid "external linkage required for symbol %q+D because of %qs attribute"
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "спољашња повезивост неопходна за симбол %q+D због атрибута %qs"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, fuzzy, gcc-internal-format
 #| msgid "%qD redeclared with different visibility"
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qD поново декларисано са другачијом видљивошћу"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
@@ -23273,13 +23284,13 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD target declared here"
 msgstr "%q+D декларисано овде"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -23388,7 +23399,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr "померај ван граница константне ниске"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -23414,424 +23425,424 @@ msgstr "трећи аргумент за %<__builtin_prefetch%> мора бит
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "неисправан трећи аргумент за %<__builtin_prefetch%>; користим нулу"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "source object declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 #| msgid "class definition may not be declared a friend"
 msgid "destination object declared here"
 msgstr "дефиниција класе не може бити декларисана пријатељем"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, gcc-internal-format
 msgid "destination object allocated here"
 msgstr ""
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
@@ -23840,7 +23851,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
@@ -23849,83 +23860,83 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid argument to %qD"
 msgstr "неисправан аргумент типа за %qs"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported argument to %qD"
@@ -23933,98 +23944,98 @@ msgstr "неподржана комбинација: %s"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 #| msgid "-mstackrealign ignored for nested functions"
 msgid "trampoline generated for nested function %qD"
 msgstr "-mstackrealign се игнорише за угњеждене функције"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid memory model argument to builtin"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 1 to %qs"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "non-integer argument 1 to %qs"
 msgstr "недостаје аргумент за „%s“"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "%qs only supported in OpenACC code"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 0 to %qs"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "illegal argument 0 to %qs"
@@ -24032,7 +24043,7 @@ msgstr "недостаје аргумент за „%s“"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
@@ -24040,123 +24051,123 @@ msgstr "неисправан аргумент за %<__builtin_frame_address%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "неисправан аргумент за %<__builtin_frame_address%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> други аргумент мора бити 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "циљни формат не подржава бесконачност"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> употребљено у функцији са фиксним аргументима"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> позвано без аргумената"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "други параметар за %<va_start%> није последњи именовани аргумент"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Hпоследњи аргумент за %D није целобројна константа између 0 и 3"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
 msgstr "%q+D декларисано овде"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, gcc-internal-format
 msgid "returned from %qD"
 msgstr ""
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, gcc-internal-format
 msgid "returned from %qT"
 msgstr ""
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, gcc-internal-format
 msgid "obtained here"
 msgstr ""
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "assignment"
 msgid "assigned here"
 msgstr "додела"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -24976,313 +24987,313 @@ msgstr "основни блокови нису положени надовезу
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "број об. белешки у ланцу ија (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "број ивица позивача је негативан"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "missing direct call for speculation %i"
 msgstr "Недостаје одредница димензија код %C"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use control speculation"
 msgid "missing ref for speculation %i"
 msgstr "Направи спекулацију контроле"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "помоћно поље постављено за ивицу %s->%s"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "елемент успостављача није константан"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Претпостави да симболи могу бити неважећи"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "помоћно поље постављено за ивицу %s->%s"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "PIC code generation is not compatible with fast indirect calls"
 msgid "edge count is not compatible with function count"
 msgstr "стварање ПИЦ кôда није сагласно са брзим посредним позивима"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "показивач inlined_to је погрешан"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "вишеструки уткани позивачи"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "показивач inlined_to постављен за неуткане позиваче"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "caller edge count does not match BB count"
 msgstr "долазна ивица се не поклапа са бројем ПХИ аргумената"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "indirect call count does not match BB count"
 msgstr "долазна ивица се не поклапа са бројем ПХИ аргумената"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "показивач inlined_to постављен али нема претходника"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "показивач inlined_to упућује на самог себе"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "дељени call_stmt:"
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "ивица показује на погрешну декларацију:"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "недостаје графпоз ивица за call_stmt:"
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "очекивана је наредба"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ивица %s->%s нема одговарајући call_stmt"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ивица %s->%s нема одговарајући call_stmt"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node није успело"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s.%d is missing"
@@ -25376,12 +25387,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "атрибут %qE се игнорише јер је %qT већ дефинисан"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F употребљено али недефинисано"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
@@ -25461,7 +25472,7 @@ msgstr "величина повратне вредности %q+D је %u бај
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "величина повратне вредности %q+D је већа од %wd бајтова"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, fuzzy, gcc-internal-format
 #| msgid "nodes with no released memory found"
 msgid "nodes with unreleased memory found"
@@ -25902,12 +25913,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -25927,7 +25938,7 @@ msgstr "дељено rtx"
 msgid "internal consistency failure"
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ИЦЕ: emit_insn употребљено где је потребно emit_jump_insn:\n"
@@ -26071,44 +26082,44 @@ msgstr "нисам могао да отворим датотеку пописа
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "велики целобројни имплицитно подсечен на неозначени тип"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "поређење је увек %d услед ширине битског поља"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању пробе опсега"
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "поређење је увек %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> непоклопљених тестова неједнакости је увек 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> међусобно искључивих тестова једнакости је увек 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when negating a division"
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "претпостављам да се означено преливање не дешава при негирању дељења"
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when negating a division"
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "претпостављам да се означено преливање не дешава при негирању дељења"
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "провера сажимања: првобитно дрво измењено сажимањем"
@@ -26125,7 +26136,7 @@ msgstr "укупна величина локалних променљивих п
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "укупна величина локалних променљивих премашује ограничење архитектуре"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "немогуће ограничење у %<asm%>"
@@ -26813,7 +26824,7 @@ msgstr "Одредба мора бити упућивач"
 msgid "function may return address of local variable"
 msgstr "функција враћа адресу на локалну променљиву"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "функција враћа адресу на локалну променљиву"
@@ -27204,57 +27215,57 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "%s у форматирајућој ниски код %C"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 msgid "%Guse of %<alloca%>"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 msgid "%Gargument to variable-length array may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 #| msgid "size of variable %q+D is too large"
 msgid "%Gargument to variable-length array is too large"
 msgstr "величина променљиве %q+D је превелика"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 #| msgid "value passed to %<-m%s%> is too large"
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "вредност прослеђена уз %<-m%s%> превелика"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 msgid "%Gunbounded use of variable-length array"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 msgid "%Gunbounded use of %<alloca%>"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 msgid "%Gargument to variable-length array is zero"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 #| msgid "Second argument of MOD at %L is zero"
 msgid "%Gargument to %<alloca%> is zero"
@@ -27392,7 +27403,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "array %qD declared here"
@@ -27419,11 +27430,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -27507,333 +27518,333 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-memory input %d must stay in memory"
 msgid "non-memory output %d must stay in memory"
 msgstr "немеморијски улаз %d мора остати у меморији"
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "немеморијски улаз %d мора остати у меморији"
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "меморијски улаз %d не може се непосредно адресирати"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr ""
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing region"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variables not supported in this target"
 msgid "threadprivate variable %qE used in target region"
 msgstr "нитно-локалне променљиве нису подржане за овај циљ"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing target region"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variables not supported in this target"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "нитно-локалне променљиве нису подржане за овај циљ"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing task"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "грешка при затварању %s: %m"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%H%qE недекларисано (прва употреба у овој функцији)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing %<target%>"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%Hнеозначена променљива итерације %qE"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should be private"
 msgstr "требало би да променљива итерације %qs буде приватна"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be linear"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<lastprivate%>"
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "неисправна декларација шаблона %qD"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "уређена област мора бити блиско угњеждена унутар петље са одредбом уређености"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "гимплификација није успела"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT се унапређује у %qT при прослеђивању кроз %<...%>"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(стога би требало да проследите %qT уместо %qT за %<va_arg%>)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "ако се овај кôд досегне, програм ће се прекинути"
@@ -28314,24 +28325,24 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s се не може користити овде у асемблеру"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "as %qD"
 msgid "for %qD"
 msgstr "као %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "величина оквира превелика за поуздану проверу стека"
@@ -28352,12 +28363,12 @@ msgstr "операнд у %<asm%> има немогућа ограничења"
 msgid "unable to find a register to spill"
 msgstr "не могу да нађем регистар за просипање у класи %qs"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "неусаглашена ограничења операнда у %<asm%>"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
@@ -29120,13 +29131,13 @@ msgstr "-mregparm=%d није између 0 и %d"
 msgid "unrecognized argument in option %qs"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s"
@@ -29263,7 +29274,7 @@ msgstr ""
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
@@ -29811,25 +29822,25 @@ msgstr "имплицитно подигнути регистри морају б
 msgid "output operand %d must use %<&%> constraint"
 msgstr "излазни операнд %d мора користити ограничење %<&%>"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "validate_value_data: [%u] Лош next_regno за празан ланац (%u)"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: Loop in regno chain (%u)"
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "validate_value_data: Петља у regno ланцу (%u)"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "validate_value_data: [%u] Лош oldest_regno (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
@@ -29898,13 +29909,13 @@ msgstr "не може се поново учитати целобројни ко
 msgid "impossible register constraint in %<asm%>"
 msgstr "немогуће регистарско ограничење у %<asm%>"
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "овај циљ не подржава %qs"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "%<&%> ограничење употребљено без регистарске класе"
@@ -29935,54 +29946,54 @@ msgstr "ограничење операнда у %<asm%> несагласно с
 msgid "output operand is constant in %<asm%>"
 msgstr "излазни операнд је константан у %<asm%>"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "РТЛ провера: приступ елта %d у „%s“ последњим елтом %d у %s, код %s:%d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "РТЛ провера: очекивах је елт %d типа „%c“, добих „%c“ (rtx %s) у %s, код %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "РТЛ провера: очекивах је елт %d типа „%c“ или „%c“, добих „%c“ (rtx %s) у %s, код %s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "РТЛ провера: очекивах кôд „%s“, добих „%s“ у %s, код %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "РТЛ провера: очекивах кôд „%s“ или „%s“, добих „%s“ у %s, код %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "РТЛ провера: очекивах кôд „%s“ или „%s“, добих „%s“ у %s, код %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "РТЛ провера: покушај узимања не-блоковског симбола као блоковског у %s, код %s:%d"
 
-#: rtl.c:937
+#: rtl.c:947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "РТЛ провера: приступ елта %d вектора последњим елтом %d у %s, код %s:%d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "РТЛ провера: приступ елта %d вектора последњим елтом %d у %s, код %s:%d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "РТЛ провера заставице: %s употребљена са неочекиваним rtx кодом „%s“ у „%s“, код %s:%d"
@@ -30027,23 +30038,23 @@ msgstr "поклапајуће ограничење упућује на неис
 msgid "invalid punctuation %qc in constraint"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "поклапајуће ограничење не дозвољава регистар"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate asm operand name %qs"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "удвостручено име asm операнда %qs"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "недостаје затворена витичаста заграда за именовани операнд"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "недефинисани именовани операнд %qs"
@@ -30784,9 +30795,9 @@ msgstr "неисправан операнд за %%R"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 #| msgid "%s:profile mismatch for '%s'\n"
 msgid "type mismatch in %qs"
@@ -30827,7 +30838,7 @@ msgstr "неисправни операнди за бинарно %s"
 msgid "invalid clique in %qs"
 msgstr "неисправна употреба %qD"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
@@ -31059,404 +31070,404 @@ msgstr "неисправан операнд у инструкцији"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid mask type in %qs"
 msgstr "неисправан апстрактни тип за %q+D"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "'&' not allowed by itself in line %d"
 msgid "not allowed type combination in %qs"
 msgstr "‘&’ не може бити само у линији %d"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "invalid position or size in %qs"
 msgstr "неисправан аргумент опције %qs"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number `%s'"
 msgid "non-trivial conversion in %qs"
 msgstr "неисправан број верзије ‘%s’"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "Missing return statement"
 msgid "%qs LHS in clobber statement"
 msgstr "Недостаје наредба повратка"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s"
 msgid "invalid operand in %qs"
 msgstr "неисправни операнди за бинарно %s"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for %q+D"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "неисправно име регистра за %q+D"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect number of vector %qs elements"
 msgstr "нетачно дељење чворова стабла"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, fuzzy, gcc-internal-format
 #| msgid "PHI def is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "ПХИ дефиниција није ГИМПЛЕ вредност"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR са увек нетачним условом"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in return statement"
 msgstr "неисправан операнд у инструкцији"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "invalid conversion in return statement"
 msgstr "Неисправна успостављачка наредба"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "goto destination is neither a label nor a pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to switch statement"
 msgstr "неисправан операнд за %%s кôд"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code for huge switch statements"
 msgid "non-integral type switch statement"
 msgstr "Створи кôд за огромне наредбе прекидача"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "%<default%> label not within a switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "етикета %<default%> није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "invalid case label in switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "invalid case range in switch statement"
 msgstr "Неисправна успостављачка наредба"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "имена параметара (без типова) у декларацији функције"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, fuzzy, gcc-internal-format
 #| msgid "format string has invalid operand number"
 msgid "incorrect setting of landing pad number"
 msgstr "форматирајућа ниска има неисправан број операнада"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%p code"
 msgid "invalid comparison code in gimple cond"
 msgstr "неисправан операнд за %%p кôд"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid labels in gimple cond"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%j code"
 msgid "invalid %<PHI%> result"
 msgstr "неисправан %%j кôд"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid IACC argument"
 msgid "invalid %<PHI%> argument"
 msgstr "неодговарајући аргумент за IACC"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "несагласни типови у додели"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_stmts није успело"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "local declaration from a different function"
 msgstr "декларација %qF баца различите изузетке"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, fuzzy, gcc-internal-format
 #| msgid "bb_for_stmt (phi) is set to a wrong basic block"
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "bb_for_stmt (phi) постављено на погрешан основни блок"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, fuzzy, gcc-internal-format
 #| msgid "from this location"
 msgid "PHI node with location"
 msgstr "на овој локацији"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "нетачно дељење чворова стабла"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "bb_for_stmt (stmt) is set to a wrong basic block"
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "bb_for_stmt (stmt) постављено на погрешан основни блок"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "наредба означена за бацање, али не чини то"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "наредба означена за бацање усред блока"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "verify_gimple failed"
 msgstr "verify_stmts није успело"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY_BLOCK has a statement list associated with it"
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK има придружену листу наредби"
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, fuzzy, gcc-internal-format
 #| msgid "EXIT_BLOCK has a statement list associated with it"
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK има придружену листу наредби"
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "пропад до излаза из об. %d"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "нелокална етикета "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "етикета "
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "контролни ток усред основног блока %d"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "пропадна ивица после контролне наредбе у об. %d"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "true/false edge after a non-COND_EXPR in bb %d"
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "ивица тачно/нетачно после не-COND_EXPR у об. %d"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "погрешне заставице излазне ивице на крају об. %d"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "експлицитно goto на крају об. %d"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "повратна ивица не показује на излаз у об. %d"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, fuzzy, gcc-internal-format
 #| msgid "found default case not at end of case vector"
 msgid "found default case not at the start of case vector"
 msgstr "нађен подразумевани случај који није на крају вектора случаја"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "етикете случајева нису сортиране: "
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "сувишна излазна ивица %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "недостаје ивица %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<noreturn%> function does return"
 msgid "%<noreturn%> function does return"
 msgstr "%H%<noreturn%> функција ипак враћа"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcontrol reaches end of non-void function"
 msgid "control reaches end of non-void function"
 msgstr "%Hконтрола стиже до краја функције непразног типа"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -32626,7 +32637,7 @@ msgstr "нитно-локални COMMON подаци нису имплемен
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "захтевано равнање за %q+D веће је од имплементираног равнања за %wu"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "величина складишта за %q+D није позната"
@@ -32803,7 +32814,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported record layout"
@@ -33490,7 +33501,7 @@ msgstr "атрибут %qE се игнорише за %qE"
 msgid "type was previously declared %qE"
 msgstr "%q+#D претходно декларисано овде"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -33514,7 +33525,7 @@ msgstr "%qD није декларисано у %qD"
 msgid "%qE argument is not a function"
 msgstr "чистачки аргумент није функција"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "deprecated message is not a string"
@@ -33975,12 +33986,12 @@ msgstr "недостаје %<@end%> у контексту имплементац
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "предлажем заграде око израза употребљеног као истинитосна вредност"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "неисправна употреба %<restrict%>"
@@ -34153,13 +34164,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "премало аргумената за функцију %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "превише аргумената за функцију %qE"
@@ -35181,7 +35192,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr "традиционални Ц одбија надовезивање константних ниски"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -35232,7 +35243,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for iteration variable %qE"
@@ -35250,19 +35261,19 @@ msgstr "%Hнеисправан тип променљиве итерације %q
 msgid "%qE is not initialized"
 msgstr "%H%qE није успостављено"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing controlling predicate"
 msgid "missing controlling predicate"
 msgstr "%Hнедостаје контролишући предикат"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid controlling predicate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing increment expression"
 msgid "missing increment expression"
@@ -35273,7 +35284,7 @@ msgstr "%Hнедостаје израз увећања"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid increment expression"
 msgid "invalid increment expression"
@@ -35343,7 +35354,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -35967,8 +35978,8 @@ msgstr ""
 msgid "wrong type argument to %s"
 msgstr "погрешан тип аргумента за abs"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "преливање у константном изразу"
@@ -36503,19 +36514,19 @@ msgstr "премало аргумената за функцију %qs"
 msgid "function %qD used as %<asm%> output"
 msgstr "само-за-читање локација употребљена као %<asm%> излаз"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only location"
 msgid "assignment of read-only location %qE"
 msgstr "додела само-за-читање локацији"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only location"
 msgid "increment of read-only location %qE"
 msgstr "увећање само-за-читање локације"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only location"
 msgid "decrement of read-only location %qE"
@@ -36719,8 +36730,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "comparison between types %qT and %qT"
@@ -36810,38 +36821,38 @@ msgstr[1] "прослеђивање аргумента %d од %qE одбацу
 msgstr[2] "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 msgstr[3] "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "defined here"
 msgstr "%q+D декларисано овде"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] ""
@@ -36849,52 +36860,52 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as %s"
 msgstr "претходна декларација %qs"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr ""
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as a pointer %s"
 msgstr "претходна декларација %qs"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as an ordinary array %s"
 msgstr "претходна декларација %qs"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s declared as a pointer"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr ""
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as an array %s"
 msgstr "претходна декларација %qs"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
@@ -36903,7 +36914,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %q+D with attribute noinline"
 msgid "previously declared as %s with %u variable bound"
@@ -36913,7 +36924,7 @@ msgstr[1] "претходна декларација %q+D са атрибуто
 msgstr[2] "претходна декларација %q+D са атрибутом неуткане"
 msgstr[3] "претходна декларација %q+D са атрибутом неуткане"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
@@ -36922,7 +36933,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
@@ -36931,7 +36942,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
@@ -36940,52 +36951,52 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "претходна декларација %qs"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "previously declared as %s with bound %qs"
 msgstr "претходна декларација %qs"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "argument %u of type %s with mismatched bound"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "add parentheses around %qE to silence this warning"
 msgstr "предложи заграде око + или - унутар помака"
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -37001,7 +37012,7 @@ msgstr "„%s“ није исправна опција предобрађива
 msgid "too many input files"
 msgstr "превише улазних датотека"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -37035,15 +37046,15 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s"
@@ -37212,62 +37223,62 @@ msgstr "-mregparm=%d није између 0 и %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
@@ -37445,91 +37456,91 @@ msgstr ""
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr ""
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> 2.95 vtable-compatability attribute applies only when compiling a kext"
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "%<%s%> атрибут сагласности в-табела са 2.95 примењује се само при компилацији у kext"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> 2.95 vtable-compatability attribute applies only to C++ classes"
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "%<%s%> атрибут сагласности в-табела са 2.95 примењује се само на Ц++ класе"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "visibility attribute not supported in this configuration; ignored"
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "атрибут видљивости није подржан у овој конфигурацији, игноришем"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr ""
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 #| msgid "-pg not supported on this platform"
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "-pg није подржано на овој платформи"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, fuzzy, gcc-internal-format
 #| msgid "-mdynamic-no-pic overrides -fpic or -fPIC"
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "-mdynamic-no-pic потискује -fpic и -fPIC"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD takes one argument only"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, fuzzy, gcc-internal-format
 #| msgid "argument to '-Xlinker' is missing"
 msgid "CFString literal is missing"
 msgstr "недостаје аргумент за ‘-Xlinker’"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "CFString literal expression is not a string constant"
 msgstr "интегрални израз %qE није константа"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr ""
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "embedded NUL in CFString literal"
@@ -37538,7 +37549,7 @@ msgstr "очекивана је дословна ниска"
 #: config/host-darwin.c:65
 #, fuzzy, gcc-internal-format
 #| msgid "couldn't unmap pch_address_space: %m"
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "нисам могао да демапирам pch_address_space: %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -37681,389 +37692,389 @@ msgstr ""
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "смеће на крају #pragma GCC java_exceptions"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new се не може применити на функцијиски тип"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code for the counting ISA extension"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Емитуј кôд за бројачко ИСА проширење"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "неисправна ограничења за операнд"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "неисправна %%h вредност"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "непозната функција навода ‘%s’"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Одредите редослед резервисања регистара"
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s;"
 msgstr "неисправан аргумент типа за %qs"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "неисправна опција показивача нити: -mtp=%s"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "неисправан аргумент за %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to '%s' option"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "опцији „%s“ недостаје аргумент"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-march%>"
 msgstr "Непозната вредност %qs за -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "неисправна опција показивача нити: -mtp=%s"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "Непозната вредност %qs за -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "прекидач -mcpu=%s коси се са -march="
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s не подржава %s"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "лоше формирано %<#pragma init%>"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент алијаса није ниска"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
 msgstr "неподржана комбинација: %s"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%s није подржано за угњеждене функције"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -38133,7 +38144,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "лоша вредност %qs за -mmemory-latency"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -38264,18 +38275,18 @@ msgstr "аргумент атрибута %qs није „ilink1“ или „il
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "аргумент атрибута %qs није „ilink1“ или „ilink2“"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -38731,243 +38742,249 @@ msgstr "циљни ЦПУ не подржава инструкције Тамб
 msgid "target CPU does not support unaligned accesses"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "switch -mcpu=%s conflicts with -march= switch"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "прекидач -mcpu=%s коси се са -march="
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check није сагласно са -mno-apcs-frame"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic и -mapcs-reent нису сагласни"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "Вишеулазни кôд АПЦСа није подржан, игноришем"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "граница величине структура може бити постављена само на %s"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "граница величине структура може бити постављена само на %s"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= је бескорисно без -fpic"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "не могу да користим „%s“ за ПИЦ регистар"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition не ради на овој архитектури"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable и -msdata=%s нису сагласни"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iWMMXt захтева ААПЦС-сагласан АБИ за правилан рад"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iWMMXt АБИ захтева iWMMXt-способан ЦПУ"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard и ВФП"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "атрибут %qE има утицаја само у јавним објектима"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "атрибут %qs је примењив само на функцијске типове"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "не могу да срачунам стварну локацију параметра на стеку"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Неочекиван крај модула"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нема доступних ниских регистара за подизање високих регистара"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -38976,24 +38993,24 @@ msgstr "неисправан тип вектора за атрибут %qE"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "непознато име регистра: %s"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -39085,19 +39102,19 @@ msgstr "-pipe није подржано"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe није подржано"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G и -static су међусобно искључиви"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
@@ -39916,153 +39933,153 @@ msgstr "аргумент за %qs мора бити двобитна неозн
 msgid "parameter to builtin not valid: %s"
 msgstr "Аргумент за -ffpe-trap није исправан: %s"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "помак мора бити непосредни"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "нетачна ија:"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "нетачно дељење чворова стабла"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "нетачна ија:"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -40085,571 +40102,571 @@ msgstr "израз ограничења стека није подржан"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "аргумент алијаса није ниска"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "Атрибут SEQUENCE код %C је већ наведен у наредби TYPE"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "превише аргумената за функцију %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "име регистра није наведено за %q+D"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "равнање се не може навести за %q+D"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= није подржано на 32-битним системима"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s није подржано у овој конфигурацији"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битни режим није укомпилован"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ЦПУ који сте изабрали не подржава скуп инструкција икс86-64"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d није између 0 и %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "-mrtd calling convention not supported in the 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "конвенција позивања -mrtd није подржана у 64-битном режиму"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-fprefetch-loop-arrays није подржано за овај циљ"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "скуп ССЕ инструкција искључен, користим 387 аритметику"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "скуп 387 инструкција искључен, користим ССЕ аритметику"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "игноришем непознату опцију %q.*s у %<-fdump-%s%>"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-fstack-protector није подржано за овај циљ"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибути fastcall и regparm нису сагласни"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибути fastcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -41145,7 +41162,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "%qE attribute requires a string argument"
@@ -42291,61 +42308,61 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "аргумент атрибута %qs није „ilink1“ или „ilink2“"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "%qs function cannot have different interrupt type"
@@ -42902,263 +42919,264 @@ msgstr "Користи регистре r2 и r5"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE је предодређено као %qs за %qs"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 захтева архитектуру ПауерПЦ-64, укључујем"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires a PowerPC64 cpu"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 захтева ЦПУ типа ПауерПЦ-64"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "Емитуј кôд сагласан са ТИјевим алатима"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "%qs unsupported for this ABI"
 msgstr "%s није подржано за угњеждене функције"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power није подржано на 64-битном Дарвину; није сагласно са инсталираним Ц и Ц++ библиотекама"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring није подржано на системима мале крајности"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-fjni није сагласно са -freduced-reflection"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT се помиње као %qs"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "Using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Користим ИЕЕЕ дугачки двоструки проширене тачности"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "Using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Користим ИБМов дугачки двоструки проширене тачности"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s не подржава %s"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "%qs needs a valid base register"
 msgstr "Потребан је позивом продрман циљни регистар"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "нема профилисања 64-битног кôда за овај АБИ"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "употреба %<long double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "употреба логичких типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "употреба %<complex%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "употреба децималних реалних типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "превазиђена употреба %<long%> у алтивек; користите %<int%>"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<long long%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "неисправан апстрактни тип %qT за %qE"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE is not initialized"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%qE није успостављено"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "навод ‘%s’ није исправан"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -43351,7 +43369,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -43426,213 +43444,219 @@ msgstr "%qs је превазиђено"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "template argument %d is invalid"
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "неисправан шаблонски аргумент %d"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "unresolved overload for Altivec builtin %qF"
 msgid "unresolved overloaded builtin"
 msgstr "неразрешено препуњавање за алтивек уграђено %qF"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
 msgid "bad builtin icode"
 msgstr "лош уграђени fcode"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "укупна величина локалних променљивих премашује ограничење архитектуре"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "величина оквира за %qs је "
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs користи динамичко резервисање стека"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Ограничи употребу хардверских инструкција покретног зареза на 32-битне операције"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float нису подржани у комбинацији"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "величина стека мора бити већа од вредности браника стека"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "величина стека не сме бити већа од 64k"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard имплицира коришћење -mstack-size"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -44006,18 +44030,23 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr ""
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "parent subprogram cannot be inlined"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "subprogram %q+F not marked %<Inline%>"
@@ -44095,8 +44124,8 @@ msgstr "атрибут %qs примењује се само на променљ
 msgid "could not read the BRIG file"
 msgstr "нисам могао да нађем датотеку навода %s\n"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "празна вредност није игнорисана а требало би"
@@ -44158,7 +44187,7 @@ msgstr "етикета %q+D дефинисана али неупотребљен
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "тип низа %q+D довршен несагласно са имплицитним успостављањем"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, fuzzy, gcc-internal-format
 #| msgid "original label is here"
 msgid "originally defined here"
@@ -44399,7 +44428,7 @@ msgstr "декларација %q+D заклања претходну не-пр
 msgid "declaration of %qD shadows a parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларација %qD заклања глобалну декларацију"
@@ -44409,7 +44438,7 @@ msgstr "декларација %qD заклања глобалну деклар
 msgid "declaration of %qD shadows a previous local"
 msgstr "декларација %qD заклања претходну локалну"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -44420,233 +44449,233 @@ msgstr "%Jзаклоњена декларација је овде"
 msgid "nested extern declaration of %qD"
 msgstr "угњеждена декларација %qD"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "имплицитна декларација функције %qE"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "имплицитна декларација функције %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qE"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "несагласна имплицитна декларација уграђене функције %qD"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "несагласна имплицитна декларација функције %qD"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function)"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%H%qE недекларисано (прва употреба у овој функцији)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "%H%qE недекларисано (прва употреба у овој функцији)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%H(Each undeclared identifier is reported only once"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Сваки недекларисани идентификатор пријављен је само једном"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "на етикету %qE упућено ван било које функције"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "скок у досег идентификатора са променљиво измењивим типом"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "Missing variable initializer"
 msgid "jump skips variable initialization"
 msgstr "Недостаје успостављач променљиве"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "label %qD defined here"
 msgstr "етикета %q+D дефинисана али неупотребљена"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "скок у наредбени израз"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "Удвостручена декларација етикете %qE"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "удвостручена етикета %qD"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, fuzzy, gcc-internal-format
 #| msgid "%Htraditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "%Hтрадиционалном Ц-у недостаје одвојени именски простор за етикете, те је идентификатор %qE у сукобу"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "switch jumps over variable initialization"
 msgstr "несагласни типови у успостављању"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "switch jumps into statement expression"
 msgstr "скок у наредбени израз"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE defined as wrong kind of tag"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qE дефинисан као погрешна врста ознаке"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "атрибут %qs је примењив само на функцијске типове"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "неименована структура/унија која не дефинише ниједан примерак"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "празна декларација са наводиоцем складишне класе која не редекларише ознаку"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "празна декларација са одредом типа која не редекларише ознаку"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration with type qualifier does not redeclare tag"
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "празна декларација са одредом типа која не редекларише ознаку"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "бескорисно име типа у празној декларацији"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> у празној декларацији у досегу датотеке"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> у празној декларацији у досегу датотеке"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "бескорисан наводилац складишне класе у празној декларацији"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "useless type name in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "бескорисно име типа у празној декларацији"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "бескорисна одредба типа у празној декларацији"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, fuzzy, gcc-internal-format
 #| msgid "useless %<__thread%> in empty declaration"
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "бескорисно %<__thread%> у празној декларацији"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "invalid use of attributes in empty declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "празна декларација"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ИСО Ц 90 не подржава %<static%> или одредбе типа у параметарским деклараторима низова"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ИСО Ц 90 не подржава деклараторе низова %<[*]%>"
@@ -44654,29 +44683,29 @@ msgstr "ИСО Ц 90 не подржава деклараторе низова %
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> није дозвољено другде осим у досегу прототипа функције"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D је обично функција"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "дефиниција типа %qD је успостављена (употребите __typeof__)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "функција %qD је успостављена као променљива"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "параметар %qD је успостављен"
@@ -44685,294 +44714,294 @@ msgstr "параметар %qD је успостављен"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "променљива %qD има успостављач али је непотпуног типа"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %q+D given attribute %qs"
 msgstr "утканој функцији %q+D дат је атрибут noinline"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "неуспостављени константни члан %qD"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD should be initialized"
 msgstr "%q+D ће бити успостављено после"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "успостављач не одређује величину за %q+D"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "недостаје величина низа у %q+D"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "нулта или негативна величина низа %q+D"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "величина складишта за %q+D није константна"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "игноришем наводилац asm за нестатичку локалну променљиву %q+D"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "не могу да ставим објекат са непостојаним пољем у регистар"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "неуспостављена константа %qD"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ИСО Ц забрањује унапредне декларације параметара"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "ширина битског поља %qs није целобројна константа"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "ширина битског поља %qs није целобројна константа"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "негативна ширина у битском пољу %qs"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "нулта ширина за битско поље %qs"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "не може се декларисати битско поље %qD са функцијским типом"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "тип битског поља %qs је проширење ГЦЦа"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "ширина %qs премашује свој тип"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs је уже од вредности свог типа"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ИСО Ц 90 забрањује низ %qs чија се величина не може израчунати"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ИСО Ц 90 забрањује низ %qs чија се величина не може израчунати"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ИСО Ц 90 забрањује низ променљиве величине %qs"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array"
 msgstr "ИСО Ц 90 забрањује низ променљиве величине %qs"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified %qE at file scope"
 msgstr "променљиво измењиво %qs у досегу датотеке"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified field at file scope"
 msgstr "променљиво измењиво %qs у досегу датотеке"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "тип спада на %<int%> у декларацији %qs"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in type name"
 msgstr "тип спада на %<int%> у декларацији %qs"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "удвостручено %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "удвостручено %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "удвостручено %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "удвостручено %<restrict%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name %qs"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "сукобљено име наткласе %qs"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "дефиниција функције декларисана као %<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "дефиниција функције декларисана као %<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "дефиниција функције декларисана као %<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "дефиниција функције декларисана као %<auto%>"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field %qE"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for parameter %qE"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "складишна класа наведена за име типа"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs has both %<extern%> and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<auto%>"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "декларација датотечног досега за %qs наводи %<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<register%>"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "декларација датотечног досега за %qs наводи %<register%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested function %qE declared %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -44981,792 +45010,792 @@ msgstr "%qs досега функције имплицитно аутоматс
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "статичка или одредба типа у непараметарском декларатору низа"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "декларација %qs као низа празних"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "декларација %qs као низа празних"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "величина низа %qs има нецелобројни тип"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "величина низа %qs има нецелобројни тип"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "size of array %qE has incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "size of unnamed array has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array %qs"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ИСО Ц забрањује нулту величину низа %qs"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ИСО Ц++ забрањује низ нулте величине"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE is negative"
 msgstr "величина низа %qs је негативна"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "негативна величина низа"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array %qE is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of unnamed array is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ИСО Ц 90 не подржава флексибилне чланске низове"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not allowed in other than a declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> није дозвољено другде осим у декларацији"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "низовни тип има непотпун тип елемента"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "дефиниција функције има одређен празан повратни тип"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ИСО Ц забрањује одређене функцијске типове"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ИСО Ц забрањује одређене функцијске типове"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type qualifiers for %q+D"
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "сукобљене одредбе типа за %q+D"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%qs specified for auto variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for parameter %qE"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field %qE"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "равнање се не може навести за %q+D"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "равнање се не може навести за %q+D"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for parameter %qE"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "равнање се не може навести за %q+D"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> примењено на битско поље"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "%qs може бити наведено само за функције"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ИСО Ц забрањује константне или непостојане функцијске типове"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "члан структуре или уније не може имати променљиво измењив тип"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "променљива или поље %qE декларисано празним"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "атрибути у параметарском декларатору низа игнорисани"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "field %qE declared as a function"
 msgstr "поље %qs декларисано као функција"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "поље %qs има непотпун тип"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid storage class for function %qE"
 msgstr "неисправна складишна класа за функцију %qs"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "функција %<main%> се не може уткати"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "променљива претходно декларисана као %<static%> поново декларисана као %<extern%>"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "скок у досег идентификатора са променљиво измењивим типом"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "објекат променљиво измењивог типа не може имати повезивост"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "декларација функције није прототип"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "имена параметара (без типова) у декларацији функције"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "параметар %u (%q+D) има непотпун тип"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "%Jпараметар %u има непотпун тип"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "параметар %u (%q+D) има празан тип"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has void type"
 msgid "parameter %u has void type"
 msgstr "%Jпараметар %u има празан тип"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> као једини параметар не може бити одређен"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> мора бити једини параметар"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "параметар %q+D има само унапредну декларацију"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "enum type defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "struct defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "union defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "поновна дефиниција %<union %E%>"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "поновна дефиниција %<struct %E%>"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "угњеждена поновна дефиниција %<union %E%>"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "угњеждена поновна дефиниција %<struct %E%>"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларација ништа не декларише"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ИСО Ц не подржава неименоване струкутре/уније"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ИСО Ц не подржава неименоване струкутре/уније"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "удвостручени члан %q+D"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "унија нема именованих чланова"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "унија нема чланова"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "структура нема именованих чланова"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "структура нема чланова"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "унија не може бити учињена провидном"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "угњеждена поновна дефиниција %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "поновљена декларација %<enum %E%>"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "наведени режим је премали за набројиве вредности"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "вредности у набрајању премашују опсег највећег целог броја"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "преливање у вредностима набрајача"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "утканој функцији %q+D дат је атрибут noinline"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "повратни тип је непотпун тип"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "повратни тип спада на %<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "Упозори на глобалне функције без прототипа"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "нема претходног прототипа за %q+D"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
 msgstr "нема претходне декларације за %q+D"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D је употребљено без декларације пре дефиниције"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "повратни тип за %q+D није %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D је обично нестатичка функција"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jстаровремска декларација параметара у дефиницији функције са прототипом"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jтрадиционални Ц одбија дефиниције функција у стилу ИСО Ц-а"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr ""
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%Jстаровремска дефиниција функције"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%Jнедостаје име параметра у листи параметара"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "више параметара по имену %q+D"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "тип за %q+D спада на %<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "параметар %q+D има непотпун тип"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "декларација за параметар %q+D, али нема таквог"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "број аргумената не одговора уграђеном прототипу"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "број аргумената не одговара прототипу"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "prototype declaration"
 msgstr "%Hдекларација прототипа"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "унапређени аргумент %qD не одговара уграђеном прототипу"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "унапређени аргумент %qD не одговара прототипу"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD не одговара уграђеном прототипу"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не одговара прототипу"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -45775,281 +45804,281 @@ msgstr "параметар %qD је успостављен"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Почетна декларација у %<for%> петљи употребљена ван режима Ц-а 99"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ИСО Ц 90 не подржава деклараторе низова %<[*]%>"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларација статичке променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> декларисан у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларација не-променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или више типова података у наводиоцима декларације"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> је предуго за ГЦЦ"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "удвостручено %qE"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ИСО Ц не подржава децимални покретни зарез"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE није ни по дефиницији типа ни уграђени тип"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE није на почетку декларације"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> употребљено уз %<auto%>"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> употребљено уз %<register%>"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> употребљено уз %<typedef%>"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не подржава %s"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> пре %<extern%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> пре %<static%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "вишеструке складишне класе у наводиоцима декларације"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> употребљено уз %qE"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@try%> без %<@catch%> или %<@finally%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "негативан леви помак"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "негативан леви помак"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "негативан десни помак"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "леви помак >= од ширине типа"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "десни помак >= од ширине типа"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "леви помак >= од ширине типа"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -46070,7 +46099,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -46082,7 +46111,7 @@ msgstr "Неочекиван крај модула"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ИСО Ц забрањује празну изворну датотеку"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr ""
@@ -46120,7 +46149,7 @@ msgid "unknown type name %qE"
 msgstr "непознато име регистра: %s"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "очекивани су наводиоци декларације"
@@ -46142,7 +46171,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -46160,7 +46189,7 @@ msgstr "атрибут се игнорише при извођењу шабло
 msgid "unexpected attribute"
 msgstr "Очекивано је име атрибутског бита"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -46202,7 +46231,7 @@ msgstr "%<auto%> у празној декларацији у досегу дат
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "очекивано је %<,%> или %<;%>"
@@ -46267,7 +46296,7 @@ msgstr "интегрални израз %qE није константа"
 msgid "static assertion failed: %E"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
@@ -46317,14 +46346,14 @@ msgstr "неисправан шаблонски аргумент %d"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "очекиван је идентификатор"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "зарез на крају листе набрајања"
@@ -46411,7 +46440,7 @@ msgstr "очекивани су наводиоци декларације или
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute does not take any arguments"
@@ -46475,7 +46504,7 @@ msgstr "%HИСО Ц 90 забрањује мешање декларација и
 msgid "expected %<}%> before %<else%>"
 msgstr "очекивано је %<,%> или %<}%>"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -46490,7 +46519,7 @@ msgstr "етикета на крају сложене наредбе"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "очекивана је наредба"
@@ -46515,19 +46544,19 @@ msgstr "очекиван је идентификатор или %<*%>"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr ""
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hпразно тело у наредби if"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%Hпразно тело у наредби else"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -46549,12 +46578,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "неисправан регистар у инструкцији"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -46571,8 +46600,8 @@ msgstr "недостаје стражар у позиву функције"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "удвостручена кн-одредба"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, fuzzy, gcc-internal-format
 #| msgid "%J  first type here"
 msgid "first seen here"
@@ -46604,12 +46633,12 @@ msgstr "ИСО Ц забрањује изостављање средњег чл
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -47039,12 +47068,12 @@ msgstr "Очекивана је декларација класе или суч
 msgid "no type or storage class may be specified here,"
 msgstr "складишна класа наведена за %qs"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -47055,55 +47084,55 @@ msgstr "недостаје атрибут Code"
 msgid "unknown property attribute %<%s%s%>"
 msgstr ""
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected %qE selector name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
@@ -47114,19 +47143,19 @@ msgstr "%<#pragma omp section%> може бити употребљено сам
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> мора бити прво"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "превише %qs одредби"
@@ -47149,60 +47178,60 @@ msgstr "очекивано је %<,%> или %<;%>"
 msgid "%qD is not a variable"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD није шаблон"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "поређење означених и неозначених целобројних израза"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -47225,124 +47254,124 @@ msgstr "вредност %<num_threads%> мора бити позитивна"
 msgid "%<num_tasks%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "очекиван је целобројни израз"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Неочекивани елемент"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент атрибута %qs није целобројна константа"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<concurrent%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "и %<long%> и %<void%> у наводиоцима декларације"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, fuzzy, gcc-internal-format
 #| msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "неисправна врста распореда"
@@ -47353,18 +47382,18 @@ msgstr "неисправна врста распореда"
 msgid "%<num_teams%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -47385,25 +47414,25 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "неисправна маска"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -47421,88 +47450,88 @@ msgstr "неисправна врста распореда"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs није исправно за %qs"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT није угњеждена класа у %qT"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "неисправна употреба %<--%> на логичкој променљивој %qD"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is used more than once in the argument list of method %qs"
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Променљива %qs употребљена више од једном у листи аргумената метода %qs"
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -47519,7 +47548,7 @@ msgstr "%qD није декларисано"
 msgid "expected function name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -47530,28 +47559,28 @@ msgstr "%q+D није функција,"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<allocator%>"
@@ -47562,92 +47591,92 @@ msgstr "очекивано је %<{%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable више није подржано"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "очекивано је %<:%>, %<,%>, %<;%>, %<}%> или %<__attribute__%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "очекивано је %<:%>, %<,%>, %<;%>, %<}%> или %<__attribute__%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -47657,34 +47686,34 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "очекивано је успостављање или декларација итерације"
@@ -47694,77 +47723,77 @@ msgstr "очекивано је успостављање или декларац
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> као једини параметар не може бити одређен"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -47780,61 +47809,61 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "expected trait selector name"
 msgstr "Очекивано је име атрибутског бита"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "score argument must be non-negative"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "очекивана је дословна ниска"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "очекиван је целобројни израз"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<match%>"
@@ -47846,13 +47875,13 @@ msgstr "очекивано је %<{%>"
 msgid "variant %qD is not a function"
 msgstr "%q+D није функција,"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -47862,34 +47891,34 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -47947,45 +47976,45 @@ msgstr "очекиван је идентификатор или %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "очекивано је %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "модела кôда %<large%> још увек није подржан"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -48001,27 +48030,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -48031,7 +48060,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -48048,7 +48077,7 @@ msgstr "%Hобухватајуће паралелно"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD има непотпун тип"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неисправна употреба израза празног типа"
@@ -48092,135 +48121,135 @@ msgstr "атрибут %qE може се применити само на јав
 msgid "function types not truly compatible in ISO C"
 msgstr "функцијски типови нису истински сагласни у ИСО Ц-у "
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and vector types"
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "не могу се мешати операнди децималног реалног и векторског типа"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and complex types"
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "не могу се мешати операнди децималног реалног и комплексног типа"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and other float types"
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "не могу се мешати операнди децималног реалног и других реалних типова"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "типови нису сасвим сагласни"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "pointer target types incompatible in C++"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "повратни типови функција нису сагласни услед %<volatile%>"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT нема члан по имену %qE"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT нема члан по имену %qE"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr ""
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "захтев за члан %qE у нечему што није ни структура ни унија"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "разрешавање %<void *%> показивача"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс низа није целобројан"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "индексирана вредност је показивач на функцију"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ИСО Ц забрањује %<register%> низове"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ИСО Ц 90 забрањује индексирање не-л-вредносног низа"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "called object %qE is not a function or function pointer"
 msgstr "позвани објекат %qE није функција"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "called object %qD is not a function or function pointer"
 msgstr "позвани објекат %qE није функција"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "called object is not a function or function pointer"
@@ -48229,1731 +48258,1731 @@ msgstr "позвани објекат %qE није функција"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "функција позвана кроз несагласан тип"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "function definition has qualified void return type"
 msgid "function with qualified void return type called"
 msgstr "дефиниција функције има одређен празан повратни тип"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "тип формалног параметра %d није потпун"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као целобројног уместо као реалног, због прототипа"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као целобројног уместо као комплексног, због прототипа"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као комплексног уместо као реалног, због прототипа"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као реалног уместо као целобројног, због прототипа"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као комплексног уместо као целобројног, због прототипа"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као реалног уместо као комплексног, због прототипа"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као %<float%> уместо као %<double%>, због прототипа"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као %qT уместо као %qT, због прототипа"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "прослеђивање аргумента %d за %qE са различитом ширином, због прототипа"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као неозначеног, због прототипа"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "прослеђивање аргумента %d за %qE као означеног, због прототипа"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to method %qE"
 msgstr "превише аргумената за функцију %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "превише аргумената за функцију %qE"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "премало аргумената за функцију %qE"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, fuzzy, gcc-internal-format
 #| msgid "comparison with string literal results in unspecified behaviour"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "поређење са дословном ниском резултује неодређеним понашањем"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "поређење између показивача и целобројног"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
 msgstr "претапање %qT у %qT не разрешава показивач"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between %q#T and %q#T"
 msgid "comparison between %qT and %qT"
 msgstr "поређење између %q#T и %q#T"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "показивачи типа %<void *%> употребљени у одузимању"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "показивач на функцију употребљен у одузимању"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "  in thrown expression"
 msgid "%<~%> on a boolean expression"
 msgstr "  у баченом изразу"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ИСО Ц не подржава %<~%> за комплексну конјугацију"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "погрешан тип аргумента за abs"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "погрешан тип аргумента уз унарни знак узвика"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing increment expression"
 msgid "increment of a boolean expression"
 msgstr "%Hнедостаје израз увећања"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only location"
 msgid "decrement of a boolean expression"
 msgstr "умањење само-за-читање локације"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ИСО Ц не подржава %<++%> и %<--%> за комплексне типове"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "погрешан тип аргумента уз увећање"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "погрешан тип аргумента уз умањење"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of expression of type %<void%>"
 msgstr "узимање адресе привременог"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "не може се узети адреса битског поља %qD"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "затражена адреса регистарске променљиве %qD"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "глобална регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "затражена адреса глобалне регистарске променљиве %qD"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "затражена адреса регистарске променљиве %qD"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "не-л-вредносни низ у условном изразу"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ИСО Ц забрањује условне изразе са само једном празном страном"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "неслагање показивачких типова у условном изразу"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "неслагање показивачких типова у условном изразу"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ИСО Ц забрањује условни израз између %<void *%> и функцијског показивача"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "неслагање показивачких типова у условном изразу"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "неслагање показивачких типова у условном изразу"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "неслагање типова показивача или целобројних у условном изразу"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "неслагање типова у условном изразу"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "in call to %qD, declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 #, fuzzy
 #| msgid "cast adds new qualifiers to function type"
 msgid "cast adds %q#v qualifier to function type"
 msgstr "претапање додаје нове одредбе функцијском типу"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "претапање одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "претапање наводи низовни тип"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "претапање наводи функцијски тип"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ИСО Ц забрањује претапање нескалара у исти тип"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ИСО Ц забрањује претапање у унијски тип"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "претапање у унијски тип из типа који не чини унију"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "претапање увећава неопходно равнање циљног типа"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "претапање из показивача у целобројни различите величине"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "претапање из функцијског позива типа %qT у непоклапајући тип %qT"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "претапање из целобројног у показивач различите величине"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ИСО Ц забрањује претварање показивача на функцију у показивач на објекат"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ИСО Ц забрањује претварање показивача на објекат у показивач на функцијски тип"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "не може се претворити из непотпуног типа %qT у %qT"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "потискивање доделе"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(близу успостављања за %qs)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "низ успостављен константном ниском у заградама"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "expected %qT but argument is of type %qT"
 msgstr "формат %q.*s очекује тип %<%T%s%>, али аргумент %d је типа %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "built-in %qD declared here"
 msgstr "%q+D декларисано овде"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "циљеви показивача у прослеђивању аргумента %d за %qE разликују се у означености"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "implicit conversion from %qT to %qT"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 #, fuzzy
 #| msgid "passing argument %d of %qE makes qualified function pointer from unqualified"
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "прослеђивање аргумента %d од %qE прави одређени функцијски показивач од неодређеног"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 #, fuzzy
 #| msgid "assignment makes qualified function pointer from unqualified"
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "додела прави одређени функцијски показивач од неодређеног"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 #, fuzzy
 #| msgid "initialization makes qualified function pointer from unqualified"
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "успостављање прави одређени функцијски показивач од неодређеног"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 #, fuzzy
 #| msgid "return makes qualified function pointer from unqualified"
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "повратак прави одређени функцијски показивач од неодређеног"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 #, fuzzy
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 #, fuzzy
 #| msgid "assignment discards qualifiers from pointer target type"
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "додела одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 #, fuzzy
 #| msgid "initialization discards qualifiers from pointer target type"
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "успостављање одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 #, fuzzy
 #| msgid "return discards qualifiers from pointer target type"
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "повратак одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ИСО Ц забрањује претварање аргумента у унијски тип"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "прослеђивање аргумента %d од %qE из несагласног показивачког типа"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "претапање из показивача у целобројни различите величине"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "успостављање из несагласног показивачког типа"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "лева страна доделе може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "лева страна успостављања може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "прослеђивање аргумента %d од %qE из несагласног показивачког типа"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr ""
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ИСО Ц забрањује прослеђивање аргумента %d од %qE између функцијског показивача и %<void *%>"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ИСО Ц забрањује доделу између функцијског показивача и %<void *%>"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ИСО Ц забрањује успостављање између функцијског показивача и %<void *%>"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ИСО Ц забрањује повратак између функцијског показивача и %<void *%>"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "циљеви показивача у прослеђивању аргумента %d за %qE разликују се у означености"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "циљеви показивача у додели разликују се у означености"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "циљеви показивача у успостављању разликују се у означености"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "циљеви показивача у прослеђивању аргумента %d за %qE разликују се у означености"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "прослеђивање аргумента %d од %qE из несагласног показивачког типа"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "додела из несагласног показивачког типа"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "успостављање из несагласног показивачког типа"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "успостављање из несагласног показивачког типа"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "return from incompatible pointer type"
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "повратак из несагласног показивачког типа"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "прослеђивање аргумента %d од %qE прави показивач од целобројног без претапања"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "додела прави показивач од целобројног без претапања"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "успостављање прави показивач од целобројног без претапања"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "прослеђивање аргумента %d од %qE прави показивач од целобројног без претапања"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "прослеђивање аргумента %d од %qE прави целобројни од показивача без претапања"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "додела прави целобројни од показивача без претапања"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "успостављање прави целобројни од показивача без претапања"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "прослеђивање аргумента %d од %qE прави целобројни од показивача без претапања"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "несагласни типови у додели %qT у %qT"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "несагласни типови у успостављању"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "несагласни типови у додели %qT у %qT"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "традиционални Ц одбија аутоматску успостављање скупина"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "успостављање флексибилног чланског низа"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "низ неподесног типа успостављен константном ниском"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "неисправна употреба не-л-вредносног низа"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "елемент успостављача није константан"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "низ успостављен не-константним низовним изразом"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer element is not a constant expression"
 msgstr "елемент успостављача није константан"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "елемент успостављача се не може израчунати при учитавању"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "неисправан успостављач"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозирни векторски типови не могу бити успостављени"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "сувишна група витичастих заграда на крају успостављача"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "витичасте заграде око скаларног успостављача"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "успостављање флексибилног чланског низа у угњежденом контексту"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "недостају витичасте заграде око успостављача"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "missing initializer for field %qD of %qT"
 msgstr "недостаје успостављач за члан %qD"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "празан скаларни успостављач"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "сувишни елементи у скаларном инцијализатору"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "индекс низа у не-низовном успостављачу"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "име поља није у успостављачу слога или уније"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "индекс низа у успостављачу није целобројан"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer not of integer type"
 msgid "array index in initializer is not an integer constant expression"
 msgstr "индекс низа у успостављачу није целобројан"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "индекс у успостављачу премашује границе низа"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "празан индексни опсег у успостављачу"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "индексни опсег у успостављачу премашује границе низа"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "успостављено поље са споредним ефектима пребрисано"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "успостављено поље пребрисано"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "сувишни елементи у успостављачу знаковног низа"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "сувишни елементи у успостављачу структуре"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "нестатичко успостављање флексибилног чланског низа"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "сувишни елементи у успостављачу уније"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "традиционални Ц одбија успостављање унија"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "сувишни елементи у успостављачу низа"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "сувишни елементи у успостављачу вектора"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "сувишни елементи у успостављачу скалара"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ИСО Ц забрањује %<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> без вредности у функцији која не враћа празан тип"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> са вредношћу у функцији која враћа празан тип"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, fuzzy, gcc-internal-format
 #| msgid "%<return%> with a value, in function returning void"
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "%<return%> са вредношћу у функцији која враћа празан тип"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "функција враћа адресу на локалну променљиву"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "величина у прекидачу није целобројна"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "%<long%> израз у прекидачу не претвара се у %<int%> у ИСО Ц-у"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "case label is not an integer constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "етикета %<default%> није у оквиру наредбе прекидача"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "наредба искакања није у оквиру петље или прекидача"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "неисправан излаз из структуираног блока ОпенМПа"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "наредба искакања употребљена са ОпенМПом за петљу"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "наредба настављања није у оквиру петље"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "наредба без ефекта"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "наредба израза има непотпун тип"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "поређење реалних помоћу == или != није безбедно"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of distinct pointer types lacks a cast"
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "поређењу различитих показивачких типова недостаје претапање"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ИСО Ц забрањује поређење %<void *%> и функцијског показивача"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "поређењу различитих показивачких типова недостаје претапање"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "поређење између показивача и целобројног"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "поређење потпуног и непотпуног показивача"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ИСО Ц забрањује поређена уређености показивача на функције"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with null pointer"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "употребљен низ који се не може претворити у показивач где се захтева скалар"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "употребљена вредност структурног типа где се захтева скалар"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "употребљена вредност унијског типа где се захтева скалар"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, fuzzy, gcc-internal-format
 #| msgid "used struct type value where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "употребљена вредност структурног типа где се захтева скалар"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD није чланска шаблонска функција"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected single pointer in %qs clause"
 msgstr "очекивана је дословна ниска"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Копирај одељке низа у непрекидан блок при улазу у процедуру"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
 msgstr "%qE нема класни тип"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "баца се NULL, које има интегрални, а не показивачки тип"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "iterator %qD has const qualified type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "битско поље %qD неинтегралног типа"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "грешка типа упућивача израза код %L"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "end expression refers to outer iterator %qD"
 msgstr "грешка типа упућивача израза код %L"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "step expression refers to outer iterator %qD"
 msgstr "грешка типа упућивача израза код %L"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected pointer in %qs clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "zero sized type %qT in %qs clause"
 msgstr "Низ претпостављене величине ‘%s’ у одредби ‘%s’ код %L"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 #| msgid "No variable %qs defined in type %qs"
 msgid "variable sized type %qT in %qs clause"
 msgstr "Променљива %qs није дефинисана у типу %qs"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE има неисправан тип за %<reduction(%s)%>"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
 msgstr "Није нађена дефиниција етикете за %qs"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE мора бити нитно-локално за %<copyin%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%qs variable is not a pointer"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE је предодређено као %qs за %qs"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "први аргумент за %<va_arg%> није типа %<va_list%>"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -50194,7 +50223,7 @@ msgstr "  за претварање из %qT у %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -50318,741 +50347,747 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%D(%A)%> "
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "показивач на чланску функцију %E не може бити позван без објекта; покушајте помоћу .* или ->*"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "нема поклапања за позив %<(%T) (%A)%>"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "двосмислен позив %<(%T) (%A)%>"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "двосмислено претварање за индекс низа"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid " (operand types are %qT and %qT)"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Кориснички оператори:\n"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "%s for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s за тернарно %<operator?:%> у %<%E ? %E : %E%>"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Лош оператор"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s за %<operator%s%> у %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Лош оператор"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s за %<operator[]%> у %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%s за %qs у %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 #| msgid "  or %<operator=(const %T&)%>"
 msgid "%<operator %s%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%s за %<operator%s%> у %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s за %<operator%s%> у %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s за %<operator%s%> у %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ИСО Ц++ забрањује изостављање средњег члана израза ?:"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "неслагање набројивих у условном изразу: %qT пр. %qT"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "неслагање набројивих у условном изразу: %qT пр. %qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "повратни тип за %q+D није %<int%>"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "поређење између %q#T и %q#T"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%q+D је обично нестатичка функција"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, fuzzy, gcc-internal-format
 #| msgid "no corresponding deallocation function for `%D'"
 msgid "no corresponding deallocation function for %qD"
 msgstr "нема одговарајуће функције за ослобађање меморије за ‘%D’"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нема погодног %<operator %s%> за %qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "у овом контексту"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "у овом контексту"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D није приступно"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "прослеђивање NULL непоказивачком аргументу %P од %qD"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "  declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "претварање у непоказивачки тип %qT из NULL"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "претварање NULL у непоказивачки тип"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  успостављање аргумента %P од %qD"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+#| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
+
+#: cp/call.c:7911
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "не може се повезати битско поље %qE са %qT"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "не може се повезати паковано поље %qE са %qT"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не може се повезати д-вредност %qE са %qT"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "не могу се проследити објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "не могу се примати објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "подразумевани аргумент за параметер %d у %qD још увек није рашчлањен"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "прослеђивање %qT као аргумента %<this%> у %q#D одбацује одредбе"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  у позиву %qD"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT није приступна основа од %qT"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "користите #include уместо тога"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "користите #include уместо тога"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%s(%A)%>"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "враћање вредности из конструктора"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "враћање вредности из деструктора"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "чланска функција %qD не може се позвати без објекта"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "прослеђивање %qT бира %qT пре него %qT"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "бирам %qD пре него %qD"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  зато што је редослед претварања за аргумент бољи"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 1:"
 msgid " candidate 1: %q#F"
 msgstr "кандидат 1:"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 2:"
 msgid " candidate 2: %q#F"
 msgstr "кандидат 2:"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ИСО Ц++ каже да је ово двосмислено, чак иако је најгоре претварање првог боље од најгорег претварања другог:"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -51082,1251 +51117,1251 @@ msgstr "не може се претворити из основе %qT у изв
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "не може се претворити из основе %qT у изведени тип %qT преко виртуелне основе %qT"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "не може се претворити из основе %qT у изведени тип %qT преко виртуелне основе %qT"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D се коси са претходном декларацијом употребе %q#D"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D не може бити препуњено"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
 msgstr "претходна декларација %q+D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "сукобљене одреднице приступа за метод %q+D, игноришем"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "сукобљене одреднице приступа за поље %qE, игноришем"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  због истоименог локалног метода %q+#D"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local method %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  због истоименог локалног члана %q+#D"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "не може се претворити из основе %qT у изведени тип %qT преко виртуелне основе %qT"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "све чланске функције у класи %qT су приватне"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T дефинише само приватни деструктор и нема пријатељâ"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T дефинише само приватне конструкторе и нема пријатељâ"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "нема јединственог коначног потискивача за %qD у %qT"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D не може бити препуњено"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D је сакривено"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  овим %q+D"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "битско поље %q+#D неинтегралног типа"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ширина битског поља %q+D није целобројна константа"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "негативна ширина у бистком пољу %q+D"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "нулта ширина за битско поље %q+D"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "ширина %q+D премашује свој тип"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D је премало да садржи све вредности за %q#T"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "члан %q+#D са конструктором није дозвољен у унији"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "члан %q+#D са деструктором није дозвољен у унији"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у унији"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D не може бити статичко зато што је члан уније"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "нестатчики константни члан %q+#D у класи без конструктора"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "поље %q+D неисправно декларисан функцијски тип"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "игноришем атрибут паковања због непакованог не-ПОД поља %q+#D"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "успостављена вишеструка поља у унији %qT"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "поље %q+#D истог имена као и класа"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T има показивачке чланске податке"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  али не потискује %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  али не потискује %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "успостављач наведен за невиртуелни метод %q+D"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T није класа"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "јаванска класа %qT не може имати деструктор"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD has non-integral type %qT"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "  non-static data member %qD has volatile type"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "нестатички упућивач %q+#D у класи без конструктора"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "нестатчики константни члан %q+#D у класи без конструктора"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуелна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "помак за %q+D можда не поштује АБИ и може се изменити у будућим верзијама ГЦЦа"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "величина низа %qs је превелика"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jфлексибилан члански низ у иначе празној структури"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jфлексибилан члански низ у иначе празној структури"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T има виртуелне функције, али невиртуелни деструктор"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "тип %qs има виртуелне чланске функције"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#D is marked %<dllimport%>"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "дефиниција %q+D означена као %<dllimport%>"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "у покушају да довршим структуру, али избачен услед претходних грешака у рашчлањивању"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "језичка ниска %<\"%E\"%> није препозната"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "не могу да разрешим препуњену функцију %qD на основу претварања у тип %qT"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нема поклапања за претварање функције %qD у тип %q#T"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "двосмислено претварање препуњене функције %qD у тип %q#T"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "претпостављам показивач на члан %qD"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "нема довољно података о типу"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "не може се претворити %qE из типа %qT у тип %qT"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
 msgstr "поново декларисано овде као %q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr ""
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type %qT"
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "параметар не може имати променљиво измењив тип %qT"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "повратни тип за %q+D није %<int%>"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract return type for function %q+#D"
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "неисправан апстрактни повратни тип за функцију %q+#D"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract return type for function %q+#D"
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "неисправан апстрактни повратни тип за функцију %q+#D"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#T has virtual base classes"
 msgstr "%q#T није класа"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%Jосновна класа %q#T треба да се експлицитно успостави у копи-конструктору"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%q+E is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "позив не-функције %qD"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 #| msgid "original label is here"
 msgid "originally declared %<const%> here"
 msgstr "првобитна етикета је овде"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a base type for type %qT"
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "тип %qT није основни тип за тип %qT"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr ""
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "%qT је двосмислена основа за %qT"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 #| msgid "allocating zero-element array"
 msgid "allocation performed here"
 msgstr "резервисање низа нулте дужине"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a previous local"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "декларација %qD заклања претходну локалну"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%q+D је употребљено без декларације пре дефиниције"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "протокол %qs има кружну зависност"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "негативан десни помак"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "разрешавање %<void *%> показивача"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "шаблонски параметар %qD типа %qT није дозвољен у интегралном константном изразу јер није интегралног или набројивог типа"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%s се не може користити овде у асемблеру"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "разрешавање %<void *%> показивача"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "allocated here"
 msgstr "позвано одавде"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "array used as initializer"
 msgid "%qD used in its own initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T није класа"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D је приватно"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "inline assembly is not a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 #| msgid "Empty array constructor at %C is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "Празан конструктор низа код %C није дозвољен"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got %qE"
 msgid "unexpected template-id %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "очекиван је израз"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "преливање у константном изразу"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "label definition is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -52337,56 +52372,56 @@ msgstr "Неочекиван крај датотеке у ‘%s’"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD није тип"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not a class type"
 msgstr "%qD није тип"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE нема класни тип"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have integral type"
 msgstr "%qE нема класни тип"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -52440,7 +52475,7 @@ msgstr "неисправно успостављање неконстантног
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "претапање %qT у %qT не разрешава показивач"
@@ -52872,7 +52907,7 @@ msgstr "од претходне декларације %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "Декларација %qs заклања претходну декларацију етикете"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -53025,8 +53060,8 @@ msgstr "претходна нефункцијска декларација %q+#D
 msgid "%q#D previously defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
@@ -53067,60 +53102,60 @@ msgstr "подразумевани аргумент дат за парамета
 msgid "previous specification in %q#D here"
 msgstr "после претходног навода у %q+#D"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of namespace %qD conflicts with"
 msgid "declaration %qD conflicts with builtin"
 msgstr "декларација именског простора %qD коси се са"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of namespace %qD conflicts with"
 msgid "declaration %qD conflicts with import"
 msgstr "декларација именског простора %qD коси се са"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "import declared %q#D here"
 msgstr "претходном декларацијом %q+#D овде"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting declaration %qD"
 msgstr "сукобљена декларација %q#D"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %q#D here"
 msgstr "претходном декларацијом %q+#D овде"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "претходна дефиниција %q+D беше овде"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "претходна декларација %q+D беше овде"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "function declared %<noreturn%> has a %<return%> statement"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "сувишна поновна декларација %qD у истом досегу"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %qD is not in namespace enclosing %qT"
 msgid "deleted definition of %qD is not first declaration"
@@ -53134,55 +53169,55 @@ msgstr "дефиниција %qD није у именском простору 
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "експлицитна специјализација %qD после прве употребе"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D: атрибут видљивости игнорисан зато што"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "redefinition of %q#D"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D се коси са претходном декларацијом употребе %q#D"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%q#D not declared in class"
 msgstr "%qD није декларисано у %qD"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "deduction guide %q+D redeclared"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -53190,725 +53225,731 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "нитно-локална декларација %q+D прати не-нитно-локалну декларацију"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "не-нитно-локална декларација %q+D прати нитно-локалну декларацију"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "декларација %q#D"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "сувишна поновна декларација %qD у истом досегу"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  одавде"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  излази из структуираног блока ОпенМПа"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  пресеца успостављање %q+#D"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  улази у блок покушаја"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  улази у блок хватања"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  улази структуирани блок ОпенМПа"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  прескаче успостављање %q+#D"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD није шаблон функције"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T није класа"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "нема шаблона класе по имену %q#T у %q#T"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именује %q#T, што није шаблон класе"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> именује %q#T, што није тип"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "захтевано равнање није степен двојке"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са конструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са деструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у анонимној скупини"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут за %q+#T мора пратити кључну реч %qs"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "вишеструки типови у једној декларацији"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "недостаје име типа у наредби typedef"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ИСО Ц++ забрањује анонимне структуре"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> може бити наведено само унутар класе"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> може бити наведено само за конструкторе"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "%qs cannot be used for type declarations"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "дефиниција типа %qD је успостављена (употребите __typeof__)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "дефиниција %q+D означена као %<dllimport%>"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "неисправна декларација чланског шаблона %qD"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ИСО Ц++ не дозвољава да %<%T::%D%> буде дефинисано као %<%T::%D%>"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "удвостручено успостављање %qD"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "променљива %q#D има успостављач али је непотпуног типа"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "скупина %q#D има непотпун тип и не може се дефинисати"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD декларисано као упућивач али није успостављено"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривијални утврђени успостављачи нису подржани"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "величина складишта за %q+D није позната"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "величина складишта за %q+D није константна"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  можете ово заобићи уклањањем успостављача"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "неуспостављена константа %qD"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%Jнеуспостављени члан %qD са %<const%> типом %qT"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "неисправан тип %qT као успостављач за вектор типа %qT"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "неисправан успостављач"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "превише успостављача за %qT"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %P has incomplete type %qT"
 msgid "structured binding has incomplete type %qT"
 msgstr "параметар %P непотпуног је типа %qT"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ИСО Ц 90 забрањује сложене дословне ниске"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "скаларни објекат %qD захтева један елемент у успостављачу"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD мора бити успостављен конструктором, не помоћу %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "низ %qD успостављен заграђеном константном ниском %qE"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "успостављач неисправан за статички члан са конструктором"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(потребно је успостављање изван класе)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "параметар %qD је успостављен"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "could not find variant declaration"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "%s: recursive invocation of constructor %qs"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s: рекурзивно позивање конструктора %qs"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "поновљена декларација набрајача %q+D"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "заклањање претходне декларације типа за %q#D"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функција %q#D успостављена као променљива"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  не може се користити застарело везивање код %q+D јер има деструктор"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT је неприступачна основа за %qT"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare variable %q+D to be of abstract type %qT"
 msgid "cannot decompose variable length array %qT"
 msgstr "не може се декларисати променљива %q+D апстрактног типа %qT"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
@@ -53918,7 +53959,7 @@ msgstr[1] "успостављач дат за функцију"
 msgstr[2] "успостављач дат за функцију"
 msgstr[3] "успостављач дат за функцију"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -53927,7 +53968,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -53936,1800 +53977,1811 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "не могу да разложим адресу"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "не могу применити %<offsetof%> на статички члански податак %qD"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларисано са одредницом изузетака"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "дефиниција %qD није у именском простору који обухвата %qT"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статичка чланска функција %q#D декларисана са одредбама типа"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "јавански метод %qD има не-јавански повратни тип %qT"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD није шаблонска функција"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "дефиниција експлицитне специјализације %qD у декларацији пријатеља"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "неисправна употреба ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> није дозвољено у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> се не може декларисати као уткано"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "%<::main%> се не може декларисати као статичко"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> се не може декларисати као статичко"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, fuzzy, gcc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "неисправан аргумент опције %qs"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> мора враћати %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "чланска функција %q#D није декларисана у класи %qT"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+#| msgid "strong using only meaningful at namespace scope"
+msgid "concept must be defined at namespace scope"
+msgstr "јако using има смисла само у досегу именског простора"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ИСО Ц++ забрањује успостављање чланске константе %qD неинтегралног типа %qT"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ИСО Ц++ забрањује низ нулте величине"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ИСО Ц++ забрањује низ променљиве величине %qD"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ИСО Ц++ забрањује низ променљиве величине"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "преливање у димензији низа"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "декларација %qs као низа празних"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "вишедимензиони низ мора имати границе за све димензије осим прве"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "навод повратног типа за конструктор није исправан"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "наведен повратни тип за %<operator %T%>"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "превише листа шаблонских параметара у декларацији %qD"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "сукобљени наводиоци у декларацији %qs"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "неименована променљива или поље декларисано празним"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "неисправна употреба одређеног имена %<::%D%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "неисправна употреба одређеног имена %<%T::%D%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "неисправна употреба одређеног имена %<%D::%D%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "декларација %qD као не-члана"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "недостаје ид. декларатора; користи се резервисана реч %qD"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "дефиниција функције не декларише параметре"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларација %qD као %s"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "није наведена ниједна класа"
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или више типова података у декларацији %qs"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "сукобљени наводиоци у декларацији %qs"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ИСО Ц++ забрањује декларацију %qs без типа"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs није подржано овим циљем"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> и %<unsigned%> наведени заједно за %qs"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> и %<short%> наведени заједно за %qs"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qT"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> употребљено уз %<typedef%>"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex неисправно за %qs"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "декларација %qs на највишем нивоу наводи %<auto%>"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs досега функције имплицитно аутоматска и декларасина као %<__thread%>"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "наводиоци складишне класе нису исправни у декларацијама пријатељских функција"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "атрибут %qE се игнорише"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Очекивана је лева заграда"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "неисправна употреба %<restrict%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "функција са %<noreturn%> враћа непразну вредност"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "не може се дефинисати пријатељска функција %qs у дефиницији локалне класе"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструктори не могу имати параметре"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "не може се декларисати показивач на члан %q#T"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "не може се декларисати битско поље %qD са функцијским типом"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "ид. шаблона %qD употребљен као декларатор"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "чланске функције су имплицитно пријатељи својих класа"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "сувишна одредба %<%T::%> на члану %qs"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "не може се дефинисати чланска функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "не може се декларисати функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "не може се декларисати члан %<%T::%s%> унутар %qT"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "члански податак не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметар не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "не-објектни члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "константно %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "typedef may not be a function definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "typedef may not be a member function definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not allowed in other than a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> није дозвољено другде осим у декларацији"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jиме за дефиницију типа не може бити угњеждени-именски-наводилац"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ИСО Ц++ забрањује угњеждени тип %qD истог имена као и обухватајућа класа"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> наведено уз декларацију пријатељске класе"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "покушај да се класа %qT учини пријатељем глобалног досега"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "неисправне одредбе уз тип не-чланске функције"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "апстрактни декларатор %qT употребљен као декларација"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "не може се декларисати параметар %q+D апстрактног типа %qT"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "локална променљива %qD не може се појавити у овом контексту"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> се не може употребити у овом контексту"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "неисправна употреба шаблонског имена %qE без листе аргумената"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ИСО Ц 90 не подржава флексибилне чланске низове"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "неисправна употреба %<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "декларација Ц функције %q#D коси се са"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функција %qD декларисана виртуелном унутар уније"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не може бити декларисана виртуелном, јер је увек статичка"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %qs"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "не могу да отворим %s"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "поље %qD има непотпун тип"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "складишна класа %<auto%> неисправна за функцију %qs"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "складишна класа %<register%> неисправна за функцију %qs"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> неисправно наведено за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуелна не-класна функција %qs"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, fuzzy, gcc-internal-format
 #| msgid "No variable %qs defined in class %qs"
 msgid "%qs defined in a non-class scope"
 msgstr "Променљива %qs није дефинисана у класи %qs"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "не може се декларисати статичка повезивост за чланску функцију %qD"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "не може се декларисати статичка функција унутар друге функције"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> не може бити употребљено при дефинисању (насупрот декларисања) статичког чланског податка"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "не може се експлицитно декларисати спољашња повезивост за члан %q#D"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "неисправан конструктор; вероватно сте мислили %<%T (const %T&)%>"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD не може бити декларисано статичко"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD мора бити или нестатичка чланска функција или не-чланска функција"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD мора имати аргумент класног или набројивог типа"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ИСО Ц++ забрањује препуњавање оператора ?:"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD мора узимати ниједан или један аргумент"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD мора узимати један или два аргумента"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "постфиксно %qD мора узимати %<int%> као аргумент"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "постфиксно %qD мора узимати %<int%> као други аргумент"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD мора узимати тачно један аргумент"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "кориснички дефинисано %qD увек израчунава оба аргумента"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD треба да враћа по вредност"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "употреба typedef-имена %qD после %qs"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D има претходну декларацију овде"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT се помиње као %qs"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T има претходну декларацију овде"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT се помиње као набрајање"
@@ -55741,109 +55793,109 @@ msgstr "%qT се помиње као набрајање"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "потребан шаблонски аргумент за %<%s %T%>"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD има исто име као и класа у којој је декларисано"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT није шаблон"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "употреба набрајања %q#D без претходне декларације"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "поновљена декларација %qT као не-шаблона"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "%qD се не може декларисати као тип битског поља"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "неисправна изведена унија %qT"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "тип основе %qT није класа или структура"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "недефинисан рекурзивни тип %qT"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "неисправан удвостручен тип основе %qT"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jпретходна дефиниција је овде"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "специјализација %qD у различитом именском простору"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "underlying type %qT of %qT must be an integral type"
@@ -55853,85 +55905,85 @@ msgstr "Крејов показивач код %C мора бити целобр
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ниједан интегрални тип не може представљати све вредности набрајача за %qT"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "вредност набрајача за %qD није целобројна константа"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "преливање у вредностима набрајача код %qD"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "вишеструке дефиниције %q#T"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> треба да враћа упућивач на %<*this%>"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "повратни типови функција нису сагласни услед %<volatile%>"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD је већ дефинисано у класи %qT"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -55972,7 +56024,7 @@ msgstr "не може се обрисати функција. Само пока
 msgid "deleting %qT is undefined"
 msgstr "брисање %qT није дефинисано"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "декларација шаблона %q#D"
@@ -55983,7 +56035,7 @@ msgstr "декларација шаблона %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD декларисан као члански шаблон"
@@ -56339,24 +56391,24 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -56464,7 +56516,7 @@ msgstr "двосмислено упућивање на %<%T::%D%>"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD није члан у %qT"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD није члан у %qT"
@@ -56475,7 +56527,7 @@ msgstr "%qD није члан у %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD није члан у %qD"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD није члан у %qD"
@@ -56676,440 +56728,440 @@ msgstr "%Jподразумевано успостављање %q#D, које ј
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "успостављање флексибилног чланског низа"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD треба да се успостави у листи успостављања чланова"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "класа %qT је имплицитно сама себи пријатељска"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "неисправна почетна вредност за члан %qs"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "неуспостављени константни члан %qD"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "%q+D ће бити успостављено после"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%Jнеуспостављени упућивачки члан %qD"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D ће бити успостављено после"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "основно %qT ће бити успостављено после"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  основног %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  када се успостави овде"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%Jвишеструка успостављања дата за %qD"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%Jвишеструка успостављања дата за основно %qT"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%Jуспостављања за више чланова из %qT"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%Jосновна класа %q#T треба да се експлицитно успостави у копи-конструктору"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D је статички члански податак; може се успостављати само при дефинисању"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "неименовани успостављач за %qT, која нема основних класа"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "неименовани успостављач за %qT, која користи вишеструко наслеђивање"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD је и непосредна основа и посредна виртуелна основа"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT није непосредна основа од %qT"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "успостављач низа мора бити нешто у витичастим заградама"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%qT is not a class type"
 msgstr "%q#T није класа"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "непотпун тип %qT нема члан %qD"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "неисправан показивач на битско поље %qD"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%Jнеуспостављени упућивачки члан %qD"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "at offset %wi from %qD declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr ""
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "целобројно преливање у изразу"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "покушајте да уклоните заграде око ид. типа"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "неисправан тип %<void%> за new"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "ниједно погодно %qD није нађено у класи %qT"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "двосмислен захтев за чланом %qD"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new се не може применити на упућивачки тип"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new се не може применити на функцијиски тип"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "откривен могућ проблем у позиву оператора delete:"
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "успостављач се прерано окончава"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "непозната величина низа за delete"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "откривен могућ проблем у позиву оператора delete:"
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "сложена дословна ниска има променљиву величину"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot capture %qE by reference"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "capture by copy of incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> was not captured for this lambda function"
@@ -57169,62 +57221,62 @@ msgstr "%qD нема аргументе који зависе од шаблон
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(ако употребите %<-fpermissive%>, Г++ ће прихватити овакав кôд, али дозвољавање недекларисаног имена је превазиђено)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "изостављени средњи операнд у %<?:%> не може бити запетљан"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -57421,239 +57473,239 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn't match"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "спољашња декларација %q#D не слаже се"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "unparseable signature: '%s'"
 msgid "expected signature: %qD"
 msgstr "нерашчлањив потпис: ‘%s’"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a template cannot be defaulted"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "%qD cannot be defaulted"
 msgstr "%q+#D се не може декларисати"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "file ends in default argument"
 msgid "defaulted function %q+D with default argument"
 msgstr "датотека се завршава подразумеваним аргументом"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "декларација %q#D заклања параметар"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D се коси са претходном декларацијом употребе %q#D"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D скрива конструктор за %q#T"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "сукобљена декларација %q#D"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "due to different exception specifications"
 msgstr "Створи кôд за проверу одредница изузетака"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "декларација %q#D заклања параметар"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "декларација коришћења %q+D коси се са претходном декларацијом коришћења"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%q#D does not have external linkage"
 msgstr "%qE нема класни тип"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> именује деструктор"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "декларација употребе за не-члан у досегу класе"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "декларација употребе за не-члан у досегу класе"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "тип %qT није непосредна основа од %qT"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD not in a namespace surrounding %qD"
 msgid "using-declaration may not name namespace %qD"
 msgstr "декларација %qD није у именском простору који окружује %qD"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларација %qD није у именском простору који окружује %qD"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "експлицитна одредба у декларацији %qD"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD треба да је декларисано унутар %qD"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибутска директива %qD игнорисана"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -57662,99 +57714,99 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> није доступно за статичке чланске функције"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "it was later defined here"
 msgstr "%J%qD декларисано овде"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "прекидач %qs више није подржан"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "Двосмислено име типа ‘%s’ код %C"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "алијас именског простора %qD није дозвољен овде, претпостављам %qD"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D декларисано овде"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 #| msgid "address area of %q+D conflicts with previous declaration"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "адресна област за %q+D коси се са претходном декларацијом"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "reachable %s definition here"
 msgstr "%Jпретходна дефиниција је овде"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX entering pop_everything ()\n"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -57781,7 +57833,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -57809,7 +57861,7 @@ msgstr "%<::%D%> није декларисано"
 msgid "request for member %qE in non-class type %qT"
 msgstr "захтев за члан %qD у некласном типу %qT"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -57901,7 +57953,7 @@ msgstr "неисправан ид. шаблона"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "претапање у тип који није ни интегрални ни набројиви не може се јавити у изразу константе"
@@ -58052,7 +58104,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -58188,7 +58240,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -58246,7 +58298,7 @@ msgstr "наредбени изрази дозвољени су само уну
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
@@ -58279,7 +58331,7 @@ msgstr "досег %qT пре %<~%> није име класе"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr ""
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
@@ -58300,13 +58352,13 @@ msgstr "декларација %<~%T%> као члана у %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-име %qD употребљено као декларатор деструктора"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "очекивана је листа наводилаца-одредби"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD није шаблон"
@@ -58346,7 +58398,7 @@ msgstr "непотпун тип %qT употребљен у угњежденом
 msgid "expected nested-name-specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
@@ -58364,7 +58416,7 @@ msgstr "не могу се дефинисати нови типови у пов
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неподржан аргумент за %<__builtin_frame_address%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -58380,1214 +58432,1220 @@ msgstr "ИСО Ц++ забрањује сложене константе"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "неисправна употреба %qD"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, fuzzy, gcc-internal-format
 #| msgid "%<%D::%D%> is not a member of %qT"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> није члан у %qT"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %qs expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "граница низа забрањена је после заграђеног ид. типа"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "покушајте да уклоните заграде око ид. типа"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "употреба старовремског претапања"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "предложи заграде око && унутар ||"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not allow extra %<;%> outside of a function"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ИСО Ц не дозвољава додатно %<;%> изван функције"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+#| msgid "definition of %q#T inside template parameter list"
+msgid "lambda-expression in template parameter type"
+msgstr "дефиниција %q#T унутар листе шаблонских параметара"
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Неочекиван крај модула"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a reference type"
 msgid "%<this%> cannot be captured by reference"
 msgstr "new се не може применити на упућивачки тип"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "увећање само-за-читање променљиве %qD"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "default argument specified for lambda parameter"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "удвостручено %<volatile%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "етикета случаја %qE ван наредбе пребацивања"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "очекивана је декларација или наредба"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "функција враћа низ"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "condition declares a function"
 msgstr "поље %qs декларисано као функција"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "non-local variable %q#D uses local type %qT"
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "не-локална променљива %q#D користи локални тип %qT"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "наредба израза има непотпун тип"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "очекивана је декларација или наредба"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ИСО Ц++ забрањује рачунско goto"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected module-name"
 msgstr "Очекивано је име"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "method declaration not in @interface context"
 msgid "module-declaration not permitted in header-unit"
 msgstr "декларација метода није у контексту @interface"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, gcc-internal-format
 msgid "private module fragment"
 msgstr ""
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "import-declaration must be at global scope"
 msgstr "декларација употребе за не-члан у досегу класе"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%qE may only occur once in an export declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "attributes are not permitted in this position"
 msgstr "атрибут %qE није подржан на овој платформи"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr ""
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "сувишно %<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "забрањено је мешање декларација и дефиниција функција"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "празна декларација"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> употребљено изван класе"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D неисправно у %q#T"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "type-specifier invalid in lambda"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "дефиниција класе не може бити декларисана пријатељем"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in explicit-specifier"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "само конструктори узимају успостављаче основе"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "статичка декларација %q+D прати нестатичку декларацију"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "анахронистични старовремски успостављач основне класе"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (успостављач одређеног члана имплицитно је тип)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "неисправан операнд услова"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
 msgstr "неочекиван операнд"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "кључна реч %<export%> није имплементирана, игнорише се"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<export%> not implemented, and will be ignored"
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "кључна реч %<export%> није имплементирана, игнорише се"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "неисправна ограничења за операнд"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> не може започети листу шаблонских аргумената"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> је другачије написано %<[%>. Убаците размак између %<<%> и %<::%>"
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(Г++ ће прихватити ово ако задате -fpermissive)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid template-argument-list"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 #| msgid "%<<::%> cannot begin a template-argument list"
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<<::%> не може започети листу шаблонских аргумената"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
 msgstr "очекивана је наредба"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "употребите %<%T::template %D%> да назначите да је шаблон"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "очекивани су наводиоци декларације или %<...%>"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специјализација шаблона са Ц повезивошћу"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Очекивано је име"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE не именује тип"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 #| msgid "Recognize GNU-defined keywords"
 msgid "concept defined here"
 msgstr "Препознаје кључне речи које дефинише Гну"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%Jиме за дефиницију типа не може бити угњеждени-именски-наводилац"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибут се игнорише за класе без примерака"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибут се игнорише при предоченом-наводиоцу-типа који није унапредна декларација"
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD није шаблон функције"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD није члан у %qT"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Инструкције min/max нису дозвољене"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Укључи аутоматско извођење шаблона"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "сувишне одредбе се игноришу"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD није име именског простора"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD није име именског простора"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Упозори када се уткана функција не може уткати"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "употреба именског простора %qD као израза"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "opaque-enum-declaration here"
 msgstr "претходном декларацијом %q+#D овде"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD није дефинисано изван досега функције"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT није именски простор"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD није дефинисано изван досега функције"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "имена параметара (без типова) у декларацији функције"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "имена параметара (без типова) у декларацији функције"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: дефиниција функције није претворена\n"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "успостављач дат за функцију"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -59597,479 +59655,479 @@ msgstr "%<%T::%D%> није тип"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "invalid declarator"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "неисправна употреба конструктора као шаблона"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "употреба %<%T::%D%> уместо %<%T::%D%> за именовање конструктора у одређеном имену"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD је именски простор"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "неочекиван операнд"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "недостаје справљачки циљ после %qs"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "%qT not permitted in template argument"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "неисправна употреба %qD"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "подразумевани аргументи су дозвољени само за параметре функција"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "не могу да нађем датотеку за класу %s"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "неисправно име класе у декларацији %qD"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "експлицитној специјализацији мора претходити %<template <>%>"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "претходна дефиниција %q+#T"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "при декларацији пријатеља мора бити употребљена кључна реч class"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "битско поље %qD неинтегралног типа"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (основна класа је имплицитно тип)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD in linkage specification"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "очекиван је идентификатор или %<(%>"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr ""
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "expression must be enclosed in parentheses"
 msgstr "наредба израза има непотпун тип"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "захтевани положај није целобројна константа"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "захтевано равнање није константа"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "премало листа параметара шаблона"
@@ -60078,682 +60136,682 @@ msgstr "премало листа параметара шаблона"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "превише листа шаблонских параметера"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именоване повратне вредности нису више подржане"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "неисправна декларација чланског шаблона у локалној класи"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "декларација шаблона %qs"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> треба да је %<> >%> унутар угњеждене листе шаблонских аргумената"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "сувишно %<>>%>, користите %<>%> за затварање листе шаблонских аргумената"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> пре %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "и %<short%> и %<char%> у наводиоцима декларације"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "удвостручено %qE"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "удвостручено %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<auto%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<co_yield%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "ознака %qs употребљена при именовању %q#T"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT декларисано са већом видљивошћу од своје основе %qT"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 #| msgid "template class without a name"
 msgid "replace the class-key with %qs"
 msgstr "шаблонска класа без имена"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qT defined as %qs here"
 msgstr "%qT се помиње као %qs"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%J%qD декларисано овде"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD поново декларисано са другачијим приступом"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (као разјашњење двосмислености) дозвољено је само унутар шаблона"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "датотека се завршава подразумеваним аргументом"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "конструкција %<@%D%> објективног Ц++а на погрешном месту"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> мора навести тип као аргумент"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "неисправно име селектора објективног Ц++а"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Очекивана је декларација класе или сучеља"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "атрибут %qE се игнорише за %qE"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "очекиван је целобројни израз"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in iterator type"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qD should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "очекиван је израз"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD није чланска шаблонска функција"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "смеће на крају %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "стандардна претварања нису дозвољена у овом контексту"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "неисправна декларација чланског шаблона %qD"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "обухватајући шаблони класа не бивају експлицитно специјализовани"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "специјализација %qD у различитом именском простору"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "специјализација %qD у различитом именском простору"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  из дефиниције %q+#D"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "експлицитно извођење %qD у именском простору %qD (који не обухвата простор %qD)"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "специјализација %qT после извођења"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -60761,156 +60819,156 @@ msgstr "  из дефиниције %q+#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "специјализација %qT после извођења %qT"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable template"
 msgstr "%qD није шаблон"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "ид. шаблона %qD за %q+D не одговара ниједној декларацији шаблона"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "експлицитна специјализација %qD после прве употребе"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "експлицитно извођење %qD у именском простору %qD (који не обухвата простор %qD)"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "експлицитна специјализација %qD после прве употребе"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "недостаје атрибут Code"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
 msgstr "недостаје атрибут Code"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "листа шаблонских параметара употребљена у експлицитном извођењу"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "дефиниција дата за експлицитно извођење"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "превише листа шаблонских параметара у декларацији %qD"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "премало листа шаблонских параметара у декларацији %qD"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "експлицитна специјализација %qD мора бити уведена помоћу %<template <>%>"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD није шаблонска функција"
@@ -60923,156 +60981,156 @@ msgstr "%qD није шаблонска функција"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "нема чланске функције %qD декларисане у %qT"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "friend declaration here"
 msgstr "%Jзаклоњена декларација је овде"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "        %qD"
 msgid "        %s"
 msgstr "        %qD"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "шаблонски параметарски тип %qT декларисан пријатељским"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments for partial specialization %qT"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -61082,19 +61140,19 @@ msgstr[1] "тип %qT шаблонског аргумента %qE зависи 
 msgstr[2] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 msgstr[3] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нема подразумеваног аргумента за %qD"
@@ -61103,53 +61161,53 @@ msgstr "нема подразумеваног аргумента за %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумевани аргумент за параметар типа %qT има тип %qT"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "параметар %qD декларисан празним"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблонска класа без имена"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -61160,59 +61218,59 @@ msgstr "%sчланска функција %qD не може имати кн-од
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "неисправна декларација шаблона %qD"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "шаблонска дефиниција нешаблонског %q#D"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "очекивах %d нивоа шаблонских параметара за %q#D, добих %d"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "добих %d шаблонских параметара за %q#T"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  а потребно је %d"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "обухватајући шаблони класа не бивају експлицитно специјализовани"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT није шаблонски тип"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "наводиоци шаблона нису задати у декларацији %qD"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -61222,7 +61280,7 @@ msgstr[1] "%qD употребљено без параметара шаблона
 msgstr[2] "%qD употребљено без параметара шаблона"
 msgstr[3] "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -61232,148 +61290,148 @@ msgstr[1] "претходном декларацијом %q+#D овде"
 msgstr[2] "претходном декларацијом %q+#D овде"
 msgstr[3] "претходном декларацијом %q+#D овде"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "шаблонски параметар %q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "поново декларисано овде као %q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration %q#D with different constraints"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT није члан из %qT"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "поређење између типова %q#T и %q#T"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs није исправно за %qs"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -61382,328 +61440,328 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT је двосмислена основа за %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "тип %qT није изведен из типа %qT"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the address of %qD is not a valid template argument"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се константне ниске не могу користити у овом контексту"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 #| msgid "template argument for %qD uses local type %qT"
 msgid "in template argument for type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се коси са кн-одредбом"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није константан израз"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "покушајте са %qE уместо тога"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је типа %qT"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "примењивање атрибута на шаблонске параметре није имплементирано"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 #| msgid "Ignoring statement label in empty statement at %C"
 msgid "ignoring attributes in template argument %qE"
 msgstr "Игноришем етикету наредбе у празној наредби код %C"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "неисправна употреба деструктора %qD као типа"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "да упутите на тип шаблонског параметра, употребите %<typename %E%>"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  очекивах константу типа %qT, добих %qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr " очекивах тип, добих %qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  очекивах шаблон класе, добих %qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  очекивах шаблон типа %qD, добих %qD"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "дат за %q+D"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "нешаблонски тип %qT употребљен као шаблон"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "за декларацију шаблона %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template constraint failure for %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE није на почетку декларације"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "стварање показивача на чланску функцију некласног типа %qT"
@@ -61721,313 +61779,313 @@ msgstr "стварање показивача на чланску функциј
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "променљива %qD има функцијски тип"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "неисправан тип параметра %qT"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "у декларацији %q+D"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функција враћа низ"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функција враћа функцију"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "обликовање упућивача на празно"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "стварање показивача на члан празног типа"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT није тип класе, структуре, нити уније"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT се разрешава до %qT, што није класни тип"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависно име %qE рашчлањује се као не-тип, али извођење производи тип"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "ставите %<typename %E%> ако мислите на тип"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "употреба неисправног поља %qD"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "неисправна употреба израза празног типа"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> за аргументе.)"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "неподржан аргумент за %<__builtin_return_address%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT јесте/користи анонимни тип"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT је променљиво измењив тип"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  покушај извођења %qD"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "експлицитно извођење %q#D"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "удвостручено експлицитно извођење %q#D"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %<extern%> на експлицитним извођењима"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "складишна класа %qD примењена на извођење шаблона"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "експлицитно извођење %q#T пре дефиниције шаблона"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %qE на експлицитним извођењима"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "удвостручено експлицитно извођење %q#T"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -62040,169 +62098,169 @@ msgstr "експлицитна специјализација %qD после п
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "експлицитно извођење %qD али дефиниција није доступна"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d извођења %q+D, могуће услед стварања виртуелних табела (употребите -ftemplate-depth-NN да повећате максимум)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "opaque vector types cannot be initialized"
 msgid "a concept cannot be constrained"
 msgstr "непрозирни векторски типови не могу бити успостављени"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT није именски простор"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "функција се не разматра за уткивање"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 #| msgid "explicit qualification in declaration of %qD"
 msgid "explicit deduction guide declared here"
 msgstr "експлицитна одредба у декларацији %qD"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Неисправна декларација метода, неопходан је повратни тип"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "не могу да емулирам %qs"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -62354,590 +62412,590 @@ msgstr "%q+#D се не може декларисати"
 msgid "  since %q+#D declared in base class"
 msgstr "  пошто је %q+#D декларисано у основној класи"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr ""
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "%Hпредложи експлицитне витичасте заграде ради избегавања двосмисленог %<else%>"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "catching non-reference type %q#T"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 #| msgid "type of asm operand %qE could not be determined"
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "тип asm-операнда %qE не може бити одређен"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "Objective-C declarations may only appear in global scope"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "декларације објективног Ц-а могу се јављати само у глобалном досегу"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "неисправна употреба члана %q+D у статичкој чланској функцији"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "%qE missing template arguments"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "аргументи нису дозвољени у деструктору"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> није доступно за статичке чланске функције"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "неисправан одредбени досег у имену псеудодеструктора"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE није типа %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "сложени дословни необјектног типа %qT"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "типски параметри шаблона морају користити кључну реч %<class%> или %<typename%>"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "неисправна употреба типа %qT као подразумеване вредности за шаблонски шаблонски параметар"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "неисправан подразумевани аргумент за шаблонски шаблонски параметар"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "дефиниција %q#T унутар листе шаблонских параметара"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "неисправна дефиниција одређеног типа %qT"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD није тип"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "употреба %<auto%> променљиве из обухватајуће функције"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "употреба параметра из обухватајуће вункције"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter from containing function"
 msgid "use of parameter outside function body"
 msgstr "употреба параметра из обухватајуће вункције"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "missing template arguments"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "шаблонски параметар %qD типа %qT није дозвољен у интегралном константном изразу јер није интегралног или набројивог типа"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "употреба шаблона класе %qT као израза"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "захтев за члан %qD двосмислен је у вишеструком снопу наслеђивања"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип за %qE није познат"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
 msgstr "%qT није шаблонски тип"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "не може се применити %<offsetof%> на деструктор %<~%T%>"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<firstprivate%>"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<lastprivate%>"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<device%> id must be integral"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not allowed in other than a declaration"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%<[*]%> није дозвољено другде осим у декларацији"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "поновљена имплементација класе %qs"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> није дефинисано као показивачки тип"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE is not file, namespace or block scope variable"
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qE није датотека, именски простор нити променљива блоковског досега"
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE has incomplete type"
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "нестатичка декларација %q+D прати статичку декларацију"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 #| msgid "second argument to %<__builtin_expect%> must be a constant"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "други аргумент за %<__builtin_expect%> мора бити константа"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -62946,22 +63004,22 @@ msgstr "неподржан аргумент за %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -62971,1184 +63029,1185 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV одредбе не могу се применити на %qT"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid " declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "основна класа %qT има кн-одредбе"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not public"
 msgstr "%qD није тип"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is mutable"
 msgstr "%qD није тип"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%qD has a non-structural type"
 msgstr "%qD има непотпун тип"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute takes no arguments"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "захтевано init_priority није целобројна константа"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "атрибут %qE може се користити само уз дефиниције објеката класног типа у датотечном досегу"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "захтевано init_priority је ван опсега"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "захтевано init_priority резервисано је за унутрашњу употребу"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "атрибут %qE није подржан на овој платформи"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "декларација %qD као %s"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "провера lang_*: крах у %s, код %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ИСО Ц++ забрањује %s између показивача типа %<void *%> и показивача-на-функцију"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ИСО Ц++ забрањује %s између показивача типа %<void *%> и показивача-на-функцију"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ИСО Ц++ забрањује %s између показивача типа %<void *%> и показивача-на-функцију"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "неисправна примена %qs на чланску функцију"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "неисправна примена %<sizeof%> на битско поље"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ИСО Ц++ забрањује примену %<sizeof%> на израз функцијског типа"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "неисправна примена %<__alignof%> на битско поље"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ИСО Ц++ забрањује примену %<__alignof%> на израз функцијског типа"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "превазиђено претварање из константне ниске у %qT"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "превазиђено претварање из константне ниске у %qT"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "захтев за члан %qD у %qE, које је не-класног типа %qT"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "захтев за члан %qD у %qE, које је не-класног типа %qT"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "неисправна употреба нестатичког чланског податка %qE"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "неисправан приступ нестатичком чланском податку %qD нултог објекта"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "тип који се уништава је %qT, али деструктор упућује на %qT"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT нема члан по имену %qE"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT нема члан по имену %qE"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> није члан у %qT"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT није основа за %qT"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD није чланска шаблонска функција"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT није типа показивач-на-објекат"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "недостаје индекс у упућивачу низа"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексирање низа декларисаног као %<register%>"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "недостаје објекат у употреби %qE"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ИСО Ц++ забрањује звање %<::main%> унутар програма"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "мора се употребити или %<.*%> или %<->*%> за позив показивача на чланску функцију у %<%E (...)%>"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметар %P за %qD непотпуног је типа %qT"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметар %P непотпуног је типа %qT"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "претпоставља се претапање у тип %qT из препуњене функције"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL употребљено аритметички"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ИСО Ц++ забрањује поређење показивача и целобројног"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "неуређено поређење са не-реалним аргументом"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "неисправни операнди типова %qT и %qT за бинарно %qO"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача типа %<void *%> у одузимању"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на метод у одузимању"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "неисправна употреба показивача на непотпун тип у аритметици са показивачима"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "неисправна употреба %qE за добијање показивача-на-чланску-функцију"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  неопходан је одређен ид."
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "заграде око %qE не могу бити коришћене за добијање показивача-на-чланску-функцију"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе неодређене или заграћене нестатичке чланске функције, за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе везане чланске функције за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ИСО Ц++ забрањује узимање адресе функције %<::main%>"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "не може се створити показивач на упућивачки члан %qD"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "не може се узети адреса битског поља %qD"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "taking address of an immediate function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "затражена је адреса експлицитне регистарске променљиве %qD"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "затражена је адреса од %qD, а декларисано је као %<register%>"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %q#T"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "претварање из %qT у %qT"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "претапање из %qT у %qT губи на тачности"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "претапање из %qT у %qT повећава неопходно равнање циљног типа"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ИСО Ц++ забрањује претапање између показивача на функцију и показивача на објекат"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "неисправно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "неисправна употреба константног претапања са типом %qT, који није показивач, нити показивач на члански податак"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "неисправна употреба константног претапања са типом %qT, који је показивач или упућивач на функцијски тип"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "неисправно константно претапање д-вредности типа %qT у тип %qT"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "неисправно константно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ИСО Ц++ забрањује претапање у низовни тип %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  у израчунавању %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несагласни типови у додели %qT у %qT"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "неисправна додела низа"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   у претварању показивача на чланску функцију"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "претварање показивача на члан преко виртуелне основе %qT"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   у претварању показивача на члан"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "лева страна доделе може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "у прослеђивању аргумента %P за %q+D"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "враћање упућивача на привремени"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "враћање упућивача на локалну променљиву %q+D"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "Missing return statement"
 msgid "redundant move in return statement"
 msgstr "Недостаје наредба повратка"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "враћање вредности из деструктора"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "не може се враћати из руковаоца у блоку покушаја у конструктору"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "враћање вредности из конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "недостаје успостављач"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> не сме вратити NULL, осим ако је декларисан уз %<throw()%> (или је задато -fcheck-new)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -64449,114 +64508,108 @@ msgstr "витичасте заграде око скаларног успост
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "скупина типа %qT не може се успостављати сложеном константном"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "прототип за %q#D не одговара ниједном у класи %qT"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поље %qD није нађено у унији која се успоставља"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "индексна вредност уместо имена поља у успостављачу уније"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "откривено кружно прослеђивање показивача"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "основни операнд за %<->%> непоказивачког је типа %qT"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> производи непоказивачки резултат"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "основни операнд за %<->%> није показивач"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE се не може користити као члански показивач, пошто је типа %qT"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "члански показивач %qE не може се применити на %qE, које је некласног типа %qT"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-#| msgid "could not convert template argument %qE to %qT"
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jподразумевано успостављање %q#D, које је упућивачког типа"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "позив функције %qD која баца непотпун тип %q#T"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "позив функције која баца непотпун тип %q#T"
@@ -64576,292 +64629,298 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "extern symbols cannot have initializers"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of type void"
 msgid "variables cannot be of type void"
 msgstr "стварање показивача на члан празног типа"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "cannot be declared to be a function"
 msgstr "new се не може применити на функцијиски тип"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of %<struct %E%>"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "поновна дефиниција %<struct %E%>"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be %s"
 msgstr "не могу да отворим %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be `scope` and `%s`"
 msgstr "не могу да отворим %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "Use the Cygwin interface"
 msgid "field not allowed in interface"
 msgstr "Користи суљеље Сигвина"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "variable-size type declared outside of any function"
 msgid "inout variables can only be declared inside inout functions"
 msgstr "тип променљиве величине декларисан изван било које функције"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 #| msgid "Omit the frame pointer in leaf functions"
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "Изостави показивач оквира у функцијама-листовима"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "manifest constants must have initializers"
 msgstr "само конструктори узимају успостављаче основе"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "size of type %s is invalid"
 msgstr "навод ‘%s’ није исправан"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%s does not have a default initializer"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "is not a static and cannot have static initializer"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "static storage variables cannot have destructors"
 msgstr "јаванска класа %qT не може имати деструктор"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "string expected for library name"
 msgstr "очекивано је име класе"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "string expected for mangled name"
 msgstr "неочекиван операнд"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "без аргумената"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "can only apply to a single declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template declaration of %qs"
 msgid "incomplete mixin declaration (%s)"
 msgstr "декларација шаблона %qs"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "enum %s must have at least one member"
 msgstr "Сопствено ‘%s’ код %L мора имати бар два аргумента"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "circular reference to enum member"
 msgstr "враћање упућивача на привремени"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgid "template tuple parameter must be last one"
 msgstr "типски параметри шаблона морају користити кључну реч %<class%> или %<typename%>"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "рекурзивно уткивање"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "рекурзивно уткивање"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "error instantiating"
 msgstr "грешка при писању %qs"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Logicals at %%L must be compared with %s instead of %s"
 msgid "%s must be a function instead of %s"
 msgstr "Логичке код %%L морају бити поређене са %s уместо %s"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "functions cannot be scope"
@@ -64870,45 +64929,55 @@ msgstr "виртуелне функције не могу бити пријат
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s method can't be abstract"
 msgid "%s functions cannot be abstract"
 msgstr "Метод %s не може бити апстрактан"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot override a non-virtual function"
 msgstr "Упозори на препуњена имена виртуелних функција"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "cannot be both final and abstract"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -64916,189 +64985,189 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot override final function %s"
 msgstr "не могу да искључим уграђену функцију %qs"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "initializer provided for function"
 msgid "multiple overrides of same function"
 msgstr "успостављач дат за функцију"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s at %L"
 msgid "incompatible covariant types %s and %s"
 msgstr "Несагласни рангови у %s код %L"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not allow extra %<;%> outside of a function"
 msgid "does not override any function"
 msgstr "ИСО Ц не дозвољава додатно %<;%> изван функције"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot override final function %s.%s"
 msgstr "не могу да искључим уграђену функцију %qs"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "override only applies to class member functions"
 msgstr "атрибут %qs примењује се само на функције"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "Упозори на препуњена имена виртуелних функција"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s or %s"
 msgid "first argument must be type size_t, not %s"
 msgstr "Ознака %s код %L мора бити типа %s или %s"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "one argument of type void* expected, not %s"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "%s method can't be abstract"
 msgid "structs, unions cannot be abstract"
 msgstr "Метод %s не може бити апстрактан"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "Cyclic class inheritance%s"
 msgid "circular inheritance"
 msgstr "Кружно наслеђивање%s"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "игноришем директоријум дупликат „%s“\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot inherit from final class %s"
 msgstr "не могу да нађем датотеку за класу %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "mixin templates are not regular templates"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "ид. шаблона %qD за %q+D не одговара ниједној декларацији шаблона"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot resolve"
 msgstr "не могу да отворим %s"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "cannot alias an expression %s"
@@ -65114,22 +65183,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, gcc-internal-format
 msgid "has forward references"
 msgstr ""
@@ -65193,23 +65262,22 @@ msgstr ""
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "повратни тип функције не може бити функција"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "Annotate assembler instructions with estimated addresses"
 msgid "naked assembly functions with contracts are not supported"
@@ -65785,7 +65853,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -67015,12 +67083,12 @@ msgstr "успостављачка ниска подсечена да одгов
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Индекс почетка подниске код %L је мањи од један"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Индекс краја подниске код %L премашује дужину ниске"
@@ -67221,7 +67289,7 @@ msgstr "Лоша одредница намере код %C"
 msgid "deferred type parameter at %C"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -69945,7 +70013,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
@@ -70036,7 +70104,7 @@ msgstr "Променљива ‘%s’ код %C не може се редефи
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -70182,12 +70250,12 @@ msgstr "Први аргумент дефинисане доделе код %L м
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Други аргумент дефинисане доделе код %L мора бити намере-у"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Други аргумент сучеља оператора код %L мора бити намере-у"
@@ -70309,589 +70377,589 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "Неисправан трећи аргумент у IBITS код %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Аргументи ‘%s’ и ‘%s’ сопственог ‘%s’ код %L морају бити истог типа"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Кључна реч ‘%s’ код %L је већ придружена другом стварном аргументу"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Више стварних него формалних аргумената у позиву процедуре код %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Недостаје одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Неочекивана одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L не може бити низ претпостављене величине"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити резервљив"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Недостаје одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Недостаје стварни аргумент за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Исти стварни аргумент придружен намере-%s аргументу ‘%s’ и намере-%s аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и има атрибут показивача"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и прослеђује се аргументу намере-%s"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и прослеђује се аргументу намере-%s"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic character length function '%s' at %L must have an explicit interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Аутоматска функција знаковне дужине ‘%s’ код %L мора имати експлицитно сучеље"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Симбол ‘%s’ код %L већ има експлицитно сучеље"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D удволичено са недефинисаним симболом %qs"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Ентитет ‘%s’ код %C је већ присутан у сучељу"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Не могу да претворим %s у %s код %L"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "Садржана процедура ‘%s’ код %L у чистој процедури мора такође бити чиста"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "Садржана процедура ‘%s’ код %L у чистој процедури мора такође бити чиста"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "Ознака %s код %L мора бити типа %s"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "Аргумент димензије код %L мора целобројни"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued internal function '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Унутрашња функција знаковне вредности ‘%s’ код %L не може бити претпостављене дужине"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Процедура ‘%s’ у %s код %L није ни функција ни потпрограм"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Превише аргумената у позиву ‘%s’ код %L"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -71051,37 +71119,37 @@ msgstr "трансформационо сопствено ‘%s’ код %L н
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Позив потпрограма сопственог ‘%s’ код %L није чист"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Позив потпрограма сопственог ‘%s’ код %L није чист"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Проширење: Претварање из %s у %s код %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Претварање из %s у %s код %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Проширење: Претварање из %s у %s код %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Претварање из %s у %s код %L"
@@ -71089,24 +71157,24 @@ msgstr "Претварање из %s у %s код %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "Не могу да претворим %s у %s код %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Не могу да претворим %s у %s код %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -71713,7 +71781,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -73009,12 +73077,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -73184,161 +73252,161 @@ msgstr "Сопствени оператор ‘%s’ поменут код %L н
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за писање код %C: %s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Грешка при отварању датотеке модула ‘%s’ за писање: %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file '%s': %s\n"
 msgid "Cannot delete module file %qs: %s"
 msgstr "%s: не могу да обришем датотеку ‘%s’: %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за писање код %C: %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create temporary file"
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "не могу да направим привремену датотеку"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs at %C already declared"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Сопствено ‘%s’ код %L није укључено у изабрани стандард"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs already declared"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "Наредба %s код %C није унутар петље"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot assign to a named constant at %C"
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "Не могу да доделим у именовану константу код %C"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за читање код %C: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Датотека ‘%s’ отворена код %C није модул Гфортрана"
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -73921,8 +73989,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
@@ -76135,7 +76203,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Етикета %d поменута код %L није дефинисана"
@@ -76266,7 +76334,7 @@ msgstr "Не могу да разрешим одређену функцију 
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -76445,230 +76513,230 @@ msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може
 msgid "Impure function at %L might not be evaluated"
 msgstr "Одредница облика код %L не може бити негативна"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Недозвољен нулти корак код %L"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "недостаје индекс у упућивачу низа"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Није наведена десна горња граница низа претпостављене величине код %L"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Индекс у димензији %d је ван граница код %L"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Индекс низа код %L мора бити скалар"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Индекс низа код %L мора бити целобројни"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Проширење: реални индекс низа код %L"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Аргумент димензије код %L мора целобројни"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Индекс низа код %L је низ ранга %d"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Индекс почетка подниске код %L мора бити целобројни"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Индекс почетка подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Индекс краја подниске код %L мора бити целобројни"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут показивача код %L"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут резервљивости код %L"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Два или више делимична упућивача са ненултим рангом не смеју бити наведени код %L"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -76678,12 +76746,12 @@ msgstr "Низ претпостављеног облика код %L мора б
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -76693,312 +76761,312 @@ msgstr "Низ претпостављеног облика код %L мора б
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s',used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’, употребљена у одредничком изразу, користи се код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’ употребљена је код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "променљива примерка %qs декларисана је %s"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, fuzzy, gcc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "Ознака %s код %L мора бити скалар"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Израз за почетак у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Израз за крај у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Израз за корак у FORALL код %L мора бити скаларни %s"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Израз за корак у FORALL код %L не може бити нула"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Израз у наредби ALLOCATE код %L мора бити резервљив или показивач"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear an the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’ не може да се јави у одредници низа код %L у истој наредби резервисања где се и само резервише"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -77007,298 +77075,298 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Израз у наредби CASE код %L мора бити врста %d"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Израз у наредби CASE код %L мора бити скалар"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE код %L не може бити праћен другим DEFAULT CASE код %L"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логички опсег у наредби CASE код %L није дозвољен"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "константна логичка вредност у наредби CASE поновљена је код %L"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Одредница опсега код %L не може никако бити поклопљена"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Блок логичког SELECT CASE код %L има више од два случаја"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Име ‘%s’ се не може употребити као дефинисани оператор код %C"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати резервљиве компоненте"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Елемент преноса података код %L не може бити пун упућивач на низ претпостављене величине"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Одредба NUM_THREADS код %L захтева скаларни целобројни израз"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Наредба код %L није исправна наредба циља гранања за наредбу гранања код %L"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -77306,12 +77374,12 @@ msgstr "Гранање код %L води у бесконачну петљу"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -77319,206 +77387,206 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Маска у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Циљ доделе у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподржана наредба унутар WHERE код %L"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL са индексом ‘%s’ изазива више од једне доделе овом објекту код %L"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Спољашња конструкција FORALL већ има индекс са овим именом %L"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Одредба WHERE/ELSEWHERE код %L захтева логички низ"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "Наредба ASSIGNED GOTO код %L захтева целобројну променљиву"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Променљивој ‘%s’ није додељена циљна етикета код %L"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Алтернативна наредба повратка код %L захтева скаларни целобројни наводилац повратка"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Аритметичко IF код %L захтева бројевни израз"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Излазни услов из петље DO WHILE код %L мора бити скаларни логички израз"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба маске у FORALL код %L захтева логички израз"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -77526,1069 +77594,1069 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "величина низа %qs је превелика"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скаларни објекат ‘%s’ код %L не може бити резервљив"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, fuzzy, gcc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Низ модула или главног програма ‘%s’ код %L мора имати константан облик"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Ентитет са претпостављеном знаковном дужином код %L мора бити лажни аргумент или параметар"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Резервљиво ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Аутоматски низ ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "у %s, код %s:%d"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "‘%s’ је приватног типа и не може бити лажни аргумент у ‘%s’, који је јаван код %L"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Елементална функција ‘%s’ код %L мора имати скаларни резултат"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
 # no-c-format
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити рекурзивна"
 
 # no-c-format
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити опциони"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Знаковна дужина компоненте ‘%s’ мора бити константан одреднички израз код %L."
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Компонента ‘%s’ је приватни тип и не може бити компонента у ‘%s’, која је јавна код %L"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонента %s типа SEQUENCE декларисаног код %L нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qD није декларисано"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Параметарски низ ‘%s’ код %L не може бити аутоматског или претпостављеног облика"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Имплицитно типски параметар ‘%s’ код %L не одговара каснијем имплицитном типу"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несагласан изведени тип у параметру код %L"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Лоша одредница за низ претпостављене величине код %C"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Низ претпостављене величине код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Симбол код %L није лажна променљива"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Изведени тип ‘%s’ код %L је типа ‘%s’, који није дефинисан."
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Лажна процедура код %L није дозвољена у елементалној процедури"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Нитно-приватно код %L не снима се"
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA елемент ‘%s’ код %L мора бити у заједничком"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "Наредба DATA код %L има више променљивих него вредности"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "Наредба DATA код %L има више вредности него променљивих"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Ознака %d код %L дефинисана али неупотребљена"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Ознака %d код %L дефинисана али не може бити употребљена"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L не може имати резервљиве компоненте како би била објекат еквиваленције"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Променљива изведеног типа ‘%s’ код %L са подразумеваним успостављачем не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L са показивачким компонентама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Члан заједничког блока ‘%s’ код %L не може бити објекат еквиваленције у чистој процедури ‘%s’"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именована константа ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Низ ‘%s’ код %L са неконстантним границама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонената структуре ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подниска код %L има нулту дужину"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Различите знаковне дужине у додели показивача код %L"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Унос ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура корисничког оператора ‘%s’ код %L не може бити претпостављене знаковне дужине"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Први аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Други аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Сучеље оператора код %L мора имати, највише, два аргумента"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -79526,17 +79594,17 @@ msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "лош тип израза током хода (%d)"
@@ -79639,119 +79707,119 @@ msgstr "Очекиван је успостављачки израз код %C"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "сопствена променљива која није процедура"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value of function %qs at %L not set"
 msgstr "Враћај вредности функција у регистрима ФПУа"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Deferred type parameter not yet supported"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "декларација зачеља за модулску променљиву %s већ постоји"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable %s declared at %L"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Неупотребљена променљива %s декларисана код %L"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "Превише аргумената за %s код %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable %s declared at %L"
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Неупотребљена променљива %s декларисана код %L"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable %s declared at %L"
 msgid "Unused variable %qs declared at %L"
 msgstr "Неупотребљена променљива %s декларисана код %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "Unused parameter %qs declared at %L"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Враћај вредности функција у регистрима ФПУа"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Непознат сопствени оператор"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Непозната функције листе аргумената код %L"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -79922,7 +79990,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
@@ -80065,7 +80133,7 @@ msgstr "-G и -static су међусобно искључиви"
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-G и -static су међусобно искључиви"
 
 #: lto/lto-object.c:107
@@ -81295,7 +81363,7 @@ msgstr "непрепознато име одељка „%s“"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr ""
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized option '-%s'"
 msgid "Unrecognized option: %qs"
@@ -81314,15 +81382,15 @@ msgstr "недостаје име макроа после %qs"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "недостаје име датотеке после %qs"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "недостаје путања после %qs"
@@ -81378,7 +81446,7 @@ msgstr "недостаје име"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "непрепозната вредност видљивости „%s“"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized scalar storage order value %qs"
@@ -81473,105 +81541,105 @@ msgstr "%qs је превазиђено"
 msgid "unknown linker output %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown excess precision style %qs"
 msgstr "непознат стил распетљавања „%s“"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "unknown floating point contraction style %qs"
 msgstr "аргумент који није у покретном зарезу за функцију %qs"
 
-#: common.opt:1718
+#: common.opt:1722
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown IRA algorithm %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "непознато име регистра: %s"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "недостаје тврдња после %qs"
 
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "непознат ТЛС модел „%s“"
 
-#: common.opt:2232
+#: common.opt:2236
 #, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr ""
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown profile update method %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Live-Patching Level %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2690
+#: common.opt:2694
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown TLS model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:3067
+#: common.opt:3071
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "непрепозната вредност видљивости „%s“"
 
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
@@ -84952,9 +85020,6 @@ msgstr "непознат машински режим %qs"
 #~ msgid "no members matching %<%T::%D%> in %q#T"
 #~ msgstr "нема члана који одговара %<%T::%D%> у %q#T"
 
-#~ msgid "strong using only meaningful at namespace scope"
-#~ msgstr "јако using има смисла само у досегу именског простора"
-
 #~ msgid "current namespace %qD does not enclose strongly used namespace %qD"
 #~ msgstr "текући именски простор %qD не обухвата јако употребљени именски простор %qD"
 
diff --git a/gcc/po/sv.po b/gcc/po/sv.po
index 0ce38c52cb0c9..c42e5182f1c7e 100644
--- a/gcc/po/sv.po
+++ b/gcc/po/sv.po
@@ -27,7 +27,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 11.1-b20210321\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2021-04-12 18:31+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
@@ -1288,11 +1288,11 @@ msgstr "    inline:ad från %qs"
 msgid "this is the insn:"
 msgstr "detta är instruktionen:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "kan inte generera omläsningar för omöjliga begränsningar:"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "kan inte generera omläsningar för:"
 
@@ -1463,16 +1463,16 @@ msgstr "okänd instruktion:"
 msgid "insn does not satisfy its constraints:"
 msgstr "instruktionen håller inte sina begränsningar:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "skapad och använd med olika inställningar av ”%s”"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "skapad och använd med olika inställningar av %<-fpic%>"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "skapad och använd med olika inställningar av %<-fpie%>"
 
@@ -1511,7 +1511,7 @@ msgstr "%s%svarning: %s-huvud version %s skiljer från biblioteksversion %s.\n"
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC heuristik: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1955,83 +1955,83 @@ msgstr "längdmodifierare i strfmon-format"
 msgid "<command-line>"
 msgstr "<kommandorad>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ej stödd operand för kod ”%c”"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ogiltig operand för ”%%%c”"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, c-format
 msgid "invalid vector constant"
 msgstr "ogiltig vektorkonstant"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "inkompatibla flyttals-/vektorregisteroperander för ”%%%c”"
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "inkompatibla registeroperander för ”%%%c”"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "operand saknas"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "ogiltig konstant"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "ogiltig operand"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ogiltig operandprefix ”%%%c”"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, c-format
 msgid "invalid address mode"
 msgstr "ogiltigt adressläge"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ogiltig konvertering från typen %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ogiltig konvertering till typen %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "operationen är inte tillåten på typen %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "det går inte att kombinera GNU- och SVE-vektorer i en binär operation"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "”%%&” använt utan någon lokal dynamisk TLS-referens"
@@ -2047,18 +2047,18 @@ msgid "invalid %%r value"
 msgstr "ogiltigt %%r-värde"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "ogiltigt %%R-värde"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "ogiltigt %%N-värde"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "ogiltigt %%P-värde"
@@ -2088,7 +2088,7 @@ msgstr "ogiltigt %%M-värde"
 msgid "invalid %%U value"
 msgstr "ogiltigt %%U-värde"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "ogiltigt %%s-värde"
@@ -2098,7 +2098,7 @@ msgstr "ogiltigt %%s-värde"
 msgid "invalid %%C value"
 msgstr "ogiltigt %%C-värde"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "ogiltigt %%E-värde"
@@ -2111,7 +2111,7 @@ msgstr "okänd avspecifikation av omlokalisering"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ogiltig %%xn-kod"
@@ -2193,35 +2193,35 @@ msgstr "ogiltig UNSPEC som operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "okänd förmodad konstant"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "ogiltig skiftoperand"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "förutsade Thumb-instruktion"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "förutsade instruktion i villkorlig sekvens"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ej stödd operand för kod ”%c”"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2229,13 +2229,13 @@ msgstr "Ej stödd operand för kod ”%c”"
 msgid "invalid operand for code '%c'"
 msgstr "ogiltig operand för kod ”%c”"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktionen aldrig utförd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "föråldrad Maverick-formatkod ”%c”"
@@ -2357,8 +2357,8 @@ msgstr "ej stödd operand"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2721,7 +2721,7 @@ msgstr "ogiltig operation på %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ogiltig %%P-operand"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "ogiltigt %%p-värde"
@@ -2775,7 +2775,7 @@ msgid "post-increment address is not a register"
 msgstr "efterinkrementeringsadress är inte ett register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "felaktig adress"
 
@@ -2827,8 +2827,8 @@ msgstr "%%%c är inte ett giltigt operandprefix"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "felaktig användning av ”%%%c”"
@@ -2964,286 +2964,286 @@ msgstr "Slut på stackutrymme.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Försök köra ”%s” i skalet för att öka dess gräns.\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "%<-mvsx%> kräver hårdvaruflyttal"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> behöver indexerad adressering"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "%<-mvsx%> och %<-mno-altivec%> är inkompatibla"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "%<-mno-altivec%> avaktiverar vsx"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<-mquad-memory%> kräver 64-bitarsläge"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> förutsätter 64-bitarsläge"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> är inte tillgängligt i läget med omvänd byteordning"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr "felaktig förflyttning"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr "Felaktig 128-bitsförflyttning"
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, c-format
 msgid "invalid %%A value"
 msgstr "ogiltigt %%A-värde"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "ogiltigt %%D-värde"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, c-format
 msgid "invalid %%e value"
 msgstr "ogiltigt %%e-värde"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "ogiltigt %%f-värde"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "ogiltigt %%F-värde"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "ogiltigt %%G-värde"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "ogiltig %%j-kod"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "ogiltig %%J-kod"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "ogiltigt %%k-värde"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "ogiltigt %%K-värde"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "ogiltigt %%O-värde"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "ogiltigt %%q-värde"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, c-format
 msgid "invalid %%t value"
 msgstr "ogiltigt %%t-värde"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "ogiltigt %%T-värde"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "ogiltigt %%u-värde"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "ogiltig %%v-kod"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, c-format
 msgid "invalid %%V value"
 msgstr "ogiltigt %%V-värde"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "ogiltigt %%x-värde"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, c-format
 msgid "invalid %%z value"
 msgstr "ogiltigt %%z-värde"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ogiltigt %%y-värde, försök använda ”Z”-begränsningen"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Felaktig blandning av IEEE 128-bitars och IBM 128-bitars flyttalstyper"
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argument skickat till funktion utan prototyp"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 msgid "Could not generate addis value for fusion"
 msgstr "Kunde inte generera addis-värde för sammanslagning"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kan inte generera ladda/lagra-avstånd för sammanslagning"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr "Felaktig GPR-sammanslagning"
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ogiltig konvertering från typen %<__vector_quad%>"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ogiltig konvertering till typen %<__vector_quad%>"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ogiltig konvertering från typen %<__vector_pair%>"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ogiltig konvertering till typen %<__vector_pair%>"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "ogiltig konvertering från typen %<* __vector_quad%>"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "ogiltig konvertering till typen %<* __vector_quad%>"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "ogiltig konvertering från typen %<* __vector_pair%>"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "ogiltig konvertering till typen %<* __vector_pair%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "symboliska minnesreferenser stödjs endast på z10 eller senare"
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "kan inte dekomponera adress"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ogiltig jämförelseoperator för utmatningsmodifieraren ”E”"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ogiltig referens för utmatningsmodifieraren ”J”"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ogiltig adress för utmatningsmodifieraren ”O”"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ogiltig adress för utmatningsmodifieraren ”R”"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "minnesreferens förväntas för utmatningsmodifieraren ”S”"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ogiltig adress för ”S”-utmatningsmodifierare"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "register- eller minnesuttryck förväntas för utmatningsmodifieraren ”N”"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "register- eller minnesuttryck förväntas för utmatningsmodifieraren ”M”"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ogiltig konstant för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ogiltig konstant - försök med att använda en utmatningsmodifierare"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ogiltig konstant vektor för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ogiltigt uttryck - försök med att använda en utmatningsmodifierare"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ogiltigt uttryck för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 msgid "vector argument passed to unprototyped function"
 msgstr "vektorargument skickat till funktion utan prototyp"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr "typer skiljer i teckenhet"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr "binäroperator stödjer inte två vektorbooleanoperander"
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr "den binära operatorn stödjer inte vektor-bool-operand"
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binär operator stödjer inte blandning av operanderna vektorboolean och flyttalsvektor"
 
@@ -3506,8 +3506,8 @@ msgstr "({anonym})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> förväntades"
@@ -3527,7 +3527,7 @@ msgstr "%<;%> förväntades"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> förväntades"
@@ -3535,7 +3535,7 @@ msgstr "%<)%> förväntades"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> förväntades"
@@ -3553,21 +3553,21 @@ msgstr "%<;%>, %<,%> eller %<)%> förväntades"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> förväntades"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> förväntades"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> förväntades"
@@ -3578,13 +3578,13 @@ msgstr "%<{%> förväntades"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> förväntades"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> förväntades"
@@ -3593,7 +3593,7 @@ msgstr "%<while%> förväntades"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> förväntades"
@@ -3602,18 +3602,18 @@ msgstr "%<,%> förväntades"
 msgid "expected %<.%>"
 msgstr "%<.%> förväntades"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> förväntades"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> förväntades"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> förväntades"
@@ -3621,28 +3621,28 @@ msgstr "%<,%> eller %<)%> förväntades"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> förväntades"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> förväntades"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> förväntades"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> förväntades"
@@ -3657,29 +3657,29 @@ msgstr "etikett förväntades"
 msgid "candidate:"
 msgstr "kandidat:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 msgid "  after user-defined conversion:"
 msgstr "  efter användardefinierad konvertering:"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidat är:"
 msgstr[1] "kandidater är:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "hopp till etikett %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "hopp till case-etikett"
 
@@ -3898,27 +3898,27 @@ msgstr "parametern %qD får inte förekomma i detta sammanhang"
 msgid "local variable %qD may not appear in this context"
 msgstr "lokal variabel %qD får inte förekomma i detta sammanhang"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using enum%> är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 msgid "%<using enum%> of dependent type %qT"
 msgstr "%<using enum%> av beroende typ %qT"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%<using enum%> av icke-uppräkningstypen %q#T"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "%<using enum%> av ofullständig typ %qT"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr "%<using enum%> av %qT före dess enum-specificerare"
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "kandidater är:"
 
@@ -3962,48 +3962,48 @@ msgstr "konvertering konverterar bort konstantskap"
 msgid "source type is not polymorphic"
 msgstr "källtypen är inte polymorfisk"
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "fel typ på argument till unärt minus"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "fel typ på argument till unärt plus"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "fel typ på argument till bitkomplement"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "fel typ på argument till abs"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "fel typ på argument till konjunktion"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr "i argument till unärt !"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr "ingen pre-ökningsoperator för typen"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr "ingen post-ökningsoperator för typen"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr "ingen pre-minskningsoperator för typen"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr "ingen post-minskningsoperator för typen"
 
@@ -4108,7 +4108,7 @@ msgstr "Vektorbindning stämmer inte för dimension 2 av vektorn (%ld/%ld)"
 msgid "Driving:"
 msgstr "Driver:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "aktuellt argument till INTENT = OUT/INOUT"
 
@@ -4238,7 +4238,7 @@ msgstr "Felaktig operator"
 msgid "Bad type in constant expression"
 msgstr "Felaktig typ i konstant uttryck"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "Oväntat modulslut"
 
@@ -4266,11 +4266,11 @@ msgstr "block-IF"
 msgid "implied END DO"
 msgstr "implicerat END DO"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "tilldelning"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "pekartilldelning"
 
@@ -4356,154 +4356,154 @@ msgstr "resultat med teckenlängd som inte är konstant"
 msgid "bind(c) procedure"
 msgstr "bind(c)-procedur"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ogiltigt sammanhang för NULL()-pekare vid %%L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operand till unär numerisk operator %%<%s%%> vid %%L är %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Oväntade entiteter av härledd typ i binär inbyggd numerisk operator %%<%s%%> vid %%L"
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operander till binär numerisk operator %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanderna till strängkonkateneringsoperatorn vid %%L är %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till logiska operatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand till operatorn .not. vid %%L är %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-kvantiteter kan inte jämföras vid %L"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logiska vid %%L måste jämföras med %s istället för %s"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till jämförelseoperatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Okänd operator %%<%s%%> vid %%L; menade du ”%s”?"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Okänd operator %%<%s%%> vid %%L"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Inkonsistenta ordningar för operator vid %%L och %%L"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr "Slingvariabel"
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr "iteratorvariabel"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr "Startuttryck i DO-slinga"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr "Slututtryck i DO-slinga"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr "Steguttryck i DO-slinga"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE-objekt"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr "ALLOCATE-objekt"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr "STAT-variabel"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr "ERRMSG-variabel"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr "objekt i READ"
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK-variabel"
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Olika CHARACTER-längder (%ld/%ld) i vektorkonstruerare"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Heltalsspill vid beräkning av mängden minne att allokera"
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "Värdet på PDT LEN-parametern ”%s” stämmer inte överens med det i attrappdeklarationen"
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Aktuell stränglängd matchar inte den deklarerade för attrappargument ”%s” (%ld/%ld)"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Aktuell stränglängd är kortare än den deklarerade för attrappargument ”%s” (%ld/%ld)"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Målet för återavbildning av ordning är för litet (%ld < %ld)"
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr "Tilldelning av skalär till en oallokerad vektor"
 
@@ -4628,26 +4628,26 @@ msgstr "Vektorreferens utanför gränserna"
 msgid "Incorrect function return value"
 msgstr "Felaktigt returvärde för funktion"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, c-format
 msgid "Error allocating %lu bytes"
 msgstr "Fel vid allokering av %lu byte"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "Försök att allokera redan allokerad variabel ”%s”"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr "Försök att allokera redan allokerad variabel"
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "Försök att DEALLOCATE oallokerad ”%s”"
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr "Fel vid reallokering till %lu byte"
@@ -4842,15 +4842,15 @@ msgstr "-Xbind-now och -Xbind-lazy är inkompatibla"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr "överväg att använda ”-pg” istället för ”-p” med gprof (1)"
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "får inte använda både -EB och -EL"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-mfloat-abi=soft och -mfloat-abi=hard får inte användas tillsammans"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian och -mlittle-endian får inte användas tillsammans"
 
@@ -4866,8 +4866,8 @@ msgstr "ingen processortyp angiven för länkning"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "ange inte både -march=... och -mcpu=..."
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared och mdll är inkompatibla"
 
@@ -5027,10 +5027,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Varna om vektortemporärer skapas."
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Gör ingenting.  Bevarad för bakåtkompatibilitet."
@@ -5505,160 +5505,160 @@ msgstr "Lägg alla lokala vektorer på stacken."
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "Sätt modulentiteternas standardtillgänglighet till PRIVATE."
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "Försök placera ut härledda typer så kompakt som möjligt."
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "Skydda parenteser i uttryck."
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr "Sökväg till huvudfil som skall för-inkluderas före varje kompileringsenhet."
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr "Aktivera intervallkontroller under kompilering."
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr "Tolka en REAL(4) som en REAL(8)."
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr "Tolka en REAL(4) som en REAL(10)."
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr "Tolka en REAL(4) som en REAL(16)."
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr "Tolka en REAL(8) som en REAL(4)."
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr "Tolka en REAL(8) som en REAL(10)."
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr "Tolka en REAL(8) som en REAL(16)."
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr "Omallokera vänsterhandssidan i tilldelningar."
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Använd 4-bytes postmarkeringar för oformaterade filer."
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Använd 8-bytes postmarkeringar för oformaterade filer."
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr "Allokera lokala variabler på stacken för att möjliggöra indirekt rekursion."
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "Kopiera vektorsektioner till sammanhängande block vid procedurstart."
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr "-fcoarray=<none|single|lib>\tAnge vilken co-vektorsparallellisering som skall användas."
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr "-fcheck=[...]\tAnge vilka körtidskontroller som skall utföras."
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "Lägg till ett andra understrykningstecken om namnet redan innehåller ett understrykningstecken."
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr "Använd negativt tecken på nollvärden."
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr "Tillåt inte svansanropsoptimering när en anropande rutin kan ha utelämnat teckenlängder."
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr "Lägg till understrykningstecken till externt synliga namn."
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Gör ingenting.  Bevarad för bakåtkompatibilitet."
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr "Länka statiskt till GNU:s Fortran-hjälpbibliotek (libgfortran)."
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Följ standarden ISO Fortran 2003."
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Följ standarden ISO Fortran 2008."
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Följ standarden ISO Fortran 2008 inklusive TS 29113."
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Följ standarden ISO Fortran 2018."
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Följ standarden ISO Fortran 95."
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr "Följ inget särskilt."
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr "Acceptera utökningar för att stödja gammal kod."
@@ -6337,8 +6337,9 @@ msgstr "Varna för avallokeringsanrop med argument returnerade från allokerings
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99883
 #: c-family/c.opt:803
-#, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+#, fuzzy, no-c-format
+#| msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr "Varna för anrop som inte stämmer överens mellan anrop till operatorn new eller delete och det motsvarande anropet till allokerings- eller avallokeringsfunktionen."
 
 #: c-family/c.opt:808
@@ -6961,8 +6962,8 @@ msgstr "-faligned-new=<N>\tAnvänd C++17 allokering av överjusterade typer för
 msgid "Allow variadic functions without named parameter."
 msgstr "Tillåt variadiska funktioner utan namngiven parameter."
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr "Stödjs inte längre."
@@ -7319,466 +7320,461 @@ msgstr "Ange standard-OpenACC-beräkningsdimensioner."
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr "-fopenacc-kernels=[decompose|parloops]\tAnge läge för hantering av OpenACC ”kernels”-kontruktioner."
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "Aktivera OpenMP (implicerar -frecursive i Fortran)."
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "Aktivera OpenMP:s SIMD-direktiv."
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "Acceptera C++-nyckelord som ”compl” och ”xor”."
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "Sök efter och använd PCH-filer även vid preprocessning."
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr "Nedgradera följsamhetsfel till varningar."
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr "Aktivera språkutvidgningar från Plan 9."
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr "Betrakta indatafilen som redan preprocessad."
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr "-ftrack-macro-expansion=<0|1|2>\tSpåra platser för symboler som kommer från makroexpansion och visa dem i felmeddelanden."
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr "Finskriv inte mallspecialiseringar som mallsignaturer följda av argumenten."
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr "Hantera kända sprintf-returvärden som konstanter."
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "Används i Fix-and-Continue-läge för att objektfiler kan bytas ut vid körtillfället."
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "Borttagen i GCC 10.  Denna flagga har ingen effekt."
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr "Generera typbeskrivarinformation för körtid."
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "Använd den smalaste möjliga heltalstypen för uppräkningstyper."
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "Tvinga den underliggande typen för ”wchar_t” att vara ”unsigned short”."
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "När ”signed” eller ”unsigned” inte anges låt bitfältet ha tecken."
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr "Låt ”char” ha tecken som standard."
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "Slå på stöd för C++14 storleksbestämd deallokering."
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr "-fsso-struct=[big-endian|little-endian|native]\tSätt standardordning för skalärlagring."
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr "Visa statistik som samlats under kompilering."
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "Antag att värdena i uppräkningstyper alltid finns inom det minsta intervallet av den typen."
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr "Följ C++17-krav på evalueringordning för tilldelningsuttryck, skift, medlemsfunktionsanrop, etc."
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "Sätt det maximala antalet mallinstansieringsnoter för en enskild varning eller fel."
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "-ftemplate-depth=<antal>\tAnge maximalt instansieringsdjup för mallar."
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "-fno-threadsafe-statics\tGenerera inte trådsäker kod för initiering a lokala statiska variabler."
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "När ”signed” eller ”unsigned” inte anges görs bitfälten teckenlösa."
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "Gör ”char” teckenlöst som standard."
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr "Använd __cxa_atexit till registerdestruerare."
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "Använd __cxa_get_exception_ptr i undantagshantering."
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "Markerar alla inline:ade funktioner och metoder att ha dold synlighet."
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "Ändrar synlighet till att vara som Microsoft Visual Studio som standard."
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr "Mata ut common-liknande symboler som svaga symboler."
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-fwide-exec-charset=<tknst>\tKonvertera alla breda strängar och teckenkonstanter till teckenuppsättningen <tknst>."
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "Generera ett #line-direktiv som pekar på aktuell katalog."
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "Generera lata klassuppslagningar (via objc_getClass()) att användas i läget Zero-Link."
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr "Skicka deklarationer till en .decl-fil."
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "-femit-struct-debug-baseonly\tAggressivt reducerad felsökningsinformation för poster."
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "-femit-struct-debug-reduced\tKonservativt reducerad felsökningsinformation för poster."
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "-femit-struct-debug-detailed=<spec-lista>\tDetaljreducerad felsökningsinformation för poster."
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr "Tolka imaginära, flyttals-, eller andra gnu-suffix på tal som motsvarande talkonstant snarare än en användardefinierad talkonstant."
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <kat>\tLägg till <kat> till slutet av sökvägen för systeminkluderingar."
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "-imacros <fil>\tTag med definitioner av makron i <fil>."
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-imultilib <kat>\tSätt <kat> att vara inkluderingsunderbiblioteket för multibibliotek."
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "-include <fil>\tInkludera innehållet i <fil> före andra filer."
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "-iprefix <skvg>\tAnge <skvg> som ett prefix för de följande två flaggorna."
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <kat>\tSätt <kat> som rotkatalog för systemet."
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <kat>\tLägg till <kat> till början av sökvägen för systeminkluderingar."
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-iquote <kat>\tLägg till <kat> till slutet av sökvägen för citerade inkluderingar."
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <kat>\tLägg till <kat> till slutet av sökvägen för systeminkluderingar."
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <kat>\tLägg till <kat> till slutet av huvudsökvägen."
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "Sök inte standardkataloger för inkluderingar (de som anges med -isystem kommer fortfarande att användas)."
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr "Sök inte i standardkataloger för systeminkluderingar för C++."
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr "Generera C-huvuden för plattformsspecifika funktioner."
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr "Översätt filnamn när filer inkluderas."
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Följ standarden ISO 1998 C++ reviderad av 2003 års tekniska rättelser."
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Följ standarden ISO 2011 C++."
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Undanbedes till förmån för -std=c++11."
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Undanbedes till förmån för -std=c++14."
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Följ standarden ISO 2014 C++."
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr "Undanbedes till förmån för -std=c++17."
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "Följ standarden ISO 2017 C++."
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Följ standarden ISO 2020 C++ (experimentellt och ofullständigt stöd)."
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Följ standardutkastet ISO 2023 C++ (experimentellt och ofullständigt stöd)."
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Följ standarden ISO 2011 C."
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "Undanbedes till förmån för -std=c11."
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Följ standarden ISO 2017 C (publicerades 2018)."
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Följ standardutkastet ISO 202X C (experimentellt och ofullständigt stöd)."
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Följ standarden ISO 1990 C."
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Följ standarden ISO 1999 C."
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr "Undanbedes till förmån för -std=c99."
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Följ standarden ISO 1998 C++ reviderad av 2003 års tekniska rättelser med GNU-utökningar."
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Följ standarden ISO 2011 C++ med GNU-utökningar."
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Undanbedes till förmån för -std=gnu++11."
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Undanbedes till förmån för -std=gnu++14."
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Följ standarden ISO 2014 C++ med GNU-utökningar."
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "Undanbedes till förmån för -std=gnu++17."
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "Följ standarden ISO 2017 C++ med GNU-utökningar."
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Följ standarden ISO 2020 C++ med GNU-utökningar (experimentellt och ofullständigt stöd)."
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Följ standardutkastet ISO 2023 C++ med GNU-utökningar (experimentellt och ofullständigt stöd)."
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Följ standarden ISO 2011 C med GNU-utökningar."
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Undanbedes till förmån för -std=gnu11."
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Följ standarden ISO 2017 C (publicerades 2018) med GNU-utökningar."
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Följ standardutkastet ISO 202X C med GNU-utökningar (experimentellt och ofullständigt stöd)."
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Följ standarden ISO 1990 C med GNU-utökningar."
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Följ standarden ISO 1999 C med GNU-utökningar."
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Undanbedes till förmån för -std=gnu99."
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Följ standarden ISO 1990 C med tillägg från 1994."
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Undanbedes till förmån för -std=iso9899:1999."
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr "-stdlib=[libstdc++|libc++]\tStandardbiblioteket att använda för C++-huvuden och körtid."
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "Aktivera traditionell preprocessning."
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\tStöd trigrafer enligt ISO C."
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr "Fördefiniera inte systemspecifika och GCC-specifika makron."
@@ -8023,6 +8019,12 @@ msgstr "Kompilera in enhetstestkod."
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr "-fversion=<nivå|ident>\tKompilera in versionskod ≥ <nivå> eller identifierad av <ident>."
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+#| msgid "Emit implicit instantiations of templates."
+msgid "Emit template instantiations as weak symbols."
+msgstr "Skapa implicita instansieringar av mallar."
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9260,143 +9262,155 @@ msgstr "Stöd mer än 8192 GOT-poster på ColdFire."
 msgid "Support TLS segment larger than 64K."
 msgstr "Stöd TLS-segment större än 64 k."
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr "Antag att mål-CPU:n är konfigurerad för rak byteordning."
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr "Antag att mål-CPU:n är konfigurerad med omvänd byteordning."
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "-mbranch-cost=N\tAnge kostnaden för grenar till ungefär N instruktioner."
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr "Vid generering av -fpic-kod, tillåt användningen av PLT:er.  Ignoreras för fno-pic."
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "Ange anropskonvention för heltal och flyttal."
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Försök håll stacken justerad till denna 2-potens."
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "Stödda ABI:er (att användas med flaggan -mabi=):"
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Använd instruktioner i hårdvara för division och kvadratrot av flyttal."
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr "Använd instruktioner i hårdvara för heltalsdivision."
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr "-march=\tGenerera kod för angiven RISC-V ISA (t.ex. RV64IM).  ISA-strängar måste vara i gemener."
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=PROCESSOR\tOptimera utmatningen för PROCESSOR."
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "-mtune=PROCESSOR\tAnvänd arkitekturen hos och optimera utmatningen för PROCESSOR."
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "-msmall-data-limit=N\tPlacera globala and statiska data mindre än <antal> byte i en speciell sektion (vissa arkitekturer)."
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "Använd mindre men långsammare prolog- och epilogkod."
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr "Konvertera BASE + LARGE_OFFSET-adresser till NEW_BASE + SMALL_OFFSET för att tillåta att minnesåtkomster genereras som komprimerade instruktioner. Siktar för närvarande på 32-bitars laddning/lagring av heltal."
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr "Ange kodmodellen."
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr "Generera inte ojusterade minnesreferenser."
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr "Kända kodmodeller (att användas med flaggan -mcmodel=):"
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr "Använd %reloc()-operatorer, istället för assemblermakron, för att läsa in adresser."
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr "Dra nytta av länkarlättnader för att reducera antalet instruktioner som krävs för att materialisera symboladresser."
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr "Mata ut RISC-V ELF-attribut."
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr "Använd den angivna datajusteringen."
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr "Kända val av datajustering (att användas med flaggan -malign-data=):"
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr "Använd angiven stackskyddsvakt."
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Giltiga argument till -mstack-protector-guard=:"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Använd angivet basregister för adressering av stackskyddsvakten."
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Använd angivet avstånd för adressering av stackskyddsvakten."
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "Stödda ISA-specifikationer (att användas med flaggan -misa-spec=):"
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr "Sätt versionen för RISC-V ISA-specifikationen."
@@ -9531,12 +9545,6 @@ msgstr "De möjliga TLS-dialekterna:"
 msgid "The code model option names for -mcmodel:"
 msgstr "Namnen för flaggan för kodmodell för -mcmodel:"
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr "Antag att mål-CPU:n är konfigurerad för rak byteordning."
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9557,12 +9565,6 @@ msgstr "Sätt att gå runt ARM Cortex-A53:s errata nummer 835796."
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr "Sätt att gå runt ARM Cortex-A53:s errata nummer 843419."
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr "Antag att mål-CPU:n är konfigurerad med omvänd byteordning."
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -16781,2162 +16783,2162 @@ msgstr "-dumpbase-ext .<änd>    Ta bort avslutande .<änd> från dumpbasnamnet
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <kat>\tAnge katalognamn att användas för dumpar."
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr "Versionen av C++-ABI:et som används."
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr "Optimera aggressivt slingor med användning av språkbegränsningar."
 
-#: common.opt:978
+#: common.opt:982
 #, no-c-format
 msgid "Align the start of functions."
 msgstr "Justera starten av funktioner."
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr "Justera etiketter som bara nås via hopp."
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr "Justera alla etiketter."
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr "Justera starten av slingor."
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr "Tillåt kompilatorn att introducera nya datakapplöpningar (race conditions) vid lagringar."
 
-#: common.opt:1013
+#: common.opt:1017
 #, no-c-format
 msgid "Enable static analysis pass."
 msgstr "Aktivera statiska analyspass."
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr "Välj vad som skall saneras."
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr "Välj typ av täckningssanering."
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr "-fasan-shadow-offset=<tal>\tAnvänd anpassat avstånd till skuggminne."
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr "-fsanitize-sections=<sek1,sek2,…>\tSanera globala variabler i användardefinierade sektioner."
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr "Efter att diagnosticera odefinierat beteende, försök fortsätta körningen."
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Denna flagga bör undvikas, använd -fsanitize-recover= istället."
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr "Använd trap istället för en biblioteksfunktion för sanering av odefinierat beteende."
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Generera tabeller för upprullning som är exakta vid varje instruktionsgräns."
 
-#: common.opt:1069
+#: common.opt:1073
 #, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "Generera auto-inc/dec-instruktioner."
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Använd samplingprofilinformation till anropsgrafers nodvikter.  Standard profilfil är fbdata.afdo i ”pwd”."
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Använd samplingsprofilinformation till anropsgrafers nodvikter.  Profilen är angiven i argumentet."
 
-#: common.opt:1087
+#: common.opt:1091
 #, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Generera kod för att kontrollera gränser före indexering i vektorer."
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Ersätt addition, jämförelse, grena med gren vid räknarregister."
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr "Använd profileringsinformation för grensannolikheter."
 
-#: common.opt:1111
+#: common.opt:1115
 #, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr "Skriv ut information om anropsgrafer för varje fil."
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "Skriv ut information om anropsgrafer för varje fil med dekorationer."
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<register>\tMarkera att <register> bevaras mellan funktioner."
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<register>\tMarkera att <register> förstörs av funktionsanrop."
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr "Spara register runt funktionsanrop."
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "Denna flagga bör undvikas, använd den inte."
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "Kontrollera returvärdet av new i C++."
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr "Utför interna konsistenskontroller."
 
-#: common.opt:1150
+#: common.opt:1154
 #, no-c-format
 msgid "Enable code hoisting."
 msgstr "Aktivera kodhissning."
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Söker efter möjligheter att minska stackjusteringar och stackreferenser."
 
-#: common.opt:1158
+#: common.opt:1162
 #, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr "Lägg oinitierade globala i den gemensamma sektionen."
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<flgr>]\tKompilera med och utan t.ex. -gtoggle, och jämför slutinstruktionsdumpen."
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "Kör endast den andra kompileringen av -fcompare-debug."
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Utför eliminering av jämförelser efter registertilldelningen har avslutats."
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "Utför inte optimeringar som märkbart ökar stackanvändningen."
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Utför ett optimeringspass för kopieringspropagering av register."
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr "Utför optimering för korshopp."
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr "När CSE körs, följ hopp till deras mål."
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr "Uteslut intervallreduktionssteget när komplex division görs."
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Komplex multiplikation och division följer Fortranregler."
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr "Placera dataobjekt i sin egen sektion."
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Lista alla tillgängliga felsökningsräknare med deras gränser och värden."
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<räknare>[:<undre_gräns1>-]:<övre_gräns1>[:<undre_gräns2>-<övre_gräns2>:…][,<räknare>:…]\tSätt gränsen för felsökningsräknare."
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr "-fdebug-prefix-map=<gammalt>=<nytt>\tÖversätt ett katalognamn till ett annat i felsökningsinformation."
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr "-ffile-prefix-map=<gammalt>=<nytt>\tÖversätt ett katalognamn till ett annat i kompileringsresultatet."
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "Mata ut en .debug_types-sektion när DWARF v4 felsökningsinformation används."
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr "Senarelägg borttagandet av funktionsargument från stacken."
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Försök fylla fördröjningsfack av greninstruktioner."
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr "Ta bort döda instruktioner som kan kasta undantag."
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr "Ta bort onödiga nollpekarkontroller."
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr "Strömma extra data för att stödja mer aggressiv avvirtualisering i lokaltransformationsläge i LTO."
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr "Utför spekulativ avvirtualisering."
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Försök att konvertera virtuella anrop till direkta."
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\tAnger hur ofta källkodspositioner skall skrivas ut i början av utskrift vid radbrytning."
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr "Visa källkodsrader med en cirkumflex som indikerar kolumnen."
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr "Visa etiketter som markerar avsnitt av källkod när källan visas."
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr "Visa radnummer i vänstermarginalen när källan visas."
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tFärglägg felmeddelanden."
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr "-fdiagnostics-urls=[never|always|auto]\tBädda in URL:ar i felmeddelanden."
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr "-fdiagnostics-column-unit=[display|byte]\tVälj huruvida kolumnnummer skrivs ut som visningskolumner (standard) eller råa byte."
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr "-fdiagnostics-column-origin=<nummer>\tAnge numret på den första kolumnen. Standard är 1-baserat enligt GNU-stil, men några verktyg kan förvänta sig 0-baserat, till exempel."
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr "-fdiagnostics-format=[text|json]\tVälj utmatningsformat."
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr "Skriv fixit-tips i maskinläsbar form."
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr "Skriv fix-it-tips till standard fel i unifierat diff-format."
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Lägg till lämpliga diagnostiska meddelanden till kommandoradsflaggan som styr dem."
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr "Skriv ut CWE-identifierare för felmeddelanden, där de är tillgängliga."
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr "Ange hur kontrollflödesvägen associerad med ett felmeddelande skrivs ut."
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr "Slå av diagnostiska funktioner som komplicerar utdata, såsom radnummer, färg och varnings-URL:er."
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "-ftabstop=<antal>       Avstånd mellan tabulatorstopp för kolumnvis rapportering."
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr "Visa stackdjup för händelser i vägar."
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr "Sätt minsta bredd på vänstermarginalen för källkod när källan visas."
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<pass>=intrvl1+intrvl2\tAvaktivera ett optimeringspass."
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<pass>=intrvl1+intrvl2\tAktivera ett optimeringspass."
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<typ>\tSkriv ut diverse intern kompilatorinformation till en fil."
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=filnamn\tSkriv instruktionerna vid slutet av översättningen till filnamn."
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=filnamn\tSkriv alla deklarationer till fil som Go-kod."
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Undertryck utskrift av adresser i felsökningsutskrifter."
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr "Samla och skriv ut felsökningsinformation till en temporärfil om ICE sker i C/C++-kompilatorn."
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr "Skriv ut detaljerad information om GCC:s interna representation av källkodsplatser."
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr "Dumpa optimeringspass."
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Undertryck utskrift av instruktionsantal, radnummernoteringar och -adresser i felsökningsutskrifter."
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Undertryck utskrift av föregående och nästa instruktionsnummer i felsökningsutskrifter."
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Aktivera CFI-tabeller via GAS-assemblerdirektiv."
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr "Utför tidig inline:ing."
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Utför interprocedurell reduktion av aggregat."
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Utför eliminering av oanvända symboler i felsökningsinformation."
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr "Utför eliminering av oanvända typer i felsökningsinformation."
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "Undertryck inte felsökningsinformation för C++-klasser."
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr "Aktivera undantagshantering."
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Utför ett antal smärre, dyra optimeringar."
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tAnge hantering av överskjutande precision på flyttal."
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tAnge vilka värden på FLT_EVAL_METHOD som är tillåtna."
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Mata ut lto-objekt som innehåller både mellanspråket och binärutdata."
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Anta att inga NaN:er eller oändligheter genereras."
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr "Anta att slingor med en utgång kommer avsluta och inte snurra i oändlighet."
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<register>\tMarkera <register> som ej tillgängligt för kompilatorn."
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Allokera inte float och double i register med utökad precision."
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Utför ett framåtpropageringspass på RTL."
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast]\tUtför kontraktion av flyttalsuttryck."
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr "Tillåt de inbyggda funktionerna ceil, floor, round, trunc att höja ”oexakt”-undantag."
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr "Tillåt att funktionsadresser läggs i register."
 
-#: common.opt:1586
+#: common.opt:1590
 #, no-c-format
 msgid "Place each function into its own section."
 msgstr "Placera varje funktion i sin egen sektion."
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr "Utför global eliminering av gemensamma deluttryck."
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Utför förbättrad förflyttning av laddning under global eliminering av gemensamma deluttryck."
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Utför förflyttning av lagring efter global eliminering av gemensamma deluttryck."
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Utför eliminering av överflödig laddning efter lagring i globala gemensamma deluttryck."
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Utför global eliminering av gemensamma deluttryck efter att registertilldelning har avslutats."
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr "-fgnat-encodings=[all|gdb|minimal]\tVälj balansen mellan GNAT-kodningar och standard DWARF som skrivs ut i felsökningsinformationen."
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr "Aktivera in och ut från Graphite-representation."
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr "Aktivera Graphite-identitetstransformation."
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Aktivera närliggande lyftningsladdning för att uppmuntra generering av villkorliga move-instruktioner."
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr "Förbättra GCC:s förmåga att följa kolumnnummer i stora källkodsfiler, på bekostnad av långsammare kompilering."
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr "Markera alla slingor som parallella."
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "Aktivera transformationer av slingutbyten.  Samma som -floop-nest-optimize."
 
-#: common.opt:1659
+#: common.opt:1663
 #, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr "Aktivera slingutbyten i träd."
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr "Utför unroll-and-jam på slingor."
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr "Aktivera stöd för GNU:s transaktionsminne."
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "Använd STB_GNU_UNIQUE om det stödjs av assemblern."
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr "Aktivera optimeraren av slingnästning."
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr "Tvinga bitfältsåtkomster att matcha sin typbredd."
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr "Slå samman intilliggande lagringar."
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr "Aktivera att grensannolikheter gissas."
 
-#: common.opt:1703
+#: common.opt:1707
 #, no-c-format
 msgid "Process #ident directives."
 msgstr "Hantera #ident-direktiv."
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Utför konvertering av villkorliga hopp till grenlösa motsvarigheter."
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Utför konvertering av villkorliga hopp till villkorlig exekvering."
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none]\tStäll in stackåteranvändningsnivån för lokala variabler."
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Konvertera villkorliga hopp i innersta slingor till grenlösa motsvarigheter."
 
-#: common.opt:1743
+#: common.opt:1747
 #, no-c-format
 msgid "Do not generate .size directives."
 msgstr "Generera inte .size-direktiv."
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr "Utför indirekt inline:ing."
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "Aktivera inline:ing av funktioner deklarerade ”inline”, avslaget avaktiveras all inline:ing."
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Integrera funktioner i deras anropare när det är klart att kodstorleken inte växer."
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Integrera funktioner deklarerade ”inline” i deras anropare när det lönar sig."
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "Integrera funktioner som endast behövs av deras enda anropare."
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<tal>\tBegränsa storlek på inline-funktioner till <tal>."
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Inline:a __atomic-operationer när en låsningsfri instruktionssekvens är tillgänglig."
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr "-fcf-protection=[full|branch|return|none|check]\tInstrumentera funktioner med kontroller för att verifiera att jump/call/return-instruktioner för styrflödesövergångar har giltiga mål."
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Instrumentera funktionsingång och -utgång med profileringsanrop."
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=namn,…\tInstrumentera inte uppräknade funktioner."
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=filenamn,…\tInstrumentera inte funktioner uppräknade i filerna."
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr "Utför konstantpropagering mellan procedurer."
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Utför kloning för att göra konstantpropagering mellan procedurer starkare."
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Utför bitvis konstantpropagering mellan procedurer."
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr "Utför modref-analyser mellan procedurer."
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr "Utför profileringspropagering mellan procedurer."
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr "Utför pekar-på-analyser mellan procedurer."
 
-#: common.opt:1846
+#: common.opt:1850
 #, no-c-format
 msgid "Discover pure and const functions."
 msgstr "Upptäck pure- och const-funktioner."
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Fäll ihop identisk kod för funktioner och endast läsbara variabler."
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr "Fäll ihop identisk kod för funktioner."
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr "Utför ihopfällning av identiskt kod för variabler."
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr "Upptäck endast läsbara och icke adresserbara statiska variabler."
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "Upptäck endast läsbara, endast skrivbara och icke adresserbara statiska variabler."
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr "Reducera stackjusteringen vid anropsplatsen om möjligt."
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr "Utför IPA-propagering av värdeintervall."
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority]\tBestäm den använda IRA-algoritmen."
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed]\tSätt regioner för IRA."
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "Använd IRA-baserad registertryckberäkning i RTL-hissningsoptimeringar."
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "Använd IRA-baserad registertryckberäkning i RTL-slingeoptimeringar."
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr "Dela fack för att spara olika hårda register."
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Dela stackfack för spillda pseudoregister."
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<tal>\tStyr IRA:ns nivå på diagnostikmeddelanden."
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr "Optimera induktionsvariabler på träd."
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Använd hopptabeller för tillräckligt stora switch-satser."
 
-#: common.opt:1945
+#: common.opt:1949
 #, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "Använd bittester för tillräckligt stora switch-satser."
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Generera kod för funktioner även om de är fullständigt inline:ade."
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "Generera kod för statiska funktioner även om de aldrig anropas."
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr "Mata ut static const-variabler även om de inte används."
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr "Ge externa symboler ett inledande understrykningstecken."
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr "Gör CFG-känsliga återmaterialiseringar i LRA."
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr "Aktivera länkningsoptimeringar."
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Optimeringar vid länktillfället med flera parallella jobb eller jobbserver."
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr "Ange algoritmen för att dela upp symboler och variabler vid länktillfället."
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr "-flto-compression-level=<tal>\tAnvänd zlib/zstd-komprimering på nivå <tal> för IL."
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "Rapportera diverse optimeringsstatistik från länkningen."
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Rapportera diverse optimeringsstatistik från länkningen endast för WPA."
 
-#: common.opt:2020
+#: common.opt:2024
 #, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr "Sätt errno efter inbyggda matematikfunktioner."
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<antal>\tMaximalt antal fel som skall rapporteras."
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr "Rapportera om permanent minnesallokering."
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Rapportera bara om permanent minnesallokering i WPA."
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Försök slå samman identiska konstanter och konstanta variabler."
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Försök slå samman identiska konstanter mellan kompileringsenheter."
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Försök slå samman identiska felsökningssträngar mellan kompileringsenheter."
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<antal>\tBegränsa felmeddelandens längd till <antal> tecken per rad.  0 stänger av radbrytning."
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Utför SMS-baserad modulo-schemaläggning före det första schemaläggningspasset."
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Utför SMS-baserad modulo-schemaläggning med tillåten registerförflyttning."
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr "Flytta slinginvarianta beräkningar ut från slingor."
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr "Använd passet på RTL för eliminering av död kod."
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "Använd passet på RTL för eliminering av död lagring."
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Aktivera/deaktivera den traditionella schemaläggningen i slingor som redan passerat modulo-schemaläggning."
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr "Stöd synkrona icke-anropsundantag."
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr "-foffload=<mål>=<flaggor>\tAnge mål att lasta av till och flaggor för dem."
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr "-foffload-abi=[lp64|ilp32]\tAnge ABI:et att använda i en avlastningskompilator."
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr "Låt bli att generera stackramar när det är möjligt."
 
-#: common.opt:2104
+#: common.opt:2108
 #, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Aktivera alla optimeringsinformationsdumpar på standard fel."
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<type>=filenamn]\tSkriv ut kompilatoroptimeringsdetaljer."
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr "Skriv en KÄLLFIL.opt-record.json-fil med detaljer om vilka optimeringar som utfördes."
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimera syskon- och svansrekursiva anrop."
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr "Utför partiell inline:ing."
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Rapportera minnesallokering för interprocedurella optimeringar."
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr "Packa ihop postmedlemmar utan hål."
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<tal>\tAnge initial maximal justering för postmedlemmar."
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr "Returnera små aggregat i minne, inte register."
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr "Utför slingavskalning."
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr "Aktivera maskinspecifika nyckelhålsoptimeringar."
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Aktivera ett RTL-nyckelhålspass före sched2."
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Generera positionsoberoende kod om möjligt (stort läge)."
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Generera positionsoberoende kod för körbara program om möjligt (stort läge)."
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Generera positionsoberoende kod om möjligt (litet läge)."
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Generera positionsoberoende kod för körbara program om möjligt (litet läge)."
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr "Använd PLT för PIC-anrop (-fno-plt: läs adressen från GOT på anropsplatsen)."
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr "Ange en insticksmodul att läsa in."
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<namn>-<nyckel>[=<värde>]\tAnge argument <nyckel>=<värde> för insticksmodul <namn>."
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr "Kör optimeringar för predikativ gemensamning."
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Generera förhandshämtningsinstruktioner (prefetch), om tillgängliga, för vektorer i slingor."
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr "Aktivera grundläggande programprofileringskod."
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr "Generera absoluta källkodssökvägar för gcov."
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr "Lägg in bågbaserad programprofileringskod."
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Sätt toppnivåkatalogen för att spara profildata.  Standard är ”pwd”."
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr "Välj namnet att lagra profileringsnoteringsfil."
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Aktivera korrigering av profilindata med inkonsistent flöde."
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tAnge metoden för profiluppdatering."
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr "Instrumentera endast funktioner från filer vars namn matchar något av de reguljära uttrycken (separerade av semikolon)."
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr "Instrumentera endast funktioner från filer vars namn inte matchar något av de reguljära uttrycken (separerade av semikolon)."
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tStyr nivån av reproducerbarhet av profilen som samlas av -fprofile-generate."
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr "Ta bort prefix från absoluta sökvägar före mangling av namn för -fprofile-generate= och -fprofile-use=."
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Aktivera vanliga flaggor för att generera profileringsinformation för optimeringar styrda av återmatad profil."
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Aktivera vanliga flaggor för att generera profileringsinformation för optimeringar styrda av återmatad profil, och sätt -fprofile-dir=."
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr "Registrera profilinformationen i sektionen .gcov_info istället för att använda konstruerare/destruerare."
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr "Registrera profilinformationen i den angivna sektionen istället för att använda konstruerare/destruerare."
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr "Anta inte att funktioner som aldrig exekveras under tågkörningen är kalla."
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Aktivera vanliga flaggor för att utföra optimeringar styrda av återmatad profil."
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Aktivera vanliga flaggor för att utföra optimeringar styrda av återmatad profil, och sätt -fprofile-dir=."
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr "Lägg in kod för att profilera värden av uttryck."
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr "Rapportera om intern konsistens hos profilen."
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr "Aktivera omflyttning av funktioner för att förbättra kodplacering."
 
-#: common.opt:2305
+#: common.opt:2309
 #, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr "Infoga NOP-instruktioner vid varje funktionsingång."
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<sträng>\tGör kompileringen reproducerbar med <sträng>."
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr "Notera gcc:s kommandoradsflaggor i objektfilen."
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr "Returnera små poster i register."
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr "Berätta för DSE att lagringen för ett C++-objekt är dött när konstrueraren börjar och när destrueraren avslutar."
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr "-flive-patching=[inline-only-static|inline-clone]\tStyr IPA-optimeringar till att ge en säker kompilering för uppdateringar i drift.  Ger på samma gång flernivåstyrning av de aktiverade IPA-optimeringarna."
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr "Säg till DCE att ta bort oanvända C++-allokeringar."
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Lättnad av registertryck genom minskning av aktivt intervall."
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr "Utför ett optimeringspass med registernamnbyten."
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Utför ett optimeringspass med målberoende instruktionssammanslagning."
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Flytta om grundblock för att förbättra kodplacering."
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr "-freorder-blocks-algorithm=[simple|stc]\tSätt algoritmen att användas för ordningsändring av grundblock."
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Flytta om grundblock och partitioner till varma och kalla sektioner."
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr "Flytta om funktioner för att förbättra kodplacering."
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Lägg till ett pass för eliminering av gemensamma deluttryck efter slingoptimeringar."
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Avaktivera optimeringar som antar standardmässigt avrundningsbeteende för FP."
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr "Aktivera schemaläggning mellan grundblock."
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Aktivera registertryckskänslig instruktionsschemaläggning."
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr "Tillåt spekulativ förflyttning av icke-laddningar."
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr "Tillåt spekulativ förflyttning av några laddningar."
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr "Tillåt spekulativ förflyttning av fler laddningar."
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<tal>\tAnge hur mångordig schemaläggaren skall vara."
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Om schemaläggning efter omläsning, gör superblockschemaläggning."
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr "Schemalägg om instruktioner före registertilldelning."
 
-#: common.opt:2449
+#: common.opt:2453
 #, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr "Schemalägg om instruktioner efter registertilldelning."
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Använd selektive schemaläggningsalgoritm för schemaläggning av instruktioner."
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr "Kör selektiv schemaläggning efter omläsning."
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr "Kör självtester, använd den angivna sökvägen för att hitta testfiler."
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Utför programvarurörläggning av inre slingor under selektiv schemaläggning."
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Utför programvarurörläggning av yttre slingor under selektiv schemaläggning."
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Schemalägg om rörlagda regioner utan rörläggning."
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr "Tillåt funktioner (eller variabler) som står emellan för sådana med annan semantik (respektive initierare) i den dynamiska länkaren."
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr "Tillåt förtida schemaläggning av köade instruktioner."
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<antal>\tAnge antalet köade instruktioner som kan schemaläggas i förtid."
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Sätt beroendeavståndet som kontrolleras i förtida schemaläggning av köade instruktioner."
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<antal>\tSätt beroendeavståndet som kontrolleras i förtida schemaläggning av köade instruktioner."
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Aktivera gruppheuristiken i schemaläggaren."
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Aktivera heuristiken för kritisk väg i schemaläggaren."
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Aktivera den spekulativa instruktionsheuristiken i schemaläggaren."
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Aktivera ordningsheuristiken i schemaläggaren."
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Aktivera heuristiken för sista instruktion i schemaläggaren."
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Aktivera heuristiken för beroende antal i schemaläggaren."
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr "Nå data i samma sektion från delade förankringspunkter."
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Slå på passet för eliminering av redundanta utökningar."
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Visa kolumnnummer i felmeddelanden, när de är tillgängliga.  Normalt på."
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Mata ut funktionsprologer bara före delar av funktionen som behöver det, istället för i början av funktionen."
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "Kapsla in delar av prologen och epilogen separat."
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Avaktivera optimeringar som kan observeras av IEEE signalerande NAN:ar."
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Avaktivera flyttalsoptimeringar som ignorerar IEEE:s tecken på noll."
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr "Konvertera flyttalskonstanter till konstanter med enkel precision."
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Dela livstiden på induktionsvariabler när slingor rullas ut."
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "Generera osammanhängande stackramar."
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr "Dela upp breda typer i oberoende register."
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr "Dela upp breda typer i oberoende register tidigare."
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Aktivera bakåtpropagering av användningsegenskaper på SSA-nivån."
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr "Optimera villkorliga mönster med SSA PHI-noder."
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Optimera mängden stdarg-register som sparas på stacken vid starten av en funktion."
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Tillämpa variabelexpansion när slingor rullas ut."
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tLägg in stackkontrollkod i programmet."
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Lägg in stackkontrollkod i programmet.  Samma som -fstack-check=specific."
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr "Infoga kod för att prova varje sida av stackutrymme när den allokeras för att skydda från attacker av typen stackkollision."
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\tFånga om stacken går förbi <register>."
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<namn>\tFånga om stacken går förbi symbolen <namn>."
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "Använd propolice som en metod att skydda stacken."
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr "Använd en metod att skydda stacken för varje funktion."
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Använd en smart metod att skydda stacken för vissa funktioner."
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Använd en metod att skydda stacken endast för funktioner med attributet stack_protect."
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr "Skriv ut information om stackanvändning för varje funktion."
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr "Anta att strikta aliasregler gäller."
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Behandla spill med tecken som odefinierat.  Negeras som -fwrapv -fwrapv-pointer."
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr "Implementera __atomic-operationer med biblioteksanrop till äldre __sync-funktioner."
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr "Leta efter syntaxfel, stoppa sedan."
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr "Skapa datafiler som behövs av ”gcov”."
 
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr "Utför hopptrådningsoptimeringar."
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr "Rapportera tiden som går åt för varje kompilatorpass."
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr "Spela in tiden som går åt till underfaser separat."
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tAnge normal kodgenereringsmodell för trådlokal lagring."
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Ordna om toppnivåfunktioner, variabler och asm:ar."
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr "Utför superblockformering via svansduplicering."
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr "För mål som normalt använder trampoliner för nästade funktioner, generera dem alltid istället för att använda deskriptorer."
 
-#: common.opt:2722
+#: common.opt:2726
 #, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr "Anta att flyttalsoperationer kan utlösa fällor."
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Fånga teckenspill i addition, subtraktion och multiplikation."
 
-#: common.opt:2730
+#: common.opt:2734
 #, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Aktivera SSA-CCP-optimering av träd."
 
-#: common.opt:2734
+#: common.opt:2738
 #, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Aktivera SSA-BIT-CCP-optimering av träd."
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr "Aktivera slinghuvudkopiering av träd."
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "Aktivera SSA-sammanläggning av användarvariabler."
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr "Aktivera kopiepropagering i träd."
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr "Transformera villkorliga lagringar till ovillkorliga."
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr "Utför konvertering av switch-initieringar."
 
-#: common.opt:2774
+#: common.opt:2778
 #, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Aktivera eliminering av död kod i SSA-optimeringen i träd."
 
-#: common.opt:2778
+#: common.opt:2782
 #, no-c-format
 msgid "Enable dominator optimizations."
 msgstr "Aktivera dominatoroptimeringar."
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "Aktivera svanssammanslagning av träd."
 
-#: common.opt:2786
+#: common.opt:2790
 #, no-c-format
 msgid "Enable dead store elimination."
 msgstr "Aktivera eliminering av död lagring."
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "Aktivera framåtpropagering på träd."
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Aktivera fullständig överflödseliminering (FRE) i träd."
 
-#: common.opt:2798
+#: common.opt:2802
 #, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "Aktivera stränglängdsoptimering av träd."
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detektera vägar som utlöser felaktigt eller odefinierat beteende på grund av dereferering av nollpekare.  Isolera dessa vägar från huvudsakliga styrflödet och gör om satsen med det felaktiga eller odefinierade beteendet till en fälla."
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detektera vägar som utlöser felaktigt eller odefinierat beteende på grund av att ett nollvärde används på ett sätt som förbjuds av ett returns_nonnull- eller nonnull-attribut.  Isolera dessa vägar från huvudsakliga styrflödet och gör om satsen med det felaktiga eller odefinierade beteendet till en fälla."
 
-#: common.opt:2815
+#: common.opt:2819
 #, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "Aktivera slingdistribution i träd."
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Aktivera slingdistribution för mönster transformerade till biblioteksanrop."
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr "Aktivera förflyttning av slingoberoende delar i träd."
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr "Skapa kanoniska induktionsvariabler i slingor."
 
-#: common.opt:2835
+#: common.opt:2839
 #, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr "Aktivera slingoptimeringar på trädnivå."
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "-ftree-parallelize-loops=<antal>\tAktivera automatisk parallellisering av slingor."
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Aktivera lyftningsladdning från villkorliga pekare."
 
-#: common.opt:2847
+#: common.opt:2851
 #, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Aktivera SSA-PRE-optimeringar i träd."
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr "I SSA-PRE-optimering på träd, aktivera eliminering av partiell-partiell redundans."
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Utför funktionslokala pekar-på-analyser i träd."
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr "Aktivera återassociering på trädnivå."
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr "Aktivera SSA-kodsänkning i träd."
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr "Utför rätlinjig styrkereduktion."
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr "Utför skalärersättning av aggregat."
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Ersätt tillfälliga uttryck i passet SSA->normal."
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Utför livstidsuppdelning under passet SSA->normal."
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr "Utför propagering av värdeintervall i träd."
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr "Dela sökvägar som leder till bakåtbågar i slingor."
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr "Anta att gemensamma deklarationer kan åsidosättas med sådana med en större avslutande vektor."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr "Kompilera en hel kompileringsenhet åt gången."
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Utför slingutrullning när iterationsantalet är känt."
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr "Utför slingutrullning för alla slingor."
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Tillåt optimeringar för flyttalsaritmetik som kan ändra resultatet av operationen på grund av avrundning."
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Samma som -fassociative-math för uttryck som inkluderar division."
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Tillåt matematikoptimeringar som kan strida mot IEEE- eller ISO-standarder."
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Utför slingavväxling."
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Utför slingdelning."
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr "Versioner av slingor baserat på om indexen har steg på ett."
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Generera bara upprullningstabeller för undantagshantering."
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Använd bfd-länkaren istället för standardlänkaren."
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Använd gold-länkaren istället för standardlänkaren."
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Använd lld LLVM-länkaren istället för standardlänkaren."
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Utför variabelspårning."
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Utför variabelspårning genom att annotera tilldelningar."
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Växla -fvar-tracking-assignments."
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Utför variabelspårning och tagga också variabler som är oinitierade."
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Aktivera vektorisering av träd."
 
-#: common.opt:3011
+#: common.opt:3015
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Aktivera slingvektorisering i träd."
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Aktivera grundblocksvektorisering (SLP) i träd."
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tAnger kostnadsmodellen för vektorisering."
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tAnger kostnadsmodellen för vektorisering för kod markerad med ett simd-direktiv."
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Aktivera den dynamiska kostnadsmodellen för vektoriseraren.  Bevarad för bakåtkompatibilitet."
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Aktivera kopiepropagering av skalärutvecklingsinformation."
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Lägg till extra kommentarer till assemblerutdata."
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tAnge standardvärde för symbolsynlighet."
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "Validera vtable-pekare före de används."
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Mata ut verifieringsräknare för vtable."
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Mata ut information om verifieringspekaruppsättningar för vtable."
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Använd uttrycksvärdeprofiler i optimeringar."
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Konstruera nät och dela orelaterade användningar av en enskild variabel."
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Aktivera villkorlig eliminering av död för inbyggda anrop."
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Utför optimering av hela program."
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Anta att pekarspill slår runt."
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Anta att spill vid teckenaritmetik slår runt."
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Lägg nollinitierad data i bss-sektionen."
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr "Nollställ anropsanvända register vid funktionsretur."
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Generera felsökningsinformation i standardformat."
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "Anta att assemblern stödjer .loc-direktiv (DWARF2+)."
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "Anta att assemblern stödjer vyer i .loc-direktiv (DWARF2+)."
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Spara DW_AT_decl_column och DW_AT_call_column i DWARF."
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Generera felsökningsinformation i standardversion av DWARF-formatet."
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Generera felsökningsinformation i DWARF v2-format (eller senare)."
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr "Använd 32-bitars DWARF-format vid utmatning av DWARF-felsökningsinformation."
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr "Använd 64-bitars DWARF-format vid utmatning av DWARF-felsökningsinformation."
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Generera felsökningsinformation i normalt utökat format."
 
-#: common.opt:3191
+#: common.opt:3195
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Generera utökad information om ingångspunkt för inline:ade funktioner."
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr "Beräkna locview-återställningspunkter baserat på uppskattningar av instruktionslängd."
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Generera inte DWARF-sektionerna pubnames och pubtypes."
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Generera DWARF-sektionerna pubnames och pubtypes."
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Generera DWARF-sektionerna pubnames och pubtypes med GNU-utvidgningar."
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Notera gcc:s kommandoradsflaggor i DWARF DW_AT_producer."
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Generera felsökningsinformation i separata .dwo-filer."
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Generera felsökningsinformation i STABS-format."
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Generera felsökningsinformation i utökat STABS-format."
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr "Mata ut progressiva rekommenderade brytpunktsplatser."
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Mata inte ut DWARF-tillägg utöver vald version."
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr "Lägg till beskrivningsattribut till några DWARF DIE:er som inte har något namnattribut."
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Växla generering av felsökningsinformation."
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr "Utöka variabelplatslistor med progressiva vyer."
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Generera felsökningsinformation i VMS-format."
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Generera felsökningsinformation i XCOFF-format."
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Generera felsökningsinformation i utökat XCOFF-format."
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Generera komprimerade felsökningssektioner."
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<format>\tGenerera komprimerade felsökningssektioner i formatet <format>."
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<kat>\tSätt <kat> att vara standardbibliotek för insticksmoduler."
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <kat>\tSätt <kat> att vara inkluderingsunderbiblioteket för multiarkitekturer."
 
-#: common.opt:3320
+#: common.opt:3324
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <fil>\tSkriv utdata i <fil>."
 
-#: common.opt:3324
+#: common.opt:3328
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Aktivera funktionsprofilering."
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Som -pedantic men ange dem som fel."
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Visa inte kompilerade funktioner eller tiden som förbrukats."
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Aktivera utförlig utskrift."
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Visa kompilatorns version."
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Undertryck varningar."
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Skapa ett delat bibliotek."
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Skapa inte ett dynamiskt länkat positionsoberoende körbart program."
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Skapa ett dynamiskt länkat positionsoberoende körbart program."
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Skapa ett statiskt positionsoberoende körbart program."
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Använd anroparens sparregister mellan anrop om möjligt."
@@ -19078,1107 +19080,1118 @@ msgstr "--param=evrp-mode=[legacy|ranger|legacy-first|ranger-first|ranger-trace|
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr "Maximalt antal argument en PHI kan ha före FSM-trådaren kommer försöka tråda igenom dess block."
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr "Skalfaktor att använda på antalet block i en trådningsväg vid jämförelse med antalet av (skalade) satser."
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr "Skalfaktor att använda på antalet satser i en trådningsväg vid jämförelse med antalet av (skalade) block."
 
 # Undrar om jag fattat syftningen i "critical edges execution count" rätt!
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "Tröskelförhållandet av antal beräkningar av kritiska bågar som tillåter att göra redundanseliminering efter omläsning."
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "Tröskelförhållandet för att utföra partiell redundanselimination efter omläsning."
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr "Skalfaktor vid beräkning av maximala distansen ett uttryck kan flyttas genom GCSE-optimeringar."
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr "Kostnaden vid vilken GCSE-optimeringar inte kommer begränsa avståndet ett uttryck kan flytta."
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "Minsta heap-expansion för att utlösa skräpsamling, som en procent av den totala storleken på heap:en."
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "Minsta heap-storlek före vi börjar samla skräp, i kilobyte."
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr "Antalet körningar av ett grundblock som betraktas som varmt.  Parametern används bara i GIMPLE FE."
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr "Huruvida kodgenereringsfel skall vara ICE:er med -fchecking."
 
-#: params.opt:206
+#: params.opt:211
 #, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr "Maximalt antal vektorer per SCoP."
 
-#: params.opt:210
+#: params.opt:215
 #, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr "Maximalt antal parameter i en SCoP."
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr "Antalet element för vilka verifiering av hashtabellen görs för varje sökt element."
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "Nämnaren n i bråket 1/n av det maximala antalet körningar av ett grundblock i hela programmet som ett grundblock åtminstone måste ha för att anses varmt (används i icke-LTO-läge)."
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr "Antalet mest exekverade promille av den profilerade körningen av hela programmet till vilken körningsräknaren för ett grundblock måste vara en del av för att betraktas som varm (används i LTO-läge)."
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "Nämnaren n i bråket 1/n av frekvensen av antalet körningar av ingångsblocket till en funktion som ett grundblock för denna funktion åtminstone måste ha för att anses varmt."
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr "Skalan (i procent) tillämpad på inline-insns-single och automatiska gränser när heuristik indikerar att inline:ing är väldigt lönsamt."
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr "Den minsta uppskattade hastighetsökningen som tillåter inline:aren att ignorera inline-insns-single och inline-insns-auto."
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "Hur mycket kan en given kompileringsenhet växa på grund av inline:ingen (i procent)."
 
-#: params.opt:242
+#: params.opt:247
 #, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "Övre gränsen för att dela heltalskonstanter."
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr "Tröskelvärde för ipa-cp-tillfällesberäkning som fortfarande betraktas som fördelaktig att klona."
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr "Bonus IPA-CP tilldelar vid kompileringstillfället till kandidater vilka gör slingbegränsningar eller -steg kända."
 
-#: params.opt:254
+#: params.opt:259
 #, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "Det maximala djupet för rekursiv kloning för självrekursiva funktioner."
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Rekursiv kloning endast när sannolikheten för att ett anrop skall göras överskrider parametern."
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr "Procentuellt straff de rekursiva funktionerna kommer få när de utvärderas för kloning."
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr "Procentuellt straff funktioner som innehåller ett ensamt anrop av en annan funktion kommer få när de utvärderas för kloning."
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "hur mycket kan en given kompileringsenhet växa på grund av interprocedurell konstantpropagering (i procent)."
 
-#: params.opt:274
+#: params.opt:279
 #, no-c-format
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "Storleken på en översättningsenhet för att IPA-CP-passet betraktar den som stor."
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr "Maximal storlek för en lista på värden associerad med varje parameter för konstantpropagering mellan procedurer."
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr "Maximalt antal besökta satser under upptäckt av avstånd för hoppfunktioner."
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr "Maximalt antal satser som kommer besökas av IPA-formatparameteranalysen baserat på aliasanalys i varje given funktion."
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr "Maximalt antal av sammansatta innehållsposter för en parameter i hoppfunktioner och gitter."
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "Maximalt antal operationer i ett parameteruttryck som kan hanteras av IPA-analys."
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr "Maximalt antal olika predikat som används för att spåra egenskaper hos slingor i IPA-analys."
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr "Maximala antalet gränsändpunkter för case-intervall i switch-satser som används under IPA-funktionssammanfattningsgenerering."
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr "Maximala antalet delar som IPA-SRA följer per formell parameter, och som en konsekvens, även det maximala antalet ersättningar av en formell parameter."
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr "Största tillåtna ökning av antal och total storlek på nya parametrar som ipa-sra ersätter en pekare till ett aggregat med."
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr "Antalet register i varje klass som behålls oanvänt vid flyttning av slinginvariant."
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr "Maximal storlek på konflikttabell i MB."
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr "Maximalt slingantal för regional RA."
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "Om antalet kandidater i mängden är mindre, försöker vi alltid ta bort oanvända iv under deras optimering."
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "Gräns för antalet kandidater under vilken alla kandidater övervägs i iv-optimeringar."
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "Gräns för antal iv-användningar i en slinga optimerad i iv-optimeringar."
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr "Det maximala förhållandet för tillväxt av kod vid expansion till en hopptabell (i procent).  Parametern används vid optimering för storlek."
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr "Det maximala förhållandet för tillväxt av kod vid expansion till en hopptabell (i procent).  Parametern används vid optimering för fart."
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr "Storleken på cache-raderna i L1."
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr "Storleken på L1-cachen."
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr "Storleken på L2-cachen."
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Maximal på grund av inline:ing av stora funktioner (i procent)."
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr "Storleken på en funktionskropp för att betraktas som stor."
 
-#: params.opt:366
+#: params.opt:371
 #, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "Storleken på en stackram för att betraktas som stor."
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Maximal storleksökning på stackram på grund av inline:ing (i procent)."
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr "Storleken på en översättningsenhet för att betraktas som stor."
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr "Maximalt antal av samtidigt öppna C++-modulfiler vid lat laddning."
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "Den minsta kostnaden av ett dyrt uttryck vid flyttning av slinginvariant."
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr "Sant om en icke kortsluten operation är optimal."
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr "Storlek på brickor för slingblockning."
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "Det maximala antalet satser i slingnästning för slingutväxling."
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "Minimala stegförhållandet för att slingutväxling skall vara lönsamt."
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr "Maximalt antal grundblock i slinga-för-slinga-invarianta förflyttningar."
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr "Maximalt antal datareferenser i en slinga för att bygga slingdataberoenden."
 
-#: params.opt:410
+#: params.opt:415
 #, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "Det maximala antalet instruktioner i en inre slinga som beaktas för versionering."
 
-#: params.opt:414
+#: params.opt:419
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "Det maximala antalet instruktioner i en yttre slinga som beaktas för versionering, ovanpå instruktionerna i inre slingor."
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr "Minimal sannolikhet för bågar att falla igenom i procent som används för att lägga till GB till arvs-EBB i LRA."
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr "Maximalt antal omläsningar av pseudoregister som övervägs när ett icke-omläst pseudoregister spills."
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr "Maximal storlek på en partition för LTO (i uppskattade instruktioner)."
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr "maximalt antal LTO-partitioner som strömmas parallellt."
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr "Minimal storlek på en partition för LTO (i uppskattade instruktioner)."
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr "Antal partitioner programmet skall delas upp i."
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "Det maximala antalet instruktioner för att överväga att rulle ut i en slinga i genomsnitt."
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr "Det maximala antalet instruktionskombinationsförsök att kombinera."
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "Det maximala djupet av nästade slingor som vi skalar helt."
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Det maximala antalet avskalningar av en enskild slinga som är helt avskalad."
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "Det maximala antalet instruktioner i en helt avskalad slinga."
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "Det maximala antalet ingående bågar att överväga för korshopp."
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr "Det maximala antalet instruktioner CSE bearbetar före tömning."
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr "Den maximala längden på sökvägar som övervägs i cse."
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Det maximala antalet minnesplatser noterade av cselib."
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr "Maximalt antal felsökningsmarkörer att expandera eller inline:a."
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "Det maximala antalet instruktioner att överväga för att fylla ett fördröjningsutrymme."
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "Det maximala antalet instruktioner att överväga för att hitta korrekt information om aktiva register."
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr "Maximalt antal aktiva lokala lagringar i RTL vid eliminering av döda lagringar."
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "Det maximala antalet nästade indirekta inline:ingar som utförs av den tidiga inline:aren."
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "Maximalt antal fält i en post före pekaranalys behandlar posten som en enda variabel."
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr "Maximalt antal grundblock i en ändlig tillståndsmaskins hopptrådsvägar."
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr "Maximalt antal instruktioner att kopiera vid duplicering av block på hopptrådvägen för en ändlig tillståndsmaskin."
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "Det maximala antalet nya hopptrådvägar att skapa för en ändlig tillståndsmaskin."
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "Det maximala förhållandet mellan insättningar och raderingar av uttryck i GCSE."
 
-#: params.opt:518
+#: params.opt:523
 #, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "Den maximala mängden minne som får allokeras av GCSE, i kilobyte."
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "Det maximala antalet instruktioner att duplicera vid avfaktorering av beräknade goto."
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "Den maximala expansionsfaktorn vid kopiering av grundblock."
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr "Maximalt djup på sökningen i dominansträd för uttryck att hissa upp."
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "Det maximala antalet instruktioner vid automatisk inline:ing."
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "Det maximala antalet instruktioner inline-funktioner kan växa till via rekursiv inline:ing."
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "Det maximala antalet instruktioner icke-inline-funktioner kan växa till via rekursiv inline:ing."
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "Det maximala antalet instruktioner i en enskild funktion tänkbar för inline:ing."
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr "Det maximala antalet instruktioner vid inline:ing för storlek."
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "Det maximala antalet instruktioner vid automatisk inline:ing av små funktioner."
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "Det maximala djupet för rekursiv inline:ing för inline-funktioner."
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "Det maximala djupet för rekursiv inline:ing för icke-inline-funktioner."
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Maximala antalet isl-operationer, 0 betyder obegränsat."
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "Begränsningen av kostnaden för ett uttryck för att beräkna antalet iterationer."
 
 # Är syftningarna rätt här?
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "Begränsning på antalet iterationer som utvärderas av råstyrkealgoritmen för att analysera antalet iterationer."
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "Maximalt antal satser som tillåts i ett block som behöver dubbleras när hopp trådas."
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "Det maximala antalet RTL-noder som kan noteras som kombinerarens sista värde."
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "Det maximala antalet instruktioner i slinghuvudet duplicerade av kopieringspasset för slinghuvuden."
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "Det maximala antalet försök att gå tillbaka schemaläggaren skall göra vid moduloschemaläggning av en slinga."
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr "Maximal längd på partiell förväntansmängd när föroptimeringar på träd görs."
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "Det maximala antalet grenar på vägen genom den skalade sekvensen."
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "Det maximala antalet avskalningar av en enskild slinga."
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr "Det maximala antalet instruktioner i en avskalad slinga."
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "Den maximala längden på schemaläggarens lista över väntande operationer."
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "Det maximala antalet block i en region som övervägs för interblockschemaläggning."
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "Det maximala antalet instruktioner i en region för att övervägas för interblockschemaläggning."
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr "Maximalt djup av sqrt-kedjor att använda vid syntetisering av exponentiering av en reell konstant."
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "Det maximala antalet slingiterationer vi förutsäger statiskt."
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "Det största antalet instruktioner att söka bakåt för att leta efter ekvivalent omläsning."
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Det maximala antalet instruktioner i grundblock att beaktas för RTL if-konvertering."
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr "Maximal tillåten kostnad för sekvensen som skulle genererats av RTL if-konverteringspasset för en gren som betraktas som förutsägbar."
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr "Maximal tillåten kostnad för sekvensen som skulle genererats av RTL if-konverteringspasset för en gren som betraktas som oförutsägbar."
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "Det maximala antal iterationer genom CFG för utökade regioner."
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "Den maximala konfliktfördröjningen för att en instruktion skall övervägas för spekulativ förflyttning."
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "Det maximala antalet instruktioner redo att matas ut för att övervägas under det första schemaläggningspasset."
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr "Maximal längd på kandidatskanningar efter rätlinjiga styrkereduktioner."
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr "Maximalt antal av may-defs som besöks vid spekulativ avvirtualisering."
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr "Maximalt tillåtet rekursionsdjup när en egenskap efterfrågas från ett SSA-namn."
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "Maximalt antal konstantlagringar att slå samman i passet för sammanslagning av lagring."
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "Maximalt antal villkorliga lagringspar som kan sänkas."
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "Maximalt antal lagringskedjor att spåra på samma gång i passet för sammanslagning av lagring."
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr "Maximalt antal liknande gb att jämföra ett gb med."
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr "Maximalt antal iterationer för passet över en funktion."
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr "Maximalt antal strängar för vilket strlen-optimeringspasset kommer följa stränglängder."
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr "Maximalt antal argument i en PHI som stödjs av TREE if-konvertering om inte slingan är märkt med simd-pragma."
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Det maximala antalet utrullningar av en enskild slinga."
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "Det maximala antalet instruktioner för att överväga att rulla ut i en slinga."
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "Det maximala antalet instruktioner i en oväxlad slinga."
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Det maximala antalet omväxlingar i en enskild slinga."
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "Om -fvariable-expansion-in-unroller är på, det maximala antalet gånger som en enskild variabel kommer expanderas under slingutrullning."
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr "Maximalt rekursionsdjup för att expandera variabelspårningsuttryck."
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr "Maximal storlek på loc-listan för vilken omvända operationer skall läggas till."
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr "Max storlek på hashtabell för variabelspårning."
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr "Maximala antalet VÄRDEn hanterade under ett enskilt anrop av find_base_term."
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr "Maximalt antal försäkranden att lägga till längs standardbågen i en switch-sats under VRP."
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "Det minsta antal av matchande instruktioner att överväga för korshopp."
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Inline:a rekursivt endast när sannolikheten för att ett anrop skall göras överskrider parametern."
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr "Minsta förhållande av instruktioner till minnesoperationer för att aktivera förhandshämtning (prefetching) för en slinga med okänt antal turer."
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr "Den minsta tröskelvärdet för sannolikheten för semi-invarianta villkorssatser för att utlösa slingdelning."
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr "Minsta UID som får användas för en icke-felsökningsinstruktion."
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr "Minsta storleken på variabler som är med i stackutrymmesdelning utan optimering."
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "Den minsta sannolikheten för att nå ett källkodsblock för spekulativ schemaläggning mellan block."
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "Om -ftree-vectorize används, den minimala slinggränsen på en slinga för att den skall övervägas för vektorisering."
 
-#: params.opt:782
+#: params.opt:787
+#, fuzzy, no-c-format
+#| msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr "-fopenacc-kernels=[decompose|parloops]\tAnge läge för hantering av OpenACC ”kernels”-kontruktioner."
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr "Styckesstorlek för omp-schema för slingor som parallelliseras av parloops."
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Det minimala antalet iterationer per trådar hos en innersta parallelliserad slinga."
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchemaläggningstyp för omp-scheman för slingor som parallelliseras av parloops."
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr "Maximala sannolikheten för ingång i GB av delad region (i procent i förhållande till ingång i GB av funktionen) för att partiell inlining skall ske."
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "Maximala uppskattade sannolikheten för en gren för att anses förutsägbar."
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr "Huruvida mjukvaruförhandshämtningstips skall matas ut för icke-konstanta steg."
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "Antalet instruktioner som körs före förhandshämtning (prefetch) är klar."
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr "Minsta förhållande av instruktioner till minnesoperationer för att aktivera förhandshämtning (prefetching) i en slinga."
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr "Det minsta konstanta steget bortom vilket vi skall använda förhandshämtningstips."
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr "Använd internt funktions-id i profileringsuppslagningar."
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "Maximalt djup av en slingnästning för fullständig optimistisk värdenumrering."
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr "Maximalt antal upplösningar av tvetydigheter att utföra per minnesåtkomst."
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "Gräns på komplexiteten av uttryck som används i analyseraren av skalära uttryck."
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "Gräns för storleken av uttryck som används i analyseraren av skalära uttryck."
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr "Styrflagga för schemaläggningsmodell av automatisk förhandshämtning i hårdvara.  Antalet cykler av framförhållning modellen tittar in i, vid ”0” aktiveras endast heuristik för instruktionssortering.  Avaktiverat som standard."
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr "Minimala avståndet mellan lagring och laddning som kan vara i konflikt."
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr "Vilken -fsched-pressure-algoritm som skall användas."
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "Den minsta sannolikheten för spekulativ framgång (i procent) för att spekulativ instruktion skall schemaläggas."
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr "Den minsta sannolikhet en båge måste ha för att schemaläggaren skall spara sitt tillstånd över den."
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "Det maximala antalet instruktioner i redolistan som betraktas som valbara för namnändring."
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr "Den maximala storleken på fönstret för framåtblickar vid selektiv schemaläggning."
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "Maximalt antal gånger som en instruktion kan schemaläggas."
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr "Antalet förhandshämtningar (prefetch) som kan vara igång samtidigt."
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr "Målet för blocks relativa exekveringsfrekvens (som en procentsats) som behövs för att sänka en sats."
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "Antalet cykler som pendlingsschemaläggaren beaktar när den söker efter konflikter med DFA."
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "Ett tröskelvärde på det genomsnittliga antalet varv som beaktas av pendlingsmoduloschemaläggaren."
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "En faktor för att trimma den övre gränsen som pendlingsmoduloschemaläggaren använder för att schemalägga en slinga."
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr "Minimivärdet på steglängden som pendlingsschemaläggaren kommer generera."
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr "Maximal storlek, i lagringsenheter, av ett aggregat som skall övervägas för skalärisering vid kompilering för storlek."
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr "Maximal storlek, i lagringsenheter, av ett aggregat som skall övervägas för skalärisering vid kompilering för hastighet."
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr "Maximalt antal artificiella åtkomster för att aktivera framåtpropagering som Skalär ersättning av aggregat kommer behålla för en lokal variabel."
 
-#: params.opt:924
+#: params.opt:942
 #, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "Det maximala antalet SSA_NAME-tilldelningar att följa för att avgöra ett värde."
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "Den undre gränsen för att en buffert skall övervägas för skydd mot stacksprängning."
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr "Storleken på stackvakten uttryckt som en potens av två i byte."
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr "Intervall inom vilket stacken skall testas uttryckt som en potens av två i byte."
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr "Tillåt passet för lagringssammanslagning att introducera ojusterade lagringar om det är tillåtet att göra det."
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr "Maximala storleken på en enda lagringssammanslagningsregion i byte."
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "Det maximala förhållandet mellan vektorstorlek och switch-grenar för att en switch-konvertering skall ske."
 
-#: params.opt:952
+#: params.opt:970
 #, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "Maximalt antal baser som lagras i varje modref-träd."
 
-#: params.opt:956
+#: params.opt:974
 #, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr "Maximalt antal referenser som lagras i varje modref-bas."
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "Maximalt antal åtkomster som lagras i varje modref-referens."
 
-#: params.opt:964
+#: params.opt:982
 #, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr "Maximalt antal tester som utförs av modref-frågor."
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr "Maximalt djup hos DFS-vandringar som används av modref-flyktanalys."
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "Maximalt antal flyktpunkter spårade av modref per SSA-namn."
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr "Storlek i byte efter vilken trådlokala aggregat skall instrumenteras med loggningsfunktioner istället för spara/återställ-par."
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "Andelen av funktion i procent, viktad efter exekveringsfrekvens, som måste täckas av spårinformation.  Används när profileringsdata inte är tillgängligt."
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "Andelen av funktion i procent, viktad efter exekveringsfrekvens, som måste täckas av spårinformation.  Används när profileringsdata är tillgängligt."
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Maximal kodtillväxt orsakad av svansduplicering (i procent)."
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "Stoppa framåttillväxt om sannolikheten av bästa båge är mindre än detta tröskelvärde (i procent).  Används när profileringsdata inte är tillgänglig."
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "Stoppa framåttillväxt om sannolikheten av bästa båge är mindre än detta tröskelvärde (i procent).  Används när profileringsdata är tillgänglig."
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "Stoppa omvänd tillväxt om den omvända sannolikheten av bästa båge är mindre än detta tröskelvärde (i procent)."
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr "Sätt maximala antalet instruktioner som exekveras parallellt i ett reassociativt träd.  Om 0, använd den målberoende heuristiken."
 
-#: params.opt:1008
+#: params.opt:1026
 #, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "Mata ut specialinstrumentering för åtkomst av volatile:r."
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr "Mata ut instrumenteringsanrop till __tsan_func_entry() och __tsan_func_exit()."
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr "Det maximala antalet nästade anrop att söka i efter styrberoenden under analys av oinitierade variabler."
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "Instruktion inräknad för funktionprolog, -epilog och andra omkostnader."
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "Tid inräknad för funktionprolog, -epilog och andra omkostnader."
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr "Instruktion inräknad för funktionssnuttsomkostnader."
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr "Tid inräknad för funktionssnuttsomkostnader."
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr "Nämnaren n i bråket 1/n för antalet profileringskörningar av hela programmet under vilken exekveringsräknare för att ett givet grundblock måste vara för att inte anses osannolik."
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr "Maximal utrullningsfaktor för transformationen unroll-and-jam."
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr "Minimal procent av minnesreferenser som måste försvinna för att unroll-and-jam skall betraktas som lönsamt."
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr "Använd direkta förgiftnings-/avgiftningsinstruktioner för variabler som är mindre eller lika med detta tal."
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr "Om kanoniska typer skall användas."
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "Aktivera vektorisering av slingepiloger med mindre vektorstorlek."
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr "Maximala antalet slingavskalningar för att förbättra justering av datareferenser i en slinga."
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "Gräns för antalet körtidskontroller som läggs in av vektoriserarens slingversionering för aliaskontroller."
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Gräns för antalet körtidskontroller som läggs in av vektoriserarens slingversionering för justeringskontroller."
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr "Styr hur slingvektoriseraren använder partiella vektorer. 0 betyder aldrig, 1 betyder endast för slingor vars behov att iterera kan tas bort, 2 betyder för alla slingor. Standardvärdet är 2."
@@ -20209,7 +20222,7 @@ msgid "expected boolean type"
 msgstr "boolesk typ förväntades"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "heltal förväntades"
@@ -20273,7 +20286,7 @@ msgstr "inte tillräckligt med argument"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "för många argument"
@@ -20627,7 +20640,7 @@ msgstr "ignorerar attributet %qE eftersom det står i konflikt med attributet %q
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "tidigare deklaration här"
@@ -20682,7 +20695,7 @@ msgstr "typattribut ignoreras efter att typen redan är definierad"
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -20711,20 +20724,20 @@ msgstr "typattribut ignoreras efter att typen redan är definierad"
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -20735,8 +20748,8 @@ msgstr "attributet %qE ignorerat"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "saknat attribut %<target%> för flerversioners %qD"
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "tidigare deklaration av %qD"
@@ -20746,59 +20759,59 @@ msgstr "tidigare deklaration av %qD"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "ignorerar attribut använda på %qT efter dess definition"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D är redan deklarerad med attributet dllexport: dllimport ignoreras"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D omdeklarerad utan attributet dllimport efter att ha refererats med länkklass dll"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D omdeklarerades utan attributet dllimport: tidigare dllimport ignoreras"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "inline-funktionen %q+D deklarerades som dllimport: attributet ignorerat"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "funktionsdefinition %q+D är markerad dllimport"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "variabeldefinition %q+D är markerad dllimport"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "extern länkklass krävs för symbol %q+D på grund av attributet %qE"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qE implicerar standardsynlighet, men %qD har redan deklarerats med annan synlighet"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] "%qD anger ett mer restriktivt attribut än sitt mål %qD: %s"
 msgstr[1] "%qD anger mer restriktiva attribut än sitt mål %qD: %s"
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "%qD målet deklarerades här"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -20900,7 +20913,7 @@ msgstr "det refererade argumentet deklarerades här"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "index %qwi till en konstant sträng pekar utanför dess gränser"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE är deklarerad här"
@@ -20925,720 +20938,720 @@ msgstr "tredje argumentet till %<__builtin_prefetch%> måste vara en konstant"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "ogiltigt tredje argument till %<__builtin_prefetch%>; använder noll"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "%K%qD den angivna gränsen %E kan överskrida maximal objektstorlek %E"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "%K%qD: den angivna gränsen %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "%Kden angivna gränsen %E kan överskrida maximal objektstorlek %E"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr "%Kden angivna gränsen %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "%K%qD angivna gränsen [%E, %E] kan överskrida maximal objektstorlek %E"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr "%K%qD angivna gränsen [%E, %E] överskrider maximal objektstorlek %E"
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "%Kangivna gränsen [%E, %E] kan överskrida maximal objektstorlek %E"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "%Kangivna gränsen [%E, %E] överskrider maximal objektstorlek %E"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr "%K%qD den angivna gränsen %E kan överskrida källstorleken %E"
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr "%K%qD den angivna gränsen %E överskrider källstorleken %E"
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr "%Kden angivna gränsen %E överskrider källstorleken %E"
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr "%Kden angivna gränsen %E överskrider källstorleken %E"
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr "%K%qD angivna gränsen [%E, %E] kan överskrida källstorleken %E"
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr "%K%qD angivna gränsen [%E, %E] överskrider källstorleken %E"
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr "%Kden angivna gränsen [%E, %E] kan överskrida källstorleken %E"
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr "%Kden angivna gränsen [%E, %E] överskrider källstorleken %E"
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, gcc-internal-format
 msgid "source object declared here"
 msgstr "källobjektet är deklarerat här"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr "källobjektet är allokerat här"
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "%K%qD den angivna storleken %E kan överskrida maximal objektstorlek %E"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr "%K%qD: den angivna storleken %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "%Kden angivna storleken %E kan överskrida maximal objektstorlek %E"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr "%Kden angivna storleken %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "%K%qD den angivna storleken mellan %E och %E kan överskrida maximal objektstorlek %E"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD: den angivna storleken mellan %E och %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "%Kden angivna storleken mellan %E och %E kan överskrida maximal objektstorlek %E"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr "%Kden angivna storleken mellan %E och %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr "%K%qD den angivna gränsen %E kan överskrida destinationsstorleken %E"
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr "%K%qD: den angivna gränsen %E överskrider destinationsstorleken %E"
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr "%Kden angivna gränsen %E kan överskrida destinationsstorleken %E"
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr "%Kden angivna gränsen %E överskrider destinationsstorleken %E"
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr "%K%qD den angivna gränsen [%E, %E] kan överskrida destinationsstorleken %E"
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr "%K%qD den angivna gränsen [%E, %E] överskrider destinationsstorleken %E"
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr "%Kden angivna gränsen [%E, %E] överskrider destinationsstorleken %E"
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, gcc-internal-format
 msgid "destination object declared here"
 msgstr "destinationsobjektet är deklarerat här"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, gcc-internal-format
 msgid "destination object allocated here"
 msgstr "destinationsobjektet är allokerat här"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr "%K%qD kan komma åt %E byte i en region av storlek %E"
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr "%K%qD kommer åt %E byte i en region av storlek %E"
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr "%K%qD kan komma åt %E byte i en region av storlek %E"
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr "%K%qD kommer åt %E byte i en region av storlek %E"
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr "%Kkan komma åt %E byte i en region av storlek %E"
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr "%Kkommer åt %E byte i en region av storlek %E"
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr "%Kkan komma åt %E byte i en region av storlek %E"
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr "%Kkommer åt %E byte i en region av storlek %E"
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr "%K%qD kan komma åt %E eller fler byte i en region av storlek %E"
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr "%K%qD kommer åt %E eller fler byte i en region av storlek %E"
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr "%Kkan komma åt %E eller fler byte i en region av storlek %E"
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr "%Kkommer åt %E eller fler byte i en region av storlek %E"
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr "%K%qD kan komma åt mellan %E och %E byte i en region av storlek %E"
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr "%K%qD kommer åt mellan %E och %E byte i en region av storlek %E"
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr "%Kkan komma åt mellan %E och %E byte i en region av storlek %E"
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr "%Kkommer åt mellan %E och %E byte i en region av storlek %E"
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr "%K%qD kan skriva %E byte till en region med storlek %E"
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr "%K%qD att skriva %E byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr "%K%qD kan skriva %E byte till en region med storlek %E"
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD att skriva %E byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr "%Kkan skriva %E byte till en region med storlek %E"
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr "%Katt skriva %E byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr "%Kkan skriva %E byte till en region med storlek %E"
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr "%Katt skriva %E byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr "%K%qD kan skriva %E eller fler byte till en region av storlek %E"
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: att skriva %E eller fler byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr "%Kkan skriva %E eller fler byte till en region av storlek %E"
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr "%Katt skriva %E eller fler byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr "%K%qD kan skriva mellan %E och %E byte till en region av storlek %E"
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: att skriva mellan %E och %E byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr "%Kkan skriva mellan %E och %E byte till en region av storlek %E"
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%Katt skriva mellan %E och %E byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr "%K%qD kan läsa %E byte från en region av storlek %E"
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr "%K%qD läser %E byte från en region av storlek %E"
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr "%K%qD kan läsa %E byte från en region av storlek %E"
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr "%K%qD läser %E byte från en region av storlek %E"
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr "%Kkan läsa %E byte från en region av storlek %E"
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr "%Kläser %E byte från en region av storlek %E"
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr "%Kkan läsa %E byte från en region av storlek %E"
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr "%Kläser %E byte från en region av storlek %E"
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr "%K%qD kan läsa %E eller fler byte från en region av storlek %E"
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr "%K%qD läser %E eller fler byte till en region av storlek %E"
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr "%Kkan läsa %E eller fler byte från en region av storlek %E"
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr "%Kläser %E eller fler byte till en region av storlek %E"
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr "%K%qD kan läsa mellan %E och %E byte från en region av storlek %E"
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr "%K%qD läser mellan %E och %E byte från en region av storlek %E"
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr "%Kkan läsa mellan %E och %E byte från en region av storlek %E"
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr "%Kläser mellan %E och %E byte från en region av storlek %E"
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] "%K%qD förväntar sig %E byte i en region av storlek %E"
 msgstr[1] "%K%qD förväntar sig %E byte i en region av storlek %E"
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] "%Kförväntar sig %E byte från en region av storlek %E"
 msgstr[1] "%Kförväntar sig %E byte från en region av storlek %E"
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr "%K%qD förväntar sig %E eller fler byte i en region av storlek %E"
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr "%Kförväntar sig %E eller fler byte i en region av storlek %E"
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr "%K%qD förväntar sig mellan %E och %E byte i en region av storlek %E"
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr "%Kförväntar sig mellan %E och %E byte i en region av storlek %E"
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr "vid avståndet %s till destinationsobjekt %qE med storlek %s"
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr "destinationsobjekt %qE av storlek %s"
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr "vid avståndet %s till destinationsobjektet med storlek %s allokerad av %qE"
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr "destinationsobjektet med storlek %s allokerat av %qE"
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr "vid avståndet %s till källobjekt %qE med storlek %s"
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr "källobjekt %qE av storlek %s"
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr "vid avståndet %s in i källobjektet med storlek %s allokerat av %qE"
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr "källobjektet med storlek %s allokerad av %qE"
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr "%K%qD den angivna gränsen %E är lika med destinationsstorleken"
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "För många argument till funktionen %<va_start%>"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "ogiltiga argument till %qD"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "argument som inte stödjs till %qD"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr "att anropa %qD med ett nollskilt argument är osäkert"
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "båda argumenten till %<__builtin___clear_cache%> måste vara pekare"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "trampolin genererad för nästad funktion %qD"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD bytte semantik i GCC 4.4"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "okänd arkitekturspecificerare i minnesmodellen till inbyggd"
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "ogiltigt minnesmodellargument till inbyggd funktion"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "felminnesmodellen kan inte vara starkare än den lyckade minnesmodellen för %<__atomic_compare_exchange%>"
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "ogiltig felminnesmodell för %<__atomic_compare_exchange%>"
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "ogiltig minnesmodell för %<__atomic_load%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ogiltigt minnesmodell för %<__atomic_store%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr "icke-konstant argument 1 till %qs"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, gcc-internal-format
 msgid "non-integer argument 1 to %qs"
 msgstr "icke-heltals-argument 1 till %qs"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "%<__builtin_thread_pointer%> stödjs inte på denna målarkitektur"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "%<__builtin_set_thread_pointer%> stödjs inte på denna målarkitektur"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr "%qs stödjs inte i OpenACC-kod"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr "icke-konstant argument 0 till %qs"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr "otillåtet argument 0 till %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kogiltig användning av %<__builtin_va_arg_pack ()%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kogiltig användning av %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "andra argumentet till %<__builtin_longjmp%> måste vara 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "målformatet stödjer inte oändligheten"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> används i en funktion med fixt antal argument"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "fel antal argument till funktionen %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> anropad utan argument"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "fel antal argument till funktionen %<__builtin_next_arg%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "andra parametern till %<va_start%> är inte det sista namngivna argumentet"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "odefinierat beteende när andra parametern till %<va_start%> är deklarerad med lagringsklass %<register%>"
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kförsta argumentet till %qD måste vara en pekare, det andra en heltalskonstant"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Ksista argumentet till %qD är inte en heltalskonstant mellan 0 och 3"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr "%K%qD anropad på pekaren %qE med nollskilt avstånd%s"
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "deklarerad här"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, gcc-internal-format
 msgid "returned from %qD"
 msgstr "returnerad från %qD"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, gcc-internal-format
 msgid "returned from %qT"
 msgstr "returnerad från %qT"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, gcc-internal-format
 msgid "obtained here"
 msgstr "erhållen här"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr "%K%qD anropat på ett oallokerat objekt %qD"
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr "%K%qD anropat på en pekare till ett oallokerat objekt %qE"
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, gcc-internal-format
 msgid "assigned here"
 msgstr "tilldelad här"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr "%K%qD anropad på en pekare returnerad från en allokeringsfunktion som inte stämmer"
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr "%K%qD anropad på en pekare till ett oallokerat objekt"
@@ -22401,302 +22414,302 @@ msgstr "grundblock inte utlagda i ordning"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "antal gb-noter i instruktionskedjan (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "antal anropande bågar är felaktigt"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr "saknat indirekt anrop i en spekulativ anropssekvens"
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr "indirekt anrop i en spekulativ anropssekvens har ingen spekulativ flagga"
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr "spekulativa bågar är inte närliggande"
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr "direkt anrop av %s i en spekulativ anropssekvens har ingen spekulativ flagga"
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr "direkt anrop av %s i en spekulativ anropssekvens har speculative_id %i utanför intervallet"
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr "dubblerat direkt anrop av %s i en spekulativ anropssekvens med speculative_id %i"
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr "call stmt-hashen pekar inte på den första direkta bågen av en spekulativ anropssekvens"
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr "dubblerad referens %s i en spekulativ anropssekvens med speculative_id %i"
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "saknade direkta anrop för spekulation %i"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "referens saknas för spekulation %i"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr "antalet spekulativa mål %i stämmer inte med num_speculative_call_targets %i"
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "aux-fält satt för båge %s->%s"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "cgraph-antalet är felaktigt"
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "inline-klon i samma comdat-grupplista"
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "inline-klonantal är inte kompatibelt"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "tp_first_run måste vara icke-negativt"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "lokala symboler måste vara definierade"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "externt synlig inline-klon"
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "inline-klon som man tar adressen till"
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "inline-klon tvingas till utdata"
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr "calls_comdat_local är satt utanför någon comdat-grupp"
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr "felaktig flagga till calls_comdat_local"
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "attributet malloc skall användas på en funktion som returnerar en pekare"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux-fält satt för indirekt båge från %s"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "bågräknaren är inte kompatibel med funktionsräknaren"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "En indirektbåge från %s är inte markerad som indirekt eller har associerad indirect_info, motsvarande sats är: "
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr "bågen har både call_stmt och lto_stmt_uid satta"
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "comdat-lokal funktion anropad av %s utanför dess comdat"
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to-pekare är fel"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "flera inline-anropare"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "inlined_to-pekare angiven för noninline-anropare"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "anropsbågantal stämmer inte med GB-antal"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "indirekta anropsantal stämmer inte med GB-antal"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr "referensen har både stmt och lto_stmt_uid satta"
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlined_to-pekare är angivet men inga företrädare finns"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to-pekare refererar till sig själv"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node har fel clone_of"
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node har fel klonlista"
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "cgraph_node är i klonlistan men den är inte en klon"
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "cgraph_node har fel prev_clone-pekare"
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "dubbellänkad lista av kloner trasig"
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias har anropsbågar"
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias har icke-alias-referens"
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias har mer än en aliasreferens"
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Analyserat alias har ingen referens"
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Ingen båge ut från snuttnod"
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Mer än en båge ut från en snuttnod"
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Snuttar får inte ha en kropp"
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "delat anropssats:"
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "bågpekare till fel deklaration:"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "ett indirekt båge med okänd anropsmål motsvarande ett call_stmt med en känd deklaration:"
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "anropsgrafsbåge saknas för anropssats:"
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "referens till död sats"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "båge %s->%s har ingen motsvarande anropssats"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "en indirekt båge från %s har inget motsvarande call_stmt"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr "ursprung saktas för en nod i en nästad lista"
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "ursprunget pekar på en annan förälder"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node misslyckades"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s: sektion %s.%d saknas"
@@ -22777,12 +22790,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "attributet %<weakref%> ignorerat för att variabeln är initierad"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F är använd men inte definierad"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F är deklarerad %<static%> men definieras aldrig"
@@ -22852,7 +22865,7 @@ msgstr "storleken på returvärdet från %q+D är %u byte"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "storleken på returvärdet från %q+D är större än %wu byte"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "noder med ej frigjort minne funna"
@@ -23256,12 +23269,12 @@ msgstr "ignorerar flaggan %<-fopt-info-%s%> som möjligen står i konflikt"
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr "multipla EH-personligheter stödjs endast med assemblerare som stödjer direktivet %<.cfi.personality%>"
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr "%<-gdwarf-6%> matas ut som version 5 med inkompatibiliteter"
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "odelegitimerad UNSPEC %s (%d) funnen på variabelplats"
@@ -23281,7 +23294,7 @@ msgstr "delad rtx"
 msgid "internal consistency failure"
 msgstr "internt konsistensfel"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn använd där emit_jump_insn behövs:\n"
@@ -23411,42 +23424,42 @@ msgstr "det gick inte att stänga slutgiltig instruktionsdumpfil %qs: %m"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "stor fixdecimalskonstant implicit trunkerad till fixdecimaltyp"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "jämförelsen är alltid %d på grund av bredd på bitfält"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "antar att teckenspill inte förekommer vid förenkling av intervalltest"
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "jämförelsen är alltid %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> mellan omatchade olikhetstester är alltid 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> mellan ömsesidigt uteslutande likhetstester är alltid 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "antar att teckenspill inte förekommer vid reduktion av konstant i jämförelse"
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "antar att teckenspill inte förekommer vid kombination av konstanter runt en jämförelse"
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vikningskontroll: originalträdet ändrat av vikning"
@@ -23461,7 +23474,7 @@ msgstr "total storlek på lokala objekt %wu överskrider maximum %wu"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "total storlek på lokala objekt överskrider maximum %wu"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "omöjlig begränsning i %<asm%>"
@@ -24077,7 +24090,7 @@ msgstr "nollpekardereferens"
 msgid "function may return address of local variable"
 msgstr "funktionen kan returnera adressen till en lokal variabel"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "funktionen returnerar adress till en lokal variabel"
@@ -24443,53 +24456,53 @@ msgstr "angiven gräns på %wu överskrider storleken %wu på destinationsobjekt
 msgid "%Gnull format string"
 msgstr "%Gnollformatsträng"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 msgid "%Guse of %<alloca%>"
 msgstr "%Ganvändning av %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 msgid "%Gargument to variable-length array may be too large"
 msgstr "%Gargumentet till en vektor med variabel längd kan vara för stort"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "%Gargumentet till %<alloca%> kan vara för stort"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr "gränsen är %wu byte, men argumentet kan vara så stort som %s"
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 msgid "%Gargument to variable-length array is too large"
 msgstr "%Gargumentet till en vektor med variabel längd är för stort"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "%Gargumentet till %<alloca%> är för stort"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr "gränsen är %wu byte, men argumentet är %s"
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 msgid "%Gunbounded use of variable-length array"
 msgstr "%Gobegränsad användning av vektor med variabel längd"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "%Gobegränsad användning av %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "%Ganvändning av %<alloca%> inuti en slinga"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 msgid "%Gargument to variable-length array is zero"
 msgstr "%Gargumentet till en vektor med variabel längd är noll"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 msgid "%Gargument to %<alloca%> is zero"
 msgstr "%Gargumentet till %<alloca%> är noll"
 
@@ -24603,7 +24616,7 @@ msgstr "%G%qD den angivna gränsen mellan %wu och %wu överskrider maximal objek
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr "%G%qD pekarspill mellan avstånd %s och storlek %s vid åtkomst av vektorn %qD av typ %qT"
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "vektorn %qD är deklarerad här"
@@ -24629,11 +24642,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "%G%qD på avståndet %s är utanför gränserna för objekt %qD med typen %qT"
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD är deklarerad här"
@@ -24708,308 +24721,308 @@ msgstr "attributet %<fallthrough%> föregår inte en case-etikett eller standard
 msgid "using result of function returning %<void%>"
 msgstr "använder resultat från funktion som returnerar %<void%>"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr "icke-minnesutdata %d måste stanna i minnet"
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "ogiltigt l-värde i %<asm%>-utdata %d"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "icke-minnesindata %d måste stanna i minnet"
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "minnesindata %d är inte direkt adresserbar"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "trådprivat variabel %qE använd i en region med en %<order(concurrent)%>-klausul"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, gcc-internal-format
 msgid "enclosing region"
 msgstr "omgivande region"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "trådprivat variabel %qE använd i målregion"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "omgivande målregion"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "trådprivat variabel %qE använd i obunden uppgift"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "omgivande uppgift"
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE inte angiven i omgivande %qs"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "omgivande %qs"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE inte angiven i omgivande OpenACC %qs-konstruktion"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "omgivande OpenACC %qs-konstruktion"
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE med %<link%>-klausul använd i %<routine%>-funktion"
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE behöver ett %<declare%>-direktiv att användas i en %<routine%>-funktion"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "%qE inte angiven i omgivande %<target%>"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr "omgivande %<target%>"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variabeln %qE deklarerad i omgivande %<host_data%>-region"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD refererad i målregion som inte har en avbildbar typ"
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "iterationsvariabel %qE är förutbestämt linjär"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "instansvariabel %qE skall vara privat"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "iterationsvariabel %qE får inte vara firstprivate"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "iterationsvariabel %qE får inte vara reduction"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "instansvariabel %qE får inte vara linjär"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr "villkorlig %<lastprivate%>-klausul på %qs-konstruktion"
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "icke-skalär variabel %qD i villkorlig %<lastprivate%>-klausul"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr "reduktionsmodifieraren %<task%> på en konstruktion med en klausul %<nowait%>"
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr "felaktig reduktionsmodifierare %<task%> på en annan konstruktion än %<parallel%>, %qs eller %<sections%>"
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "en %<inscan%> %<reduction%>-klausul på en %qs-konstruktion"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%>-klausul för en annan variabel än en slingiterator angiven vid konstruktion kombinerad med %<distribute%>"
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "avbildningsfältet %qE med variabel längds post"
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE förekommer mer än en gång i avbildningsklausuler"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "copyprivate-variabel %qE är inte privat threadprivate eller private i yttre sammanhang"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s-variabel %qE är privat i yttre sammanhang"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%qs %<if%>-klausulmodifierare förväntades snarare än %qs"
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr "%qD angivet i en %qs-klausul men inte i en %<inscan%> %<reduction%>-klausul av den inneslutande konstruktionen"
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD i implicit %<map%>-klausul"
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD i implicit %<firstprivate%>-klausul vid %<target%>-konstruktion"
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD i %<firstprivate%>-klausul vid %<target%>-konstruktion"
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "samma variabel använd i %<firstprivate%>- och %<lastprivate%>-klausuler vid %<distribute%>-konstruktion"
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "inkompatibel dataklausul med reduktion på %qE; befordrar till %<present_or_copy%>"
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr "%qD angivet i en %<inscan%> %<reduction%>-klausul men inte i en %<scan%>-direktivklausul"
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "ogiltig privat reduktion av %qE"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "en %<inscan%> %<reduction%>-klausul använd tillsammans med en %<linear%>-klausul för en annan variabel än slingitereraren"
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "%<mutexinoutset%>-sort i %<depend%>-klausul vid %<taskwait%>-konstruktion"
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr "%qs-klausul får inte förekomma på en ickerektangulär %qs"
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "villkorlig %<lastprivate%>-klausul på slingitereraren %qD ignorerad"
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "%<bind%>-klausul inte angiven på en %<loop%>-konstruktion som inte är nästad inuti en annan OpenMP-konstruktion"
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "%<bind(parallel)%> på en %<loop%>-konstruktion nästad inuti en %<simd%>-konstruktion"
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "%<bind(teams)%> på en %<loop%>-region som inte är strikt nästad inuti en %<teams%>-region"
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "%<lastprivate%>-klausul på en %<loop%>-konstruktion refererar till en variabel %qD som inte är slingiteratorn"
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%>-konstruktion med %<depend%>-klausul måste vara nära innesluten inuti en slinga med %<ordered%>-klausul med en parameter"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "variabeln %qE är inte en iterator av den yttersta slingan %d, %qE förväntades"
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "antalet variabler i %<depend%>-klausul med %<sink%>-modifierare stämmer inte med antalet iterationsvariabler"
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "mer än en %<depend%>-klausul med %<source%>-modifierare på en %<ordered%>-konstruktion"
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "%<depend%>-klausul med %<source%>-modifierare angiven tillsammans med %<depend%>-klausuler med %<sink%>-modifierare på samma konstruktion"
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification misslyckades"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT konverteras till %qT när det skickas via %<...%>"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(alltså skall du skicka %qT och inte %qT till %<va_arg%>)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "om denna kod nås, kommer programmet att avbryta"
@@ -25458,22 +25471,22 @@ msgstr "Funktionen %qs, parametern %u, har IPA-SRA-åtkomst som överlappar"
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr "Funktionen %s, parameter %u, används men har inte någon säker IPA-SRA-åtkomst"
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s kan inte användas i en %<asm%> här"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr "rampekare behövs, men är reserverad"
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr "för %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "ramstorlek för stor för pålitlig stackkontroll"
@@ -25493,12 +25506,12 @@ msgstr "%<asm%>-operand har omöjliga begränsningar"
 msgid "unable to find a register to spill"
 msgstr "kan inte hitta ett register att spilla"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "inkonsistenta operandbegränsningar i en %<asm%>"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "maximalt antal genererade omladdningsinstruktioner per instruktion uppnått (%d)"
@@ -26206,12 +26219,12 @@ msgstr "argument till %qs är inte mellan %d och %d"
 msgid "unrecognized argument in option %qs"
 msgstr "okänt argument till flaggan %qs"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "giltiga argument till %qs är: %s; menade du %qs?"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "giltiga argument till %qs är: %s"
@@ -26336,7 +26349,7 @@ msgstr "transaktionsminne stödjs inte i denna konfiguration"
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr "sektionsankare måste vara avaktiverade när ordningsändring på toppnivå är avaktiverat"
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> fungerar inte med undantag på denna arkitektur"
@@ -26838,22 +26851,22 @@ msgstr "explicit använda register måste vara grupperade i toppen på stacken"
 msgid "output operand %d must use %<&%> constraint"
 msgstr "utdataoperand %d måste använda %<&%>-begränsning"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "%qs: [%u] felaktigt %<next_regno%> för tom kedja (%u)"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "%qs: slinga i %<next_regno%>-kedja (%u)"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "%qs: [%u] felaktigt %<oldest_regno%> (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr "%qs: [%u] ej tomt register i kedja (%s %u %i)"
@@ -26915,12 +26928,12 @@ msgstr "kan inte läsa om heltalskonstantoperand i %<asm%>"
 msgid "impossible register constraint in %<asm%>"
 msgstr "omöjlig registerbegränsning i %<asm%>"
 
-#: reload.c:2687
+#: reload.c:2692
 #, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "denna målarkitektur stödjer inte %<asm goto%> med utdata i %<asm%>"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "%<&%>-begränsning använd utan registerklass"
@@ -26950,52 +26963,52 @@ msgstr "%<asm%>-operandbegränsningar inkompatibla med operandstorlek"
 msgid "output operand is constant in %<asm%>"
 msgstr "utdataoperand är konstant i %<asm%>"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "RTL-kontroll: åtkomst av elt %d av ”%s” med sista elt %d i %s, vid %s:%d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL-kontroll: förväntade elt %d typ ”%c”, har ”%c” (rtx %s) i %s, vid %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL-kontroll: förväntade elt %d typ ”%c” eller ”%c”, har ”%c” (rtx %s) i %s, vid %s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL-kontroll: förväntade kod ”%s”, har ”%s” i %s, vid %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL-kontroll: förväntade kod ”%s” eller ”%s”, har ”%s” i %s, vid %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL-kontroll: förväntade kod ”%s”, ”%s” eller ”%s”, har ”%s” i %s, vid %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "RTL-kontroll: försök att hantera icke-block-symbol som en blocksymbol i %s, vid %s:%d"
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL-kontroll: åtkomst av hwi elt %d i vektor med sista elt %d i %s, vid %s:%d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL-kontroll: åtkomst av elt %d i vektor med sista elt %d i %s, vid %s:%d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "RTL-flaggkontroll: %s använt med oväntad rtx-kod ”%s” i %s, vid %s:%d"
@@ -27040,22 +27053,22 @@ msgstr "matchningsbegränsning refererar ogiltigt operandnummer"
 msgid "invalid punctuation %qc in constraint"
 msgstr "ogiltig interpunktion %qc i begränsning"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "matchningsbegränsning tillåter inte ett register"
 
-#: stmt.c:524
+#: stmt.c:525
 #, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "upprepning av %<asm%>-operandnamn %qs"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "avslutande klammer för namngiven operand saknas"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "odefinierad namngiven operand %qs"
@@ -27733,9 +27746,9 @@ msgstr "ogiltig operand till %qs"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "typer stämmer inte i %qs"
@@ -27770,7 +27783,7 @@ msgstr "ogiltig avståndsoperand i %qs"
 msgid "invalid clique in %qs"
 msgstr "felaktig klick i %qs"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr "%qs i gimple IL"
@@ -27976,362 +27989,362 @@ msgstr "ogiltiga operander treställig operation"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "första argumentet till en %qs måste vara av boolesk vektortyp med samma antal element som resultatet"
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "vektortyper förväntades i %qs"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "vektorer med olika elementantal funna i %qs"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "ogiltig masktyp i %qs"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "otillåten typkombination i %qs"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "ogiltig position eller storlek i %qs"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "%qs in i icke-läges-precisionsoperand"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "insättning utanför intervallet i %qs"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qs inte på elementgräns"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "icketrivial konvertering i %qs"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "%qs vänstersida i clobber-sats"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "ogiltig operand till %qs"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "ogiltig högersida för gimple-minneslagring: %qs"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "felaktig typ av vektor-%qs-element"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "felaktigt antal vektor-%qs-element"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "felaktig typ av vektor-CONSTRUCTOR-element"
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr "vektor-%qs med elementindex som inte är NULL"
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "vektor-%qs-element är inte ett GIMPLE-värde"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "%qs för annat än en vektor med element"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr "%qs med villkor som alltid är falskt"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "ogiltig operand i retursats"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "ogiltig konvertering i retursats"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "goto-destination är varken en etikett eller en pekare"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "ogiltig operand till switch-sats"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "annat än heltalstyp i en switch-sats"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "ogiltig standardfallsetikett i en switch-sats"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "ogiltig %<CASE_CHAIN%>"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "ogiltig case-etikett i en switch-sats"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "ogiltigt case-intervall i en switch-sats"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "typprecision stämmer inte i en switch-sats"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "typer stämmer inte för case-etikett i en switch-sats"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case-etiketter är inte sorterade i en switch-sats"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "etikettens kontext är inte den aktuella funktionsdeklarationen"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "felaktig post i %<label_to_block_map%>"
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "felaktig inställning av nummer på landningsplatta"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "ogiltig jämförelsekod i gimple-villkor"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "ogiltig etikett i gimple-villkor"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "ogiltigt %<PHI%>-resultat"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "%<PHI%>-definition saknas"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "ogiltigt %<PHI%>-argument"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "inkompatibla typer i %<PHI%>-argument %u"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "%<verify_gimple%> misslyckades"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "död sats i EH-tabell"
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "platsreferensblock som inte är i blockträd"
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "lokal deklaration från en annan funktion"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) är satt till ett felaktigt grundblock"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "PHI-nod med plats"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "felaktig delning av trädnoder"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "virtuell PHI med argumentplatser"
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (sats) är satt till ett felaktigt grundblock"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "sats markerad för att kasta, men gör inte det"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "sats markerad för att kasta i mitten av block"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple misslyckades"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK har IL associerat med sig"
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK har IL associerat med sig"
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fall igenom till utgång från gb %d"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "ickelokal etikett "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH-landningsplattas etikett "
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "etikett "
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "flödesstyrning mitt i grundblock %d"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "fall igenom-båge efter styrsats i gb %d"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "sant/falskt-båge efter en icke-GIMPLE_COND i gb %d"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "felaktiga utgående bågflaggor vid slutet av gb %d"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "uttrycklig goto vid slutet av gb %d"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "returbåge pekar inte på utgång i gb %d"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "hittade standardfall som inte var vid början av case-vektor"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "case-etiketter är inte sorterade: "
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "extra utgående båge %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "båge saknas %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>-funktion returnerar"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "flödet når slutet på en icke-void-funktion"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet %<warn_unused_result%>"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "ignorerar returvärdet av funktion deklarerad med attributet %<warn_unused_result%>"
@@ -29415,7 +29428,7 @@ msgstr "trådlokal COMMON-data är inte implementerat"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "begärd justering för %q+D är större än implementerad justering av %wu"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "lagringsstorlek på %q+D är okänd"
@@ -29576,7 +29589,7 @@ msgstr "bytekodström: förväntade taggen %s istället för %s"
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "bytekodström: taggen %s ligger inte i det förväntade intervallet [%s, %s]"
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, gcc-internal-format
 msgid "unsupported record layout"
 msgstr "ej stödd postlayout"
@@ -30180,7 +30193,7 @@ msgstr "attributet %qE följer %qE"
 msgid "type was previously declared %qE"
 msgstr "typen var tidigare deklarerad %qE"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> kan endast anges för en virtuell funktion"
@@ -30200,7 +30213,7 @@ msgstr "%qD är inte kompatibel med %qD"
 msgid "%qE argument is not a function"
 msgstr "argumentet %qE är inte en funktion"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "deprecated-meddelande är inte en sträng"
@@ -30625,12 +30638,12 @@ msgstr "%<?:%> använder heltalskonstanter i en boolesk kontext"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "kompilatorn kan anta att adressen till %qD kommer alltid beräknas till %<true%>"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "föreslår parenteser runt tilldelning som används som sanningsvärde"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "ogiltigt användning av %<restrict%>"
@@ -30791,13 +30804,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "attributet %<fallthrough%> angivet med en parameter"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "för få argument till funktionen %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "för många argument till funktionen %qE"
@@ -31731,7 +31744,7 @@ msgstr "ej stödd konkatenering av stränglitteraler som inte följer standard"
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionell C stödjer inte strängkonstantsammanslagning"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> med %<hint%>-klausul kräver ett namn, utom när %<omp_sync_hint_none%> används"
@@ -31781,7 +31794,7 @@ msgstr "%<depobj%>-beroendetyp angiven i %<depend%>-klausul på en %<depobj%>-ko
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "en %<iterator%>-modifierare får inte anges på en %<depobj%>-konstruktion"
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ogiltig typ för iterationsvariabeln %qE"
@@ -31796,17 +31809,17 @@ msgstr "%<_Atomic%>-iterationsvariabel %qE"
 msgid "%qE is not initialized"
 msgstr "%qE är inte initierad"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "styrpredikat saknas"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "ogiltigt styrpredikat"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "utelämnat ökningsuttryck"
@@ -31816,7 +31829,7 @@ msgstr "utelämnat ökningsuttryck"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "ökningen är inte en konstant 1 eller -1 för villkoret %<!=%>"
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ogiltigt ökningsuttryck"
@@ -31881,7 +31894,7 @@ msgstr "felaktig reduktionsmodifierare %<task%> på en konstruktion inte kombine
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr "%<inscan%> %<reduction%>-klausul på en annan konstruktion än %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr "%qD angivet i en %<allocate%>-klausul men inte i en explicit privatiseringsklausul"
@@ -32446,8 +32459,8 @@ msgstr "<returvärde>"
 msgid "wrong type argument to %s"
 msgstr "fel typ på argument till %s"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "spill i konstant uttryck"
@@ -32932,17 +32945,17 @@ msgstr "minskning av funktion %qD"
 msgid "function %qD used as %<asm%> output"
 msgstr "funktionen %qD använd som %<asm%>-utdata"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "tilldelning till endast läsbar plats %qE"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "ökning av endast läsbar plats %qE"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "minskning av endast läsbar plats %qE"
@@ -33122,8 +33135,8 @@ msgstr "%<memset%> använd med konstant parameter med längd noll; detta kan ber
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr "%<memset%> använt med en längd lika med antalet element utan att multiplicera med elementstorleken"
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "jämförelse mellan typer %qT och %qT"
@@ -33199,158 +33212,158 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "att skicka argument %i till en %qs-kvalificerad parameter blir alias med argument %Z"
 msgstr[1] "att skicka argument %i till en %qs-kvalificerad parameter blir alias med argumenten %Z"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "detta villkor har identiska grenar"
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr "makrot expanderar till flera satser"
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr "några delar av makroexpansionen är inte skyddade av denna %qs-klausul"
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr "att konvertera en packad %qT-pekare (justering %d) till en %qT-pekare (justering %d) kan resultera i ett ojusterat pekarvärde"
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, gcc-internal-format
 msgid "defined here"
 msgstr "definierad här"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr "att ta adressen till en packad medlem i %qT kan resultera i ett ojusterat pekarvärde"
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "gränsen %Z av argument %u deklarerad som %s stämmer inte"
 msgstr[1] "gränserna %Z av argument %u deklarerad som %s stämmer inte"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr "tidigare deklarerad som %s"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "argument %u med typen %s deklarerad som en vektor med variabel längd"
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
 msgstr "tidigare deklarerad som en pekare %s"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
 msgstr "tidigare deklarerad som en vanlig vektor %s"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr "argument %u av typen %s deklarerad som en pekartyp"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr "tidigare deklarerad som en vektor %s med variabel längd"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr "tidigare deklarerad som en vektor %s"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr "argument %u av typen %s deklarerat som en vanlig vektor"
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] "argument %u av typen %s deklarerad med %u variabelgräns"
 msgstr[1] "argument %u av typen %s deklarerad med %u variabelgränser"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "tidigare deklarerad som %s med %u variabelgräns"
 msgstr[1] "tidigare deklarerad som %s med %u variabelgränser"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] "argument %u av typen %s deklarerad med %u ospecificerad variabelgräns"
 msgstr[1] "argument %u av typen %s deklarerad med %u ospecificerade variabelgränser"
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] "tidigare deklarerad som %s med %u ospecificerad variabelgräns"
 msgstr[1] "tidigare deklarerad som %s med %u ospecificerade variabelgränser"
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] "därefter deklarerad som %s med %u ospecificerad variabelgräns"
 msgstr[1] "därefter deklarerad som %s med %u ospecificerade variabelgränser"
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr "argument %u av typen %s deklarerat med gränsargument %E som inte stämmer"
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "argument %u av typen %s deklarerat med gräns %<%s%> som inte stämmer"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr "tidigare deklarerad %s med bundet argument %E"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "tidigare deklaration som %s med gränsen %<%s%>"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr "tidigare deklaration som %s med gränsen %qs"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr "argument %u av typen %s med gräns som inte stämmer"
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr "uttrycket beräknar inte antalet element i denna vektor; elementtypen är %qT, inte %qT"
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr "lägg till parenteser runt %qE för att tysta denna varning"
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr "lägg till parenteser runt den andra %<sizeof%> för att tysta denna varning"
@@ -33365,7 +33378,7 @@ msgstr "%qs är inte en giltig flagga till preprocessorn"
 msgid "too many input files"
 msgstr "för många indatafiler"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "okänt värde %qs till %<-mcpu%>"
@@ -33396,14 +33409,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "okänd flagga skickad till %%:target_mode_check"
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "giltiga argument är: %s; menade du %qs?"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "giltiga argument är: %s"
@@ -33553,62 +33566,62 @@ msgstr "argumentet till %<-misr-secure=%d%> är inte mellan 0 och 3"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr "för flaggan %<-mcache-block-size=X%> måste ett giltigt X vara: 4, 8, 16, 32, 64, 128, 256 eller 512"
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr "%<-march=%s%>: Utökningen ”%s” förekommer mer än en gång."
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "%<-march=%s%>: ett tal förväntades efter %<%dp%>."
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "%<-march%s%>: rv%de är inte en giltig bas-ISA"
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr "versionen av ”g” kommer utelämnas, ange en version för individuell utökning."
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr "%<-march=%s%>: första ISA-undergrupp måste vara %<e%>, %<i%> eller %<g%>"
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr "%<-march=%s%>: ISA-delmängd som ej stödjs %<%c%>"
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr "%<-march=%s%>: ISA-strängen är inte i kanonisk ordning. %<%c%>"
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>: namnet på %s måste vara mer än 1 bokstav"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%>: %s måste separeras med _"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "%<-march=%s%>: ISA-strängen måste börja med rv32 eller rv64"
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr "%<-march=%s%>: oväntad ISA-sträng på slutet: %qs"
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<-mcpu=%s%>: okänd CPU"
@@ -33769,89 +33782,90 @@ msgstr "%s står i konflikt med ppc (arch-flaggor ignoreras)"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr "%s står i konflikt med ppc64 (arch-flaggor ignoreras)"
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "det gick inte att öppna temporär fil %s för LTO-utdata"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "%qE 2.95-vtable-kompatibilitetsattribut är bara tillämpligt vid kompilering av en kext"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "%qE 2.95-vtable-kompatibilitetsattribut är bara tillämpligt på C++-klasser"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "synlighetsattributet skyddat stödjs inte för denna konfiguration, ignoreras"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "det gick inte att öppna temporär fil %s med LTO-utdata"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> 2 måste användas för 64-bitars mål med %<-fnext-runtime%>"
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> %d stödjs inte för 32-bitars mål med %<-fnext-runtime%>"
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "%<-gsplit-dwarf%> stödjs inte på denna plattform, ignoreras"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "%<-mdynamic-no-pic%> åsidosätter %<-fpic%>, %<-fPIC%>, %<-fpie%> eller %<-fPIE%>"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr "%<-mpic-symbol-stubs%> krävs inte för 64-bitars kod (ignoreras)"
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "inbyggd funktion %qD behöver flaggan %<-mconstant-cfstrings%>"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "inbyggd funktion %qD tar bara ett argument"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "CFString-litteral saknas"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "CFString-litteraluttryck är inte en strängkonstant"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr "icke-ASCII-tecken i CFString-litteral"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr "inbäddad NUL i CFString-litteral"
 
 #: config/host-darwin.c:65
-#, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+#, fuzzy, gcc-internal-format
+#| msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "det gick inte att avmappa %<pch_address_space%> %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -33987,362 +34001,362 @@ msgstr "%<#pragma GCC aarch64%> kräver en strängparameter"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "okänd %<#pragma GCC aarch64%>-flagga %qs"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "attributet %qE kan inte användas på en SVE-funktionstyp"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "oväntat %<%s%> efter %<%s%>"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs är inkompatibel med användningen av flyttalstyper"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs är inkompatibel med användningen av vektortyper"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "funktionsmodifieraren %qs är inkompatibel med användningen av flyttalstyper"
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "funktionsmodifieraren %qs är inkompatibel med användningen av vektortyper"
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "denna operation kräver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "du kan aktivera SVE genom att använda kommandoradsflaggan %<-march%>, eller genom att använda attributet eller pragmat %<target%>"
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "argument av typen %qT kräver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "SVE-typen %qT kan inte skickas till en funktion utan prototyp"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 9.1"
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "%qE behöver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "anrop till funktioner av typen %qT behöver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "stackprov för SVE-ramar"
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "okänd flagga skickad i %<-moverride=%s%> (%s)"
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "%s-sträng är felformad\n"
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "felaktigt format på sve_width"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "ogiltigt sve_width-värde: %d"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "trimningssträngen saknas i flaggan (%s)"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "okänd trimningsflagga (%s)"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "inkompatibla flaggor %<-mstack-protector-guard=global%> och %<-mstack-protector-guard-offset=%s%>"
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "både %<-mstack-protector-guard-offset%> och %<-mstack-protector-guard-reg%> måste användas med %<-mstack-protector-guard=sysreg%>"
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr "ange ett systemregister med en liten stränglängd."
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs är inte ett giltigt avstånd i %qs"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr "endast värdena 12 (4 kB) och 16 (64 kB) stödjs som vaktstorlek.  Det givna värdet %d (%llu kB) är utanför intervallet"
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr "stackkrockvaktsstorlek %<%d%> måste vara lika med testintervallet %<%d%>"
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "giltiga argument är: %s;"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "cpu-namn saknas i %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "ogiltig funktionsmodifierare %qs i %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "ogiltigt argument givet till %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr "%<%s%> måste vara ensamt till %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "ogiltigt argument %<%s%> till %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "ogiltigt argument %<%s%> till %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "argumentet saknas till %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "arkitekturnamn saknas i %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "okänt värde %qs till %<-march%>"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "ogiltig funktionsmodifierare %qs i %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "cpu-namn saknas i %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "okänt värde %qs till %<-mtune%>"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "flaggan %<-mcpu=%s%> står i konflikt med flaggan %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "assemblern stödjer inte %<-mabi=ilp32%>"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr "signering av returadress stödjs endast för %<-mabi=lp64%>"
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "kodmodell %qs med %<-f%s%>"
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "kodmodellen %qs stödjs inte i ilp32-läge"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "namn saknas i pragmat eller attributet %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "felaktigt namn (”%s”) i pragmat eller attributet %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "felaktig funktionsmodifierare %s på värdet (”%s”) i pragmat eller attributet %<target()%>"
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "namn saknas i pragmat eller attributet %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "felaktigt namn (”%s”) i pragmat eller attributet %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "argument saknas till pragmat eller attributet %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "felaktig skyddstyp (”%s”) i pragmat eller attributet %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "felaktigt namn (”%s”) i pragmat eller attributet %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "värde saknas i pragmat eller attributet %<target()%>"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "felformaterat pragma eller attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "pragmat eller attributet %<target(\"%s\")%> tar inte något argument"
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "pragmat eller attributet %<target(\"%s\")%> tillåter inte en negerad form"
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "pragmat eller attributet %<target(\"%s=%s\")%> är inte giltigt"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "argument till attribut %<target%> är inte en sträng"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "pragmat eller attributet %<target(\"%s\")%> är inte giltigt"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "felformaterat pragma eller attribut %<target(\"%s\")%>"
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "parameterskickandet för argument av typen %qT med %<[[no_unique_address]]%>-medlemmar ändrades %{i GCC 10.1%}"
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "parameterskickandet för argument av typen %qT när C++17 är aktiverat ändrades till att matcha C++14 %{i GCC 10.1%}"
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Kbana %wd utanför intervallet %wd - %wd"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "bana %wd utanför intervallet %wd - %wd"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "ej stödd simdlen %wd"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "GCC stödjer för närvarande inte typer av blandad storlek till %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "GCC stödjer för närvarande inte returtypen %qT för %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "returtypen %qT stödjs ej för %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "GCC stödjer för närvarande inte argumenttypen %qT för %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "GCC stödjer för närvarande inte simdlen %wd för typen %qT"
@@ -34403,7 +34417,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "felaktigt värde %qs till %<-mmemory-latency%>"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -34523,18 +34537,18 @@ msgstr "argumentet till attributet %qE är inte ”ilink1” eller ”ilink2”"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "argumentet till attributet %qE är inte ”ilink” eller ”firq”"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -34964,223 +34978,230 @@ msgstr "målprocessorn stödjer inte THUMB-instruktioner"
 msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessorn stödjer inte ojusterade åtkomster"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "flaggan %<-mcpu=%s%> står i konflikt med flaggan %<-march=%s%>"
+
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "%<-mapcs-stack-check%> är inkompatibel med %<-mno-apcs-frame%>"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "%<-fpic%> och %<-mapcs-reent%> är inkompatibla"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS-återanropsbar kod stödjs inte.  Ignoreras"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr "flaggan %<-mstructure-size-boundary%> bör undvikas"
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "storleksgräns för poster kan bara sättas till 8, 32 eller 64"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "storleksgräns för poster kan bara sättas till 8 eller 32"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC är inkompatibelt med %<-msingle-pic-base%>"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "FDPIC-läget stödjs inte i Thumb-1-läge"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "%<-mpic-register=%> är meningslös utan %<-fpic%>"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "kan inte använda %qs som PIC-register"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> stödjs inte på denna arkitektur"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "valda fp16-alternativ är inkompatibla"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt kräver ett AAPCS-kompatibelt ABI för att fungera riktigt"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt-abi kräver en CPU som klarar iwmmxt"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "målprocessorn stödjer inte interworking"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS stödjer inte %<-mcaller-super-interworking%>"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS stödjer inte %<-mcallee-super-interworking%>"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 och ingen ldrh"
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "målprocessorn stödjer inte ARMv8-M:s säkerhetstillägg"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr "ARMv8-M Security Extensions är inkompatibelt med den valda FPU:n"
 
-#: config/arm/arm.c:3859
-#, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+#: config/arm/arm.c:3864
+#, fuzzy, gcc-internal-format
+#| msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr "%<-mfloat-abi=hard%>: den valda processorn saknar en FPU"
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "%<-mfloat-abi=hard%> och VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "icke-AAPCS-härledd PCS-variant"
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "variadiska funktioner måste använda bas-AAPCS-varianten"
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS-variant"
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 hårda flyttals VFP ABI"
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr "argument av typen %qT är inte tillåtna med -mgeneral-regs-only"
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 7.1"
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr "FP-register kan vara överskrivna trots attributet %qE: kompilera med %<-mgeneral-regs-only%>"
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "attributet %qE är inte tillgängligt för funktioner med argument som skickas på stacken"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "attributet %qE är inte tillgängligt för funktioner med ett variabelt antal argument"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "attributet %qE är inte tillgängligt för funktioner som returnerar ett värde på stacken"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "attributet %qE ignorerat utan flaggan %<-mcmse%>."
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "attributet %qE har ingen effekt på funktioner med statisk länkklass"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "attributet %qE är bara tillämpligt på bastypen av en funktionspekare"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "att nå trådlokal lagring stödjs inte för närvarande med %<-mpure-code%> eller %<-mslow-flash-data%>"
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd utanför intervall %wd - %wd"
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd utanför intervall %wd - %wd"
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan inte beräkna verklig plats för stackparameter"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Oväntat långt thumb1-hopp"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "inga låga register tillgängliga för att poppa höga register"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Avbrottshanteringsrutiner kan inte kodas i Thumb-1-läge"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> för Thumb-1"
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ogiltig fpu för målattributet eller pragmat %qs"
@@ -35188,22 +35209,22 @@ msgstr "ogiltig fpu för målattributet eller pragmat %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatiskt fpu-val är för närvarande inte tillåtet här"
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ogiltig arkitektur för målattribut eller -pragma %qs"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "okänt målattribut eller -pragma %qs"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "asm-flaggor stödjs inte i thumb1-läge"
@@ -35282,17 +35303,17 @@ msgstr "%<-fpie%> stödjs inte"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> stödjs inte"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "funktionsattributen %qs och %qs är ömsesidigt uteslutande"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "funktionen %qs kan inte ha argument"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktionen %qs kan inte returnera ett värde"
@@ -36032,132 +36053,132 @@ msgstr "parameter till inbyggd måste vara en strängkonstant eller -litteral"
 msgid "parameter to builtin not valid: %s"
 msgstr "parameter till inbyggd är inte giltig: %s"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "avbrottshanteringsrutiner kan inte anropas direkt"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "det sista argumentet måste vara en 2-bitars omedelbar"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "det femte argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "det tredje argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "det sista argumentet måste vara en 3-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "det sista argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "det sista argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "det näst sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "det sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "det tredje argumentet måste vara en jämförelsekonstant"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "felaktigt jämförelsesätt"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "felaktig avrundningsoperand"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "väljaren måste vara en heltalskonstant i intervallet [0..%wi]"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE behöver en okänd isa-flagga"
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE behöver isa-flaggan %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "det sista argumentet måste vara en 32-bitars omedelbar"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "sista argumentet måste vara en omedelbar"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "det sista argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "det fjärde argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "felaktig tipsoperand"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "argumentet till den inbyggda %<xabort%> måste vara en 8-bitars omedelbar"
@@ -36177,519 +36198,519 @@ msgstr "multiversionering av virtuell funktion stödjs inte"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "multiversionering behöver %<ifunc%> som inte stödjs på detta mål"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodmodellen %s stödjer inte PIC-läge"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "argument till attribut %qs är inte en sträng"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "argument %2$qs till attribut %1$qs är okänt"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "attributvärdet %qs specificerades redan i attributet %qs"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "attributvärdet %qs är okänt i attributet %qs"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "felaktigt argument %qs till flaggan %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "storleksintervall till flaggan %qs skall vara ökande"
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "felaktigt strateginamn %qs angivet till flaggan %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "strateginamn %qs angivet till flaggan %qs stödjs inte i 32-bitars kod"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "okänd justering %qs angiven till flaggan %qs"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "maxvärdet för det sista storleksintervallet skall vara -1 för flaggan %qs"
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "för många storleksintervall angivna i flaggan %qs"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "okänd parameter till flaggan %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel MCU psABI stödjs inte i %s-läge"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> bör undvikas.  Använd istället det som passar av %<-mtune=k8%> och %<-mtune=generic%>"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> bör undvikas.  Använd istället det som passar av %<target(\"tune=k8\")%> och %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressläget %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> stödjs inte med X32 ABI"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=address%>"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodmodellen %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodmodellen %qs stödjs inte i x32-läge"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> stödjs inte i denna konfiguration"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bitsläge inte inkompilerat"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<generic%> kan användas endast till flaggan %<-mtune=%>"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<generic%> kan användas endast till attributet %<target(\"tune=\")%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<intel%> kan användas endast till flaggan %<-mtune=%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<intel%> kan användas endast till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU:n du valde stödjer inte instruktionsuppsättningen x86-64"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "felaktigt värde (%qs) till flaggan %<-march=%>"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "felaktigt värde (%qs) till attributet %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "felaktigt värde (%qs) till flaggan %<-mtune=%>"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "felaktigt värde (%qs) till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> ignoreras för Intel MCU psABI"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> är inte mellan 0 och %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> stödjs inte för denna målarkitektur"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> är inte mellan %d och %d"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> är inte mellan %d och 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> är inte implementerat för %<-fPIC%>"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> använd utan SSE aktiverat"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> använt utan SSE aktiverat"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "instruktionsuppsättningen SSE avaktiverad, använder 387-aritmetik"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "instruktionsuppsättningen 387 avaktiverad, använder SSE-aritmetik"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stackavkänning kräver %<-maccumulate-outgoing-args%> för att bli korrekt"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stackavkänning kräver %<target(\"accumulate-outgoing-args\")%> för att bli korrekt"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "fasta ebp-register kräver %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "fasta ebp-register kräver %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> stödjs inte för 32 bitar i kombination med %<-fpic%>"
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> är inte kompatibelt med SEH"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> stödjs inte för närvarande med SEH"
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "okänt alternativ till %<-mrecip=%s%>"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs är inte ett giltigt tal i %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs är inte ett giltigt avstånd i %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs är inte ett giltigt basregister i %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attributen interrupt och naked är inte kompatibla"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "endast felsökningsformatet DWARF stödjs för en avbrottshanteringsrutin"
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> och %<-fcf-protection%> är inte kompatibla"
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> och %<-fcf-protection%> är inte kompatibla"
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-instruktioner är inte tillåtna i en undantagshanteringsrutin"
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-instruktioner är inte tillåtna i en avbrottshanteringsrutin"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-instruktioner är inte tillåtna i en funktion med attributet %<no_caller_saved_registers%>"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attributen fastcall och regparm är inte kompatibla"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attributen regparam och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "attributet %qE kräver en heltalskonstant som argument"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument till attributet %qE är större än %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attributen fastcall och cdecl är inte kompatibla"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attributen fastcall och stdcall är inte kompatibla"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attributen fastcall och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attributen stdcall och cdecl är inte kompatibla"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attributen stdcall och fastcall är inte kompatibla"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attributen stdcall och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attributen cdecl och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "attributet %qE används för annat än klassmetod"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibelt attribut ignorerat"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attributet %qE är bara tillgängligt för 32 bitar"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumentet till attributet %qE är varken noll eller ett"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "attributen %qs och %qs är inte kompatibla"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attributet %qE kräver en strängkonstant som argument"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumentet till attributet %qE är inte (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "avbrottshanteringsrutiner skall ha en pekare som första argument"
 
 # "unsigned %sint" är tänkt att expanderas till C-syntax
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "avbrottshanteringsrutiner skall ha %qs som andra argument"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "avbrottshanteringrutiner kan endast ha ett pekarargument och ett valfritt heltalsargument"
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "avbrottshanteringsrutiner måste returnera %<void%>"
@@ -37143,7 +37164,7 @@ msgstr "%qE får inte ha båda attributet %qs och %qs"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE omdeklarerad med motstridiga %qs-attribut"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "attributet %qE behöver ett strängargument"
@@ -38203,57 +38224,57 @@ msgstr "%<__delay_cycles%> är begränsad till 32-bitars slingräknare"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "okänt cpu %qs till %<-mtune%>"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI:et för en tillplattad post med nollängds bitfält ändrades i GCC 10"
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "argumentet till attributet %qE är inte ”user”, ”supervisor” eller ”machine”"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> kräver %<-march%> för att innefatta utökningen %<M%>"
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "begärt ABI kräver %<-march%> för att innefatta utökningen %qc"
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e kräver ABI:et ilp32e"
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI:et kräver %<-march=rv%d%>"
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> måste vara mellan %d och %d"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "%<-mriscv-attribute%> RISC-V ELF-attribut behöver GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs är inte ett giltigt basregister i %qs"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs är inte ett giltigt tal i %qs"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "funktionen %qs kan inte ha olika avbrottstyp"
@@ -38756,240 +38777,242 @@ msgstr "%qs använder register r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Stackramar större än 2 G stödjs inte med %<-fsplit-stack%>"
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs kräver %qs eller %qs"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs kräver PowerPC64-arkitektur, aktiverar"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "%<-mcall-aixdesc%> är inkompatibel med %<-mabi=elfv2%>"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "%<-m64%> kräver en PowerPC64-CPU"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=96248
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "%<-mcmodel%> är inkompatibel med andra toc-flaggor"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "%qs stödjs inte för detta ABI"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "%qs stödjs inte för 64-bitars Darwin, det är inkompatibelt med de installerade C- och C++-biblioteken"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec stödjs inte på denna målarkitektur"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "%qs stödjs inte på system med omvänd byteordning"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "målflaggan för power9 är inkompatibel med %<%s=<xxx>%> för <xxx> som är mindre än power9"
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs är inkompatibel med uttryckligen avaktiverade flaggor"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs behöver %qs"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "målattribut eller pragma ändrar storlek på %<long double%>"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%qs behöver fullt ISA 2.06-stöd"
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Använder %<long double%> med IEEE:s utökade precision"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Använder %<long double%> med IBM:s utökade precision"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs behöver VSX-stöd"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr "Flaggan %<-mfloat128%> kanske inte stödjs fullt ut"
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs behöver fullt ISA 3.0-stöd"
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "okänd ABI-typ (%qs) till vektoriseringsbibliotek för flaggan %qs"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "målattribut eller pragma ändrar AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "målattribut eller pragma ändrar darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs behöver ett giltigt basregister"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "okänt alternativ till %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs bör undvikas och rekommenderas inte under några omständigheter"
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "layouten av aggregat som innehåller vektorer med %d-bytejustering har ändrats i GCC 5"
 
-#: config/rs6000/rs6000.c:10582
-#, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+#: config/rs6000/rs6000.c:10675
+#, fuzzy, gcc-internal-format
+#| msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs är en ogenomskinlig typ, och det går inte att sätta den till andra värden."
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering av 64-bitskod för detta ABI"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "du kan inte ta adressen till en nästad funktion om du använder flaggan %qs"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "användning av %<long double%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "användning av booleaner i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "användning av %<complex%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "användning av decimala flyttalstyper i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan %qs"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "användning av %<long%> i AltiVec-typer bör undvikas, använd %<int%>"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<long long%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<double%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "felaktig cpu %qs för %s%qs%s"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s är inte tillåtet"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s är ogiltigt"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> slår av %<-m%s%>"
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "attributet %<target_clones%> behöver GLIBC (2.23 och nyare) som exporterar bitar om hårdvaruegenskaper"
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "multiversionering behöver ifunc som inte stödjs på detta mål"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionering av virtuell funktion stödjs inte"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "resultatet av instruktionen xxspltidp är odefinierat för undernormala indatavärden"
@@ -39168,7 +39191,7 @@ msgstr "RX FPU-instruktioner stödjer inte NaN:er och oändligheter"
 msgid "builtin vec_step can only be used on vector types."
 msgstr "inbyggd vec_step kan endast användas på vektortyper."
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "konstant värde behövs till den inbyggda %qF argument %d"
@@ -39238,200 +39261,206 @@ msgstr "%qs-matchningsvariant bör undvikas."
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "det konstanta argumentet %d till den inbyggda %qF är utanför intervallet för måltypen"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "det konstanta argumentet %d till den inbyggda %qF ligger utanför intervallet (0..%wu)"
+
+#: config/s390/s390.c:766
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "det konstanta argumentet %d till den inbyggda %qF ligger utanför intervallet (0..%wu)"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "det konstanta argumentet %d till den inbyggda %qF ligger utanför intervallet (%wd..%wd)"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr "inbyggd %qF stödjs inte utan %<-mhtm%> (standard med %<-march=zEC12%> och högre)."
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr "inbyggd %qF behöver %<-mvx%> (standard med %<-march=z13%> och högre)."
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr "Inbyggd %qF kräver z14 eller högre."
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr "Inbyggd %qF kräver z15 eller högre."
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr "Inbyggd %qF kräver arch14 eller högre."
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "ej upplöst överlagrad inbyggd"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "felaktig inbyggd icode"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "ogiltigt argument %d till den inbyggda %qF"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "begärt attribut %qE är inte ett kommaseparerat par av ickenegativa heltalskonstanter eller för stort (max. %d)"
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "argumentet till attributet %qE är inte (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "totala storleken på lokala variabler överskrider arkitekturens gräns"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket överskrider användarens valda stackgräns på %d byte.  En ovillkorlig fälla läggs till."
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket är mer än hälften av stackstorleken.  Den dynamiska kontrollen skulle inte vara pålitlig.  Ingen kontroll läggs ut för denna funktion."
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "ramstorlek på %qs är %wd byte"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs använder dynamisk stackallokering"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "nästade funktioner kan inte profileras med %<-mfentry%> på s390"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bits ABI stödjs inte i ESA/390-läge"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline stödjs endast med %<-mindirect-branch-jump%>"
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "vektorstöd i hårdvara är inte tillgängliga på %s"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "stöd för hårdvaruvektorer är inte tillgängligt med %<-msoft-float%>"
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "hårdvaruinstruktioner för decimala flyttal är inte tillgängliga på %s"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "hårdvaruinstruktioner för decimalflyttal är inte tillgängliga i läget ESA/390"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> kan inte användas tillsammans med %<-msoft-float%>"
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> stödjs inte i kombination"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "stackstorlek måste vara större än stackvaktsvärdet"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "stackstorlek får inte vara större än 64 k"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> implicerar användning av %<-mstack-size%>"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-prologue-check behöver ett heltal i intervallet 0..4095"
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-prologue-target behöver ett heltal i intervallet 0..4095"
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-epilogue-check behöver ett heltal i intervallet 0..4095"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-epilogue-target behöver ett heltal i intervallet 0..4095"
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> stödjs endast för 64-bitars CPU:er"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumenten till %qs skall vara ickenegativa heltal"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argumentet till %qs är för stort (max. %d)"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> kan inte användas utan %<-fpic%>/%<-fPIC%>"
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) är okänt"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "värdet %qs stödjs inte av attributet %<target%>"
@@ -39777,17 +39806,23 @@ msgstr "%<-fexcess-precision=standard%> för Ada"
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr "STABS-felsökningsinformation för Ada är föråldrat och stödjs inte längre"
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "STOP code at %C contains too many digits"
+msgid "%s contains too many lines"
+msgstr "STOP-kod vid %C innehåller för många siffror"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr "underprogrammet %q+F är inte markerat %<Inline_Always%>"
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "föräldraunderprogrammet kan inte inline:as"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr "underprogrammet %q+F är inte markerat %<Inline%>"
@@ -39853,8 +39888,8 @@ msgstr "attributet %qs är bara tillämpbart på vektortyper"
 msgid "could not read the BRIG file"
 msgstr "det gick inte att läsa BRIG-filen"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "värdet av typen void ignoreras inte vilket bör göras"
@@ -39914,7 +39949,7 @@ msgstr "variabeln %qD sätts men används inte"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "den kompletterade typen på vektor %q+D är inkompatibel med implicit initiering"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "ursprungligen definierad här"
@@ -40136,7 +40171,7 @@ msgstr "deklaration av %q+D skuggar tidigare icke-variabel"
 msgid "declaration of %qD shadows a parameter"
 msgstr "deklaration av %qD skuggar en parameter"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklaration av %qD skuggar en global deklaration"
@@ -40147,7 +40182,7 @@ msgstr "deklaration av %qD skuggar en global deklaration"
 msgid "declaration of %qD shadows a previous local"
 msgstr "deklaration av %qD skuggar en tidigare lokal deklaration"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "skuggad deklaration är här"
@@ -40157,212 +40192,212 @@ msgstr "skuggad deklaration är här"
 msgid "nested extern declaration of %qD"
 msgstr "nästad extern-deklaration av %qD"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "implicit deklaration av funktionen %qE; menade du %qs?"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "implicit deklaration av funktionen %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr "inkludera %qs eller ge en deklaration av %qE"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "inkompatibel implicit deklaration av inbyggd funktion %qD"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "inkludera %qs eller ge en deklaration av %qD"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "inkompatibel implicit deklaration av funktionen %qD"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE är odeklarerad här (inte i en funktion); menade du %qs?"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE är odeklarerad här (inte i en funktion)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE är odeklarerad (första förekomsten i denna funktion); menade du %qs?"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE är odeklarerad (första förekomsten i denna funktion)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "varje odeklarerad identifierare rapporteras bara en gång för varje funktion den förekommer i"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "etikett %qE är refererad till utanför någon funktion"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "hopp in i räckvidd för identifierare med variabel typ"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "hoppar över variabelinitiering"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "etikett %qD är definierad här"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "hopp in i satsuttryck"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "dubbel deklaration av etikett %qE"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "dubblerad etikett %qD"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "traditionell C saknar en separat namnrymd för etiketter, identifierare %qE står i konflikt"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "switch hoppar över variabelinitieringar"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch börjar här"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "switch hoppar in i satsuttryck"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE definierad som fel sorts tagg"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attributet %qE tillämpat på %qD med returtypen void"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "attributet %qE kan bara användas på funktioner eller på struktur-, union- eller uppräkningstyper"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "odöpt struktur/union som inte har någon instans"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "tom deklaration med specificerare av lagringsklass deklarerar inte om tagg"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "tom deklaration med typkvalificerare deklarerar inte om en tagg"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "tom deklaration med %<_Alignas%> deklarerar inte om en tagg"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "oanvändbart typnamn i tom deklaration"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> i tom deklaration"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> i tom deklaration"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "%<auto%> tom deklaration på filnivå"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "%<register%> i tom deklaration på filnivå"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "oanvändbar specificerare av lagringsklass i tom deklaration"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "oanvändbar %qs i tom deklaration"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "oanvändbar typkvalificerare i tom deklaration"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "oanvändbar %<_Alignas%> i tom deklaration"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr "felaktig användning av attribut i en tom deklaration"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "tom deklaration"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 stödjer inte %<static%> eller typkvalificerare i parametervektordeklarerare"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 stödjer inte %<[*]%>-vektordeklarerare"
@@ -40370,28 +40405,28 @@ msgstr "ISO C90 stödjer inte %<[*]%>-vektordeklarerare"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> är inte tillåtet annat än inom en funktionsprototyp"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D är vanligtvis en funktion"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD är initierad (använd %<__typeof__%> istället)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "funktionen %qD är initierad som en variabel"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "parametern %qD är initierad"
@@ -40400,267 +40435,267 @@ msgstr "parametern %qD är initierad"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "objekt med variabel storlek kan inte initieras"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "variabeln %qD har initierare men ofullständig typ"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr "inline-funktionen %q+D har fått attributet %qs"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "oinitierad const-medlem i %qT är ogiltigt i C++"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD borde initieras"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "initierare misslyckas med att bestämma storleken på %q+D"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "vektorstorlek saknas i %q+D"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "noll eller negativ storlek på vektorn %q+D"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "lagringsstorlek på %q+D är inte konstant"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "ignorerar %<asm%>-specificerare för ickestatisk lokal variabel %q+D"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "kan inte lägga objekt med volatile-fält i register"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, gcc-internal-format
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "oinitierad %<const %D%> är ogiltig i C++"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D i deklarationsmålsdirektiv har inte en avbildbar typ"
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C förbjuder framåtdeklaration av parametrar"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "att definiera en typ i en sammansatt litteral är ogiltigt i C++"
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "bredden på bitfältet %qs är inte en heltalskonstant"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bredden på bitfältet %qs är inte ett konstant heltalsuttryck"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "negativ storlek i bitfält %qs"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "storlek noll på bitfält %qs"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bitfältet %qs har ogiltig typ"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "det går inte att deklarera bitfältet %qs med typen %<warn_if_not_aligned%>"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "typen på bitfältet %qs är en GCC-utvidgning"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "bredden på %qs är större än sin typ"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs är smalare än värdena av sin typ"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 förbjuder vektor %qE vars storlek inte kan beräknas"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 förbjuder vektorer vars storlek inte kan beräknas"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 förbjuder vektor %qE med variabel längd"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 förbjuder vektorer med variabel längd"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "variabelt ändrad %qE i filräckvidd"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "variabelt ändrat fält i filräckvidd"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "typen sätts skönsmässigt till %<int%> i deklarationen av %qE"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "typen sätts skönsmässigt till %<int%> i typnamnet"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "dubblerat %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "dubblerad %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "dubblerad %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "dubblerad %<_Atomic%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "motstridande namngivna adressrymder (%s respektive %s)"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "%<_Atomic%>-kvalificerad vektortyp"
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "funktionsdefinition deklarerad som %<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "funktionsdefinition deklarerad som %<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "funktionsdefinition deklarerad som %<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "funktionsdefinition deklarerad som %qs"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "lagringsklass angiven för postfält %qE"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "lagringsklass angiven för postfält"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "lagringsklass angiven för parameter %qE"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklass angiven för namnlös parameter"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklass angiven för typnamn"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE initierad och deklarerad %<extern%>"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE har både %<extern%> och initierare"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "filnivådeklaration av %qE anger %<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "filnivådeklaration av %qE anger %<register%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "nästad funktion %qE är deklarerad %<extern%>"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "%qE i funktions definitionsområde är implicit auto och deklarerad %qs"
@@ -40668,711 +40703,711 @@ msgstr "%qE i funktions definitionsområde är implicit auto och deklarerad %qs"
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static- eller typkvalificerare i vektordeklarerare som inte är parameter"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "deklaration av %qE som en vektor av void"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "deklaration av typnamn som en vektor av void"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "deklaration av %qE som en vektor av funktioner"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "deklaration av typnamn som en vektor av funktioner"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ogiltig användning av post med flexibel vektormedlem"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "storlek på vektorn %qE är inte av heltalstyp"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "storlek på en namnlös vektor är inte av heltalstyp"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "storlek på vektorn %qE har ofullständig typ"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "storlek på en namnlös vektor har ofullständig typ"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C förbjuder vektor %qE med storlek noll"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C förbjuder vektorer med storlek noll"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "storleken på vektorn %qE är negativ"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "storleken på en namnlös vektor är negativ"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "storleken på vektorn %qE är för stor"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "storleken på en namnlös vektor är för stor"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 stödjer inte flexibla vektormedlemmar"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> är inte i en deklaration"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "vektortyp har ofullständig elementtyp %qT"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av %qE som flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE är deklarerad som en funktion som returnerar en funktion"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "typnamn är deklarerat som en funktion som returnerar en funktion"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE är deklarerad som en funktion som returnerar en vektor"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "typnamn är deklarerat som en funktion som returnerar en vektor"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "funktionsdefinition som har kvalificerad void-returtyp"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typkvalificerare ignoreras för funktions returtyp"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "%<_Atomic%>-kvalificerad funktionstyp"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C förbjuder kvalificerade funktionstyper"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs kombinerad med %<auto%>-kvalificerare för %qE"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs kombinerat med %<register%>-kvalificerare för %qE"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs angiven för auto-variabel %qE"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs angiven för parameter %qE"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs angiven för namnlös parameter"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs angiven för postfält %qE"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs angiven för postfält"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "bitfältet %qE har atomär typ"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "bitfältet har atomär typ"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "minnesjustering angiven för typedef %qE"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "minnesjustering angiven för %<register%>-objekt %qE"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "minnesjustering angiven för parameter %qE"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "minnesjustering angiven för namnlös parameter"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "minnesjustering angiven för bitfältet %qE"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "minnesjustering angiven för namnlöst bitfält"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "minnesjustering angiven för funktionen %qE"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<_Alignas%>-specificerare kan inte reducera justeringen hos %qE"
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<_Alignas%>-specificerare kan inte reducera justeringen för namnlösa fält"
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typdef %q+D deklarerad %<inline%>"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C förbjuder const- eller volatile-funktionstyper"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "en medlem av an post eller union får inte ha variabel typ"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel eller fält %qE deklarerad void"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "attribut i parametervektordeklarerare ignoreras"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parametern %q+D deklarerad %<inline%>"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parametern %q+D deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "fältet %qE deklarerat som en funktion"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "fält %qE har ofullständig typ"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "namnlöst fält har ofullständig typ"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "ogiltig lagringsklass för funktionen %qE"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "kan inte inline:a funktionen %<main%>"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 stödjer inte %<_Noreturn%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 stödjer inte %<_Noreturn%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variabel tidigare deklarerad %<static%> omdeklarerad som %<extern%>"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variabeln %q+D deklarerad %<inline%>"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variabeln %q+D deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "onästad funktion med variabelt modifierad typ"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "objekt med variabel typ får inte ha länkklass"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "funktionsdeklarationen är inte en prototyp"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parameternamn (utan typer) i funktionsdeklaration"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parameter %u (%q+D) har ofullständig typ"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "parameter %u har ofullständig typ"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parameter %u (%q+D) har void-typ"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "parameter %u har void-typ"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> som enda parameter kan inte kvalificeras"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> måste vara den enda parametern"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parameter %q+D har endast en framåtdeklaration"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "%<%s %E%> deklarerad inuti parameterlista kommer inte vara synlig utanför denna definition eller deklaration"
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "anonym %s deklarerad inuti parameterlista kommer inte vara synlig utanför denna definition eller deklaration"
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "enum-typ definierad här"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "post definierad här"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "union definierad här"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "omdefinition av %<union %E%>"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "omdefinition av %<struct %E%>"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "nästad omdefinition av %<union %E%>"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "nästad omdefinition av %<struct %E%>"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "att definiera en typ i %qs-uttryck är ogiltigt i C++"
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "deklaration som inte deklarerar något"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 stödjer inte namnlösa strukturer/unioner"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 stödjer inte namnlösa strukturer/unioner"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "dubblerad medlem %q+D"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr "tom post har storlek 0 i C, storlek 1 i C++"
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "tom union har storlek 0 i C, storlek 1 i C++"
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "unionen har inga namngivna medlemmar"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "unionen har inga medlemmar"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "posten har inga namngivna medlemmar"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "posten har inga medlemmar"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibel vektormedlem i union"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexibel vektormedlem inte vid slutet av post"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "flexibel vektormedlem i struct utan namngivna medlemmar"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "typen %qT är för stor"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "unionen kan inte göras transparent"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "nästad omdefinition av %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "omdeklaration av %<enum %E%>"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "angiven sort för liten för uppräkningsvärden"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "uppräkningsvärden överskrider gränsen för största heltal"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "uppräkningsvärde för %qE är inte en heltalskonstant"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "uppräkningsvärde för %qE är inte ett konstant heltalsuttryck"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "överspill i uppräkningsvärden"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begränsar uppräkningsvärden till intervallet hos %<int%>"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "inline-funktionen %qD har fått attributet %qs"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "returtypen är en ofullständig typ"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "returtyp sätts skönsmässigt till %<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D deklarerat som en variadisk funktion utan prototyp"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "ingen tidigare prototyp för %qD"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD användes utan någon prototyp före sin definition"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidigare deklaration av %qD"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD användes utan någon deklaration före sin definition"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "returtypen för %qD är inte %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%>-kvalificerad returtyp till för %qD"
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD är normalt en icke-statisk funktion"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "gammaldags parameterdeklarationer i funktionsdefinition med prototyp"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionell C tillåter inte ISO C:s stil av funktionsdefinitioner"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "ISO C stödjer inte att utelämna parameternamn i funktionsdefinitioner före C2X"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "gammaldags funktionsdefinition"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parameternamn saknas i parameterlista"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD deklarerad som en icke-parameter"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "flera parametrar med namnet %qD"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "parameter %qD deklarerad med typen void"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "typen på %qD sätts skönsmässigt till %<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "parametern %qD har ofullständig typ"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "deklaration av parameter %qD med det finns ingen sådan parameter"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "antalet argument stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "antalet argument stämmer inte med prototypen"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "prototypdeklaration"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "befordrat argument %qD stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "befordrat argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argument %qD stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen retursats i funktion som returnerar icke-void"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametern %qD sätts men används inte"
@@ -41380,257 +41415,257 @@ msgstr "parametern %qD sätts men används inte"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-slinga med startdeklaration är endast tillåtet i C99- och C11-läge"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "använd flaggan %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> eller %<-std=gnu11%> för att kompilera din kod"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 stödjer inte %<for%>-slingor med initiala deklarationer"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av statisk variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av %<extern%>-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av icke-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "inkompatibla adressrymdskvalificerare %qs och %qs"
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "dubblerade %qE-deklarationsspecificerare"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "två eller fler datatyper i deklaration av specificerare"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> är för långt för GCC"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 stödjer inte %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 stödjer inte komplexa typer"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C stödjer inte mättning av typer"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "dubblerad %qE"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C stödjer inte typen %<__int%d%>"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 stödjer inte booleska typer"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C stödjer inte typen %<_Float%d%s%>"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C stödjer inte decimala flyttal före C2X"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "fixdecimaltyper stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C stödjer inte fixdecimaltyper"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++-uppslagning av %qD skulle returnera ett fält, inte en typ"
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE är varken en typedef eller en inbyggd typ"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE är inte i början av deklarationen"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE använd med %<auto%>"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE använd med %<register%>"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE använd med %<typedef%>"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 stödjer inte %qE"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 stödjer inte %qE"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> före %<extern%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> före %<static%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "dubblerat %<_Thread_local%> eller %<__thread%>"
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flera lagringsklasser i deklarationsspecificerare"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs använd med %qE"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> används utan %<_Fract%> eller %<_Accum%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%> följt av %<[[]]%>-attribut"
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C stödjer inte komplexa heltalstyper"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-kombinerare refererar variabeln %qD som inte är varken %<omp_out%> eller %<omp_in%>"
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-initierare refererar till variabeln %qD som inte är varken %<omp_priv%> eller %<omp_orig%>"
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "vänsterskift med negativt värde"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vänstershiftoperanden är negativ"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "högershiftoperanden är negativ"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vänstershiftoperanden ≥ storleken på typen"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "högershiftoperanden ≥ storleken på typen"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "vänstershiftoperanden ≥ storleken på vektorelementet"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "högershiftoperanden ≥ storleken på vektorelementet"
@@ -41650,7 +41685,7 @@ msgstr "markör för versionshanteringskonflikt i filen"
 msgid "to match this %qs"
 msgstr "för att matcha denna %qs"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "oväntat radslut"
@@ -41660,7 +41695,7 @@ msgstr "oväntat radslut"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C förbjuder tomma översättningsenheter"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> utan en motsvarande %<#pragma omp end declare target%>"
@@ -41696,7 +41731,7 @@ msgid "unknown type name %qE"
 msgstr "okänt typnamn %qE"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "deklarationsspecificerare förväntades"
@@ -41716,7 +41751,7 @@ msgstr "attributet %<fallthrough%> på toppnivå"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identifierare eller %<(%> förväntades"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "prefixattribut ignoreras för metoder"
@@ -41731,7 +41766,7 @@ msgstr "prefixattribut ignoreras för implementeringar"
 msgid "unexpected attribute"
 msgstr "oväntat attribut"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "attributet %<fallthrough%> följs inte av %<;%>"
@@ -41769,7 +41804,7 @@ msgstr "%<__auto_type%> behöver en initierad datadeklaration"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kan endast användas med en ensam deklarerare"
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> eller %<;%> förväntades"
@@ -41827,7 +41862,7 @@ msgstr "uttryck i statisk försäkran är inte konstant"
 msgid "static assertion failed: %E"
 msgstr "statisk försäkran misslyckades: %E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statisk försäkran misslyckades"
@@ -41872,14 +41907,14 @@ msgstr "tom enum är ogiltig"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identifierare förväntades"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutet av uppräkningslista"
@@ -41964,7 +41999,7 @@ msgstr "deklarationsspecificerare eller %<...%> förväntades"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "parenteser måste utelämnas om attributargumentlistan är tom"
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "attributet %qE tar inga argument"
@@ -42024,7 +42059,7 @@ msgstr "ISO C90 förbjuder blandade deklarationer och kod"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> förväntades före %<else%>"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> utan ett föregående %<if%>"
@@ -42039,7 +42074,7 @@ msgstr "etikett vid slutet av sammansatt sats"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "sats förväntades"
@@ -42064,17 +42099,17 @@ msgstr "identifierare eller %<*%> förväntades"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "bara attributet %<fallthrough%> kan användas på en tom sats"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<if%>-sats"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<else%>-sats"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "föreslår uttryckliga klamrar för att undvika tvetydighet i %<else%>"
@@ -42094,12 +42129,12 @@ msgstr "flera iterationsvariabler i snabb uppräkning"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ogiltigt iterationsvariabel i snabb uppräkning"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "slingvillkor saknas i slinga med %<GCC ivdep%>-pragma"
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "slingvillkor saknas i slinga med %<GCC unroll%>-pragma"
@@ -42114,8 +42149,8 @@ msgstr "saknad samling i snabb uppräkning"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "upprepade %<asm%>-kvalificerare %qE"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr "först sedd här"
@@ -42142,12 +42177,12 @@ msgstr "ISO C förbjuder utelämnande av den mittersta termen i ett %<?:%>-uttry
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "divisionen %<sizeof (%T) / sizeof (%T)%> beräknar inte antalet vektorelement"
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "första %<sizeof%>-operanden deklarerades här"
@@ -42538,12 +42573,12 @@ msgstr "objective-c-metoddeklaration förväntas"
 msgid "no type or storage class may be specified here,"
 msgstr "ingen typ eller lagringsklass kan anges här,"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "tom egenskapsattributslista"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, gcc-internal-format
 msgid "missing property attribute"
 msgstr "saknat egenskapsattribut"
@@ -42553,51 +42588,51 @@ msgstr "saknat egenskapsattribut"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "okänt egenskapsattribut %<%s%s%>"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "okänt egenskapsattribut"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "%<=%> förväntades efter Objective-C %qE"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "%qE-väljarnamn förväntades"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "setter-metodnamn måste avslutas med %<:%>"
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> kräver ett tilldelningsuttryck som beräknas till en icke-negativ heltalskonstant mindre än %u"
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> måste ha filräckvidd"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> får bara användas i en slingkonstruktion med %<inscan%> %<reduction%>-klausul"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-konstruktion"
@@ -42607,18 +42642,18 @@ msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-k
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp requires%> får bara användas med filräckvidd"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- eller do-sats förväntades"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> måste komma först"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "för många %qs-klausuler"
@@ -42638,53 +42673,53 @@ msgstr "%<)%> eller %<,%> förväntades"
 msgid "%qD is not a variable"
 msgstr "%qD är inte en variabel"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD är inte en pekarvariabel"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> eller %<present%> förväntades"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> eller %<shared%> förväntades"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> eller %<exit%> förväntades"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> förväntades"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "för många %<if%>-klausuler med %qs-modifierare"
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "för många %<if%>-klausuler"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "för många %<if%>-klausuler utan modifierare"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "om någon %<if%>-klausul har en modifierare måste alla %<if%>-klausuler använda modifierare"
@@ -42706,107 +42741,107 @@ msgstr "%<num_threads%>-värdet måste vara positivt"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%>-värdet måste vara positivt"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%>-värdet måste vara positivt"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%>-värdet måste vara positivt"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "konstant heltalsuttryck med giltigt sync-hint-värde förväntades"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> eller %<default%> förväntades"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<scalar%>, %<aggregate%> eller %<pointer%> förväntades"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "för många %<defaultmap%>-klausuler med %qs-modifierare"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "för många %<defaultmap%>-klausuler med ospecificerad kategori"
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-uttrycket måste vara ett heltal"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs-värdet måste vara positivt"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "för många %<static%>-argument"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "oväntat argument"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumentet till %<tile%> behöver en positiv heltalskonstant"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<concurrent%> förväntades"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<teams%>, %<parallel%> eller %<thread%> förväntades"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "ordered-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> eller identifierare förväntades"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "både %<monotonic%>- och %<nonmonotonic%>-modifierare angivna"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "%<runtime%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "%<auto%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "värdet på styckesstorleken måste vara positivt"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ogiltig schedule-sort"
@@ -42816,17 +42851,17 @@ msgstr "ogiltig schedule-sort"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%>-värdet måste vara positivt"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%>-värdet måste vara positivt"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%<aligned%>-klausulens justeringsuttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "%<allocate%>-klausulens allokeraruttryck har typen %qT istället för %<omp_allocator_handle_t%>"
@@ -42846,22 +42881,22 @@ msgstr "%<safelen%>-klausulens uttryck måste vara ett positivt konstant heltals
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%>-klausulens uttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "modifieraren %<iterator%> är inkompatibel med %qs"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ogiltig depend-sort"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ogiltig map-sort"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ogiltig dist_schedule-sort"
@@ -42876,82 +42911,82 @@ msgstr "ogiltig proc_bind-sort"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<host%>, %<nohost%> eller %<any%> förväntades"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr "%<detach%>-klausulens händelsehandtag har typen %qT istället för %<omp_event_handle_t%>"
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma acc%>-klausul förväntades"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs är inte giltigt för %qs"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "klausuler i %<simd%>-egenskap skall separeras av %<,%>"
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs måste vara den första klausulen i %qs"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%>-klausul förväntades"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "inga giltiga klausuler angivna i %<#pragma acc declare%>"
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "vektorsektionen i %<#pragma acc declare%>"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD måste vara en global variabel i %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ogiltig OpenACC-klausul vid filräckvidd"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<extern%>-variabel %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<global%>-variabeln %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD måste vara en variabel deklarerad i samma räckvidd som %<#pragma acc declare%>"
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variabeln %qD använd mer än en gång med %<#pragma acc declare%>"
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> förväntades efter %<#pragma acc %s%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> har ingen dataflyttningsklausul"
@@ -42966,7 +43001,7 @@ msgstr "%qE har inte deklarerats"
 msgid "expected function name"
 msgstr "ett funktionsnamn förväntades"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD refererar inte till en funktion"
@@ -42976,27 +43011,27 @@ msgstr "%qD refererar inte till en funktion"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före användning"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före definitionen"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> måste innehålla åtminstone en %<device%>- eller %<host%>- eller %<self%>-klausul"
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, gcc-internal-format
 msgid "expected %<allocator%>"
 msgstr "%<allocator%> förväntades"
@@ -43006,82 +43041,82 @@ msgstr "%<allocator%> förväntades"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "%<allocator%>-klausulens allokeraruttryck har typen %qT istället för %<omp_allocator_handle_t%>"
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "%<#pragma omp allocate%> stödjs inte ännu"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "%<read%>-, %<write%>-, %<update%>- eller %<capture%>-klausul förväntades"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "%<read%>-, %<write%>-, %<update%>-, %<capture%>-, %<seq_cst%>-, %<acq_rel%>-, %<release%>-, %<relaxed%>- eller %<hint%>-klausul förväntades"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "för många atomära klausuler"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "för många minnesordningsklausuler"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp atomic read%> är inkompatibel med en %<acq_rel%>- eller %<release%>-klausul"
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic write%> är inkompatibel med en %<acq_rel%>- eller %<acquire%>-klausul"
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic update%> är inkompatibel med en %<acq_rel%>- eller %<acquire%>-klausul"
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ogiltig form på %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ogiltig operator för %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika uttryck till minne"
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "uttrycket %<depobj%> är inte ett l-värde-uttryck"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<in%>, %<out%>, %<inout%> eller %<mutexinoutset%> förväntades"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<depend%>-, %<destroy%>- eller %<update%>-klausul förväntades"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<acq_rel%>, %<release%> eller %<acquire%> förväntades"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<flush%>-lista specificerat tillsammans med minnesordningsklausul"
@@ -43091,32 +43126,32 @@ msgstr "%<flush%>-lista specificerat tillsammans med minnesordningsklausul"
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> eller filslut förväntades"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "en %<inclusive%>- eller %<exclusive%>-klausul förväntades"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp scan%> förväntades"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-klausulparameter är mindre än %<collapse%>"
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "en %<linear%>-klausul får inte anges tillsammans med en %<ordered%>-klausul med en parameter"
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for-sats förväntades"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "iterationsdeklaration eller initiering förväntades"
@@ -43126,72 +43161,72 @@ msgstr "iterationsdeklaration eller initiering förväntades"
 msgid "not enough perfectly nested loops"
 msgstr "inte tillräckligt med perfekt nästade slingor"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "kollapsade slingor inte perfekt nästade"
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterationsvariabel %qD får inte vara firstprivate"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "en %<ordered%>-klausul med parameter får inte anges på en %qs-konstruktion"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> med %<depend%>-klausul får bara användas i sammansatta satser"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> förväntades efter %qs"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> förväntades"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> måste innehålla åtminstone en %<map%>-, %<use_device_ptr%>- eller %<use_device_addr%>-klausul"
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> måste innehålla åtminstone en %<from%>- eller %<to%>-klausul"
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> med en annan map-typ än %<to%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> med en annan map-typ än %<from%>-, %<release%>- eller %<delete%> på %<map%>-klausul"
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
@@ -43206,57 +43241,57 @@ msgstr "%<#pragma omp declare %s%> måste följas av funktionsdeklaration eller
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> måste följas av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "trait-väljarnamn förväntades"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "selektorn %qs är inte tillåten för kontextselektormängd %qs"
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "väljaren %qs tar inte några egenskaper"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "värdesargument måste vara ett konstant heltalsuttryck"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "värdesargumentet måste vara ickenegativt"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "egenskaper måste vara ett konstant heltalsuttryck eller en strängkonstant"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "identifierare eller strängkonstant förväntades"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "egenskapen måste vara ett konstant heltalsuttryck"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "egenskaper för %<simd%>-väljare får inte anges i %<metadirective%>"
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<construct%>, %<device%>, %<implementation%> eller %<user%> förväntades"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<match%> förväntades"
@@ -43266,12 +43301,12 @@ msgstr "%<match%> förväntades"
 msgid "variant %qD is not a function"
 msgstr "varianten %qD är inte en funktion"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "varianten %qD och basen %qD har inkompatibla typer"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "varianten %qD är en inbyggd"
@@ -43281,32 +43316,32 @@ msgstr "varianten %qD är en inbyggd"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare %s%> som inte omedelbart följs av en funktionsdefinition eller -deklaration"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare %s%> som inte omedelbart följs av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD angivet både i deklarationsmålets %<link%>- och %<to%>-klausuler"
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr "direktiv med endast %<device_type%>-klausuler ignoreras"
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> förväntades"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> förväntades"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> utan en motsvarande %<#pragma omp declare target%>"
@@ -43361,42 +43396,42 @@ msgstr "funktionsnamn %<(%> förväntades"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "en av initierarens anropsargument skall vara %<&omp_priv%>"
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<simd%>, %<reduction%>, %<target%> eller %<variant%> förväntades"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<seq_cst%>, %<relaxed%> eller %<acq_rel%> förväntades"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "en klausul %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> eller %<atomic_default_mem_order%> förväntades"
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "klausulen %qs på direktivet %<requires%> stödjs inte ännu"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "klausulen %qs använd lexikalt efter första målkonstruktionen eller avlastnings-API:et"
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "mer än en klausul %<atomic_default_mem_order%> i en enskild kompileringsenhet"
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "klausulen %<atomic_default_mem_order%> använd lexikalt efter första konstruktionen %<atomic%> utan minnesordningsklausul"
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> kräver åtminstone en klausul"
@@ -43411,27 +43446,27 @@ msgstr "nollstor typ %qT i %<reduction%>-klausul"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "typen %qT med variabel storlek i-%<reduction%>-klausul"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE är deklarerad %<threadprivate%> efter första användningen"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatisk variabel %qE kan inte vara %<threadprivate%>"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE har ofullständig typ"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> utan att stöd för transaktionsminne är aktiverat"
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> inom en %<__transaction_relaxed%>"
@@ -43441,7 +43476,7 @@ msgstr "%<__transaction_cancel%> inom en %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "yttre %<__transaction_cancel%> som inte är inuti en yttre %<__transaction_atomic%>- eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> inte inom %<__transaction_atomic%>"
@@ -43456,7 +43491,7 @@ msgstr "ingen avslutande klammer"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD har en ofullständig typ %qT"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ogiltig användning av void-uttryck"
@@ -43497,127 +43532,127 @@ msgstr "attributet %qs kan användas på en funktion som inte tar variabla argum
 msgid "function types not truly compatible in ISO C"
 msgstr "funktionstyper inte riktigt kompatibla i ISO C"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "det går inte att blanda operander av typerna decimalt flyttal och vektor"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "det går inte att blanda operander av typerna flyttal och komplext tal"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "det går inte att blanda operander av typerna decimalt flyttal och annat flyttal"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "pekare till vektorer med olika kvalificerare är inkompatibla i ISO C"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "typerna är inte riktigt kompatibla"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "pekares måltyper är inkompatibla i C++"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "funktionsreturtyper är inte kompatibla på grund av %<volatile%>"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "konvertering av en sammansatt vektorlitteral till en pekare är felaktigt i C++"
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT har ingen medlem med namnet %qE; menade du %qE?"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT har ingen medlem med namnet %qE"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr "använder en medlem %qE av en atomär struktur %qE"
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "åtkomst av medlemmen %qE i en atomär union %qE"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr "%qE är en pekare; tänkte du använda %<->%>?"
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "begäran av medlem %qE i något som inte är en post eller union"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "derefererar %<void *%>-pekare"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "fältindex är inte ett heltal"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "indexerat värde är en funktionspekare"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C förbjuder indexering av %<register%>-vektor"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C90 förbjuder indexering av icke-l-värde-vektor"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr "uppräkningskonstant definierad här"
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> på vektorfunktionsparametern %qE kommer returnera storleken på %qT"
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "anropat objekt %qE är inte en funktion eller funktionspekare"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "anropat objekt %qD är inte en funktion eller funktionspekare"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "anropat objekt är inte en funktion eller funktionspekare"
@@ -43625,1594 +43660,1594 @@ msgstr "anropat objekt är inte en funktion eller funktionspekare"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "funktion anropad via en inkompatibel typ"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "funktion med kvalificerad void-returtyp anropad"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "typen på formell parameter %d är ofullständig"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "skickar argument %d till %qE som heltal istället för flyttal på grund av prototyp"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "skickar argument %d till %qE som heltal istället för komplext på grund av prototyp"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "skickar argument %d till %qE som komplext istället för flyttal på grund av prototyp"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "skickar argument %d till %qE som flyttal istället för heltal på grund av prototyp"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "skickar argument %d till %qE som komplext istället för heltal på grund av prototyp"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "skickar argument %d till %qE som flyttal istället för komplext på grund av prototyp"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "skickar argument %d till %qE som %<float%> istället för %<double%> på grund av prototyp"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "skickar argument %d till %qE som %qT istället för %qT på grund av prototyp"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "skickar argument %d till %qE med annan vidd på grund av prototyp"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "skickar argument %d till %qE teckenlöst på grund av prototyp"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "skickar argument %d till %qE med tecken på grund av prototyp"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "för många argument till metoden %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, gcc-internal-format
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "för många argument till den inbyggda funktionen %qE, %d förväntades"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "implicit konvertering från %qT till %qT när argument skickas till en funktion"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, gcc-internal-format
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "för få argument till den inbyggda funktionen %qE, %u förväntades"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "jämförelse med stränglitteral resulterar i odefinierat beteende"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "jämförelse mellan pekare och teckenkonstanten noll"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "tänkte du dereferera pekaren?"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "jämförelse mellan %qT och %qT"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "pekare av typ %<void *%> använd i subtraktion"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "pekare till funktion använd i subtraktion"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik på pekare till ofullständig typ"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmetik på pekare till ett tomt aggregat"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> på ett booleskt uttryck"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "tänkte du använda logiskt icke?"
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C stödjer inte %<~%> för komplex konjugering"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, gcc-internal-format
 msgid "wrong type argument to absu"
 msgstr "fel typ på argument till absu"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "fel typ på argument till unärt utropstecken"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "ökning av uppräkningsvärde är ogiltigt i C++"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "minskning av uppräkningsvärde är ogiltigt i C++"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "ökning av ett booleskt uttryck"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "minskning av ett booleskt uttryck"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C stödjer inte %<++%> och %<--%> på komplexa typer"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "fel typ på argument till ökning"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "fel typ på argument till minskning"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "ökning en pekare till en ofullständig typ %qT"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "minskning av en pekare till en ofullständig typ %qT"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "tar adressen till uttryck av typ %<void%>"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "kan inte ta adressen till bitfält %qD"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "kan inte ta adressen till skalär med omvänd lagringsordning"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "adress till vektor med omvänd skalär lagringsordning begärd"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "global registervariabel %qD använd i nästad funktion"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "registervariabel %qD använd i nästad funktion"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "adress till global registervariabel %qD efterfrågad"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "adress på registervariabeln %qD efterfrågad"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "icke-l-värde-vektor i villkorsuttryck"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "implicit konvertering från %qT till %qT för att stämma med andra resultat i villkor"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr "operand till %<?:%> ändrar teckenläge från %qT till %qT på grund av teckenlöshet hos en annan operand"
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C förbjuder villkorliga uttryck med bara en sida void"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "pekare till skilda adressrymder använda i villkorsuttryck"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "pekare till vektor tappar kvalificerare i villkorsuttryck"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C förbjuder villkorliga uttryck mellan %<void *%> och funktionspekare"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, gcc-internal-format
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "pekartyper stämmer inte mellan %qT och %qT hos %qD och %qD i villkorsuttryck"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "pekartyper stämmer inte i villkorsuttryck"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "pekar-/heltalstyper stämmer inte i villkorsuttryck"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "typer stämmer inte i villkorsuttryck"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet %<nodiscard%>: %E"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet %<nodiscard%>"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "ignorerar returnerat värde av typen %qT, deklarerat med attributet %<nodiscard%>: %E"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "ignorerar returnerat värde av typen %qT, deklarerat med attributet %<nodiscard%>"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "i anrop av %qD, deklarerad här"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "vänster operand av kommauttryck har ingen effekt"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "höger operand av kommauttryck har ingen effekt"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr "typkonvertering lägger %q#v-kvalificerare till funktionstyp"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "typkonvertering kastar bort %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "för att vara säker måste alla mellanliggande pekare i typkonvertering från %qT till %qT vara %<const%>-kvalificerade"
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "typkonvertering anger vektortyp"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "typkonvertering anger funktionstyp"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C förbjuder typkonvertering av ickeskalärer till samma typ"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C förbjuder typkonvertering till unionstyper"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "typkonvertering till unionstyp från typ som ej finns i unionen"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "typkonvertering till adressrymdspekare %s från skild generisk adressrymdspekare"
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "typkonvertering till generisk adressrymdspekare från skild adressrymdspekare till %s"
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "typkonvertering från adressrymdspekare till %s från skild adressrymdspekare till %s"
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "typkonvertering ökar kravet på justering av måltypen"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "typkonvertering från pekare till heltal av annan storlek"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "typkonvertering från funktionsanrop av typ %qT till typ %qT matchar inte"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typkonvertering till pekare från heltal med annan storlek"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C förbjuder konvertering av funktionspekare till objektpekartyp"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C förbjuder konvertering av objektpekare till funktionspekartyp"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "typkonvertering mellan inkompatibla funktionstyper från %qT till %qT"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "definition av en typ i en typkonvertering är ogiltigt i C++"
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "tilldelning till uttryck med vektortyp"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "uppräkningskonvertering i tilldelning är ogiltigt i C++"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(i närheten av initiering av %qs)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "vektor initierad från strängkonstant inom parentes"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "%qT förväntades men argumentet har typ %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr "typen på argument %2$d till %1$qD är %3$qT där %4$qT förväntas i ett anrop av den inbyggda funktionen som deklarerats utan prototyp"
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr "argument %2$d till %1$qD befordras till %3$qT där %4$qT förväntas i ett anrop till den inbyggda funktionen som deklarerats utan prototyp"
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr "den inbyggda %qD är deklarerad här"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "enum-konvertering när argument %d till %qE skickades är ogiltigt i C++"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "enum-konvertering från %qT till %qT i tilldelning är ogiltigt i C++"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "enum-konvertering från %qT till %qT i initiering är ogiltigt i C++"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "enum-konvertering från %qT till %qT i retursats är ogiltigt i C++"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT"
 msgstr "implicit konvertering från %qT till %qT"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "att skicka argument %d till %qE skapar en %q#v-kvalificerad funktionspekare från en okvalificerad"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "tilldelning skapar en %q#v-kvalificerad funktionspekare från en okvalificerad"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "initiering skapar en %q#v-kvalificerad funktionspekare från en okvalificerad"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "retur skapar en %q#v-kvalificerad funktionspekare från en okvalificerad"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "att skicka argument %d till %qE kastar %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "tilldelning kastar %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "initiering kastar %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "retur kastar %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C förbjuder argumentkonvertering till unionstyp"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "begäran om implicit konvertering från %qT till %qT tillåts inte i C++"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "skickar argument %d till %qE från pekare till adressutrymme som inte är inneslutet"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "tilldelning från pekare till adressutrymme som inte är inneslutet"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "initiering från pekare till adressutrymme som inte är inneslutet"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "retur från pekare till ej omgivande adressrymd"
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "argumentet %d till %qE kan vara kandidat för ett formatattribut"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "vänsterhandssida av initiering kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "returtypen kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "skickar argument %d till %qE från inkompatibel skalär lagringsordning"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "tilldelning till %qT från pekartypen %qT med inkompatibel skalär lagringsordning"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "initiering av %qT från pekartypen %qT med inkompatibel skalär lagringsordning"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "returnerar %qT från en pekartyp med inkompatibel skalär lagringsordning %qT"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C förbjuder att skicka argument %d till %qE mellan funktionspekare och %<void *%>"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C förbjuder tilldelning mellan funktionspekare och %<void *%>"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C förbjuder initiering mellan funktionspekare och %<void *%>"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C förbjuder retur mellan funktionspekare och %<void *%>"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "pekarmål när argument %d till %qE skickades skiljer i teckenhet"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "pekarmål i tilldelning från %qT till %qT skiljer i teckenhet"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "pekarmål i initiering från %qT till %qT skiljer i teckenhet"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "pekarmål vid retur av %qT från en funktion med returtyp %qT skiljer i teckenhet"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "skickar argument %d till %qE från inkompatibel pekartyp"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "tilldelning till %qT från pekare till %qD med inkompatibel typ %qT"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "tilldelning till %qT från inkompatibel pekartyp %qT"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "initiering av %qT från pekare till %qD med inkompatibel typ %qT"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "initiering av %qT från inkompatibel pekartyp %qT"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "returnerar pekare till %qD av typen %qT från en funktion med inkompatibel typ %qT"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "returnerar %qT från en funktion med inkompatibel returtyp %qT"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "att skicka argument %d till %qE skapar pekare av ett heltal utan typkonvertering"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "tilldelning till %qT från %qT skapar pekare av heltal utan typkonvertering"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "initiering av %qT från %qT skapar pekare från heltal utan typkonvertering"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "att returnera %qT från en funktion med returtyp %qT skapar pekare av ett heltal utan typkonvertering"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "att skicka argument %d till %qE skapar pekare från heltal utan typkonvertering"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "tilldelning till %qT från %qT skapar heltal från pekare utan typkonvertering"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "initiering av %qT från %qT skapar heltal från pekare utan typkonvertering"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "att returnera %qT från en funktion med returtyp %qT skapar pekare från heltal utan typkonvertering"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "inkompatibel typ för argument %d av %qE"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "inkompatibla typer i tilldelning till typ %qT från typ %qT"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "inkompatibla typer i när typ %qT initierades med typ %qT"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "inkompatibla typer när typ %qT returnerades men %qT förväntades"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "traditionell C tillåter inte aggregatinitiering"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initiering av medlem som är en flexibel vektor"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "det går inte att initiera vektorn av %qT från en stränglitteral med typvektor %qT"
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "vektor av typ som inte passar initierad från strängkonstant"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ogiltig användning av icke-l-värde-vektor"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "initierarelement är inte konstant"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "vektor initierad från icke-konstant vektoruttryck"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "initierarelement är inte ett konstant uttryck"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "initierarelement är inte beräkningsbart vid laddtidpunkt"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "ogiltig initierare"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "ogenomskinliga vektortyper kan inte initieras"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "extra klammergrupp vid slutet av initierare"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "klamrar runt skalär initierare"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initiering av medlem som är en flexibel vektor i nästat sammanhang"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "klamrar saknas runt initierare"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "initierare saknas för fält %qD i %qT"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "tom skalär initierare"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "extra element i skalär initierare"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "vektorindex i initierare för annat än vektor"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "fältnamn i initierare för annat än post eller union"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "vektorindex i initierare inte av heltalstyp"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "vektorindex i initierare inte av ett konstant heltalsuttryck"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "ickekonstant vektorindex i initierare"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "vektorindex i initierare överskrider vektorns storlek"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "tomt indexintervall i initierare"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "vektorindexintervall i initierare överskrider vektorns gränser"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "initierat fält med sidoeffekter överskrivet"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "initierat fält överskrivet"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "enum-konvertering i initiering är ogiltigt i C++"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, gcc-internal-format
 msgid "excess elements in %<char%> array initializer"
 msgstr "överflödiga element i %<char%>-vektorinitierare"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "överflödiga element i postinitierare"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "positionsinitiering av fält i %<struct%> deklarerad med attributet %<designated_init%>"
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "icke-statisk initiering av an flexibel vektormedlem"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "överflödiga element i unioninitierare"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "traditionell C tillåter inte initiering av unioner"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "överflödiga element i vektorinitierare"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "överflödiga element i vector-initierare"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "överflödiga element i skalärinitierare"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C förbjuder %<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "funktion deklarerad %<noreturn%> har en %<return%>-sats"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> utan värde i funktion som returnerar icke-void"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> med värde i funktion som returnerar void"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C förbjuder %<return%> med värde i funktion som returnerar void"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "funktionen returnerar adress till en etikett"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-argument är inte ett heltal"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "%<long%>-switch-uttryck konverteras inte till %<int%> i ISO C"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case-etikett är inte ett konstant heltalsuttryck"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etikett är inte i en switch-sats"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>-etikett som inte ligger i en switch-sats"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sats som inte är i en loop eller switch"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ogiltig utgång från OpenMP-strukturerat block"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-sats använd med OpenMP-for-slinga"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sats som inte är i en loop"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "sats utan effekt"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "uttryckssats har ofullständig typ"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "jämför vektorer med skilda elementtyper"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "jämför vektorer med olika antal element"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "det går inte att hitta en heltalstyp med samma storlek som %qT"
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "att jämföra flyttal med %<==%> eller %<!=%> är osäkert"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "jämförelsen kommer alltid beräknas till %<false%> för adressen till %qD kommer aldrig att vara NULL"
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "jämförelsen kommer alltid beräknas till %<true%> för adressen till %qD kommer aldrig att vara NULL"
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "jämförelse av pekare till skilda adressutrymmen"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C förbjuder jämförelse mellan %<void *%> och funktionspekare"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "jämförelse av skilda pekartyper saknar en typkonvertering"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "jämförelse mellan pekare och heltal"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "jämförelse av kompletta och ofullständiga pekare"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C förbjuder ordningsjämförelse på pekare till funktioner"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "ordningsjämförelse av pekare med nollpekare"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordningsjämförelse av pekare med heltalet noll"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "implicit konvertering från %qT till %qT för att matcha den andra operanden i binärt uttryck"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "vektor använd som inte kan konverteras till en pekare där en skalär krävs"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "struct-typvärde använt där skalär krävs"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "värde av uniontyp använt där skalär krävs"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "vektortyp använd där skalär krävs"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%<cancel%> %<if%>-klausulmodifierare förväntades"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE i %qs-klausul"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfältet %qE i %qs-klausul"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE är en medlem i en union"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "det går inte att dereferera %qE i en %qs-klausul"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD i %qs-klausul"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD är en trådprivat variabel i en %qs-klausul"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "undre gränsen %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "längden %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "en enda pekare förväntades i en %qs-klausul"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "nollängds vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "för en vektor med okänd gräns måste ett längduttryck anges"
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negativ nedre gräns i vektorsektion i %qs-klausul"
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "negativ längd i vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "nedre gränsen %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "längden %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "övre gräns %qE ovanför storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "för en vektorfunktionsparameter måste ett längduttryck anges"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "för pekartyper måste ett längduttryck anges"
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "vektorsektionen är inte sammanhängande i %qs-klausulen"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE har inte pekar- eller vektortyp"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "iteratorn %qD har varken heltals- eller pekartyp"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "iteratorn %qD har %<_Atomic%>-kvalificerad typ"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "iteratorn %qD har const-kvalificerad typ"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "iteratorsteg med en icke-heltalstyp"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr "iteratorn %qD har nollsteg"
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr "typ av iteratorn %qD refererar till den yttre iteratorn %qD"
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "startuttrycket refererar till den yttre iteratorn %qD"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "slututtrycket refererar till den yttre iteratorn %qD"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "steguttrycket refererar till den yttre iteratorn %qD"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "pekare förväntades i en %qs-klausul"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "%<inscan%>- och icke-%<inscan%> %<reduction%>-klausul på samma konstruktion"
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "en %<inscan%> %<reduction%>-klausul med vektorsektion"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD i %<reduction%>-klausul är en vektor med storlek noll"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE i %<reduction%>-klausul"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr "nollstor typ %qT i %qs-klausul"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr "typen %qT med variabel storlek i %qs-klausul"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE har ogiltig typ för %<reduction(%s)%>"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "ingen användardefinierad reduktion funnen för %qE"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "elementtyp med variabel längd i vektor-%<reduction%>-klausul"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "en %<nowait%>-klausul får inte användas tillsammans med %<copyprivate%>"
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE måste vara %<threadprivate%> för %<copyin%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "modifierare skall inte anges i %<linear%>-klausul på %<simd%>- eller %<for%>-konstruktioner"
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "en linjär klausul använd på variabel som inte är heltal och inte pekare med typen %qT"
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD i %<linear%>-klausul"
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "%<linear%>-klausulens steg %qE är varken en konstant eller en parameter"
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE är inte en variabel i klausul %qs"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD förekommer mer än en gång i reduktionsklausuler"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE förekommer mer än en gång i dataklausuler"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD förekommer mer än en gång i dataklausuler"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD förekommer både i data- och map-klausuler"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE är inte en variabel i klausul %<firstprivate%>"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE är inte en variabel i klausul %<lastprivate%>"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE är inte en variabel i %<aligned%>-klausul"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "%qE i %<aligned%>-klausul är varken en pekare eller en vektor"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%<_Atomic%> %qD i %<aligned%>-klausul"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE är inte en variabel i en %<nontemporal%>-klausul"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE förekommer mer än en gång i %<nontemporal%>-klausuler"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE är inte en variabel i %<allocate%>-klausul"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE förekommer mer än en gång i %<allocate%>-klausuler"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr "klausulen %<depend%> med beroendetyp %<depobj%> på vektorsektion"
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE är varken ett l-värdeuttryck eller en vektorsektion i en %<depend%>-klausul"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr "%qE har inte en typ %<omp_depend_t%> i klausulen %<depend%> med beroendetyp %<depobj%>"
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr "%qE skall inte ha en typ %<omp_depend_t%> i klausulen %<depend%> med annan beroendetyp än %<depobj%>"
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "vektorsektionen har inte en avbildbar typ i %qs-klausulen"
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD förekommer mer än en gång i rörelseklausuler"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD förekommer mer än en gång i avbildningsklausuler"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE är varken en variabel eller ett funktionsnamn i klausulen %qs"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE förekommer mer än en gång i samma %<declare target%>-direktiv"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD är inte en ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE är inte ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "variabeln %qs är inte en pekare"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "%qs-variabeln är varken en pekare eller en vektor"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "en %<order%>-klausul får inte användas tillsammans med %<ordered%>"
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "för många %qs-klausuler på en task-konstruktion"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "en %<inbranch%>-klausul är inkompatibel med %<notinbranch%>"
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE är förutbestämd som %qs för %qs"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-kvalificerad %qE kan förekomma endast i klausuler %<shared%> eller %<firstprivate%>"
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-klausulvärde är större än %<safelen%>-klausulvärde"
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-schemaläggningsmodifierare angiven tillsammans med %<ordered%>-klausul"
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "en %qs-klausul angiven tillsammans med en %<inscan%> %<reduction%>-klausul"
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-klausulsteg är en parameter %qD inte angiven i %<uniform%>-klausul"
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "en %<nogroup%>-klausul får inte användas tillsammans med en %<reduction%>-klausul"
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "en %<detach%>-klausul får inte användas tillsammans med en %<mergeable%>-klausul"
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr "händelsehanteraren för en %<detach%>-klausul skall inte finnas i en datadelningsklausul"
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "kan inte använda %<va_arg%> med omvänd lagringsordning"
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "andra argumentet till %<va_arg%> är av ofullständig typ %qT"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ kräver en befordrad typ, inte en enum-typ, i %<va_arg%>"
@@ -45417,7 +45452,7 @@ msgstr "  ingen känd konvertering från %qH till %qI"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  ingen känd konvertering för argument %d från %qH till %qI"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -45526,663 +45561,669 @@ msgstr "initiering av %qH med %qI i konverterat konstantuttryck binder inte dire
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "konvertering från %qH till %qI i ett konverterat konstantuttryck"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%D(%A)%>"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%D(%A)%> är tvetydigt"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "pekar-till-medlemsfunktion %qE kan inte anropas utan ett objekt, överväg att använda %<.*%> eller %<->*%>"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "ingen träff för anrop till %<(%T) (%A)%>"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "anrop av %<(%T) (%A)%> är tvetydigt"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "tvetydig överlagring för "
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr "ingen matchning för "
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (operandtyper är %qT, %qT och %qT)"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (operandtyper är %qT och %qT)"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (operandtyp är %qT)"
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "treställig %<operator?:%>"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "treställig %<operator?:%> i %<%E ? %E : %E%>"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> i %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> i %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs i %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%<operator %s%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator %s%> i %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> i %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> i %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ förbjuder uteslutande av mittersta termen i ett %<?:%> uttryck"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "den härledda skalära typen %qT är inte en heltals- eller flyttalstyp av samma storlek som %qT"
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "konvertering av skalären %qH till vektorn %qI innebär avhuggning"
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "inkompatibla vektortyper i villkorsuttryck: %qT, %qT och %qT"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "andra operanden till villkorsoperatorn är av typ %<void%>, men den tredje operanden är varken ett throw-uttryck eller av typ %<void%>"
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "tredje operanden till villkorsoperatorn är av typ %<void%>, men den andra operanden är varken ett throw-uttryck eller av typ %<void%>"
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "operander till %<?:%> har olika typer %qT och %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  och båda typerna kan konverteras till den andra"
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "implicit konvertering från %qH till %qI för att stämma med andra resultat i villkor"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "uppräkningsmissmatch i villkorsuttryck: %qT kontra %qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "villkorsuttryck mellan uppräkningstypen %qT och flyttalstypen %qT bör undvikas"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "villkorsuttryck mellan flyttalstypen %qT och uppräkningstypen %qT bör undvikas"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "uppräknings- och inte uppräkningstyp i villkorsuttryck"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs, försöker med prefixoperator istället"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "i C++20 anropar denna jämförelse den aktuella funktionen rekursivt med omvända argument"
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "returtypen för %qD är inte %qs"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "använd som omskriven kandidat för jämförelse mellan %qT och %qT"
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "jämförelse mellan %q#T och %q#T"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "undantagsuppstädning för denna placerande new väljer icke-placerande %<operator delete%>"
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD är som en vanlig (icke placerande) avallokeringsfunktion i C++14 (eller med %<-fsized-deallocation%>)"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD är en vanlig (utan placering) avallokeringsfunktion"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "ingen motsvarande avallokeringsfunktion för %qD"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passande %<operator %s%> för %qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D är privat inom denna kontext"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "deklarerad privat här"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D är skyddad inom denna kontext"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "deklarerad skyddad här"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D är oåtkomlig inom denna kontext"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "skickar NULL till icke-pekarargument %P till %qD"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  deklarerad här"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "konverterar till icke-pekartyp %qT från NULL"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "konverterar %<false%> till pekartyp för argument %P till %qD"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterar %<false%> till pekartyp %qT"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  initierar argument %P till %qD"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "konverteringar till vektorer med okänd gräns är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "för många klamrar runt initierare för %qT"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "konvertering till %qH från %qI behöver en direktinitiering"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ogiltig användardefinierad konvertering från %qH till %qI"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "ogiltig konvertering från %qH till %qI"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "att konvertera till %qT från initierarlista skulle använda den explicita konstrueraren %qD"
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "i C++11 och senare kan en standardkonstruerare vara explicit"
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "kan inte binda r-värdesreferens av typen %qH till ett l-värde av typ %qI"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+#| msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "kan inte binda icke-const-l-värde av typen %qH till ett r-värde av typ %qI"
+
+#: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "kan inte binda icke-const-l-värde av typen %qH till ett r-värde av typ %qI"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "det går inte att binda en referens av typen %qH till %qI på grund av olika vektorgränser"
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "att binda en referens av typen %qH till %qI kastar kvalificerare"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "det går inte att binda bitfält %qE till %qT"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "det går inte att binda packat fält %qE till %qT"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "det går inte att binda rvalue %qE till %qT"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "implicit konvertering från %qH till %qI när argument skickas till en funktion"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "enum %qT med räckvidd skickad vidare %<...%> som %qT före %<-fabi-version=6%>, %qT efter"
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "att skicka objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "det går inte att referera typen %qT via %<...%>"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "att ta emot objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursiv beräkning av standardargument till %q#D"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "anrop till %qD använder standardargumentet för parameter %P, vilket inte definierats ännu"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argument till funktionsanrop kan vara en kandidat för ett formatattribut"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "användning av multiversionsfunktion utan ett standardfall"
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "att skicka %qT som %<this%>-argument kastar kvalificerare"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  i anrop till %qD"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT är inte en åtkomlig bas till %qT"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "skickar argument till ellips av den ärvda konstrueraren %qD"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "tilldelning från en temporär %<initializer_list%> utökar inte livslängden på den underliggande vektorn"
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%qD skriver till ett objekt av typen %#qT utan någon trivial kopieringstilldelning"
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD skriver till ett object av den icke-triviala typen %#qT%s"
 
 # %qs blir "protected" eller "private"
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%qD skriver till ett objekt av typen %#qT med %qs-medlem %qD"
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%qD skriver till ett objekt av typen %#qT som innehåller en pekare till datamedlem%s"
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; använd tilldelning eller värdeinitiering istället"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; använd tilldelning istället"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; använd värdeinitiering istället"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD nollställer ett objekt av typen %#qT utan någon trivial kopieringstilldelning%s"
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD nollställer ett objekt av den icke-triviala typen %#qT%s"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD nollställer ett objekt av typen %#qT som innehåller en pekare-till-medlem%s"
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; använd kopieringstilldelning eller kopieringsinitiering istället"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; använd kopieringstilldelning istället"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; använd kopieringsinitiering istället"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD skriver till ett objekt av typen %#qT utan någon trivial kopieringstilldelning%s"
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD skriver till ett objekt av typen %#qT som inte är trivialt kopierbar%s"
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD skriver till ett objekt med en borttagen kopieringskonstruerare"
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD kopierar ett objekt med en icke-trivial typ %#qT från en vektor av %#qT"
 
 # %qs blir "protected" eller "private"
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD kopierar ett objekt av typen %#qT med %qs-medlem %qD från en vektor av %#qT; använd tilldelning eller kopieringsinitiering istället"
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD skriver till ett objekt med en icke-trivial typ %#qT och lämnar %wu byte oförändrade"
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD skriver till ett objekt av en icke-trivial typ %#qT och lämnar %wu byte oförändrade"
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD flyttar ett objekt av en icke trivialt kopierbar typ %#qT; använd %<new%> och %<delete%> istället"
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD flyttar ett objekt av typen %#qT med en borttagen kopieringskonstruerare; använd %<new%> och %<delete%> istället"
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD flyttar ett objekt av typen %#qT med en borttagen destruerare"
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD flyttar ett objekt av den icke-triviala typen %#qT och storleken %E in i en region av storleken %E"
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT är deklarerad här"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "konstruerare delegerar till sig själv"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 msgid "cannot convert %qH to %qI"
 msgstr "det går inte att konvertera %qH till %qI"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "anrop av icke-funktion %qD"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan inte anropa konstrueraren %<%T::%D%> direkt"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "för en typkonvertering i funktionsstil, ta bort det överflödiga %<::%D%>"
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%s(%A)%>"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%s(%A)%> är tvetydigt"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtual %q#D anropad från initierare av ickestatisk datamedlem"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtual %q#D anropad från en konstruerare"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtual %q#D anropad från en destruerare"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "det går inte att anropa medlemsfunktion %qD utan ett objekt"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "att skicka %qT väljer %qT framför %qT"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "väljer %qD framför %qD"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 msgid "  for conversion from %qH to %qI"
 msgstr "  för konvertering från %qH till %qI"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  för att konverteringssekvensen för argumentet är bättre"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "standardargument stämmer inte överens i upplösning av överlagring"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ säger att dessa är tvetydiga, trots att den sämsta konverteringen för den första är bättre än den sämsta konverteringen för den andra:"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "en temporär bunden till %qD består endast tills konstrueraren avslutar"
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ogiltig initiering av icke konstant referens av typ %qH från ett r-värde av typ %qI"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ogiltig initiering av referens av typ %qH från uttryck av typ %qI"
 
@@ -46206,1127 +46247,1127 @@ msgstr "kan inte konvertera från pekare till basklassen %qT till pekare till de
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "kan inte konvertera från basklassen %qT till den härledda klassen %qT via den virtuella basen %qT"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "kan inte konvertera %qT till basklassen %qT eftersom %qT är inkomplett"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D står i konflikt med versionen ärvd från %qT"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "versionen ärvd från %qT är deklarerad här"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D kan inte överlagras med %q#D"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "tidigare deklaration %q#D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "åtkomstspecifikationer i konflikt för metod %q+D, ignoreras"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "åtkomstspecifikationer i konflikt för fält %qE, ignoreras"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "%qD är ogiltig i %q#T på grund av lokal metod %q#D med samma namn"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "den lokala metoden %q#D är deklarerad här"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "%qD är ogiltig i %q#T på grund av lokal medlem %q#D med samma namn"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "den lokala medlemmen %q#D är deklarerad här"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD ärver ABI-etiketten %E som %qT (använd i sin returtyp) har"
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT är deklarerad här"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD ärver ABI-taggen %E som %qT (använd i dess typ) har"
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qT har inte ABI-taggen %E som basen %qT har"
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qT har inte ABI-taggen %E som %qT (använd i typen av %qD) har"
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "kan inte härleda från %<final%> bas %qT i härledd typ %qT"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "alla medlemsfunktioner i klass %qT är privata"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T definierar bara en privat destruerare och har inga vänner"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T definierar bara privata konstruerare och har inga vänner"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D är public, men behöver ett befintligt %q#T-objekt"
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "ingen unik slutlig ersättare för %qD i %qT"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD kan markeras override"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D är markerad %<override%>, men den åsidosätter inte"
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D är markerad %<final%>, men är inte virtuell"
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD var dold"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  av %qD"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ogiltig, en anonym union kan bara ha publika ickestatiska datamedlemmar"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "denna flexibilitet bör undvikas och kommer tas bort"
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "ellipsen i %qD ärvs inte"
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bitfält %q#D har en icke-heltalstyp %qT"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bredd för bitfältet %q+D inte en heltalskonstant"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "negativ bredd i bitfält %q+D"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "noll i bredd i bitfält %q+D"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "bredden på %qD är större än dess typ"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD är för liten för att få plats med alla värden hos %q#T"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "medlem %q+#D med konstruerare inte tillåten i union"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "medlem %q+#D med destruerare inte tillåten i union"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator inte tillåten i union"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "obegränsade unioner är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "i C++98 får %q+D inte vara statisk eftersom den är medlem av en union"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "icke-statisk datamedlem %q+D i en union får inte ha referenstyp %qT"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "datamedlemmen %q+D ogiltigt deklarerad funktionstyp"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "datamedlemmen %q+D ogiltigt deklarerad metodtyp"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "ignorerar attributet packed på grund av opackat icke-POD-fält %q#D"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "medlem %q+D kan inte deklareras som en %<mutable%> referens"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "medlemmen %q+D kan inte både deklareras %<const%> och %<mutable%>"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "flera fält i unionen %qT initierade"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "den initierade medlemmen %q+D är deklarerad här"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "fält %q#D med samma namn som en klass"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T har pekardatamedlemmar"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  men deklarerar inte %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eller %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  men deklarerar inte %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "pekarmedlemmen %q+D är deklarerad här"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "justeringen av %qD ökade i %<-fabi-version=9%> (GCC 5.2)"
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "justering av %qD kommer öka i %<-fabi-version=9%>"
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initierare angiven för icke-virtuell metod %q+D"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "destrueraren för %qT är tvetydig"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "metoden åsidosätter både metoderna %<transaction_pure%> och %qE"
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "metod deklarerad %qE åsidosätter %qE-metod"
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "omslutande klass till %<constexpr%> icke-statisk medlemsfunktion %q+#D är inte en litteral typ"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T är inte litteral för att:"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT är en höljestyp (closure), som är litteraler endast i C++17 och senare"
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T har en icke-trivial destruerare"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T har inte en %<constexpr%>-destruerare"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T är inte ett aggregat, har inte en trivial standardkonstruerare och har ingen %<constexpr%>-konstruerare som inte är en kopierings- eller flyttningskonstruerare"
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  basklassen %qT till %q+T är inte litteral"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  den icke-statiska datamedlemmen %qD har icke-litteral typ"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  den icke-statiska datamedlemmen %qD har volatile typ"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "basklassen %q#T har en åtkomlig icke-virtuell destruerare"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "icke-statisk referens %q#D i klass utan en konstruerare"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "icke-statisk const-medlem %q#D i klass utan en konstruerare"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkt bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuell bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "förskjutningen av %qD följer inte ABI:et och kan ändras i en framtida version av GCC"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "storleken på typen %qT är för stor (%qE byte)"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ogiltig användning av %qT med en vektor av storlek noll i %q#D"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ogiltig användning av %q#T med flexibel vektormedlem i %q#T"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "vektormedlem %q#D är deklarerad här"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "vektormedlem %qD med storlek noll är inte vid slutet av %q#T"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "vektormedlem %qD med storlek noll i en i övrigt tom %q#T"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "i definitionen av %q#T"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexibel vektormedlem %qD inte vid slutet av %q#T"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexibel vektor medlem %qD i en i övrigt tom %q#T"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "nästa medlem %q#D är deklarerad här"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "omdefinition av %q#T"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T har virtuella funktioner och åtkomlig ickevirtuell destruerare"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typgenomskinliga %q#T har inga fält"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "den typgenomskinliga klassen %qT har basklasser"
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "den typgenomskinliga klassen %qT har virtuella funktioner"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparenta %q#T kan inte göras transparent eftersom typen på första fältet har ett annat ABI än klassen som helhet"
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "definitionen av %qD matchar inte %<#include <initializer_list>%>"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "försökte avsluta post, men hoppade ut på grund av tidigare parsningsfel"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "språksträng %<”%E”%> känns inte igen"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "det går inte att lösa upp överlagrad funktion %qD baserat på konvertering till typ %qT"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen match som konverterar funktionen %qD till typen %q#T"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering av överlagrad funktion %qD till typ %q#T är tvetydig"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "antar pekare till medlem %qD"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en pekare på medlem kan bara skapas med %<&%E%>)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "inte tillräcklig typinformation"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "kan inte konvertera %qE från typ %qT till typ %qT"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "deklaration av %q#D ändrar betydelsen av %qD"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%qD deklarerad här som %q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "typen %qT för %<constexpr%>-variabeln %qD är inte en litteral"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "variabeln %qD av den ej litterala typen %qT i en %<constexpr%>-funktion"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "%<constexpr%>-variabeln %qD har variabelt modifierad typ %qT"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "ärvd konstruerare %qD är inte %<constexpr%>"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "ogiltig typ för parameter %d till %<constexpr%>-funktion %q+#D"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "lambdan är implicit %<constexpr%> endast i C++17 och senare"
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "ogiltig returtyp %qT för %<constexpr%>-funktionen %q+D"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T har virtuella basklasser"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr "%<constexpr%>-konstruerare har inte tom kropp"
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%>-konstrueraren för unionen %qT måste initiera precis en icke statisk datamedlem"
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "medlemmen %qD måste initieras av en mem-initierare i %<constexpr%>-konstruerare"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr "kroppen i %<constexpr%>-funktionen %qD är inte en retursats"
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD är inte användbar som en %<constexpr%>-funktion eftersom:"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "%<constexpr%>-anrop flödar förbi slutet på funktionen"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E är inte ett konstant uttryck"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "anrop av intern funktion %qE"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "ändring av ett const-objekt %qE är inte tillåten i ett konstant uttryck"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr "ursprungligen deklarerad %<const%> här"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr "referensen %<dynamic_cast%> misslyckades"
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "den dynamiska typen %qT av sin operand har inte en basklass av typen %qT"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr "den virtuella tabellpekaren används oinitierad"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr "den statiska typen %qT av sin operand är en icke-publik basklass av den dynamiska typen %qT"
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "%qT är en tvetydig basklass till den dynamiska typen %qT av sin operand"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "den dynamiska typen %qT av sin operand har inte en otvetydig publik basklass %qT"
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "anrop av icke-%<constexpr%>-funktion %qD"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "uttrycket %qE anger inte en %<constexpr%>-funktion"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr "vektordeallokering av objekt allokerade med icke-vektor-allokering"
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, gcc-internal-format
 msgid "allocation performed here"
 msgstr "allokeringen utförd här"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr "icke-vektor-deallokering av objekt allokerade med vektorallokering"
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr "avallokering av en redan avallokerad lagring"
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr "avallokering av lagring som inte tidigare allokerades"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD anropad i ett konstant uttryck före dess definition är komplett"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD anropad i ett konstant uttryck"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD användes före sin definition"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "anrop har cirkulärt beroende"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "beräkning av %<constexpr%> överskrider maxvärdet på %d (använd %<-fconstexpr-depth=%> för att öka maxvärdet)"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "höger operand av skiftuttrycket %q+E är negativ"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "högra operanden av skiftuttrycket %q+E är större än eller lika med precisionen %wu av den vänstra operanden"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "vänster operand av skiftuttrycket %q+E är negativ"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "skiftuttrycket %q+E spiller över"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "aritmetik som innefattar en nollpekare i %qE"
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "vektorindexvärdet %qE är utanför gränserna för vektorn %qD av typen %qT"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "icke-noll vektorindex %qE används med vektorn %qD av typen %qT med okända gränser"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "vektorindexvärdet %qE är utanför gränserna för vektortypen %qT"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "icke-noll vektorindex %qE används med en vektor av typen %qT med okända gränser"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "använder oinitierat vektorelement"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "derefererar en nollpekare i %qE"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "muterbar %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "använder oinitierad medlem %qD"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "använder medlem %qD istället för initierad medlem %qD i ett konstant uttryck"
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är en uniontyp"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT innehåller en uniontyp"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är en pekartyp"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT innehåller en pekartyp"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är en referenstyp"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT innehåller en referenstyp"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är en pekare-till-medlem-typ"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT innehåller en pekare-till-medlem-typ"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är volatil"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qs är inte ett konstant uttryck eftersom  %qT innehåller ett volatilt delobjekt"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%qs kan inte beräknas konstant på denna målarkitektur"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr "%qs kan inte vara konstant beräknat eftersom typen är för stor"
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qs kan inte beräknas konstant eftersom argumentet inte kan kodas"
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "%qs använder oinitierad byte vid avståndet %d"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs kan inte beräknas konstant eftersom argumentet inte kan tolkas"
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "derefererar en nollpekare"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "använder värdet av %qE genom ett %qT-glvalue i ett konstant uttryck"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "innehållet av den oinitierade lagringen är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "allokerad här"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "användning av allokerad lagring efter deallokering i ett konstant uttryck"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "värdet på %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD använd i sin egen initierare"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D är inte const"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D är volatile"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD initierades inte med ett konstant uttryck"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD deklarerades inte %<constexpr%>"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD har inte heltals- eller uppräkningstyp"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "ändring av %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "ändring av den aktiva medlemmen av en union %qD till %qD"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "ändring av den aktiva medlemmen av en union %qD till %qD under initiering"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "satsen är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "%<constexpr%>-slingiterationsantal överskrider gränsen på %d (använd %<-fconstexpr-loop-limit=%> för att öka gränsen)"
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "inline-assembler är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr "endast oevaluerad inline:ad assembler är tillåten i en %<constexpr%>-funktion i C++20"
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "värdet %qE av typen %qT är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "antalet %<constexpr%>-evalueringsoperationer överskrider gränsen på %wd (använd %<-fconstexpr-ops-limit=%> för att öka gränsen)"
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporär av den ej litterala typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "en %<reinterpret_cast%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "konvertering från pekartypen %qT till den aritmetiska typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "typkonvertering från %qT är inte tillåtet"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "uttrycket %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "oväntat mall-id %qE"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "funktionskoncept måste anropas"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "adressen för ett anrop av %qs är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "oväntat uttryck %qE av sorten %s"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE är inte ett konstant uttryck eftersom det har referenser till muterbara delobjekt av %qT"
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar till en ofullständigt initierad variabel"
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar ett resultat av %<operator new%>"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE är inte ett konstant uttryck eftersom allokerad lagring inte har avallokerats"
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "omedelbar evaluering returnerar adressen till en omedelbar funktion %qD"
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "konvertering av l-värde till r-värde av ett volatilt l-värde %qE med typen %qT"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "lambdafångst av %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "för att det används som ett gl-värde"
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> från heltal till pekare"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "adress-av på ett objekt %qE med trådlokal eller automatisk lagring är inte ett konstant uttryck"
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%<this%> används i ett konstant uttryck"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "lambdauttryck är inte ett konstant uttryck före C++17"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "virtuella funktioner kan inte %<constexpr%> före C++20"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<typeid%> är inte ett konstant uttryck eftersom %qE har polymorf typ"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "typkonvertering till %qT som inte är en heltalstyp i ett konstant uttryck"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD är deklarerad %<static%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD är deklarerad %<thread_local%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "division med noll är inte ett konstant uttryck"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ickekonstant vektorinitierare"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "etikettdefinitionen är inte ett konstant uttryck"
 
 # ast = abstract syntax tree
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "oväntat AST av sorten %s"
@@ -47336,52 +47377,52 @@ msgstr "oväntat AST av sorten %s"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr "båda grenarna av en %<if%>-sats markerad som %qs"
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> kommer alltid anropa %<terminate%>"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "i C++11 är standard för destruerare %<noexcept%>"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "i C++11 kommer denna %<throw%> att anropa %<terminate%> eftersom standard för destruerare är %<noexcept%>"
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "ignorerar attributet %qE efter tidigare %qE"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD är inte en typ"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD är inte en klasstyp"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD har inte typen %<const char *%>"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD har inte heltalstyp"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> innehåller inte endast icke-statiska datamedlemmar %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> och %<_M_column%>"
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "beräknar %qs"
@@ -47422,7 +47463,7 @@ msgstr "konvertering till icke konstant referens av typ %q#T från ett r-värde
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konvertering från %qH till %qI kastar kvalificerare"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "typkonvertering av %qT till %qT derefererar inte pekare"
@@ -47805,7 +47846,7 @@ msgstr "än tidigare deklaration av %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "omdeklaration av %qD skiljer i %qs från tidigare deklaration"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "tidigare deklaration %qD"
@@ -47935,8 +47976,8 @@ msgstr "tidigare %<pragma omp declare reduction%>-deklaration"
 msgid "%q#D previously defined here"
 msgstr "%q#D definierades tidigare här"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D tidigare deklarerad här"
@@ -47971,52 +48012,52 @@ msgstr "standardargumentet angivet för parameter %d till %q#D"
 msgid "previous specification in %q#D here"
 msgstr "tidigare specifikation i %q#D här"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr "deklarationen %qD står i konflikt med inbyggd"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr "deklaration %qD står i konflikt med import"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr "importdeklarerad %q#D här"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
 msgstr "motstridande exporterande deklaration av %qD"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, gcc-internal-format
 msgid "previous declaration %q#D here"
 msgstr "tidigare deklaration %q#D här"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "tidigare definition av %qD här"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "tidigare deklaration av %qD här"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "funktionen %qD är deklarerad %<[[noreturn]]%> men dess första deklaration var inte det"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "överflödig omdeklaration av %qD i samma definitionsområde"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "borttagen definition av %qD är inte första deklarationen"
@@ -48029,48 +48070,48 @@ msgstr "borttagen definition av %qD är inte första deklarationen"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "explicit specialisering av %qD efter första användningen"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: synlighetsattributet ignoreras eftersom det står i konflikt med tidigare deklaration"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "omdefinition av %q#D"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD står i konflikt med använd funktion"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D inte deklarerad i klassen"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D omdeklarerad inline med attributet %<gnu_inline%>"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D omdeklarerad inline utan attributet %<gnu_inline%>"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr "härledningsguiden %q+D omdeklarerad"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "jämförelseoperatorn %q+D standarddefinierades efter sin första deklaration"
@@ -48078,2300 +48119,2317 @@ msgstr "jämförelseoperatorn %q+D standarddefinierades efter sin första deklar
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "omdeklaration av vän %q#D kan inte ha standardmallargument"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "trådlokal deklaration av %q#D följer på icke trådlokal deklaration"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "icke trådlokal deklaration av %q#D följer på trådlokal deklaration"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "omdeklaration av %q#D"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "överflödig omdeklaration av statisk %<constexpr%>-datamedlem %qD"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "den lokala etiketten %qE står i konflikt med en befintlig etikett"
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr "tidigare etikett"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  härifrån"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  går ut från OpenMP-strukturerat block"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  passerar initiering av %q#D"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  går in i räckvidden hos %q#D, som har en icke-trivial destruerare"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  går in i %<try%>-block"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  går in i %<catch%>-block"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  går in i OpenMP-strukturerat block"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  går in i synkroniserad eller atomär sats"
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  går in %<constexpr if%>-sats"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  hoppar över initiering av %q#D"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  går in i räckvidden hos %q#D som har en icke-trivial destruerare"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD använd utan mallargument"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD är inte en funktionsmall"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T är inte en klass"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klassmall med namnet %q#T i %q#T"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "ingen typ med namnet %q#T i %q#T"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "uppslagning av %qT i %qT är tvetydig"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> namnger %q#T, som inte är en klassmall"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> namnger %q#T, som inte är en typ"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "mallparametrar stämmer inte med mallen %qD"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> är inte en potens av två"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med konstruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med destruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator är inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoreras i deklaration av %q#T"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "attribut för %q#T måste komma efter nyckelordet %qs"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flera typer i en deklaration"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omdeklaration av inbyggd C++-typ %qT"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kan endast anges för variabler eller funktionsdeklarationer"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typnamn saknas i typedef-deklaration"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ förbjuder anonyma poster"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kan endast anges för funktioner"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kan endast anges för funktioner"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kan endast anges inuti en klass"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kan endast anges för konstruerare"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "en lagringsklass kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> ignorerades i denna deklaration"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs kan inte användas till typdeklarationer"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoreras i explicit instansiering av %q#T"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "inget attribut kan användas på en explicit instansiering"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "ignorerar attribut använda på klasstypen %qT utanför dess definition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "ignorerar attribut använda på beroende typ %qT utan en associerad deklaration"
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD är initierad (använd %qs istället)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarationen av %q#D har %<extern%> och är initierad"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definitionen av %q#D är markerad %<dllimport%>"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D är inte en statisk datamedlem i %q#T"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "icke-medlemsmalldeklaration av %qD"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "stämmer inte med medlemsmalldeklarationen här"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillåter inte %<%T::%D%> att definieras som %<%T::%D%>"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubblerad initierare av %qD"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklaration av %q#D utanför en klass är inte en definition"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr "extern-deklaration %q#D med blockräckvidd är inte tillåtet i modulens räckvidd"
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qD är deklarerad %<thread_local%> i en %qs-funktion"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qD är deklarerad %<static%> i en %qs-funktion"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabeln %q#D har initierare men ofullständig typ"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen i vektorn %q#D har ofullständig typ"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "aggregatet %q#D har ofullständig typ och kan inte definieras"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD är deklarerad som en referens men inte initierad"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "namn använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "namnet %qD använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "icketriviala designerade initierare stödjs inte"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-beteckningen %qE är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "initierare misslyckas med att bestämma storleken på %qD"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "vektorstorlek saknas i %qD"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "vektor med storlek noll %qD"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstorlek på %qD är inte känd"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstorlek på %qD är inte konstant"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-variabeln %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-funktioners statiska data %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "du kan gå runt detta genom att ta bort initieraren"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "oinitierad %<const %D%>"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "oinitierad variabel %qD i %<constexpr%>-funktion"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "oinitierad variabel %qD i %<constexpr%>-kontext"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T har ingen användardefinierad standardkonstruerare"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "konstrueraren är inte användarens egna eftersom den är uttryckligen standarddefinierad i klasskroppen"
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "och den implicit definierade konstrueraren initierar inte %q#D"
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ogiltig typ %qT som initierare för en vektor med typ %qT"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "initierare för %qT måste vara inom klamrar"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> använt i en designerad initierare i GNU-stil för klassen %qT"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT har ingen icke-statisk medlem med namnet %qD"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ogiltig initierare för %q#D"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-beteckningen %qE utanför aggregatinitierare"
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "för många initierare för %qT"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "för många klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "klamrar saknas runt initierare för %qT"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "strukturerad bindning har en ofullständig typ %qT"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "element i vektorn %q#T har ofullständig typ"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "sammansatta litteral med variabel storlek"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D har ofullständig typ"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalärt objekt %qD kräver ett element i initieraren"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "i C++98 måste %qD initieras med en konstruerare, inte med %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "vektor %qD initierad från strängkonstant inom parentes %qE"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initierare är ogiltig för statisk medlem med konstruerare"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ej konstant initiering inom klassen av statisk medlem %qD"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ej konstant initiering inom klassen är felaktig för icke inline statisk medlem %qD"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en initiering utanför klassen krävs)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "referensen %qD initieras med sig själv"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "kunde inte hitta en variantdeklaration"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> på konstrueraren %qD"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> på destrueraren %qD"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> på standarddefinierad %qD"
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> på raderad %qD"
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> på virtuell %qD"
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tilldelning (inte initiering) i deklaration"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillåter inte specificeraren %<register%> av lagringsklass"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "specificeraren %<register%> av lagringsklass angiven"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "initieraren för %<decltype(auto) %D%> har funktionstyp; glömde du %<()%>?"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "variabelkoncept har ingen initierare"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skuggar tidigare typdeklaration av %q#D"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%<constinit%> kan bara tillämpas på en variabel med statisk eller trådlagringsvaraktighet"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen %q#D är initierad som en variabel"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "det går inte dekomponera klasstypen %qT för att den har en anonym struct-medlem"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "kan inte dekomponera klasstypen %qT för att den har en anonym unionsmedlem"
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "det går inte att dekomponera en oåtkomlig medlem %qD av %qT"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: både den och dess basklass %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: dess basklasser %qT och %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "strukturerad bindning refererar till ofullständig typ %qT"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u namn angivet för strukturerad bindning"
 msgstr[1] "%u namn angivna för strukturerad bindning"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "endast %u namn angivet för strukturerad bindning"
 msgstr[1] "endast %u namn angivna för strukturerad bindning"
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "medan %qT dekomponeras till %wu element"
 msgstr[1] "medan %qT dekomponeras till %wu element"
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "medan %qT dekomponeras till %E element"
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "i initieringen av variabel %qD i strukturerad bindning"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "det går inte att dekomponera unionstypen %qT"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "det går inte att dekomponera typen %qT som inte är en klass eller vektor"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "det går inte att dekomponera lambdahöljestypen %qT"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "strukturerad bindning refererar till ofullständig klasstyp %qT"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "det går inte att dekomponera klasstypen %qT utan icke-statiska datamedlemmar"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "ickelokal variabel %qD deklarerad %<__thread%> behöver dynamisk initiering"
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "den icke-lokala variabeln %qD deklarerad %<__thread%> har en icke-trivial destruerare"
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> tillåter dynamisk initialisering och destruktion"
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "initierare misslyckas med att bestämma storleken på %qT"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "vektorstorlek saknas i %qT"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "vektor med storlek noll %qT"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruerare för främmande class %qT kan inte vara en medlem"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruerare för främmande klass %qT kan inte vara en medlem"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD deklarerad som en %<virtual%>-variabel"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i variabeldeklaration"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD deklarerad som en %<virtual%>-parameter"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD deklarerad som en %<inline%>-parameter"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i parameterdeklaration"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD deklarerad som en %<virtual%>-typ"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD deklarerad som en %<inline%>-typ"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i typdeklaration"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD deklarerat som ett %<virtual%>-fält"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD deklarerat som ett %<inline%>-fält"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i fältdeklaration"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D deklarerad som en vän"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D deklarerad med en undantagsspecifikationer"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definitionen av %qD är inte i en namnrymd som innesluter %qT"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion %q#D deklarerad med typkvalificerare"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "konceptet %q#D deklarerad med funktionsparametrar"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "konceptet %q#D deklarerat med en härledd returtyp"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "koncept %q#D med icke-%<bool%>-returtyp %qT"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "konceptet %qD har ingen definition"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "ett funktionskoncept kan inte begränsas"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "begränsning av en funktion som inte är en mall"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definierar explicit specialisering %qD i vändeklaration"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ogiltig användning av mall-id %qD i deklaration av primär mall"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardargument är inte tillåtna i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> är inte tillåtet i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "vändeklarationen av %qD anger standardargument och är inte en definition"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "det går inte att deklarera %<::main%> som en mall"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "det går inte att deklarera %<::main%> som inline"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "det går inte att deklarera %<::main%> som %qs"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "det går inte att deklarera %<::main%> som static"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "härledningsguiden %qD måste deklareras med namnrymdsräckvidd"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "härledningsguiden %qD måste deklareras med i samma räckvidd som %qT"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "härledningsguiden %qD får inte ha en funktionskropp"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "litteral operator med C-länkning"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD har en ogiltig argumentlista"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "heltalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "flyttalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "litterala operatorsuffix som inte föregås av %<_%> är reserverade för framtida standardisering"
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD måste vara en icke-medlems-funktion"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> måste returnera %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "omdefinition av implicit deklarerad %qD"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition av explicit standarddefinierad %q+D"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicit standarddefinierad här"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion %q#D deklarerad i klassen %qT"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "det går inte att deklarera %<::main%> som en global variabel"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "en icke-mallvariabel variabel kan inte vara %<concept%>"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+#| msgid "deduction guide %qD must be declared at namespace scope"
+msgid "concept must be defined at namespace scope"
+msgstr "härledningsguiden %qD måste deklareras med namnrymdsräckvidd"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "koncept måste ha typen %<bool%>"
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "ett variabelkoncept kan inte begränsas"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med ofullständig typ"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> behövs för initiering i klassen av statisk datamedlem med icke heltalstyp %q#D"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med icke-litteral typ"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ogiltig initiering i klassen av statisk datamedlem med icke heltalstyp %qT"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ förbjuder initiering inom klassen av icke-konstant statisk medlem %qD"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ förbjuder initiering av medlemskonstant %qD av icke heltalstyp %qT"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "storlek på vektorn %qD av typen %qT är inte en heltalstyp"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "storlek på vektorn av typen %qT är inte en heltalstyp"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "storlek på vektorn %qD är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "storlek på vektorn är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med storlek noll"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ förbjuder vektor med storlek noll"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med variabel längd"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ förbjuder vektor med variabel längd"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "vektor %qD med variabel längd används"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "vektor med variabel längd används"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "spill i vektordimension"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD är deklarerad som en vektor av %qT"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "skapar vektor av %qT"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "deklaration av %qD som en vektor av void"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "skapar vektor av void"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "deklaration av %qD som en vektor av funktioner"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "skapar vektor av funktioner"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "deklaration av %qD som en vektor av referenser"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "skapar vektor av referenser"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "deklaration av %qD som en vektor av funktionsmedlemmar"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "skapar vektor av funktionsmedlemmar"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av %qD som flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "en returtypsspecifikation för konstruerare är ogiltig"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kvalificerare är inte tillåtna vid konstruerardeklaration"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "specifikation av returtyp för destruerare är ogiltigt"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kvalificerare är inte tillåtna vid destruerardeklaration"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "returtyp angiven för %<operator %T%>"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kvalificerare är inte tillåtna på deklaration av %<operator %T%>"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "returtypen angiven för härledningsguiden"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kvalificerare är inte tillåtna på deklaration av härledningsguide"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "mallmallparameter %qT i deklaration av härledningsguide"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> i deklaration av härledningsguide"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "namnlös variabel eller fält deklarerad void"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller fält deklarerad void"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "specificeraren %<inline%> är ogiltig för variabeln %qD deklarerad med blockräckvidd"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline-variabler är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ogiltigt användning av kvalificerat namn %<::%D%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%T::%D%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%D::%D%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T är inte en klass eller namnrymd"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "deklaration av %qE som en icke-funktion"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "deklaration av %qE som icke-medlem"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "deklarerar-id saknas, använder reserverat ord %qD"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktionsdefinition deklarerar inte parametrar"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklaration av %qD som en icke-funktion"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklaration av %qD som %<typedef%>"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "deklaration av %qD som en parameter"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "både %qs och %qs angivna"
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs kan inte förekomma i en typedef-deklaration"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "man kan använda högst en av specificerarna %<constinit%> och %<constexpr%>"
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "två eller fler datatyper i deklaration av %qs"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "motstridande specificerare i deklarationen av %qs"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ förbjuder deklaration av %qs utan typ"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> stödjs inte på denna målarkitektur"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ stödjer inte %<__int%d%> för %qs"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> och %<unsigned%> givna tillsammans"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> och %<short%> angivna tillsammans"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs specificerad med %qT"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs specificerad med %<decltype%>"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs specificerad använd med %<typeof%>"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ogiltig för %qs"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "mallens platshållartyp %qT måste följas av ett enkelt deklarerar-id"
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlem %qD kan inte deklareras både %<virtual%> och %<static%>"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "medlem %qD kan deklareras både %<virtual%> och %<constexpr%> endast i %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-deklaration ogiltig i parameterdeklaration"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklass angiven för mallparameter %qs"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklass angiven för parameter %qs"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "en parameter kan inte deklareras %qs"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> utanför klassdeklaration"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "deklaration av strukturerad bindning får inte vara %qs"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "strukturerade bindningsdeklarationer kan vara %qs endast i %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "%<volatile%>-kvalificerad strukturerad bindning bör undvikas"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "deklaration av strukturerad bindning får inte vara C++98 %<auto%>"
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "deklaration av strukturerad bindning får inte ha typen %qT"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "typen måste vara en cv-kvalificerad %<auto%> eller en referens till en cv-kvalificerad %<auto%>"
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flera lagringsklasser i deklaration av %qs"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "lagringsklass angiven för %qs"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "nästad funktion %qs är deklarerad %<extern%>"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "toppnivådeklaration av %qs anger %<auto%>"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktionsdefinitionsområde %qs implicit auto och deklarerat %<__thread%>"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "ogiltig specificerare av lagringsklass i vänfunktionsdeklarationer"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attributet ignorerat"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "Ett attribut som gäller en viss typspecificerare ignoreras"
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "onödiga parenteser i deklaration av %qs"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "ta port parenteser"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-klausul på returtypen"
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "funktionen %qs använder typspecificeraren %<auto%> utan avslutande returtyp"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "härledd returtyp är endast tillgänglig med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuell funktion kan inte ha härledd returtyp"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %qT som sin typ istället för bara %<auto%>"
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %<decltype(auto)%> som sin typ istället för bara %<auto%>"
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ogiltigt användning av %<decltype(auto)%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "härledd klasstyp %qD i funktionens returtyp"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "härledningsguiden för %qT måste ha en avslutande returtyp"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "den avslutande returtypen %qT hos deduktionsguiden är inte en specialisering av %qT"
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "avslutande returtyp är endast tillgänglig med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "funktionen %qs med avslutande returtyp är inte deklarerad med typspecificeraren %<auto%>"
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<volatile%>-kvalificerad returtyp bör undvikas"
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs är deklarerad som en funktion som returnerar en funktion"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs är deklarerad som en funktion som returnerar en vektor"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<constinit%> på en funktions returtyp är inte tillåtet"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT som en typ snarare en enkel %<decltype(auto)%>"
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> får inte vara cv-kvalificerad"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "destruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "konstruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "destruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "konstruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruerare kan inte deklareras %<virtual%>"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuella funktioner kan inte vara vänner"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "vändeklaration är inte i klassdefinition"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "det går inte att definiera vänfunktion %qs i en lokal klassdefinition"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "vänfunktionsdefinitionen %qs får inte ha ett namn kvalificerat med %<::%>"
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "vänfunktionsdefinitionen %qs får inte ha ett namn kvalificerat med %<%D::%>"
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en konverteringsfunktion kan inte ha en avslutande returtyp"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruerare får inte ha parametrar"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "det går inte att deklarera pekare till %q#T"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "det går inte att deklarera referens till %q#T"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "det går inte att deklarera pekare medlem av %q#T"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "det går inte att deklarera en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "det går inte att deklarera en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "det går inte att deklarera en referens till %q#T, som inte är ett typedef- eller ett malltypargument"
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "mall-id %qD använd som en deklarerare"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner är implicit vänner till sin klass"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "extra kvalifikation %<%T::%> på medlem %qs"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "det går inte att definiera medlemsfunktion %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlemsfunktionen %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlem %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "icke-parameter %qs kan inte vara ett parameterpaket"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem får inte ha variabel typ %qT"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter får inte ha variabel typ %qT"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> utanför klassdeklaration"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> i vändeklaration"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "endast deklarationer av konstruerare och konverteringsoperatorer kan vara %<explicit%>"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "icke-medlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "icke-objektmedlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%<static%> %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%<const%> %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referensen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "typedef kan inte vara en funktionsdefinition"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "typedef får inte vara en medlemsfunktionsdefinition"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> är inte tillåtet i en aliasdeklaration"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef deklarerad %<auto%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-klausul på typedef"
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-namn får inte vara en nästad-namnspecificerare"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ förbjuder nästad typ %qD med samma namn som en omgivande klass"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet för vänklassdeklaration"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "mallparametrar kan inte vara vänner"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "försöker göra klassen %qT en vän med global räckvidd"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ogiltiga kvalificerare på typ som inte är medlemsfunktion"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-klausul på type-id"
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt deklarerare %qT använd som deklaration"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-klausul vid deklaration av icke-funktionstypen %qT"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "det går inte att använda %<::%> i parameterdeklaration"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "det går inte att deklarera en parameter med %<decltype(auto)%>"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "klassmallplatshållaren %qE är tillåten i detta sammanhang"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "använd %<auto%> för en förkortad funktionsmall"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "en %<auto%>-parameter är tillåten i detta sammanhang"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametern deklarerad %<auto%>"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ogiltig användning av mallnamnet %qE utan en argumentlista"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ej statisk datamedlem deklarerad med platshållaren %qT"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ förbjuder den flexibla vektormedlemmen %qs"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ förbjuder flexibla vektormedlemmar"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ogiltigt användning av %<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "deklaration av funktionen %qD i ogiltig kontext"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen %qD deklarerad %<virtual%> inuti en union"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kan inte deklareras %<virtual%>, eftersom den alltid är statisk"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för destruerare %qD"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklaration av %qD som medlem av %qT"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "en destruerare kan inte vara %qs"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%>-destruerare är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för konstruerare %qD"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "en konstruerare kan inte vara %<concept%>"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ett koncept kan inte vara en medlemsfunktion"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD kan inte vara %qs"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering av variabelmall %qD deklarerad som en funktion"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabelmallen är deklarerad här"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "fältet %qD har den ofullständiga typen %qT"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "namnet %qT har ofullständig typ"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "ett namnlöst fält är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "statisk datamedlem %qE deklarerad %qs"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statiska %<constexpr%>-datamedlemmen %qD måste ha en initierare"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "ickestatisk datamedlem %qE deklarerad %qs"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen %<auto%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen %<register%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen %<__thread%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen %<thread_local%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specificerare i %qs är inte tillåtet utanför en klassdefinition"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<static%> är ogiltigt för funktion %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<inline%> är ogiltig för funktionen %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuell icke klassfunktion %qs"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs definierad utan att vara i klassräckvidd"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs deklarerad utan att vara i klassräckvidd"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "det går inte deklarera medlemsfunktionen %qD att ha statisk länkklass"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan inte deklarera en statisk funktion i en annan funktion"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> får inte användas vid definition (till skillnad mot deklaration) av statisk datamedlem"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem %qD deklarerad %<register%>"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "det går inte att deklarera medlem %q#D att ha extern länkklass"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarationen av %<constexpr%>-variabeln %qD är inte en definition"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "en variabel kan inte deklareras %<consteval%>"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarationen av %q#D har ingen initierare"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initierad och deklarerad %<extern%>"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs har både %<extern%> och initierare"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "standardargument %qE använder %qD"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardargument %qE använder lokal variabel %qD"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "felaktig användning av cv-kvalificerad typ %qT i en parameterdeklaration"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "felaktig användning av typen %<void%> i en parameterdeklaration"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<volatile%>-kvalificerad parameter bör undvikas"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD ogiltigt deklarerad metodtyp"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar pekare till vektor %qT med okänd gräns"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar referens till vektor %qT med okänd gräns"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ogiltig konstruerare, du menade förmodligen %<%T (const %T&)%>"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD är kanske inte deklarerad i en namnrymd"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD får inte deklareras som statisk"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD måste vara en icke-statisk medlemsfunktion"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD måste vara antingen en medlemsfunktion som inte är statisk eller funktion som inte är medlem"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD måste ha ett argument med klass- eller uppräkningstyp"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ förhindrar överlagring av %<operator ?:%>"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD får inte ha variabelt antal argument"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD måste ha antingen noll eller ett argument"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD måste ha antingen ett eller två argument"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD måste ha %<int%> som sitt argument"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD måste ha %<int%> som sitt andra argument"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD får inte ha några argument"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD måste ha exakt ett argument"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD måste ha exakt två argument"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kan inte ha standardargument"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konvertering av %qT till %<void%> kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering av %qT till en referens till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konvertering av %qT till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konvertering av %qT till en referens till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konvertering av %qT till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "användardefinierad %qD beräknar alltid båda argumenten"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD skall returnera %qT"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD skall returnera %qT"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD skall returnera som värde"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "malltypparametern %qT används efter %qs"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "användning av aliasmallspecialisering %qT efter %qs"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-namnet %qD används efter %qs"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD har en tidigare deklaration här"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT refererad till som %qs"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT har en tidigare deklaration här"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT refererad till som enum"
@@ -50383,105 +50441,105 @@ msgstr "%qT refererad till som enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "mallargument krävs för %<%s %T%>"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referens till %qD är tvetydig"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD har samma namn som klassen den är deklarerad i"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT är inte en mall"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "kanske du vill explicit lägga till %<%T::%>"
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "enum %q#D används utan tidigare deklaration"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "omdeklaration av %qT som en icke-mall"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, gcc-internal-format
 msgid "cannot declare %qD in a different module"
 msgstr "det går inte att deklarera %qD i en annan modul"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "härledd unionen %qT ogiltig"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT definierad med flera direkta baser"
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT definierad med en direkt virtuell bas"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "bastyp %qT är ingen post- eller klasstyp"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiv typ %qT odefinierad"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "upprepat bastyp %qT ogiltig"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "uppräkningstyp med/utan räckviddsbegränsning stämmer inte överens för enum %q#T"
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidigare definition här"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "underliggande typ stämmer inte överens i enum %q#T"
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "olika underliggande typ i enum %q#T"
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr "det går inte att definiera %qD i en annan modul"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
@@ -50490,77 +50548,77 @@ msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ingen heltalstyp kan representera alla uppräkningsvärdena i %qT"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "uppräkningsvärde för %qD är inte en heltalstyp eller uppräkningstyp utan räckviddsbegränsning"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "uppräkningsvärde för %qD är inte en heltalskonstant"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<unsigned long%>"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<long%>"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "överspill i uppräkningsvärden vid %qD"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "uppräkningsvärdet %qE är utanför intervallet för den underliggande typen %qT"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "fler definitioner av %q#T"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "returtypen %q#T är ofullständig"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> skall returnera en referens till %<*this%>"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "inga retursatser i funktion som returnerar %qT"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "endast enkel returtyp %<auto%> kan härledas till %<void%>"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "ingen retursats i %<constexpr%>-funktion som returnerar icke-void"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD är redan definierad i klassen %qT"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "användning av %qD före härledning av %<auto%>"
@@ -50600,7 +50658,7 @@ msgstr "det går inte att radera en funktion.  Endast pekare till objekt är gil
 msgid "deleting %qT is undefined"
 msgstr "radera %qT är odefinierat"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malldeklaration av %q#D"
@@ -50610,7 +50668,7 @@ msgstr "malldeklaration av %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "mallparameterlistan som ges stämmer inte mallparametrarna till %qD"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destrueraren %qD deklarerad som medlemsmall"
@@ -50935,22 +50993,22 @@ msgstr "för att %qT har användarlevererad %qD"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterar lambda som använder %<...%> till funktionspekare"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "användning av borttagen funktion %qD"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "användning av funktionen %qD med ej uppfyllda begränsningar"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "användning av det inbyggda parameterpaketet %qD utanför en mall"
@@ -51055,7 +51113,7 @@ msgstr "referens till %<%T::%D%> är tvetydig"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD är inte en medlem av %qT; menade du %qs?"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD har inte en medlem av %qT"
@@ -51065,7 +51123,7 @@ msgstr "%qD har inte en medlem av %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD är inte en medlem av %qD; menade du %qs?"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD är inte en medlem av %qD"
@@ -51251,408 +51309,408 @@ msgstr "värdeinitiering av referenstypen %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "rekursiv instansiering av standardmedleminitierare för %qD"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "standardmedlemsinitieraren för %qD behövs före slutet på dess omgivande klass"
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "initierare för flexibel vektormedlem %q#D"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr "initiering av %qD från %qE utökar inte livslängden på den underliggande vektorn"
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD skall initieras i medlemsinitieringslistan"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD initieras med sig själv"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ogiltig initierare för vektormedlem %q#D"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "oinitierad const-medlem i %q#T"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D borde initieras"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "oinitierad referensmedlem i %q#T"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD kommer initieras efter"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "basen %qT kommer initieras efter"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  basen %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  vid initiering här"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "flera initieringar givna för %qD"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "flera initieringar givna för basen %qT"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "initiering av flera medlemmar av %qT"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "basklass %q#T skulle varit explicit initierad i kopieringskonstrueraren"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "klass %qT har inget fält med namnet %qD"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D är en statisk datamedlem; den kan endast initieras vid sin definition"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D är inte en icke-statisk datamedlem i %qT"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "namnlös initierare för %qT, som inte har några basklasser"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "namnlös initierare för %qT som använder multipelt arv"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD är både en direkt bas och en indirekt virtuell bas"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "typ %qT är inte en direkt eller virtuell bas till %qT"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "typ %qT är inte en direkt bas till %qT"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "vektorer måste initieras med en initierare inom klamrar"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT är inte en klasstyp"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "ofullständig typ %qT har inte medlem %qD"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ogiltigt pekare till bitfält %qD"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion %qD"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ogiltig användning av icke-statisk datamedlem %qD"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "oinitierad referensmedlem i %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "oinitierad referensmedlem i basen %q#T till %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "oinitierad referensmedlem i basen %q#T till %q#T"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "oinitierad const-medlem i %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "oinitierad const-medlem i basen %q#T till %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "oinitierad const-medlem i basen %q#T till %q#T"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar ett objekt av typen %<%T [%wu]%> och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "placerande new konstruerar ett objekt av typen %<%T [%wu]%> och storleken %qwu i en region av typen %qT och storleken högst %qwu"
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar en vektor av objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "placerande new konstruerar en vektor av objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken högst %qwu"
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar ett objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr "placerande new konstruerar ett objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken högst %qwu"
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr "vid avståndet %wi från %qD deklarerad här"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "vid avståndet [%wi, %wi] från %qD deklarerad här"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "heltalsspill i vektorstorlek"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "vektorstorlek i new-uttryck måste vara en konstant"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "variabelt ändrad typ inte tillåten i new-uttryck"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "en ny längd för en icke-konstant vektor måste anges direkt, inte av %<typedef%>"
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "new-längden för en icke-konstant vektor måste anges utan parenteserna runt typ-id:t"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "ogiltig typ %<void%> för %<new%>"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "%<new%> av %<initializer_list%> utökar inte livslängden på den underliggande vektorn"
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "oinitierad const i %<new%> av %q#T"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "ingen lämplig %qD i klassen %qT"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "begäran av medlem %qD är tvetydig"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> av typ %qT med utökad justering %d"
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "använder %qD, som inte har någon justeringsparameter"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "använd %<-faligned-new%> för att aktivera stöd för C++17 överjusterade new"
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "initierare inom parentes i vektor-new"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "storlek i vektor-new måste ha heltalstyp"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new kan inte användas på en referenstyp"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new kan inte användas på en funktionstyp"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "möjligt problem upptäckt vid anrop av operatorn %<delete []%>"
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika operatorn %<delete []%> kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "initierare tar slut i förtid"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "okänd vektorstorlek i delete"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "möjligt problem upptäckt vid anrop av %<operator delete%>"
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika %<operator delete%> kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "radering av objekt av den abstrakta klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "radering av objekt av den polymorfa klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "typ till vektor-delete är varken pekar- eller vektortyp"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr "vektor- och körtidsgränser kan inte fångas av kopiering, endast via referens"
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "fångst av den variabelt modifierade typen %qT som inte är en N3639-vektor av körtidsgräns"
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "eftersom vektorelementtypen %qT har variabel storlek"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "det går inte att fånga %qE via referens"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "fångst av kopia av ofullständig typ %qT"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr "försök att fånga %qD i instansiering av en generisk lambda"
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr "implicit fångst av %qE via %<[=]%> bör undvikas i C++20"
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr "lägg till explicit fångst av %<this%> eller %<*this%>"
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> fångades inte för denna lambdafunktion"
@@ -51707,62 +51765,62 @@ msgstr "det finns inga argument till %qD som beror på en mallparameter, så en
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(om du använder %<-fpermissive%>, kommer G++ acceptera din kod, men man bör undvika att tillåta användning av ett odeklarerat namn)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr "manglar %<typeof%>, använd %<decltype%> istället"
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr "manglar %<__underlying_type%>"
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "manglar okänd fixdecimaltyp"
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "användning av inbyggd egenskap %qE i funktionssignatur; använd biblioteksegenskaper istället"
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "manglar %C"
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "utelämnad mittenoperand till %<?:%> kan inte manglas"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "det manglade namnet för %qD kommer ändras i C++17 eftersom undantagsspecifikationen är en del av funktionstypen"
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "det manglade namnet på %qD ändrades mellan %<%s=%d%> (%qD) och %<%s=%d%> (%qD)"
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "det manglade namnet på %qD ändras mellan %<%s=%d%> (%qD) och %<%s=%d%> (%qD)"
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "det manglade namnet på en snutt för %qD ändras mellan %<-fabi-version=%d%> och %<-fabi-version=%d%>"
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "det manglade namnet på %qD ändras mellan %<-fabi-version=%d%> och %<-fabi-version=%d%>"
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "det manglade namnet på initieringsvaktsvariabeln för %qD ändras mellan %<-fabi-version=%d%> och %<-fabi-version=%d%>"
@@ -51943,301 +52001,301 @@ msgstr "%q#D är underförstått borttagen eftersom standarddefinitionen skulle
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F tas implicit bort för att dess undantagsspecifikation stämmer inte med den implicita undantagsspecifikationen %qX"
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "standarddeklaration %q+D stämmer inte med den förväntade signaturen"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "förväntad signatur: %qD"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "den explicit standarddefinierade funktionen %q+D kan inte deklareras som %qs för att den implicita deklarationen är inte %qs:"
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "en mall kan inte standarddefinieras"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD kan inte standarddefinieras"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "standarddefinierad funktion %q+D med standardargument"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "omdeklaration av %q#D med andra mallparametrar"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D står i konflikt med tidigare deklaration"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D döljer konstruerare för %q#D"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "motstridande deklaration av C-länkning av %q#D"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "på grund av olika undantagsspecifikationer"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "lambdaparametern %qD är deklarerad tidigare som en fångst"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "deklaration av %q#D skuggar en parameter"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "deklarationen av %qD skuggar en medlem av %qT"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "vändeklaration %qD i lokal klass utan en tidigare lokal deklaration"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "%q#D har inte extern länkning"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D är deklarerad här"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T%s%D%> namnger en destruerare"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-deklaration för icke-medlem vid klassräckvidd"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> med uppräkningsräckvidd %q#T är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT är inte en klass, namnrymd eller uppräkning"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "icke-medlems using-deklaration namnger konstrueraren för %qT"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "using-deklaration för medlem vid icke-klass-räckvidd"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%qT är inte en direkt bas till %qT"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "menade du %<using enum %T::%D%>?"
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD har inte deklarerats i %qD"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "en using-deklaration får inte namnge namnrymden %qD"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> namnger konstruerare i %qT"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklaration av %qD inte i namnrymd som omger %qD"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explicit-kvalifikation i deklaration av %qD"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD borde ha deklarerats inuti %qD"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD har inte deklarerats inom %qD"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "endast här som %<friend%>"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "attributet %qD kräver ett ensamt NTBS-argument"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "attributet %qD är meningslöst eftersom medlemmar av den anonyma namnrymden får lokala symboler"
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "ignorerar attributet %qD på en anonym namnrymd"
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "ignorerar attributet %qD på en namnrymd som inte är inline"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attributdirektivet %qD ignorerat"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "maxgräns på %d namnrymder sökta %qE"
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "föreslaget alternativ:"
 msgstr[1] "föreslagna alternativ:"
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%<std::%s%> är definierad i huvudet %qs; glömde du %<#include %s%>?"
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> är bara tillgänglig från %s och framåt"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "makrot %qs har inte definierats ännu"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "det definierades senare här"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "definitionen av %<std::initializer_list%> matchar inte %<#include <initializer_list>%>, är inte en mall"
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "ett %<strong%> using-direktiv stödjs inte längre"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "du kan använda en inline-namnrymd istället"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "det går inte att nästa mer än %d namnrymder"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> är tvetydig"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namnrymdsalias %qD inte tillåtet här, antar %qD"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "inline-namnrymder måste anges vid den ursprungliga definitionen"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD definierades här"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%s-namnrymd %qD står i konflikt med nåbar definition"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "nåbar %s-definition här"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX går in i %<pop_everything ()%>"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX lämnar %<pop_everything ()%>"
@@ -52262,7 +52320,7 @@ msgstr "identifieraren %qE är ett nyckelord i C++20"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> är inte satt till true"
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> som inte omedelbart följs av en funktionsdeklaration eller -definition"
@@ -52287,7 +52345,7 @@ msgstr "%<::%E%> har inte deklarerats"
 msgid "request for member %qE in non-class type %qT"
 msgstr "begäran av medlem %qE i typ %qT som inte är en klasstyp"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> har inte deklarerats"
@@ -52367,7 +52425,7 @@ msgstr "ogiltigt mall-id"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ förbjuder användning av en flyttalslitteral i ett konstantuttryck"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "en typomvandling till en annan typ än en heltals- eller uppräkningstyp kan inte förekomma i ett konstantuttryck"
@@ -52503,7 +52561,7 @@ msgstr "C++20 %<constinit%> är endast tillgängligt med %<-std=c++20%> eller %<
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> är endast tillgängligt med %<-std=c++20%> eller %<-fconcepts%>"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<requires%> är endast tillgängligt med %<-std=c++20%> eller %<-fconcepts%>"
@@ -52628,7 +52686,7 @@ msgstr "kan inte hitta en stränglitteraloperator %qD med argumenten %qT, %qT"
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr "globala modulfragments innehåll måste komma från preprocessorinkludering"
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "en deklaration förväntades"
@@ -52678,7 +52736,7 @@ msgstr "satsuttryck är inte tillåtna utanför funktioner eller i mallargumentl
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "vikningsuttryck är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "primäruttryck förväntades"
@@ -52708,7 +52766,7 @@ msgstr "räckvidd %qT före %<~%> är inte ett klassnamn"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "nyckelordet %<template%> är tillåtet i destruerarnamn"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%<~auto%> är endast tillgängligt med %<-std=c++14%> eller %<-std=gnu++14%>"
@@ -52728,12 +52786,12 @@ msgstr "deklaration av %<~%T%> som medlem av %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-namnet %qD använt som destruerardeklarerare"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "okvalificerat id förväntades"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD är inte en mall"
@@ -52768,7 +52826,7 @@ msgstr "variabelmall-id %qD i nästad namnspecificerare"
 msgid "expected nested-name-specifier"
 msgstr "nästat namn-specificerare förväntades"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "typer får inte definieras i typkonverteringar"
@@ -52783,7 +52841,7 @@ msgstr "typer får inte definieras i ett %<typeid%>-uttryck"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "fel antal argument till %<__builtin_addressof%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "fel antal argument till %<__builtin_launder%>"
@@ -52798,1113 +52856,1119 @@ msgstr "ISO C++ förbjuder sammansatta litteraler"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "två på varandra följande %<[%> får bara introducera ett attribut"
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ogiltigt användning av %qD"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> är inte en klassmedlem"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "icke skalär typ"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tillåter inte %<alignof%> med annat än en typ"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "typer får inte definieras i %<noexcept%>-uttryck"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "typer får inte definieras i en %qs-uttryck"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr "%<__builtin_has_attribute%> med beroende argument stödjs inte ännu"
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "typer får inte definieras i en new-uttryck"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "vektorgräns är förbjuden efter typ-id i parenteser"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "försök ta bort parenteserna runt typ-id:t"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "initiering av new-uttryck för typen %<auto%> tar precis ett element"
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "uttryckslista eller typ-id förväntades"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "typer får inte definieras i en new-type-id"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "uttryck i new-deklarerare måste ha heltals- eller uppräkningstyp"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "användning av gammaldags typkonvertering till %q#T"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "operatorn %<>>%> hanteras som två högervinkelparenteser i C++11"
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "föreslår parenteser runt %<>>%>-uttryck"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ tillåter inte %<?:%> med mellersta operanden utelämnad"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "kommauttryck på toppnivå i vektorindex bör undvikas"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "typer får inte definieras i %<__builtin_offsetof%>"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+#| msgid "definition of %q#T inside template parameter list"
+msgid "lambda-expression in template parameter type"
+msgstr "definition av %q#T inuti mallparameterlista"
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambdauttryck i oberäknade sammanhang är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambdauttryck i mallargument är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "icke-lokala lambda-uttryck kan inte ha en standardfångst"
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "slut på fångstlista förväntades"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "explicit fångst via kopiering av %<this%> överflödigt med standardfall av fångst via kopiering"
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "redan infångad %qD i lambdauttryck"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fångst av %<*this%> är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "det går inte att fånga %<this%> via referens"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "pack init-fångst är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr "%<&%> skall komma före %<...%>"
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambdafångstinitierare är endast tillgängliga med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "tom initierare för lambdas init-fångst"
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "fångst av en icke-variabel %qE"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "fångst av variabeln %qD med ej automatisk lagringsvaraktighet"
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "för många %<...%> i lambdafångst"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "explicit fångst via kopiering av %qD överflödigt vid standardfångst via kopiering"
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "explicit fångst via referens av %qD överflödigt med standardfångst via referens"
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambdamallar är endast tillgängliga med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambdamallar är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "standardargumentet angivet för lambdaparameter"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "en parameterdeklaration före lambdadeklarationsspecificerare är endast valfritt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "dubblerad %<mutable%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "en parameterdeklaration före lambdatransaktionskvalificerare är endast valfritt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "en parameterdeklaration före en lambdaundantagsspecifikation är endast valfritt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "en parameterdeklaration före lambdas efterföljande returtyp är endast valfritt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<constexpr%> lambda är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "attribut vid början av satser ignoreras"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "etikettsats förväntades"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-etikett %qE är inte i en switch-sats"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> behövs före %qE för att %qT är en beroende räckvidd"
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> namnger konstrueraren, inte typen"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "sammansatt sats i en %<constexpr%>-funktion"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<if constexpr%> är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "init-satsen i valsatser är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "selektionssats förväntades"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr "villkor deklarerar en vektor"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr "villkor deklarerar en funktion"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "typer får inte definieras i villkor"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initierare förväntades"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr "slingvariabeln %qD av typen %qT binder till en temporär konstruerad från typen %qT"
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr "använd icke-referens-typ %qT för att göra kopieringen explicit eller %qT för att förhindra kopiering"
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "slingvariabeln %qD skapar en kopia från typen %qT"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr "använd referenstyp för att förhindra kopiering"
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "intervallbaserat %<for%>-uttryck av typen %qT har ofullständig typ"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "inkonsistenta start-/sluttyper i intervallbaserad %<for%>-sats: %qT och %qT"
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "iterationssats förväntades"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "intervallbaserade %<for%>-slingor med initierare är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "intervallbaserad %<for%>-slinga är endast tillgänglig med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> i %<constexpr%>-funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ förbjuder beräknade goto"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "hoppsats förväntades"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, gcc-internal-format
 msgid "expected module-name"
 msgstr "modulnamn förväntades"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr "en moduldeklaration är inte tillåtet i en huvudenhet"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr "privata modulfragment är endast tillåtna inom räckvidden för modulgränssnittet eller -partitionen"
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, gcc-internal-format
 msgid "private module fragment"
 msgstr "privat modulfragment"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr "moduldeklarationer är endast tillåtna som första deklaration, eller som avslutning av ett globalt modulfragment"
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr "post-modul-deklarations-importer måste vara sammanhängande"
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr "kanske infoga en radbrytning, eller annat sätt att särskilja, för att förhindra att detta betraktas om en modul-styr-rad"
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr "import-deklaration måste vara på global räckvidd"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "import får inte förekomma direkt i en länkningsspecifikation"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr "post-modul-deklarations-importer får inte vara include-översatta"
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr "post-modul-deklarations-importer får inte vara från huvudinkludering"
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr "%qE får endast förekomma efter en modulgränssnittsdeklaration"
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr "%qE får bara förekomma en gång i en exportdeklaration"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr "%<export%> är inte del av ett följande moduldirektiv"
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "attribut är inte tillåtna på denna position"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr "attribut får infogas här"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "extra %<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> som inte inleder ett block"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "icke-variabel %qD i deklaration med mer än en deklarerare med platshållartyp"
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "inkonsistent härledning för %qT: %qT och sedan %qT"
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "att blanda deklarationer och funktionsdefinitioner är förbjudet"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "typer får inte definieras i en for-range-deklaration"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initierare i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flera deklarationer i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "strukturerade bindningar är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "tom deklaration av strukturerad bindning"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ogiltig initierare för deklaration av strukturerad bindning"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> använd utanför en klass"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "nyckelordet %<bool%> är inte tillåtet i en C++20 konceptdefinition"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr "syntaxen för en C++20 konceptdefinition är %<concept <namn> = <uttr>%>"
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> ändrar betydelse i C++11; var god ta bort det"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%<decl-specifier%> är ogiltigt i ett villkor"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD är ogiltigt i lambda"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "typspecificerare är ogiltig i lambda"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "klassdefinition kan inte deklareras som en vän"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallar får inte vara %<virtual%>"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "typer får inte definieras i en explicit-specificerare"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<explicit(bool)%> är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ogiltig länkklasspecifikation"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<static_assert%> utan ett meddelande är endast tillgänglig med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "typspecificeraren %<decltype(auto)%> är endast tillgängligt med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "typer får inte definieras i %<decltype%>-uttryck"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "typer får inte definieras i en conversion-type-id"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ogiltig användning av %<auto%> i konverteringsoperator"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "användning av %<auto%> i medlemsmallskonverteringsoperator kan aldrig vara härledd"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "endast konstruerare tar medlemsinitierare"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "det går inte att expandera initierare för medlem %qD"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "minnesinitierare för %qD följer en konstruerardelegering"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "konstruerardelegering följer mem-initierare för %qD"
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anakronistisk gammaldags basklassinitierare"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (en kvalificerad medlemsinitierare är implicit en typ)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "oväntat nyckelord; ta bort mellanrum mellan citationstecken och suffixidentifierare"
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "suffixidentifierare förväntades"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "en tom sträng förväntades efter nyckelordet %<operator%>"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ogiltigt kodningsprefix i litteral operator"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operator förväntades"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "nyckelordet %<export%> är inte implementerat och kommer ignoreras"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "nyckelordet %<export%> bör undvikas, och ignoreras"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr "nyckelordet %<export%> är aktiverat med %<-fmodules-ts%>"
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ogiltig begränsad typparameter"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-kvalificerad typparameter"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "felaktig användning av %<auto%> i standardmallargument"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "mallparameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "mallparameterpaket kan inte ha standardargument"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "mall-id förväntades"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kan inte inleda en argumentlista till en mall"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> är en alternativ stavning av %<[%>.  Lägg in mellanrum mellan %<<%> och %<::%>"
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(om du använder %<-fpermissive%> eller %<-std=c++11%> eller %<-std=gnu++11%> kommer G++ acceptera din kod)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "felaktig mallargumentlista"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr "ett funktionsnamn som vänster operand av %<<%> är felformad i C++20; slå in funktionsnamnet i %<()%>"
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<(%> förväntades efter mallargumentlista"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "parsningsfel i mallargumentlista"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "mallnamn förväntades"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "icke-mall %qD använd som mall"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "använd %<%T::template %D%> för att indikera att det är en mall"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "parameterpaket förväntades före %<...%>"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "mallargument förväntades"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ogiltigt mallargument som inte är en typ"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "en explicit instansiering skall inte använda %<inline%>-specificerare"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "en explicit instansiering skall inte använda %<constexpr%>-specificerare"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "en explicit instansiering skall inte använda %<consteval%>-specificerare"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "mallspecialisering med C-länkning"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "användning av %<auto%> i lambdaparameterdeklarationer är endast tillgängligt med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med %<-fconcepts-ts%>"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "mall-id för typ förväntades"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "typnamn förväntades"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE begränsar inte en typ"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr "konceptet är definierat här"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<auto%> eller %<decltype(auto)%> förväntades efter %qE"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr "oväntad platshållare i en begränsad resultattyp"
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "beräknad typspecifikation för en enum med räckvidd får inte använda nyckelordet %qD"
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%<template%> måste följa en nästad-namnspecificerare"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklaration %qD deklarerar inte något"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributet ignorerat på oinstansierad typ"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attribut ignoreras vid mallinstansiering"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attribut ignoreras för bearbetade typspecificerare som inte är en framåtdeklaration"
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD är en uppräkningsmall"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD är inte namnet på en uppräkningstyp i %qT"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "namnlös enum med räckvidd är inte tillåtet"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> eller %<{%> förväntades"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "det går inte att lägga till en uppräkningslista till en mallinstansiering"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "nästad namnspecificerare %qT för enum-deklaration som inte namnger en klass eller namnrymd"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "deklaration av %qD i namnrymd %qD som inte innesluter %qD"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "deklaration av %qD i %qD som inte innesluter %qD"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "extra kvalifikation inte tillåten"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ förbjuder tomma namnlösa enum"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "ogenomskinlig enum-specifikation utan namn"
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "en ogenomskinlig enum-specifikation måste använda en enkel identifierare"
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD är inte ett namnrymdsnamn; menade du %qs?"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD är inte ett namnrymdsnamn"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "namnrymdsnamn förväntades"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "nästade inline-namnrymdsdefinitioner är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr "standardattribut på namnrymder måste föregå namnrymdsnamnet"
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "nästade namnrymdsdefinitioner är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "nästat namnrymdsnamn krävs"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "namnrymdsnamn krävs"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "en nästad namnrymdsdefinition kan inte ha attribut"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "en nästad namnrymdsdefinition kan inte inline:as"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "gick in i namnrymden %qD"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-definition är inte tillåten här"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "paketexpansion i using-deklaration är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ett mall-id får inte förekomma i en using-deklaration"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "en kommaseparerad lista i using-deklaration är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "åtkomstdeklarationer bör undvikas till förmån för using-deklarationer; förslag: lägg till nyckelordet %<using%>"
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "ogenomskinlig enum-deklaration här"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "typer får inte definieras i aliasmalldeklarationer"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<asm%> i en %<constexpr%>-funktion är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "dubblerad %<asm%>-kvalificerare %qT"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%<asm%>-kvalificeraren %qT ignoreras utanför en funktionskropp"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT är inte en %<asm%>-kvalificerare"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%<asm%>-kvalificerare utanför funktionskropp"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "tvetydigheten i tomma parenteser löstes upp som en funktionsdeklaration"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr "ta bort parenteser för att standardinitiera en variabel"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr "eller ersätt parenteser med klamrar för att aggregatinitiera en variabel"
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr "eller ersätt parenteser med klamrar för att värdeinitiera en variabel"
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, gcc-internal-format
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "tvetydigheten i parenteser löstes upp som en funktionsdeklaration"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr "ersätt parenteser med klamrar för att deklarera en variabel"
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr "lägg till parenteser för att deklarera en variabel"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "en funktionsdefinition är inte tillåten här"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "en %<asm%>-specifikation är inte tillåten på en funktionsdefinition"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "attribut är inte tillåtna vid en funktionsdefinition"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "konstruerare, destruerare eller typkonvertering förväntades"
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initierare angiven för funktion"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attribut efter initierare inom parentes ignoreras"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "icke-funktionen %qD deklarerad som implicit mall"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "vektorgräns är inte en heltalskonstant"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "det går inte att definiera medlem av beroende typedef %qT"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> är inte en typ"
@@ -53913,430 +53977,430 @@ msgstr "%<%T::%E%> är inte en typ"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ogiltig deklarator"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ogiltig användning av konstruerare som en mall"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "använd %<%T::%D%> istället för %<%T::%D%> för att namnge konstrueraren i ett kvalificerat namn"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "kvalificerad id i deklaration"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "deklarator förväntades"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD är en namnrymd"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "kan inte skapa en pekare till medlem av %q#T som inte är en klass"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "oväntad pekaroperator"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "upprepade cv-kvalificerare"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "upprepade ref-kvalificerare"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE kräver %<-fgnu-tm%>"
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "upprepade virt-specificerare"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "mallargument saknas efter %qT"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr "%qT är inte tillåtet i mallargument"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ogiltigt användning av %qT"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "typer får inte definieras i mallargument"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "felaktig användning av %<auto%> i mallargument"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> eller %<...%> förväntades"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "typer får inte definieras i parametertyper"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardargument är endast tillåtna för funktionsparametrar"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "mallparameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "funktions-try-blockskropp av %<constexpr%>-konstruerare är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "funktions-try-blockskropp av %<constexpr%>-funktioner är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++ designerade initierare är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tillåter inte GNUs designerade initierare"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillåter inte C99:s designerade initierare"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "antingen skall alla initierarklausuler vara designerade eller så skall ingen av dem vara det"
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> är inte tillåtet i en designerad initierarlista"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "designeraren %<.%s%> använd flera gånger i samma initierarlista"
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "klassnamn förväntades"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> förväntades efter klassdefinition"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> förväntades efter postdefinition"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> förväntades efter uniondefinition"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> eller %<:%> förväntades"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "det går inte att ange %<override%> för en klass"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globala kvalificering av klassnamn är ogiltigt"
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "kvalificerat namn namnger inte en klass"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "nyckelordet %<template%> är inte tillåtet i klasshuvudnamn"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ogiltigt klassnamn i deklaration av %qD"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "en explicit specialisering måste föregås av %<template <>%>"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktionsmall %qD omdeklarerad som en klassmall"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "det gick inte att lösa upp typnamnstyp"
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "föregående definition av %q#T"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "klassnyckel förväntades"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ISO C++ förbjuder nyckelordet typename i mall-mall-parameter; använd %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> eller %<typename%> förväntades"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "i C++03 måste en klassnyckel användas när en vän deklareras"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "vändeklaration som inte namnger en klass eller funktion"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "en lagringklass på ett anonymt aggregat i klassräckvidd tillåts inte"
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "standardmedlemsinitierare för bitfält är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "standardmedlemsinitierare för namnlöst bitfält"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ tillåter endast bitfältsattribut före symbolen %<:%>"
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bitfältet %qD har icke-heltalstypen %qT"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-specificerare på funktionsdefinition"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "extra %<;%> efter funktionsdefinition i klassen"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "överblivet %<,%> vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> förväntades vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ogiltig pure-specificerare (endast %<= 0%> är tillåtet)"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "en klammeromsluten initierare är inte tillåten här"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> anges mer än en gång i basspecificerare"
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "mer än en åtkomstspecifikation i basspecificerare"
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "nyckelordet %<typename%> är inte tillåtet utanför mallar"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (basklassen är implicit en typ)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "typer får inte definieras i en undantagsspecifikation"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 tillåter inte dynamiska undantagsspecifikationer"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamiska undantagsspecifikationer undanbedes i C++11"
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ogiltig användning av %<auto%> i undantagsspecifikation"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<try%> i %<constexpr%>-funktioner är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "typer får inte definieras i undantagsdeklarationer"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "attribut som använder prefix använt tillsammans med attributsymboler med räckvidd"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "en identifierare förväntades som attributnamn"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr "parenteser måste utelämnas om argumentlistan till attributet %qE är tom"
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr "attributet %qs angivet flera gånger"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut förväntades före %<...%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribut som använder prefix är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "uttrycket måste vara inneslutet i parenteser"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "ytterligare %<requires%> saknas för att inleda ett requires-uttryck"
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "resultattypen är inte en enkel typbegränsning"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "returtypskravet är inte en typbegränsning"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "specialisering av medlem %<%T::%E%> kräver %<template<>%>-syntax"
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ogiltig omdeklaration av %<%T::%E%>"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "för få mallparameterlistor"
@@ -54345,757 +54409,757 @@ msgstr "för få mallparameterlistor"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "för många mallparameterlistor"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "namngivna returvärden stödjs inte längre"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "ISO C++ antog inte mallar för stränglitteralsoperatorer som tar argumentpaket av tecken"
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista; ett mallargument som inte är en typ pack %<<char...>%> eller en ensam icke-typparameter av klasstyp förväntades"
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista; en mallparameter som inte är en typ pack %<<char...>%> förväntades"
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr "mallintroduktioner är inte en del av C++20 koncept; använd %qs för att aktivera"
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "det finns inget matchande koncept för mallintroduktionen"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ogiltig deklaration av medlemsmall i lokal klass"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "mall med C-länkning"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ogiltig explicit specifikation"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malldeklaration av %<typedef%>"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "en klassmallsdeklaration får inte deklarera något annat"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explicit mallspecialisering kan inte ha en lagringsklass"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> skulle vara %<> >%> inuti en nästad mallargumentlista"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "vilsekommet %<>>%>, använd %<>%> för att avsluta en mallargumentlista"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "argument till %<sizeof...%> måste omges av parenteser"
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ogiltig användning av %qD i länkklasspecifikation"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> före %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 stödjer inte %<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "både %<__thread%> och %<thread_local%> angivna"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "dubblerad %qD"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "dubblerad %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> förväntades"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> förväntades"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> förväntades"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> förväntades"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> förväntades"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> förväntades"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> förväntades"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> förväntades"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> förväntades"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> förväntades"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> förväntades"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> förväntades"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> förväntades"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> förväntades"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> förväntades"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<auto%> förväntades"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> förväntades"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> förväntades"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> förväntades"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> förväntades"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> förväntades"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> förväntades"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<co_yield%> förväntades"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> förväntades"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> förväntades"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> förväntades"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> förväntades"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> eller %<::%> förväntades"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> eller %<template%> förväntades"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "överflödig enum-nyckel %<enum%s%> i referens till %q#T"
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs-tagg använd vid namngivning av %q#T"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T deklarerades tidigare här"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "överflödig klassnyckel %qs i referens till %q#T"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT är deklarerad med en klassnyckel som inte stämmer %qs"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "ta bort klassnyckeln eller ersätt den med %qs"
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "ersätt klassnyckeln med %qs"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT är definierad som %qs här"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT är först deklarerad som %qs här"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omdeklarerad med annan åtkomst"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "i C++98 är %<template%> (för att lösa upp tvetydighet) är endast tillåtet inuti mallar"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "filen slutar i standardargument"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "felplacerad Objective-C++-konstruktion %<@%D%>"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++-meddelandemottagare förväntades"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++-meddelandeargument förväntades"
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> måste ange en typ som ett argument"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "ogiltigt Objective-C++-väljarnamn"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "metoddeklaration i objective-c++ förväntades"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "metodattribut måste anges på slutet"
 
 # %qs blir "{" eller "}"
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "vilsekommet %qs mellan Objective-C++ metoder"
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ogiltig typ för iterationsvariabel"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identifierare förväntades efter %<@protocol%>"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "attribut får inte anges före Objective-C++-nyckelordet %<@%D%>"
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefixattribut ignoreras före %<@%D%>"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ogiltig typ på egenskap"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "okänt egenskapsattribut %qE"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "heltalsuttryckslista förväntades"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-uttryck måste vara heltal"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ogiltig reduktionsidentifierare"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "typer får inte definieras i iteratortyp"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "initiering i parenteser är inte tillåtet i en OpenMP-%<for%>-slinga"
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "en %<ordered%>-klausul med parameter på en intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterationsvariabel %qD skall inte vara reduction"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "inte tillräckligt med for-slingor att kollapsa"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> följt av %<#pragma omp declare %s%>"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ogiltig initierarklausul"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "id-uttryck förväntades (argument)"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "en av initieraranropets argument skall vara %<omp_priv%> eller %<&omp_priv%>"
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "typer får inte definieras i en declare reduction-typlista"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "en fördeklarerad aritmetisk typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "funktions- eller vektortyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "referenstyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "%<const%>-, %<volatile%>- eller %<__restrict%>-kvalificerad typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> namnger en mängd överlagrade"
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD refererar inte till en funktion med namnrymdsräckvidd"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "yttre %<__transaction_cancel%> som inte är inom en yttre %<__transaction_atomic%>"
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "felformat %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp requires%> kan endast användas med fil- eller namnrymdsräckvidd"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> måste vara inuti en funktion"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> måste vara inuti en funktion"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "flerkällskompileringar är inte implementerade för C++"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "en platshållartyp är inte tillåtet i denna kontext"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "implicita mallar får inte vara %<virtual%>"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-länkning startade här"
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "datamedlem %qD kan inte vara en medlemsmall"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "ogiltig medlemsmalldeklaration %qD"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "explicit specialisering som inte är i namnrymdsområde %qD"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "inneslutande klassmallar är inte explicit specialiserade"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "specialisering av %qD i förekomma i namnrymdsräckvidd"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "specialisering av %qD i en annan namnrymd"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  från definitionen av %q#D"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "explicit instansiering av %qD i namnrymden %qD (som inte omsluter namnrymden %qD)"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "namn på klass skuggar mallmallparameter %qD"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "specialisering av aliasmall %qD"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "explicit specialisering av icke-mall %qT"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "specialisering av %qT efter instansiering"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "från definitionen av %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "specialisering %qT efter instansiering %qT"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "mallspecialisering av %qD är inte tillåten av ISO C++"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering av %qD efter instansiering"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD är inte en funktionsmall"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD är inte en variabelmall"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "mall-id %qD för %q+D stämmer inte med någon malldeklaration"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "såg %d %<template<>%>, behöver %d för specialisering av medlemsfunktionsmall"
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "tvetydig mallspecialisering %qD för %q+D"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "variabelmallar är endast tillgängliga med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "fel antal mallhuvuden för %qD (skulle vara %d)"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "medlemmar av en explicit specialiserad klass definieras utan ett mallhuvud"
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explicit specialisering av %qD utanför dess namnrymd måste använda en nästat-namn-specificerare"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explicit instansiering av %qD utanför dess namnrymd måste använda en nästat-namn-specificerare"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "explicit specialisering %q#D kan sakna attribut"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "primära mallattribut %s saknas"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "primärt mallattribut %s saknas"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "mall-id %qE i deklaration av primär mall"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "mallparameterlista använd i explicit instansiering"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definition given för explicit instansiering"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "för många mallparameterlistor i deklarationen av %qD"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "för få mallparameterlistor i deklarationen av %qD"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "explicit specialisering av %qD måste inledas av %<template <>%>"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "explicit specialisering  deklarerad %<concept%>"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "partiell specialisering som inte är en typ av %qE är inte tillåten"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "partiell specialisering som inte är en klass eller variabel av %qE är inte tillåten"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "standardargument angivet i explicit specialisering"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD är inte en mallfunktion"
@@ -55108,159 +55172,159 @@ msgstr "%qD är inte en mallfunktion"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "specialisering av implicit deklarerad specialmedlemsfunktion"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "ingen medlemsfunktion %qD är deklarerad i %qT"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "vändeklarationen %qD är inte synlig för en explicit specialisering"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "vändeklarationen här"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "explicit specialisering av funktionskonceptet %qD"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "argument till %<__integer_pack%> måste vara mellan 0 och %d"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "basinitierarexpansionen %qT innehåller inga parameterpaket"
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "expansionsmönster %qT innehåller inga parameterpaket"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "expansionsmönster %qE innehåller inga parameterpaket"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameterpaket expanderas inte med %<...%>:"
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "deklaration av mallparametern %q+D skuggar en mallparameter"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "deklaration av %q+#D skuggar en mallparameter"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "mallparametern %qD deklarerad här"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "specialisering av variabelkonceptet %q#D"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "mallparameter är inte härledbara i partiell specialisering:"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument och är inte mer begränsad än den primära mallen; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "huvudmall här"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partiell specialisering är inte mer specialiserad än huvudmallen eftersom den ersätter flera parametrar med en paketexpansion"
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "för många argument till en partiell specialisering %qT"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partiell specialisering %qD är inte mer specialiserad än"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "huvudmallen %qD"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameterpaketargument %qE måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameterpaketargument %qT måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "mallargument %qE berör mallparametrar"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "typ %qT för mallargument %qE beror på en mallparameter"
 msgstr[1] "typ %qT för mallargument %qE beror på mallparametrar"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "deklaration av %qD gör tidigare mallinstansiering av %qD tvetydig"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "partiell specialisering %qD efter instansiering av %qD"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "inget standardargument för %qD"
@@ -55269,47 +55333,47 @@ msgstr "inget standardargument för %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameterpaket %q+D måste vara vid slutet av mallens parameterlista"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardmallargument får inte användas i vänomdeklaration av funktionsmall"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardmallargument får inte användas i vändeklarerade mallar"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "standarmallargument får inte användas i funktionsmallar utan %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "standardmallargument får inte användas i partiella specialiseringar"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardargumentet för mallparameter för klass om omsluter %qD"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "mallen %qD deklarerad"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "mallklass utan ett namn"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "medlemsmallen %qD kan inte ha virt-specificerare"
@@ -55319,493 +55383,493 @@ msgstr "medlemsmallen %qD kan inte ha virt-specificerare"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ogiltig malldeklaration av %qD"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malldefinition av icke-mall %q#D"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d nivåer av mallparametrar förväntades till %q#D, %d fanns"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "fick %d mallparametrar till %q#D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "fick %d mallparametrar till %q#T"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d behövs"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "mallargument till %qD stämmer inte med originalmallen %qD"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "använd %<template<>%> för en explicit specialisering"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT är inte en malltyp"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "mallspecificerare inte angivna i deklarationen av %qD"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "omdeklarerad med %d mallparameter"
 msgstr[1] "omdeklarerad med %d mallparametrar"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "tidigare deklaration av %qD använde %d mallparameter"
 msgstr[1] "tidigare deklaration av %qD använde %d mallparametrar"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "mallparameter %q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "omdeklarerad här som %q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "deklaration av mallparametern %q+#D med andra begränsningar"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprunglig deklaration fanns här"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinition av standardargument till %q#D"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprunglig definition fanns här"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "omdeklaration av %q#D med andra begränsningar"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "det måste vara adressen till en funktion med extern lagringsklass"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "det måste vara namnet på en funktion med extern lagringsklass"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "det måste vara en pekare-till-medlem på formen %<&X::Y%>"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "för att den är en medlem av %qT"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  kunde inte härleda mallparametrar %qD"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  typerna %qT och %qT har inkompatibla cv-kvalificerare"
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  typerna %qT och %qT stämmer inte överens"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  mallparameter %qD är inte ett parameterpaket, men argument %qD är det"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  mallargument %qE stämmer inte med pekare till medlem-konstanten %qE"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE är inte ekvivalent med %qE"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  inkonsistent härledning av parameterpaket med %qT och %qT"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  härledda typer i konflikt för parametern %qT (T%qT och %qT)"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  härledda värden i konflikt för icke-typ-parametern %qE (%qE och %qE)"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  vektortypen %qT med variabel storlek är inte ett giltigt mallargument"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  medlemsfunktionstypen %qT är inte ett giltigt mallargument"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 msgstr[1] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  kan inte konvertera %qE (typen %qT) till typ %qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT är en tvetydig basklass till %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT är inte härledd från %qT"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  mallparametrarna till ett mallmallargument är inkonsistenta med andra härledda mallargument"
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  det går inte att härleda en mall för %qT från typen %qT som inte är en mall"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  mallargument %qE stämmer inte med %qE"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qE inte är en variabel"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument av typ %qT i C++98 eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "adressen till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "adressen till underobjektet %qT till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "adressen till %qD är inte ett giltigt mallargument eftersom den inte har statisk lagringsvaraktighet"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD är inte ett giltigt mallargument för att %qD är en variabel, inte adressen till en variabel"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE är inte ett giltigt mallargument till %qT för det är inte adressen till en variabel"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom strängkonstanter aldrig kan användas i detta sammanhang"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "i mallargument för typen %qT"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "mallargumentet %qE för typen %qT är inte ett kompileringstidskonstant"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom det står i konflikt med cv-kvalificeringar"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom inte är ett l-värde"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D är inte ett giltigt mallargument till typen %qT eftersom en referensvariabel inte har en konstant adress"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är en pekare"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "försök att använda %qE istället"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är av typen %qT"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "ignorerar attribut på mallargumentet %qT"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "ignorerar attribut i mallargumentet %qE"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "inskjutet klassnamn %qD använt som mallmallargument"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ogiltig användning av destrueraren %qE som en typ"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "för att referera till en typmedlem av en mallparameter, använd %<typename %E%>"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "typ/värde stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  förväntade en konstant av typen %qT, fick %qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  tvetydigt mallargument till en mallparameter som inte är en typ hanteras som en funktionstyp"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  förväntade en klassmall, fick %qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  förväntade en typ, fick %qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  förväntade en typ, fick %qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  förväntade en klassmall, fick %qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  förväntade en mall av typen %qD, fick %qT"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "begränsningar stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD förväntades men fick %qD"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunde inte konvertera mallargument %qE från %qT till %qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "mallargument %d är ogiltigt"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "fel antal mallargument (%d, skulle vara %d)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "fel antal mallargument (%d, skulle vara åtminstone %d)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "angivna till %qD"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till aliasmall %qD"
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till konceptet %qD"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "så varje instansiering med ett icke-tomt parameterpaket vore felformulerad"
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D är inte en funktionsmall"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "icke-malltyp %qT använd som en mall"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "för malldeklaration %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "mallbegränsningsfel för %qD"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "användning av felaktig variabelmall %qE"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d (använd %<-ftemplate-depth=%> för att öka maxvärdet)"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexibel vektormedlem %qD i union"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "fold över tom expansion över %O"
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE är inte hela mönstret av paketexpansionen"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qT"
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qE"
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  vid instansiering av standardargument för anrop av %qD"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "skapar pekare till medlemsfunktion i typ %qT som inte är en klass"
@@ -55823,291 +55887,291 @@ msgstr "skapar pekare till medlemsfunktion i typ %qT som inte är en klass"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabeln %qD har funktionstyp"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ogiltig parametertyp %qT"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "i deklaration %q+D"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "funktion som returnerar en vektor"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion som returnerar en funktion"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formar referens till void"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formar pekare till en referenstyp %qT"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formar referens till en referenstyp %qT"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formerar en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formerar en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "skapar pekare till medlem av typ %qT som inte är en klass"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "skapar pekare till medlemsreferenstyp %qT"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "skapar pekare till medlem av typ void"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD instansieras för ett tomt paket"
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT är inte en klass-, post- eller unionstyp"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT slås upp till %qT som inte är en uppräkningstyp"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT löses upp till %qT, som inte är en klasstyp"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "användning av %qs i mall"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "kvalificerande typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "namnet %qE i den beroende tolkas som något annat än en typ, men instansiering ger en typ"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "säg %<typename %E%> om en typ avses"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "initierare för %q#D expanderar till en tom uttryckslista"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "användning av ogiltigt fält %qD"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ogiltig användning av paketexpansionsuttryck"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "använd %<...%> för att expandera argumentpaket"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tom initierare i lambdas init-fångst"
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD deklarerades inte i detta definitionsområde, och inga deklarationer hittades av en argumentberoende uppslagning vid instansieringspunkten"
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "deklarationer i beroende bas %qT hittas inte av en okvalificerad uppslagning"
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "använd %<this->%D%> istället"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "använd %<%T::%D%> istället"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD är deklarerad här, senare i översättningsenheten"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "fel antal argument till %<__builtin_convertvector%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT är inte en klass eller namnrymd"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD är inte en klass eller namnrymd"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT är/använder en namnlös typ"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "mallargumentet för %qD använder lokal typ %qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT är en variabel typ"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "heltalsuttryck %qE är inte konstant"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  försöker instansiera %qD"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig mallinstansiering av %q#T"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig mallinstansiering av %q#D"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explicit instansiering av icke-mall %q#D"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "explicit instansiering av variabelkonceptet %q#D"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "explicit instansiering av funktionskonceptet %q#D"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD är inte en statisk datamedlem i en klassmall"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "det finns ingen matchande mall för %qD"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "typ %qT för explicit instansiering %qD stämmer inte med deklarerad typ %qT"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explicit instansiering av %q#D"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "dubblerad explicit instansiering av %q#D"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 förbjuder användning av %<extern%> vid explicita instansieringar"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklass %qD tillämpad på mallinstansiering"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explicit instansieringar av mallen %q#D som inte är en klass"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explicit instansieringar av icke-malltyp %qT"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explicit instansiering av %q#T före definitionen av mallen"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ förbjuder användning av %qE vid explicita instansieringar"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "dubblerad explicit instansiering av %q#T"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "explicit specifikation av %qD beror på sig själv"
@@ -56119,153 +56183,153 @@ msgstr "explicit specifikation av %qD beror på sig själv"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explicit instansiering av %qD men ingen definition tillgänglig"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d vid instansiering av %q+D, möjligen från generering av virtuell tabell (använd %<-ftemplate-depth=%> för att öka maxvärdet)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mallparameter av härledd klasstyp som inte är en typ är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT är inte en giltig typ för en mallparameter som inte är en typ eftersom det inte är en struktur"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mallparameter av klasstyp som inte är en typ är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ogiltig mallparameter som inte är en typ"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T är inte en giltig typ för en mallparameter som inte är en typ"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "nyckelordet %<template%> är inte tillåtet i deklarerar-id"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "ett koncept kan inte begränsas"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "konceptet %qE är inte i namnrymdsräckvidd"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "härledning från klammeromgiven initierarlista kräver %<#include <initializer_list>%>"
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "icke härledbar mall %qT använd utan mallargument"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "aliasmallhärledning är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "kan inte härleda mallargument för kopieinitiering av %qT, eftersom den inte har några icke-explicita härledningsguider eller användardeklarerade konstruerare"
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "kan inte härleda mallargument till %qT, eftersom den inte några användbara härledningsguider"
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "härledning av klassmallargument misslyckades:"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "explicita härledningsguider övervägs inte vid kopieinitiering"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "klassmallargumentshärledningen för %qT misslyckades: explicit härledningsguide vald i kopieringslistinitiering"
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "explicit härledningsguide deklarerad här"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT är kanske inte avsett att stödja härledning av klassmallargument"
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "lägg till en härledningsguide för att undertrycka denna varning"
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direkt listinitiering av %<auto%> tar precis ett element"
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "för härledning till %<std::initializer_list%>, använd kopielistinitiering (d.v.s. lägg till %<=%> före %<{%>)"
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "kan inte härleda lambdareturtyp från %qE"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan inte härleda %qT från %qE"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "platshållarbegränsningar är inte uppfyllt"
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "härledd initierare uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "härledd returtyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "härledd uttryckstyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "felaktig användning av %qT i mallargument"
@@ -56400,531 +56464,531 @@ msgstr "%q+#D kan inte deklareras"
 msgid "  since %q+#D declared in base class"
 msgstr "  eftersom %q+#D är deklarerad i basklassen"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%qs beräknas alltid till sant i %<if constexpr%>"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "föreslår uttryckliga klamrar runt tom kropp i %<do%>-sats"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr "fångar polymorf typ %q#T efter värde"
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr "fångar typ %q#T efter värde"
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr "fångar icke-referenstyp %q#T"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "typen på %<asm%>-operanden %qE kunde inte avgöras"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "%<__label__%>-deklarationer får bara förekomma på funktionsnivå"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "ogiltig användning av %qD i en statisk medlemsfunktion"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "%qE mallargument saknas"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "ett satsuttryck är otillräckligt sammanhang för upplösning av överlagring"
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "det går inte att anropa ett koncept som en funktion"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "argument till destruerare är inte tillåtet"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> är inte tillgängligt i en statisk medlemsfunktion"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ogiltig användning av %<this%> i icke-medlemsfunktion"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ogiltigt användning av %<this%> på toppnivå"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ogiltigt kvalificerande räckvidd i pseudodestruerarnamn"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "kvalificerad typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE har inte typen %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "sammansatt litteral för ej objekttyp %qT"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "malltypparametrar måste använda nyckelordet %<class%> eller %<typename%>"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ogiltigt användning av typ %qT som standardvärde för en mallmallparameter"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ogiltigt standardargument för en mallmallparameter"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "definition av %q#T inuti mallparameterlista"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ogiltig definition av kvalificerad typ %qT"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ogiltig basklasspecifikation"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "kan inte fånga medlemmen %qD i anonym union"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD är inte fångad"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "lambdat har ingen standardfångst"
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "lambda i lokal klass %q+T kan inte fånga variabler från det omgivande sammanhanget"
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "användning av lokal variabel med automatisk lagringsklass från en kringliggande funktion"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "användning av parameter från den kringliggande funktionen"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "användning av parameter utanför funktionskroppen"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "mallargument saknas"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "mallparameter %qD av typ %qT är inte tillåten i ett konstant heltalsuttryck eftersom den inte är av heltals- eller uppräkningstyp"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "användning av klassmall %qT som uttryck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "begäran av medlem %qD är tvetydig i gitter av multipelt arv"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD får inte finnas i ett konstantuttryck"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "typen på %qE är okänd"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT är inte ett uppräkningstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "parameterpaketets %<__bases%> är endast giltiga i malldeklarationer"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "det går inte att applicera %<offsetof%> på destrueraren %<~%T%>"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "det går inte att använda %<offsetof%> på medlemsfunktion %qD"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "det går inte att använda %<offsetof%> på en medlemsfunktion"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "det går inte att använda %<offsetof%> på en uppräknare %qD"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "%<offsetof%> inom icke-standardlayouttypen %qT är villkorligt stött"
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> tillåtet i OpenMP endast i %<declare simd%>-klausuler"
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "användardefinierad reduktionsuppslagning är tvetydig"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE i %<reduction%>-klausul är en vektor med storlek noll"
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE har const-typ för %<reduction%>"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "användardefinierad reduktion med konstruerarinitierare för basklassen %qT"
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "linjär klausul med modifieraren %qs tillämpad på en variabel som inte är en referens med typen %qT"
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "linjär klausul tillämpad på en variabel som inte är heltal och inte pekare med typen %qT"
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "ett linjärt steguttryck måste vara ett heltal"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD är inte en variabel i klausul %qs"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD är inte en variabel i klausul %<firstprivate%>"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD är inte en variabel i klausul %<lastprivate%>"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "%<gang%>-statiskt uttryck måste vara heltal"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<gang%>-statiskt värde måste vara positivt"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "%<gang%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "%<vector%>-längduttryck måste vara ett heltal"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "%<worker%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<vector%>-längdvärdet måste vara positivt"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "uttryck för styckesstorlek för schemaläggning måste vara heltal"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "%qs-längduttryck måste vara ett heltal"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%qs längduttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-id måste vara ett heltal"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "%<dist_schedule%> styckesstorleksuttryck måste vara heltal"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD är inte en variabel i %<aligned%>-klausul"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE i %<aligned%>-klausul är varken en pekare eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "%<aligned%>-klausuls justeringsuttryck måste vara heltal"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD är inte en variabel i %<nontemporal%>-klausul"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD förekommer mer än en gång i %<nontemporal%>-klausuler"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%<this%> är inte en tillåtet i en %<allocate%>-klausul"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD är inte en variabel i %<allocate%>-klausul"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD förekommer mer än en gång i %<allocate%>-klausuler"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD är inte ett l-värdeuttryck eller vektorsektion i en %<depend%>-klausul"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "mallen %qE i-klausulen %qs"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "överlagrad funktion med namnet %qE i klausulen %qs"
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<grainsize%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "%<priority%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "%<hint%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%<hint%>-uttryck måste vara ett konstant heltalsuttryck"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "variabeln %qs är varken en pekare eller en referens till en pekare"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "%qs-variabeln är varken en pekare, eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tile%>-argumentet behöver en heltalstyp"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-kvalificerad %qE utan en %<mutable%>-medlem kan endast förekomma i klausuler %<shared%> eller %<firstprivate%>"
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD är inte fil-, namnrymds- eller blockräckviddsvariabel"
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE-direktiv inte i %qT-definition"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "skillnaden mellan %qE och %qD har inte heltalstyp"
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> använd med klassiterationsvariabeln %qE"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> använder två olika uttryck för minne"
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statisk försäkran misslyckades: %s"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr "%qE beräknas till falskt"
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "icke-konstant villkor i statisk deklaration"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "argument till %<decltype%> måste vara ett uttryck"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> kan inte lösa upp adressen till en överlagrad funktion"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operanden till vikningsuttrycket har inget oexpanderat parameterpaket"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "båda argumenten i en binär vikning har oexpanderade parameterpaket"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "inga oexpanderade parameterpack i binär fold"
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "icke-pekar-argument till %<__builtin_launder%>"
@@ -56932,22 +56996,22 @@ msgstr "icke-pekar-argument till %<__builtin_launder%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "%<__builtin_bit_cast%>-måltyp %qT är en vektortyp"
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%>-måltyp %qT är inte trivialt kopierbar"
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%>-källtyp %qT är inte trivialt kopierbar"
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "%<__builtin_bit_cast%>-källstorlek %qE är inte lika med måltypstorleken %qE"
@@ -56957,1052 +57021,1053 @@ msgstr "%<__builtin_bit_cast%>-källstorlek %qE är inte lika med måltypstorlek
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV-kvalificerare kan inte tillämpas på %qT"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "satsuttryck i ett konstant uttryck"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr "%<-fabi-version=13%> (GCC 8.2) fixar anropskonventionen för %qT, som ändrades av misstag i 8.1"
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr "%<-fabi-version=12%> (GCC 8.1) ändrar av misstag anropskonventionen för %qT"
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, gcc-internal-format
 msgid " declared here"
 msgstr " deklarerad här"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "anropskonventionen för %qT ändras i %<-fabi-version=13%> (GCC 8.2)"
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " för att alla dess kopierings- och flyttkonstruerare är borttagna"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "basklassen %qT är inte publik"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qD är inte publik"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD är muterbar"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD är en icke-strukturell typ"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "argument till attribut %qE måste vara en strängkonstant"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "attributet %qE kan bara användas på funktioner eller på klass- eller uppräkningstyper"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "attributet %qE kan bara användas på icke-statiska datamedlemmar"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "attributet %qE kan inte tillämpas på ett bitfält"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "attributet %qE tar inga argument"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "ISO C++-attributet %qE är inte tillämpligt på funktioner; hanteras som %<[[gnu::%E]]%>"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "begärd %<init_priority%> är inte en heltalskonstant"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "det går bara att använda attributet %qE på definitioner av objekt- eller klasstyp med filräckvidd"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "begärd %<init_priority%> %i är utanför sitt intervall [0, %i]"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "begärd %<init_priority%> %i är reserverad för internt bruk"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "attributet %qE stödjs inte på denna plattform"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "omdeklaration av %qD lägger till abi-taggen %qE"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "attributet %qE behöver argument"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumenten till attributet %qE måste vara smala strängkonstanter"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumenten till attributet %qE måste innehålla giltiga identifierare"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> är inte ett giltigt första tecken för en identifierare"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> är inte ett giltig bokstav i en identifierare"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "attributet %qE använt på typen %qT som inte är en klass eller uppräkningstyp"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attributet %qE använt på %qT efter dess definition"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "ignorerar attributet %qE använt på mallinstansieringen %qT"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "ignorerar attributet %qE använt på mallspecialiseringen %qT"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attributet %qE tillämpat på %qD som inte är en funktion eller variabel"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attributet %qE tillämpat på extern \"C\"-deklaration %qD"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "noll som en nollpekarkonstant"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "%<lang_*%>-kontroll: misslyckades i %s, vid %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "jämförelse mellan olika pekartyper %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "konvertering mellan olika pekartyper %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "villkorsuttryck mellan olika pekartyper %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ förbjuder jämförelser mellan pekare av typ %<void *%> och pekare till funktioner"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ förbjuder konvertering mellan pekare av typ %<void *%> och pekare till funktioner"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ förbjuder villkorliga uttryck mellan pekare av typ %<void *%> och pekare till funktioner"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "jämförelse mellan olika pekare-på-medlem-typer %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "konvertering mellan olika pekare-på-medlem-typer %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "villkorsuttryck mellan olika pekare-på-medlem-typer %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "kanoniska typer skiljer för identiska typer %qT och %qT"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "samma kanoniska typnod för olika typer %qT och %qT"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "ogiltig användning av %qs på en medlemsfunktion"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ogiltig användning av %<sizeof%> på ett bitfält"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ förbjuder användning av %<sizeof%> på ett uttryck med funktionstyp"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ogiltig användning av %<__alignof%> på ett bitfält"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ förbjuder användning av %<__alignof%> på ett uttryck med funktionstyp"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "argumentet till %<alignas%> har typen %qT som inte är en heltalstyp"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion av typen %qT"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "tar adress till temporär vektor"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ förbjuder konvertering av en strängkonstant till %qT"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "konvertering från strängkonstant till %qT bör undvikas"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "begäran av medlem %qD i %qE, som är av pekartypen %qT (kanske du hade tänkt använda %<->%> ?)"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "begäran av medlem %qD i %qE, som är av icke-klasstyp %qT"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "ogiltig användning av icke-statisk datamedlem %qE"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ogiltig åtkomst av icke-statisk datamedlem %qD i virtuell bas till NULL-objekt"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "objekttyp %qT stämmer inte med destruerarnamnet ~%qT"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "typen som destrueras är %qT, men destrueraren refererar till %qT"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "fältet %q#D kan kommas åt via %q#D"
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T har ingen medlem med namnet %qE"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %q#D? (åtkomligt via %q#D)"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %q#D? (inte åtkomlig från detta sammanhang)"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %qE?"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> är inte en medlem av %qT"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT är inte en basklass till %qT"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD är inte en medlemsmallfunktion"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT är inte en pekare-på-objekt-typ"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ogiltig användning av vektorindexering på pekare till medlem"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ogiltig användning av unärt %<*%> på pekare till medlem"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ogiltig användning av implicit konvertering av pekare till medlem"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "vänstra operanden till %<->*%> måste vara en pekare på en klass, men är en pekare på en medlem av typen %qT"
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "index saknas i vektorreferens"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "indexering av vektor deklarerad %<register%>"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objekt saknas i användning av %qE"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ förbjuder anrop av %<::main%> inifrån program"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "man måste använda %<.*%> eller %<->*%> för att anropa en pekare-till-medlems-funktion i %<%E (...)%>, t.ex. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kan inte användas som en funktion"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kan inte användas som en funktion"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "uttryck kan inte användas som en funktion"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "för många argument till konstrueraren %q#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "för få argument till konstrueraren %q#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "för många argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "för få argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "för många argument till funktionen %q#D"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "för få argument till funktionen %q#D"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "för många argument till metoden %q#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "för få argument till metoden %q#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "för många argument till funktion"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "för få argument till funktion"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P till %qD har ofullständig typ %qT"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametern %P har ofullständig typ %qT"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen till %qD kommer aldrig vara NULL"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "kompilatorn kan anta att adressen till %qD aldrig kommer att vara NULL"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "bitvis konvertering mellan olika uppräkningstyper %qT och %qT bör undvikas"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "aritmetik mellan olika uppräkningstyper %qT och %qT bör undvikas"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr "jämförelse av uppräkningstypen %qT med flyttalstypen %qT är föråldrad"
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "jämförelse av flyttalstypen %qT med uppräkningstypen %qT bör undvikas"
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "aritmetik mellan uppräkningstypen %qT och flyttalstypen %qT är föråldrad"
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "aritmetik mellan flyttalstypen %qT och uppräkningstypen %qT är föråldrad"
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antar typkonvertering till %qT från överlagrad funktion"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL använd i aritmetik"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ förbjuder jämförelse mellan pekare och heltal"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operandtyper är %qT och %qT"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "trevägsjämförelse av vektorer"
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "ordningsjämförelse av pekare med heltalet noll (%qT och %qT)"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "oordnad jämförelse av argument som inte är flyttal"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "implicit konvertering från %qH till %qI för att matcha den andra operanden i binärt uttryck"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ogiltiga operander av typ %qT och %qT till binär %qO"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare av typ %<void *%> i subtraktion"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en funktion i subtraktion"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en metod i subtraktion"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ogiltig användning av en pekare till en ofullständig typ i pekararitmetik"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "tar adressen till konstrueraren %qD"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "tar adressen till destrueraren %qD"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ogiltig användning av %qE för att skapa en pekare-till-medlem-funktion"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  ett kvalificerat id krävs"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parenteser runt %qE kan inte användas för att skapa en pekare-till-medlem-funktion"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en okvalificerad eller parentetiserad icke-statisk medlemsfunktion för att skapa en pekare till en medlemsfunktion.  Säg %<&%T::%D%>"
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en bunden medlemsfunktion för att skapa en pekare till medlemsfunktion.  Säg %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "tar adress till ett r-värde"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ förbjuder att ta adressen till funktionen %<::main%>"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan inte skapa pekare till referensmedlem %qD"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "försök att ta adressen till bitfält"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "tar adressen till en omedelbar funktion %qD"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> på ett uttryck av typen %<bool%>"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "tänkte du använda logiskt icke (%<!%>)?"
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ förbjuder ökning av enum"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ förbjuder minskning av enum"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "det går inte att öka en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "det går inte att minska en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder ökning av pekare på typ %qT"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder minskning av pekare på typ %qT"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "%qs-uttryck av en %<volatile%>-kvalificerad typ bör undvikas"
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "användning av en operand av typen %qT i %<operator--%> är förbjudet"
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "användning av en operand av typen %qT i %<operator++%> är förbjudet i C++17"
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "användning av en operand av typen %qT i %<operator++%> bör undvikas"
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan inte ta adressen till %<this%>, som är ett rvalue-uttryck"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adress till explicit registervariabel %qD begärd"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adress begärd till %qD, som är deklarerad %<register%>"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "listinitierare för en typ som inte är en klass får inte vara inom parenteser"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i initierare"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i medlemsinitierare"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "uttryckslista behandlas som sammansatt uttryck i funktionstypkonvertering"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "uttryckslistan %s behandlas som sammansatt uttryck"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "ingen kontext för att lösa upp typen på %qE"
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "konvertering från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<static_cast%> från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<reinterpret_cast%> från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "oanvändbar konvertering till typen %q#T"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "typkvalificerare ignoreras för typkonverterings resultattyp"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ogiltig %<static_cast%> från typ %qT till typ %qT"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "returtypen %qT är ofullständig"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 msgid "converting from %qH to %qI"
 msgstr "konvertering från %qH till %qI"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "ogiltig typkonvertering av ett rvärdeuttryck av typ %qT till typ %qT"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
 msgstr "konvertering från %qH till %qI förlorar precision"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "konvertering mellan inkompatibla funktionstyper från %qH till %qI"
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "typkonvertering mellan inkompatibla pekare till medlemstyper från %qH till %qI"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "typkonvertering från %qH till %qI ökar kravet på justering för måltypen"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "typkonvertering mellan pekare-till-funktion och pekare-till-objekt stödjs villkorligt"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ogiltig konvertering från typ %qT till typ %qT"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ogiltig användning av %<const_cast%> med typ %qT, som inte är en pekare, referens, eller pekare-till-datamedlem-typ"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "ogiltig användning av %<const_cast%> med typ %qT, som är en pekare eller referens till en funktionstyp"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ogiltig %<const_cast%> av ett rvärde av typ %qT till typ %qT"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ogiltig %<const_cast%> från typ %qT till typ %qT"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ förbjuder typkonvertering till en vektortyp %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ogiltig konvertering till funktionstyp %qT"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr "sammansatt tilldelning med %<volatile%>-kvalificerad vänsteroperand bör undvikas"
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i beräkningen av %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "tilldelning till en vektor från en initierarlista"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "inkompatibla typer i tilldelning av %qT till %qT"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "vektor använd som initierare"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ogiltig vektortilldelning"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i konvertering av pekare till medlemsfunktion"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "konvertering av pekare till medlem via virtuell bas %qT"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i konvertering av pekare till medlem"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ogiltig konvertering till typ %qT från typ %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "det går inte att konvertera %qH till %qI i standardargument"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "det går inte att konvertera %qH till %qI när argument skickas"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "det går inte att konvertera %qH till %qI i initiering"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 msgid "cannot convert %qH to %qI in return"
 msgstr "det går inte att konvertera %qH till %qI i retur"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "det går inte att konvertera %qH till %qI i tilldelning"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "parameter %qP till %qD kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "parameter kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "målet för konvertering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "målet för initialisering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "när argument %P till %qD skickades"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerar referens till en temporär"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "att returnera en temporär %<initializer_list%> utökar inte livslängden på den underliggande vektorn"
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "referens till lokal variabel %qD returnerad"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "att returnera en lokal %<initializer_list%>-variabel %qD utökar inte livslängden på den underliggande vektorn"
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adressen till etiketten %qD returnerad"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adress till lokal variabel %qD returnerad"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "att flytta ett lokalt objekt i en retursats förhindrar att kopiering undviks"
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "ta bort anrop av %<std::move%>"
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "redundant förflyttning i retursats"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerar ett värde från en destruerare"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "det går inte att returnerar från en hanterare i ett funktions-try-block eller en konstruerare"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerar ett värde från en konstruerare"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-sats utan värde i funktion som returnerar %qT"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "returnerar en initierarlista"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "inkonsistenta typer %qT och %qT härledda för lambda-returtypen"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "inkonsistent härledning för auto-returtyp: %qT och sedan %qT"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return-sats med ett värde i funktion som returnerar %qT"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> får inte returnera NULL om den inte är deklarerad %<throw()%> (eller %<-fcheck-new%> är aktivt)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "använder r-värde som l-värde"
@@ -58266,107 +58331,102 @@ msgstr "ta bort %<{ }%> runt initierare"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "det går inte att initiera aggregat med typ %qT med en sammansatt litteral"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initierare saknas för medlem %qD"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "medlem %qD är oinitierad referens"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlem %qD med oinitierade referensfält"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "ordningen på designeraren för fält %qD stämmer inte med deklarationsordningen i %qT"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "inget fält %qD finns i unionen som initieras"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indexvärde istället för fältnamn i unioninitierare"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "cirkulär pekardelegering detekterad"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "basoperanden till %<->%> har icke-pekartyp %qT"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet av %<operator->()%> ger annat än pekare"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "basoperanden till %<->%> är inte en pekare"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kan inte användas som en medlemspekare eftersom den är av typen %qT"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "det går inte att applicera medlemspekare %qE på %qE, som är av typ %qT som inte är en klass"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "pekare-på-medlemstyp %qT är inkompatibel med objekttyp %qT"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pekare-till-medlemsfunktionstyp %qT kräver ett r-värde"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde före C++20"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionell konvertering till vektortypen %qT"
 
-#: cp/typeck2.c:2213
-#, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "kan inte härleda mallargument för %qT från %<()%>"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ogiltig värdeinitiering av referenstyper"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "anrop till funktion %qD som kastar ofullständig typ %q#T"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "anrop till funktion som kastar ofullständig typ %q#T"
@@ -58386,266 +58446,273 @@ msgstr "kan inte öppna loggfilen %<vtv_set_ptr_data.log%>: %m"
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr "kan inte öppna loggfilen %<vtv_count_data.log%>: %m"
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr "saknad eller trasig object.d"
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr "%p har ingen semantisk rutin"
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr "externa symboler kan inte ha initierare"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "__gshared är inte tillåtet i säkra funktioner; använd shared"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr "typen %s är härledd från initieraren %s, och variabler kan inte vara av typen void"
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr "variabler kan inte ha typen void"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, gcc-internal-format
 msgid "cannot be declared to be a function"
 msgstr "kan inte deklareras till att vara en funktion"
 
-#: d/dmd/dsymbolsem.c:416
-#, gcc-internal-format, gfc-internal-format
-msgid "no definition of struct %s"
+#: d/dmd/dsymbolsem.c:418
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "ingen definition av struct %s"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr "lagringsklassen ”auto” har ingen effekt om typen inte är härledd, menade du ”scope”?"
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr "kan inte vara final, kanske du menade const?"
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be %s"
 msgstr "får inte vara %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
 msgstr "får inte vara ”scope” och ”%s”"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr "fält får inte vara ”scope”"
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr "ett fält är inte tillåtet i ett gränssnitt"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr "ytterligare fält går inte för att det kommer ändra den bestämda %s-storleken"
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr "det går inte att använda mallar för att lägga till fält till aggregatet ”%s”"
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr "endast parametrar eller foreach-deklarationer kan vara ref"
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr "endast parametrar eller stackbaserade variabler kan vara inout"
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr "inout-variabler kan endast deklareras inuti inout-funktioner"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr "standardkonstruktion är avslaget för typen %s"
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr "globala, statiska, fält, manifestkonstanter, ref och out-parametrar kan inte vara scope"
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr "referens till scope-klass måste vara scope"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "void-initierare för pekare är inte tillåtna i säkra funktioner"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr "manifestkonstanter måste ha initierare"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr "storleken på typen %s är ogiltig"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr "%s har inte någon standardinitierare"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr "är inte statisk och kan inte ha en statisk initierare"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr "av typen struct %s använder this(this), vilket inte är tillåtet i statisk initiering"
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr "statiska lagringsvariabler kan inte ha destruerare"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, gcc-internal-format
 msgid "string expected for library name"
 msgstr "sträng förväntades som biblioteksnamn"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr "funktionsnamn förväntades som startadress"
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr "funktionsnamn förväntades som startadress, inte ”%s”"
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr "sträng förväntades som manglat namn"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr "nollängdssträng är inte tillåtet som manglat namn"
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr "manglade namns tecken kan endast vara av typen char"
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr "tecknet 0x%02x är inte tillåtet i manglade namn"
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr "tecknet 0x%04x är inte tillåtet i manglade namn"
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "inga argument"
+
+#: d/dmd/dsymbolsem.c:1526
 #, gcc-internal-format
 msgid "can only apply to a single declaration"
 msgstr "kan endast gälla för en enda deklaration"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr "pragma saknar avslutande ”;”"
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
 msgstr "ofullständig mixin-deklaration (%s)"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr "bastypen får inte vara void"
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr "enum %s måste ha åtminstone en medlem"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, gcc-internal-format
 msgid "circular reference to enum member"
 msgstr "cirkulär referens till en enum-medlem"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr "initiering med (%s.%s + 1) orsakar spill för typen ”%s”"
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr "har ett oexakt värde, på grund av precisionsförlust"
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr "malltupelparametern måste vara den sista"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, gcc-internal-format
 msgid "recursive mixin instantiation"
 msgstr "rekursiv mixin-instansiering"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, gcc-internal-format
 msgid "recursive expansion"
 msgstr "rekursiv expansion"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, gcc-internal-format
 msgid "error instantiating"
 msgstr "fel vid instansiering"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr "%s måste vara en funktion istället för %s"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "without `this` cannot be %s"
 msgstr "utan ”this” får inte vara %s"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr "lagringsklassen ”auto” har ingen effekt om returtypen inte härleds"
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, gcc-internal-format
 msgid "functions cannot be scope"
 msgstr "funktioner får inte vara räckvidd"
@@ -58653,42 +58720,52 @@ msgstr "funktioner får inte vara räckvidd"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr "statisk medlem har ingen ”this” på vilken ”return” kan verka"
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr "%s-funktioner får inte vara abstrakta"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr "metoden %s är inte virtuell och kan inte åsidosätta"
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr "det går inte att åsidosätta en icke-virtuell funktion"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, gcc-internal-format
 msgid "cannot be both final and abstract"
 msgstr "det går inte att vara både slutlig och abstrakt"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr "konstruerare, destruerare, postblits, invarianter, new- och delete-funktioner är inte tillåtna i gränssnittet %s"
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr "en funktionskropp är endast tillåten i slutliga funktioner i gränssnittet %s"
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr "destruerare, postblits och invarianter är inte tillåtna i unionen %s"
@@ -58696,172 +58773,172 @@ msgstr "destruerare, postblits och invarianter är inte tillåtna i unionen %s"
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr "returtypshärledning stödjs inte om den kan åsidosätta basklassfunktionen"
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr "det går inte att åsidosätta den slutliga funktionen %s"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr "flera åsidosättanden av samma funktion"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr "inkompatibla kovarianta typer %s och %s"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr "åsidosätter inte någon funktion, menade du att åsidosätta ”%s%s”?"
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, gcc-internal-format
 msgid "does not override any function"
 msgstr "åsidosätter inte någon funktion"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "det går inte att åsidosatta en slutlig funktion %s.%s"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "åsidosättandet är bara tillämpligt på klassmedlemsfunktioner"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr "in- och utkontrakt kan endast förekomma utan en kropp när de är virtuella gränssnittsfunktioner eller abstrakt"
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "det går inte att använda en mall för att lägga till en virtuell funktion till klassen ”%s”"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr "standardkonstruerare för struct:er är endast tillåtna med @disable, ingen kropp och inga parametrar"
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr "åtminstone ett argument av typen size_t förväntades"
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr "första argumentet måste vara av typen size_t, inte %s"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr "ett argument av typen void* förväntades"
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr "ett argument av typen void* förväntades, inte %s"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, gcc-internal-format
 msgid "structs, unions cannot be abstract"
 msgstr "struct:er, union:er kan inte vara abstrakta"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr "finns redan vid %s. Kanske i en annan funktion med samma namn?"
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr "lagringsklassen ”auto” är ogiltig vid deklaration av en klass, tänkte du använda ”scope”?"
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr "bastypen måste vara en klass eller ett gränssnitt, inte %s"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, gcc-internal-format
 msgid "circular inheritance"
 msgstr "cirkulärt arv"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr "bastypen måste vara ett gränssnitt, inte %s"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, gcc-internal-format, gfc-internal-format
 msgid "inherits from duplicate interface %s"
 msgstr "ärver från dubblerat gränssnitt %s"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot inherit from final class %s"
 msgstr "det går inte att ärva från en slutlig klass %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "C++-basklassen %s behöver åtminstone en virtuell funktion"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr "en statisk klass kan inte ärva från en nästad klass %s"
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr "är nästad inuti %s, men superklassen %s är nästad inuti %s"
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr "är inte nästad, men superklassen %s är nästad inuti %s"
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr "kan inte implicit generera en standardkonstruerare när basklassen %s saknar en standardkonstruerare"
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr "Fältmedlemmar i en synkroniserad klass kan inte vara %s"
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr "cirkulärt arv av gränssnitt"
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr "mixin-mallar är inte med normala mallar"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "mallinstansiering %s framåtrefererar malldeklarationen %s"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, gcc-internal-format
 msgid "cannot resolve"
 msgstr "kan inte slå upp"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr "det går inte att göra ett alias för uttrycket %s"
@@ -58876,22 +58953,22 @@ msgstr "”%.*s”"
 msgid "(%s) is false"
 msgstr "(%s) är falskt"
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ": Det går inte att initiera uppräkningstyp med klass eller pekare till strukt. Använd statisk konstantvariabel istället."
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr "är muterbar. Endast konstanta eller omuterbar klass trådlokala variabler är tillåtna, inte %s"
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr "är en pekare på en muterbar struktur. Endast pekare till konstanta, omuterbara eller delad struktur-lokala variabler är tillåtna, inte %s"
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, gcc-internal-format
 msgid "has forward references"
 msgstr "har framåtreferenser"
@@ -58951,22 +59028,24 @@ msgstr "ingen matchning för implicit anrop av super() i konstrueraren"
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr "kan inte anropa super() implicit för att den är annoterad med @disable"
 
-#: d/dmd/semantic3.c:860
-#, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+#: d/dmd/semantic3.c:862
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr "har ingen retursats, men förväntas returnera ett värde av typen %s"
 
-#: d/dmd/semantic3.c:862
-#, gcc-internal-format
-msgid "no return exp; or assert(0); at end of function"
+#: d/dmd/semantic3.c:864
+#, fuzzy, gcc-internal-format
+#| msgid "no return exp; or assert(0); at end of function"
+msgid "no `return exp;` or `assert(0);` at end of function"
 msgstr "inget returuttryck; eller assert(0); vid slutet av funktionen"
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr "den synkroniserade funktionen %s måste vara en medlem av en klass"
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr "nakna assemblerfunktioner med kontrakt stödjs inte"
@@ -59502,7 +59581,7 @@ msgstr "BOZ-litteralkonstanten vid %L kan inte vara ett aktuellt argument till %
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Argument till %qs vid %L och %L kan inte båda vara litterala BOZ-konstanter"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Felaktig användning av en BOZ-litteralkonstant vid %L"
@@ -60595,12 +60674,12 @@ msgstr "Oanvänd initieringssträng vid %L för att variabeln har nollängd"
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Initieringssträng vid %L höggs av för att stämma med variabeln (%ld/%ld)"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Delsträngs startindex vid %L är mindre än ett"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Slutindex för delsträng vid %L överstiger strängens längd"
@@ -60780,7 +60859,7 @@ msgstr "Felaktig INTENT-specifikation vid %C"
 msgid "deferred type parameter at %C"
 msgstr "fördröjd typparameter vid %C"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalärt INTEGER-uttryck förväntades vid %L"
@@ -63263,7 +63342,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Otillåtet id i copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63344,7 +63423,7 @@ msgstr "Variabeln %qs vid %L satt till odefinierad inuti slingan som börjar vid
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variabeln %qs vid %L ej definierbar inuti slingan som börjar vid %L är argument INTENT(INOUT) till funktionen %qs"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Kod för omallokering av den allokerbara vektorn vid %L kommer läggas till"
@@ -63479,12 +63558,12 @@ msgstr "Första argumentet till definierad tilldelning vid %L måste vara INTENT
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Andra argumentet av definierad tilldelning vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Första argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Andra argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
@@ -63594,542 +63673,542 @@ msgstr "Ordning stämmer inte mellan aktuellt argument vid %L och aktuellt argum
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Ordning stämmer inte mellan aktuellt argument vid %L och aktuellt argument vid %L (ordning %d och ordning %d)"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Ogiltigt procedurargument vid %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Gränssnitt stämmer inte överens i attrapprocedur %qs vid %L: %s"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Aktuellt argument till sammanhängande pekarattrapp %qs vid %L måste vara enkelt sammanhängande"
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Typen stämmer inte mellan aktuellt argument vid %L och aktuellt argument vid %L (%s/%s)."
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Typ stämmer inte i argument %qs vid %L; skickade %s till %s"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Aktuellt argument med antagen typ vid %L kräver att attrappargumentet %qs har antagen typ"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Aktuellt argument till %qs vid %L måste vara polymorft"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Aktuellt argument till %qs vid %L måste ha samma deklarerade typ"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Aktuella argument till %qs vid %L måste vara obegränsat polymorfa eftersom det formella argumentet är en pekare eller allokerbar obegränsat polymorf entitet [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Aktuellt argument till %qs vid %L måste vara en co-vektor"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Co-ordning stämmer inte i argument %qs vid %L (%d och %d)"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "Aktuellt argument till %qs vid %L måste vara enkelt sammanhängande eller ett element i en sådan vektor"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Aktuellt argument till icke-INTENT(INOUT)-attrappen %qs vid %L, som är LOCK_TYPE eller har en LOCK_TYPE-komponent"
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Aktuellt argument till icke-INTENT(INOUT)-attrappen %qs vid %L, som är EVENT_TYPE eller har en EVENT_TYPE-komponent"
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Attrappargument %qs måste vara en pekare, vektor med antagen form eller ordning utan attributet CONTIGUOUS - eftersom det aktuella argumentet vid %L inte är enkelt sammanhängande och båda är ASYNCHRONOUS eller VOLATILE"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Skickar co-vektor vid %L till allokerbart, icke co-vektor, INTENT(OUT) attrappargument %qs"
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Skickar co-vektor vid %L till allokerbart, icke co-vektor attrappargument %qs, som är ogiltigt om allokeringsstatusen ändras"
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorf skalär skickad till vektorattrappargument %qs vid %L"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Element av vektor med antagen form eller pekare skickat som aktuellt argument vid %L kan inte motsvara aktuellt argument vid %L"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Element av vektor med antagen form eller pekare skickat till vektorattrappargument %qs vid %L"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Utökning: Skalärt CHARACTER-argument som inte är av standardsort och inte C_CHAR-sort med vektorattrappargument %qs vid %L"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Aktuellt skalärt CHARACTER-argument med attrappargument som är vektor %qs vid %L"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Nyckelordsargument %qs vid %L är felaktigt i en satsfunktion"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Nyckelordsargument %qs vid %L finns inte i proceduren; menade du %qs?"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Nyckelordsargument %qs vid %L finns inte i proceduren"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Nyckelordsargumentet %qs vid %L är redan associerat med ett annat aktuellt argument"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Fler aktuella än formella argument i proceduranrop vid %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Alternativ returspecificerare saknas i subrutinanrop vid %L"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Oväntad alternativ returspecificerare i subrutinanrop vid %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Oväntad inbyggd NULL() vid %L till attrapp %qs"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Nollpekare vid %L till icke-pekarattrapp %qs"
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "Aktuellt argument vid %L till attrapp med antagen typ är av en härledd typ med typgräns eller FINAL-procedurer"
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Teckenlängd stämmer inte (%ld/%ld) mellan aktuellt argument och pekare eller allokerbart attrappargument %qs vid %L"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Teckenlängd stämmer inte (%ld/%ld) mellan aktuellt argument och attrappargument med antagen form %qs vid %L"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Aktuellt argument vid %L till allokerbart eller pekarattrappargument %qs måste ha en fördröjd längdtypparameter om och endast om attrappen har en"
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Teckenlängden på aktuellt argument är kortare än attrappargumentet %qs (%lu/%lu) vid %L"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Aktuellt argument innehåller för få element för attrappargument %qs (%lu/%lu) vid %L"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "En procedurpekare förväntade som argument %qs vid %L"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Förväntade en procedur som argument %qs vid %L"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Aktuellt argument till %qs kan inte vara en vektor med antagen storlek vid %L"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Aktuellt argument till %qs skall vara en pekare vid %L"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Aktuellt argument som inte är en pekare vid %L till pekarattrapp %qs"
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Co-indexerat faktiskt argument vid %L till pekarattrapp %qs"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Co-indexerat aktuellt argument vid %L till allokerbar attrapp %qs kräver INTENT(IN)"
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Co-indexerat ASYNCHRONOUS eller VOLATILE aktuellt argument vid %L kräver att attrappen %qs varken har ASYNCHRONOUS eller VOLATILE"
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Co-indexerat faktiskt argument vid %L med allokerbar slutlig komponent till attrappen %qs kräver antingen VALUE eller INTENT(IN)"
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Aktuellt CLASS-vektorargument till %qs måste vara en fullständig vektor vid %L"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Aktuellt argument till %qs skall vara en ALLOCATABLE vid %L"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Vektorsektion som aktuellt argument med vektorindex vid %L är inte kompatibelt med attributet INTENT(OUT), INTENT(INOUT), VOLATILE eller ASYNCHRONOUS på attrappargumentet %qs"
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Aktuellt argument med antagen form vid %L är inte kompatibel med attrappargumentet %qs utan antagen form på grund av attributet VOLATILE"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Vektorsektion som aktuellt argument vid %L är inkompatibelt med attrappargumentet %qs utan antagen form på grund av attributet VOLATILE"
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Pekarvektor som aktuellt argument vid %L kräver ett attrappargument %qs med antagen form eller pekarvektor på grund av attributet VOLATILE"
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Alternativ returspecifikation saknas i subrutinanrop vid %L"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Aktuellt argument saknas för argument %qs vid %L"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Felaktig komponentkod"
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Listor stämmer inte"
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): trasig data"
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Samma aktuella argument associerat med INTENT(%s)-argument %qs och INTENT(%s)-argument %qs vid %L"
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Listor stämmer inte"
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Procedurargument vid %L är lokalt i en PURE-procedur och har attributet POINTER"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Co-indexerat aktuellt argument vid %L i en PURE-procedur skickas till ett INTENT(%s)-argument"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Co-indexerat aktuell argument vid %L i en PURE-procedur skickas till ett POINTER-attrappargument"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Co-indexerat polymorft aktuellt argument vid %L skickas ett polymorft attrappargument %qs"
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Proceduren %qs anropad vid %L är inte explicit deklarerad; menade du %qs?"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Proceduren %qs anropad vid %L är inte explicit deklarerad"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Procedur %qs anropad med ett implicit gränssnitt vid %L"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Pekarobjektet %qs vid %L måste ha ett explicit funktionsgränssnitt eller deklareras som vektor"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Det allokerbara objektet %qs vid %L måste ha ett explicit funktionsgränssnitt eller deklareras som vektor"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Allokerbar funktion %qs vid %L måste ha ett explicit funktionsgränssnitt"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Explicit gränssnitt krävs för polymorft argument vid %L"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Nyckelordsargument kräver explicit gränssnitt för proceduren %qs vid %L"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Argumentet ”%s” med antagen typ vid %L kräver ett explicit gränssnitt"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Aktuellt argument till LOCK_TYPE eller med LOCK_TYPE-komponent vid %L kräver ett explicit gränssnitt för proceduren %qs"
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Aktuellt argument till EVENT_TYPE eller med EVENT_TYPE-komponent vid %L kräver ett explicit gränssnitt för proceduren %qs"
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD-argumentet till NULL krävs vid %L"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Argumentet med antagen ordning kräver ett explicit gränssnitt vid %L"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Procedurpekarkomponent %qs anropad med ett implicit gränssnitt vid %L"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Nyckelordsargument kräver explicit gränssnitt för procedurpekarkomponent %qs vid %L"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= krävs i NULL()-argument vid %L: Tvetydighet mellan de specifika funktionerna %s och %s"
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Kan inte hitta symbolen %qs"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entiteten %qs vid %L finns redan i gränssnittet"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Felaktig gränssnittstyp"
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Det går inte att skriva över GENERIC %qs vid %L"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs vid %L åsidosätter en procedurbindning deklarerad NON_OVERRIDABLE"
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs vid %L får inte vara DEFERRED eftersom det åsidosätter en ej DEFERRED bindning"
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs vid %L åsidosätter en PURE-procedur och måste också vara PURE"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs vid %L åsidosätter en ELEMENTAL-procedur och måste också vara ELEMENTAL"
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs vid %L åsidosätter en icke-ELEMENTAL-procedur och får inte heller vara ELEMENTAL"
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs vid %L åsidosätter en SUBROUTINE och måste också vara en SUBROUTINE"
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs vid %L åsidosätter en FUNCTION och måste också vara en FUNCTION"
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Resultaten stämmer inte överens för den åsidosättande proceduren %qs vid %L: %s"
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs vid %L åsidosätter en PUBLIC-procedur och får inte vara PRIVATE"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Attrappargument %qs till %qs vid %L skulle ha namnet %qs för att stämma med motsvarande argument i den åsidosatta proceduren"
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Argument stämmer inte överens för den åsidosättande proceduren %qs vid %L: %s"
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs vid %L måste ha samma antal formella argument som den åsidosatta proceduren"
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs vid %L åsidosätter en NOPASS-bindning och måste också vara NOPASS"
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs vid %L åsidosätter en bindning med PASS och måste också vara PASS"
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Attrappargument för pass-objekt till %qs vid %L måste vara på samma position som attrappargumentet för pass-objektet i den åsidosatta proceduren"
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "DTIO-attrappargument vid %L måste ha typen %s"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "DTIO-attrappargument vid %L måste ha KIND = %d"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "DTIO-attrappargument vid %L måste vara skalärt"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "DTIO-attrappargument vid %L måste vara en ASSUMED SHAPE ARRAY"
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "DTIO-teckenargumentet vid %L måste ha antagen längd"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "DTIO-attrappargument vid %L måste ha INTENT %s"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Alternativ retur vid %L är inte tillåtet i en DTIO-procedur"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "DTIO-proceduren %qs vid %L måste vara en subrutin"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "För få attrappargument i DTIO-proceduren %qs vid %L"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "För många attrappargument i DTIO-proceduren %qs vid %L"
@@ -64274,33 +64353,33 @@ msgstr "Transformerande funktion %qs vid %L är ogiltig i ett initieringsuttryck
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Elementär funktion som initieraruttryck med argument som inte är heltal/tecken vid %L"
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Subrutinanrop till inbyggda %qs i DO CONCURRENT-block vid %L är inte PURE"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Subrutinanrop till inbyggd %qs vid %L är inte PURE"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Utökning: Konvertering från %s till %s vid %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Ickestandardkonvertering från %s till %s vid %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Möjlig ändring av värde vid konvertering från %s till %s vid %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Konvertering från %s till %s vid %L"
@@ -64308,22 +64387,22 @@ msgstr "Konvertering från %s till %s vid %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Kan inte konvertera %s till %s vid %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Kan inte konvertera %qs till %qs vid %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "%qs deklarerad vid %L kan skugga den inbyggda med samma namn.  För att anropa den inbyggda kan en explicit INTRINSIC-deklaration krävas."
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "%qs deklarerad vid %L är också namnet på en inbyggd.  Den kan bara anropas via ett explicit gränssnitt eller om den deklareras EXTERNAL."
@@ -64860,7 +64939,7 @@ msgstr "NAMELIST %qs i READ-sats vid %L innehåller symbolen %qs som inte får s
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-objektet %qs i namnlistan %qs vid %L med ALLOCATABLE- eller POINTER-komponenter"
@@ -66032,12 +66111,12 @@ msgstr "match_level_4(): Felaktig operator"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr "gfc_basic_typename(): Odefinierad typ"
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "gfc_typename(): Odefinierad typ"
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "gfc_code2string(): Felaktig kod"
@@ -66192,147 +66271,147 @@ msgstr "Inbyggd operator %qs refererad från %L finns inte i modulen %qs"
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): felaktig modulsymbol %qs"
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbolen inte skriven"
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, gcc-internal-format
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "Kan inte öppna modulfilen %qs för skrivning vid %C: %s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Fel när modulfilen %qs skrevs: %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "Kan inte radera modulfilen %qs: %s"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Kan inte ändra namn på modulfilen %qs till %qs: %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "Kan inte radera temporär modulfil %qs: %s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Symbolen %qs vid %C är redan deklarerad"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Kan inte skapa en symbol för %s"
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Symbolen %qs, refererad vid %L, finns inte i den valda standarden"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Symbolen %qs refererad från %L hittas inte i den inbyggda modulen ISO_C_BINDING"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbolen %qs är redan deklarerad"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Användning av inbyggd modul %qs vid %C står i konflikt med namn på ej inbyggd modul använd tidigare"
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Användning av namngiven NUMERIC_STORAGE_SIZE-konstant från inbyggd modul ISO_FORTRAN_ENV vid %L är inte kompatibelt med flaggan %qs"
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Användning av namngiven NUMERIC_STORAGE_SIZE-konstant från inbyggd modul ISO_FORTRAN_ENV vid %C är inte kompatibelt med flaggan %s"
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Symbolen %qs refererad vid %L hittas inte i den inbyggda modulen ISO_FORTRAN_ENV"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "USE-sats vid %C har ingen ONLY-kvalificerare"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "inbyggd modul ISO_FORTRAN_ENV vid %C"
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "ISO_C_BINDING-modul vid %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "Det finns ingen inbyggd modul med namnet %qs vid %C"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "IEEE_FEATURES-modul vid %C"
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "IEEE_EXCEPTIONS-modul vid %C"
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "IEEE_ARITHMETIC-modul vid %C"
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, gcc-internal-format
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Kan inte öppna modulfilen %qs för läsning vid %C: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Modulfilen %qs har inte genererats, antingen för att modulen inte innehåller en MODULE PROCEDURE eller så finns det ett fel i modulen."
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Användning av ej inbyggd modul %qs vid %C står i konflikt med namn på inbyggd modul använd tidigare"
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Filen %qs öppnad vid %C är inte en GNU Fortran-modulfil"
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Kan inte läsa modulfilen %qs öppnad vid %C, eftersom den skapades av en annan version av GNU Fortran"
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr "Det går inte att göra USE på en submodul som just nu byggs"
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr "Det går inte att göra USE på en modul som just nu byggs"
@@ -66868,8 +66947,8 @@ msgstr "Den implicit deklarerade subrutinen %s används i !$OMP DECLARE REDUCTIO
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "ORDERED-klausulparameter är mindre än COLLAPSE vid %L"
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-klausul vid %L kräver ett skalärt LOGICAL-uttryck"
@@ -68893,7 +68972,7 @@ msgstr "Den inbyggda %qs deklarerad INTRINSIC vid %L är inte tillgänglig i den
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Icke RECURSIVE procedur %qs vid %L anropar kanske sig själv rekursivt.  Deklarera den RECURSIVE eller använd %<-frecursive%>"
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Etikett %d som refereras vid %L är aldrig definierad"
@@ -69008,7 +69087,7 @@ msgstr "Kan inte slå upp den specifika funktionen %qs vid %L"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ; menade du %qs?"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ"
@@ -69164,212 +69243,212 @@ msgstr "Den orena funktionen %qs vid %L beräknas eventuellt inte"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Den orena funktionen vid %L beräknas eventuellt inte"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "BOZ-litteralkonstanten vid %L får inte vara en operand till den unära operatorn %qs"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr "Operander vid %L och %L kan inte förekomma som operander av den binära operatorn %qs"
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "BOZ-litteralkonstanten nära %L får inte förekomma som en operand till en relationsoperator"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr "Likhetsjämförelse av %s vid %L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr "Olikhetsjämförelse av %s vid %L"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Felaktig inbyggd"
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Felaktigt uttryck"
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i co-dimension %d"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i co-dimension %d"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Otillåtet steg på noll vid %L"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Felaktig vektorreferens"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Högraste övre gränsen av en sektion av vektor med antagen storlek inte angiven vid %L"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Ordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Co-indexordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Co-index i co-dimension %d måste vara en skalär vid %L"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Vektorindex vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Vektorindex vid %L måste ha INTEGER-typ, fann %s"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-vektorindex vid %L"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Dim-argumentet vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Dim-argumentet vid %L måste ha INTEGER-typ"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Specifikation saknas"
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): oanvänd as(1)"
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): oanvänd as(2)"
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Vektorindex vid %L är en vektor med ordning %d"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Startindex för delsträng vid %L måste typen INTEGER"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Startindex för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Slutindex för delsträng vid %L måste ha typen INTEGER"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Slutsträng för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Slutindex för delsträng vid %L är för stort"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Felaktig vektorreferens"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet POINTER vid %L"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet ALLOCATABLE vid %L"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Två eller flera delreferenser med ordning skild från noll får inte anges vid %L"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "gfc_expression_rank(): Två vektorspecifikationer"
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får bara användas som ett aktuellt argument"
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen typ vid %L får bara användas som ett aktuellt argument"
@@ -69378,12 +69457,12 @@ msgstr "Variabeln %s med antagen typ vid %L får bara användas som ett aktuellt
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen typ %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen ordning vid %L kan bara användas som ett aktuellt argument"
@@ -69392,293 +69471,293 @@ msgstr "Variabeln %s med antagen ordning vid %L kan bara användas som ett aktue
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen ordning %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen typ vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen ordning vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs, använd i ett specifikationsuttryck, refereras vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs används vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorft subobjekt till co-indexerat objekt vid %L"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Co-indexerat objekt med polymorf allokerbar delkomponent vid %L"
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "Att använda variabeln %qs vid %L bör undvikas"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs vid %L är värdassocierad vid %L in i en innesluten procedur med en intern procedur med samma namn"
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Fel i typbundet anrop vid %L"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Skickat objekt vid %L måste vara skalär"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för procedurpekarkomponentanrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för typbundet proceduranrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basobjekt för typbundet NOPASS-proceduranrop vid %L måste vara skalärt"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Hittade ingen matchande specifik bindning för anropet till GENERIC %qs vid %L"
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs vid %L skulle vara en FUNCTION"
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Felaktig uttryckstyp"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s vid %L måste vara en skalär"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s vid %L måste vara ett heltal"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s vid %L måste vara INTEGER"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Steguttryck i DO-slinga vid %L får inte vara noll"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-slinga vid %L kommer köras noll gånger"
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller över"
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller under"
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-steguttryck vid %L måste vara en skalär %s"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-steguttryck vid %L får inte vara noll"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-index %qs får inte förekomma i triplettspecifikation vid %L"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allokeringsobjekt vid %L måste vara ALLOCATABLE eller en POINTER"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Co-indexerat allokerbart objekt vid %L"
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Källuttryck vid %L måste vara skalärt eller ha samma ordning som allokeringsobjektet vid %L"
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Källuttryck vid %L och allokeringsobjekt vid %L måste ha samma form"
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typen på entiteten vid %L är typinkompatibel med källuttrycket vid %L"
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allokeringsobjektet vid %L och källuttrycket vid %L skall ha samma sorts typparameter"
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen LOCK_TYPE eller ha en LOCK_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen EVENT_TYPE eller ha en EVENT_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Allokering %s av ABSTRACT bastyp vid %L behöver en typspecifikation eller source-uttryck"
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Allokerar %s vid %L med typspecifikation kräver samma teckenlängdsparameter som i deklarationen"
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation eller vektorvärt SOURCE=-uttryck krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Co-vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Felaktig vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "Övre cobound är mindre än den lägre cobound vid %L"
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "Övre cobound är mindre än lägre cobound av 1 vid %L"
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs får inte förekomma i vektorspecifikationen vid %L i samma ALLOCATE-sats där den själv allokeras"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "”*” förväntades i co-indexspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Felaktig co-vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Statvariabel vid %L måste vara en INTEGER-variabel"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Statvariabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG vid %L är oanvändbart utan en STAT-tagg"
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG-variabeln vid %L måste vara en skalär standard-CHARACTER-variabel"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allokeringsobjekt vid %L förekommer också vid %L"
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
@@ -69687,284 +69766,284 @@ msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-etikett vid %L överlappar med CASE-etikett vid %L"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "uttryck i CASE-sats vid %L måste vara av typ %s"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Uttryck i CASE-sats vid %L måste ha sort %d"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Uttryck i CASE-sats vid %L måste vara skalärt"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Valuttryck i beräknad-GOTO-sats vid %L måste vara ett skalärt heltalsuttryck"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument till SELECT-sats vid %L kan inte vara %s"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumentet till SELECT-satsen vid %L måste vara ett skalärt uttryck"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Uttryck i CASE-sats vid %L ligger inte i intervallet %s"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE vid %L får inte följas av ett andra DEFAULT CASE vid %L"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logiskt intervall CASE-sats vid %L är inte tillåtet"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstant logiskt värde i CASE-sats upprepas vid %L"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Intervallspecifikationen vid %L kan aldrig matchas"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logiskt SELECT CASE-block vid %L har mer än två fall"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Den associerande entiteten %qs vid %L är en procedurpekare"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Den härledda typen %qs får inte användas som en variabel vid %L"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Den associerande entiteten %qs vid %L är ett procedurnamn"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "Det associerande selector-uttrycket vid %L ger en procedur"
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektorn vid %L får inte vara NULL()"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektorn vid %L har ingen typ"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associationsnamn %qs vid %L används som en vektor"
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-väljare vid %L behöver en temporär som inte är implementerad ännu"
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektorer skall vara polymorfiska i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektorn vid %L får inte vara co-indexerad"
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS vid %L överlappar med TYPE IS vid %L"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Härledd typ %qs vid %L måste vara utökningsbar"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Härledd typ %qs vid %L måste vara en utökning av %qs"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Oväntad inbyggd typ %qs vid %L"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Typspecifikationen vid %L skall ange att varje längdtypparameter är antagen"
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Dubbelt CLASS IS-block i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT vid %L upprepas vid %L"
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) vid %L upprepas vid %L"
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) vid %L upprepas vid %L"
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) vid %L får inte användas med en pekare eller allokerbar selector vid %L"
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ogiltigt sammanhang för inbyggd NULL () vid %L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s-procedur vid %L måste vara rekursiv"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte vara polymorft om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha POINTER-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Dataöverföringselement vid %L får inte ha procedurpekarkomponenter"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha ALLOCATABLE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Dataöverföringselement vid %L får inte ha PRIVATE-komponenter"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha PRIVATE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Dataöverföringselement vid %L får inte vara en full referens till en vektor med antagen storlek"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Låsvariabel vid %L måste vara en skalär av typen LOCK_TYPE"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Händelsevariabeln vid %L måste vara en skalär av typen EVENT_TYPE"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor eller co-indexerat"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor men inte co-indexerat"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=-argumentet vid %L måste vara en skalär INTEGER-variabel"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=-variabeln vid %L måste vara en skalär CHARACTER-variabel"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=-argumentet vid %L måste vara en skalär LOGICAL-variabel"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT=-argumentet vid %L måste vara ett skalärt INTEGER-uttryck"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Bildmängdsargument vid %L måste vara ett skalärt eller INTEGER-uttryck av ordning 1"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Bildmängdsargument vid %L måste vara mellan 1 och num_images()"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sats vid %L är inte en giltig grenmålssats för grensatsen vid %L"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Gren vid %L kan orsaka en oändlig slinga"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar CRITICAL-konstruktion för etikett vid %L"
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
@@ -69972,192 +70051,192 @@ msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Etiketten vid %L är inte i samma block som GOTO-satsen vid %L"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-mask vid %L har inkonsistent form"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-tilldelningsmål vid %L har inkonsistent form"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Ej ELEMENTAL användardefinierad tilldelning i WHERE vid %L"
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ej stödd sats inuti WHERE vid %L"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Tilldelning till en FORALL-indexvariabel vid %L"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL med index %qs används inte på vänster sida av en tilldelning vid %L och kan därför orsaka multipla tilldelningar till detta objekt"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "FORALL-konstruktion vid %L"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär variabel av heltalstyp"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "En yttre FORALL-konstruktion har redan ett index med detta namn %L"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE-klausul vid %L kräver en LOGICAL-vektor"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Felaktig blocktyp"
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-uttryck kommer att huggas av i tilldelning (%ld/%ld) vid %L"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Co-indexerat uttryck vid %L är tilldelat till en härledd typvariabel med en POINTER-komponent i en PURE-procedur"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "I ett rent underprogram skall inte ett INTENT(IN) attrappargument användas som uttrycket vid %L av en inbyggd tilldelningssats i vilken variabeln är av an härledd typ om den härledda typen har en pekarkomponent på någon nivå av komponentvalet."
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Tilldelning till en co-indexerad variabel vid %L i en PURE-procedur"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Tilldelning till en polymorf co-vektor vid %L är inte tillåtet"
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L kräver %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Ej allokerbar variabel får inte vara polymorf i inbyggd tilldelning vid %L - kontrollera att det finns en matchande specifik subrutin för operatorn ”=”"
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Co-indexerad variabel får inte ha en allokerbar yttersta komponent i tilldelningen vid %L"
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "ATT GÖRA: typbegränsad definierad tilldelning vid %L inte gjord för att multipla delvektorreferenser skulle uppträda i intermediära uttryck."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Procedurpekartilldelning vid %L"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsresultatet på vänstersidan av tilldelningen vid %L måste ha attributet pointer."
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO-sats vid %L kräver en skalär INTEGER-variabel"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabeln %qs har inte tilldelats någon måletikett vid %L"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternativ RETURN-sats vid %L kräver en SCALAR-INTEGER-returspecificerare"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-sats vid %L kräver en skalär standard-INTEGER-variabel"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ogiltig NULL vid %L"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Aritmetisk IF-sats vid %L kräver ett skalärt REAL- eller INTEGER-uttryck"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Inget uttryck i DO WHILE"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Avslutsvillkor i DO WHILE-slinga vid %L måste vara ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-maskklausul vid %L kräver ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Felaktig satskod"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Att använda parametern %qs deklarerad vid %L bör undvikas"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variabeln %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som en entitet vid %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använder samma globala identifierare som entiteten vid %L från modulen %qs"
@@ -70165,964 +70244,964 @@ msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använde
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Proceduren %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som entiteten vid %L"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Stränglängden vid %L är för stor"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Den allokerbara vektorn %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalärt objekt %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Vektorpekaren %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Vektor %qs vid %L kan inte ha en fördröjd form"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typen %qs på CLASS-variabeln %qs vid %L är inte utvidgningsbar"
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-variabel %qs vid %L måste vara en attrapp, allokerbar eller pekare"
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Typen %qs kan inte vara värdassocierad vid %L för att den blockeras av ett inkompatibelt objekt med samma namn deklarerat vid %L"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Implicerad SAVE för modulvariabeln %qs vid %L, behövs på grund av standardinitieringar"
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Enheten %qs vid %L har en fördröjd typparameter och kräver antingen attributet POINTER eller ALLOCATABLE"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul- eller huvudprogramvektorn %qs vid %L måste ha konstant form"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entitet med antagen teckenlängd vid %L måste vara ett attrappargument eller en PARAMETER"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs vid %L måste ha konstant teckenlängd i detta sammanhang"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-variabeln %qs vid %L måste ha konstant teckenlängd"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Allokerbar %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Extern %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Attrapp-%qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Inbyggd %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsresultat %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisk vektor %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s vid %L"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Teckenvärd satsfunktion %qs vid %L måste ha konstant längd"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs är av en PRIVATE-typ och kan inte vara ett attrappargument till %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Proceduren %qs i PUBLIC-gränssnittet %qs vid %L tar attrappargument för %qs som är PRIVATE"
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externt objekt %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktion %qs vid %L måste ha ett skalärt resultat"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Satsfunktionen %qs vid %L får inte ha attributet pointer eller allocatable"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha vektorvärde"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha pekarvärde"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara pure"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara rekursiv"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-funktionen %qs vid %L"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Procedurpekaren %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Attrapprocedur %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionens resultatvariabel %qs vid %L för den elementära funktionen %qs skall inte ha ett attribut ALLOCATABLE eller POINTER"
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med SAVE-attribut i %qs vid %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med INTENT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med RESULT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribut i konflikt med FUNCTION-attribut i %qs vid %L"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Procedurpekarresultat %qs vid %L saknar pekarattributet"
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "ELEMENTAL-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "PURE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "RECURSIVE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s mellan MODULE PROCEDURE-deklarationen i MODULE %qs och deklarationen vid %L i (SUB)MODULE %qs"
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-procedur %qs vid %L är inte en SUBROUTINE"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-procedur vid %L måste ha precis ett argument"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument till FINAL-procedur vid %L måste ha typen %qs"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument till FINAL-procedur vid %L får inte vara en POINTER"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument till FINAL-procedur vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument till FINAL-procedur vid %L får inte vara OPTIONAL"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument till FINAL-procedur vid %L får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Ickeskalär FINAL-procedur vid %L skulle ha argument med antagen form"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL-procedur %qs deklarerad vid %L har samma ordning (%d) som %qs"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Endast vektor-FINAL-procedurer deklarerade för den härledda typen %qs definierade vid %L, föreslår även en skalär"
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs och %qs kan inte blandad FUNCTION/SUBROUTINE för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs och %qs för GENERIC %qs vid %L är tvetydiga"
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Odefinierad specifik bindning %qs som mål för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs vid %L måste ha som mål en specifik bindning, %qs är också GENERIC"
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs vid %L kan inte åsidosätta en specifik bindning med samma namn"
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Typbindningsoperator vid %L kan inte vara NOPASS"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs måste vara en modulprocedur eller en extern procedur med ett explicit gränssnitt vid %L"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Proceduren %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Procedur %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Ickepolymorfa attrappargument för pass-objekt till %qs vid %L"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Skickat objekt-attrappargument till %qs vid %L måste vara skalärt"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara POINTER"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Procedur %qs vid %L har samma namn som en komponent i %qs"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proceduren %qs vid %L har samma namn som den ärvd komponent i %qs"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Härledd typ %qs deklarerad vid %L måste vara ABSTRACT för att %qs är DEFERRED och inte åsidosatt"
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Co-vektorkomponent %qs vid %L måste vara allokerbar med fördröjd form"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponenten %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponenten %qs vid %L med co-vektorkomponent skall skalär som inte är en pekare eller allokerbar"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Component %qs vid %L har attributet CONTIGUOUS men är inte en vektorpekare"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponenten %qs med typen BIND(C) vid %L måste ha längden ett"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Procedurpekarkomponent %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Procedurpekarkomponent %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste vara skalärt"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte ha attributet POINTER"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponent %qs i %qs vid %L har samma namn som en ärvd typbunden procedur"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Teckenlängd på komponent %qs behöver vara ett konstant specifikationsuttryck vid %L"
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Teckenkomponent %qs av %qs vid %L med fördröjd längd måste vara en POINTER eller ALLOCATABLE"
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "komponenten %qs är en PRIVATE-typ och kan inte vara en komponent i %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorf komponent %s vid %L i SEQUENCE- eller BIND(C)-typ %s"
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponent %s av SEQUENCE-typ deklarerad vid %L har inte attributet SEQUENCE"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initierare som står i konflikt i unionen vid %L och %L"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Eftersom utvidgningen av %qs vid %L har en co-vektorkomponent, skall föräldratypen %qs också ha en"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Ej utvidgningsbar härledd typ %qs vid %L får inte vara ABSTRACT"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Den parametriserade typen %qs har inte någon komponent som motsvarar parametern %qs vid %L"
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Det generiska namnet %qs på funktionen %qs vid %L är samma namn som den härledda typen vid %L"
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Härledd typ %qs vid %L har inte deklarerats"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %L är inte tillåtet"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med antagen form i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant form in namnlistan %qs vid %L"
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant längd i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs deklarerades PRIVATE och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har användningsassociativa PRIVATE-komponenter och kan inte vara medlem av namnlistan %qs vid %L"
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har PRIVATE-komponenter och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med NAMELIST-attribut i %qs vid %L"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametervektor %qs vid %L kan inte ha automatisk eller fördröjd form"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implicit typad PARAMETER %qs vid %L matchar inte en senare IMPLICIT-typ"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Inkompatibel härledd typ i PARAMETER vid %L"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variabeln %qs vid %L får inte ha attributet PARAMETER"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Objektet %qs vid %L har en fördröjd LEN-parameter %qs och är varken allokerbar eller en pekare"
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "AUTOMATIC-objektet %qs vid %L får inte ha attributet SAVE eller vara en variabel deklarerad i huvudprogrammet, en modul eller en submodul(F08/C513)"
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Objektet %qs vid %L med ASSUMED typparametrar måste vara en attrapp eller en SELECT TYPE-selektor(F08/4.2)"
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Ledsen, allocatable/pointer-komponenter i co-vektor av polymorf (CLASS)-typ vid %L stödjs inte"
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attributet PROTECTED står i konflikt med attributet EXTERNAL vid %L"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attributet PROCEDURE står i konflikt med attributet PROTECTED vid %L"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs vid %L har attributet CONTIGUOUS, men är inte en vektorpekare eller en vektor med antagen form eller antagen ordning"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Felaktig specifikation för vektor med antagen storlek vid %L"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Vektor med antagen storlek vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Vektor med antagen form vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Vektor med antagen ordning vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Vektor med antagen ordning vid %L kan inte ha attributet VALUE eller CODIMENSION"
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol vid %L är inte en DUMMY-variabel"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs vid %L kan inte ha attributet VALUE eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Teckenvärd attrappvariabel %qs vid %L med attributet VALUE måste ha konstant längd"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-interoperativ teckenattrappvariabel %qs vid %L med attributet VALUE måste ha längd ett"
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Den härledda typen %qs vid %L har typen %qs, som inte har definierats"
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall vara ett attrappargument"
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall ha typen TYPE(*) eller en numerisk inbyggd typ"
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall antingen vara en skalär eller en vektor med förmodad storlek"
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Den antagna typen på variabeln %s vid %L är bara tillåten för attrappvariabler"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variabeln %s med antagen typ vid %L får inte vara en vektor med explicit form"
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel %qs vid %L kan inte vara BIND(C) eftersom den varken är ett COMMON-block eller deklarerad med räckvidd modulnivå"
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-variabeln %qs vid %L måste ha längden ett"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs vid %L har PRIVATE härledd typ %qs"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen LOCK_TYPE eller med en delkomponent av typen LOCK_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen EVENT_TYPE eller med en delkomponent av typen EVENT_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT)-attrappargumentet %qs vid %L har ASSUMED SIZE och kan därför inte ha en standardinitierare"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av LOCK_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av EVENT_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsresultat %qs vid %L skall inte vara en co-vektor eller ha en co-vektorkomponent"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variabeln %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variabeln %qs vid %L med co-vektorkomponent skall vara en skalär som inte är en pekare eller allokerbar och inte en co-vektor"
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variabeln %qs vid %L är en co-vektor och är inte ALLOCATABLE, SAVE eller ett attrappargument"
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Co-vektorvariabeln %qs vid %L skall inte ha co-dimensioner med fördröjd form"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allokerbar co-vektorvariabel %qs vid %L måste ha en fördröjd form"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variabeln %qs vid %L är INTENT(OUT) och kan alltså inte vara en allokerbara co-vektor eller har co-vektorkomponenter"
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Co-attrappvariabeln %qs vid %L är inte tillåten i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-attrappargumentet %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-resultatvariabeln %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Namnlistan %qs får inte vara ett argument till en subrutin eller funktion vid %L"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Trådprivat vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET-variabeln %qs vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Definierbar entitet förväntades nära %L"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA-element %qs vid %L måste vara i COMMON"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-vektor %qs vid %L måste anges i en tidigare deklaration"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-elementet %qs vid %L kan inte ha ett co-index"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-element %qs vid %L är en pekare och måste då vara en fullständig vektor"
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "DATA-objektet nära %L har pekarattributet och det motsvarande DATA-värdet är inte ett giltigt initialt-data-mål"
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "DATA-elementet %qs vid %L får inte ha attributet ALLOCATABLE"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Ickekonstant vektorsektion vid %L i DATA-sats"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-sats vid %L har fler variabler än värden"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "början av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "slutet av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "steget i implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "steget i implicerad do-slinga vid %L skall inte vara noll"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-sats vid %L har fler värden än variabler"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Etiketten %d vid %L är definierad men inte använd"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Etiketten %d vid %L är definierad men kan inte användas"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L måste ha attributet SEQUENCE för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L kan inte ha ALLOCATABLE-komponenter för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Härledd typvariabel %qs vid %L med standardinitiering kan inte vara i EQUIVALENCE med en variabel i COMMON"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L med pekarkomponent(er) kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfel i EQUIVALENCE-sats vid %L"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Antingen alla eller inget av objekten i EQUIVALENCE-mängden vid %L kan ha attributet PROTECTED"
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-blockmedlem %qs vid %L kan inte vara ett EQUIVALENCE-objekt i den rena proceduren %qs"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Namngiven konstant %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Vektor %qs vid %L med icke-konstanta gränser kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Postkomponent %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Delsträng vid %L har längden noll"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Självreferens i uttrycket för teckenlängd för %qs vid %L"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-funktionen %qs vid %L har PRIVATE typ %qs"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Användaroperatorprocedur %qs vid %L måste vara en FUNCTION"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Användaroperatorprocedur %qs vid %L får inte ha antagen teckenlängd"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Användaroperatorprocedur %qs vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Första argumentet till operatorgränssnitt vid %L får inte vara frivilligt"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Andra argumentet till operatorgränssnitt vid %L får inte vara valfritt"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorgränssnitt vid %L måste ha, högst, två argument"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Innesluten procedur %qs vid %L i en PURE-procedur måste också vara PURE"
@@ -71989,17 +72068,17 @@ msgstr "Överlappande olika initierare i EQUIVALENCE vid %C"
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Antalet element i vektorkonstrueraren vid %L kräver en ökning av den tillåtna övre gränsen %d.  Se flaggan %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Skapar vektortemporär vid %L för argument %qs"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "felaktig uttryckstyp under genomlöpning (%d)"
@@ -72090,107 +72169,107 @@ msgstr "ej konstant initieringsuttryck vid %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr "Vektorn %qs vid %L är större än gränsen satt med %<-fmax-stack-var-size=%>, flyttad från stacken till statisk lagring.  Detta gör proceduren osäker när den anropas rekursivt, eller samtidigt från flera trådar.  Överväg att använda %<-frecursive%>, eller öka gränsen %<-fmax-stack-var-size=%>, eller ändra koden till att använda en ALLOCATABLE vektor."
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "inbyggd variabel som inte är en procedur"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Returvärdet för funktionen %qs vid %L är inte satt"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Fördröjd typparameter stödjs inte ännu"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "bakändedeklaration för modulvariabel %qs finns redan"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Oanvänd PRIVATE modulvariabel %qs deklarerad vid %L"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Attrappargument %qs vid %L deklarerades INTENT(OUT) men sattes inte"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Attrappargument med härledd typ %qs vid %L deklarerades INTENT(OUT) men sattes inte och har inte en standardinitierare"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Oanvänt attrappargument %qs vid %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Oanvänd modulvariabel %qs som uttryckligen har importerats vid %L"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Oanvänd variabel %qs deklarerad vid %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Oanvänd parameter %qs deklarerad vid %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Oanvänd parameter %qs som uttryckligen har importerats vid %L"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Returvärdet %qs för funktionen %qs deklarerad vid %L är inte satt"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Ledsen, !$ACC DECLARE vid %L är inte tillåtet i BLOCK-konstruktion"
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "Kan inte beräkna längden på teckenvektorn vid %L."
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Kod för omallokering av den allokerbara variabeln vid %L kommer läggas till"
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Ledsen, co-indexerad åtkomst till ett obegränsat polymorft objekt vid %L stödjs inte ännu"
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Ledsen, co-indexerad åtkomst till en obegränsat polymorf komponent vid %L stödjs inte"
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Okänd inbyggd op"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Okänd argumentlistefunktion vid %L"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Om ommappning av gränser anges vid %L skall pekarmålet inte vara NULL"
@@ -72341,7 +72420,7 @@ msgstr "gfc_validate_kind(): Fick felaktig typ"
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr "gfc_validate_kind(): Fick felaktig sort"
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code(): Felaktig satskod"
@@ -72468,8 +72547,9 @@ msgstr "%<-fwpa%> och %<-fltrans%> är ömsesidigt uteslutande"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99883
 #: lto/lto-lang.c:898
-#, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+#, fuzzy, gcc-internal-format
+#| msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "%<-flinker-output=rel%> och %<-fltrans%> är ömsesidigt uteslutande"
 
 #: lto/lto-object.c:107
@@ -73570,7 +73650,7 @@ msgstr "Okänd flagga till byteordervärde: %qs"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "Okänt argument till -floating-point initieringsvärde: %qs"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "Okänd flagga: %qs"
@@ -73588,15 +73668,15 @@ msgstr "makronamn saknas efter %qs"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "filnamn saknas efter %qs"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "sökväg saknas efter %qs"
@@ -73646,7 +73726,7 @@ msgstr "modulnamn saknas"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "okänt ivar-synlighetsvärde %qs"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "okänt värde för skalär lagringsordning %qs"
@@ -73729,92 +73809,92 @@ msgstr "%qs bör undvikas"
 msgid "unknown linker output %qs"
 msgstr "okänd länkarutmatning %qs"
 
-#: common.opt:1502
+#: common.opt:1506
 #, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "okänd stil för överskjutande precision %qs"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr "okänd specifikation för uppsättningen av värden på FLT_EVAL_METHOD att tillåta %qs"
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "okänd stil för flyttalssammandragning %qs"
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "okänd stackåteranvändningsmodell %qs"
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "okänd nivå för kontrollflödesskydd %qs"
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "okänd IRA-algoritm %qs"
 
-#: common.opt:1902
+#: common.opt:1906
 #, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "okänd IRA-region %qs"
 
-#: common.opt:1980
+#: common.opt:1984
 #, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "okänd LTO-partitioneringsmodell %qs"
 
-#: common.opt:2082
+#: common.opt:2086
 #, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "flaggor eller mål saknas efter %qs"
 
-#: common.opt:2090
+#: common.opt:2094
 #, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "okänd avlastnings-ABI %qs"
 
-#: common.opt:2232
+#: common.opt:2236
 #, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "okänd profilreproduceringsmetod %qs"
 
-#: common.opt:2248
+#: common.opt:2252
 #, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "okänd profiluppdateringsmetod %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr "okänd live-patchnings-nivå %qs"
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "okänd algoritm for omordning av grundblock %qs"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "okänd TLS-modell %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "okänd kostnadsmodell för vektorisering %qs"
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "okänt synlighetsvärde %qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "okänd initieringsprioritet för vtable-verifiering %qs"
@@ -73823,3 +73903,6 @@ msgstr "okänd initieringsprioritet för vtable-verifiering %qs"
 #, gcc-internal-format
 msgid "unknown evrp mode %qs"
 msgstr "okänt evrp-läge %qs"
+
+#~ msgid "cannot deduce template arguments for %qT from %<()%>"
+#~ msgstr "kan inte härleda mallargument för %qT från %<()%>"
diff --git a/gcc/po/tr.po b/gcc/po/tr.po
index e549c1b42bfe9..14aa12cb5d595 100644
--- a/gcc/po/tr.po
+++ b/gcc/po/tr.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 5.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2015-09-11 20:22+0300\n"
 "Last-Translator: Nilgün Belma Bugüner <nilgun@fide.org>\n"
 "Language-Team: Turkish <gnu-tr-u12a@lists.sourceforge.net>\n"
@@ -1401,13 +1401,13 @@ msgstr "%qs için complex geçersiz"
 msgid "this is the insn:"
 msgstr "bu o komuttur:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "aşağıdakiler için yeniden yüklemeler üretilemiyor:"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "aşağıdakiler için yeniden yüklemeler üretilemiyor:"
 
@@ -1604,18 +1604,18 @@ msgstr "tanımlanamayan komut:"
 msgid "insn does not satisfy its constraints:"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "`%s''in farklı ayarları ile oluşturulup kullanılmış"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "-fpic'in farklı ayarları ile oluşturulup kullanıldı"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1664,7 +1664,7 @@ msgstr ""
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC yaklaşımları: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2138,18 +2138,18 @@ msgstr "strfmon biçiminde uzunluk değiştirici"
 msgid "<command-line>"
 msgstr "<komut-satırı>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, fuzzy, c-format
@@ -2157,78 +2157,78 @@ msgstr "terim, kod `%c' için geçersiz"
 msgid "invalid operand for '%%%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid vector constant"
 msgstr "geçersiz komut:"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "terim eksik"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "geçersiz komut:"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "geçersiz %%d terimi"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "adres geçersiz"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 #| msgid "invalid operands to binary %s"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "iki terimli %s için terimler geçersiz"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2244,18 +2244,18 @@ msgid "invalid %%r value"
 msgstr "%%r değeri geçersiz"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "%%R değeri geçersiz"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "%%N değeri geçersiz"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "%%P değeri geçersiz"
@@ -2285,7 +2285,7 @@ msgstr "%%M değeri geçersiz"
 msgid "invalid %%U value"
 msgstr "%%U değeri geçersiz"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "%%s değeri geçersiz"
@@ -2295,7 +2295,7 @@ msgstr "%%s değeri geçersiz"
 msgid "invalid %%C value"
 msgstr "%%C değeri geçersiz"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "%%E değeri geçersiz"
@@ -2308,7 +2308,7 @@ msgstr "bilinmeyen yerdeğişim unspec"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "%%xn kodu geçersiz"
@@ -2397,37 +2397,37 @@ msgstr "terim olarak UNSPEC geçersiz"
 msgid "unrecognized supposed constant"
 msgstr "tanınmayan tahmini sabit"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "geçersiz %%f terimi"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "isnatlı Thumb komutu"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "koşullu dizilimde isnatlı komut"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2435,14 +2435,14 @@ msgstr "terim, kod `%c' için geçersiz"
 msgid "invalid operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
 msgstr "komut hiç çalıştırılmadı"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2585,8 +2585,8 @@ msgstr "beklenmeyen terim"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2970,7 +2970,7 @@ msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 msgid "invalid %%P operand"
 msgstr "%%P terimi geçersiz"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "%%p değeri geçersiz"
@@ -3028,7 +3028,7 @@ msgid "post-increment address is not a register"
 msgstr "sonradan arttırımlı adres bir yazmaç değil"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "hatalı adres"
 
@@ -3085,8 +3085,8 @@ msgstr "'%s' geçerli bir sınıf ismi değil"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, fuzzy, c-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of '%%%c'"
@@ -3235,342 +3235,342 @@ msgstr "Yığıt taştı.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Sınırını belirlemek için kabukta `%s' çalıştırmayı deneyin.\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Donanım kayan nokta aritmetiği kullanılır"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "İndisli adresleme kapatılır"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-f%s ile -msdata=%s uyumsuz."
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "Kıymetsiz baytın başta olduğu kod üretilir"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "hatalı test"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "%%D değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "%%f değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "%%F değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "%%G değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "%%j kodu geçersiz"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "%%J kodu geçersiz"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "%%k değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "%%K değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "%%O değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "%%q değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "%%T değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "%%u değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "%%v değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "%%x değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Her işlev için tek çıkış noktası üretilmez"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "aşağıdakiler için yeniden yüklemeler üretilemiyor:"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "adres çözümlenemez"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "'O' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "geçersiz terim çıktı kodu"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression - try using an output modifier"
 msgstr "terim olarak ifade geçersiz"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "dönüş değerinde gösterici hedefleri farklı signed'lıkta"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 #, fuzzy
 #| msgid "target format does not support infinity"
 msgid "binary operator does not support vector bool operand"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3855,8 +3855,8 @@ msgstr "<anonim>"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> umuluyordu"
@@ -3876,7 +3876,7 @@ msgstr "%<;%> umuluyordu"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -3885,7 +3885,7 @@ msgstr "%<{%> umuluyordu"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -3906,14 +3906,14 @@ msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<(%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -3921,8 +3921,8 @@ msgstr "%<{%> umuluyordu"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> umuluyordu"
@@ -3933,14 +3933,14 @@ msgstr "%<{%> umuluyordu"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -3950,7 +3950,7 @@ msgstr "%<{%> umuluyordu"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -3962,20 +3962,20 @@ msgstr "%<{%> umuluyordu"
 msgid "expected %<.%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -3984,32 +3984,32 @@ msgstr "%<,%> veya %<;%> umuluyordu"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> umuluyordu"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 #, fuzzy
 #| msgid "<anonymous>"
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -4028,13 +4028,13 @@ msgstr "sınıf ismi umuluyordu"
 msgid "candidate:"
 msgstr "1. aday:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 #| msgid "Enable use of DB instruction"
 msgid "  after user-defined conversion:"
 msgstr "DB komutunun kullanımı etkin olur"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -4042,19 +4042,19 @@ msgid_plural "candidates are:"
 msgstr[0] "1. aday:"
 msgstr[1] "1. aday:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "1. aday:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "2. aday:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "%qD yaftasına jump"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "case yaftasına jump"
 
@@ -4315,33 +4315,33 @@ msgstr "yerel değişken %qD bu kapsamda görünemez"
 msgid "local variable %qD may not appear in this context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "%<using enum%> of dependent type %qT"
 msgstr "tamamlanmamış typedef %qD kullanımı geçersiz"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 #| msgid "%qT is not a template type"
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%qT bir şablon türü değil"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 #| msgid "invalid use of incomplete typedef %qD"
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "tamamlanmamış typedef %qD kullanımı geçersiz"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "adaylar:"
 
@@ -4399,50 +4399,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tek terimli eksiye yanlış türde argüman"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bit-tümler için yanlış türde argüman"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs'a yanlış türde argüman"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "mantıksal çarpım için yanlış türde argüman"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4548,7 +4548,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Sürülüm:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 #, fuzzy
 #| msgid "Actual argument at %L must be definable to match dummy INTENT = OUT/INOUT"
 msgid "actual argument to INTENT = OUT/INOUT"
@@ -4686,7 +4686,7 @@ msgstr "Hatalı işleç"
 msgid "Bad type in constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "Beklenmeyen modül sonu"
 
@@ -4714,11 +4714,11 @@ msgstr "blok IF"
 msgid "implied END DO"
 msgstr "örtük END DO"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "atama"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "gösterici ataması"
 
@@ -4834,177 +4834,177 @@ msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, fuzzy, c-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "%%L'deki tek terimli sayısal '%s' işlecinin terimi %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki iki terimli sayısal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "%%L'deki dizge ekleme işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki mantıksal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L'deki .NOT. işlecinin terimi %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L'de COMPLEX nicelikler karşılaştırılamıyor"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L'deki mantıksallar %s ile karşılaştırılmalı %s ile değil"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki '%s' karşılaştırma işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimi %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Değişken izleme uygulanır"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "terim olarak ifade geçersiz"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "YERAÇ "
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "AYIR "
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5136,27 +5136,27 @@ msgstr "Dizi başvurusu sınırların dışında"
 msgid "Incorrect function return value"
 msgstr "İşlevinin dönüş değeri yanlış"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 #| msgid "gimplification failed"
 msgid "Error allocating %lu bytes"
 msgstr "gimpleme başarısız"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr ""
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr ""
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -5385,17 +5385,17 @@ msgstr "-Xbind-now ile -Xbind-lazy uyumsuz"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "-EB ve -EL birlikte kullanılamayabilir"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 #, fuzzy
 #| msgid "-msoft-float and -mhard_float may not be used together"
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-msoft-float ve -mhard_float birlikte kullanılamayabilir"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian ve -mlittle-endian birlikte kullanılamayabilir"
 
@@ -5417,8 +5417,8 @@ msgstr "belirtim dosyası ilintilenecek özellik içermiyor"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "hem -C hem de -o belirtilemez"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared ve mdll uyumsuz"
 
@@ -5600,10 +5600,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "İşlev gösterici aritmetiği hakkında uyarır"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -6132,175 +6132,175 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "Modül öğelerinin öntanımlı erişilebilirliğini PRIVATE yapar"
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, fuzzy, no-c-format
 #| msgid "Try to layout derived types as compact as possible"
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "Türetilmiş türler mümkün olduğunca yoğun tertiplenmeye çalışılır"
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 #| msgid "Expected a right parenthesis in expression at %C"
 msgid "Protect parentheses in expressions."
 msgstr "%C'deki ifadede bir sağ parantez umuluyordu"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable range checking during compilation."
 msgstr "İlintileyici en iyilemesi etkinleştirilir"
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, fuzzy, no-c-format
 #| msgid "incompatible types in assignment"
 msgid "Reallocate the LHS in assignments."
 msgstr "atamada uyumsuz türler"
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, fuzzy, no-c-format
 #| msgid "Use a 4-byte record marker for unformatted files"
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Biçimlenmemiş dosyalar için 4 baytlık kayıt imleyici kullanılır"
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, fuzzy, no-c-format
 #| msgid "Use an 8-byte record marker for unformatted files"
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Biçimlenmemiş dosyalar için 8 baytlık kayıt imleyici kullanılır"
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, fuzzy, no-c-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, fuzzy, no-c-format
 #| msgid "Append a second underscore if the name already contains an underscore"
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "İsim zaten bir altçizgi içeriyorsa bir ikinci altçizgi ekler"
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, fuzzy, no-c-format
 #| msgid "Append underscores to externally visible names"
 msgid "Append underscores to externally visible names."
 msgstr "Dışsal olarak görünür isimlere altçizgiler ekler"
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "ISO Fortran 2003 standardına uyumlu olunur"
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "ISO Fortran 2003 standardına uyumlu olunur"
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "ISO Fortran 2003 standardına uyumlu olunur"
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "ISO Fortran 2003 standardına uyumlu olunur"
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 95 standard"
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "ISO Fortran 95 standardına uyumlu olunur"
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, fuzzy, no-c-format
 #| msgid "Conform nothing in particular"
 msgid "Conform to nothing in particular."
 msgstr "Hiçbir şeye uyumlu olunmaz"
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, fuzzy, no-c-format
 #| msgid "Accept extensions to support legacy code"
 msgid "Accept extensions to support legacy code."
@@ -7073,7 +7073,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7767,8 +7767,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, fuzzy, no-c-format
 #| msgid "switch %qs is no longer supported"
 msgid "No longer supported."
@@ -8162,543 +8162,538 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, fuzzy, no-c-format
 #| msgid "Unclassifiable statement at %C"
 msgid "Enable OpenMP's SIMD directives."
 msgstr "%C'de tasnif edilemeyen deyim"
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, fuzzy, no-c-format
 #| msgid "Recognize C++ kewords like \"compl\" and \"xor\""
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "\"compl\" ve \"xor\" benzeri C++ anahtar sözcükleri tanınır"
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, fuzzy, no-c-format
 #| msgid "Look for and use PCH files even when preprocessing"
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "Önişlem yaparken bile PCH dosyalarına bakılır ve kullanılır"
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, fuzzy, no-c-format
 #| msgid "Downgrade conformance errors to warnings"
 msgid "Downgrade conformance errors to warnings."
 msgstr "Uyumluluk hatalarını uyarılara indirger"
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, fuzzy, no-c-format
 #| msgid "Enable linker relaxations"
 msgid "Enable Plan 9 language extensions."
 msgstr "İlintileyici esnekleştiriciler etkin olur"
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, fuzzy, no-c-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "Treat the input file as already preprocessed."
 msgstr "Girdi dosyaları evvelce önişlemden geçirilmiş kabul edilir"
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, fuzzy, no-c-format
 #| msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime"
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "Nesne dosyalarının çalışma anında takaslanabileceğini belirten Fix-and-Continue kipi kullanılır"
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "Önerilmiyor. Bu seçenek etkisizdir."
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, fuzzy, no-c-format
 #| msgid "Generate run time type descriptor information"
 msgid "Generate run time type descriptor information."
 msgstr "Çalışma anı tür tanımlayıcı bilgisi üretilir"
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, fuzzy, no-c-format
 #| msgid "Use the narrowest integer type possible for enumeration types"
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "Sıralı sabit türleri için olası en dar tamsayı türü kullanılır"
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\""
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "\"wchar_t\" için temel türün \"unsigned short\" olmasını sağlar"
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "\"signed\" veya \"unsigned\" verilmezse bit alanı sign'lı yapılır"
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, fuzzy, no-c-format
 #| msgid "Make \"char\" signed by default"
 msgid "Make \"char\" signed by default."
 msgstr "Öntanımlı olarak \"char\" sign'lı yapılır"
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, fuzzy, no-c-format
 #| msgid "Specify if floating point hardware should be used"
 msgid "Enable C++14 sized deallocation support."
 msgstr "Eğer kayan nokta donanımı kulanılmalıysa belirtilir"
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, fuzzy, no-c-format
 #| msgid "Display statistics accumulated during compilation"
 msgid "Display statistics accumulated during compilation."
 msgstr "Derleme sırasında toplanan istatistikler gösterilir"
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, fuzzy, no-c-format
 #| msgid "Set the maximum number of iterations for RPTS to N"
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "RPTS için azami yineleme sayısını N yapar"
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, fuzzy, no-c-format
 #| msgid "Specify maximum template instantiation depth"
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "Azami şablon örnekleme derinliği belirtilir"
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, fuzzy, no-c-format
 #| msgid "Do not generate thread-safe code for initializing local statics"
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "Yerel istatistiklerin ilklendirilmesi için evrece güvenli kod üretilmez"
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "\"signed\" veya \"unsigned\" verilmediğinde bit alanı unsigned olur"
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, fuzzy, no-c-format
 #| msgid "Make \"char\" unsigned by default"
 msgid "Make \"char\" unsigned by default."
 msgstr "\"char\" öntanımlı olarak unsigned yapılır"
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, fuzzy, no-c-format
 #| msgid "Use __cxa_atexit to register destructors"
 msgid "Use __cxa_atexit to register destructors."
 msgstr "Yazmaç yıkıcılara __cxa_atexit kullanılır"
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr ""
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, fuzzy, no-c-format
 #| msgid "Marks all inlined methods as having hidden visibility"
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "Tüm satıriçine alınmış yöntemler gizli görünürlüğe sahip olarak imlenir"
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Emit common-like symbols as weak symbols"
 msgid "Emit common-like symbols as weak symbols."
 msgstr "Benzer semboller zayıf semboller olarak ele alınir"
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, fuzzy, no-c-format
 #| msgid "Convert all wide strings and character constants to character set <cset>"
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "Tüm geniş karakterli dizgeler ve sabitler <kküme> karakter kümesine dönüştürülür"
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, fuzzy, no-c-format
 #| msgid "Generate a #line directive pointing at the current working directory"
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "O anki çalışma dizinini betimleyen bir #line yönergesi üretilir"
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, fuzzy, no-c-format
 #| msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode"
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "Zero-Link kipinde kullanmak için çılgın sınıf araması (objc_getClass() üzerinden) üretilir"
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Dump declarations to a .decl file"
 msgid "Dump declarations to a .decl file."
 msgstr "Bildirimler bir .decl dosyasına dökümlenir"
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the system include path"
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "<dizin> sistem başlık dosyaları arama yolunun sonuna eklenir"
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, fuzzy, no-c-format
 #| msgid "Accept definition of macros in <file>"
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "<dosya>daki makro tanımları kabul edilir"
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, fuzzy, no-c-format
 #| msgid "Set <dir> to be the system root directory"
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "<dizin> sistemin kök dizini olur"
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, fuzzy, no-c-format
 #| msgid "Include the contents of <file> before other files"
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "<dosya>nın içeriği diğer dosyaların başlangıcına eklenir"
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, fuzzy, no-c-format
 #| msgid "Specify <path> as a prefix for next two options"
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "<yol> sonraki iki seçenek için önek olur"
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, fuzzy, no-c-format
 #| msgid "Set <dir> to be the system root directory"
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "<dizin> sistemin kök dizini olur"
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the start of the system include path"
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "<dizin> sistem başlık dosyaları arama yolunun başına eklenir"
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the quote include path"
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "<dizin> tırnaklı başlık dosyaları arama yolunun sonuna eklenir"
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the system include path"
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "<dizin> sistem başlık dosyaları arama yolunun sonuna eklenir"
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, fuzzy, no-c-format
 #| msgid "Add <dir> to the end of the main include path"
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "<dizin> ana başlık dosyaları arama yolunun sonuna eklenir"
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories (those specified with -isystem will still be used)"
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "Standart sistem başlık dosyaları dizinleri aranmaz (-isystem ile belirtilenler yine de kullanılır) "
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories for C++"
 msgid "Do not search standard system include directories for C++."
 msgstr "C++ için standart sistem başlık dosyaları dizinleri aranmaz"
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, fuzzy, no-c-format
 #| msgid "Generate C header of platform-specific features"
 msgid "Generate C header of platform-specific features."
 msgstr "Platforma özel niteliklerin C başlıklarını üretir"
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, fuzzy, no-c-format
 #| msgid "Remap file names when including files"
 msgid "Remap file names when including files."
 msgstr "Dosyalar içerildiğinde dosya isimleri yeniden eşlenir"
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "GNU oluşumlu ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++11."
 msgstr "-std=c99  lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++14."
 msgstr "-std=c99  lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++17."
 msgstr "-std=c99  lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "GNU oluşumlu ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "GNU oluşumlu ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2011 C standard."
 msgstr "ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c11."
 msgstr "-std=c99  lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "ISO 1990 C standardına 1994 düzeltmesiyle uyulur"
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "ISO 1990 C standardına 1994 düzeltmesiyle uyulur"
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 1990 C standard."
 msgstr "ISO 1990 C standardına uyulur"
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard"
 msgid "Conform to the ISO 1999 C standard."
 msgstr "ISO 1999 C standardına uyulur"
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c99."
 msgstr "-std=c99  lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "GNU oluşumlu ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "GNU oluşumlu ISO 1990 C standardına uyulur"
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "-std=gnu99 lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "-std=gnu99 lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "GNU oluşumlu ISO 1990 C standardına uyulur"
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "-std=gnu99 lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "GNU oluşumlu ISO 1990 C standardına uyulur"
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "GNU oluşumlu ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "GNU oluşumlu ISO 1998 C++ standardına uyulur"
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "GNU oluşumlu ISO 1990 C standardına uyulur"
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "-std=gnu99 lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "GNU oluşumlu ISO 1990 C standardına uyulur"
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "GNU oluşumlu ISO 1990 C standardına uyulur"
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "GNU oluşumlu ISO 1990 C standardına uyulur"
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard with GNU extensions"
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "GNU oluşumlu ISO 1999 C standardına uyulur"
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "-std=gnu99 lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "ISO 1990 C standardına 1994 düzeltmesiyle uyulur"
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=iso9899:1999"
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "-std=iso9899:1999 lehine kullanımı önerilmiyor"
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable traditional preprocessing."
 msgstr "Geleneksel önişlem etkin olur"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, fuzzy, no-c-format
 #| msgid "Support ISO C trigraphs"
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "ISO C üçlü harfleri desteklenir"
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Do not predefine system-specific and GCC-specific macros"
 msgid "Do not predefine system-specific and GCC-specific macros."
@@ -8962,6 +8957,12 @@ msgstr ""
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+#| msgid "Emit implicit instantiations of templates"
+msgid "Emit template instantiations as weak symbols."
+msgstr "Şablonlarının örtük örneklenimleri çıktılanır"
+
 #: d/lang.opt:346
 #, fuzzy, no-c-format
 #| msgid "Do not assume that standard C libraries and \"main\" exist"
@@ -10308,158 +10309,172 @@ msgstr ""
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as big endian"
+msgid "Assume target CPU is configured as big endian."
+msgstr "Hedef işlemci kıymetli baytın başta olduğu yapılandırmaya sahip kabul edilir"
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as little endian"
+msgid "Assume target CPU is configured as little endian."
+msgstr "Hedef işlemci kıymetsiz baytın başta olduğu yapılandırmaya sahip kabul edilir"
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 #| msgid "Specify the name of the target floating point hardware/format"
 msgid "Specify integer and floating-point calling convention."
 msgstr "Hedef kayan noktalı donanım/biçim ismi belirtilir"
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, fuzzy, no-c-format
 #| msgid "Attempt to keep stack aligned to this power of 2"
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Bunun 2.kuvvetine ayarlanmış yığıt tutmaya çalışır"
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 #| msgid "Allow the use of hardware floating-point instructions"
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Donanım kayan nokta komutlarının kullanımına izin verilir"
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 #| msgid "Use trap instructions to check for integer divide by zero"
 msgid "Use hardware instructions for integer division."
 msgstr "Tamsayıların sıfırla bölünmesinde sınama için yakalama komutları kullanılır"
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, fuzzy, no-c-format
 #| msgid "Optimize the output for PROCESSOR"
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "Çıktı İŞLEMCİ için eniyilenir"
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 #| msgid "Optimize the output for PROCESSOR"
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "Çıktı İŞLEMCİ için eniyilenir"
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, fuzzy, no-c-format
 #| msgid "Put global and static data smaller than <number> bytes into a special section (on some targets)"
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "Global ve static verileri <sayı> bayttan küçükse bir özel bölüme (bazı hedeflerdeki) koyar"
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "İşlev önbilgisi/sonbilgisi için altyordamlar kullanılır"
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, fuzzy, no-c-format
 #| msgid "Specify the register allocation order"
 msgid "Specify the code model."
 msgstr "Yazmaç ayırma sırası belirtilir"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 #| msgid "Do not use unaligned memory references"
 msgid "Do not generate unaligned memory accesses."
 msgstr "Hizalamasız bellek referansları kullanılmaz"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, fuzzy, no-c-format
 #| msgid "Do not tune writable data alignment"
 msgid "Use the given data alignment."
 msgstr "Yazılabilir veri hizalaması ayarlanmaz"
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, fuzzy, no-c-format
 #| msgid "Use propolice as a stack protection method"
 msgid "Use given stack-protector guard."
 msgstr "Yığıt koruma yöntemi olarak propolice kullanılır"
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, fuzzy, no-c-format
 #| msgid "invalid option for -mfloat-gprs: '%s'"
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "-mfloat-gprs için seçenek geçersiz: '%s'"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, fuzzy, no-c-format
 #| msgid "Use propolice as a stack protection method"
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Yığıt koruma yöntemi olarak propolice kullanılır"
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, fuzzy, no-c-format
 #| msgid "Use propolice as a stack protection method"
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Yığıt koruma yöntemi olarak propolice kullanılır"
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr ""
@@ -10600,13 +10615,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as big endian"
-msgid "Assume target CPU is configured as big endian."
-msgstr "Hedef işlemci kıymetli baytın başta olduğu yapılandırmaya sahip kabul edilir"
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 #| msgid "Generate code without GP reg"
@@ -10629,13 +10637,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as little endian"
-msgid "Assume target CPU is configured as little endian."
-msgstr "Hedef işlemci kıymetsiz baytın başta olduğu yapılandırmaya sahip kabul edilir"
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -18856,2437 +18857,2437 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "Dökümleme için kullanılacak dosyanın salt ismi belirtilir"
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "İşlevlerin başlangıcı hizalanır"
 
-#: common.opt:988
+#: common.opt:992
 #, fuzzy, no-c-format
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "Sadece atlanarak ulaşılabilen yaftalara hizalanır"
 
-#: common.opt:995
+#: common.opt:999
 #, fuzzy, no-c-format
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "Tum yaftalara hizalanır"
 
-#: common.opt:1002
+#: common.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "Döngü başlangıcına hizalanır"
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable static analysis pass."
 msgstr "Geleneksel önişlem etkin olur"
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy, no-c-format
 #| msgid "Select the target MCU"
 msgid "Select what to sanitize."
 msgstr "Hedef MCU ismi belirtilir"
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, fuzzy, no-c-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, fuzzy, no-c-format
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Birbirlerini etkilemeyenlerin tablosu her komutun tam sınırında oluşturulur"
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "isel komutları üretilir"
 
-#: common.opt:1073
+#: common.opt:1077
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Dallanma olasılıkları için ayrımlama bilgileri kullanılır"
 
-#: common.opt:1078
+#: common.opt:1082
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Dallanma olasılıkları için ayrımlama bilgileri kullanılır"
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Diziler indislenmeden önce sınırlarını sınayacak kod üretilir"
 
-#: common.opt:1091
+#: common.opt:1095
 #, fuzzy, no-c-format
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Ekleme, karşılaştırma, dallanma sayaç yazmacı üzerinden dallanma ile değiştirilir"
 
-#: common.opt:1095
+#: common.opt:1099
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "Dallanma olasılıkları için ayrımlama bilgileri kullanılır"
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output callgraph information on a per-file basis."
 msgstr "Her işlev için r30 yeniden kullanılır"
 
-#: common.opt:1115
+#: common.opt:1119
 #, fuzzy, no-c-format
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "Her işlev için r30 yeniden kullanılır"
 
-#: common.opt:1119
+#: common.opt:1123
 #, fuzzy, no-c-format
 #| msgid "Mark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "<yazmaç> işlevlere karşı korunmuş olarak imlenir"
 
-#: common.opt:1123
+#: common.opt:1127
 #, fuzzy, no-c-format
 #| msgid "Mark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "<yazmaç> işlev çağrıları tarafından bozulmuş olarak imlenir"
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "İşlev çağrıları civarındaki yazmaçlar saklanır"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy, no-c-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy, no-c-format
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "new için dönüş değeri sınanır"
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, fuzzy, no-c-format
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "dahili tutarlılık hatası"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "İşlev ayrımlama etkinleştirilir"
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Put uninitialized globals in the common section."
 msgstr "İlklendirilmemiş global'ler ortak bölüme konmaz"
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Global ortak alt ifade elemesi yazmaç ayırmasından sonra uygulanır"
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy, no-c-format
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Yazmaç kopyalama girişimi eniyileme geçişi uygulanır"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy, no-c-format
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "Çapraz atlama eniyilemesi uygulanır"
 
-#: common.opt:1190
+#: common.opt:1194
 #, fuzzy, no-c-format
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Ortak alt ifade elemesi sırasında hedeflerine dallanmalar izlenir"
 
-#: common.opt:1198
+#: common.opt:1202
 #, fuzzy, no-c-format
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "Karmaşık bölme sırasında aralık arttırma adımı atlanır"
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, fuzzy, no-c-format
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "Veri öğelerini kendi bölümlerine yerleştirir"
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, fuzzy, no-c-format
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "Yığıttan işlev argümanlarının çekilmesini erteler"
 
-#: common.opt:1236
+#: common.opt:1240
 #, fuzzy, no-c-format
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Dallanma komutlarının gecikme yuvalarını doldurmaya çalışır"
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, fuzzy, no-c-format
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "Kullanışsız boş gösterici sınamalarını siler"
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, fuzzy, no-c-format
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization."
 msgstr "Kuyruk tekrarı üzerinden süper blok oluşumu uygulanır"
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, fuzzy, no-c-format
 #| msgid "How often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "Satır sarmalamalı teşhislerin başlangıcında kaynak konumunun ne sıklıkta gösterileceği belirtilir. once: bir kere, every-line: her satırda"
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, fuzzy, no-c-format
 #| msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "İlgili teşhis iletileri onları denetleyen komut satırı seçenekleri ile iyileştirilir"
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, fuzzy, no-c-format
 #| msgid "Distance between tab stops for column reporting"
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "Sütunlu raporlama için sekme durakları arası mesafe"
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, fuzzy, no-c-format
 #| msgid "Dump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "Çeşitli derleyici iç oluşumları bir dosyaya dökümlenir"
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, fuzzy, no-c-format
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Hata ayıklama dökümlerinde satır numarası ve komut numarası bilgilerinin çıktılanması engellenir"
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, fuzzy, no-c-format
 #| msgid "Perform loop optimizations"
 msgid "Dump optimization passes."
 msgstr "Döngü eniyilemeleri uygulanır"
 
-#: common.opt:1455
+#: common.opt:1459
 #, fuzzy, no-c-format
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Hata ayıklama dökümlerinde satır numarası ve komut numarası bilgilerinin çıktılanması engellenir"
 
-#: common.opt:1459
+#: common.opt:1463
 #, fuzzy, no-c-format
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Hata ayıklama dökümlerinde satır numarası ve komut numarası bilgilerinin çıktılanması engellenir"
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1471
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "Erken satıriçine alma uygulanır"
 
-#: common.opt:1475
+#: common.opt:1479
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1479
+#: common.opt:1483
 #, fuzzy, no-c-format
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Hata ayıklama bilgilerinde kullanılmamış tür elemesi uygulanır"
 
-#: common.opt:1483
+#: common.opt:1487
 #, fuzzy, no-c-format
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "Hata ayıklama bilgilerinde kullanılmamış tür elemesi uygulanır"
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Olağan dışılıkların yakalanması etkinleştirilir"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy, no-c-format
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Masraflı eniyilemelerden birkaçını uygular"
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, fuzzy, no-c-format
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "NaNların ya da sonsuzların üretilmediği varsayılır"
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, fuzzy, no-c-format
 #| msgid "Mark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "<yazmaç> derleyici için elverişsiz olarak imlenir"
 
-#: common.opt:1546
+#: common.opt:1550
 #, fuzzy, no-c-format
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Ek duyarlık yazmaçlarında float'lar ve double'lar ayrılmaz"
 
-#: common.opt:1554
+#: common.opt:1558
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Ağaçlarda Değer Aralığı Girişimi uygulanır"
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, fuzzy, no-c-format
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "Yazmaçlarda tutulan işlev adreslerine izin verilir"
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "Her işlev kendi bölümüne yerleştirilir"
 
-#: common.opt:1590
+#: common.opt:1594
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "Global ortak alt ifade elemesi uygulanır"
 
-#: common.opt:1594
+#: common.opt:1598
 #, fuzzy, no-c-format
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Global ortak alt ifade elemesi sırasında genişletilmiş yük hareketi uygulanır"
 
-#: common.opt:1598
+#: common.opt:1602
 #, fuzzy, no-c-format
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Global ortak alt ifade elemesinden sonra saklama hareketi uygulanır"
 
-#: common.opt:1602
+#: common.opt:1606
 #, fuzzy, no-c-format
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Genel ortak alt ifade içindeki saklama elemesinden sonra gereğinden fazla yük uygulanır"
 
-#: common.opt:1607
+#: common.opt:1611
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Global ortak alt ifade elemesi yazmaç ayırmasından sonra uygulanır"
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Enable in and out of Graphite representation."
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:1633
+#: common.opt:1637
 #, fuzzy, no-c-format
 #| msgid "Emit call graph information"
 msgid "Enable Graphite Identity transformation."
 msgstr "Çağrı çizge bilgisi üretir"
 
-#: common.opt:1637
+#: common.opt:1641
 #, fuzzy, no-c-format
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Koşullu taşımalar etkin olur"
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "Ağaçlarda döngü başlığı kopyalaması etkin olur"
 
-#: common.opt:1667
+#: common.opt:1671
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, fuzzy, no-c-format
 #| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "Yafta hizalama eniyilemesi etkin olur"
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, fuzzy, no-c-format
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "Dallanma olasılıklarının tahmini etkinleştirilir"
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "#ident yönergeleri işlenir"
 
-#: common.opt:1707
+#: common.opt:1711
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Dallanmasız karşılıklara koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:1711
+#: common.opt:1715
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Koşullu çalıştırmaya koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Dallanmasız karşılıklara koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr ".size yönergeleri üretilmez"
 
-#: common.opt:1747
+#: common.opt:1751
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform indirect inlining."
 msgstr "Erken satıriçine alma uygulanır"
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, fuzzy, no-c-format
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Basit işlevler onları çağıranların içine gömülür"
 
-#: common.opt:1761
+#: common.opt:1765
 #, fuzzy, no-c-format
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "İşlevler onları çağıranların içine bir defa gömülür"
 
-#: common.opt:1765
+#: common.opt:1769
 #, fuzzy, no-c-format
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "İşlevler onları çağıranların içine bir defa gömülür"
 
-#: common.opt:1772
+#: common.opt:1776
 #, fuzzy, no-c-format
 #| msgid "Limit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "Satıriçine alınacak işlevlerin uzunluğu <sayı> ile sınırlanır"
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, fuzzy, no-c-format
 #| msgid "Instrument function entry and exit with profiling calls"
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "İşlevi giriş ve çıkışı ayrımlama çağrılarıyla yapılır"
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1822
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1822
+#: common.opt:1826
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1830
+#: common.opt:1834
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1834
+#: common.opt:1838
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural modref analysis."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1838
+#: common.opt:1842
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural profile propagation."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1842
+#: common.opt:1846
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural points-to analysis."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "Saf ve sabit işlevler keşfedilir"
 
-#: common.opt:1850
+#: common.opt:1854
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for functions."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:1858
+#: common.opt:1862
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only and non addressable static variables."
 msgstr "Salt okunur ve adreslenemeyen durağan değişkenler keşfedilir"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "Salt okunur ve adreslenemeyen durağan değişkenler keşfedilir"
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "Ağaçlarda Değer Aralığı Girişimi uygulanır"
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, fuzzy, no-c-format
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "Ağaçlarda tümevarım değişkenleri eniyilenir"
 
-#: common.opt:1941
+#: common.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Yeterince büyük switch deyimleri için sıçrama tabloları kullanılır"
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "Yeterince büyük switch deyimleri için sıçrama tabloları kullanılır"
 
-#: common.opt:1949
+#: common.opt:1953
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Tamamen satıriçi olsalar bile işlevler için kod üretilir"
 
-#: common.opt:1953
+#: common.opt:1957
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "Tamamen satıriçi olsalar bile işlevler için kod üretilir"
 
-#: common.opt:1957
+#: common.opt:1961
 #, fuzzy, no-c-format
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "Kullanılmamış bile olsa statik sabit değişkenler içerilir"
 
-#: common.opt:1961
+#: common.opt:1965
 #, fuzzy, no-c-format
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "Alt çizgi ile başlayan harici simgeler verilir"
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "İlintileyici en iyilemesi etkinleştirilir"
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Report various link-time optimization statistics."
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:2016
+#: common.opt:2020
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "Yerleşik matematik işlevlerinden sonra errno kullanılır"
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:2028
+#: common.opt:2032
 #, fuzzy, no-c-format
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "Ayrılan kalıcı bellek miktarı raporlanır"
 
-#: common.opt:2032
+#: common.opt:2036
 #, fuzzy, no-c-format
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Ayrılan kalıcı bellek miktarı raporlanır"
 
-#: common.opt:2039
+#: common.opt:2043
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Özdeş sabitler ve sabit değişkenleri katıştırılmaya çalışılır"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Özdeş sabitler derleme birimlerine karşın katıştırılmaya çalışılır"
 
-#: common.opt:2047
+#: common.opt:2051
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Özdeş sabitler derleme birimlerine karşın katıştırılmaya çalışılır"
 
-#: common.opt:2051
+#: common.opt:2055
 #, fuzzy, no-c-format
 #| msgid "Limit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "Teşhis iletilerinin uzunluğu her satırda <sayı> karakterle sınırlanır. 0 satır sarmalamayı engeller"
 
-#: common.opt:2055
+#: common.opt:2059
 #, fuzzy, no-c-format
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "İlk zamanlama geçişinden önce SMS tabanlı artanlı zamanlama uygular"
 
-#: common.opt:2059
+#: common.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "İlk zamanlama geçişinden önce SMS tabanlı artanlı zamanlama uygular"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy, no-c-format
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "Döngü ile değişmeyen hesaplamalar döngü dışına taşınır"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead code elimination pass."
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead store elimination pass."
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy, no-c-format
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Zaten artanlı zamanlamaya tabi tutulmuş döngülerde geleneksel zamanlama etkin olur/iptal edilir"
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "Eşzamanlı çağrısız olağandışılıklar desteklenir"
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, fuzzy, no-c-format
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "Mümkün olduğunca yığıt çerçeveleri üretilmez"
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Ağaç seviyesinde döngü eniyilemeleri etkinleştirilir"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, fuzzy, no-c-format
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Kardeş ve kuyruk özyinelemeli çağrıları eniyilenir"
 
-#: common.opt:2124
+#: common.opt:2128
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform partial inlining."
 msgstr "Erken satıriçine alma uygulanır"
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy, no-c-format
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "Yapı üyelerini birlikte deliksiz paketler"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy, no-c-format
 #| msgid "Set initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "İlk azami yapı üyesi hizalaması belirtilir"
 
-#: common.opt:2144
+#: common.opt:2148
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "Yazmaçlardaki değil bellekteki küçük kümeler döndürülür"
 
-#: common.opt:2148
+#: common.opt:2152
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "Döngü soyması uygulanır"
 
-#: common.opt:2152
+#: common.opt:2156
 #, fuzzy, no-c-format
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "Makineye özel gözlem deliği eniyilemesi etkinleştirilir"
 
-#: common.opt:2156
+#: common.opt:2160
 #, fuzzy, no-c-format
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "sched2 öncesi bir rtl gözlem deliği aşaması etkin olur"
 
-#: common.opt:2160
+#: common.opt:2164
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Mümkünse, konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:2164
+#: common.opt:2168
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:2168
+#: common.opt:2172
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Mümkünse, konumdan bağımsız kod üretilir (küçük kip)"
 
-#: common.opt:2172
+#: common.opt:2176
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (küçük kip)"
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, fuzzy, no-c-format
 #| msgid "Specify options to GNAT"
 msgid "Specify a plugin to load."
 msgstr "GNAT'a özgü seçenekler"
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, fuzzy, no-c-format
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Yazmaç taşıma eniyilemesi etkinleştirilir"
 
-#: common.opt:2192
+#: common.opt:2196
 #, fuzzy, no-c-format
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Mümkünse, döngülerdeki diziler için önalım komutları üretilir"
 
-#: common.opt:2196
+#: common.opt:2200
 #, fuzzy, no-c-format
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "Temel program profil çıkarma kodu etkinleştirilir"
 
-#: common.opt:2200
+#: common.opt:2204
 #, fuzzy, no-c-format
 #| msgid "Generate fast indirect calls"
 msgid "Generate absolute source path names for gcov."
 msgstr "Hızlı dolaylı çağrılar üretilir"
 
-#: common.opt:2204
+#: common.opt:2208
 #, fuzzy, no-c-format
 #| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "arc-tabanlı yazılım ayrımlama kodu eklenir"
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, fuzzy, no-c-format
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin ayrımlama bilgileri üretimi için ortak seçenekler etkinleştirilir"
 
-#: common.opt:2269
+#: common.opt:2273
 #, fuzzy, no-c-format
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin ayrımlama bilgileri üretimi için ortak seçenekler etkinleştirilir"
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, fuzzy, no-c-format
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin uygulanması için ortak seçenekler etkinleştirilir"
 
-#: common.opt:2289
+#: common.opt:2293
 #, fuzzy, no-c-format
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin uygulanması için ortak seçenekler etkinleştirilir"
 
-#: common.opt:2293
+#: common.opt:2297
 #, fuzzy, no-c-format
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "Kod, ifade ayrımlama değerlerine yerleştirilir"
 
-#: common.opt:2297
+#: common.opt:2301
 #, fuzzy, no-c-format
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile."
 msgstr "dahili tutarlılık hatası"
 
-#: common.opt:2301
+#: common.opt:2305
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "Kod yerleşimini iyileştirecek işlevleri yeniden sıralar"
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 #| msgid "Reserve space for outgoing arguments in the function prologue"
 msgid "Insert NOP instructions at each function entry."
 msgstr "İşlev önbilgisinde çıkan argümanlar için ayrılmış alan"
 
-#: common.opt:2312
+#: common.opt:2316
 #, fuzzy, no-c-format
 #| msgid "Make compile reproducible using <string>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "<dizge> kullanılarak derleme yeniden türetilebilir yapılır"
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "Yazmaçlardaki küçük kümeler döndürülür"
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:2372
+#: common.opt:2376
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:2376
+#: common.opt:2380
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Kod yerleşimini iyileştirecek temel blokları yeniden sıralar"
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks and partition into hot and cold sections"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Temel blokları ve parçaları sıcak ve soğuk bölümler halinde yeniden sıralar"
 
-#: common.opt:2397
+#: common.opt:2401
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "Kod yerleşimini iyileştirecek işlevleri yeniden sıralar"
 
-#: common.opt:2401
+#: common.opt:2405
 #, fuzzy, no-c-format
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Döngü eniyilemesinden sonra bir ortak alt ifade elemesi aşaması eklenir"
 
-#: common.opt:2409
+#: common.opt:2413
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Kayan nokta yuvarlama davranışını öntanımlı varsayan eniyilemeler yapılmaz"
 
-#: common.opt:2413
+#: common.opt:2417
 #, fuzzy, no-c-format
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "Temel bloklar arasında zamanlama etkinleştirilir"
 
-#: common.opt:2417
+#: common.opt:2421
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2421
+#: common.opt:2425
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "Yük oluşturmayanların tahmini hareketine izin verilir"
 
-#: common.opt:2425
+#: common.opt:2429
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "Bazı yüklerin tahmini hareketine izin verilir"
 
-#: common.opt:2429
+#: common.opt:2433
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "Fazla yüklerin tahmini hareketine izin verilir"
 
-#: common.opt:2433
+#: common.opt:2437
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2437
+#: common.opt:2441
 #, fuzzy, no-c-format
 #| msgid "If scheduling post reload, do superblock scheduling"
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Sonradan yeniden yükleme zamanlaması varsa süper blok zamanlaması yapılır"
 
-#: common.opt:2445
+#: common.opt:2449
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "Yazmaç tahsisinden önce komutları yeniden zamanlar"
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "Yazmaç tahsisinden sonra komutları yeniden zamanlar"
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy, no-c-format
 #| msgid "Allow premature scheduling of queued insns"
 msgid "Allow premature scheduling of queued insns."
 msgstr "Kuyruklanmış komutların erken zamanlanmasına izin verilir"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy, no-c-format
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "Erken zamanlanabilen kuyruklanmış komutların sayısı belirtilir"
 
-#: common.opt:2498
+#: common.opt:2502
 #, fuzzy, no-c-format
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Kuyruklanmış komutların erken zamanlanmasında bağımlılık aralığı denetimi yapılır"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy, no-c-format
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "Kuyruklanmış komutların erken zamanlanmasında bağımlılık aralığı denetimi yapılır"
 
-#: common.opt:2506
+#: common.opt:2510
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2514
+#: common.opt:2518
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2522
+#: common.opt:2526
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy, no-c-format
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy, no-c-format
 #| msgid "Show column numbers in diagnostics, when available.  Default on"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Mümkünse, teşhiste sütun numaralarını gösterir. Öntanımlı"
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "IEEE sinyalleme NaNları tarafından farkedilebilen eniyilemeler iptal edilir"
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, fuzzy, no-c-format
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "Kayan noktalı sabitler tek duyarlıklı sabitlere dönüştürülür"
 
-#: common.opt:2571
+#: common.opt:2575
 #, fuzzy, no-c-format
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Döngüler geri sarılırken tümevarım ömrü bölünür"
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy, no-c-format
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "APCS uyumlu yığıt çerçeveleri üretilir"
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation on trees"
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Ağaçlarda kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy, no-c-format
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Döngüler geri sarılırken değişken yorumlaması uygulanır"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Programa yığıt sınama kodu yerleştirilir"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Programa yığıt sınama kodu yerleştirilir"
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy, no-c-format
 #| msgid "Trap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "Yığıt <yazmaç> geçmişine giderse yakalanır"
 
-#: common.opt:2623
+#: common.opt:2627
 #, fuzzy, no-c-format
 #| msgid "Trap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "Yığıt <isim> simgesinin geçmişine giderse yakalanır"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy, no-c-format
 #| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "Yığıt koruma yöntemi olarak propolice kullanılır"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy, no-c-format
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "Her işlev için r30 yeniden kullanılır"
 
-#: common.opt:2655
+#: common.opt:2659
 #, fuzzy, no-c-format
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "Sıkı takma ad kuralları uygulanacağı varsayılır"
 
-#: common.opt:2659
+#: common.opt:2663
 #, fuzzy, no-c-format
 #| msgid "Treat missing header files as generated files"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Kayıp başlık dosyaları üretilen dosyalar olarak ele alınır"
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, fuzzy, no-c-format
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "Sözdizimi denetimi yaptıktan sonra durur"
 
-#: common.opt:2671
+#: common.opt:2675
 #, fuzzy, no-c-format
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "\"gcov\" için gereken veri dosyaları oluşturulur"
 
-#: common.opt:2675
+#: common.opt:2679
 #, fuzzy, no-c-format
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "Atlama evreleme eniyilemesi uygulanır"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy, no-c-format
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "Her derleme aşaması için harcanan zaman raporlanır"
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, fuzzy, no-c-format
 #| msgid "Set the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "Öntanımlı yerel-evreli saklama kodu üretim modeli belirtilir"
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2710
+#: common.opt:2714
 #, fuzzy, no-c-format
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "Kuyruk tekrarı üzerinden süper blok oluşumu uygulanır"
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "Kayan nokta işlemlerinin yakalanabileceği varsayılır"
 
-#: common.opt:2726
+#: common.opt:2730
 #, fuzzy, no-c-format
 #| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Toplama, çıkartma, çarpmada signed taşması için kapan kurulur"
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Ağaçlarda SSA-CCP eniyilemesi etkinleştirilir"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Ağaçlarda SSA-CCP eniyilemesi etkinleştirilir"
 
-#: common.opt:2742
+#: common.opt:2746
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "Ağaçlarda döngü başlığı kopyalaması etkin olur"
 
-#: common.opt:2750
+#: common.opt:2754
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA coalescing of user variables."
 msgstr "Ağaçlarda SSA kod soğurumu etkinleştirilir"
 
-#: common.opt:2758
+#: common.opt:2762
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "Ağaçlarda kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2766
+#: common.opt:2770
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones."
 msgstr "Koşullu çalıştırmaya koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:2770
+#: common.opt:2774
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Koşullu çalıştırmaya koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Ağaçlarda SSA ölü kod eleme eniyilemesi etkin olur"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Baskınlık eniyilemeleri etkin olur"
 
-#: common.opt:2782
+#: common.opt:2786
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable tail merging on trees."
 msgstr "Ağaçlarda döngü başlığı kopyalaması etkin olur"
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:2790
+#: common.opt:2794
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation on trees"
 msgid "Enable forward propagation on trees."
 msgstr "Ağaçlarda kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2794
+#: common.opt:2798
 #, fuzzy, no-c-format
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Ağaçlarda Tam Artıklık Elemesi (TAE) etkin olur"
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable string length optimizations on trees."
 msgstr "Ağaçlarda SSA-CCP eniyilemesi etkinleştirilir"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop distribution on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2819
+#: common.opt:2823
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2823
+#: common.opt:2827
 #, fuzzy, no-c-format
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "Ağaçlarda döngü içinde değişmez hareket etkin olur"
 
-#: common.opt:2831
+#: common.opt:2835
 #, fuzzy, no-c-format
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "Döngülerde meşru tümevarım değişkenleri oluşturulur"
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "Ağaç seviyesinde döngü eniyilemeleri etkinleştirilir"
 
-#: common.opt:2839
+#: common.opt:2843
 #, fuzzy, no-c-format
 #| msgid "Enable automatic template instantiation"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "Özdevinimli şablon örneklenimi etkin olur"
 
-#: common.opt:2843
+#: common.opt:2847
 #, fuzzy, no-c-format
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Koşullu taşımalar etkin olur"
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Ağaçlarda SSA-PRE eniyilemesi etkinleştirilir"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2859
+#: common.opt:2863
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable reassociation on tree level."
 msgstr "Ağaç seviyesinde döngü eniyilemeleri etkinleştirilir"
 
-#: common.opt:2867
+#: common.opt:2871
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "Ağaçlarda SSA kod soğurumu etkinleştirilir"
 
-#: common.opt:2871
+#: common.opt:2875
 #, fuzzy, no-c-format
 #| msgid "Perform strength reduction optimizations"
 msgid "Perform straight-line strength reduction."
 msgstr "Güç azaltma eniyilemesi uygulanır"
 
-#: common.opt:2875
+#: common.opt:2879
 #, fuzzy, no-c-format
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "Ortak değerlerde sabit yer değiştirmesi yapılır"
 
-#: common.opt:2879
+#: common.opt:2883
 #, fuzzy, no-c-format
 #| msgid "Replace temporary expressions in the SSA->normal pass"
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Geçici ifadeler SSA->normal geçişine yerleştirilir"
 
-#: common.opt:2883
+#: common.opt:2887
 #, fuzzy, no-c-format
 #| msgid "Perform live range splitting during the SSA->normal pass"
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "SSA->normal aşamasında canlı aralık ayırması yapılır"
 
-#: common.opt:2887
+#: common.opt:2891
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "Ağaçlarda Değer Aralığı Girişimi uygulanır"
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "Derleme biriminin tamamı bir defada derlenir"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Yineleme sayısı bilindiğinde döngü tersine uygulanır"
 
-#: common.opt:2908
+#: common.opt:2912
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "IEEE veya ISO standartlarını bozabilen matematiksel eniyilemelere izin verilir"
 
-#: common.opt:2940
+#: common.opt:2944
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "Döngü anahtarlamaması uygulanır"
 
-#: common.opt:2944
+#: common.opt:2948
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "Döngü soyması uygulanır"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Olağandışılıkların yakalanması için birbirlerini etkilemeyenlerin tablosu oluşturulur"
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:3003
+#: common.opt:3007
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:3015
+#: common.opt:3019
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:3050
+#: common.opt:3054
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation for stores and loads"
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Saklama ve yüklemelerde kopyalama girişimi etkinleştirilir"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Çevirici çıktısına fazladan açıklama ekler"
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "Eniyilemelerde ifade değeri ayrımlaması kullanılır"
 
-#: common.opt:3111
+#: common.opt:3115
 #, fuzzy, no-c-format
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Izgara oluşturur ve tek bir değişkenin ilgisiz kullanımlarını ayırır"
 
-#: common.opt:3115
+#: common.opt:3119
 #, fuzzy, no-c-format
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Ağaçlarda SSA ölü kod eleme eniyilemesi etkin olur"
 
-#: common.opt:3119
+#: common.opt:3123
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "Bütün yazılım eniyilemeleri uygulanır"
 
-#: common.opt:3123
+#: common.opt:3127
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "İşaretli aritmetik taşmaların olurunun bulunduğu varsayılır"
 
-#: common.opt:3127
+#: common.opt:3131
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "İşaretli aritmetik taşmaların olurunun bulunduğu varsayılır"
 
-#: common.opt:3131
+#: common.opt:3135
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "bss bölümüne sıfır ilklendirmeli veri yerleştirilir"
 
-#: common.opt:3135
+#: common.opt:3139
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Clear call-used registers upon function return."
 msgstr "İşlev çağrıları civarındaki yazmaçlar saklanır"
 
-#: common.opt:3139
+#: common.opt:3143
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3175
+#: common.opt:3179
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "DWARF v2 biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "Öntanımlı gelişmiş biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Her işlev için tek çıkış noktası üretilir"
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3223
+#: common.opt:3227
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "STABS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3227
+#: common.opt:3231
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Gelişmiş STABS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "VMS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "VMS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3258
+#: common.opt:3262
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "XCOFF biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3262
+#: common.opt:3266
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Gelişmiş XCOFF biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3280
+#: common.opt:3284
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "isel komutları üretilir"
 
-#: common.opt:3284
+#: common.opt:3288
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3291
+#: common.opt:3295
 #, fuzzy, no-c-format
 #| msgid "Set <dir> to be the system root directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "<dizin> sistemin kök dizini olur"
 
-#: common.opt:3295
+#: common.opt:3299
 #, fuzzy, no-c-format
 #| msgid "Set <dir> to be the system root directory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "<dizin> sistemin kök dizini olur"
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "Çıktı <dosya>ya yazılır"
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "İşlev ayrımlama etkinleştirilir"
 
-#: common.opt:3334
+#: common.opt:3338
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "-pedantic gibidir ancak uyarılar hata olarak ele alınır"
 
-#: common.opt:3374
+#: common.opt:3378
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Derlenen işlevler ve geçen zaman gösterilmez"
 
-#: common.opt:3406
+#: common.opt:3410
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Ayrıntılı çıktı verilir"
 
-#: common.opt:3410
+#: common.opt:3414
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Derleyici sürümünü gösterir."
 
-#: common.opt:3414
+#: common.opt:3418
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Uyarılar engellenir"
 
-#: common.opt:3424
+#: common.opt:3428
 #, fuzzy, no-c-format
 #| msgid "Enable ID based shared library"
 msgid "Create a shared library."
 msgstr "ID tabanlı paylaşımlı kütüphane etkin olur"
 
-#: common.opt:3472
+#: common.opt:3476
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:3476
+#: common.opt:3480
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:3480
+#: common.opt:3484
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Create a static position independent executable."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -21443,42 +21444,47 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload"
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "Yeniden yükleme sonrası fazlalık elemesi yapılırken izin verilen kritik ayrıt çalıştırma sayısının eşik oranı/hızı."
 
-#: params.opt:178
+#: params.opt:183
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio for performing partial redundancy elimination after reload"
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "Yeniden yükleme sonrası fazlalıkların kısmî elemesi için eşik oranı/hızı."
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, fuzzy, no-c-format
 #| msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap"
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
@@ -21487,7 +21493,7 @@ msgstr ""
 "                                      gereken minimum artış, üst bellek\n"
 "                                      boyutunun yüzdesi olarak"
 
-#: params.opt:194
+#: params.opt:199
 #, fuzzy, no-c-format
 #| msgid "Minimum heap size before we start collecting garbage, in kilobytes"
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
@@ -21495,393 +21501,393 @@ msgstr ""
 "Çöp toplamaya başlanmadan önceki kilobayt\n"
 "                                      cinsinden en küçük üst bellek boyutu"
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 #| msgid "maximum value of parameter %qs is %u"
 msgid "Maximum number of arrays per SCoP."
 msgstr "%qs parametresinin azami değeri %u'dur."
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 #| msgid "maximum value of parameter %qs is %u"
 msgid "Maximum number of parameters in a SCoP."
 msgstr "%qs parametresinin azami değeri %u'dur."
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot"
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "Temel blokun sıcak olarak düşünülmesi gereğine göre yazılımda temel blokun azami icra sıklığının kesrini seçer"
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot"
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "Temel blokun sıcak olarak düşünülmesi gereğine göre yazılımda temel blokun azami icra sıklığının kesrini seçer"
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, fuzzy, no-c-format
 #| msgid "how much can given compilation unit grow because of the inlining (in percent)"
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "satıriçine almadan dolayı belirtilen hesaplama biriminin büyüme oranı"
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 #| msgid "The upper bound for sharing integer constants"
 msgid "The upper bound for sharing integer constants."
 msgstr "Tamsayı sabitlerin paylaşımı için üst sınır"
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "Satıriçi işlevlerde azami satıriçi iç içelik derinliği"
 
-#: params.opt:258
+#: params.opt:263
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Ardışık satıriçine alma sadece çağrının icrasında parametre aşımı olasılığı varken yapılır"
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, fuzzy, no-c-format
 #| msgid "how much can given compilation unit grow because of the inlining (in percent)"
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "satıriçine almadan dolayı belirtilen hesaplama biriminin büyüme oranı"
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "Çok büyük olacağı varsayılan dönüşüm birimi boyutu"
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr ""
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, fuzzy, no-c-format
 #| msgid "The minimum cost of an expensive expression in the loop invariant motion"
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr "döngü içinde değişmez hareket içinde pahalı ifadenin asgari maliyeti"
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr ""
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr ""
 
-#: params.opt:326
+#: params.opt:331
 #, fuzzy, no-c-format
 #| msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization"
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "Eğer kümedeki aday sayısı küçükse, daima en iyileme sırasında kullanılmamış iv'leri kaldırmaya çalışırız"
 
-#: params.opt:330
+#: params.opt:335
 #, fuzzy, no-c-format
 #| msgid "Bound on number of candidates below that all candidates are considered in iv optimizations"
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "iv en iyilemelerinde ele alınan tüm adayların sayısının üst sınırı"
 
-#: params.opt:334
+#: params.opt:339
 #, fuzzy, no-c-format
 #| msgid "Bound on number of iv uses in loop optimized in iv optimizations"
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "iv en iyilemelerinde en iyilenmiş döngülerde kullanılan iv sayısının sınırı"
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr ""
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr ""
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr ""
 
-#: params.opt:358
+#: params.opt:363
 #, fuzzy, no-c-format
 #| msgid "Maximal growth due to inlining of large function (in percent)"
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Büyük işlevlerin satıriçine alınması nedeniyle oluşan en yüksek büyüme (yüzde olarak)"
 
-#: params.opt:362
+#: params.opt:367
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of function body to be considered large."
 msgstr "İşlev gövdesinin büyük olduğu varsayılır"
 
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of stack frame to be considered large."
 msgstr "İşlev gövdesinin büyük olduğu varsayılır"
 
-#: params.opt:370
+#: params.opt:375
 #, fuzzy, no-c-format
 #| msgid "Maximal growth due to inlining of large function (in percent)"
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Büyük işlevlerin satıriçine alınması nedeniyle oluşan en yüksek büyüme (yüzde olarak)"
 
-#: params.opt:374
+#: params.opt:379
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit to be considered large."
 msgstr "Çok büyük olacağı varsayılan dönüşüm birimi boyutu"
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, fuzzy, no-c-format
 #| msgid "The minimum cost of an expensive expression in the loop invariant motion"
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "döngü içinde değişmez hareket içinde pahalı ifadenin asgari maliyeti"
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "Ortalama olarak, bir döngü içinde çevrime sokulmayacağı varsayılan en fazla komut sayısı "
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr ""
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "Bloklar arası zamanlama için ele alınacak bir bölgedeki asm komutlarının azami sayısı"
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "Bir döngü içinde çevrime sokulmayacağı varsayılan en fazla komut sayısı"
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "Ortalama olarak, bir döngü içinde çevrime sokulmayacağı varsayılan en fazla komut sayısı "
 
-#: params.opt:446
+#: params.opt:451
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of insns combine tries to combine."
 msgstr "Çapraz sıçrama için dikkate alınacak gelen azami ayrıt sayısı"
 
-#: params.opt:450
+#: params.opt:455
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "Tamamen soyulmuş bir döngüdeki azami komut sayısı"
 
-#: params.opt:454
+#: params.opt:459
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop that is peeled completely"
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Tamamen soyulan tek bir döngüdeki azami soyulma sayısı"
 
-#: params.opt:458
+#: params.opt:463
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "Tamamen soyulmuş bir döngüdeki azami komut sayısı"
 
-#: params.opt:462
+#: params.opt:467
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "Çapraz sıçrama için dikkate alınacak gelen azami ayrıt sayısı"
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr ""
 
-#: params.opt:470
+#: params.opt:475
 #, fuzzy, no-c-format
 #| msgid "The maximum length of path considered in cse"
 msgid "The maximum length of path considered in cse."
 msgstr "Ortak altifade elemesi içinde olacağı varsayılan yolun azami uzunluğu"
 
-#: params.opt:474
+#: params.opt:479
 #, fuzzy, no-c-format
 #| msgid "The maximum memory locations recorded by cselib"
 msgid "The maximum memory locations recorded by cselib."
 msgstr "cselib tarafından kaydedilmiş azami bellek konumu"
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to fill a delay slot"
 msgid "The maximum number of instructions to consider to fill a delay slot."
@@ -21889,7 +21895,7 @@ msgstr ""
 "Bir gecikme yuvasını dolduracağı\n"
 "                                      varsayılan en fazla komut sayısı"
 
-#: params.opt:486
+#: params.opt:491
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to find accurate live register information"
 msgid "The maximum number of instructions to consider to find accurate live register information."
@@ -21898,12 +21904,12 @@ msgstr ""
 "                                      bulunmasını dikkate alacak asm\n"
 "                                      komutlarının azami sayısı"
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of nested indirect inlining performed by early inliner."
@@ -21911,23 +21917,23 @@ msgstr ""
 "Satıriçi için seçilebilir bir işlevde\n"
 "                                      en çok asm komutu sayısı"
 
-#: params.opt:498
+#: params.opt:503
 #, fuzzy, no-c-format
 #| msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable"
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "Gösterici çözümlemesinin yapıyı tek değişken olarak ele almasından önce bir yapı içindeki alanların azami sayısı"
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to fill a delay slot"
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
@@ -21935,13 +21941,13 @@ msgstr ""
 "Bir gecikme yuvasını dolduracağı\n"
 "                                      varsayılan en fazla komut sayısı"
 
-#: params.opt:514
+#: params.opt:519
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "Bir döngü içinde çevrime sokulmayacağı varsayılan en fazla komut sayısı"
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE"
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
@@ -21949,24 +21955,24 @@ msgstr ""
 "Genel ortak alt ifade elemesi tarafından\n"
 "                                      ayrılan en büyük bellek"
 
-#: params.opt:522
+#: params.opt:527
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of an unswitched loop"
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "Bir switch'siz döngüdeki azami komut sayısı"
 
-#: params.opt:526
+#: params.opt:531
 #, fuzzy, no-c-format
 #| msgid "The maximum expansion factor when copying basic blocks"
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "Temel blokların kopyalanması sırasındaki azami genişletme çarpanı"
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining."
@@ -21974,19 +21980,19 @@ msgstr ""
 "Özdevinimli olarak satıriçine alınırken en çok\n"
 "                                      asm komutu sayısı"
 
-#: params.opt:538
+#: params.opt:543
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "Satıriçi işlevlerin iç içe satıriçine alma sırasında büyüyebileceği azami komut sayısı"
 
-#: params.opt:542
+#: params.opt:547
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions non-inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "Satıriçi olmayan işlevlerin iç içe satıriçine alma sırasında büyüyebileceği azami komut sayısı"
 
-#: params.opt:546
+#: params.opt:551
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions in a single function eligible for inlining."
@@ -21994,7 +22000,7 @@ msgstr ""
 "Satıriçi için seçilebilir bir işlevde\n"
 "                                      en çok asm komutu sayısı"
 
-#: params.opt:550
+#: params.opt:555
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when inlining for size."
@@ -22002,7 +22008,7 @@ msgstr ""
 "Özdevinimli olarak satıriçine alınırken en çok\n"
 "                                      asm komutu sayısı"
 
-#: params.opt:554
+#: params.opt:559
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining small functions."
@@ -22010,83 +22016,83 @@ msgstr ""
 "Özdevinimli olarak satıriçine alınırken en çok\n"
 "                                      asm komutu sayısı"
 
-#: params.opt:558
+#: params.opt:563
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "Satıriçi işlevlerde azami satıriçi iç içelik derinliği"
 
-#: params.opt:562
+#: params.opt:567
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for non-inline functions"
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "Satıriçi olmayan işlevlerde azami satıriçi iç içelik derinliği"
 
-#: params.opt:566
+#: params.opt:571
 #, fuzzy, no-c-format
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Erken zamanlanabilen kuyruklanmış komutların sayısı belirtilir"
 
-#: params.opt:570
+#: params.opt:575
 #, fuzzy, no-c-format
 #| msgid "Bound on size of expressions used in the scalar evolutions analyzer"
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "Değişmez değerlemeler çözümleyicisinde kullanılan ifadelerin boyut sınırı"
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr ""
 
-#: params.opt:578
+#: params.opt:583
 #, fuzzy, no-c-format
 #| msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps"
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "sıçramalar evrelenirken yinelenmesi gereken bir blokta izin verilen deyimlerin azami sayısı"
 
-#: params.opt:582
+#: params.opt:587
 #, fuzzy, no-c-format
 #| msgid "The maximum number of RTL nodes that can be recorded as combiner's last value"
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "Birleştiricinin son değeri olarak kaydedilebilen RTL düğümlerinin azami sayısı"
 
-#: params.opt:586
+#: params.opt:591
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a peeled loop"
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "Soyulmuş bir döngüdeki azami komut sayısı"
 
-#: params.opt:590
+#: params.opt:595
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "Bir döngü içinde çevrime sokulmayacağı varsayılan en fazla komut sayısı"
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "Tamamen soyulmuş bir döngüdeki azami komut sayısı"
 
-#: params.opt:602
+#: params.opt:607
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop"
 msgid "The maximum number of peelings of a single loop."
 msgstr "Tek bir döngüdeki azami soyulma sayısı"
 
-#: params.opt:606
+#: params.opt:611
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a peeled loop"
 msgid "The maximum number of insns of a peeled loop."
 msgstr "Soyulmuş bir döngüdeki azami komut sayısı"
 
-#: params.opt:610
+#: params.opt:615
 #, fuzzy, no-c-format
 #| msgid "The maximum length of scheduling's pending operations list"
 msgid "The maximum length of scheduling's pending operations list."
@@ -22094,97 +22100,97 @@ msgstr ""
 "İşlemler listesinin tamamlanmasını\n"
 "                                         bekleyenlerin en büyük uzunluğu"
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, fuzzy, no-c-format
 #| msgid "The maximum number of blocks in a region to be considered for interblock scheduling"
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "Bloklar arası zamanlama için ele alınacak bir bölgedeki blokların azami sayısı"
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "Bloklar arası zamanlama için ele alınacak bir bölgedeki asm komutlarının azami sayısı"
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically"
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "statik olarak öngördüğümüz döngü yinelemelerinin azami sayısı"
 
-#: params.opt:630
+#: params.opt:635
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to search backward when looking for equivalent reload"
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "Eşdeğer yeniden yükleme için bakılırken geriye doğru aranacak komutların azami sayısı"
 
-#: params.opt:634
+#: params.opt:639
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Bloklar arası zamanlama için ele alınacak bir bölgedeki asm komutlarının azami sayısı"
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, fuzzy, no-c-format
 #| msgid "Set the maximum number of iterations for RPTS to N"
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "RPTS için azami yineleme sayısını N yapar"
 
-#: params.opt:650
+#: params.opt:655
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "Bloklar arası zamanlama için ele alınacak bir bölgedeki asm komutlarının azami sayısı"
 
-#: params.opt:654
+#: params.opt:659
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "Bloklar arası zamanlama için ele alınacak bir bölgedeki asm komutlarının azami sayısı"
 
-#: params.opt:666
+#: params.opt:671
 #, fuzzy, no-c-format
 #| msgid "Perform strength reduction optimizations"
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr "Güç azaltma eniyilemesi uygulanır"
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr ""
 
-#: params.opt:682
+#: params.opt:687
 #, fuzzy, no-c-format
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "Erken zamanlanabilen kuyruklanmış komutların sayısı belirtilir"
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
@@ -22192,226 +22198,231 @@ msgstr ""
 "Satıriçi için seçilebilir bir işlevde\n"
 "                                      en çok asm komutu sayısı"
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unrollings of a single loop"
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Tek bir döngüde işlenemeyenlerin azami sayısı"
 
-#: params.opt:714
+#: params.opt:719
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "Bir döngü içinde çevrime sokulmayacağı varsayılan en fazla komut sayısı"
 
-#: params.opt:718
+#: params.opt:723
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of an unswitched loop"
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "Bir switch'siz döngüdeki azami komut sayısı"
 
-#: params.opt:722
+#: params.opt:727
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unswitchings in a single loop"
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Tek bir döngüdeki switch'sizlerin azami sayısı"
 
-#: params.opt:726
+#: params.opt:731
 #, fuzzy, no-c-format
 #| msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling"
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "-fvariable-expansion-in-unroller seçeneği kullanıldığında, tek bir değişkenin döngünün gerisarılması sırasında genişletileceği azami yineleme sayısı"
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, fuzzy, no-c-format
 #| msgid "The minimum number of matching instructions to consider for crossjumping"
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "Çapraz atlama için düşünülen eşleşme komutlarının asgari sayısı"
 
-#: params.opt:754
+#: params.opt:759
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Ardışık satıriçine alma sadece çağrının icrasında parametre aşımı olasılığı varken yapılır"
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, fuzzy, no-c-format
 #| msgid "The minimum probability of reaching a source block for interblock speculative scheduling"
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "Bloklar arası tartımlı zamanlama için bir kaynak bloka ulaşma olasılığının asgarisi"
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr ""
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Bir döngü içinde çevrime sokulmayacağı varsayılan en fazla komut sayısı"
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr ""
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr ""
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, fuzzy, no-c-format
 #| msgid "cannot find file for class %s"
 msgid "Use internal function id in profile lookup."
 msgstr "sınıf %s için dosya bulunamıyor"
 
-#: params.opt:840
+#: params.opt:858
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "Tamamen soyulmuş bir döngüdeki azami komut sayısı"
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, fuzzy, no-c-format
 #| msgid "Bound on size of expressions used in the scalar evolutions analyzer"
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "Değişmez değerlemeler çözümleyicisinde kullanılan ifadelerin boyut sınırı"
 
-#: params.opt:852
+#: params.opt:870
 #, fuzzy, no-c-format
 #| msgid "Bound on size of expressions used in the scalar evolutions analyzer"
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "Değişmez değerlemeler çözümleyicisinde kullanılan ifadelerin boyut sınırı"
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, fuzzy, no-c-format
 #| msgid "The minimum probability of reaching a source block for interblock speculative scheduling"
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "Bloklar arası tartımlı zamanlama için bir kaynak bloka ulaşma olasılığının asgarisi"
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
@@ -22419,116 +22430,116 @@ msgstr ""
 "Satıriçi için seçilebilir bir işlevde\n"
 "                                      en çok asm komutu sayısı"
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, fuzzy, no-c-format
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "Erken zamanlanabilen kuyruklanmış komutların sayısı belirtilir"
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr ""
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr ""
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr ""
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr ""
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr ""
 
-#: params.opt:928
+#: params.opt:946
 #, fuzzy, no-c-format
 #| msgid "The lower bound for a buffer to be considered for stack smashing protection"
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "yığıt parçalanma koruması için ele alınacak bir tampon için alt sınır"
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr ""
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 #| msgid "maximum value of parameter %qs is %u"
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "%qs parametresinin azami değeri %u'dur."
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 #| msgid "maximum value of parameter %qs is %u"
 msgid "Maximum number of references stored in each modref base."
 msgstr "%qs parametresinin azami değeri %u'dur."
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr ""
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "Maximum number of tests performed by modref query."
@@ -22536,149 +22547,149 @@ msgstr ""
 "Satıriçi için seçilebilir bir işlevde\n"
 "                                      en çok asm komutu sayısı"
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr ""
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "İşlevin izlenme oluşumu ile kapsanacak, işlenme sıklığı ile çarpılmış yüzdesi. Profil geribeslemesi mümkün olmadığında kullanılır"
 
-#: params.opt:984
+#: params.opt:1002
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "İşlevin izlenme oluşumu ile kapsanacak, işlenme sıklığı ile çarpılmış yüzdesi Profil geribeslemesi mevcut olduğu zaman kullanılır"
 
-#: params.opt:988
+#: params.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Maximal code growth caused by tail duplication (in percent)"
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Kuyruk tekrarı tarafından oluşturulan en yüksek kod büyümesi (yüzde olarak)"
 
-#: params.opt:992
+#: params.opt:1010
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "En iyi ayrıt olasılığı bu eşik değerden (yüzde olarak) küçükse ileriye doğru büyüme durdurulur. Profil geribeslemesi mümkün değilse kullanılır"
 
-#: params.opt:996
+#: params.opt:1014
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "En iyi ayrıt olasılığı bu eşik değerden (yüzde olarak) küçükse ileriye doğru büyüme durdurulur. Profil geribeslemesi mümkünse kullanılır"
 
-#: params.opt:1000
+#: params.opt:1018
 #, fuzzy, no-c-format
 #| msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)"
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "En iyi ayrıt tersine olasılığı bu eşik değerden (yüzde olarak) küçükse geriye doğru büyüme durdurulur"
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 #| msgid "Emit implicit instantiations of templates"
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "Şablonlarının örtük örneklenimleri çıktılanır"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "İşlev önbilgisi/sonbilgisi için altyordamlar kullanılır"
 
-#: params.opt:1024
+#: params.opt:1042
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "İşlev önbilgisi/sonbilgisi için altyordamlar kullanılır"
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr ""
 
-#: params.opt:1056
+#: params.opt:1074
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, fuzzy, no-c-format
 #| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning"
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "tek boyutlu dizi yapan döngü tanımı tarafından yerleştirilen çalışma anı sınama sayısı sınırı"
 
-#: params.opt:1068
+#: params.opt:1086
 #, fuzzy, no-c-format
 #| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning"
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "tek boyutlu dizi yapan döngü tanımı tarafından yerleştirilen çalışma anı sınama sayısı sınırı"
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -22719,7 +22730,7 @@ msgid "expected boolean type"
 msgstr "İfade türü umuluyordu"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -22806,7 +22817,7 @@ msgstr "argüman yok"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments"
@@ -23258,7 +23269,7 @@ msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -23321,7 +23332,7 @@ msgstr "tür öznitelikleri sadece tür tanımlarında uygulanabilir"
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -23350,20 +23361,20 @@ msgstr "tür öznitelikleri sadece tür tanımlarında uygulanabilir"
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -23374,8 +23385,8 @@ msgstr "%qE özniteliği yoksayıldı"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -23387,61 +23398,61 @@ msgstr "%q+D bildiriminin önceki bildirimi"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D zaten dllexport özniteliği ile bildirilmiş: dllimport yoksayıldı"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D' dll ilintileme ile ilişkilendirildikten sonra dllimport özniteliği olmaksızın yeniden bildirildi"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D dllimport özniteliği olmaksızın yeniden bildirildi; önceki dllimport yoksayıldı"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared as  dllimport: attribute ignored"
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "%q+D satıriçi işlevi dllimport olarak bildirilmiş: öznitelik yoksayıldı"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "%q+D değişkeninin tanımı dllimport imli"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, fuzzy, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "%2$qs özniteliğinden dolayı %1$q+D' simgesi için dış ilintileme gerekli"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr ""
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 msgstr[1] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD target declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -23549,7 +23560,7 @@ msgstr "deyim umuluyordu"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "göreli konum sabit dizgenin sınırlarının dışında"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -23575,515 +23586,515 @@ msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "%<__builtin_prefetch%> için 3. argüman geçersiz; sıfır kullanılıyor"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "source object declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 #| msgid "class definition may not be declared a friend"
 msgid "destination object declared here"
 msgstr "sınıf tanımı kardeş olarak bildirilemeyebilir"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "destination object allocated here"
 msgstr "%s: işlev tanımı dönüştürülmedi\n"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 msgstr[1] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "invalid IACC argument"
 msgid "invalid argument to %qD"
 msgstr "IACC argümanı geçersiz"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument to %qD"
@@ -24091,98 +24102,98 @@ msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for static member function %qD"
 msgid "trampoline generated for nested function %qD"
 msgstr "statik üye işlev %qD için ilklendirici belirtilmiş"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid memory model argument to builtin"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 1 to %qs"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "non-integer argument 1 to %qs"
 msgstr "\"%s\" için argüman eksik"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s not supported: ignored"
 msgid "%qs only supported in OpenACC code"
 msgstr "-f%s  desteklenmiyor: yoksayıldı"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 0 to %qs"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "illegal argument 0 to %qs"
@@ -24190,7 +24201,7 @@ msgstr "\"%s\" için argüman eksik"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
@@ -24198,126 +24209,126 @@ msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%>'in ikinci argümanı 1 olmalı"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> işlev içinde sabit sayıda argümanla kullanılmış"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%H%D için son argüman 0 .. 3 arasında bir tamsayı sabit değil"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "returned from %qD"
 msgstr "%q+D için sağlanmış"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "returned from %qT"
 msgstr "%q+D için sağlanmış"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "obtained here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "assigned here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -25142,317 +25153,317 @@ msgstr "temel bloklar ardışık numaralı değil"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "komut zinciri (%d) içindeki bb notlarının sayısı != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "çağrıcı ayrıt sayısı negatif"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "missing direct call for speculation %i"
 msgstr "'%s' işlevinde argüman listesi eksik (%C'de)"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Create console application"
 msgid "missing ref for speculation %i"
 msgstr "Konsol uygulaması oluşturulur"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "ayrıt %s->%s için yardımcı alan belirtilmiş"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "tp_first_run must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Tüm simgelerin geçersiz olabileceği varsayılır"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function returning 'void'"
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "'void' dönüşlu işlevde değer içeren `return' deyimi"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "ayrıt %s->%s için yardımcı alan belirtilmiş"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "edge count is not compatible with function count"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to göstericisi yanlış"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "çok sayıda satıriçi çağrısı"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "Inlined_to göstericisi satıriçi olmayan çağrıcılar için belirtilmiş"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "caller edge count does not match BB count"
 msgstr "gelen ayrıt sayısı PHI argüman sayısı ile uyuşmuyor"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "indirect call count does not match BB count"
 msgstr "gelen ayrıt sayısı PHI argüman sayısı ile uyuşmuyor"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "inlined_to pointer is set but no predecesors found"
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlined_to göstericisi var ama bir öncül yok"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Inlined_to göstericisi kendini gösteriyor"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "paylaşımlı call_stmt:"
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "yanlış bildirimin köşeleri:"
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "çağrı deyimi için çağrı çizgesi ayrıtı eksik"
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "deyim umuluyordu"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ayrıt %s->%s için karşılığı olan çağrı deyimi yok"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ayrıt %s->%s için karşılığı olan çağrı deyimi yok"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "origin points to a different parent"
 msgstr "göstericiden farklı tamsayı türlere dönüşüm"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node başarısız"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s.%d is missing"
@@ -25545,12 +25556,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F işlevi tanımlanmadan kullanılmış"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
@@ -25630,7 +25641,7 @@ msgstr "%q+D dönüş değerinin uzunluğu %u bayt"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "%q+D dönüş değerinin genişligi %wd bayttan büyük"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, fuzzy, gcc-internal-format
 #| msgid "nodes with no released memory found"
 msgid "nodes with unreleased memory found"
@@ -26076,12 +26087,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -26101,7 +26112,7 @@ msgstr "paylaşımlı rtx"
 msgid "internal consistency failure"
 msgstr "dahili tutarlılık hatası"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_jump_insn gereken yerde emit_insn kullanılmış:\n"
@@ -26246,42 +26257,42 @@ msgstr "döküm dosyası %qs açılamadı: %s"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "büyük tamsayı örtük olarak unsigned türe indirgendi"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "karşılaştırma bit alanının genişliğinden dolayı daima %d"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "karşılaştırma sonucu daima %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "eşleşmeyenlerin farklılık sınamalarının %<or%> sonucu daima 1 dir"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "bağdaşmayanların eşitlik sınamalarının %<and%> sonucu daima 0 dir"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold sınaması: özgün ağac fold tarafından değiştirildi"
@@ -26298,7 +26309,7 @@ msgstr "%Jyerel nesnelerin toplam boyutu çok büyük"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "%Jyerel nesnelerin toplam boyutu çok büyük"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> içindeki kısıt imnkansız"
@@ -26992,7 +27003,7 @@ msgstr "PRINT_OPERAND boş gösterici"
 msgid "function may return address of local variable"
 msgstr "işlev yerel değişkenin adresi ile dönüyor"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "işlev yerel değişkenin adresi ile dönüyor"
@@ -27364,69 +27375,69 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "Biçim dizgesi içinde %s (%C'de)"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 #| msgid "invalid use of %<::%>"
 msgid "%Guse of %<alloca%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 #| msgid "Warn when a variable is unused"
 msgid "%Gargument to variable-length array may be too large"
 msgstr "Bir değişken kullanılmamışsa uyarır"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 #| msgid "argument to %qs attribute larger than %d"
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 #| msgid "Warn when a variable is unused"
 msgid "%Gargument to variable-length array is too large"
 msgstr "Bir değişken kullanılmamışsa uyarır"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 #| msgid "argument to %qs attribute larger than %d"
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 #| msgid "invalid use of %<::%>"
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 #| msgid "Warn when a variable is unused"
 msgid "%Gargument to variable-length array is zero"
 msgstr "Bir değişken kullanılmamışsa uyarır"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 #| msgid "Second argument of MOD at %L is zero"
 msgid "%Gargument to %<alloca%> is zero"
@@ -27542,7 +27553,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "array %qD declared here"
@@ -27569,11 +27580,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -27658,328 +27669,328 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "asm çıktısı %d içinde geçersiz sol değer"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "bellek girdisi %d doğrudan adreslenebilir değil"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, gcc-internal-format
 msgid "enclosing region"
 msgstr ""
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qD bildirilmemiş"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "%s kapatılırken hata: %m"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%H%qE bildirilmemiş (bu işlevde ilk kullanımı)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "enclosing %<target%>"
 msgstr "%<{%> umuluyordu"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should be private"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qE should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be linear"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "%s variable %qE is private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimpleme başarısız"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT %<...%> üzerinden aktarılırken %qT'ye yükseltgenir"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(bu durumda %<va_arg%>'a %qT değil %qT akarılmalı)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Bu kodun bitiminde uygulama çıkacak"
@@ -28459,24 +28470,24 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s burada asm içinde kullanılamaz"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "as %qD"
 msgid "for %qD"
 msgstr "%qD olarak"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "güvenilir yığıt sınaması için çerçeve boyutu çok büyük"
@@ -28499,12 +28510,12 @@ msgstr "%<asm%> terimi imkansız yeniden yükleme gerektiriyor"
 msgid "unable to find a register to spill"
 msgstr "%qs sınıfı içinde dökülecek bir yazmaç bulunamadı"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "bir %<asm%> içindeki terim terim kısıtı tutarsız"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
@@ -29254,13 +29265,13 @@ msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 msgid "unrecognized argument in option %qs"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
@@ -29397,7 +29408,7 @@ msgstr ""
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
@@ -29950,25 +29961,25 @@ msgstr "örtük olarak çekilmiş yazmaçlar yığıtın tepesinde gruplanmalı"
 msgid "output operand %d must use %<&%> constraint"
 msgstr "çıktı terimi %d %<&%> kısıtını kullanmalı"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "validate_value_data: [%u] Boş zincir için next_regno hatalı (%u)"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: Loop in regno chain (%u)"
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "validate_value_data: regno zinciri içinde döngü (%u)"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "validate_value_data: [%u] oldest_regno hatalı (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
@@ -30037,13 +30048,13 @@ msgstr "%<asm%> içindeki tamsayı sabit terim yeniden yüklenemiyor"
 msgid "impossible register constraint in %<asm%>"
 msgstr "%<asm%> içindeki yazmaç kısıtı imkansız"
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "%s %s desteği vermiyor"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "%<&%> kısıtı yazmaç sınıfsız kullanılmış"
@@ -30074,52 +30085,52 @@ msgstr "%<asm%> teriminin kısıtı terim boyutu ile uyumsuz"
 msgid "output operand is constant in %<asm%>"
 msgstr "çıktı terimi %<asm%> içindeki bir sabit"
 
-#: rtl.c:850
+#: rtl.c:860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "RTL sınaması: %5$s dosyasının %6$d. satırında %4$s içinde %3$d öğeli '%2$s'nin %1$d. öğesine erişim"
 
-#: rtl.c:860
+#: rtl.c:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL sınaması: %6$s dosyasının %7$d. satırında '%2$c' türünde öğe %1$d umuluyordu,  %5$s içinde (rtx %4$s)'%3$c' var"
 
-#: rtl.c:870
+#: rtl.c:880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL sınaması: %7$s dosyasının %8$d. satırında, '%2$c' veya '%3$c' türünde öğe %1$d umuluyordu,  %6$s içinde (rtx %5$s) '%4$c' var"
 
-#: rtl.c:879
+#: rtl.c:889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL sınaması: %4$s dosyasının %5$d. satırında '%1$s' kodu umuluyordu, %3$s içinde '%2$s' var"
 
-#: rtl.c:889
+#: rtl.c:899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL sınaması: %5$s dosyasının %6$d. satırında '%1$s' veya '%2$s'kodu umuluyordu, %4$s içinde '%3$s' var"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL sınaması: %5$s dosyasının %6$d. satırında '%1$s' veya '%2$s'kodu umuluyordu, %4$s içinde '%3$s' var"
 
-#: rtl.c:927
+#: rtl.c:937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "RTL sınaması: %5$s dosyasının %6$d. satırında %4$s içinde %3$d öğeli '%2$s'nin %1$d. öğesine erişim"
 
-#: rtl.c:937
+#: rtl.c:947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL sınaması: %4$s dosyasının %5$d. satırında %3$s içinde %2$d öğeli vektörün %1$d. öğesine erişim"
 
-#: rtl.c:947
+#: rtl.c:957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL sınaması: %4$s dosyasının %5$d. satırında %3$s içinde %2$d öğeli vektörün %1$d. öğesine erişim"
 
-#: rtl.c:958
+#: rtl.c:968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "RTL seçenek denetimi: %4$s dosyasının %5$d. satırında %3$s içinde %1$s umulmayan rtx kodu `%2$s' ile kullanılmış"
@@ -30164,23 +30175,23 @@ msgstr "kısıt referansları geçersiz terim numaraları eşleştiriyor"
 msgid "invalid punctuation %qc in constraint"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "eşleşen kısıt bir yazmaça izin vermez"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate asm operand name %qs"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "asm terim ismi '%qs' yinelenmiş"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "isimli terim için kapama parantezi eksik"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "tanımlanmamış isimli terim '%qs'"
@@ -30925,9 +30936,9 @@ msgstr "%%R için terim geçersiz"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "type mismatch in %qs"
@@ -30968,7 +30979,7 @@ msgstr "%%R için terim geçersiz"
 msgid "invalid clique in %qs"
 msgstr "%qD kullanımı geçersiz"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
@@ -31202,411 +31213,411 @@ msgstr "komuttaki terim geçersiz"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "vector types expected in %qs"
 msgstr "ifade umuluyordu"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "vectors with different element number found in %qs"
 msgstr "?: için terimler farklı türde"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid mask type in %qs"
 msgstr "geçersiz döngü komutu"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid position or size in %qs"
 msgstr "gösterici kipi olarak %qs geçersiz"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "%qs into non-mode-precision operand"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qs not at element boundary"
 msgstr "%q+D bir işlev değil,"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "atamanın sol tarafı geçersiz"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "%qs LHS in clobber statement"
 msgstr "deyim umuluyordu"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "%%R için terim geçersiz"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid indirect memory address"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "geçersiz dolaylı bellek adresi"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "incorrect number of vector %qs elements"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, fuzzy, gcc-internal-format
 #| msgid "PHI def is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "PHI tanımı bir GIMPLE değeri değil"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "non-vector %qs with elements"
 msgstr "?: için terimler farklı türde"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "always-false koşuluyla ASSERT_EXPR"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in return statement"
 msgstr "komuttaki terim geçersiz"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid conversion in return statement"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "goto destination is neither a label nor a pointer"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to switch statement"
 msgstr "%%s kodu için terim geçersiz"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code for huge switch statements"
 msgid "non-integral type switch statement"
 msgstr "huge switch deyimleri için kod üretilir"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "%<default%> label not within a switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "%<default%> etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "invalid case label in switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid case range in switch statement"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "işlev bildiriminde (türleri belirtmeksizin) parametre isimleri"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, fuzzy, gcc-internal-format
 #| msgid "format string has invalid operand number"
 msgid "incorrect setting of landing pad number"
 msgstr "biçim dizgesi geçersiz sayıda terim içeriyor"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%p code"
 msgid "invalid comparison code in gimple cond"
 msgstr "%%p kodu için terim geçersiz"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in increment"
 msgid "invalid labels in gimple cond"
 msgstr "arttırmada geçersiz sol taraf"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid address"
 msgid "invalid %<PHI%> result"
 msgstr "adres geçersiz"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "missing %<PHI%> def"
 msgstr "tanım eksik"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid IACC argument"
 msgid "invalid %<PHI%> argument"
 msgstr "IACC argümanı geçersiz"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "atamada uyumsuz türler"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_stmts başarısız"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "local declaration from a different function"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, fuzzy, gcc-internal-format
 #| msgid "bb_for_stmt (phi) is set to a wrong basic block"
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "bb_for_stmt (phi) yanlış temel bloka atanmış"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, fuzzy, gcc-internal-format
 #| msgid "from this location"
 msgid "PHI node with location"
 msgstr "buradan"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "Ağaç düğümlerinin paylaşımı yanlış"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "bb_for_stmt (stmt) is set to a wrong basic block"
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "bb_for_stmt (stmt) yanlış temel bloka atanmış"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "deyim yakalama için imli, ama olmuyor."
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "Deyim blokun ortasında yakalama için imlenmiş"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "verify_gimple failed"
 msgstr "verify_stmts başarısız"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY_BLOCK has a statement list associated with it"
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK onunla ilişkili bir deyim listesi içeriyor"
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, fuzzy, gcc-internal-format
 #| msgid "EXIT_BLOCK has a statement list associated with it"
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK onunla ilişkili bir deyim listesi içeriyor"
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "bb %d deki çıkışa düşüş"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "%d. temel blokun ortasında denetim akışı"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "bb %d içinde bir denetim deyimi sonrası düşen kenar"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fallthru edge after a control statement in bb %d"
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "bb %d içinde bir denetim deyimi sonrası düşen kenar"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "bb %d sonunda çıkan ayrıt bayrağı sayısı yanlış"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "bb %d sonunda açıkça goto"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "dönüş ayrıtı bb %d içindeki çıkışı göstermiyor"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, fuzzy, gcc-internal-format
 #| msgid "found default case not at end of case vector"
 msgid "found default case not at the start of case vector"
 msgstr "default case, case vektörünün sonunda değil"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "case labels not sorted:"
 msgid "case labels not sorted: "
 msgstr "sırasız case etiketleri:"
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "fazladan çıkan ayrıt %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "ayrıt %i->%i eksik"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<noreturn%> function does return"
 msgid "%<noreturn%> function does return"
 msgstr "%H%<noreturn%> işlev değer döndürüyor"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcontrol reaches end of non-void function"
 msgid "control reaches end of non-void function"
 msgstr "%Hdenetim void olmayan işlevin sonunu aşıyor"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -32757,7 +32768,7 @@ msgstr "yerel evreli COMMON verisi henüz gerçeklenmedi"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%q+D için istenen hizalama gerçeklenmiş hizalama %wu'den daha büyük"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
@@ -32931,7 +32942,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "support for mode %qs"
 msgid "unsupported record layout"
@@ -33622,7 +33633,7 @@ msgstr "%qE özniteliği %qE için yoksayıldı"
 msgid "type was previously declared %qE"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -33646,7 +33657,7 @@ msgstr "assert: %s %s ile uyumlu atanıyor"
 msgid "%qE argument is not a function"
 msgstr "cleanup argümanı bir işlev değil"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "deprecated message is not a string"
@@ -34113,12 +34124,12 @@ msgstr "gerçeklenim bağlamında %<@end%> eksik"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "atamayı sarmalayan parantezler muhtemelen doğruluk değeri olarak kullanılmış"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "%<restrict%> kullanımı geçersiz"
@@ -34289,13 +34300,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "%qE işlevi için çok fazla argüman belirtildi"
@@ -35312,7 +35323,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr "geleneksel C dizge sabitlerin birleştirilmesine izin vermez"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -35364,7 +35375,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid type for iteration variable %qE"
@@ -35382,18 +35393,18 @@ msgstr "%qE özniteliği için vektör türü geçersiz"
 msgid "%qE is not initialized"
 msgstr "ilklendirici yok"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid controlling predicate"
 msgstr "koşullu terim geçersiz"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "missing increment expression"
@@ -35404,7 +35415,7 @@ msgstr "atama engelleme"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, fuzzy, gcc-internal-format
 #| msgid "invalid truth-value expression"
 msgid "invalid increment expression"
@@ -35475,7 +35486,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -36106,8 +36117,8 @@ msgstr ""
 msgid "wrong type argument to %s"
 msgstr "abs'a yanlış türde argüman"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "sabit ifadesinde taşma"
@@ -36645,19 +36656,19 @@ msgstr "%qs işlevi için argümanlar çok az"
 msgid "function %qD used as %<asm%> output"
 msgstr "salt-okunur konum %<asm%> çıktısı olarak kullanılmış"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only location"
 msgid "assignment of read-only location %qE"
 msgstr "salt-okunur konuma atama"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only location"
 msgid "increment of read-only location %qE"
 msgstr "salt-okunur konuma eksiltim"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only location"
 msgid "decrement of read-only location %qE"
@@ -36862,8 +36873,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "comparison between types %qT and %qT"
@@ -36951,38 +36962,38 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 msgstr[1] "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "mismatch in bound %Z of argument %u declared as %s"
@@ -36990,59 +37001,59 @@ msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 msgstr[1] "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "previously declared as %s"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr ""
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "previously declared as a pointer %s"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "previously declared as an ordinary array %s"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn when a variable is unused"
 msgid "previously declared as a variable length array %s"
 msgstr "Bir değişken kullanılmamışsa uyarır"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "previously declared as an array %s"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %q+D with attribute noinline"
 msgid "previously declared as %s with %u variable bound"
@@ -37050,71 +37061,71 @@ msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "önceki %q+D bildirimi 'inline' öznitelikli değil"
 msgstr[1] "önceki %q+D bildirimi 'inline' öznitelikli değil"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr ""
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "previously declared as %s with bound argument %E"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %<%c%s%>"
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "%<%c%s%>'in önceki bildirimi"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previously declared as %s with bound %qs"
 msgstr "önceden %q+D bildirimi"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -37130,7 +37141,7 @@ msgstr "\"%s\" önişlemci için geçerli bir seçenek değil"
 msgid "too many input files"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -37164,15 +37175,15 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s"
@@ -37342,63 +37353,63 @@ msgstr "-mregparm=%d, 0 ile %d arasında değil"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qE is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
@@ -37579,90 +37590,90 @@ msgstr "-mcpu=%s ile -march= seçenekleri çelişiyor"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr ""
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr ""
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr ""
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "visibility attribute not supported in this configuration; ignored"
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "görünürlük özniteliği bu yapılandırmada desteklenmiyor; yoksayıldı"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr ""
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, fuzzy, gcc-internal-format
 #| msgid "-mdynamic-no-pic overrides -fpic or -fPIC"
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "-mdynamic-no-pic seçeneği -fpic veya -fPIC seçeneklerini iptal eder"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD takes one argument only"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, fuzzy, gcc-internal-format
 #| msgid "argument to '-Xlinker' is missing"
 msgid "CFString literal is missing"
 msgstr "'-Xlinker' için argüman belirtilmemiş"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "CFString literal expression is not a string constant"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "non-ASCII character in CFString literal"
 msgstr "dizge sabiti umuluyordu"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "embedded NUL in CFString literal"
@@ -37671,7 +37682,7 @@ msgstr "dizge sabiti umuluyordu"
 #: config/host-darwin.c:65
 #, fuzzy, gcc-internal-format
 #| msgid "couldn't unmap pch_address_space: %m"
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "pch_address_space unmap edilemedi: %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -37818,396 +37829,396 @@ msgstr "%<#pragma%> burada kullanılamaz"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "#pragma GCC pch_preprocess bozuk, yoksayıldı"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new bir işlev türe uygulanamaz"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use hardware floating point"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "Donanım kayan nokta aritmetiği kullanılmaz"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the bit-field instructions"
 msgid "this operation requires the SVE ISA extension"
 msgstr "Bit alanı komutları kullanılmaz"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "Use the Cray Pointer extension"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Cray Göstericisi eklentisi kullanılır"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "kısıtlar terim için geçersiz"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "%%h değeri geçersiz"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid floating point option: -mfpu=%s"
 msgid "tuning string missing in option (%s)"
 msgstr "geçersiz gerçel değer seçeneği: -mfpu=%s"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "bilinmeyen '%s' spec işlevi"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s;"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-march%>"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 #| msgid "missing filename after %qs"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "%qs den sonra dosyaismi yok"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s ile -march= seçenekleri çelişiyor"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "multilib desteklenmiyor"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> bozuk"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -38277,7 +38288,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "-mmemory-latency için değer %qs hatalı"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -38409,18 +38420,18 @@ msgstr "%qs özniteliğinin argümanı \"ilink1\" ya da \"ilink2\" değildir"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qs özniteliğinin argümanı \"ilink1\" ya da \"ilink2\" değildir"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -38883,245 +38894,251 @@ msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 msgid "target CPU does not support unaligned accesses"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "switch -mcpu=%s conflicts with -march= switch"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "-mcpu=%s ile -march= seçenekleri çelişiyor"
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check ile -mno-apcs-frame uyumsuz"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic ve -mapcs-reent uyumsuz"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS yeniden girişli kod desteklenmiyor. Yoksayıldi"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "veri yapısı boyut sınırı sadece %s ye ayarlanabilir"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "veri yapısı boyut sınırı sadece %s ye ayarlanabilir"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register=, -fpic olmaksızın kullanışsız"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "PIC yazmacı için '%s' kullanılamıyor"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition bu mimaride çalışmaz"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable ile -msdata=%s uyumsuz"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt, düzgün işlem için ABI uyumlu bir AAPCS gerektiriyor"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi bir iwmmxt yetenekli işlemci gerektiriyor"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard ve VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE özniteliği sadece genel nesnelerde etkilidir"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "yığıttaki parametrenin gerçek konumu hesaplanamıyor"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Beklenmeyen modül sonu"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "yüksek yazmaçları çekmeye elverişli düşük yazmaç yok"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -39130,24 +39147,24 @@ msgstr "%qs özniteliğinin argümanı geçersiz"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
@@ -39238,19 +39255,19 @@ msgstr "-pipe desteklenmiyor"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe desteklenmiyor"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G ve -static birlikte kullanılamaz"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
@@ -40072,153 +40089,153 @@ msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 msgid "parameter to builtin not valid: %s"
 msgstr "-ffpe-trap seçeneğinin argümanı geçersiz: %s"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "shift bir anlık değer olmalı"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "yanlış komut:"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "Ağaç düğümlerinin paylaşımı yanlış"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "yanlış komut:"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -40241,576 +40258,576 @@ msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "attribute %qs argument is not a string"
 msgstr "%qs öznitelik argümanı bir dizge sabit değil"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "%qs öznitelik argümanı bir dizge sabit değil"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "%C'de SEQUENCE deyimi zaten TYPE deyiminde belirtilmiş"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function '%s'"
 msgid "wrong argument %qs to option %qs"
 msgstr "'%s' spec işlevi için argümanlar hatalı"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 #| msgid "static is not supported on TPF-OS"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "static TPF-OS'da desteklenmiyor"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bitlik kip bunun içinde derlenmiş değil:"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Seçtiginiz işlemci  x86-64 komutlarını desteklemiyor."
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp32 used with a 64-bit ABI"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mgp32 bir 64-bit ABI ile kullanılmış"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d, 0 ile %d arasında değil"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "bu hedefte -fprefetch-loop-arrays desteklenmiyor"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE komut kümesi iptal edildi, 387 aritmetiği kullanılıyor"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 komut kümesi iptal edildi, SSE aritmetiği kullanılıyor"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, fuzzy, gcc-internal-format
 #| msgid "Use a stack protection method for every function"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall ve regparm öznitelikleri uyumlu değil"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "'-%c' option must have argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "'-%c' seçeneğinde argüman eksik"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -41314,7 +41331,7 @@ msgstr "Sayısal sabit, %C özniteliklerine sahip olamaz"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string argument"
@@ -42466,61 +42483,61 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs geçerli bir sınıf ismi değil"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have different interrupt type"
@@ -43086,266 +43103,266 @@ msgstr "%<__thread%> %<register%> ile kullanılmış"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "%qs requires %qs or %qs"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 seçeneği PowerPC64 mimarisini gerektirir, etkinleştiriliyor"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mapcs-stack-check ile -mno-apcs-frame uyumsuz"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires a PowerPC64 cpu"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 seçeneği PowerPC64 mimarisi gerektirir"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "TI araçları ile uyumlu kod üretilir"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 #| msgid "support for mode %qs"
 msgid "%qs unsupported for this ABI"
 msgstr "%qs kipi için destek"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 64 bitlik Darwin için desteklenmiyor; kurulu C ve C++ kütüphaneleri ile uyumsuz"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring kıymetsiz baytın başta olduğu sistemlerde desteklenmez"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "TI araçları ile uyumlu kod üretilir"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "Using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "IEEE ek duyarlıklı long double kullanılıyor"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "Using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "IBM ek duyarlıklı long double kullanılıyor"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s %s desteği vermiyor"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "%qs needs a valid base register"
 msgstr "Çağrı taşırmalı hedef yazmacı gerekir"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for %<%s=%s%>"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, fuzzy, gcc-internal-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Önerilmiyor. Bu seçenek etkisizdir."
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "bu ABI için 64 bitlik profilleme kodu yok"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<long double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<complex%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:20055
+#: config/rs6000/rs6000.c:20172
 #, fuzzy, gcc-internal-format
 #| msgid "use of boolean types in AltiVec types is invalid"
-msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec türlerde %<long%> kullanımı önerilmiyor; %<int%> kullanın"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<long long%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' geçersiz"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -43538,7 +43555,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "constant value required for builtin %qF argument %d"
@@ -43614,215 +43631,221 @@ msgstr "%qs önerilmiyor"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "template argument %d is invalid"
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "%d. şablon argümanı geçersiz"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "unresolved overloaded builtin"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
 msgid "bad builtin icode"
 msgstr "hatalı yerleşik fcode"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Yerel değişkenlerin toplam boyutu mimarinin izin verdigi sınırı aşıyor"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs çerçevi boyutu "
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs özdevimli yığıt tahsisi kullanıyor"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware vector support not available on %s"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float bir arada desteklenmiyor"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "yığıt boyutunun yığıt koruma değerinden büyük olması gerekir"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "yığıt boyutu 64k'dan büyük olmamalıdır"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard, -mstack-size uyguluyor"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "\"%s\" için argüman sıfır ya da pozitif bir tamsayı olmalı"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -44197,18 +44220,24 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "invalid address"
+msgid "%s contains too many lines"
+msgstr "adres geçersiz"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "parent subprogram cannot be inlined"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "subprogram %q+F not marked %<Inline%>"
@@ -44286,8 +44315,8 @@ msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 msgid "could not read the BRIG file"
 msgstr "belirtim dosyası %s bulunamadı\n"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void değer yoksayılması gerekirken yoksayılmadı"
@@ -44349,7 +44378,7 @@ msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "%q+D dizisinin türü örtük ilklendirme ile uyumsuz olarak tamamlanmış"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "originally defined here"
@@ -44590,7 +44619,7 @@ msgstr "%qD bildirimi bir önceki değişken olmayan bildirimi gölgeliyor"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
@@ -44600,7 +44629,7 @@ msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 msgid "declaration of %qD shadows a previous local"
 msgstr "%qD bildirimi önceki yereli gölgeliyor"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -44611,233 +44640,233 @@ msgstr "%Jgölgeli bildirim burada"
 msgid "nested extern declaration of %qD"
 msgstr "%qD için iç içe 'extern' bildirimi"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qE"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "%qD yerleşik işlevinin uyumsuz örtük bildirimi"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "%qD işlevinin uyumsuz örtük bildirimi"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function)"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%H%qE bildirilmemiş (bu işlevde ilk kullanımı)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function)"
 msgstr "%H%qE bildirilmemiş (bu işlevde ilk kullanımı)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%H(Each undeclared identifier is reported only once"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Bildirilmemiş her betimleyici görüldüğü her işlev"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "%qE yaftası işlev dışına başvuruyor"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "değişkene göre değişen türde betimleyici etki alanına jump"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "jump skips variable initialization"
 msgstr "  %q+#D ilklendirmesi atlanıyor"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "label %qD defined here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "deyim ifadesine jump"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "%qE yaftası bildirimi yinelenmiş"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "yinelenmiş %qD yaftası"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, fuzzy, gcc-internal-format
 #| msgid "%Htraditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "%Hgeleneksel C yaftalar için ayrı bir isim alanından yoksundur, %qE betimleyici çelişiyor"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "switch jumps over variable initialization"
 msgstr "ilklendirmede uyumsuz türler"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "switch jumps into statement expression"
 msgstr "deyim ifadesine jump"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE defined as wrong kind of tag"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qEyanlış etiket çeşidi olarak tanımlı"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "ilk tanımı olmayan adsız struct/union"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "saklatım sınıfı belirteçli boş bildirim yeniden etiket bildirmez"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "tür niteleyicili boş bildirim yeniden etiket bildirmez"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration with type qualifier does not redeclare tag"
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "tür niteleyicili boş bildirim yeniden etiket bildirmez"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "boş bildirimde kullanışsız tür ismi"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "dosya etki alanı boş bildiriminde %<auto%>"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "boş bildirimde kullanışsız saklatım sınıfı belirteci"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "useless type name in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "boş bildirimde kullanışsız tür ismi"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "boş bildirimde kullanışsız tür niteleyici"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, fuzzy, gcc-internal-format
 #| msgid "useless %<__thread%> in empty declaration"
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "boş bildirimde kullanışsız %<__thread%>"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of attributes in empty declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "boş bildirim"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90, parametre dizisi bildirimlerinde `%<static%> veya tür niteleyicileri desteklemez"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 %<[*]%> dizi bildirimlerini desteklemez"
@@ -44845,29 +44874,29 @@ msgstr "ISO C90 %<[*]%> dizi bildirimlerini desteklemez"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D çoğu kez bir işlevdir"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD ilklendirilmiş (yerine  __typeof__  kullanın)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "%qD işlevi bir değişken gibi ilklendirilmiş"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "%qD parametresi ilklendirilmiş"
@@ -44876,294 +44905,294 @@ msgstr "%qD parametresi ilklendirilmiş"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "değişken uzunluklu nesne ilklendirilemeyebilir"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "%qD değişkeni ilklendiricili ama içi boş türde"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %q+D given attribute %qs"
 msgstr "satıriçi %q+D işlevine satıriçi olmayan öznitelik verilmiş"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "ilklendirilmemiş sabit üyesi %qD"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD should be initialized"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "ilklendirici %q+D'nin boyutunu saptayamıyor"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "%q+D de dizi boyutu eksik"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "%q+D dizisi sıfır ya da negatif uzunlukta"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "%q+D nin saklama genişligi sabit değil"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "static olmayan yerel değişken %q+D için asm-belirteci yoksayılıyor"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "oynak alanlı nesne yazmaça konulamaz"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C ileriye dönük parametre bildirimlerine izin vermez"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "%qs bit alanı genişliği bir tamsayı sabit değil"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "%qs bit alanı genişliği bir tamsayı sabit değil"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "%qs bit alanının genişliği negatif"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "bit alanı %qs için sıfır genişlik"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "%qs bit alanı türü bir GCC oluşumudur"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs in genişliği türünü aşıyor"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs genişliği türününkinden daha dar"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 değerlendirilemeyen boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 değerlendirilemeyen boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "variably modified %qE at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "variably modified field at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "%qs bildiriminde tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in type name"
 msgstr "%qs bildiriminde tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "%<const%> yinelenmiş"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "%<restrict%> yinelenmiş"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "%<volatile%> yinelenmiş"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "%<restrict%> yinelenmiş"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name %qs"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "super sınıf ismi %qs çelişiyor"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "%<auto%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "%<typedef%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "%<auto%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field %qE"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for parameter %qE"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "veri türü ismi için saklama sınıfı belirtildi"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs has both %<extern%> and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<auto%>"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "%qs için dosya etki alanı bildirimi %<auto%> belirtiyor"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<register%>"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "%qs için dosya etki alanı bildirimi %<register%> belirtiyor"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested function %qE declared %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -45172,793 +45201,793 @@ msgstr "%qs işlevinin etki alanı dolaylı olarak auto ve %<__thread%> bildirim
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "parametresiz dizi bildirimi içinde 'static' veya tür niteleyiciler"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "esnek dizi üyeli yapı kullanımı geçersiz"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has incomplete type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has incomplete type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array %qs"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C sıfır boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++'da sıfır boyutlu dizi yasaktır"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE is negative"
 msgstr "%qs dizisinin boyutu negatif"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "dizi boyutu negatif"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array %qE is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of unnamed array is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "dizi türü içi boş öğe türü içeriyor"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "işlev tanımı nitelikli void dönüş türü içeriyor"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type qualifiers for %q+D"
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%q+D için çelişen tür niteleyiciler"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "illegal aggregate type %qs specified for instance variable %qs"
 msgid "%qs specified for auto variable %qE"
 msgstr "kümeleme türü %qs gerçeklenim değişkeni %qs için kuraldışı"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for parameter %qE"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field %qE"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for parameter %qE"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> bir bit-alanına uygulanmış"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C 'const' ya da 'volatile' işlev türlerini yasaklar"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type %qT"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "void bildirimli değişken ya da alan %qE"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "parametre dizisi bildirimindeki öznitelikler yoksayıldı"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "field %qE declared as a function"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "%qs alanı tamamlanmamış türde"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid storage class for function %qE"
 msgstr "%qs işlevi için geçersiz saklama sınıfı"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "%<main%> satıriçi işlev olamaz"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "evvelce %<static%> bildirilmiş değişken %<extern%> olarak yeniden bildirilmiş"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "değişkene göre değişen türde betimleyici etki alanına jump"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "işlev bildirimi bir prototip değil"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "işlev bildiriminde (türleri belirtmeksizin) parametre isimleri"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "%u. parametre (%q+D) tamamlanmamış türde"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "%u. parametre (%q+D) void türde"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has void type"
 msgid "parameter %u has void type"
 msgstr "%J%u. parametre void türde"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "tek parametre olarak %<void%> yeterli olmayabilir"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> tek parametre olmalıdır"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "%q+D parametresi tam bir ilerletme bildirimine sahip"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "enum type defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "struct defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "union defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> yeniden tanımlanmış"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> yeniden tanımlanmış"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "%<union %E%> iç içe yeniden tanımlanmış"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "%<struct %E%> iç içe yeniden tanımlanmış"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C isimsiz struct/union'lara izin vermez"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C isimsiz struct/union'lara izin vermez"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "yinelenmiş üye %q+D"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union hiç isimli üye içermiyor"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union hiç üye içermiyor"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "yapı hiç isimli üye içermiyor"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "yapı hiç üye içermiyor"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "%<enum %E%> iç içe yeniden tanımlanmış"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> yeniden bildirilmiş"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "belirtilen kip sırali sayısal değerler için çok küçük"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "sembolik sabit grubunun değerleri en büyük tamsayı aralığını aşıyor."
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "sembolik sabit listesi değerlerinde taşma"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "satıriçi %q+D işlevine satıriçi olmayan öznitelik verilmiş"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "dönen tür %<int%> türüne öntanımlıdir"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "%q+D için önceki prototip yok"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
 msgstr "%q+D için evvelce bildirim yok"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D tanımından önce bildirimsiz kullanılmış"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "%q+D için dönüş türü %<int%> değil"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D normalde bir static olmayan işlevdir"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jprototipli işlev tanımında eski tarz parametre bildirimi"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jgeleneksel C, ISO C tarzı işlev tanımlarına izin vermez"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr ""
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%Jparametre ismi parametre listesinde yok"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "%q+D isimli çok sayıda parametre"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "%q+D için tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "%q+D parametresi için bildirim var ama böyle bir parametre yok"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "argüman sayısı yerleşik prototiple uyumsuz"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "argüman sayısı prototiple uyumsuz"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "prototype declaration"
 msgstr "%Hprototip bildirimi"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "yükseltgenmiş argüman %qD yerleşik prototiple uyumsuz"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "yükseltgenmiş argüman %qD prototiple uyumsuz"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "%qD argümanı yerleşik prototiple eslesmiyor"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "%qD argümanı prototiple uyumsuz"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -45967,282 +45996,282 @@ msgstr "%qD parametresi ilklendirilmiş"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> döngüsünün ilk bildirimi C99 kipinin dışında kullanılmış"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "(-fpermissive kullanırsanız G++ kodunuzu kabul edecek)"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 %<[*]%> dizi bildirimlerini desteklemez"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde statik değişken %q+D bildirimi"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde değişken olmayan %q+D bildirimi"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "bildirim belirteçleri içinde iki veya daha fazla veri türü"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> GCC için çok uzun"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE yinelenmiş"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE bir typedef veya yerleşik veri türü olarak başarısız"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE bildirimin başlangıcında değil"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> %<auto%> ile kullanılmış"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s %s desteği vermiyor"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<static%>  öncesinde %<__thread%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "bildirim belirteçlerinde çok sayıda saklama sınıfı"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@catch%> veya %<@finally%> olmaksızın %<@try%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "sola kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "sağa kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "sola kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -46264,7 +46293,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "%J  diğer tür burada"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -46276,7 +46305,7 @@ msgstr "Beklenmeyen modül sonu"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C boş kaynak dosyalarına izin vermez"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr ""
@@ -46314,7 +46343,7 @@ msgid "unknown type name %qE"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "bildirim belirteçleri umuluyordu"
@@ -46336,7 +46365,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -46354,7 +46383,7 @@ msgstr "tür öznitelikleri sadece tür tanımlarında uygulanabilir"
 msgid "unexpected attribute"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -46396,7 +46425,7 @@ msgstr "dosya etki alanı boş bildiriminde %<auto%>"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
@@ -46461,7 +46490,7 @@ msgstr "bütünleyen ifade %qE bir sabit değil"
 msgid "static assertion failed: %E"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
@@ -46511,14 +46540,14 @@ msgstr "%d. şablon argümanı geçersiz"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "betimleyici umuluyordu"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "sembolik sabitler listesinin sonunda virgul"
@@ -46605,7 +46634,7 @@ msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute does not take any arguments"
@@ -46669,7 +46698,7 @@ msgstr "%HISO C90 kod ve bildirimlerin karışmasına izin vermez"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -46684,7 +46713,7 @@ msgstr "bileşik ifadenin sonunda yafta kullanımı"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "deyim umuluyordu"
@@ -46710,19 +46739,19 @@ msgstr "betimleyici veya %<*%> umuluyordu"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hif deyiminin gövdesi boş"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%Helse gövdesi boş"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -46744,12 +46773,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -46766,8 +46795,8 @@ msgstr "işlev çağrısında gözcü eksik"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -46798,12 +46827,12 @@ msgstr "ISO C ?: üç terimlisinin orta teriminin atlanmasına izin vermez"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -47234,12 +47263,12 @@ msgstr "bildirim belirteçleri umuluyordu"
 msgid "no type or storage class may be specified here,"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -47251,55 +47280,55 @@ msgstr "Code özniteliği eksik"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "Hatalı işleç"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 #| msgid "misplaced %<@%D%> Objective-C++ construct"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected %qE selector name"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -47309,20 +47338,20 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for, while or do statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "#pragma GCC pch_preprocess bozuk, yoksayıldı"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
@@ -47346,61 +47375,61 @@ msgstr "%<,%> veya %<;%> umuluyordu"
 msgid "%qD is not a variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -47424,120 +47453,120 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<grainsize%> value must be positive"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "ifade umuluyordu"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be scalar"
 msgid "%qs expression must be integral"
 msgstr "%L'deki ifade değişmez olmalı"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%qs value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many %<static%> arguments"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "unexpected argument"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qs öznitelik argümanı bir tamsayı sabit değil"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<concurrent%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "chunk size value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid schedule kind"
@@ -47548,17 +47577,17 @@ msgstr "const_double terim geçersiz"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -47578,25 +47607,25 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "geçersiz %%d terimi"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "mask geçersiz"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -47614,89 +47643,89 @@ msgstr "geçersiz döngü komutu"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not valid for %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT %qT'nin alt sınıfı değil"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "invalid OpenACC clause at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "dizge sabiti umuluyordu"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -47713,7 +47742,7 @@ msgstr "%qD bildirilmemişti"
 msgid "expected function name"
 msgstr "umulmadık düğüm"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -47725,30 +47754,30 @@ msgstr "%qD bir üye şablon işlevi değil"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<allocator%>"
@@ -47759,92 +47788,92 @@ msgstr "%<{%> umuluyordu"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable artık desteklenmiyor"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many atomic clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many memory order clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma align%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma align%> bozuk"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<:%>, %<,%>, %<;%>, %<}%> veya %<__attribute__%> umuluyordu"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -47855,35 +47884,35 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "Beklenmeyen modül sonu"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration declaration or initialization"
@@ -47894,76 +47923,76 @@ msgstr "bildirim veya deyim umuluyordu"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "tek parametre olarak %<void%> yeterli olmayabilir"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -47980,64 +48009,64 @@ msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected trait selector name"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "score argument must be constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "score argument must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "property must be constant integer expression or string literal"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "dizge sabiti umuluyordu"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "property must be constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<match%>"
@@ -48049,13 +48078,13 @@ msgstr "%<{%> umuluyordu"
 msgid "variant %qD is not a function"
 msgstr "%q+D bir işlev değil,"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -48066,35 +48095,35 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -48151,45 +48180,45 @@ msgstr "betimleyici veya %<(%> umuluyordu"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "%<large%> kod modeli henüz desteklenmiyor"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -48205,30 +48234,30 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -48238,7 +48267,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -48254,7 +48283,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD bir tamamlanmamış tür içeriyor"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void ifade kullanımı geçersiz"
@@ -48298,133 +48327,133 @@ msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 msgid "function types not truly compatible in ISO C"
 msgstr "işlev türleri  ISO C'de tam uyumlu değil"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr ""
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr ""
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr ""
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "türler tam uyumlu değil"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "pointer target types incompatible in C++"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "işlevin dönüş türü %<volatile%> den dolayı uyumsuz"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "bir struct veya union olmayan şeyin %qE üyesi için istek"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "indisli değer, işleve göstericidir"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C %<register%> dizisi indislemesine izin vermez"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C90 sol tarafsız dizi indislemesine izin vermez"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "called object %qE is not a function or function pointer"
 msgstr "çağrılan nesne %qE bir işlev değil"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "called object %qD is not a function or function pointer"
 msgstr "çağrılan nesne %qE bir işlev değil"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "called object is not a function or function pointer"
@@ -48433,1725 +48462,1725 @@ msgstr "çağrılan nesne %qE bir işlev değil"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "uyumlu olmayan türde işlev çağrısı"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "function definition has qualified void return type"
 msgid "function with qualified void return type called"
 msgstr "işlev tanımı nitelikli void dönüş türü içeriyor"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "%d biçimsel parametre türü tamamlanmayan türde"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı gerçel sayı değil tamsayı aktarılması"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı karmaşık sayı değil tamsayı aktarılması"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı gercel sayı değil karmaşık sayı aktarılması"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı tamsayı değil gercel sayı aktarılması"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı tamsayı değil karmaşık sayı aktarılması"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı karmaşık sayı değil gerçel sayı aktarılması"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı %<double%> değil %<float%> aktarılması"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı karmaşık sayı değil tamsayı aktarılması"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı farklı genişlikte değer aktarılması"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı işaretsiz tamsayı aktarılması"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "%2$qE işlevinin %1$d. argümanına prototipten dolayı işaretli tamsayı aktarılması"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to method %qE"
 msgstr "%qE işlevi için çok fazla argüman belirtildi"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "%qE işlevi için çok fazla argüman belirtildi"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "%q+D zayıf bildirimi ilk kullanımdan sonra belirsiz davranışla sonuçlanıyor"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "gösterici ile tamsayı arasında karşılaştırma"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
 msgstr "%qT türünden %qT türüne dönüşüm gösterici başvurusunu kaldırmaz"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between %q#T and %q#T"
 msgid "comparison between %qT and %qT"
 msgstr "%q#T ile %q#T arasında karşılaştırma"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "çıkartmada %<void *%> türünde gösterici kullanılmış"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "çıkartmada işlev göstericisi kullanılmış"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "%<~%> on a boolean expression"
 msgstr "ifade umuluyordu"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C karmaşık sayıların mantıksal çarpımında %<~%> desteklemez"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "abs'a yanlış türde argüman"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "tek terimli tümleyen için yanlış türde argüman"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "increment of a boolean expression"
 msgstr "ifade umuluyordu"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "decrement of a boolean expression"
 msgstr "ifade umuluyordu"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C karmaşık sayı türlerinde %<++%> ve %<--%> desteklemez"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "arttırımda yanlış türde argüman"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "eksiltmede yanlış türde argüman"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of expression of type %<void%>"
 msgstr "gecicinin adresi alıniyor"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "%qD bit-alanının adresi alınamaz"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "%qD yazmaç değişkeninin adresi istendi"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "genel yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "%qD genel yazmaç değişkeninin adresi istenmiş"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "%qD yazmaç değişkeninin adresi istendi"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "koşullu ifadede sol değersiz dizi"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C tek taraflı void tür içeren koşullu ifadelere izin vermez"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "koşullu ifadede gösterici türü uyumsuzluğu"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "koşullu ifadede gösterici türü uyumsuzluğu"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C %<void *%> ve işlev göstericisi arasında koşullu ifadelere izin vermez"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "koşullu ifadede gösterici türü uyumsuzluğu"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "koşullu ifadede gösterici türü uyumsuzluğu"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "koşullu ifadede gösterici/tamsayı tür uyumsuzluğu"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "koşullu ifadede tür uyumsuzluğu"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "in call to %qD, declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 #, fuzzy
 #| msgid "cast adds new qualifiers to function type"
 msgid "cast adds %q#v qualifier to function type"
 msgstr "tür dönüşümü, işlev türüne yeni niteleyiciler ekliyor"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "tür dönüşümü, gösterici hedef türünden niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "tür dönüşümü dizi belirtiyor"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "tür dönüşümü işlev belirtiyor"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C skalar olmayandan aynı türe dönüşüme izin vermez"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C union türe dönüşüme izin vermez"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "union içinde mevcut olmayan türden union türe dönüşüm"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "tür dönüşümü hedef türün gerekli hizalamasını azaltıyor"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "göstericiden farklı tamsayı türlere dönüşüm"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "%qT türündeki işlev çağrısından eşleşmeyen %qT türüne dönüşüm"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "farklı boyuttaki tamsayı türden göstericiye dönüşüm"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C işlev göstericisinin nesne göstericisine dönüştürülmesini yasaklar"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C nesne göstericisinin işlev göstericisine dönüştürülmesini yasaklar"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "içi boş %qT türünden %qT türüne dönüşüm yapılamaz"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "atama engelleme"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(%qs için near ilklendirme)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "parantezli dizge sabitten ilklendirmeli dizi"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "expected %qT but argument is of type %qT"
 msgstr "%q.*s biçiminin %<%T%s%> türünde olması umuluyor, ama %d. argüman %qT türünde"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "built-in %qD declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, fuzzy, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "implicit conversion from %qT to %qT"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "%2$qE işlevinin %1$d. argümanına aktarım niteliksiz göstericiyi nitelikli yapıyor"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 #, fuzzy
 #| msgid "assignment makes qualified function pointer from unqualified"
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "atama niteliksiz işlev göstericisini nitelikli yapıyor"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 #, fuzzy
 #| msgid "initialization makes qualified function pointer from unqualified"
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "ilklendirme niteliksiz işlev göstericisini nitelikli yapıyor"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 #, fuzzy
 #| msgid "return makes qualified function pointer from unqualified"
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "dönüş değeri niteliksiz işlev göstericisini nitelikli yapıyor"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 #, fuzzy
 #| msgid "assignment discards qualifiers from pointer target type"
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "atama gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 #, fuzzy
 #| msgid "initialization discards qualifiers from pointer target type"
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "ilklendirme gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 #, fuzzy
 #| msgid "return discards qualifiers from pointer target type"
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "dönüş değeri gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C union türe argüman dönüşümünü yasaklar"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "göstericiden farklı tamsayı türlere dönüşüm"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "uyumsuz gösterici türünde ilklendirme"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "%2$qE işlevinin %1$d. argümanı bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "ilklendirmede sol taraf bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr ""
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C işlev göstericisi ile  %<void *%> arasında %2$qE işlevinin %1$d. argümanının  aktarımına izin vermez"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C de işlev göstericisi ile %<void *%> arasında atama yasaktır"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C de işlev göstericisi ile %<void *%> arasında ilklendirme yasaktır"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C de işlev göstericisi ile %<void *%> arasında return yasaktır"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "atama sırasında gösterici hedefleri farklı signed'lıkta"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "ilklendirmede gösterici hedefleri farklı signed'lıkta"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "uyumsuz gösterici türünde atama"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "uyumsuz gösterici türünde ilklendirme"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "uyumsuz gösterici türünde ilklendirme"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "%<return%> with a value, in function returning void"
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "void dönüşlü işlevde %<return%> değer içeriyor"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın tamsayıdan gösterici yapılıyor"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "atama bir tür dönüşümü olmaksızın tamsayıdan gösterici yapıyor"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "ilklendirme bir tür dönüşümü olmaksızın tamsayıdan gösterici yapıyor"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın tamsayıdan gösterici yapılıyor"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın göstericiden tamsayı yapılıyor"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "atamada bir tür dönüşümü olmaksızın göstericiden tamsayı yapılıyor"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "ilklendirmede bir tür dönüşümü olmaksızın göstericiden tamsayı yapılıyor"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın göstericiden tamsayı yapılıyor"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, fuzzy, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "ilklendirmede uyumsuz türler"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "geleneksel C özdevinimli ortak değer ilklendirmesini reddeder"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "esnek dizi üyesi ilklendirmesi"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "dizge sabitten ilgisiz türde ilklendirilmiş dizi"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sol değersiz dizi kullanımı geçersiz"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "dizi sabit olmayan dizi ifadesinden ilklendirilmiş"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer element is not a constant expression"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "ilkledirici öğe yükleme sırasında hesaplanabilir değil"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "geçersiz ilklendirici"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opak vektör türleri ilklendirilemez"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "ilklendiricinin sonunda fazladan parantezli grup"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "skalar ilklendiriciyi kuşatan parantezler"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "iç içe bağlam içinde esnek dizi üyesi ilklendirmesi"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "ilklendiriciyi çevreleyen parantezler yok"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "missing initializer for field %qD of %qT"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "skalar ilklendirici boş"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "skalar ilklendiricide fazladan öğeler"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "dizi olmayan ilklendiricide dizi indisi"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "alan ismi kayıt ya da union ilklendiricisinde kullanılmamış"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "ilklendiricideki dizi indisi tamsayı türünde değil"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer not of integer type"
 msgid "array index in initializer is not an integer constant expression"
 msgstr "ilklendiricideki dizi indisi tamsayı türünde değil"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "ilklendiricideki dizi indisi dizi sınırlarının dışında"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "ilklendiricide indis aralığı boş"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "ilklendiricideki dizi indisi aralığı dizi sınırlarını aşıyor"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "yan etkili ilklendirilmiş alanın üzerine yazıldı"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, fuzzy, gcc-internal-format
 #| msgid "initialized field with side-effects overwritten"
 msgid "initialized field overwritten"
 msgstr "yan etkili ilklendirilmiş alanın üzerine yazıldı"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "karakter dizisi ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "struct ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "esnek dizi üyesinin statik olmayan ilklendirmesi"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "union ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "geleneksel C union ilklendirmesini reddeder"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "dizi ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "vektör ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "skalar ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C %<goto *expr;%> kullanımına izin vermez"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "dönüş değeri void olmayan işlevde %<return%> değer içermiyor"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "void dönüşlü işlevde %<return%> değer içeriyor"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, fuzzy, gcc-internal-format
 #| msgid "%<return%> with a value, in function returning void"
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "void dönüşlü işlevde %<return%> değer içeriyor"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "işlev yerel değişkenin adresi ile dönüyor"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch miktarı bir tamsayı değil"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "ISO C'de %<long%> switch ifadesi %<int%> türüne dönüştürülmez"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "case label is not an integer constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> etiketi bir switch deyimi içinde değil"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue deyimi bir döngü içinde değil"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "deyim etkisiz"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "ifade deyimi boş tür içeriyor"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "?: için terimler farklı türde"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "== veya != ile karşılaştırma gerçel sayılarda güvenli değil"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of distinct pointer types lacks a cast"
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "bir tür dönüşümü olmaksızın ayrı gösterici türlerinin karşılaştırması"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C %<void *%> ile işlev göstericisinin karşılaştırılmasına izin vermez"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın ayrı gösterici türlerinin karşılaştırması"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "gösterici ile tamsayı arasında karşılaştırma"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "tamamlanmış ve içi boş göstericilerin karşılaştırılması"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C işlev göstericilerinin sıralı karşılaştırmalarına izin vermez"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with null pointer"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "doğrudan değer gereken yerde göstericiye dönüştürülemeyen dizi kullanılmış"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "doğrudan değer gereken yerde yapı türünde değer kullanılmış"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "doğrudan değer gereken yerde union türünde değer kullanılmış"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, fuzzy, gcc-internal-format
 #| msgid "used struct type value where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "doğrudan değer gereken yerde yapı türünde değer kullanılmış"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bir üye şablon işlevi değil"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "expected single pointer in %qs clause"
 msgstr "işlev `%s' (%C'deki) zaten %L'de tanımlı"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "zero length array section in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "tumleyen, gösterici olmayan NULL yakalanıyor"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "bit-alanı %q+#D tümleyen türde değil"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "end expression refers to outer iterator %qD"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 #| msgid "expresion reference type error at %L"
 msgid "step expression refers to outer iterator %qD"
 msgstr "%L'de ifade başvuru türü hatası"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected pointer in %qs clause"
 msgstr "Tamsayı umuluyordu"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "zero sized type %qT in %qs clause"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "variable sized type %qT in %qs clause"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction not found for %qE"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bir işlev şablonu değil"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of %<->%> is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "%<->%> için taban terim bir gösterici değil"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses on a task construct"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%>'ın ilk argümanının türü %<va_list%> değil"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -50392,7 +50421,7 @@ msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -50515,736 +50544,742 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%D(%A)%> çağrısı belirsiz"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "üye göstericisi işlevi %E nesnesiz çağrılamaz; .* or ->* kullanımı önerilir"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "%<(%T) (%A)%> çağrısı için eşleşme yok"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> çağrısı belirsiz"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "dizi indisi için dönüşüm belirsiz"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types %qT and %qT to binary %qO"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Kullanıcı işleçleri:\n"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%2$E ? %3$E : %4$E%> içindeki %<?: üç terimlisi%> için %1$s"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<%3$E%4$s%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%2$E[%3$E]%> içindeki %<[] işleci%> için %1$s"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%<%3$s %4$E%> içindeki %2$qs için %1$s"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator %s%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<%3$s%4$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<%3$E %4$s %5$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<%3$s%4$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ bir ?: üç terimlisinde ikinci terimin eksikliğine izin vermez"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "koşullu ifade içinde enum uyumsuzluğu: %qT vs %qT"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "koşullu ifade içinde enum uyumsuzluğu: %qT vs %qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "%q+D için dönüş türü %<int%> değil"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T ile %q#T arasında karşılaştırma"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%2$qT için uygun bir %<%1$s işleci%> yok"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D erişilebilir değil"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "%2$qD işlevinin gösterici olmayan %1$P argümanına NULL aktarılması"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "  declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL'dan gösterici olmayan %qT türüne dönüşüm"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  %2$qD işlevinin %1$P argümanının ilklendirilmesi"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 #, fuzzy
 #| msgid "converting to %qT from %qT"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "%qT türüne %qT türünden dönüşüm"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+#| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
+
+#: cp/call.c:7911
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "%qE bitalanı %qT türüne bağlanamaz"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "%qE paketli alanı %qT türüne bağlanamaz"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "sağ taraf değeri %qE, %qT türüne bağlanamaz"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden aktarılamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD işlevinin %1$d. parametresi için öntanımlı argüman henüz çözümlenmedi"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  %qD çağrısında"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "yerine #include kullanın"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "; use value-initialization instead"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "yerine #include kullanın"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "; use copy-initialization instead"
 msgstr "Ek:`%s' için (%L'de) yeniden ilklendirme"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%s(%A)%> çağrısı belirsiz"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from constructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from destructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "üye işlev %qD nesne olmaksızın çağrılamaz"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "%qT aktarımı %qT türünü %qT türü üzerinden seçiyor"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD %qD üzerinden,"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  çünkü argüman için dönüşüm süreci daha iyi"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 1: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 2: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "İlkinin en kotü dönüşümü ikincisinden daha iyi olsa bile ISO C++ bunlar belirsizdir der:"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -51274,1273 +51309,1273 @@ msgstr "taban %qT türünden türetilmiş %qT türüne dönüşüm sanal taban %
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "taban %qT türünden türetilmiş %qT türüne dönüşüm sanal taban %qT üzerinden yapılamaz"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "taban %qT türünden türetilmiş %qT türüne dönüşüm sanal taban %qT üzerinden yapılamaz"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with function declaration %q#D"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "işlev bildirimi %q#D ile çelişiyor"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with function declaration %q#D"
 msgid "version inherited from %qT declared here"
 msgstr "işlev bildirimi %q#D ile çelişiyor"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D,"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "%q+D yöntemi için erişim özellikleri çelişkili, yoksayıldı"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "%qE alanı için erişim özellikleri çelişkili, yoksayıldı"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  çünkü yerel yöntem %q+#D ile ismi aynı"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "local method %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  çünkü yerel üye %q+#D ile aynı isimde"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "local member %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "taban %qT türünden türetilmiş %qT türüne dönüşüm sanal taban %qT üzerinden yapılamaz"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "sınıf %qT içindeki tüm üye işlevler 'private'"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T sadece private bir yıkıcı tanımlıyor ve kardeşleri yok"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T sadece private kurucular tanımlıyor ve kardeşleri yok"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD için %qT içinde eşsiz bir son değiştirici yok"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D,"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  %q+D tarafından gizlendi"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bit-alanı %q+#D tümleyen türde değil"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bit alanı %q+D için genişlik bir tamsayı sabit değil"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bit alanı %q+D için genişlik negatif"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bit alanı %q+D için sıfır genişlik"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D kendi türünden geniş"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D alanı %#T türünün tüm değerlerini tutmak için çok küçük"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "union içinde kuruculu üye %q+#D olamaz"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "union içinde yıkıcılı üye %q+#D olamaz"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "union içinde kopya atama isleçli üye %q+#D olamaz"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D bir union üyesi olduğundan static olmayabilir"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "%q+D alanı ile geçersiz olarak işlev türü bildirildi"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute on unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "paketsiz POD olmayan %q+#D alanı üzerinde paketli öznitelik yoksayılıyor"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "union %qT içinde çok sayıda alan ilklendirildi"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "initialized member %q+D declared here"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "%q+#D alanı sınıf ile aynı isimde"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T gösterici veri üyeleri içeriyor"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  ama %<%T(const %T&)%>ye değiştirilmiyor"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  ya da %<operator=(const %T&)%> içeriyor"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  ama %<operator=(const %T&)%>ye değiştirilmiyor"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "sanal olmayan yöntem %q+D için ilklendirici belirtilmiş"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "%q+T is not literal because:"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %qD has volatile type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "bir kurucu olmaksızın sınıf içinde static olmayan başvuru %q+#D"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "bir kurucu olmaksızın sınıf içinde static olmayan sabit üye %q+#D"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "doğrudan taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "sanal taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D alanının göreli konumu ABI-uyumlu değil ve bu GCC'nin gelecek sürümünde değişebilir"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "esnek dizi üyeli yapı kullanımı geçersiz"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "array member %q#D declared here"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "next member %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T sanal olmayan kuruculu sanal işlevler içeriyor"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "%qs türü sanal üye işlevlere sahip"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D definition is marked dllimport"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "yapı tamamlanmaya çalışılırken önceki ayrıştırma hatalarından dolayı kesildi"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "dil dizgesi %<\"%E\"%> tanınmıyor"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "%2$qT türüne dönüşüme dayalı aşırı yüklü %1$qD işlevi çözümlenemiyor"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "%qD işlevinin %q#T türüne dönüşümü için eşleşme yok"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "aşırı yüklü %qD işlevinin %q#T türüne dönüşümü belirsiz"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "%qD üyesine gösterici varsayılıyor"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE ifadesi %qT türünden %qT türüne dönüştürülemez"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
 msgstr "burada %q#D olarak yeniden bildirilmiş"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type %qT"
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "parametre değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of %qT as a non-template"
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract return type for function %q+#D"
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "işlev %q+#D için soyut dönüş değeri türü geçersiz"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract return type for function %q+#D"
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "işlev %q+#D için soyut dönüş değeri türü geçersiz"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "%q#T has virtual base classes"
 msgstr "%qs türü sanal üye işlevlere sahip"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%Jtaban sınıf %q#T kopyalama kurucusunda doğrudan ilklendirilmiş olmalı"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D normalde bir static olmayan işlevdir"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%q+E is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "originally declared %<const%> here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a base type for type %qT"
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "tür %qT tür %qT için bir taban tür değil"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD may not have been initialized"
 msgid "virtual table pointer is used uninitialized"
 msgstr "değişken %q+D ilklendirilmiş olmayabilir"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "%qT bir belirsiz %qT tabanıdır"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr "-client_name ile -dynamiclib birarada olmaz"
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "allocation performed here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr "-client_name ile -dynamiclib birarada olmaz"
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a previous local"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "%qD bildirimi önceki yereli gölgeliyor"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokol %qs döngüsel bağımlılık içeriyor"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "%qD şablon parametresi %qT türündeyse butunleyen ya da sırali türde olmadığından bir butunleyen sabit ifadesinde kullanılmaz"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 #| msgid "global destructors not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "bu hedefte global yıkıcılar desteklenmiyor"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "allocated here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "no field %qD found in union being initialized"
 msgid "%qD used in its own initializer"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%q#D is not const"
 msgstr "%q+D bir işlev değil,"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D private'dir"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "%s den %s e dönüşüm (%L'de)"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "statement is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline assembly is not a constant expression"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "cast from %qT is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "unexpected template-id %qE"
 msgstr "deyim umuluyordu"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 #| msgid "function not inlinable"
 msgid "function concept must be called"
 msgstr "işlev satıriçine alınabilir değil"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "ifade umuluyordu"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinin %qT türüne dönüşümü geçersiz"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "label definition is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -52551,59 +52586,59 @@ msgstr "'%s' de umulmadık dosya sonu"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a type"
 msgstr "%qD bir şablon değil"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD is not a class type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "evaluating %qs"
@@ -52657,7 +52692,7 @@ msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklend
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "%qT türünden %qT türüne dönüşüm gösterici başvurusunu kaldırmaz"
@@ -53082,7 +53117,7 @@ msgstr "önceki %q+F bildirimindeki farklı olağandışılıkları yakalıyor"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -53235,8 +53270,8 @@ msgstr "önceden işlev olmayan bildirim %q+#D"
 msgid "%q#D previously defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
@@ -53276,60 +53311,60 @@ msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 msgid "previous specification in %q#D here"
 msgstr "%q+#D bildirimindeki önceki belirtimden sonra verilmiş"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration %qD conflicts with builtin"
 msgstr "%q#D yerleşik bildirimiyle çelişiyor"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration %qD conflicts with import"
 msgstr "%q#D yerleşik bildirimiyle çelişiyor"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "import declared %q#D here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting declaration %qD"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D here"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "%q+D'nin önceki tanımı buradaydı"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "%qD'nin önceki bildirimi buradaydı"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "function declared %<noreturn%> has a %<return%> statement"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "%qD bildiriminin aynı bağlamda bununla yeniden bildirimi anlamsız:"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "deleted definition of %qD is not first declaration"
@@ -53343,55 +53378,55 @@ msgstr "%q+D için yeniden tanımlama"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D: görünürlük özniteliği yoksayıldı çünkü"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "redefinition of %q#D"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%q#D not declared in class"
 msgstr "%qD bildirilmemiş"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "deduction guide %q+D redeclared"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -53399,731 +53434,737 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%q+D'nin yerel-evreli bildirimi yerel-olmayan-evreli bildirimi izliyor"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%q+D'nin yerel-olmayan-evreli bildirimi yerel-evreli bildirimi izliyor"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "%q#D yeniden bildirimi"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "%qD bildiriminin aynı bağlamda bununla yeniden bildirimi anlamsız:"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous label"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  buradan"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  %q+#D ilklendirmesini kesiyor"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  catch blokuna giriyor"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters OpenMP structured block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  %q+#D ilklendirmesi atlanıyor"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD bir işlev şablonu değil"
+
+#: cp/decl.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a template"
 msgid "%q#T is not a class"
 msgstr "%q#T bir şablon değil"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde sınıf şablonu yok"
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "trampolines desteklenmiyor"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kuruculu üye %q+#D kullanılamaz"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde yıkıcılı üye %q+#D kullanılamaz"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kopya atama isleçli üye %q+#D kullanılamaz"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T için öznitelik %qs anahtar sözcüğünü izlemeli"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "bir bildirimde birden fazla tür"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++ yerleşik türü %qT için yeniden bildirim"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef bildiriminde tür ismi eksik"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ anonim yapıları (struct) yasaklar"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sadece kurucular için belirtilebilir"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%qs cannot be used for type declarations"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD ilklendirilmiş (yerine  __typeof__  kullanın)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D definition is marked dllimport"
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "geçersiz üye sablonu bildirimi %qD"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ %<%T::%D%>nin %<%T::%D%> olarak tanımlanmasına izin vermez"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "%qD ilklendirmesi yinelenmiş"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "%q#D değişkeni ilklendirilmiş ama içi boş türde"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "küme %q#D içi boş türde olup tanımlı olamaz"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD başvuru olarak bildirilmiş ama ilklendirilmemiş"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "alelade olmayan ilklendiriciler desteklenmiyor"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "%q+D nin saklama genişligi sabit değil"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  ilklendiriciyi kaldırarak bunun olurunu bulabilirsiniz"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "%qs türü bir kullanıcı tanımlı yapıcıya sahip"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "%2$qT türündeki bir vektör için ilklendirici olarak %1$qT türü geçersiz"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "geçersiz ilklendirici"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT için ilklendirici sayısı çok fazla"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C90 bileşik sabitlere izin vermez"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD içi boş türde"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "union ilklendiricide gereğinden fazla öğe"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD bir kurucu ile ilklendirilmeli, %<{...}%> ile değil"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "parantezli dizge sabiti %2$qE ile ilklendirilmiş %1$qD dizgesi"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "kuruculu statik üye için ilklendirici geçersiz"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(bir sınıf dışı ilklendirme gerekli)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD parametresi ilklendirilmiş"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "could not find variant declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "enumerator %q+D yeniden bildirilmiş"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "değişken uzunluklu nesne ilklendirilemeyebilir"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "önceki %q#D tür bildirimini gölgeliyor"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "%q#D işlevi bir değişken gibi ilklendirilmiş"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  %q+D'deki atıl baglantı bir yıkıcıya sahip olduğundan kullanılamaz"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT, bir erişilemeyen %qT tabanıdır"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "içi boş ture gösterici ilişkilendirme"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%u name provided for structured binding"
@@ -54131,1813 +54172,1824 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs yapı alan için saklama sınıfı belirtilmiş"
 msgstr[1] "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "in initialization of structured binding variable %qD"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot decompose union type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "adres çözümlenemez"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için yıkıcı, bir üye olamaz"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için kurucu, bir üye olamaz"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D bir olağandışılık belirtimi ile bildirilmiş"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD tanımı %qT bağlamını kapsayan isim alanınında değil"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statik üye işlev %q#D tür niteleyicilerle bildirilmiş"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java yöntemi %qD Java olmayan %qT dönüş türünü içeriyor"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "concept %qD has no definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "a function concept cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD bir şablon işlevi değildir"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "%qD doğrudan özelleştirmesinin kardeş bildirimde tanımı"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "birincil şablon bildiriminde %qD şablon kimliğinin kullanımı geçersiz"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "kardeş şablon özelleştirmesi %qD bildiriminde %<inline%> kullanılamaz"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> inline olarak bildirilemez"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "%<::main%> static olarak bildirilemez"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> static olarak bildirilemez"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "seçenek argümanı %qs geçersiz"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> %<int%> döndürmeli"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "sınıf %2$qT içinde bildirilmiş %1$q#D diye bir üye işlev yok"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+#| msgid "strong using only meaningful at namespace scope"
+msgid "concept must be defined at namespace scope"
+msgstr "kesin kullanım sadece isimalanı kapsamında anlamlıdır"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot be a sub-component"
 msgid "a variable concept cannot be constrained"
 msgstr "%C'deki döngü değişkeni bir alt bileşen olamaz"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ tümlemeyen %2$qT türündeki %1$qD üye sabitinin ilklendirilmesine izin vermez"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++'da sıfır boyutlu dizi yasaktır"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ değişken boyutlu %qD dizisine izin vermez"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++  değişken boyutlu diziye izin vermez"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "dizi boyutunda taşma"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "kurucu için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "%<operator %T%> için dönüş türü belirtilmiş"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD bildiriminde çok fazla şablon parametresi listeleniyor"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "void bildirimli adsız değişken ya da alan"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "üye olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "bildirimci kimliği eksik; yedek sözcük %qD kullanılıyor"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<register%>"
 msgid "function definition does not declare parameters"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs bildiriminde iki veya daha fazla veri türü"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ türsüz %qs bildirimine izin verilmez"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs bu hedef tarafından desteklenmiyor"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%qs için signed ve unsigned birlikte verilmiş"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%qs için long ve short birlikte belirtilmiş"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs specified with %qT"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "%qs için tepe-seviye bildirim %<auto%> belirtiyor"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs işlevinin etki alanı dolaylı olarak auto ve %<__thread%> bildirimli"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "saklatım sınıfı belirteçleri kardeş işlev bildirimlerinde geçersiz"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Umulmadık sol parantez"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "requires-clause on return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "yıkıcı bir statik üye işlev olamaz"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "kurucular cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "kardeş bildirimi sınıf bildiriminde değil"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "yerel sınıf tanımı içinde kardeş işlev %qs tanımlanamaz"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "yıkıcılar parametre almayabilir"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "%q#T üyeye gösterici bildirilemez"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "şablon kimliği %qD bir bildirici olarak kullanılmış"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "üye işlevler sınıflarının örtük kardeşleridir"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, fuzzy, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "üye %2$qs üzerinde fazladan niteleme %<%1$T::%>"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "üye işlev %<%T::%s%> %<%T%> içinde tanımlanamaz"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "uye işlev %<%T::%s%> %<%T%> içinde bildirilemez"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "üye %<%T::%s%> %qT içinde bildirilemez"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parametre değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "sadece kurucuların bildirimleri %<explicit%> olabilir"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "nesne olmayan üye %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "sabit %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "typedef may not be a function definition"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "typedef may not be a member function definition"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jtypedef ismi bir iç içe isimli belirteç olmayabilir"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ kapsayan sınıf ile aynı isimde yuvalanmış %qD türüne izin vermez"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "kardeş sınıf bildirimi için %<inline%> belirtilmiş"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend bildirimi sınıf anahtarı gerektirir, %<friend class %T::%D%> gibi"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend bildirimi %<friend %#T%> gibi bir sınıf anahtarı gerektirir"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "sınıf %qT genel bağlamın kardeşi yapılmaya çalışılıyor"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "üye olmayan işlev türünde niteleyiciler geçersiz"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "mutlak bildirimci %qT bildirim olarak kullanılmış"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "parametre %q+D soyut %qT türünde bildirilemez"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "bir argüman listesi olmaksızın %qE şablon isminin kullanımı geçersiz"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "işlev %qD bir union içinde virtual olarak bildirilmiş"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD daima static olduğundan sanal olarak bildirilemez"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %qs"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "%s açılamıyor"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "saklama sınıfı %<auto%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "saklama sınıfı %<register%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<static%> belirteci geçersiz"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "sınıf olmayan sanal işlev %qs"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qs defined in a non-class scope"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "üye işlev %qD static ilintilemeli olarak bildirilemez"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statik işlev başka bir işlevin içinde bildirilemez"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "bir statik veri üyesi tanımlarken (bildirime zit olarak) %<static%> kullanılamayabilir"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "üye %q#D harici ilintilemeli olarak doğrudan bildirilemez"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "kurucu geçersiz; muhtemelen %<%T (const %T&)%> anlamında kullandınız"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD static olarak bildirilemeyebilir"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD ya bir statik olmayan üye işlev ya da üye olmayan işlev olmalıdır"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD ya bir sınıf argümanına sahip olmalı ya da enum türünde olmalı"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ ?: üç terimlisinin aşırı yüklenmesini yasaklar"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD ya hiç argüman almamalı ya da bir argüman almalı"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD ya bir ya da iki argüman almalı"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "sonek %qD argüman olarak %<int%> almalı"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "sonek %qD ikinci argümanı olarak %<int%> almalı"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD sadece ve sadece bir argüman almalı"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "kullanıcı tanımlı %qD daima her iki argümanıyla birlikte değerlendirilir"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "önek %qD %qT döndürmeli"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "sonek %qD %qT döndürmeli"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD değeriyle döndürülmeli"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "%2$qs sonrası typedef-ismi %1$qD kullanımı"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D için burada önceki bir bildirim var"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T için burada önceki bir bildirim var"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT türüne enum olarak başvuruluyor"
@@ -55949,110 +56001,110 @@ msgstr "%qT türüne enum olarak başvuruluyor"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD bildirildiği sınıf ile aynı isimde"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT bir şablon değil"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "önceden bildirim olmaksızın enum %q#D kullanımı"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "%qD bir bit alanı türü olarak bildirilemez"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "türetilmiş union %qT geçersiz"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in the class %qT"
 msgid "%qT defined with multiple direct bases"
 msgstr "%qD zaten sınıf %qT içinde tanımlı"
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "taban tür %qT bir yapı veya sınıf türü olarak hatalı"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "ardışık tür %qT tanımsız"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "yinelenmiş taban türü %qT geçersiz"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jönceden burada tanımlı"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
@@ -56061,85 +56113,85 @@ msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarı
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "%qT için simgesel sabit değerlerinin tamamını hiçbir tümleyen tür temsil edemez"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD'de simgesel sabit değerlerinde taşma"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "çok sayıda %q#T tanımı"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>, %<*this%> için bir başvuru döndürmeli"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "işlevin dönüş türü %<volatile%> den dolayı uyumsuz"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD zaten %qT sınıfında tanımlı"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -56180,7 +56232,7 @@ msgstr "bir işlev silinemez. Sadece nesnelerin göstericileri %<delete%>'e konu
 msgid "deleting %qT is undefined"
 msgstr "%qT silinmesi tanımsız"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D şablon bildirimi"
@@ -56191,7 +56243,7 @@ msgstr "%q#D şablon bildirimi"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "yıkıcı %qD üye şablon olarak bildirilmiş"
@@ -56543,25 +56595,25 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -56668,7 +56720,7 @@ msgstr "%<%T::%D%> ile ilişkilendirme belirsiz"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
@@ -56679,7 +56731,7 @@ msgstr "%qD %qT'nin bir üyesi değil"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD, %qD nin bir üyesi değil"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD, %qD nin bir üyesi değil"
@@ -56879,439 +56931,439 @@ msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "initializer for flexible array member %q#D"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD üye ilklendirme listesinde ilklendirilmiş olmalı"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "sınıf %T kendisiyle dolaylı kardeş"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "ilklendirilmemiş sabit üyesi %qD"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%Jilklendirilmemiş referans üye %qD"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "taban %qT sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  taban %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  burada ilklendirildiğinde"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%J%qD için çok sayıda ilklendirici belirtilmiş"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%Jtaban %qT için çok sayıda ilklendirici belirtilmiş"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%J%qT'nin çok sayıda üyesi için ilklendirmeler"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%Jtaban sınıf %q#T kopyalama kurucusunda doğrudan ilklendirilmiş olmalı"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D bir static veri üyesidir; sadece tanımında ilklendirilebilir"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "taban sınıfı olmayan %qT için isimsiz ilklendirici"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "çoklu miras kullanan %qT için isimsiz ilklendirici"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD  hem doğrudan hem de dolaylı sanal taban"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qT türü bir doğrudan %qT tabanı değil"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qT is not a class type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "içi boş tür %qT üye %qD'yi içermiyor"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "%qD bit alanına gösterici geçersiz"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%Jilklendirilmemiş referans üye %qD"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "at offset %wi from %qD declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr ""
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "ifadede tamsayı taşması"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "tür kimliğini sarmalayan parantezleri kaldırmayı deneyin"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "new için %<void%> türü geçersiz"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "%2$qT sınıfında uygun bir %1$qD yok"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "üye %qD için istek belirsiz"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new bir referans türe uygulanamaz"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new bir işlev türe uygulanamaz"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "silme işlecinin çağrısında bir sorun saptandı:"
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "ilklendirici erken sonlanıyor"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete içindeki dizi boyutu bilinmiyor"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "silme işlecinin çağrısında bir sorun saptandı:"
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "bileşik sabit değişken boyuta sahip"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot capture %qE by reference"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "capture by copy of incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> was not captured for this lambda function"
@@ -57371,66 +57423,66 @@ msgstr "%qD için bir şablon parametresine bağımlı bir argüman yok, o halde
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(%<-fpermissive%> kullanırsaniz, G++ kodunuzu kabul edecek ama bildirilmemiş isim kullanımına izin vermek artık önerilmiyor)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "%<?:%> için ortadaki terim olmadığından yorumlanamadı"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
@@ -57629,339 +57681,339 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "array does not match the region tree"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "dizi bölge ağacıyla eşleşmiyor"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "array does not match the region tree"
 msgid "expected signature: %qD"
 msgstr "dizi bölge ağacıyla eşleşmiyor"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a template cannot be defaulted"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "%qD cannot be defaulted"
 msgstr "%q+#D bildirilemez"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "file ends in default argument"
 msgid "defaulted function %q+D with default argument"
 msgstr "öntanımlı argüman içinde dosya sonu"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D %q#T kurucusunu gizliyor"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "due to different exception specifications"
 msgstr "Olağan dışılık belirtimlerini sınayacak kod üretilir"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "%q+D bildirimi kullanımı önceki bildirimlerden biri ile çelişiyor"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%q#D does not have external linkage"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> yıkıcı isimlendiriyor"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "sınıf bağlamında üye olmayan için using bildirimi"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "sınıf bağlamında üye olmayan için using bildirimi"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "%qT türü bir doğrudan %qT tabanı değil"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qD bildirilmemiş"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "using-declaration may not name namespace %qD"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD bildirimi %qD'yi kuşatan isim alanında değil"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD bildiriminde doğrudan niteleme"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD %qD içinde bildirilmeliydi"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD bildirilmemiş"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%qD öznitelik yönergesi yoksayıldı"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "statik üye işlevlerde %<this%> kullanılmaz"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "%q+#D bildirilemez"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "it was later defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "switch %qs artık desteklenmiyor"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "'%s' simgesi (%L'de) belirsiz"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "burada isim alanı rumuzu %qD kullanılamaz, %qD varsayılıyor"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "%qD defined here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "reachable %s definition here"
 msgstr "%Jönceden burada tanımlı"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX, pop_everything () işlevine giriyor\n"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -57988,7 +58040,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -58016,7 +58068,7 @@ msgstr "%<::%D%> bildirilmemişti"
 msgid "request for member %qE in non-class type %qT"
 msgstr "sınıf olmayan %2$qT türündeki %1$qD üyesi için istek"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -58108,7 +58160,7 @@ msgstr "geçersiz şablon kimliği"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -58261,7 +58313,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -58397,7 +58449,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -58455,7 +58507,7 @@ msgstr "deyim ifadelerine sadece işlevlerin içinde izin verilir"
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
@@ -58490,7 +58542,7 @@ msgstr "%qT bir sınıf ya da isim alanı değil"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
@@ -58511,13 +58563,13 @@ msgstr "%2$qT üyesi olarak %<~%1$T%> bildirimi"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef ismi %qD yıkıcı bildiricisi olarak kullanılmış"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "belirteç niteleyici listesi umuluyordu"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bir şablon değil"
@@ -58557,7 +58609,7 @@ msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 msgid "expected nested-name-specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
@@ -58575,7 +58627,7 @@ msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -58591,1225 +58643,1231 @@ msgstr "ISO C++ birleşik sabitlere izin vermez"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, fuzzy, gcc-internal-format
 #| msgid "%<%D::%D%> is not a member of %qT"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%>, %qT'nin bir üyesi değil"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %qs expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "parantezli tür kimliğinden sonra dizi sınırı yasak"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "tür kimliğini sarmalayan parantezleri kaldırmayı deneyin"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "eski tarz tür dönüşümü"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "|| içindeki && çevresinde parantezler önerilir"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+#| msgid "parse error in template argument list"
+msgid "lambda-expression in template parameter type"
+msgstr "şablon argüman listesinde çözümleme hatası"
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Beklenmeyen modül sonu"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "%<this%> cannot be captured by reference"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "salt-okunur değişken %qD için eksiltme"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "%<volatile%> yinelenmiş"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case etiketi %qE bir switch deyimi içinde değil"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "Discover pure and const functions"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "Saf ve sabit işlevler keşfedilir"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "bir dizi döndüren işlev"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "condition declares a function"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot be a sub-component"
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "%C'deki döngü değişkeni bir alt bileşen olamaz"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "ifade deyimi boş tür içeriyor"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ hesaplanmış goto'lara izin vermez"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected module-name"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "method declaration not in @interface context"
 msgid "module-declaration not permitted in header-unit"
 msgstr "yöntem tanımı @interface bağlamında değil"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "private module fragment"
 msgstr "argüman yok"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "import-declaration must be at global scope"
 msgstr "sınıf bağlamında üye olmayan için using bildirimi"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "%qE may only occur once in an export declaration"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "attributes are not permitted in this position"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attributes may be inserted here"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "fazladan %<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "karışık bildirimler ve işlev tanımları yasaktır"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "boş bildirim"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for structured binding declaration"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D %q#T içinde geçersiz"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "type-specifier invalid in lambda"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "sınıf tanımı kardeş olarak bildirilemeyebilir"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in explicit-specifier"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "temel ilklendiricileri sadece kurucular alır"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D statik bildirimi statik olmayan bildirimi izliyor"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "artık tarih olmuş eski tarz temel sınıf ilklendiricisi"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (bir nitelikli üye ilklendirici örtük olarak bir tür olduğundan)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "koşullu terim geçersiz"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
 msgstr "beklenmeyen terim"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "%<export%> anahtar sözcüğü gerçekleştirilmedi ve yoksayılacak"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<export%> not implemented, and will be ignored"
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "%<export%> anahtar sözcüğü gerçekleştirilmedi ve yoksayılacak"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> bir şablon argüman listesi başlatamaz"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ile %<[%> aynı şeyi gösterir. %<<%> ile %<::%> arasında boşluk bırakın"
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(-fpermissive kullanırsanız G++ kodunuzu kabul edecek)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid template-argument-list"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<(%> after template-argument-list"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "şablon argüman listesinde çözümleme hatası"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
 msgstr "deyim umuluyordu"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "bir şablon olduğunu belirtmek için %<%T::template %D%> kullanın"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "C ilintileme ile şablon özelleştirmesi"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Umulmadık isim"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE bir türü isimlendirmiyor"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "concept defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%Jtypedef ismi bir iç içe isimli belirteç olmayabilir"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "attributes ignored on uninstantiated type"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Özdevinimli şablon örneklenimi etkin olur"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "fazladan niteleme yoksayıldı"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD bir isim alanı ismi değil"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD bir isim alanı ismi değil"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "nested namespace name required"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "isim alanı %qD'nin ifade olarak kullanımı"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "opaque-enum-declaration here"
 msgstr "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD işlev etki alanı dışında tanımlı değil"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT bir isim alanı değil"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD işlev etki alanı dışında tanımlı değil"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "işlev bildiriminde (türleri belirtmeksizin) parametre isimleri"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "remove parentheses to default-initialize a variable"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "işlev bildiriminde (türleri belirtmeksizin) parametre isimleri"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "add parentheses to declare a variable"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: işlev tanımı dönüştürülmedi\n"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function %qs"
 msgid "initializer provided for function"
 msgstr "kardeş işlev %qs ilklendirilemiyor"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -59819,481 +59877,481 @@ msgstr "%<%T::%D%> bir tür değil"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD bir isim alanıdır"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "beklenmeyen terim"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "missing template arguments after %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "%qT not permitted in template argument"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "öntanımlı argümanlara sadece işlev parametresi olarak izin verilir"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "sınıf %s için dosya bulunamıyor"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD bildirimindeki sınıf ismi geçersiz"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "bir doğrudan özelleştirme %<template <>%> ile öncelenmeli"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T türünde önceden tanım"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "bir kardeş bildirilirken bir sınıf anahtarı kullanılmalıdır"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "%<__alignof%> bir bit-alanına uygulanmış"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD has non-integral type %qT"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "expected %<;%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (taban sınıfı örtük olarak bir türdür)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "Olağan dışılık belirtimlerini sınayacak kod üretilir"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "attribute %qs specified multiple times"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be scalar"
 msgid "expression must be enclosed in parentheses"
 msgstr "%L'deki ifade değişmez olmalı"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "istenen konum bir tamsayı sabit değil"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "istenen hizalama bir sabit değil"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "şablon parametresi listesi çok az"
@@ -60302,684 +60360,684 @@ msgstr "şablon parametresi listesi çok az"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "şablon parametresi listesi çok fazla"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "isimli dönüş değerleri artık desteklenmiyor"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template %q#D in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "yerel sınıf içinde %q#D üye şablonu bildirimi geçersiz"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "%qs şablon bildirimi"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> alt şablon argüman listesinde %<> >%> olmalıydı"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "sahte  %<>>%>, bir şablon argüman listesini sonlandırmak için %<>%> kullanın"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> before %<extern%>"
 msgid "%<__thread%> before %qD"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "bildirim belirteçlerinde hem %<short%> hem de %<char%>"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE yinelenmiş"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs yinelenmiş"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<auto%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<co_yield%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs yaftası %q#T isimlemesinde kullanılmış"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "replace the class-key with %qs"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "%qT defined as %qs here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT first declared as %qs here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD farklı erişimle tekrar bildirilmiş"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (bir belirsizlik giderici olarak) sadece şablonlarda kullanılabilir"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "öntanımlı argüman içinde dosya sonu"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> bir argüman olarak bir tür belirtmeli"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Nesnel-C++ seçici ismi geçersiz"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, fuzzy, gcc-internal-format
 #| msgid "illegal reference type specified for instance variable %qs"
 msgid "invalid type for instance variable"
 msgstr "gerçekleme değişkeni %qs için ilişkilendirme türü kuraldışı"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE özniteliği %qE için yoksayıldı"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown property attribute %qE"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected integer expression list"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<wait%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in iterator type"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bir üye şablon işlevi değil"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC pch_preprocess bozuk, yoksayıldı"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "geçersiz üye sablonu bildirimi %qD"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  %q+#D tanımından"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%3$qD isim alanını kapsamayan %2$qD isim alanında doğrudan %1$qD bildirimi"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, fuzzy, gcc-internal-format
 #| msgid "invalid default argument for a template template parameter"
 msgid "name of class shadows template template parameter %qD"
 msgstr "bir şablonun şablon parametresi için öntanımlı argüman geçersiz"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "örneklenim sonrası %qT özelleştirmesi"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -60987,155 +61045,155 @@ msgstr "  %q+#D tanımından"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "örneklenim %2$qT sonrası %1$qT özelleştirmesi"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable template"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%3$qD isim alanını kapsamayan %2$qD isim alanında doğrudan %1$qD bildirimi"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "Code özniteliği eksik"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
 msgstr "Code özniteliği eksik"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "birincil şablon bildiriminde şablon kimliği %qD"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "şablon parametre listesi doğrudan örneklenimde kullanılmış"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "tanım doğrudan örneklenim için sağlanmış"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD bildiriminde çok fazla şablon parametresi listeleniyor"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD bildiriminde çok az şablon parametresi listeleniyor"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD doğrudan özelleştirmesi %<template <>%> tarafından vurgulanmalı"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD bir şablon işlevi değildir"
@@ -61148,177 +61206,177 @@ msgstr "%qD bir şablon işlevi değildir"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "%2$qT türünde bildirimli %1$qD isminde üye işlev yok"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %q#D declares a non-template function"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend bildirimi %q#D bir şablon olmayan işlev bildiriyor"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "friend declaration here"
 msgstr "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "        %qD"
 msgid "        %s"
 msgstr "        %qD"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "şablon parametre türü %qT %<friend%> bildirimli"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of variable concept %q#D"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "%qE işlevi için çok fazla argüman belirtildi"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label %qD"
 msgid "primary template %qD"
 msgstr "yinelenmiş %qD yaftası"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 msgstr[1] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD için öntanımlı argüman yok"
@@ -61327,54 +61385,54 @@ msgstr "%qD için öntanımlı argüman yok"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "%qT türündeki parametre için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "bir isim olmaksızın şablon sınıfı"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -61385,59 +61443,59 @@ msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "şablon olmayan %q#D için şablon tanımı"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d seviye umulurken %q#D için şablon parametresi seviyesi olarak %d seviye alındı"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d şablon parametresi %q#T için alındı"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  ama %d gerekiyordu"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bir şablon türü değil"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD bildiriminde şablon belirteçleri belirtilmemiş"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -61445,7 +61503,7 @@ msgid_plural "redeclared with %d template parameters"
 msgstr[0] "%qD şablon parametreleri olmaksızın kullanılmış"
 msgstr[1] "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -61453,478 +61511,478 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 msgstr[1] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "şablon parametresi %q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "burada %q#D olarak yeniden bildirilmiş"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "typedef %q+D için yeniden tanımlama"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of %qT as a non-template"
 msgid "redeclaration %q#D with different constraints"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "%q#T ile %q#T türleri arasında karşılaştırma"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT bir belirsiz %qT tabanıdır"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "%qT türü %qT türünden türetilmemiş"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "%qT türündeki argüman %qT ile eşleşmiyor"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü bu bağlamda dizge sabitler kullanılamaz"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "in template argument for type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "cv nitelemesinde çeliştiğinden dolayı %qE %qT türü için geçerli bir şablon argümanı değildir"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a constant pointer"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir sabit göstericisi değildir"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "yerine %qE kullanmayı deneyin"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qT türündedir"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes in template argument %qE"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of destructor %qE as a type"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "bir şablon parametresinin bir tür üyesine basvurmak için %<typename %E%> kullanın"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  %qT türünde bir sabit umulurken %qT alındı"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "%qT türündeki parametre için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  bir sınıf sablonu umulurken %qE alındı"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  bir tür umulurken %qT alındı"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  bir sınıf sablonu umulurken %qT alındı"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  %qD türünde bir şablon umulurken %qD alındı"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "%q+D için sağlanmış"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "şablon olarak şablon olmayan tür %qT kullanılmış"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "%q+D şablon bildirimi için"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "template constraint failure for %qD"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE bildirimin başlangıcında değil"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye işlev göstericisi oluşturulması"
@@ -61942,314 +62000,314 @@ msgstr "sınıf olmayan %qT türünde üye işlev göstericisi oluşturulması"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has initializer but incomplete type"
 msgid "variable %qD has function type"
 msgstr "%qD değişkeni ilklendiricili ama içi boş türde"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "%q+D bildiriminde"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "bir dizi döndüren işlev"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "bir işlev döndüren işlev"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "void'e referans oluşturuluyor"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "void türünde üyeye gösterici oluşturulması"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ne bir class, ne struct, ne de union türünde"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "şablonda %qs kullanımı"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "%qE bağımlı ismi bir tür olarak çözümlenmedi ama örneklenim onun bir tür olmasını istiyor"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "eğer bu bir tür anlamındaysa %<typename %E%> deyin"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "geçersiz alan %qD kullanımı"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "void ifade kullanımı geçersiz"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> kabul edeceği varsayılacak.)"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<__builtin_choose_expr%> not a constant"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "%<__builtin_choose_expr%> için ilk argüman bir sabit değil"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ne bir sınıf ne de isim alanı"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT anonim türdür/tür kullanır"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument for %qD uses local type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT değişkene göre değişen türde"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  %qD örneklenmeye çalışılıyor"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "yinelenmiş doğrudan %q#D örneklenimi"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %<extern%> kullanımına izin vermez"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "şablon tanımından önce %q#T'nin doğrudan örneklenimi"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %qE kullanımına izin vermez"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "yinelenmiş doğrudan %q#T örneklenimi"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -62262,170 +62320,170 @@ msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "bir tanımlama olmadan %qD'nin doğrudan örneklenimi"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %q+D örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "a concept cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT bir isim alanı değil"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "işlev satıriçine alınma sırasında görmezden gelinir"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "explicit deduction guide declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "%qs öykünümü mümkün değil"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %qT in template argument"
@@ -62577,584 +62635,584 @@ msgstr "%q+#D bildirilemez"
 msgid "  since %q+#D declared in base class"
 msgstr "  `%q+#D' taban sınıfta bildirildiğinden"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "%Hanlamca belirsiz %<else%>den kaçınmak için kaşlı ayraçlar önerilir"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "catching non-reference type %q#T"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 #| msgid "type of asm operand %qE could not be determined"
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "asm terimi %qE'nin türü saptanamadı"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "Objective-C declarations may only appear in global scope"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "Objective-C bildirimleri sadece genel etki alanında görünebilir"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "%qE missing template arguments"
 msgstr "tür argümanı geçersiz"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "yıkıcıların argümanı olmaz"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "statik üye işlevlerde %<this%> kullanılmaz"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "sözde yıkıcı isminde niteleyen etki alanı geçersiz"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE %qT türünde değil"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "compound literal of non-object type %qT"
 msgstr "bileşik sabit değişken boyuta sahip"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "şablon türü parametrelerde %<class%> ya da %<typename%> sözcüğü kullanılmalı"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "bir şablonun şablon parametresinin öntanımlı değeri olarak %qT türünün kullanımı geçersiz"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "bir şablonun şablon parametresi için öntanımlı argüman geçersiz"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "şablon parametre listesi içinde %q#T tanımı"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "nitelikli tür %qT tanımı geçersiz"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not captured"
 msgstr "%qD bir şablon değil"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "iceren işlevden %<auto%> kullanımı"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "iceren işlevden parametre kullanımı"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter from containing function"
 msgid "use of parameter outside function body"
 msgstr "iceren işlevden parametre kullanımı"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "missing template arguments"
 msgstr "tür argümanı geçersiz"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "%qD şablon parametresi %qT türündeyse butunleyen ya da sırali türde olmadığından bir butunleyen sabit ifadesinde kullanılmaz"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "sınıf sablonu %qT'nin ifade olarak kullanımı"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "uye %qD için istek çoklu miras kafesi içinde belirsiz"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE türü bilinmiyor"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
 msgstr "%qT bir şablon türü değil"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "saklatım sınıfı belirteçleri parametre bildiriminde geçersiz"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> static expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> static value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<vector%> length expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<worker%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> num value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "yığıt boyutu ikinin üstel katlarında olmalı"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<grainsize%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<priority%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<hint%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> bir gösterici türü olarak tanımlı değil"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "%q+D statik olmayan bildirim statik bildirimi izliyor"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -63163,22 +63221,22 @@ msgstr "%<__builtin_return_address%>'e aktarılan argüman desteklenmiyor"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -63188,1188 +63246,1189 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV niteleyicileri %qT'ye uygulanamaz"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid " declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %qT is not public"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not public"
 msgstr "%qD bir şablon değil"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is mutable"
 msgstr "%qD bir şablon değil"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%qD has a non-structural type"
 msgstr "%qD bir tamamlanmamış tür içeriyor"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qs öznitelik argümanı bir dizge sabit değil"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qE attribute takes no arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "istenen init_priority bir tamsayı sabit değil"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "%qE özniteliği sadece sınıf türünde nesnelerin dosya bağlamı tanımlarında kullanılabilir"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "istenen init_priority aralık dışında"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "istenen init_priority iç kullanim için ayrilmiştir"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "the %qE attribute requires arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* denetimi: %2$s dosyasının %3$d. satırındaki %1$s içinde başarısız"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++'da bir işlev göstericisi ile %<void *%> türünde göstericiler arasında %s yasaktir"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++'da bir işlev göstericisi ile %<void *%> türünde göstericiler arasında %s yasaktir"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++'da bir işlev göstericisi ile %<void *%> türünde göstericiler arasında %s yasaktir"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "bir üye işleve %qs uygulanması geçersiz"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to a bit-field"
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "bir bit alanına %qs uygulanması geçersiz"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids applying %qs to an expression of function type"
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ işlev türünde bir ifadeye %qs uygulanmasına izin vermez"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to a bit-field"
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "bir bit alanına %qs uygulanması geçersiz"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids applying %qs to an expression of function type"
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ işlev türünde bir ifadeye %qs uygulanmasına izin vermez"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ %qT dizi türüne dönüşüme izin vermez"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT'"
 msgid "deprecated conversion from string constant to %qT"
 msgstr "dizge sabitten %qT'ye dönüşüm artik önerilmiyor"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "sınıf olmayan %3$qT türündeki %2$qE içindeki %1$qD üyesi için istek"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "sınıf olmayan %3$qT türündeki %2$qE içindeki %1$qD üyesi için istek"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "static olmayan veri üyesi %qE kullanımı geçersiz"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "iptal edilen tür %qT iken yıkıcı %qT ile ilişkili"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%>, %qT'nin bir üyesi değil"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD bir üye şablon işlevi değil"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT bir nesne göstericisi türü değil"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "dizi başvurusunda altindis yok"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "%<register%> olarak bildirilmiş dizi indislemesi"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "%qE kullanimında nesne eksik"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ program içinden %<::main%> çağrısına izin vermez"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<%E (...)%> içinde üye gösterici işlevi çağrısı için %<.*%> veya %<->*%> kullanılmalı"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "işlev için çok fazla argüman belirtildi"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "işlev için çok az argüman belirtildi"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%P parametresi %qD içinde tamamlanmamış %qT türünde"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametre %P tamamlanmamış %qT türünde"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the address of %qD will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "aşırı yüklü işlevden %qT türüne dönüşüm yapildigi varsayılıyor"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "aritmetik içinde NULL kullanımı"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ da gösterici ile tamsayı arasında karşılaştırmaya izin verilmez"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "gerçel sayı olmayan argümanlar arasında düzenlenmemiş karşılaştırma"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ bir çıkarma içinde %<void *%> türde gösterici kullanımına izin vermez"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içindeki bir işlev göstericisi kullanımına izin vermez"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içinde bir yöntem göstericisi kullanımına izin vermez"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "gösterici aritmetiginde tamamlanmamış ture gösterici kullanımı geçersiz"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "%qE kullanımı üye işleve gösterici biçiminde geçersiz"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  bir nitelemeli kimlik gerekli"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around %qE cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parantez icene alınmis %qE üye işleve gösterici biçiminde kullanilamaz"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir niteliksiz ya da parantezli statik olmayan üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir."
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir sınır üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ %<::main%> işlevinin adresinin alınmasına izin vermez"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "referans üye %qD için gösterici oluşturulamaz"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "%qD bit-alanının adresi alınamaz"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of an immediate function %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "%qD doğrudan yazmaç değişkeninin adresi istendi"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr " %qD için adres istegi (%<register%> olarak bildirilmiş olan)"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %q#T"
 msgstr "%qT yerel tür %qT kullanıyor"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "%qT'den %qT'ye dönüşüm"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinin %qT türüne dönüşümü geçersiz"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "%qT'den %qT'ye tür dönüşümü hassasiyet kaybi oluşturuyor"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "%qT türünden %qT türüne dönüşüm hedef türün hizalama gereksinimini arttiriyor"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ işlev ve nesne göstericileri arasında dönüşüme izin vermez"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ne bir gösterici türü ne de bir veri üyesine gösterici türü olan %qT ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "bir gösterici ya da bir işlev türüne referans olan %qT türü ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ %qT dizi türüne dönüşüme izin vermez"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  %<%Q(%#T, %#T)%> nin gelisiminde"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "dizi ilklendirici hatalı"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "atamanın sol tarafı geçersiz"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   üye işleve gösterici dönüşümünde"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "sanal taban %qT üzerinden üye göstericisine dönüşüm"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   üyeye gösterici dönüşümünde"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE işlevinin %1$d. argümanı bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "%2$q+D işlevinin %1$P. argümanına aktarımda"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "geçiciye başvuru dönüyor"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "yerel değişken %q+D'ye referans donduruldu"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "redundant move in return statement"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "bir yıkıcıdan değer donuyor"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "bir kurucunun bir işlev deneme blokunun bir tutamagından dondurulemez"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "kurucudan bir değer dondurulemez"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "ilklendirici yok"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%>', %<throw()%> olarak bildirilmedikce (ya da -fcheck-new etkinken) NULL donmemeli"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -64671,116 +64730,110 @@ msgstr "skalar ilklendiriciyi kuşatan parantezler"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "bir bileşik sabitli %qT türündeki küme ilklendirilemez"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "birlesik yapı ilklendiricideki alan isminin yerine index değeri"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "döngüsel gösterici görevlendirmesi saptandi"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> için taban terim gösterici olmayan %qT türünde"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr " %<operator->()%> gösterici olmayan sonuc veriyor"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> için taban terim bir gösterici değil"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE bir üye göstericisi olarak kullanilamaz, cunku %qT türünde"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer %qE to %qE, which is of non-aggregate type %qT"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "uye göstericisi %qE %qE'ye kümeleme türü olmayan %qT türünde uygulanamaz"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-#| msgid "could not convert template argument %qE to %qT"
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%qD işlevine çağrı (ici boş tür `%q#T' yakalanırken)"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "ici boş tür `%q#T' yakalanırken işleve çağrı"
@@ -64800,294 +64853,300 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "extern symbols cannot have initializers"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "Variable tag cannot be INTENT(IN) at %C"
 msgid "variables cannot be of type void"
 msgstr "%C'de değişken etiketi INTENT(IN) olamaz"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "cannot be declared to be a function"
 msgstr "new bir işlev türe uygulanamaz"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of %<struct %E%>"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "%<struct %E%> yeniden tanımlanmış"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be %s"
 msgstr "%s açılamıyor"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be `scope` and `%s`"
 msgstr "%s açılamıyor"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qD not allowed in using-declaration"
 msgid "field not allowed in interface"
 msgstr "using bildiriminde isim alanı %qD kullanılamaz"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "inout variables can only be declared inside inout functions"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to scope class must be scope"
 msgstr "deyim umuluyordu"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "manifest constants must have initializers"
 msgstr "temel ilklendiricileri sadece kurucular alır"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "braced spec body '%s' is invalid"
 msgid "size of type %s is invalid"
 msgstr "kaşlı ayraçlı spec gövdesi '%s' geçersiz"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%s does not have a default initializer"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "is not a static and cannot have static initializer"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "static storage variables cannot have destructors"
 msgstr "Java sınıfı %qT bir yıkıcıya sahip olamaz"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "string expected for library name"
 msgstr "sınıf ismi umuluyordu"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "string expected for mangled name"
 msgstr "%C'de değişken ismi umuluyordu"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "argüman yok"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "can only apply to a single declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "incomplete mixin declaration (%s)"
 msgstr "%q#D bildirimi çelişkili"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "enum %s must have at least one member"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "circular reference to enum member"
 msgstr "geçiciye başvuru dönüyor"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgid "template tuple parameter must be last one"
 msgstr "şablon türü parametrelerde %<class%> ya da %<typename%> sözcüğü kullanılmalı"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "iç içe satıriçine alma işlemi"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "iç içe satıriçine alma işlemi"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "error instantiating"
 msgstr "%qs yazılırken hata"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%s must be a function instead of %s"
 msgstr "%qT %qT'nin alt sınıfı değil"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "functions cannot be scope"
@@ -65096,45 +65155,55 @@ msgstr "birleşik yapı şeffaf olamaz"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "%s functions cannot be abstract"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot override a non-virtual function"
 msgstr "Aşırı yüklü sanal işlev isimleri hakkında uyarır"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "cannot be both final and abstract"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -65142,190 +65211,190 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "cannot override final function %s"
 msgstr "%s %q#D işlevini gölgeliyor"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "multiple overrides of same function"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in return"
 msgid "incompatible covariant types %s and %s"
 msgstr "dönüş değerinde uyumsuz türler"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not allow extra %<;%> outside of a function"
 msgid "does not override any function"
 msgstr "ISO C işlevler dışında fazladan %<;%> kullanımına izin vermez"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "cannot override final function %s.%s"
 msgstr "%s %q#D işlevini gölgeliyor"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "override only applies to class member functions"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "Aşırı yüklü sanal işlev isimleri hakkında uyarır"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "first argument of %q+D should be %<int%>"
 msgid "first argument must be type size_t, not %s"
 msgstr "%q+D için ilk argüman %<int%> olmalıydı"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of IBCLR exceeds bit size at %L"
 msgid "one argument of type void* expected, not %s"
 msgstr "%L'de IBCLR'nin ikinci argümanı bit boyutunu aşıyor"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "structs, unions cannot be abstract"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "circular pointer delegation detected"
 msgid "circular inheritance"
 msgstr "döngüsel gösterici görevlendirmesi saptandi"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "base type must be interface, not %s"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "tekrar belirtilen \"%s\" dizini yok sayılıyor\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot inherit from final class %s"
 msgstr "sınıf %s için dosya bulunamıyor"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "%qs türü sanal üye işlevlere sahip"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "mixin templates are not regular templates"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot resolve"
 msgstr "%s açılamıyor"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "cannot alias an expression %s"
@@ -65341,22 +65410,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "has forward references"
@@ -65423,23 +65492,22 @@ msgstr ""
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "işlevin dönüş türü işlev olamaz"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "naked assembly functions with contracts are not supported"
@@ -66016,7 +66084,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir sabit olmalı"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -67248,12 +67316,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "%C'deki ilklendirme bir gösterici değişkeni için değil"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L'deki altdizge başlangıç indisi birden küçük olmalıdır"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L exceeds the string length"
@@ -67455,7 +67523,7 @@ msgstr "%C'deki INTENT belirtimi hatalı"
 msgid "deferred type parameter at %C"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -70201,7 +70269,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
@@ -70293,7 +70361,7 @@ msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -70441,12 +70509,12 @@ msgstr "%L'de tanımlanmış atamanın ilk argümanı INTENT(IN) veya INTENT(INO
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L'de tanımlanmış atamanın ikinci argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı INTENT(IN) olmalıdır"
@@ -70571,593 +70639,593 @@ msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "%L'de IBITS'in üçüncü argümanı geçersiz"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Anahtar sözcük argümanı '%s' (%L'de) başka bir fiili argümanla zaten ilişkili"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "%L'deki yordam çağrısında biçimselden daha gerçekçi argümanlar"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında diğer return belirtimi eksik"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında umulmadık diğer return belirtimi"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "'%s' için fiili argüman (%L'de) bir tahmini boyutlu dizi olamaz"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında diğer return belirtimi eksik"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Argüman '%s' için fiili argüman eksik (%L'de)"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "INTENT(%s) ile '%s' argümanı ve INTENT(%s) ile '%s' argümanı aynı fiili argüman ile ilişkilendirilmiş"
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup POINTER özniteliğine sahiptir"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup bir INTENT(%s) argümanına aktarılmıştır"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup bir INTENT(%s) argümanına aktarılmıştır"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "'%s' simgesi %L'de zaten bir aleni arayüze sahip"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D tanımsız %qs simgesine rumuzlu"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "'%s' öğesi (%C'de) zaten arayüzde mevcut"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "Bir PURE yordamında içerilmiş '%s' yordamının kendisi de PURE olmalı"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "Bir PURE yordamında içerilmiş '%s' yordamının kendisi de PURE olmalı"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "%L'de boyut argümanı INTEGER türünde olmalı"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued internal function '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Karakter değerli iç işlev '%s' tahmini uzunlukta olmamalı (%L'de)"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "'%s' yordamı (%s içinde, %L'de) be işlev ne de altyordam"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "`%s' çağrısındaki argümanlar çok fazla (%L'de)"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -71320,37 +71388,37 @@ msgstr "%s'in KIND parametresi %L'de bir ilklendirme ifadesi olmalıdır"
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "'%s' yerleşiğine altyordam çağrısı %L'de PURE değil"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "'%s' yerleşiğine altyordam çağrısı %L'de PURE değil"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Ek: %s den %s e dönüşüm (%L'de)"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "%s den %s e dönüşüm (%L'de)"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Ek: %s den %s e dönüşüm (%L'de)"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "%s den %s e dönüşüm (%L'de)"
@@ -71358,24 +71426,24 @@ msgstr "%s den %s e dönüşüm (%L'de)"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -71991,7 +72059,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -73287,12 +73355,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -73462,160 +73530,160 @@ msgstr "Başvurulan '%s' yerleşik işleci (%L'de), '%s' modülünde yok"
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "Modül dosyası`%s' yazmak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Modül dosyası `%s' yazmak için açılırken hata: %s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file '%s': %s\n"
 msgid "Cannot delete module file %qs: %s"
 msgstr "%s: `%s' silinemiyor: %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Modül dosyası`%s' yazmak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file '%s': %s\n"
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "%s: yardımcı bilgi dosyası `%s' silinemiyor: %s\n"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs at %C already declared"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs already declared"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%s deyimi bir döngü içinde değil (%C'de)"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "procedure name = %s"
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Modül dosyası`%s' okumak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -74204,8 +74272,8 @@ msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
@@ -76407,7 +76475,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Yafta %d (%L'de başvurulu) hiç tanımlanmamış"
@@ -76537,7 +76605,7 @@ msgstr "'%s' özel işlevi (%L'de) çözümlenemiyor"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -76711,230 +76779,230 @@ msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L'de sıfır adım uzunluğu kuraldışı"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "dizi başvurusunda altindis yok"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Tahmini boyutlu dizi bölümünün en sağ üst sınırı %L'de belirtilmemiş"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L'de dizi indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ek: %L'de REAL dizi indisi"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L'de boyut argümanı INTEGER türünde olmalı"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L'deki dizi indisi %d. mertebeden bir dizidir"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge başlangıç indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L'deki altdizge başlangıç indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge son indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L'de sıfırdan farklı bir mertebeden iki veya daha fazla parça başvurusu belirtilmemelidir"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -76944,12 +77012,12 @@ msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -76959,309 +77027,309 @@ msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in typebound call at %L"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "%s' etiketi (%L'de) bir değişmez olmalı"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Öğesel yordamın '%s' argümanı değişmez olmalı (%L'de)"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL başlatma ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL son ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L'deki FORALL adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L'de ALLOCATE deyimindeki ifade ya bir POINTER ya da ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -77270,301 +77338,301 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L'de CASE deyimindeki ifade %d. çeşit olmalı"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L'de CASE deyimindeki ifade bir değişmez olmalı"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L'deki DEFAULT CASE deyiminden sonra %L'de ikinci bir DEFAULT CASE olamaz"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L'deki aralık belirtimi asla eşleşmeyebilir"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L'deki mantıksal SELECT CASE blokunun ikiden fazla case'i var"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "'%s' ismi (%C'de) tanımlı bir işleç olarak kullanılamaz"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L'deki veri aktarım elemanı tahmini boyutlu bir diziye bir tam başvuru olamaz"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L'deki deyim %L'deki dallanma deyimi için geçerli bir dallanma hedef deyimi değildir"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -77572,12 +77640,12 @@ msgstr "%L'deki dallanma bir sonsuz döngüye sebep oluyor"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -77585,201 +77653,201 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L'deki WHERE maskesi uyumsuz biçimde"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L'deki WHERE atama hedefi uyumsuz biçimde"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L'deki WHERE içinde desteklenmeyen deyim"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "'%s' indisli FORALL %L'de bu nesneye birden fazla atamaya sebep oluyor"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "FORALL construct at %L"
 msgstr "Kurucu %s olmayabilir"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Bir dış FORALL oluşumu zaten bu isimde bir indise sahip (%L'de)"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L'deki WHERE/ELSEWHERE deyimi bir değişmez LOGICAL dizisi gerektirir"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "%L'deki ASSIGNED GOTO deyimi bir INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "'%s' değişkenine %L'de bir hedef etiketi atanmış olmamalıydı"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate RETURN statement at %L requires an INTEGER return specifier"
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Diğer RETURN deyimi %L'de bir INTEGER dönüş belirteci gerektirir"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L'deki aritmetik IF deyimi bir sayısal ifade gerektirir"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L'deki DO WHILE döngüsünün çıkış koşulu bir sabit LOGICAL ifadesi olmalıdır"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki FORALL maske deyimi bir LOGICAL ifadesi gerektirir"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -77787,7 +77855,7 @@ msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -77796,63 +77864,63 @@ msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "'%s' sabit nesnesi %L'de ALLOCATABLE olmayabilir"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -77860,996 +77928,996 @@ msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olm
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modül veya ana program dizisi '%s' %L'de sabit biçimde olmalı"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L'deki tahmini karakter uzunluklu öğe ya bir sözde argüman ya da bir PARAMETER olmalı"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Ayrılabilir '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Özdevinimli dizi '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s işlevinde (%s dosyasının %d. satırı)"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "'%s' bir PRIVATE türündedir ve '%s' (%L'de PUBLIC tanımlı) için bir sözde argüman olamaz"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de iç içe olamaz"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' of PURE procedure at %L must also be PURE"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "PURE yordamının '%s' sözde yordamı da ayrıca PURE olmalı"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) OPTIONAL olmamalı"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Bileşen karakter uzunluğu '%s'in %L'de bir sabit belirtim ifadesi olması gerekir"
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Bileşen '%s' bir PRIVATE türdür ve '%s' (%L'de PUBLIC tanımlı) bileşeni olamaz"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component %s of SEQUENCE type declared at %C does not have the SEQUENCE attribute"
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "SEQUENCE türünün %s bileşeni SEQUENCE özniteliğine sahip değil (%C'de)"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametre dizisi '%s' %L'de özdevinimli veya tahmini biçimli olamaz"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Örtük olarak  PARAMETER türlü '%s' %L'de sonraki bir IMPLICIT türle eşleşmiyor"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L'de PARAMETER içindeki türetilmiş tür uyumsuz"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olmaksızın ertelenmiş dizi boyutu"
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C'deki tahmini boyutlu dizi için belirtim hatalı"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L'deki tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Türetilmiş %qs türü %L'de tanımlanmamış olan %qs türündedir."
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC işlev '%s' %L'de PRIVATE '%s' türünde olamaz"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) sözde argüman %qs %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L'deki sözde yordama ELEMENTAL yordamında izin verilmez"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting definable entity near %L"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA öğesi %qs %L'de COMMON içinde olmalıdır"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "DATA deyiminde %L'de sabit olmayan dizi bölümü"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L'deki DATA deyiminde değerden çok değişken var"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L'deki DATA deyiminde değişkenden çok değer var"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılmamış"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılamıyor"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de öntanımlı ilklendiriciyle bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Ortak blok üyesi %qs %L'de, %qs pure yordamındaki bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%qs isimli sabiti %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Sınırları sabit olmayan %qs dizisi %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Yapı bileşeni %qs %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L'deki altdizge sıfır uzunlukta"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs %L'de hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Yerleşik işleç arayüzü %qs %L'de bir FUNCTION olmalı"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Kullanıcı işleci yordamı %qs %L'de tahmini karakter uzunluğunda olamaz"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı %qs %L'de için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ilk argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L'deki işleç arayüzünün en fazla iki argümanı olmalı"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -79783,17 +79851,17 @@ msgstr "%C'deki G/C listesinde virgül umuluyordu"
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "yürüyüş sırasında ifade türü hatalı (%d)"
@@ -79901,117 +79969,117 @@ msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "bir yordam olmayan yerleşik değişken"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value of function %qs at %L not set"
 msgstr "FPU yazmaçlarındaki işlevlerin değerleri döner"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Deferred type parameter not yet supported"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "modül değişkeni %qs için artyüz bildirimi zaten mevcut"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "gerçekleme değişkeni %qs %s olarak bildirilmiş"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "INTENT(OUT) sözde argüman '%s' %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "%s için argümanlar %L'de çok fazla"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Unused variable %qs declared at %L"
 msgstr "gerçekleme değişkeni %qs %s olarak bildirilmiş"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "Unused parameter %qs declared at %L"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "FPU yazmaçlarındaki işlevlerin değerleri döner"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Bilinmeyen yerleşik terim"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "Unknown argument list function at %L"
 msgstr "'%s' işlevinde argüman listesi eksik (%C'de)"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -80181,7 +80249,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
@@ -80325,7 +80393,7 @@ msgstr "-G ve -static birlikte kullanılamaz"
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-G ve -static birlikte kullanılamaz"
 
 #: lto/lto-object.c:107
@@ -81512,7 +81580,7 @@ msgstr "bölüm ismi \"%s\" tanınmıyor"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr ""
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized option '-%s'"
 msgid "Unrecognized option: %qs"
@@ -81531,15 +81599,15 @@ msgstr "%qs den sonra makro ismi eksik"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "%qs den sonra dosyaismi yok"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "%qs den sonra yol eksik"
@@ -81595,7 +81663,7 @@ msgstr "aç-parantez eksik"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "visibility değeri \"%s\" tanınmıyor"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized scalar storage order value %qs"
@@ -81691,108 +81759,108 @@ msgstr "%qs önerilmiyor"
 msgid "unknown linker output %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown excess precision style %qs"
 msgstr "cendereleme tarzı %s bilinmiyor"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "unknown floating point contraction style %qs"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: common.opt:1718
+#: common.opt:1722
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown IRA algorithm %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs den sonra olumlama eksik"
 
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "\"%s\" tls-modeli bilinmiyor"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown profile reproducibility method %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown profile update method %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Live-Patching Level %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2690
+#: common.opt:2694
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown TLS model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:3067
+#: common.opt:3071
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "visibility değeri \"%s\" tanınmıyor"
 
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
@@ -83858,9 +83926,6 @@ msgstr "%qs makine kipi bilinmiyor"
 #~ msgid "no members matching %<%T::%D%> in %q#T"
 #~ msgstr "%3$q#T içinde %<%1$T::%2$D%> ile eşleşen bir üye yok"
 
-#~ msgid "strong using only meaningful at namespace scope"
-#~ msgstr "kesin kullanım sadece isimalanı kapsamında anlamlıdır"
-
 #, fuzzy
 #~ msgid "current namespace %qD does not enclose strongly used namespace %qD"
 #~ msgstr "%3$qD isim alanını kapsamayan %2$qD isim alanında doğrudan %1$qD bildirimi"
@@ -83868,11 +83933,6 @@ msgstr "%qs makine kipi bilinmiyor"
 #~ msgid "%qE does not have class type"
 #~ msgstr "%qE sınıf türüne sahip değil"
 
-#, fuzzy
-#~| msgid "parse error in template argument list"
-#~ msgid "lambda-expression in template-argument"
-#~ msgstr "şablon argüman listesinde çözümleme hatası"
-
 #, fuzzy
 #~| msgid "break statement not within loop or switch"
 #~ msgid "break statement used with Cilk Plus for loop"
diff --git a/gcc/po/uk.po b/gcc/po/uk.po
index 87e66d27e06dc..59a8c1a69a1b7 100644
--- a/gcc/po/uk.po
+++ b/gcc/po/uk.po
@@ -2,13 +2,13 @@
 # Copyright (C) 2015 Free Software Foundation, Inc.
 # This file is distributed under the same license as the gcc package.
 #
-# Yuri Chornoivan <yurchor@ukr.net>, 2015, 2016, 2017, 2018, 2019, 2020.
+# Yuri Chornoivan <yurchor@ukr.net>, 2015, 2016, 2017, 2018, 2019, 2020, 2021.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 10.1.0\n"
+"Project-Id-Version: gcc 11.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
-"PO-Revision-Date: 2020-05-08 13:32+0300\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
+"PO-Revision-Date: 2021-04-28 17:09+0300\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
 "Language-Team: Ukrainian <trans-uk@lists.fedoraproject.org>\n"
 "Language: uk\n"
@@ -17,7 +17,7 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
 "Plural-Forms: nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);\n"
-"X-Generator: Lokalize 20.07.70\n"
+"X-Generator: Lokalize 20.12.0\n"
 
 #: cfgrtl.c:2797
 msgid "flow control insn inside a basic block"
@@ -150,28 +150,26 @@ msgstr "У файлі, який включено у"
 
 #. 2
 #: diagnostic.c:732
-#, fuzzy
-#| msgid "In file included from"
 msgid "        included from"
-msgstr "У файлі, який включено у"
+msgstr "        включено у"
 
 #: diagnostic.c:733
 msgid "In module"
-msgstr ""
+msgstr "У модулі"
 
 #. 4
 #: diagnostic.c:734
 msgid "of module"
-msgstr ""
+msgstr "модуля"
 
 #: diagnostic.c:735
 msgid "In module imported at"
-msgstr ""
+msgstr "У модулі, імпортованому у"
 
 #. 6
 #: diagnostic.c:736
 msgid "imported at"
-msgstr ""
+msgstr "імпортовано у"
 
 #: diagnostic.c:1220
 #, c-format
@@ -186,7 +184,7 @@ msgstr "Внутрішня помилка компілятора: повторн
 #: diagnostic.c:1888 diagnostic.c:1907
 #, gcc-internal-format, gfc-internal-format
 msgid "in %s, at %s:%d"
-msgstr ""
+msgstr "у %s, %s:%d"
 
 #: final.c:1127
 msgid "negative insn length"
@@ -806,10 +804,9 @@ msgstr ""
 "%s.\n"
 
 #: gcov-tool.c:528
-#, fuzzy, c-format
-#| msgid "Copyright %s 2020 Free Software Foundation, Inc.\n"
+#, c-format
 msgid "Copyright %s 2021 Free Software Foundation, Inc.\n"
-msgstr "© %s Free Software Foundation, Inc., 2020\n"
+msgstr "© %s Free Software Foundation, Inc., 2021\n"
 
 #: gcov.c:924
 #, c-format
@@ -845,6 +842,8 @@ msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
 "                                    rather than percentages\n"
 msgstr ""
+"  -c, --branch-counts             Виводити кількість гілок,\n"
+"                                    а не частку\n"
 
 #: gcov.c:930
 #, c-format
@@ -854,7 +853,7 @@ msgstr "  -d, --display-progress          Виводити дані щодо п
 #: gcov.c:931
 #, c-format
 msgid "  -D, --debug\t\t\t    Display debugging dumps\n"
-msgstr ""
+msgstr "  -D, --debug\t\t\t    Виводити діагностичні дані\n"
 
 #: gcov.c:932
 #, c-format
@@ -867,18 +866,16 @@ msgid "  -h, --help                      Print this help, then exit\n"
 msgstr "  -h, --help                      Вивести ці довідкові дані, потім вийти\n"
 
 #: gcov.c:934
-#, fuzzy, c-format
-#| msgid "  -i, --json-format               Output JSON intermediate format into .gcov.json.gz file\n"
+#, c-format
 msgid ""
 "  -j, --json-format               Output JSON intermediate format\n"
 "                                    into .gcov.json.gz file\n"
-msgstr "  -i, --json-format               вивести дані у проміжному форматі JSON до файла .gcov.json.gz\n"
+msgstr "  -j, --json-format               вивести дані у проміжному форматі JSON до файла .gcov.json.gz\n"
 
 #: gcov.c:936
-#, fuzzy, c-format
-#| msgid "  -j, --human-readable            Output human readable numbers\n"
+#, c-format
 msgid "  -H, --human-readable            Output human readable numbers\n"
-msgstr "  -j, --human-readable            Виводити зручні для читання числа\n"
+msgstr "  -H, --human-readable            Виводити зручні для читання числа\n"
 
 #: gcov.c:937
 #, c-format
@@ -907,7 +904,7 @@ msgstr "  -n, --no-output                 не створювати файла 
 #: gcov.c:942
 #, c-format
 msgid "  -o, --object-directory DIR|FILE Search for object files in DIR or called FILE\n"
-msgstr ""
+msgstr "  -o, --object-directory КАТ|ФАЙЛ Шукати об'єктні файли у каталозі КАТ або із назвою ФАЙЛ\n"
 
 #: gcov.c:943
 #, c-format
@@ -955,24 +952,23 @@ msgid "  -x, --hash-filenames            Hash long pathnames\n"
 msgstr "  -x, --hash-filenames            хешувати довгі шляхи\n"
 
 #: gcov.c:952
-#, fuzzy, c-format
-#| msgid "Options:\n"
+#, c-format
 msgid ""
 "\n"
 "Obsolete options:\n"
-msgstr "Параметри:\n"
+msgstr ""
+"\n"
+"Застарілі параметри:\n"
 
 #: gcov.c:953
-#, fuzzy, c-format
-#| msgid "  -i, --json-format               Output JSON intermediate format into .gcov.json.gz file\n"
+#, c-format
 msgid "  -i, --json-format               Replaced with -j, --json-format\n"
-msgstr "  -i, --json-format               вивести дані у проміжному форматі JSON до файла .gcov.json.gz\n"
+msgstr "  -i, --json-format               Замінено на -j, --json-format\n"
 
 #: gcov.c:954
-#, fuzzy, c-format
-#| msgid "  -j, --human-readable            Output human readable numbers\n"
+#, c-format
 msgid "  -j, --human-readable            Replaced with -H, --human-readable\n"
-msgstr "  -j, --human-readable            Виводити зручні для читання числа\n"
+msgstr "  -j, --human-readable            Замінено на -H, --human-readable\n"
 
 #: gcov.c:965
 #, c-format
@@ -1032,7 +1028,7 @@ msgstr "%s:не вдалося відкрити файл нотаток\n"
 #: gcov.c:1756
 #, c-format
 msgid "%s:not a gcov notes file\n"
-msgstr ""
+msgstr "%s:не є файлом нотаток gcov\n"
 
 #: gcov.c:1769
 #, c-format
@@ -1268,11 +1264,11 @@ msgstr ""
 msgid "this is the insn:"
 msgstr "це інструкція:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 msgid "unable to generate reloads for impossible constraints:"
 msgstr ""
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr ""
 
@@ -1298,7 +1294,7 @@ msgstr ""
 #: opts.c:1382
 #, c-format
 msgid "Same as %s."
-msgstr ""
+msgstr "Те саме, що і %s"
 
 #: opts.c:1390
 #, c-format
@@ -1443,16 +1439,16 @@ msgstr ""
 msgid "insn does not satisfy its constraints:"
 msgstr ""
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr ""
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 msgid "created and used with different settings of %<-fpic%>"
 msgstr ""
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 msgid "created and used with different settings of %<-fpie%>"
 msgstr ""
 
@@ -1488,7 +1484,7 @@ msgstr ""
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr ""
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1588,17 +1584,15 @@ msgstr ""
 
 #: cif-code.def:125
 msgid "optimization level attribute mismatch"
-msgstr ""
+msgstr "невідповідність атрибутів рівня оптимізації"
 
 #: cif-code.def:129
 msgid "callee refers to comdat-local symbols"
 msgstr ""
 
 #: cif-code.def:134
-#, fuzzy
-#| msgid "function attribute mismatch"
 msgid "sanitizer function attribute mismatch"
-msgstr "невідповідність атрибутів функції"
+msgstr "невідповідність атрибутів функції-санітайзера"
 
 #: cif-code.def:139
 msgid "function has external linkage when the user requests only inlining static for live patching"
@@ -1934,83 +1928,83 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "некоректний операнд для «%%%c»"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, c-format
 msgid "invalid vector constant"
 msgstr "некоректна векторна константа"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "несумісний операнд регістру для «%%%c»"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "пропущено операнд"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "некоректна константа"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "некоректний операнд"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "некоректний префікс операнда «%%%c»"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, c-format
 msgid "invalid address mode"
 msgstr "некоректний режим адресування"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "некоректне перетворення з типу %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "некоректне перетворення до типу %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' використано без будь-яких локальних динамічних посилань TLS"
@@ -2026,18 +2020,18 @@ msgid "invalid %%r value"
 msgstr "некоректне значення %%r"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "некоректне значення %%R"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "некоректне значення %%N"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "некоректне значення %%P"
@@ -2067,7 +2061,7 @@ msgstr "некоректне значення %%M"
 msgid "invalid %%U value"
 msgstr "некоректне значення %%U"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "некоректне значення %%s"
@@ -2077,7 +2071,7 @@ msgstr "некоректне значення %%s"
 msgid "invalid %%C value"
 msgstr "некоректне значення %%C"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "некоректне значення %%E"
@@ -2090,7 +2084,7 @@ msgstr ""
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr ""
@@ -2172,35 +2166,35 @@ msgstr ""
 msgid "unrecognized supposed constant"
 msgstr ""
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr ""
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr ""
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2208,13 +2202,13 @@ msgstr ""
 msgid "invalid operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2334,8 +2328,8 @@ msgstr "непідтримуваний операнд"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2698,7 +2692,7 @@ msgstr ""
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "некоректне значення %%p"
@@ -2752,7 +2746,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "помилкова адреса"
 
@@ -2804,8 +2798,8 @@ msgstr ""
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr ""
@@ -2941,303 +2935,286 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> потребує індексованого адресування."
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr "Помилкове 128-бітове пересування"
 
-#: config/rs6000/rs6000.c:13496
-#, fuzzy, c-format
-#| msgid "invalid %%J value"
+#: config/rs6000/rs6000.c:13589
+#, c-format
 msgid "invalid %%A value"
-msgstr "некоректне значення %%J"
+msgstr "некоректне значення %%A"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "некоректне значення %%D"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, c-format
 msgid "invalid %%e value"
 msgstr "некоректне значення %%e"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "некоректне значення %%f"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "некоректне значення %%F"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "некоректне значення %%G"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, c-format
 msgid "invalid %%t value"
 msgstr "некоректне значення %%t"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "некоректне значення %%T"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "некоректне значення %%u"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "некоректне значення %%v"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, c-format
 msgid "invalid %%V value"
 msgstr "некоректне значення %%V"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, c-format
 msgid "invalid %%z value"
 msgstr "некоректне значення %%z"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
-#, fuzzy
-#| msgid "invalid conversion from type %<bfloat16_t%>"
+#: config/rs6000/rs6000.c:27776
 msgid "invalid conversion from type %<__vector_quad%>"
-msgstr "некоректне перетворення з типу %<bfloat16_t%>"
+msgstr "некоректне перетворення з типу %<__vector_quad%>"
 
-#: config/rs6000/rs6000.c:27659
-#, fuzzy
-#| msgid "invalid conversion to type %<bfloat16_t%>"
+#: config/rs6000/rs6000.c:27778
 msgid "invalid conversion to type %<__vector_quad%>"
-msgstr "некоректне перетворення до типу %<bfloat16_t%>"
+msgstr "некоректне перетворення до типу %<__vector_quad%>"
 
-#: config/rs6000/rs6000.c:27661
-#, fuzzy
-#| msgid "invalid conversion from type %<bfloat16_t%>"
+#: config/rs6000/rs6000.c:27780
 msgid "invalid conversion from type %<__vector_pair%>"
-msgstr "некоректне перетворення з типу %<bfloat16_t%>"
+msgstr "некоректне перетворення з типу %<__vector_pair%>"
 
-#: config/rs6000/rs6000.c:27663
-#, fuzzy
-#| msgid "invalid conversion to %<__fpreg%>"
+#: config/rs6000/rs6000.c:27782
 msgid "invalid conversion to type %<__vector_pair%>"
-msgstr "некоректне перетворення до %<__fpreg%>"
+msgstr "некоректне перетворення до %<__vector_pair%>"
 
-#: config/rs6000/rs6000.c:27678
-#, fuzzy
-#| msgid "invalid conversion from type %<bfloat16_t%>"
+#: config/rs6000/rs6000.c:27797
 msgid "invalid conversion from type %<* __vector_quad%>"
-msgstr "некоректне перетворення з типу %<bfloat16_t%>"
+msgstr "некоректне перетворення з типу %<* __vector_quad%>"
 
-#: config/rs6000/rs6000.c:27680
-#, fuzzy
-#| msgid "invalid conversion to type %<bfloat16_t%>"
+#: config/rs6000/rs6000.c:27799
 msgid "invalid conversion to type %<* __vector_quad%>"
-msgstr "некоректне перетворення до типу %<bfloat16_t%>"
+msgstr "некоректне перетворення до типу %<* __vector_quad%>"
 
-#: config/rs6000/rs6000.c:27682
-#, fuzzy
-#| msgid "invalid conversion from type %<bfloat16_t%>"
+#: config/rs6000/rs6000.c:27801
 msgid "invalid conversion from type %<* __vector_pair%>"
-msgstr "некоректне перетворення з типу %<bfloat16_t%>"
+msgstr "некоректне перетворення з типу %<* __vector_pair%>"
 
-#: config/rs6000/rs6000.c:27684
-#, fuzzy
-#| msgid "invalid conversion to %<__fpreg%>"
+#: config/rs6000/rs6000.c:27803
 msgid "invalid conversion to type %<* __vector_pair%>"
-msgstr "некоректне перетворення до %<__fpreg%>"
+msgstr "некоректне перетворення до %<* __vector_pair%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "некоректний вираз для модифікатора виведення «%c»"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 msgid "vector argument passed to unprototyped function"
 msgstr ""
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3500,8 +3477,8 @@ msgstr "({анонімний})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "мало бути %<;%>"
@@ -3521,7 +3498,7 @@ msgstr "мало бути %<;%>"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "мало бути %<)%>"
@@ -3529,7 +3506,7 @@ msgstr "мало бути %<)%>"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "мало бути %<]%>"
@@ -3547,21 +3524,21 @@ msgstr "мало бути %<;%>, %<,%> або %<)%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "мало бути %<(%>"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "мало бути %<[%>"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "мало бути %<{%>"
@@ -3572,13 +3549,13 @@ msgstr "мало бути %<{%>"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "мало бути %<:%>"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "мало бути %<while%>"
@@ -3587,7 +3564,7 @@ msgstr "мало бути %<while%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "мало бути %<,%>"
@@ -3596,18 +3573,18 @@ msgstr "мало бути %<,%>"
 msgid "expected %<.%>"
 msgstr "мало бути %<.%>"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "мало бути %<@end%>"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "мало бути %<>%>"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "мало бути %<,%> або %<)%>"
@@ -3615,28 +3592,28 @@ msgstr "мало бути %<,%> або %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "мало бути %<=%>"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "мало бути %<}%>"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "мало бути %<#pragma omp section%> або %<}%>"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(анонімний)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "мало бути %<<%>"
@@ -3651,30 +3628,30 @@ msgstr "мало бути вказано мітку"
 msgid "candidate:"
 msgstr "кандидат:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr ""
 
@@ -3893,29 +3870,27 @@ msgstr ""
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 msgid "%<using enum%> of dependent type %qT"
 msgstr ""
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr ""
 
-#: cp/parser.c:20744
-#, fuzzy
-#| msgid "conversion to incomplete type"
+#: cp/parser.c:20781
 msgid "%<using enum%> of incomplete type %qT"
-msgstr "перетворення до неповного типу"
+msgstr "%<using enum%> неповного типу %qT"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr ""
 
@@ -3959,48 +3934,48 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4010,7 +3985,7 @@ msgstr ""
 
 #: fortran/check.c:70
 msgid " [see %<-fno-allow-invalid-boz%>]"
-msgstr ""
+msgstr " [див. %<-fno-allow-invalid-boz%>]"
 
 #: fortran/check.c:3717
 #, c-format
@@ -4040,11 +4015,11 @@ msgstr ""
 
 #: fortran/error.c:876
 msgid "Fortran 2018 deleted feature:"
-msgstr ""
+msgstr "Вилучена можливість у Fortran 2018:"
 
 #: fortran/error.c:878
 msgid "Fortran 2018 obsolescent feature:"
-msgstr ""
+msgstr "Застаріла можливість у Fortran 2018:"
 
 #: fortran/error.c:880
 msgid "Fortran 2018:"
@@ -4052,27 +4027,27 @@ msgstr "Fortran 2018:"
 
 #: fortran/error.c:882
 msgid "Fortran 2008 obsolescent feature:"
-msgstr ""
+msgstr "Застаріла можливість у Fortran 2008:"
 
 #: fortran/error.c:888
 msgid "GNU Extension:"
-msgstr ""
+msgstr "Розширення GNU:"
 
 #: fortran/error.c:890
 msgid "Legacy Extension:"
-msgstr ""
+msgstr "Застаріле розширення:"
 
 #: fortran/error.c:892
 msgid "Obsolescent feature:"
-msgstr ""
+msgstr "Застаріла можливість:"
 
 #: fortran/error.c:894
 msgid "Deleted feature:"
-msgstr ""
+msgstr "Вилучена можливість:"
 
 #: fortran/expr.c:3705
 msgid "array assignment"
-msgstr ""
+msgstr "призначення масиву"
 
 #: fortran/frontend-passes.c:2386
 msgid "Index variable %qs redefined at %L in procedure %qs called from within DO loop at %L"
@@ -4097,55 +4072,47 @@ msgstr ""
 #: fortran/gfortranspec.c:427
 #, c-format
 msgid "Driving:"
-msgstr ""
+msgstr "Керування:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
-msgstr ""
+msgstr "справжній аргумент INTENT = OUT/INOUT"
 
 #: fortran/intrinsic.c:4852
-#, fuzzy
-#| msgid "[available in "
 msgid "available since Fortran 77"
-msgstr "[доступний у "
+msgstr "доступний з Fortran 77"
 
 #: fortran/intrinsic.c:4856
 msgid "obsolescent in Fortran 95"
-msgstr ""
+msgstr "визнано застарілим у Fortran 95"
 
 #: fortran/intrinsic.c:4860
 msgid "deleted in Fortran 95"
-msgstr ""
+msgstr "вилучено у Fortran 95"
 
 #: fortran/intrinsic.c:4864
 msgid "new in Fortran 95"
-msgstr ""
+msgstr "впроваджено у Fortran 95"
 
 #: fortran/intrinsic.c:4868
-#, fuzzy
-#| msgid "Fortran 2018:"
 msgid "new in Fortran 2003"
-msgstr "Fortran 2018:"
+msgstr "впроваджено у Fortran 2003"
 
 #: fortran/intrinsic.c:4872
-#, fuzzy
-#| msgid "Fortran 2018:"
 msgid "new in Fortran 2008"
-msgstr "Fortran 2018:"
+msgstr "впроваджено у Fortran 2008"
 
 #: fortran/intrinsic.c:4876
-#, fuzzy
-#| msgid "Fortran 2018:"
 msgid "new in Fortran 2018"
-msgstr "Fortran 2018:"
+msgstr "впроваджено у Fortran 2018"
 
 #: fortran/intrinsic.c:4880
 msgid "a GNU Fortran extension"
-msgstr ""
+msgstr "розширення GNU Fortran"
 
 #: fortran/intrinsic.c:4884
 msgid "for backward compatibility"
-msgstr ""
+msgstr "для зворотної сумісності"
 
 #: fortran/io.c:1873
 #, c-format
@@ -4199,7 +4166,7 @@ msgstr "Мало бути ціле число"
 
 #: fortran/module.c:1639 fortran/module.c:2837
 msgid "Expected string"
-msgstr ""
+msgstr "Мало бути використано рядок"
 
 #: fortran/module.c:1664
 msgid "find_enum(): Enum not found"
@@ -4237,7 +4204,7 @@ msgstr ""
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr ""
 
@@ -4265,11 +4232,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "присвоювання"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr ""
 
@@ -4355,154 +4322,154 @@ msgstr ""
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Невідомий оператор %%<%s%%> у %%L; хотіли написати «%s»?"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Невідомий оператор %%<%s%%> у %%L"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4627,26 +4594,26 @@ msgstr ""
 msgid "Incorrect function return value"
 msgstr ""
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, c-format
 msgid "Error allocating %lu bytes"
 msgstr "Не вдалося розмістити у пам'яті %lu байтів"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "Спроба розмістити у пам'яті вже розміщену змінну «%s»"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr ""
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr ""
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -4841,15 +4808,15 @@ msgstr ""
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr ""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr ""
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr ""
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr ""
 
@@ -4865,8 +4832,8 @@ msgstr ""
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr ""
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr ""
 
@@ -5026,10 +4993,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Попереджати щодо створення тимчасових масивів."
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5504,160 +5471,160 @@ msgstr ""
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr ""
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr ""
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr ""
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr ""
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr ""
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr ""
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr ""
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr ""
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr ""
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr ""
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr ""
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr ""
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr ""
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr ""
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr ""
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr ""
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr ""
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr ""
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr ""
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr ""
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr ""
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr ""
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr ""
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr ""
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr ""
@@ -6035,10 +6002,9 @@ msgid "Mark implicitly-declared copy operations as deprecated if the class has a
 msgstr ""
 
 #: c-family/c.opt:535
-#, fuzzy, no-c-format
-#| msgid "Warn about certain operations on boolean expressions."
+#, no-c-format
 msgid "Warn about deprecated arithmetic conversions on operands of enumeration types."
-msgstr "Попереджати щодо певних дій із булевими виразами."
+msgstr "Попереджати про застарілі арифметичні перетворення операндів нумерованих типів."
 
 #: c-family/c.opt:539
 #, no-c-format
@@ -6337,7 +6303,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -6843,7 +6809,7 @@ msgstr ""
 #: c-family/c.opt:1302
 #, no-c-format
 msgid "Warn about using variadic macros."
-msgstr ""
+msgstr "Попереджати про використання варіативних макросів."
 
 #: c-family/c.opt:1306
 #, no-c-format
@@ -6858,7 +6824,7 @@ msgstr ""
 #: c-family/c.opt:1314
 #, no-c-format
 msgid "Warn if a variable length array is used."
-msgstr ""
+msgstr "Попереджати, якщо використано масив змінної довжини."
 
 #: c-family/c.opt:1318
 #, no-c-format
@@ -6868,13 +6834,12 @@ msgstr ""
 #: c-family/c.opt:1324
 #, no-c-format
 msgid "Disable Wvla-larger-than= warning.  Equivalent to Wvla-larger-than=<SIZE_MAX> or larger."
-msgstr ""
+msgstr "Вимкнути попередження Wvla-larger-than=. Еквівалент Wvla-larger-than=<SIZE_MAX> або більше."
 
 #: c-family/c.opt:1328
-#, fuzzy, no-c-format
-#| msgid "Warn about implicit declarations."
+#, no-c-format
 msgid "Warn about mismatched declarations of VLA parameters."
-msgstr "Попереджати про неявні оголошення."
+msgstr "Попереджати про невідповідні оголошення параметрів VLA."
 
 #: c-family/c.opt:1332
 #, no-c-format
@@ -6961,8 +6926,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr "Більше не підтримується."
@@ -7130,12 +7095,12 @@ msgstr ""
 #: c-family/c.opt:1655
 #, no-c-format
 msgid "Use traditional GNU semantics for inline functions."
-msgstr ""
+msgstr "Використовувати традиційну семантику GNU для вбудованих функцій."
 
 #: c-family/c.opt:1668
 #, no-c-format
 msgid "Assume normal C execution environment."
-msgstr ""
+msgstr "Припускати звичайне середовище виконання C."
 
 #: c-family/c.opt:1676
 #, no-c-format
@@ -7170,12 +7135,12 @@ msgstr ""
 #: c-family/c.opt:1706
 #, no-c-format
 msgid "Enable C++ modules-ts (experimental)."
-msgstr ""
+msgstr "Увімкнути modules-ts C++ (експериментальна можливість)."
 
 #: c-family/c.opt:1714
 #, no-c-format
 msgid "Enable C++ header module (experimental)."
-msgstr ""
+msgstr "Увімкнути модуль заголовків C++ (експериментальна можливість)."
 
 #: c-family/c.opt:1721
 #, no-c-format
@@ -7190,19 +7155,17 @@ msgstr ""
 #: c-family/c.opt:1729
 #, no-c-format
 msgid "Mapper for module to CMI files."
-msgstr ""
+msgstr "Засіб прив'язки модулів до файлів CMI."
 
 #: c-family/c.opt:1733
-#, fuzzy, no-c-format
-#| msgid "Enable code hoisting."
+#, no-c-format
 msgid "Enable lazy module importing."
-msgstr "Увімкнути підняття коду."
+msgstr "Увімкнути «ліниве» імпортування модулів."
 
 #: c-family/c.opt:1741
-#, fuzzy, no-c-format
-#| msgid "Warn about semicolon after in-class function definition."
+#, no-c-format
 msgid "Warn about macros that have conflicting header units definitions."
-msgstr "Попереджати про крапку з комою після визначення функції у класі."
+msgstr "Попереджати про макроси, у яких є конфліктні визначення модулів заголовків."
 
 #: c-family/c.opt:1745
 #, no-c-format
@@ -7321,466 +7284,461 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr ""
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr ""
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr ""
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr ""
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr ""
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr ""
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr ""
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr ""
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr ""
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr ""
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr ""
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr ""
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr ""
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr ""
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr ""
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr ""
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr ""
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr ""
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr ""
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr ""
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr ""
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr ""
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr ""
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr ""
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr ""
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr ""
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr ""
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr ""
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr ""
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr ""
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr ""
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr ""
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr ""
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr ""
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr ""
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr ""
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr ""
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr ""
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr ""
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr ""
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr ""
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr ""
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr ""
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr ""
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr ""
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr ""
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr ""
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr ""
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr ""
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr ""
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr ""
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr ""
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr ""
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr ""
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, no-c-format
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr ""
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr ""
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr ""
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr ""
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr ""
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr ""
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr ""
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr ""
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr ""
@@ -8025,6 +7983,11 @@ msgstr ""
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr ""
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -8246,10 +8209,9 @@ msgid "Warn about code paths which attempt to write to a const object."
 msgstr ""
 
 #: analyzer/analyzer.opt:135
-#, fuzzy, no-c-format
-#| msgid "Warn about format strings that are not literals."
+#, no-c-format
 msgid "Warn about code paths which attempt to write to a string literal."
-msgstr "Попереджати, якщо рядки форматування не є літералами."
+msgstr "Попереджати про шляхи коду, у яких робиться спроба записати до рядкового літерала."
 
 #: analyzer/analyzer.opt:139
 #, no-c-format
@@ -9263,143 +9225,155 @@ msgstr ""
 msgid "Support TLS segment larger than 64K."
 msgstr ""
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:34
 #, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr ""
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr ""
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr ""
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr ""
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, no-c-format
 msgid "Use hardware instructions for integer division."
 msgstr ""
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr ""
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr ""
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, no-c-format
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr ""
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr ""
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, no-c-format
 msgid "Do not generate unaligned memory accesses."
 msgstr ""
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr ""
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr ""
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr ""
@@ -9534,12 +9508,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9560,12 +9528,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr ""
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -10240,10 +10202,9 @@ msgid "Use call0 ABI."
 msgstr ""
 
 #: config/xtensa/xtensa.opt:58
-#, fuzzy, no-c-format
-#| msgid "Use fp registers."
+#, no-c-format
 msgid "Use windowed registers ABI."
-msgstr "Використовувати fp-регістри."
+msgstr "Використовувати бінарний інтерфейс із віконними регістрами."
 
 #: config/i386/cygming.opt:23
 #, no-c-format
@@ -12931,10 +12892,9 @@ msgid "Generate (do not generate) pc-relative memory optimizations for externals
 msgstr ""
 
 #: config/rs6000/rs6000.opt:618
-#, fuzzy, no-c-format
-#| msgid "Generate divide instructions."
+#, no-c-format
 msgid "Generate (do not generate) MMA instructions."
-msgstr "Створити інструкції divide."
+msgstr "Створювати (не створювати) інструкції MMA."
 
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
@@ -16785,2162 +16745,2162 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, no-c-format
 msgid "Align the start of functions."
 msgstr ""
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, no-c-format
 msgid "Enable static analysis pass."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1073
 #, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr ""
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr ""
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1111
+#: common.opt:1115
 #, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr ""
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr ""
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "Перевіряти повернуте значення new у C++."
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr "Виконувати внутрішні перевірки сумісності."
 
-#: common.opt:1150
+#: common.opt:1154
 #, no-c-format
 msgid "Enable code hoisting."
 msgstr "Увімкнути підняття коду."
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, no-c-format
 msgid "Put uninitialized globals in the common section."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr ""
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr ""
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1586
+#: common.opt:1590
 #, no-c-format
 msgid "Place each function into its own section."
 msgstr ""
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, no-c-format
 msgid "Enable loop interchange on trees."
 msgstr ""
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr ""
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1703
+#: common.opt:1707
 #, no-c-format
 msgid "Process #ident directives."
 msgstr ""
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1743
+#: common.opt:1747
 #, no-c-format
 msgid "Do not generate .size directives."
 msgstr ""
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, no-c-format
 msgid "Discover pure and const functions."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr ""
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1886
+#: common.opt:1890
 #, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1899
+#: common.opt:1903
 #, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1945
+#: common.opt:1949
 #, no-c-format
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr ""
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr ""
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr ""
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:2020
+#: common.opt:2024
 #, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr ""
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:2104
+#: common.opt:2108
 #, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Створити виконуваний файл з незалежним позиціюванням, якщо можливо (малий режим)"
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2305
+#: common.opt:2309
 #, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr ""
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2449
+#: common.opt:2453
 #, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr ""
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr ""
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr ""
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2730
+#: common.opt:2734
 #, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2734
+#: common.opt:2738
 #, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2774
+#: common.opt:2778
 #, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr ""
 
-#: common.opt:2778
+#: common.opt:2782
 #, no-c-format
 msgid "Enable dominator optimizations."
 msgstr ""
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2786
+#: common.opt:2790
 #, no-c-format
 msgid "Enable dead store elimination."
 msgstr ""
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2798
+#: common.opt:2802
 #, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr ""
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr ""
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2835
+#: common.opt:2839
 #, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr ""
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2847
+#: common.opt:2851
 #, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr ""
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:3011
+#: common.opt:3015
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Розташувати ініціалізовані нулями дані у розділі bss."
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr ""
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Створити діагностичні дані у типовому форматі."
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3191
+#: common.opt:3195
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3320
+#: common.opt:3324
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr ""
 
-#: common.opt:3324
+#: common.opt:3328
 #, no-c-format
 msgid "Enable function profiling."
 msgstr ""
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Увімкнути докладне виведення."
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Придушити попередження."
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Створити бібліотеку спільного використання."
 
-#: common.opt:3472
+#: common.opt:3476
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Не створювати динамічно скомпонований виконуваний файл з незалежним позиціюванням."
 
-#: common.opt:3476
+#: common.opt:3480
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Створити динамічно скомпонований виконуваний файл з незалежним позиціюванням."
 
-#: common.opt:3480
+#: common.opt:3484
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Створити статичний виконуваний файл з незалежним позиціюванням."
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19021,15 +18981,14 @@ msgid "Enable hwasan instrumentation of store operations."
 msgstr ""
 
 #: params.opt:87
-#, fuzzy, no-c-format
-#| msgid "invalid argument to built-in function %s"
+#, no-c-format
 msgid "Enable hwasan instrumentation of builtin functions."
-msgstr "некоректний аргумент вбудованої функції %s"
+msgstr "Увімкнути укомплектування HWASAN для вбудованих функцій."
 
 #: params.opt:91
 #, no-c-format
 msgid "Average number of iterations of a loop."
-msgstr ""
+msgstr "Середня кількість ітерацій циклу."
 
 #: params.opt:95
 #, no-c-format
@@ -19083,1105 +19042,1115 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr ""
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr ""
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr ""
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr ""
 
-#: params.opt:210
+#: params.opt:215
 #, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr ""
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr ""
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr ""
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr ""
 
-#: params.opt:242
+#: params.opt:247
 #, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr ""
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, no-c-format
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr ""
 
-#: params.opt:258
+#: params.opt:263
 #, no-c-format
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr ""
 
-#: params.opt:274
+#: params.opt:279
 #, no-c-format
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr ""
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr ""
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr ""
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr ""
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr ""
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr ""
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr ""
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr ""
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr ""
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr ""
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr ""
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr ""
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr ""
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr ""
 
-#: params.opt:366
+#: params.opt:371
 #, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr ""
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr ""
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr ""
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr ""
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr ""
 
-#: params.opt:394
+#: params.opt:399
 #, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr ""
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr ""
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr ""
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr ""
 
-#: params.opt:414
+#: params.opt:419
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr ""
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr ""
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr ""
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr ""
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr ""
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr ""
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr ""
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr ""
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr ""
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr ""
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr ""
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr ""
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr ""
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr ""
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr ""
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr ""
 
-#: params.opt:518
+#: params.opt:523
 #, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr ""
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr ""
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr ""
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr ""
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr ""
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr ""
 
-#: params.opt:550
+#: params.opt:555
 #, no-c-format
 msgid "The maximum number of instructions when inlining for size."
 msgstr ""
 
-#: params.opt:554
+#: params.opt:559
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr ""
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr ""
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr ""
 
-#: params.opt:566
+#: params.opt:571
 #, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr ""
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr ""
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr ""
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr ""
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr ""
 
-#: params.opt:586
+#: params.opt:591
 #, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr ""
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr ""
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr ""
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr ""
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr ""
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr ""
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr ""
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr ""
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr ""
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr ""
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr ""
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr ""
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr ""
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr ""
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr ""
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr ""
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr ""
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr ""
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr ""
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr ""
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr ""
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr ""
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr ""
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr ""
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr ""
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr ""
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr ""
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr ""
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr ""
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr ""
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr ""
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr ""
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr ""
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr ""
 
-#: params.opt:840
+#: params.opt:858
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr ""
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr ""
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr ""
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr ""
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr ""
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr ""
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr ""
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr ""
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr ""
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr ""
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr ""
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, no-c-format
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr ""
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr ""
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "Максимальне значення відношення розміру масиву до кількості відгалужень перемикання для перетворення на перемикання."
 
-#: params.opt:952
+#: params.opt:970
 #, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr ""
 
-#: params.opt:956
+#: params.opt:974
 #, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr ""
 
-#: params.opt:960
+#: params.opt:978
 #, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr ""
 
-#: params.opt:964
+#: params.opt:982
 #, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr ""
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr ""
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr ""
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr ""
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr ""
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr ""
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr ""
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, no-c-format
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1024
+#: params.opt:1042
 #, no-c-format
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr ""
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr ""
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr ""
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr ""
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20212,7 +20181,7 @@ msgid "expected boolean type"
 msgstr ""
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "мало бути ціле число"
@@ -20276,7 +20245,7 @@ msgstr "недостатньо аргументів"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "забагато аргументів"
@@ -20630,7 +20599,7 @@ msgstr ""
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr ""
@@ -20685,7 +20654,7 @@ msgstr ""
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -20714,20 +20683,20 @@ msgstr ""
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -20738,8 +20707,8 @@ msgstr ""
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr ""
@@ -20749,47 +20718,47 @@ msgstr ""
 msgid "ignoring attributes applied to %qT after definition"
 msgstr ""
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr ""
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr ""
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr ""
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, gcc-internal-format
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr ""
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr ""
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr ""
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr ""
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr ""
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
@@ -20797,12 +20766,12 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "Ціль %qD оголошено тут"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -20893,19 +20862,19 @@ msgstr ""
 #: builtins.c:1181
 #, gcc-internal-format
 msgid "%qs argument missing terminating nul"
-msgstr ""
+msgstr "у аргументі %qs пропущено завершальний nul"
 
 #: builtins.c:1188 gimple-ssa-sprintf.c:3288
 #, gcc-internal-format
 msgid "referenced argument declared here"
-msgstr "."
+msgstr "аргумент посилання оголошено тут:"
 
 #: builtins.c:1450
 #, gcc-internal-format
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE оголошено тут"
@@ -20930,424 +20899,422 @@ msgstr ""
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr ""
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
-#, fuzzy, gcc-internal-format
-#| msgid "  declared here"
+#: builtins.c:4028
+#, gcc-internal-format
 msgid "source object declared here"
-msgstr "  оголошено тут"
+msgstr "об'єкт джерела оголошено тут:"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
-#, fuzzy, gcc-internal-format
-#| msgid "in call to %qD, declared here"
+#: builtins.c:4117
+#, gcc-internal-format
 msgid "destination object declared here"
-msgstr "у виклику %qD, оголошено тут"
+msgstr "об'єкт призначення оголошено тут:"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, gcc-internal-format
 msgid "destination object allocated here"
 msgstr ""
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
-msgstr ""
+msgstr "%K%qD може записати %E байт до області розміру %E"
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
-msgstr ""
+msgstr "%K%qD може записати %E байтів до області розміру %E"
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
-msgstr ""
+msgstr "%Kможе записати %E байт до області розміру %E"
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgstr "%Kзапис %E байта до області розміру %E призводить до переповнення призначення"
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
-msgstr ""
+msgstr "%Kможе записати %E байтів до області розміру %E"
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
-msgstr ""
+msgstr "%Kзапис %E байтів до області розміру %E призводить до переповнення призначення"
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
-msgstr ""
+msgstr "%K%qD може записати %E байтів або більше до області розміру %E"
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
-msgstr ""
+msgstr "%Kможе записати %E байтів або більше до області розміру %E"
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
-msgstr ""
+msgstr "%Kзапис %E байтів або більше до області розміру %E призводить до переповнення призначення"
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
-msgstr ""
+msgstr "%Kможе записати від %E до %E байтів до області розміру %E"
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
-msgstr ""
+msgstr "%Kзапис від %E до %E байтів до області розміру %E призводить до переповнення призначення"
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
@@ -21355,7 +21322,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
@@ -21363,295 +21330,291 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "некоректний аргумент %qD"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr ""
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr ""
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr ""
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr ""
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr ""
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, gcc-internal-format
 msgid "non-constant argument 1 to %qs"
 msgstr "аргумент 1 %qs, який не є сталим"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, gcc-internal-format
 msgid "non-integer argument 1 to %qs"
 msgstr "нецілий аргумент 1 %qs"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "підтримки %<__builtin_thread_pointer%> для цього призначення не передбачено"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "підтримки %<__builtin_set_thread_pointer%> для цього призначення не передбачено"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, gcc-internal-format
 msgid "%qs only supported in OpenACC code"
 msgstr ""
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, gcc-internal-format
 msgid "non-constant argument 0 to %qs"
 msgstr "аргумент 0 %qs, який не є сталим"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr "некоректний аргумент 0 %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr ""
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr ""
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "оголошено тут"
 
-#: builtins.c:13541 builtins.c:13666
-#, fuzzy, gcc-internal-format
-#| msgid "required from here\n"
+#: builtins.c:13545 builtins.c:13670
+#, gcc-internal-format
 msgid "returned from %qD"
-msgstr "потрібен звідси\n"
+msgstr "повернуто з %qD"
 
-#: builtins.c:13544
-#, fuzzy, gcc-internal-format
-#| msgid "required from here\n"
+#: builtins.c:13548
+#, gcc-internal-format
 msgid "returned from %qT"
-msgstr "потрібен звідси\n"
+msgstr "повернуто з %qT"
 
-#: builtins.c:13546
-#, fuzzy, gcc-internal-format
-#| msgid "defined here"
+#: builtins.c:13550
+#, gcc-internal-format
 msgid "obtained here"
-msgstr "визначено тут"
+msgstr "отримано тут:"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
-msgstr ""
+msgstr "%K%qD викликано на вказівнику на нерозміщений у пам'яті об'єкт %qE"
 
-#: builtins.c:13618
-#, fuzzy, gcc-internal-format
-#| msgid "defined here"
+#: builtins.c:13622
+#, gcc-internal-format
 msgid "assigned here"
-msgstr "визначено тут"
+msgstr "призначено тут:"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -21742,10 +21705,9 @@ msgid "%Kbound argument %i value %s is negative for a variable length array argu
 msgstr ""
 
 #: calls.c:2077
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument value %qE is negative"
+#, gcc-internal-format
 msgid "%Kargument %i value %s is negative"
-msgstr "значення аргументу атрибута %qE, %qE, від'ємним"
+msgstr "%Kзначення %i аргументу %s є від'ємним"
 
 #: calls.c:2124
 #, gcc-internal-format
@@ -21758,16 +21720,14 @@ msgid "%Kargument %i is null but the corresponding size argument %i value is %s"
 msgstr ""
 
 #: calls.c:2144
-#, fuzzy, gcc-internal-format
-#| msgid "%Gargument %u null where non-null expected"
+#, gcc-internal-format
 msgid "%Kargument %i to %<%T[static %E]%> is null where non-null expected"
-msgstr "%Gпорожній аргумент %u там, де мав бути непорожній аргумент"
+msgstr "%K %i-й аргумет %<%T[static %E]%> є порожнім там, де мало бути непорожнє значення"
 
 #: calls.c:2203
-#, fuzzy, gcc-internal-format
-#| msgid "in template argument for type %qT"
+#, gcc-internal-format
 msgid "referencing argument %u of type %qT"
-msgstr "в аргументі шаблона для типу %qT"
+msgstr ""
 
 #: calls.c:2216
 #, gcc-internal-format
@@ -21780,10 +21740,9 @@ msgid "in a call with type %qT and attribute %qs"
 msgstr ""
 
 #: calls.c:2227
-#, fuzzy, gcc-internal-format
-#| msgid "in a call to built-in function %qD"
+#, gcc-internal-format
 msgid "in a call to function %qD"
-msgstr "у виклику вбудованої функції %qD"
+msgstr "у виклику функції %qD"
 
 #: calls.c:2230
 #, gcc-internal-format
@@ -22418,302 +22377,302 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr ""
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr ""
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr ""
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "встановлено вказівник inlined_to, але не виявлено попередників"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr ""
@@ -22794,12 +22753,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F використано, але ніколи не визначено"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -22869,7 +22828,7 @@ msgstr ""
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr ""
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "виявлено вузли із незвільненою пам'яттю"
@@ -23273,12 +23232,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -23298,7 +23257,7 @@ msgstr ""
 msgid "internal consistency failure"
 msgstr ""
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -23428,42 +23387,42 @@ msgstr ""
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23478,7 +23437,7 @@ msgstr ""
 msgid "total size of local objects exceeds maximum %wu"
 msgstr ""
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -23893,10 +23852,9 @@ msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr ""
 
 #: gcc.c:10634
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "too many arguments"
+#, gcc-internal-format, gfc-internal-format
 msgid "too many arguments for %%:dumps"
-msgstr "забагато аргументів"
+msgstr "забагато аргументів для %%:dumps"
 
 #: gcc.c:10738
 #, gcc-internal-format, gfc-internal-format
@@ -23904,10 +23862,9 @@ msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr ""
 
 #: gcc.c:10759
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong number of arguments to %<__builtin_addressof%>"
+#, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:dwarf-version-gt"
-msgstr "помилкова кількість аргументів %<__builtin_addressof%>"
+msgstr "помилкова кількість аргументів %%:dwarf-version-gt"
 
 #: gcov-tool.c:73
 #, gcc-internal-format, gfc-internal-format
@@ -24077,10 +24034,9 @@ msgid "%s not supported for variable length aggregates"
 msgstr ""
 
 #: gimple-fold.c:4747
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%<__int%d%> is not supported on this target"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
-msgstr "підтримки %<__int%d%> для цього призначення не передбачено"
+msgstr "підтримки %s для цього призначення не передбачено"
 
 #: gimple-ssa-isolate-paths.c:290
 #, gcc-internal-format
@@ -24097,7 +24053,7 @@ msgstr "розіменування нульового вказівника"
 msgid "function may return address of local variable"
 msgstr "функція може повертати адресу локальної змінної"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr ""
@@ -24115,7 +24071,7 @@ msgstr ""
 #: gimple-ssa-sprintf.c:2777 gimple-ssa-sprintf.c:2897
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
-msgstr ""
+msgstr "%qE виведення обрізано до останнього символу форматування"
 
 #: gimple-ssa-sprintf.c:2780 gimple-ssa-sprintf.c:2900
 #, gcc-internal-format
@@ -24474,53 +24430,53 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 msgid "%Guse of %<alloca%>"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 msgid "%Gargument to variable-length array may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 msgid "%Gargument to variable-length array is too large"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "%Gаргумент %<alloca%> є надто великим"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 msgid "%Gunbounded use of variable-length array"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "%Gнеобмежене використання %<alloca%>"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "%Gвикористання %<alloca%> у циклі"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 msgid "%Gargument to variable-length array is zero"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 msgid "%Gargument to %<alloca%> is zero"
 msgstr ""
 
@@ -24645,7 +24601,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "масив %qD оголошено тут"
@@ -24671,11 +24627,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -24750,308 +24706,308 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, gcc-internal-format
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr ""
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr ""
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, gcc-internal-format
 msgid "enclosing region"
 msgstr ""
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE не задано у замиканні %qs"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr ""
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "некоректне приватне спрощення %qE"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -25432,10 +25388,9 @@ msgid "name %qs is defined to different value in another translation unit"
 msgstr ""
 
 #: ipa-devirt.c:4279
-#, fuzzy, gcc-internal-format
-#| msgid "missing definition"
+#, gcc-internal-format
 msgid "mismatching definition"
-msgstr "пропущено визначення"
+msgstr "невідповідне визначення"
 
 #: ipa-fnsummary.c:4466
 #, gcc-internal-format
@@ -25507,22 +25462,22 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, gcc-internal-format
 msgid "%s cannot be used in %<asm%> here"
 msgstr ""
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr ""
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr ""
@@ -25542,12 +25497,12 @@ msgstr ""
 msgid "unable to find a register to spill"
 msgstr ""
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr ""
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
@@ -25915,10 +25870,9 @@ msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
 #: omp-low.c:2630
-#, fuzzy, gcc-internal-format
-#| msgid "pointers are not permitted as case values"
+#, gcc-internal-format
 msgid "argument not permitted on %qs clause"
-msgstr "вказівники не можуть бути значеннями випадків"
+msgstr ""
 
 #: omp-low.c:2634
 #, gcc-internal-format
@@ -26256,12 +26210,12 @@ msgstr ""
 msgid "unrecognized argument in option %qs"
 msgstr ""
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr ""
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr ""
@@ -26272,10 +26226,9 @@ msgid "switch %qs is no longer supported"
 msgstr ""
 
 #: opts-common.c:1471
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qs must be a constant"
+#, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
-msgstr "аргумент 1 %qs має бути сталою"
+msgstr "аргумент %qs перевищує %d"
 
 #: opts-common.c:1807
 #, gcc-internal-format
@@ -26387,7 +26340,7 @@ msgstr ""
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr ""
@@ -26503,10 +26456,9 @@ msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr ""
 
 #: opts.c:2166
-#, fuzzy, gcc-internal-format
-#| msgid "invalid arguments for %<-fpatchable_function_entry%>"
+#, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable-function-entry%>"
-msgstr "некоректні аргументи %<-fpatchable_function_entry%>"
+msgstr "некоректні аргументи %<-fpatchable-function-entry%>"
 
 #: opts.c:2279
 #, gcc-internal-format
@@ -26611,12 +26563,12 @@ msgstr ""
 #: passes.c:1073
 #, gcc-internal-format
 msgid "unrecognized option %<-fenable%>"
-msgstr ""
+msgstr "нерозпізнаний параметр %<-fenable%>"
 
 #: passes.c:1075
 #, gcc-internal-format
 msgid "unrecognized option %<-fdisable%>"
-msgstr ""
+msgstr "нерозпізнаний параметр %<-fdisable%>"
 
 #: passes.c:1083
 #, gcc-internal-format
@@ -26884,22 +26836,22 @@ msgstr ""
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr ""
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr ""
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr ""
@@ -26961,12 +26913,12 @@ msgstr ""
 msgid "impossible register constraint in %<asm%>"
 msgstr ""
 
-#: reload.c:2687
+#: reload.c:2692
 #, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr ""
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr ""
@@ -26996,52 +26948,52 @@ msgstr ""
 msgid "output operand is constant in %<asm%>"
 msgstr ""
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:900
+#: rtl.c:910
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr ""
@@ -27086,22 +27038,22 @@ msgstr ""
 msgid "invalid punctuation %qc in constraint"
 msgstr ""
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr ""
 
-#: stmt.c:524
+#: stmt.c:525
 #, gcc-internal-format
 msgid "duplicate %<asm%> operand name %qs"
 msgstr ""
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr ""
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr ""
@@ -27352,10 +27304,9 @@ msgid "symtab_node::verify failed"
 msgstr ""
 
 #: symtab.c:1378
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid operands to %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid order in asm node %i"
-msgstr "некоректні операнди %qs"
+msgstr "некоректний порядок у вузлі asm %i"
 
 #: symtab.c:1402
 #, gcc-internal-format
@@ -27383,10 +27334,9 @@ msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "підтримки %<__builtin_saveregs%> для цього призначення не передбачено"
 
 #: targhooks.c:1017
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int%d%> is not supported on this target"
+#, gcc-internal-format
 msgid "%qs not supported on this target"
-msgstr "підтримки %<__int%d%> для цього призначення не передбачено"
+msgstr "підтримки %qs для цього призначення не передбачено"
 
 #: targhooks.c:1060
 #, gcc-internal-format
@@ -27579,10 +27529,9 @@ msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supporte
 msgstr ""
 
 #: toplev.c:1708
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fdata-sections%> not supported for this target"
+#, gcc-internal-format
 msgid "%<-fsanitize=address%> not supported for this target"
-msgstr "підтримки %<-fdata-sections%> для цього призначення не передбачено"
+msgstr "підтримки %<-fsanitize=address%> для цього призначення не передбачено"
 
 #: toplev.c:1717
 #, gcc-internal-format
@@ -27590,10 +27539,9 @@ msgid "%<-fsanitize=kernel-address%> with stack protection is not supported with
 msgstr ""
 
 #: toplev.c:1727
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int%d%> is not supported on this target"
+#, gcc-internal-format
 msgid "%qs is not supported for this target"
-msgstr "підтримки %<__int%d%> для цього призначення не передбачено"
+msgstr "підтримки %qs для цієї цілі не передбачено"
 
 #: toplev.c:2057
 #, gcc-internal-format
@@ -27783,9 +27731,9 @@ msgstr "некоректні операнди %qs"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "невідповідність типів у %qs"
@@ -27820,7 +27768,7 @@ msgstr "некоректний операнд зсуву у %qs"
 msgid "invalid clique in %qs"
 msgstr ""
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
@@ -28026,362 +27974,362 @@ msgstr ""
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "у %qs мало бути використано векторні типи"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "некоректний тип маскування у %qs"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr ""
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "некоректна позиція або розмір у %qs"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr ""
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr ""
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr ""
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "некоректний операнд у %qs"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr ""
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr ""
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr ""
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr ""
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr ""
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "некоректний %<CASE_CHAIN%>"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr ""
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "некоректний результат %<PHI%>"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "некоректний аргумент %<PHI%>"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr ""
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "помилка %<verify_gimple%>"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "локальне оголошення з іншої функції"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "мітка "
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr ""
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr ""
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr ""
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr ""
@@ -28562,10 +28510,9 @@ msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
 #: tree-ssa-alias.c:3847
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid use of register '%s'"
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid fn spec attribute \"%s\""
-msgstr "некоректне використання регістру «%s»"
+msgstr "некоректний атрибути специфікації функції «%s»"
 
 #: tree-ssa-alias.c:3886
 #, gcc-internal-format, gfc-internal-format
@@ -28577,10 +28524,9 @@ msgid "%G%qs pointer is null"
 msgstr ""
 
 #: tree-ssa-ccp.c:3570 c-family/c-common.c:5601
-#, fuzzy, gcc-internal-format
-#| msgid "In static member function %qs"
+#, gcc-internal-format
 msgid "in a call to non-static member function %qD"
-msgstr "У статичній функції-члені %qs"
+msgstr "у виклику нестатичної функції-члена %qD"
 
 #: tree-ssa-ccp.c:3576
 msgid "%Gargument %u null where non-null expected"
@@ -28592,10 +28538,9 @@ msgid "in a call to built-in function %qD"
 msgstr "у виклику вбудованої функції %qD"
 
 #: tree-ssa-ccp.c:3586 c-family/c-common.c:5611
-#, fuzzy, gcc-internal-format
-#| msgid "in a call to function %qD declared here"
+#, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
-msgstr "у виклику функції %qD, оголошено тут"
+msgstr "у виклику функції %qD, оголошено %qs"
 
 #: tree-ssa-loop-niter.c:3374
 #, gcc-internal-format, gfc-internal-format
@@ -28665,9 +28610,9 @@ msgstr[2] ""
 #: tree-ssa-strlen.c:2027
 msgid "%Gwriting %wu byte into a region of size %wu"
 msgid_plural "%Gwriting %wu bytes into a region of size %wu"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "%Gзапис %wu байта до області розміру %wu"
+msgstr[1] "%Gзапис %wu байтів до області розміру %wu"
+msgstr[2] "%Gзапис %wu байтів до області розміру %wu"
 
 #: tree-ssa-strlen.c:2037
 msgid "%G%qD writing %wu byte into a region of size between %wu and %wu"
@@ -28702,9 +28647,9 @@ msgstr ""
 #: tree-ssa-strlen.c:2970
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "%G%qD виведення обрізано до завершального nul копіюванням %E байта з рядка тієї самої довжини"
+msgstr[1] "%G%qD виведення обрізано до завершального nul копіюванням %E байтів з рядка тієї самої довжини"
+msgstr[2] "%G%qD виведення обрізано до завершального nul копіюванням %E байтів з рядка тієї самої довжини"
 
 #: tree-ssa-strlen.c:2986
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
@@ -28730,7 +28675,7 @@ msgstr ""
 
 #: tree-ssa-strlen.c:3181
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
-msgstr ""
+msgstr "%G%qD виведення обрізано до завершального nul копіюванням якомога більшої кількості байтів з рядка як його довжини"
 
 #: tree-ssa-strlen.c:3194
 msgid "%G%qD specified bound depends on the length of the source argument"
@@ -28768,52 +28713,42 @@ msgid "%qD was declared here"
 msgstr "%qD було оголошено тут:"
 
 #: tree-ssa-uninit.c:419
-#, fuzzy
-#| msgid "%qE is used uninitialized in this function"
 msgid "%G%qE is used uninitialized"
-msgstr "%qE використано без ініціалізації у цій функції"
+msgstr "%G%qE використано без ініціалізації"
 
 #: tree-ssa-uninit.c:432
-#, fuzzy
-#| msgid "%qE may be used uninitialized in this function"
 msgid "%G%qE may be used uninitialized"
-msgstr "%qE може бути використано без ініціалізації у цій функції"
+msgstr "%G%qE може бути використано без ініціалізації"
 
 #: tree-ssa-uninit.c:547
-#, fuzzy, gcc-internal-format
-#| msgid "in call to %qD, declared here"
+#, gcc-internal-format
 msgid "in a call to %qD declared with attribute %<%s%> here"
-msgstr "у виклику %qD, оголошено тут"
+msgstr "у виклику %qD, оголошеної з атрибутом %<%s%> тут:"
 
 #: tree-ssa-uninit.c:554
-#, fuzzy, gcc-internal-format
-#| msgid "in call to %qD, declared here"
+#, gcc-internal-format
 msgid "in a call to %qT declared with attribute %<%s%>"
-msgstr "у виклику %qD, оголошено тут"
+msgstr "у виклику %qT, оголошеної з атрибутом %<%s%>"
 
 #: tree-ssa-uninit.c:570
-#, fuzzy, gcc-internal-format
-#| msgid "argument %qD declared here"
+#, gcc-internal-format
 msgid "by argument %u of type %s to %qD declared here"
-msgstr "аргумент %qD оголошено тут:"
+msgstr "аргументом %u типу %s до %qD, оголошеної тут:"
 
 #: tree-ssa-uninit.c:578
-#, fuzzy, gcc-internal-format
-#| msgid "wrong argument %qs to option %qs"
+#, gcc-internal-format
 msgid "by argument %u of type %s to %qT"
-msgstr "помилковий аргумент %qs параметра %qs"
+msgstr "аргументом %u типу %s до %qT"
 
 #: tree-ssa-uninit.c:633
-#, fuzzy, gcc-internal-format
-#| msgid "%qD should be initialized"
+#, gcc-internal-format
 msgid "%qD is used uninitialized"
-msgstr "%qD має бути ініціалізовано"
+msgstr "%qD використано без ініціалізації"
 
 #: tree-ssa-uninit.c:638
-#, fuzzy, gcc-internal-format
-#| msgid "%qD may be used uninitialized in this function"
+#, gcc-internal-format
 msgid "%qD may be used uninitialized"
-msgstr "%qD може бути використано без ініціалізації у цій функції"
+msgstr "%qD може бути використано без ініціалізації"
 
 #: tree-ssa-uninit.c:2968
 #, gcc-internal-format
@@ -29148,7 +29083,7 @@ msgstr ""
 #: tree.c:14137
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
-msgstr ""
+msgstr "тип%'s %<TYPE_SIZE_UNIT%>"
 
 #: tree.c:14160
 #, gcc-internal-format
@@ -29173,7 +29108,7 @@ msgstr ""
 #: tree.c:14213
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
-msgstr ""
+msgstr "тип%'s %<TYPE_BINFO%>"
 
 #: tree.c:14252
 #, gcc-internal-format
@@ -29203,7 +29138,7 @@ msgstr ""
 #: tree.c:14277 tree.c:14288
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
-msgstr ""
+msgstr "тип%'s %<TREE_TYPE%>"
 
 #: tree.c:14284
 #, gcc-internal-format
@@ -29361,10 +29296,9 @@ msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
 
 #: tsan.c:506
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not supported by arch %s"
+#, gcc-internal-format
 msgid "%qs is not supported with %qs"
-msgstr "%qs є непідтримуваним на архітектурі %s"
+msgstr "підтримки %qs не передбачено із %qs"
 
 #: value-prof.c:496
 #, gcc-internal-format
@@ -29486,7 +29420,7 @@ msgstr ""
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
@@ -29647,7 +29581,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, gcc-internal-format
 msgid "unsupported record layout"
 msgstr ""
@@ -29739,16 +29673,14 @@ msgid "ignoring attribute %qs because it conflicts with previous %qs"
 msgstr ""
 
 #: c-family/c-attribs.c:920
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for type %qT"
+#, gcc-internal-format
 msgid "%qE attribute only supported on boolean types"
-msgstr "Атрибут %qE для типу %qT проігноровано"
+msgstr "підтримку атрибута %qE передбачено лише для булевих типів"
 
 #: c-family/c-attribs.c:930
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for type %qT"
+#, gcc-internal-format
 msgid "%qE attribute with unsupported boolean precision"
-msgstr "Атрибут %qE для типу %qT проігноровано"
+msgstr "атрибут %qE із непідтримуваною булевою точністю"
 
 #: c-family/c-attribs.c:953
 #, gcc-internal-format
@@ -30138,10 +30070,9 @@ msgid "%qE attribute applies only to functions"
 msgstr ""
 
 #: c-family/c-attribs.c:3220
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for type %qT"
+#, gcc-internal-format
 msgid "%<%E (%E)%> attribute ignored on functions declared %qs"
-msgstr "Атрибут %qE для типу %qT проігноровано"
+msgstr ""
 
 #: c-family/c-attribs.c:3230
 #, gcc-internal-format
@@ -30149,30 +30080,26 @@ msgid "%<%E (%E)%> attribute ignored with deallocation functions declared %qs"
 msgstr ""
 
 #: c-family/c-attribs.c:3234
-#, fuzzy, gcc-internal-format
-#| msgid "in a call to allocation function %qD declared here"
+#, gcc-internal-format
 msgid "deallocation function declared here"
-msgstr "у виклику до функції отримання області пам'яті %qD оголошено тут"
+msgstr ""
 
 #: c-family/c-attribs.c:3261
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for type %qT"
+#, gcc-internal-format
 msgid "%qE attribute ignored; valid only for functions"
-msgstr "Атрибут %qE для типу %qT проігноровано"
+msgstr ""
 
 #: c-family/c-attribs.c:3271
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute on function returning %<void%>"
+#, gcc-internal-format
 msgid "%qE attribute ignored on functions returning %qT; valid only for pointer return types"
-msgstr "атрибут %qE на функції, яка повертає %<void%>"
+msgstr ""
 
 #. Handle specially the common case of specifying one of a number
 #. of overloads, such as operator delete.
 #: c-family/c-attribs.c:3317
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument value %qE is negative"
+#, gcc-internal-format
 msgid "%qE attribute argument 1 is ambiguous"
-msgstr "значення аргументу атрибута %qE, %qE, від'ємним"
+msgstr ""
 
 #: c-family/c-attribs.c:3319
 #, gcc-internal-format
@@ -30180,37 +30107,32 @@ msgid "use a cast to the expected type to disambiguate"
 msgstr ""
 
 #: c-family/c-attribs.c:3324
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument %qE is not an integer constant"
+#, gcc-internal-format
 msgid "%qE attribute argument 1 does not name a function"
-msgstr "аргумент атрибута %qE, %qE, не є цілим сталим значенням"
+msgstr ""
 
 #: c-family/c-attribs.c:3327
-#, fuzzy, gcc-internal-format
-#| msgid "referenced argument declared here"
+#, gcc-internal-format
 msgid "argument references a symbol declared here"
-msgstr "."
+msgstr "аргумент посилається на символ, який оголошено тут:"
 
 #. Reject functions without a prototype.
 #: c-family/c-attribs.c:3343
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument %qE is not an integer constant"
+#, gcc-internal-format
 msgid "%qE attribute argument 1 must take a pointer type as its first argument"
-msgstr "аргумент атрибута %qE, %qE, не є цілим сталим значенням"
+msgstr ""
 
 #: c-family/c-attribs.c:3346 c-family/c-attribs.c:3359
-#, fuzzy, gcc-internal-format
-#| msgid "referenced argument declared here"
+#, gcc-internal-format
 msgid "referenced symbol declared here"
-msgstr "."
+msgstr ""
 
 #. Reject functions that don't take a pointer as their first
 #. argument.
 #: c-family/c-attribs.c:3356
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument %qE is not an integer constant"
+#, gcc-internal-format
 msgid "%qE attribute argument 1 must take a pointer type as its first argument; have %qT"
-msgstr "аргумент атрибута %qE, %qE, не є цілим сталим значенням"
+msgstr ""
 
 #: c-family/c-attribs.c:3470 c-family/c-attribs.c:3518
 #: c-family/c-attribs.c:3545
@@ -30219,16 +30141,14 @@ msgid "%qE attribute ignored on a function returning %qT"
 msgstr ""
 
 #: c-family/c-attribs.c:3564
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument %qE is not an integer constant"
+#, gcc-internal-format
 msgid "%qE attribute argument %E is not an integer constant"
-msgstr "аргумент атрибута %qE, %qE, не є цілим сталим значенням"
+msgstr "аргумент атрибута %qE, %E, не є цілим сталим значенням"
 
 #: c-family/c-attribs.c:3572
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument value %qE is negative"
+#, gcc-internal-format
 msgid "%qE attribute argument %E is not positive"
-msgstr "значення аргументу атрибута %qE, %qE, від'ємним"
+msgstr ""
 
 #: c-family/c-attribs.c:3583
 #, gcc-internal-format
@@ -30265,7 +30185,7 @@ msgstr ""
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -30285,7 +30205,7 @@ msgstr ""
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -30486,10 +30406,9 @@ msgid "empty string in attribute %<target%>"
 msgstr ""
 
 #: c-family/c-attribs.c:5432
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized visibility value %qs"
+#, gcc-internal-format
 msgid "unrecognized %qE attribute argument %qs"
-msgstr "невідоме значення видимості %qs"
+msgstr "нерозпізнаний аргумент атрибута %qE, %qs"
 
 #: c-family/c-attribs.c:5450
 #, gcc-internal-format
@@ -30507,10 +30426,9 @@ msgid "%qE attribute argument %qE is not an integer constant"
 msgstr "аргумент атрибута %qE, %qE, не є цілим сталим значенням"
 
 #: c-family/c-attribs.c:5510
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument value %qE exceeds %wu"
+#, gcc-internal-format
 msgid "%qE attribute argument %qE exceeds %u"
-msgstr "значення аргументу атрибута %qE, %qE, перевищує %wu"
+msgstr "аргумент атрибуту %qE, %qE, перевищує %u"
 
 #: c-family/c-attribs.c:5532
 #, gcc-internal-format
@@ -30518,10 +30436,9 @@ msgid "%qE attribute may be put on a typedef only; attribute is ignored"
 msgstr ""
 
 #: c-family/c-attribs.c:5544
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for type %qT"
+#, gcc-internal-format
 msgid "%qE attribute is for pointer types only"
-msgstr "Атрибут %qE для типу %qT проігноровано"
+msgstr "атрибут %qE призначено лише для типів вказівників"
 
 #: c-family/c-attribs.c:5563
 #, gcc-internal-format
@@ -30529,22 +30446,19 @@ msgid "%qE is only applicable to Objective-C class interfaces, attribute ignored
 msgstr ""
 
 #: c-family/c-attribs.c:5586
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for type %qT"
+#, gcc-internal-format
 msgid "%qE cannot be applied to non-pointer type %qT"
-msgstr "Атрибут %qE для типу %qT проігноровано"
+msgstr "%qE не може бути застосовано до типу %qT, який не є вказівниковим"
 
 #: c-family/c-attribs.c:5599
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument %qE is not an integer constant"
+#, gcc-internal-format
 msgid "%qE attribute argument %qE is not an integer constant between 0 and 3"
-msgstr "аргумент атрибута %qE, %qE, не є цілим сталим значенням"
+msgstr "аргумент атрибута %qE, %qE, не є цілим сталим значенням від 0 до 3"
 
 #: c-family/c-attribs.c:5611
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument %qE is not an integer constant"
+#, gcc-internal-format
 msgid "%qE attribute argument %qE is not recognised"
-msgstr "аргумент атрибута %qE, %qE, не є цілим сталим значенням"
+msgstr "аргумент атрибута %qE, %qE, не розпізнано"
 
 #: c-family/c-attribs.c:5628
 #, gcc-internal-format
@@ -30716,12 +30630,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "некоректне використання %<restrict%>"
@@ -30857,10 +30771,9 @@ msgid "%qs pointer is null"
 msgstr ""
 
 #: c-family/c-common.c:5607
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%Gargument %u null where non-null expected"
+#, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
-msgstr "%Gпорожній аргумент %u там, де мав бути непорожній аргумент"
+msgstr "порожній аргумент %u там, де мав бути непорожній аргумент"
 
 #: c-family/c-common.c:5706 c-family/c-common.c:5756
 #, gcc-internal-format
@@ -30883,13 +30796,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr ""
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr ""
@@ -30961,16 +30874,14 @@ msgid "argument 3 in call to function %qE has boolean type"
 msgstr ""
 
 #: c-family/c-common.c:6216
-#, fuzzy, gcc-internal-format
-#| msgid "in a call to function %qD declared here"
+#, gcc-internal-format
 msgid "argument %u in call to function %qE does not have pointer type"
-msgstr "у виклику функції %qD, оголошено тут"
+msgstr ""
 
 #: c-family/c-common.c:6222
-#, fuzzy, gcc-internal-format
-#| msgid "Warn when deleting a pointer to incomplete type."
+#, gcc-internal-format
 msgid "argument %u in call to function %qE points to incomplete type"
-msgstr "Попереджати щодо вилучення вказівника на неповний тип."
+msgstr ""
 
 #: c-family/c-common.c:6487
 #, gcc-internal-format
@@ -31028,10 +30939,9 @@ msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
 #: c-family/c-common.c:7121
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qs must be a constant"
+#, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
-msgstr "аргумент 1 %qs має бути сталою"
+msgstr ""
 
 #: c-family/c-common.c:7130
 #, gcc-internal-format
@@ -31064,22 +30974,19 @@ msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
 #: c-family/c-common.c:7197
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qs must be a constant"
+#, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
-msgstr "аргумент 1 %qs має бути сталою"
+msgstr ""
 
 #: c-family/c-common.c:7202
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qs must be a constant"
+#, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
-msgstr "аргумент 1 %qs має бути сталою"
+msgstr ""
 
 #: c-family/c-common.c:7211
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qs must be a constant"
+#, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
-msgstr "аргумент 1 %qs має бути сталою"
+msgstr ""
 
 #: c-family/c-common.c:7216
 #, gcc-internal-format
@@ -31829,7 +31736,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -31879,7 +31786,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -31894,17 +31801,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
@@ -31914,7 +31821,7 @@ msgstr ""
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -31950,10 +31857,9 @@ msgid "outer iteration variable %qD multiplier expression %qE is not integral"
 msgstr ""
 
 #: c-family/c-omp.c:1296
-#, fuzzy, gcc-internal-format
-#| msgid "integral expression %qE is not constant"
+#, gcc-internal-format
 msgid "outer iteration variable %qD addend expression %qE is not integral"
-msgstr "інтегральний вираз %qE не є сталою"
+msgstr ""
 
 #: c-family/c-omp.c:1361 c-family/c-omp.c:1447
 #, gcc-internal-format
@@ -31980,7 +31886,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -32545,8 +32451,8 @@ msgstr ""
 msgid "wrong type argument to %s"
 msgstr ""
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -33031,17 +32937,17 @@ msgstr ""
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr ""
@@ -33221,8 +33127,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -33299,88 +33205,84 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
-msgstr ""
+msgstr "ця умова має однакові гілки"
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
-msgstr ""
+msgstr "макрос розгортається до декількох інструкцій"
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, gcc-internal-format
 msgid "defined here"
-msgstr "визначено тут"
+msgstr "визначено тут:"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%q#D previously declared here"
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
+#, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
-msgstr "%q#D раніше оголошено тут"
+msgstr "раніше оголошено як %s"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
-msgstr ""
+msgstr "аргумент %u типу %s оголошено як масив змінної довжини"
 
-#: c-family/c-warn.c:3457
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%q#D previously declared here"
+#: c-family/c-warn.c:3458
+#, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
-msgstr "%q#D раніше оголошено тут"
+msgstr "раніше оголошено як вказівник %s"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
-msgstr ""
+msgstr "раніше оголошено як звичайний масив %s"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument %qD declared here"
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
+#, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
-msgstr "аргумент %qD оголошено тут:"
+msgstr "аргумент %u типу %s оголошено як вказівник"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
-msgstr ""
+msgstr "раніше оголошено як масив змінної довжини %s"
 
-#: c-family/c-warn.c:3488
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%q#D previously declared here"
+#: c-family/c-warn.c:3489
+#, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
-msgstr "%q#D раніше оголошено тут"
+msgstr "раніше оголошено як масив %s"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
@@ -33388,7 +33290,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
@@ -33396,7 +33298,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
@@ -33404,7 +33306,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
@@ -33412,7 +33314,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
@@ -33420,49 +33322,47 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr ""
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3648
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %qD"
+#: c-family/c-warn.c:3649
+#, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
-msgstr "попереднє оголошення %qD"
+msgstr "раніше оголошено як %s із межами %<%s%>"
 
-#: c-family/c-warn.c:3667
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %qD"
+#: c-family/c-warn.c:3668
+#, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
-msgstr "попереднє оголошення %qD"
+msgstr "раніше оголошено як %s із обмеженням %qs"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
-msgstr ""
+msgstr "аргумент %u типу %s із невідповідним обмеженням"
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -33475,9 +33375,9 @@ msgstr ""
 #: c-family/cppspec.c:113
 #, gcc-internal-format
 msgid "too many input files"
-msgstr ""
+msgstr "надто багато вхідних файлів"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr ""
@@ -33508,14 +33408,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "коректними аргументами є такі: %s; ви мали на увазі %qs?"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "коректні аргументи: %s"
@@ -33593,7 +33493,7 @@ msgstr ""
 #: common/config/bfin/bfin-common.c:323
 #, gcc-internal-format
 msgid "%<-mcpu=%s%> is not valid"
-msgstr ""
+msgstr "%<-mcpu=%s%> є некоректним"
 
 #: common/config/bfin/bfin-common.c:359
 #, gcc-internal-format
@@ -33665,65 +33565,65 @@ msgstr ""
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
-msgstr ""
+msgstr "%<-march=%s%>: розширення «%s» вказано декілька разів."
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "%<-march=%s%>: після %<%dp%> мало бути число."
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
-msgstr ""
+msgstr "%<-march=%s%>: rv%de не є коректною основою ISA"
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
-msgstr ""
+msgstr "%<-march=%s%>: непідтримувана підмножина ISA %<%c%>"
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
-msgstr ""
+msgstr "%<-march=%s%>: рядок ISA записано у неканонічному вигляді. %<%c%>"
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
-msgstr ""
+msgstr "%<-march=%s%>: назва %s має складатися з понад 1 літери"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
-msgstr ""
+msgstr "%<-march=%s%>: %s має відокремлюватися _"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
-msgstr ""
+msgstr "%<-march=%s%>: рядок ISA має починатися з rv32 або rv64"
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
-msgstr ""
+msgstr "%<-march=%s%>: неочікуваний рядок ISA наприкінці: %qs"
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
-msgstr ""
+msgstr "%<-mcpu=%s%>: невідомий процесор"
 
 #: common/config/rs6000/rs6000-common.c:184 config/sparc/sparc.c:1740
 #, gcc-internal-format
@@ -33837,10 +33737,9 @@ msgid "couldn%'t understand kern.osversion %q.*s"
 msgstr ""
 
 #: config/darwin-driver.c:232
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "couldn%'t understand version %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "could not understand version %s"
-msgstr "не вдалося визначити версію %s"
+msgstr "не вдалося зрозуміти версію %s"
 
 #: config/darwin-driver.c:308
 #, gcc-internal-format, gfc-internal-format
@@ -33882,89 +33781,89 @@ msgstr ""
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr ""
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr ""
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr ""
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr ""
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr ""
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr ""
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr ""
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr ""
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr ""
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr ""
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr ""
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr ""
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr ""
 
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr ""
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34100,365 +33999,362 @@ msgstr ""
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "неочікуване %<%s%> після %<%s%>"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "некоректний формат sve_width"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "некоректне значення sve_width: %d"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "невідомий параметр регулювання (%s)"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs не є коректним зсувом у %qs"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "коректні аргументи: %s;"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "некоректний модифікатор можливості %qs у %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14877
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument %qs to %qs"
+#: config/aarch64/aarch64.c:16511
+#, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
-msgstr "некоректний аргумент %qs %qs"
+msgstr "некоректний аргумент %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument %qs to %qs"
+#: config/aarch64/aarch64.c:16527
+#, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
-msgstr "некоректний аргумент %qs %qs"
+msgstr "некоректний аргумент %<%s%> %<-mharden-sls=%>"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "некоректний модифікатор можливості %qs у %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "підтримки моделі коду %qs у режимі ilp32 не передбачено"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
-msgstr ""
+msgstr "помилкове форматування вказівки транслятору або атрибута %<target(\"%s\")%>"
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported operand"
+#, gcc-internal-format
 msgid "unsupported simdlen %wd"
-msgstr "непідтримуваний операнд"
+msgstr "непідтримуване simdlen %wd"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr ""
@@ -34519,7 +34415,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr ""
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -34639,18 +34535,18 @@ msgstr ""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr ""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -35080,223 +34976,228 @@ msgstr ""
 msgid "target CPU does not support unaligned accesses"
 msgstr ""
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "перемикач %<-mcpu=%s%> конфліктує з перемикачем %<-march=%s%>"
+
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
-msgstr ""
+msgstr "%<-mapcs-stack-check%> є несумісним із %<-mno-apcs-frame%>"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "не можна використовувати %qs для регістру PIC"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr ""
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr ""
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr ""
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -35304,22 +35205,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr ""
@@ -35398,17 +35299,17 @@ msgstr "підтримки %<-fpie%> не передбачено"
 msgid "%<-fPIE%> is not supported"
 msgstr "підтримки %<-fPIE%> не передбачено"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr ""
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr ""
@@ -35587,12 +35488,12 @@ msgstr ""
 #: config/bfin/bfin.c:2373
 #, gcc-internal-format
 msgid "%<-mshared-library-id=%> specified without %<-mid-shared-library%>"
-msgstr ""
+msgstr "%<-mshared-library-id=%> вказано без %<-mid-shared-library%>"
 
 #: config/bfin/bfin.c:2378
 #, gcc-internal-format
 msgid "%<-fstack-limit-%> options are ignored with %<-mfdpic%>; use %<-mstack-check-l1%>"
-msgstr ""
+msgstr "параметри %<-fstack-limit-%> буде проігноровано з %<-mfdpic%>; скористайтеся %<-mstack-check-l1%>"
 
 #: config/bfin/bfin.c:2384
 #, gcc-internal-format
@@ -35607,12 +35508,12 @@ msgstr ""
 #: config/bfin/bfin.c:2392 config/m68k/m68k.c:590
 #, gcc-internal-format
 msgid "cannot specify both %<-msep-data%> and %<-mid-shared-library%>"
-msgstr ""
+msgstr "не можна одночасно вказувати %<-msep-data%> і %<-mid-shared-library%>"
 
 #: config/bfin/bfin.c:2412
 #, gcc-internal-format
 msgid "%<-mmulticore%> can only be used with BF561"
-msgstr ""
+msgstr "%<-mmulticore%> можна використовувати лише з BF561"
 
 #: config/bfin/bfin.c:2415
 #, gcc-internal-format
@@ -35640,16 +35541,14 @@ msgid "can%'t apply both longcall and shortcall attributes to the same function"
 msgstr ""
 
 #: config/bpf/bpf.c:92
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute takes no arguments"
+#, gcc-internal-format
 msgid "%qE attribute requires an integer argument"
-msgstr "Атрибут %qE не приймає аргументів"
+msgstr "атрибут %qE потребує цілочисельного аргументу"
 
 #: config/bpf/bpf.c:99
-#, fuzzy, gcc-internal-format
-#| msgid "%qD must have no arguments"
+#, gcc-internal-format
 msgid "%qE requires an argument"
-msgstr "%qD не приймає аргументів"
+msgstr "%qE потребує аргументу"
 
 #: config/bpf/bpf.c:297
 #, gcc-internal-format
@@ -35746,10 +35645,9 @@ msgstr ""
 #. detectable.  Still change to the values we expect, to avoid
 #. further errors.
 #: config/cris/cris.c:2350
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fPIC%>/%<-fpic%> not supported for this target"
+#, gcc-internal-format
 msgid "%<-fPIC%> and %<-fpic%> are not supported on this target"
-msgstr "підтримки %<-fPIC%>/%<-fpic%> для цього призначення не передбачено"
+msgstr "підтримки %<-fPIC%> і %<-fpic%> для цієї цілі не передбачено"
 
 #: config/cris/cris.c:2551
 #, gcc-internal-format
@@ -36151,132 +36049,132 @@ msgstr ""
 msgid "parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr ""
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr ""
@@ -36296,516 +36194,514 @@ msgstr ""
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr ""
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr ""
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "помилковий аргумент %qs параметра %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
-msgstr ""
+msgstr "невідомий параметр параметра %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> вважається застарілим; скористайтеся одним із відповідників: %<-mtune=k8%> або %<-mtune=generic%>"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> вважається застарілим; скористайтеся одним із відповідників: %<target(\"tune=k8\")%> або %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
-msgstr ""
+msgstr "підтримки %<-mstringop-strategy=rep_8byte%> для 32-бітового коду не передбачено"
 
-#: config/i386/i386-options.c:1914
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mcmodel=%> is not supported in 32-bit mode"
+#: config/i386/i386-options.c:1924
+#, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
-msgstr "підтримки %<-mcmodel=%> у 32-бітовому режимі не передбачено"
+msgstr "підтримки %<-muintr%> для 32-бітового коду не передбачено"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "підтримки %<-mabi=ms%> для ABI X32 не передбачено"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "коректними аргументами перемикача %<-march=%> є такі: %s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "коректними аргументами перемикача %<-mtune=%> є такі: %s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "підтримки %<-mpreferred-stack-boundary%> для цього призначення не передбачено"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "невідомий параметр для %<-mrecip=%s%>"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fcf-protection=full%> is not supported for this target"
+#: config/i386/i386-options.c:3043
+#, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
-msgstr "підтримки %<-fcf-protection=full%> для цього призначення не передбачено"
+msgstr "%<-fcf-protection%> є несумісним із цією ціллю"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -36975,17 +36871,16 @@ msgstr ""
 #: config/i386/i386.c:16801
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
-msgstr ""
+msgstr "двійковий інтерфейс передавання порожнього параметра %qT класу змінено у %<-fabi-version=12%> (GCC 8)"
 
 #: config/i386/i386.c:20702
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
-msgstr ""
+msgstr "вирівнювання полів %<_Atomic %T%> змінено у %{GCC 11.1%}"
 
 #: config/i386/i386.c:20798
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mcmodel=%> is not supported in 32-bit mode"
+#, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
-msgstr "підтримки %<-mcmodel=%> у 32-бітовому режимі не передбачено"
+msgstr "підтримки профілювання %<-mcmodel=large%> із PIC не передбачено"
 
 #: config/i386/i386.c:22452
 #, gcc-internal-format
@@ -37260,7 +37155,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -37996,7 +37891,7 @@ msgstr ""
 #: config/nios2/nios2.c:573
 #, gcc-internal-format
 msgid "Unknown form for stack limit expression"
-msgstr ""
+msgstr "Невідома форма виразу обмеження стека"
 
 #: config/nios2/nios2.c:1182
 #, gcc-internal-format
@@ -38026,30 +37921,27 @@ msgstr ""
 #: config/nios2/nios2.c:1360
 #, gcc-internal-format
 msgid "PIC support for %<-fstack-limit-symbol%>"
-msgstr ""
+msgstr "підтримка PIC для %<-fstack-limit-symbol%>"
 
 #: config/nios2/nios2.c:1382
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mabi=ms%> not supported with X32 ABI"
+#, gcc-internal-format
 msgid "%<-mgpopt%> not supported with PIC"
-msgstr "підтримки %<-mabi=ms%> для ABI X32 не передбачено"
+msgstr "підтримки %<-mgpopt%> не передбачено із PIC"
 
 #: config/nios2/nios2.c:1384
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mabi=ms%> not supported with X32 ABI"
+#, gcc-internal-format
 msgid "%<-mgprel-sec=%> not supported with PIC"
-msgstr "підтримки %<-mabi=ms%> для ABI X32 не передбачено"
+msgstr "підтримки %<-mgprel-sec=%> із PIC не передбачено"
 
 #: config/nios2/nios2.c:1386
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mabi=ms%> not supported with X32 ABI"
+#, gcc-internal-format
 msgid "%<-mr0rel-sec=%> not supported with PIC"
-msgstr "підтримки %<-mabi=ms%> для ABI X32 не передбачено"
+msgstr "підтримки %<-mr0rel-sec=%> із PIC не передбачено"
 
 #: config/nios2/nios2.c:1394
 #, gcc-internal-format
 msgid "%<-mgprel-sec=%> argument is not a valid regular expression"
-msgstr ""
+msgstr "аргумент %<-mgprel-sec=%> не є коректним формальним виразом"
 
 #: config/nios2/nios2.c:1400
 #, gcc-internal-format
@@ -38082,10 +37974,9 @@ msgid "custom instruction opcode must be a compile-time constant in the range 0-
 msgstr ""
 
 #: config/nios2/nios2.c:3892
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "constant argument out of range for %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "control register number must be in range 0-31 for %s"
-msgstr "сталий аргумент поза припустимим діапазоном для %s"
+msgstr ""
 
 #: config/nios2/nios2.c:3920
 #, gcc-internal-format, gfc-internal-format
@@ -38103,10 +37994,9 @@ msgid "the ENI instruction operand must be either 0 or 1"
 msgstr ""
 
 #: config/nios2/nios2.c:4005
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "builtin %qs requires builtin %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "built-in function %s requires Nios II R%d"
-msgstr "вбудований код %qs потребує вбудованого коду %qs"
+msgstr ""
 
 #: config/nios2/nios2.c:4085
 #, gcc-internal-format
@@ -38119,10 +38009,9 @@ msgid "call to %<__builtin_custom_%s%> conflicts with switch %<-mcustom-%s%>"
 msgstr ""
 
 #: config/nios2/nios2.c:4212
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fpic%> is not supported"
+#, gcc-internal-format
 msgid "%<custom-fpu-cfg%> option does not support %<no-%>"
-msgstr "підтримки %<-fpic%> не передбачено"
+msgstr ""
 
 #: config/nios2/nios2.c:4217
 #, gcc-internal-format
@@ -38147,13 +38036,12 @@ msgstr ""
 #: config/nios2/nios2.c:4283
 #, gcc-internal-format
 msgid "%<custom-%s=%> is not recognized as FPU instruction"
-msgstr ""
+msgstr "%<custom-%s=%> не розпізнано як інструкцію FPU"
 
 #: config/nios2/nios2.c:4290
-#, fuzzy, gcc-internal-format
-#| msgid "invalid private reduction on %qE"
+#, gcc-internal-format
 msgid "invalid custom instruction option %qs"
-msgstr "некоректне приватне спрощення %qE"
+msgstr "некоректний параметр нетипової інструкції %qs"
 
 #: config/nvptx/mkoffload.c:110
 #, gcc-internal-format
@@ -38283,7 +38171,7 @@ msgstr ""
 
 #: config/pru/pru-pragma.c:61
 msgid "%<CTABLE_ENTRY%> index %"
-msgstr ""
+msgstr "%<CTABLE_ENTRY%> індекс %"
 
 #: config/pru/pru-pragma.c:64
 msgid "redefinition of %<CTABLE_ENTRY %"
@@ -38319,57 +38207,57 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr ""
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -38519,15 +38407,14 @@ msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr ""
 
 #: config/rs6000/rs6000-c.c:1837
-#, fuzzy, gcc-internal-format
-#| msgid "builtin %qs requires builtin %qs"
+#, gcc-internal-format
 msgid "builtin %qs requires 4 arguments"
-msgstr "вбудований код %qs потребує вбудованого коду %qs"
+msgstr "вбудована %qs потребує 4 аргументів"
 
 #: config/rs6000/rs6000-c.c:1913
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
-msgstr "вбудований код %qs потребує вбудованого коду %qs"
+msgstr "вбудована %qs потребує вбудованої %qs"
 
 #: config/rs6000/rs6000-c.c:1917
 #, gcc-internal-format
@@ -38645,10 +38532,9 @@ msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr ""
 
 #: config/rs6000/rs6000-call.c:9550
-#, fuzzy, gcc-internal-format
-#| msgid "Argument must be a constant between 0 and 31."
+#, gcc-internal-format
 msgid "argument 2 must be unsigned literal between 2 and 7 inclusive"
-msgstr "Аргумент має бути сталою від 0 до 31."
+msgstr ""
 
 #: config/rs6000/rs6000-call.c:9562
 #, gcc-internal-format
@@ -38723,34 +38609,29 @@ msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability
 msgstr ""
 
 #: config/rs6000/rs6000-call.c:10543
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qs must be a constant"
+#, gcc-internal-format
 msgid "argument 4 must be an 8-bit unsigned literal"
-msgstr "аргумент 1 %qs має бути сталою"
+msgstr "аргумент 4 має бути 8-бітовим літералом без знаку"
 
 #: config/rs6000/rs6000-call.c:10555
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qs must be a constant"
+#, gcc-internal-format
 msgid "argument 4 must be a 3-bit unsigned literal"
-msgstr "аргумент 1 %qs має бути сталою"
+msgstr "аргумент 4 має бути 3-бітовим літералом без знаку"
 
 #: config/rs6000/rs6000-call.c:10569
-#, fuzzy, gcc-internal-format
-#| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
+#, gcc-internal-format
 msgid "argument 3 must be in the range 0 to 3"
-msgstr "Аргументом ATANH у %L має бути число у діапазоні від -1 до 1"
+msgstr "аргумент 3 має потрапляти до діапазону від 0 до 3"
 
 #: config/rs6000/rs6000-call.c:10583
-#, fuzzy, gcc-internal-format
-#| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
+#, gcc-internal-format
 msgid "argument 3 must be in the range 0 to 12"
-msgstr "Аргументом ATANH у %L має бути число у діапазоні від -1 до 1"
+msgstr "аргумент 3 має потрапляти до діапазону від 0 до 12"
 
 #: config/rs6000/rs6000-call.c:10603
-#, fuzzy, gcc-internal-format
-#| msgid "Argument must be a constant between 0 and 31."
+#, gcc-internal-format
 msgid "argument 3 must be a constant in the range 0 to 7"
-msgstr "Аргумент має бути сталою від 0 до 31."
+msgstr "аргумент 3 має бути сталою у діапазоні від 0 до 7"
 
 #: config/rs6000/rs6000-call.c:10673
 #, gcc-internal-format
@@ -38810,13 +38691,12 @@ msgstr ""
 #: config/rs6000/rs6000-call.c:11264
 #, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
-msgstr ""
+msgstr "третій аргумент %qs має потрапляти до діапазону [0, 12]"
 
 #: config/rs6000/rs6000-call.c:11282
-#, fuzzy, gcc-internal-format
-#| msgid "Second argument of %s is negative at %L"
+#, gcc-internal-format
 msgid "Second argument of %qs must be in the range [0, 3]."
-msgstr "Другий аргумент %s є від'ємним у %L"
+msgstr "Другий аргумент %qs має потрапляти до діапазону [0, 3]."
 
 #: config/rs6000/rs6000-call.c:11500
 #, gcc-internal-format
@@ -38880,239 +38760,239 @@ msgstr "%qs використовує регістр r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs потребує %qs або %qs"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
-msgstr ""
+msgstr "%qs потребує архітектури PowerPC64, вмикаємо"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
-msgstr ""
+msgstr "%<-mcall-aixdesc%> є несумісним із %<-mabi=elfv2%>"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, gcc-internal-format
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs потребує %qs"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "невідомий параметр для %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20055
+#: config/rs6000/rs6000.c:20172
 #, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "некоректний процесор %qs для %s%qs%s"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> вимикає %<-m%s%>"
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -39291,7 +39171,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -39361,201 +39241,205 @@ msgstr ""
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, gcc-internal-format
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr ""
+
+#: config/s390/s390.c:766
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr ""
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr ""
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
-#, fuzzy, gcc-internal-format
-#| msgid "%qF requires z14 or higher"
+#: config/s390/s390.c:856
+#, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
-msgstr "%qF потребує z14 або вищого"
+msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "некоректний аргумент %d для вбудованої %qF"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr ""
@@ -39897,17 +39781,22 @@ msgstr ""
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr ""
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr ""
@@ -39973,8 +39862,8 @@ msgstr ""
 msgid "could not read the BRIG file"
 msgstr ""
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -40034,7 +39923,7 @@ msgstr "змінній %qD надано значення, але цю змінн
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
@@ -40072,22 +39961,19 @@ msgid "prototype for %q+D follows non-prototype definition"
 msgstr ""
 
 #: c/c-decl.c:1922
-#, fuzzy, gcc-internal-format
-#| msgid "previous definition of %qD here"
+#, gcc-internal-format
 msgid "previous definition of %q+D with type %qT"
-msgstr "попереднє визначення %qD було тут"
+msgstr ""
 
 #: c/c-decl.c:1926
-#, fuzzy, gcc-internal-format
-#| msgid "previous implicit declaration of %q+D was here"
+#, gcc-internal-format
 msgid "previous implicit declaration of %q+D with type %qT"
-msgstr "попереднє неявне оголошення %q+D було тут"
+msgstr ""
 
 #: c/c-decl.c:1930
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration of %qD here"
+#, gcc-internal-format
 msgid "previous declaration of %q+D with type %qT"
-msgstr "попереднє оголошення %qD було тут"
+msgstr ""
 
 #: c/c-decl.c:1970
 #, gcc-internal-format
@@ -40259,7 +40145,7 @@ msgstr ""
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -40269,7 +40155,7 @@ msgstr ""
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
@@ -40279,213 +40165,212 @@ msgstr ""
 msgid "nested extern declaration of %qD"
 msgstr ""
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "неявне оголошення функції %qE; ви мали на увазі %qs?"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "неявне оголошення функції %qE"
 
-#: c/c-decl.c:3405
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration of %q#D"
+#: c/c-decl.c:3404
+#, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
-msgstr "попереднє оголошення %q#D"
+msgstr ""
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "несумісне неявне оголошення вбудованої функції %qD"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr ""
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "несумісне неявне оголошення функції %qD"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr ""
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr ""
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr ""
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr ""
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr ""
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr ""
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr ""
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr ""
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr ""
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr ""
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr ""
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr ""
@@ -40493,28 +40378,28 @@ msgstr ""
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr ""
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr ""
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr ""
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr ""
@@ -40523,267 +40408,267 @@ msgstr ""
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "об'єкт розмірності змінної може бути не ініціалізовано"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr ""
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, gcc-internal-format
 msgid "inline function %q+D given attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD має бути ініціалізовано"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr ""
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr ""
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr ""
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr ""
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr ""
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, gcc-internal-format
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr ""
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr ""
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr ""
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr ""
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr ""
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "дублювання %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "дублювання %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "дублювання %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "дублювання %<_Atomic%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr ""
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr ""
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -40791,711 +40676,711 @@ msgstr ""
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr ""
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr ""
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr ""
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr ""
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr ""
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr ""
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr ""
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr ""
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr ""
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr ""
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr ""
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr ""
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr ""
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr ""
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr ""
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "У ISO C99 не передбачено підтримки %<_Noreturn%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "У ISO C90 не передбачено підтримки %<_Noreturn%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr ""
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr ""
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr ""
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr ""
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr ""
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr ""
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr ""
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr ""
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr ""
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr ""
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr ""
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr ""
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr ""
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr ""
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "встановлено значення параметра %qD, але сам параметр ніде не використано"
@@ -41503,257 +41388,257 @@ msgstr "встановлено значення параметра %qD, але 
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr ""
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr ""
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "У ISO C90 не передбачено підтримки %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr ""
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr ""
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr ""
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "підтримки %<__int%d%> для цього призначення не передбачено"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr ""
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "У ISO C не передбачено підтримки типу %<_Float%d%s%>"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "підтримки %<_Float%d%s%> для цього призначення не передбачено"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr ""
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr ""
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr ""
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr ""
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> до %<extern%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> до %<static%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -41773,7 +41658,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "для відповідності цьому %qs"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -41783,7 +41668,7 @@ msgstr ""
 msgid "ISO C forbids an empty translation unit"
 msgstr ""
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr ""
@@ -41819,7 +41704,7 @@ msgid "unknown type name %qE"
 msgstr ""
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -41839,7 +41724,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -41854,7 +41739,7 @@ msgstr ""
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -41892,7 +41777,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "мало бути %<,%> або %<;%>"
@@ -41950,7 +41835,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -41995,14 +41880,14 @@ msgstr ""
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -42087,7 +41972,7 @@ msgstr ""
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr ""
@@ -42147,7 +42032,7 @@ msgstr ""
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -42162,7 +42047,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
@@ -42187,17 +42072,17 @@ msgstr ""
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr ""
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -42217,12 +42102,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -42237,8 +42122,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr ""
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -42265,12 +42150,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "перший операнд %<sizeof%> було оголошено тут:"
@@ -42661,70 +42546,66 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.c:11965 cp/parser.c:34726
-#, fuzzy, gcc-internal-format
-#| msgid "missing primary template attribute %s"
+#: c/c-parser.c:11965 cp/parser.c:34780
+#, gcc-internal-format
 msgid "missing property attribute"
-msgstr "пропущено атрибут основного шаблона %s"
+msgstr "пропущено атрибут властивості"
 
 #: c/c-parser.c:12004
-#, fuzzy, gcc-internal-format
-#| msgid "unknown option for %<%s=%s%>"
+#, gcc-internal-format
 msgid "unknown property attribute %<%s%s%>"
-msgstr "невідомий параметр для %<%s=%s%>"
+msgstr "невідомий атрибут властивості %<%s%s%>"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12016 cp/parser.c:34772
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<for%> after %qs"
+#: c/c-parser.c:12016 cp/parser.c:34826
+#, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
-msgstr "мало бути %<for%> після %qs"
+msgstr "очікувалося %<=%> після %qE Objective-C"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
-#, fuzzy, gcc-internal-format
-#| msgid "expected function name"
+#: c/c-parser.c:12027 cp/parser.c:34840
+#, gcc-internal-format
 msgid "expected %qE selector name"
-msgstr "мало бути вказано назву функції"
+msgstr ""
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> має перебувати у області видимості файла"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -42734,18 +42615,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp requires%> можна використовувати лише на рівні файла"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
@@ -42765,53 +42646,53 @@ msgstr "мало бути %<)%> або %<,%>"
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "мало бути %<none%> або %<present%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "мало бути %<none%> або %<shared%>"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "мало бути %<data%>, %<update%>, %<enter%> або %<exit%>"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "мало бути %<data%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -42833,108 +42714,107 @@ msgstr "значення %<num_threads%> має бути додатним"
 msgid "%<num_tasks%> value must be positive"
 msgstr "значення %<num_tasks%> має бути додатним"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "значення %<grainsize%> має бути додатним"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "значення %<priority%> має бути невід’ємним"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
-#, fuzzy, gcc-internal-format
-#| msgid "expected constant integer expression"
+#: c/c-parser.c:13885 cp/parser.c:36421
+#, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
-msgstr "мало бути використано сталий цілочисельний вираз"
+msgstr "мало бути використано сталий цілочисельний вираз із коректним значенням підказки щодо синхронізації"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "мало бути %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> або %<default%>"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "мало бути %<scalar%>, %<aggregate%> або %<pointer%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "значення %qs має бути додатним"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "забагато аргументів %<static%>"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "несподіваний аргумент"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "мало бути %<concurrent%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "мало бути %<teams%>, %<parallel%> або %<thread%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "значення розміру фрагмента має бути додатним"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -42944,17 +42824,17 @@ msgstr ""
 msgid "%<num_teams%> value must be positive"
 msgstr "значення %<num_teams%> має бути додатним"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "значення %<thread_limit%> має бути додатним"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -42974,22 +42854,22 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr ""
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -43004,82 +42884,82 @@ msgstr ""
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "мало бути %<host%>, %<nohost%> або %<any%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "мало бути %<data%> після %<#pragma acc %s%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -43094,7 +42974,7 @@ msgstr ""
 msgid "expected function name"
 msgstr "мало бути вказано назву функції"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -43104,115 +42984,112 @@ msgstr ""
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> має бути застосовано до використання"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> має бути застосовано до визначення"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
+#: c/c-parser.c:17322 cp/parser.c:38796
+#, gcc-internal-format
 msgid "expected %<allocator%>"
-msgstr "мало бути %<operator%>"
+msgstr "мало бути %<allocator%>"
 
 #: c/c-parser.c:17338
 #, gcc-internal-format
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
-#, fuzzy, gcc-internal-format
-#| msgid "%<-pipe%> not supported"
+#: c/c-parser.c:17353 cp/parser.c:38811
+#, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
-msgstr "Підтримки %<-pipe%> не передбачено"
+msgstr "підтримки %<#pragma omp allocate%> ще не передбачено"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
+#: c/c-parser.c:17452 cp/parser.c:38904
+#, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
-msgstr "мала бути команда %<depend%>, %<destroy%> або %<update%>"
+msgstr "мала бути команда %<read%>, %<write%>, %<update%> або %<capture%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "мала бути команда %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> або %<hint%>"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "забагато атомарних команд"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr ""
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr ""
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "мало бути %<in%>, %<out%>, %<inout%> або %<mutexinoutset%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "мала бути команда %<depend%>, %<destroy%> або %<update%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "мало бути %<acq_rel%>, %<release%> або %<acquire%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -43222,32 +43099,32 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "мала бути команда %<inclusive%> або %<exclusive%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "мало бути %<#pragma omp scan%>"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -43257,72 +43134,72 @@ msgstr ""
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "мало бути %<for%> після %qs"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "мало бути %<point%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -43337,57 +43214,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr ""
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr ""
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "мало бути %<construct%>, %<device%>, %<implementation%> або %<user%>"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "мало бути %<match%>"
@@ -43397,12 +43274,12 @@ msgstr "мало бути %<match%>"
 msgid "variant %qD is not a function"
 msgstr ""
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr ""
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43412,32 +43289,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "мало бути %<target%>"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "мало бути %<declare%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -43492,42 +43369,42 @@ msgstr "мало бути вказано назву функції %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "мало бути %<simd%>, %<reduction%>, %<target%> або %<variant%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "мало бути %<seq_cst%>, %<relaxed%> або %<acq_rel%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
-msgstr ""
+msgstr "мала бути команда %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> або %<atomic_default_mem_order%>"
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -43542,27 +43419,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -43572,7 +43449,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -43587,7 +43464,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -43628,127 +43505,127 @@ msgstr ""
 msgid "function types not truly compatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr ""
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr ""
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr ""
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr ""
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr ""
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr ""
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr ""
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr ""
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr ""
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr ""
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr ""
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr ""
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr ""
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr ""
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr ""
@@ -43756,1595 +43633,1594 @@ msgstr ""
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr ""
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr ""
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr ""
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr ""
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, gcc-internal-format
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "забагато аргументів для вбудованої функції %qE; мало бути %d"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, gcc-internal-format
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "замало аргументів для вбудованої функції %qE; мало бути %u"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr ""
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> над булевим виразом"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr ""
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, gcc-internal-format
 msgid "wrong type argument to absu"
 msgstr "помилковий тип аргументу absu"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr ""
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr ""
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr ""
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr ""
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr ""
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, gcc-internal-format
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr ""
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr ""
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr ""
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr ""
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "у виклику %qD, оголошено тут"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr ""
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr ""
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr ""
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr ""
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr "вбудований %qD оголошено тут"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT"
 msgstr ""
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
-msgstr ""
+msgstr "ініціалізація відкидає кваліфікатор %qv з типу призначення вказівника"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
-msgstr ""
+msgstr "return відкидає кваліфікатор %qv з типу призначення вказівника"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "У ISO C заборонено перетворення аргументу до типу об'єднання"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
-msgstr ""
+msgstr "ліва частина інструкції призначення може бути кандидатом на атрибут форматування"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7260
-#, fuzzy, gcc-internal-format
-#| msgid "returning %qT from a function with incompatible return type %qT"
+#: c/c-typeck.c:7320
+#, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
-msgstr "повертає %qT з функції із несумісним типом повернення %qT"
+msgstr ""
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "повертає %qT з функції із несумісним типом повернення %qT"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr ""
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "несумісні типи при ініціалізації типу %qT за допомогою %qT"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr ""
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr ""
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr ""
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозорі типи векторів не може бути ініціалізовано"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr ""
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr ""
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
-msgstr ""
+msgstr "пропущено ініціалізатор для поля %qD %qT"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr ""
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr ""
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr ""
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr ""
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, gcc-internal-format
 msgid "excess elements in %<char%> array initializer"
 msgstr ""
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr ""
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr ""
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr ""
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr ""
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr ""
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr ""
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr ""
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr ""
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr ""
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr ""
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr ""
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -45549,7 +45425,7 @@ msgstr ""
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -45659,661 +45535,665 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr "немає відповідників "
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr ""
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> у %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> у %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs у %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%<operator %s%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator %s%> у %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> у %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> у %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr ""
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr ""
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr ""
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  оголошено тут"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "некоректне перетворення з %qH на %qI"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr ""
+
+#: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT оголошено тут:"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 msgid "cannot convert %qH to %qI"
 msgstr "не вдалося перетворити %qH на %qI"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " кандидат 1: %q#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " кандидат 2: %q#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -46337,1131 +46217,1126 @@ msgstr ""
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr ""
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr ""
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D конфліктує зі версією, успадкованою від %qT"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "версію, успадковану від %qT, оголошено тут:"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr ""
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "локальний метод %q#D оголошено тут:"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "локальний член %q#D оголошено тут"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT оголошено тут:"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr ""
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  але не оголошує %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  або %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  але не оголошує %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr ""
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr ""
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "член масиву %q#D оголошено тут"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "у оголошенні %q#T"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "оголошення %q#D змінює сенс %qD"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%qD оголошено тут як %q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr ""
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr ""
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr ""
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr ""
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "член %qD має бути ініціалізовано ініціалізатором mem у конструкторі %<constexpr%>"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "виклик внутрішньої функції %qE"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr "спочатку оголошено %<const%> тут"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr ""
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr ""
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, gcc-internal-format
 msgid "allocation performed here"
 msgstr ""
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr ""
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
-#, fuzzy, gcc-internal-format
-#| msgid "%<goto%> is not a constant expression"
+#: cp/constexpr.c:4062
+#, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
-msgstr "%<goto%> не є сталим виразом"
+msgstr ""
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.c:4021
-#, fuzzy, gcc-internal-format
-#| msgid "%<goto%> is not a constant expression"
+#: cp/constexpr.c:4076
+#, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
-msgstr "%<goto%> не є сталим виразом"
+msgstr ""
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4064
-#, fuzzy, gcc-internal-format
-#| msgid "%<goto%> is not a constant expression"
+#: cp/constexpr.c:4119
+#, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
-msgstr "%<goto%> не є сталим виразом"
+msgstr ""
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr ""
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "розіменування нульового вказівника"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, gcc-internal-format
 msgid "allocated here"
 msgstr ""
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "зміна %qE не є сталим виразом"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "інструкція не є сталим виразом"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "значення %qE типу %qT не є сталим виразом"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%<reinterpret_cast%> не є сталим виразом"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr ""
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не є сталим виразом"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "вираз %qE не є сталим виразом"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6960
-#, fuzzy, gcc-internal-format
-#| msgid "size of array %qE is not a constant expression"
+#: cp/constexpr.c:7023
+#, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
-msgstr "розмір масиву %qE не є сталим виразом"
+msgstr ""
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr ""
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ділення на нуль не є сталим виразом"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не є сталим виразом"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не є сталим виразом"
 
-#: cp/constexpr.c:8834
-#, fuzzy, gcc-internal-format
-#| msgid "statement is not a constant expression"
+#: cp/constexpr.c:8897
+#, gcc-internal-format
 msgid "label definition is not a constant expression"
-msgstr "інструкція не є сталим виразом"
+msgstr "визначення мітки не є сталим виразом"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -47471,52 +47346,52 @@ msgstr ""
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD не є типом класів"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr ""
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr ""
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "обчислюємо %qs"
@@ -47557,7 +47432,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -47940,7 +47815,7 @@ msgstr "з попереднього оголошення %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr ""
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "попереднє оголошення %qD"
@@ -48070,11 +47945,11 @@ msgstr "попереднє оголошення %<pragma omp declare reduction%>
 msgid "%q#D previously defined here"
 msgstr ""
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, gcc-internal-format
 msgid "%q#D previously declared here"
-msgstr "%q#D раніше оголошено тут"
+msgstr "%q#D раніше оголошено тут:"
 
 #: cp/decl.c:1912
 #, gcc-internal-format
@@ -48106,60 +47981,55 @@ msgstr ""
 msgid "previous specification in %q#D here"
 msgstr ""
 
-#: cp/decl.c:2047
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %qD shadows a built-in function"
+#: cp/decl.c:2045
+#, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
-msgstr "оголошення %qD затінює вбудовану функцію"
+msgstr "оголошення %qD конфліктує із вбудованим значенням"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr ""
 
-#: cp/decl.c:2056
-#, fuzzy, gcc-internal-format
-#| msgid " declared here"
+#: cp/decl.c:2054
+#, gcc-internal-format
 msgid "import declared %q#D here"
-msgstr " оголошено тут"
+msgstr "імпортуванням оголошено %q#D тут:"
 
-#: cp/decl.c:2064
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting declaration %q#D"
+#: cp/decl.c:2062
+#, gcc-internal-format
 msgid "conflicting exporting declaration %qD"
-msgstr "конфлікт оголошень %q#D"
+msgstr "конфлікт оголошення експортування %qD"
 
-#: cp/decl.c:2065
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration of %qD here"
+#: cp/decl.c:2063
+#, gcc-internal-format
 msgid "previous declaration %q#D here"
-msgstr "попереднє оголошення %qD було тут"
+msgstr "попереднє оголошення %q#D тут:"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "попереднє визначення %qD було тут"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "попереднє оголошення %qD було тут"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2166
-#, fuzzy, gcc-internal-format
-#| msgid "deleted definition of %qD"
+#: cp/decl.c:2164
+#, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
-msgstr "вилучене визначення %qD"
+msgstr "вилучене оголошення %qD не є першим оголошенням"
 
 #. From [temp.expl.spec]:
 #.
@@ -48169,49 +48039,48 @@ msgstr "вилучене визначення %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3102 cp/decl.c:3160
-#, fuzzy, gcc-internal-format
-#| msgid "template %qD declared"
+#: cp/decl.c:3084 cp/decl.c:3142
+#, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
-msgstr "оголошено шаблон %qD"
+msgstr ""
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48219,656 +48088,660 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, gcc-internal-format
 msgid "previous label"
 msgstr "попередня мітка"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  звідси"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, gcc-internal-format
 msgid "  enters %<try%> block"
-msgstr ""
+msgstr "  входить до блоку %<try%>"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  входить до блоку %<catch%>"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD використано без аргументів шаблона"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, gcc-internal-format
+msgid "%qD is a function, not a type"
+msgstr "%qD є функцією, а не типом"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr ""
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr ""
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr ""
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "не ініціалізовано %<const %D%>"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:6822
-#, fuzzy, gcc-internal-format
-#| msgid "<structured bindings>"
+#: cp/decl.c:6818
+#, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
-msgstr "<структуровані прив'язки>"
+msgstr "тип структурованої прив'язки є неповним, %qT"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "у C++98 %qD має бути ініціалізовано конструктором, а не за допомогою %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr ""
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "неможливо розкласти недоступний член %qD %qT"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -48876,7 +48749,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -48884,7 +48757,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -48892,1632 +48765,1641 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не є інтегральним сталим виразом"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "не вдалося розкласти тип об'єднання %qT"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr ""
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D явним чином типово визначено тут"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr ""
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T не є класом або простором назв"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr ""
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr ""
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr ""
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr ""
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs визначено з %qT"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs визначено з %<decltype%>"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs визначено з %<typeof%>"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr ""
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr ""
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "некоректне використання %<decltype(auto)%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr ""
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "некоректне використання %<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD не може бути %qs"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, gcc-internal-format
 msgid "variable template declared here"
-msgstr ""
+msgstr "шаблон змінної оголошено тут:"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:14746
-#, fuzzy, gcc-internal-format
-#| msgid "In static member function %qs"
+#: cp/decl.c:14764
+#, gcc-internal-format
 msgid "%qD must be a non-static member function"
-msgstr "У статичній функції-члені %qs"
+msgstr "%qD має бути нестатичною функцією-членом"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD не приймає аргументів"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT має попереднє оголошення тут"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -50529,106 +50411,105 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
-msgstr ""
+msgstr "використання переліку %q#D без попереднього оголошення"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
-msgstr ""
+msgstr "повторне оголошення %qT не як шаблона"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
-#, fuzzy, gcc-internal-format
-#| msgid "local declaration from a different function"
+#: cp/decl.c:15347 cp/semantics.c:3354
+#, gcc-internal-format
 msgid "cannot declare %qD in a different module"
-msgstr "локальне оголошення з іншої функції"
+msgstr "не можна оголошувати %qD в іншому модулі"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -50637,77 +50518,77 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr ""
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -50747,7 +50628,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -50757,7 +50638,7 @@ msgstr ""
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -51082,22 +50963,22 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr ""
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -51202,7 +51083,7 @@ msgstr ""
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
@@ -51212,7 +51093,7 @@ msgstr ""
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
@@ -51398,410 +51279,408 @@ msgstr ""
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr ""
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD має бути ініціалізовано у списку ініціалізації членів"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr ""
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D має бути ініціалізовано"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD буде ініціалізовано після"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "базове %qT буде ініціалізовано після"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
-msgstr ""
+msgstr "  %q#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  коли ініціалізовано тут"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "масив має бути ініціалізовано за допомогою взятого у фігурні дужки ініціалізатора"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr ""
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
-#, fuzzy, gcc-internal-format
-#| msgid "local method %q#D declared here"
+#: cp/init.c:2675
+#, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
-msgstr "локальний метод %q#D оголошено тут:"
+msgstr "зі зсувом %wi з %qD оголошено тут"
 
-#: cp/init.c:2672
-#, fuzzy, gcc-internal-format
-#| msgid "version inherited from %qT declared here"
+#: cp/init.c:2679
+#, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
-msgstr "версію, успадковану від %qT, оголошено тут:"
+msgstr "зі зсувом [%wi, %wi] з %qD оголошено тут:"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "некоректний тип %<void%> для %<new%>"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr ""
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -51814,7 +51693,7 @@ msgstr "некоректне %<#pragma %s%>"
 #: cp/lex.c:612
 #, gcc-internal-format
 msgid "%<#pragma vtable%> no longer supported"
-msgstr ""
+msgstr "підтримку %<#pragma vtable%> припинено"
 
 #: cp/lex.c:684
 #, gcc-internal-format
@@ -51856,62 +51735,62 @@ msgstr ""
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -52092,216 +51971,213 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "очікуваний підпис: %qD"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr ""
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr ""
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D приховує конструктор для %q#D"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "конфліктує із оголошенням компонування мови C %q#D"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "через різні специфікації виключення"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr ""
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
-msgstr ""
+msgstr "оголошення %qD затінює член %qT"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, gcc-internal-format
 msgid "%q#D does not have external linkage"
-msgstr ""
+msgstr "%q#D не має зовнішньої прив'язки"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, gcc-internal-format
 msgid "%q#D declared here"
-msgstr ""
+msgstr "%q#D оголошено тут:"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
-msgstr ""
+msgstr "%<%T%s%D%> є назвою деструктора"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
-#, fuzzy, gcc-internal-format
-#| msgid "%qT is not a class or namespace"
+#: cp/name-lookup.c:5645 cp/pt.c:18297
+#, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
-msgstr "%qT не є класом або простором назв"
+msgstr "%qT не є класом, простором назв або переліком"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5672
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid offset in %qs"
+#: cp/name-lookup.c:5689
+#, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
-msgstr "%qs не є коректним зсувом у %qs"
+msgstr "%qT не є безпосередньою основою %qT"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is declared in header %qs"
+#: cp/name-lookup.c:5746
+#, gcc-internal-format
 msgid "%qD has not been declared in %qD"
-msgstr "%qD оголошено у файлі заголовків %qs"
+msgstr "%qD не було оголошено у %qD"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -52309,89 +52185,88 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr ""
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD визначено тут"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr ""
 
-#: cp/name-lookup.c:8917
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "previous definition of %qD here"
+#: cp/name-lookup.c:8934
+#, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
-msgstr "попереднє визначення %qD було тут"
+msgstr "доступне визначення %s тут:"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -52416,7 +52291,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -52441,7 +52316,7 @@ msgstr ""
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -52521,7 +52396,7 @@ msgstr ""
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -52657,7 +52532,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -52782,7 +52657,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -52832,7 +52707,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -52862,7 +52737,7 @@ msgstr ""
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr ""
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
@@ -52882,12 +52757,12 @@ msgstr ""
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
@@ -52922,7 +52797,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
@@ -52937,7 +52812,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "помилкова кількість аргументів %<__builtin_addressof%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "помилкова кількість аргументів %<__builtin_launder%>"
@@ -52952,1118 +52827,1118 @@ msgstr ""
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr ""
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr ""
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr ""
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "у виразах %qs не можна визначати типи"
 
-#: cp/parser.c:8946
-#, fuzzy, gcc-internal-format
-#| msgid "%<__builtin_thread_pointer%> is not supported on this target"
+#: cp/parser.c:8953
+#, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
-msgstr "підтримки %<__builtin_thread_pointer%> для цього призначення не передбачено"
+msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr ""
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr "лямбда-вираз у типі параметра шаблона"
+
+#: cp/parser.c:10819
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "вже захоплене %qD у лямбда-виразі"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr ""
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "забагато %<...%> у лямбда-захопленні"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "визначено типовий аргумент для лямбда-параметра"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "дублювання %<mutable%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr ""
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr ""
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr "умова оголошує функцію"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr ""
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> у функції %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:13724
-#, fuzzy, gcc-internal-format
-#| msgid "expected type-name"
+#: cp/parser.c:13748
+#, gcc-internal-format
 msgid "expected module-name"
-msgstr "мало бути вказано тип-назву"
+msgstr "мало бути вказано module-name"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, gcc-internal-format
 msgid "private module fragment"
 msgstr ""
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr ""
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr ""
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
-#, fuzzy, gcc-internal-format
-#| msgid "pointers are not permitted as case values"
+#: cp/parser.c:14044
+#, gcc-internal-format
 msgid "attributes are not permitted in this position"
-msgstr "вказівники не можуть бути значеннями випадків"
+msgstr "не можна використовувати атрибути у цій позиції"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr ""
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "зайве %<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD є некоректним у лямбді"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "специфікатор типу є некоректним у лямбді"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr ""
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "некоректний префікс кодування у буквальному операторі"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "мало бути вказано оператор"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, gcc-internal-format
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr ""
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "некоректний параметр обмеженого типу"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr ""
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr ""
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "помилка обробки у списку аргументів шаблона"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr ""
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "спеціалізація шаблона із C-компонуванням"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "мало бути вказано специфікатор типу"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "мало бути вказано тип-назву"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE не обмежує тип"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr ""
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "мало бути %<;%> або %<{%>"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "У ISO C++ заборонено порожні enum без назви"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr ""
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
-#, fuzzy, gcc-internal-format
-#| msgid "friend declaration here"
+#: cp/parser.c:20793
+#, gcc-internal-format
 msgid "opaque-enum-declaration here"
-msgstr "оголошення friend тут:"
+msgstr "тут opaque-enum-declaration"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr ""
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr ""
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr ""
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
-#, fuzzy, gcc-internal-format
-#| msgid "Warn about implicit function declarations."
+#: cp/parser.c:21377 cp/parser.c:21402
+#, gcc-internal-format
 msgid "parentheses were disambiguated as a function declaration"
-msgstr "Попереджати про неявні оголошення функцій."
+msgstr ""
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не є типом"
@@ -54072,431 +53947,430 @@ msgstr "%<%T::%E%> не є типом"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE потребує %<-fgnu-tm%>"
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:23238
-#, fuzzy, gcc-internal-format
-#| msgid "%qE missing template arguments"
+#: cp/parser.c:23275
+#, gcc-internal-format
 msgid "%qT not permitted in template argument"
-msgstr "у %qE пропущено аргументи шаблона"
+msgstr "%qT не можна використовувати у аргументі шаблона"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "мало бути вказано специфікатор типу"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "мало бути %<,%> або %<...%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "мало бути %<{%> або %<:%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "не вдалося визначити тип typename"
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "попереднє визначення %q#T"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "мало бути %<class%> або %<typename%>"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "У ISO C++17 не можна визначати динамічні специфікації виключень"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr ""
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "мав бути атрибут перед %<...%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr ""
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr ""
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -54505,758 +54379,756 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "У ISO C++ 1998 не передбачено підтримки %<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "вказано одразу %<__thread%> і %<thread_local%>"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "дублювання %qD"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублювання %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "мало бути %<new%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "мало бути %<delete%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "мало бути %<return%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "мало бути %<extern%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "мало бути %<static_assert%>"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "мало бути %<decltype%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "мало бути %<operator%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "мало бути %<class%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "мало бути %<template%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "мало бути %<namespace%>"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "мало бути %<using%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "мало бути %<asm%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "мало бути %<try%>"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "мало бути %<catch%>"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "мало бути %<throw%>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "мало бути %<auto%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "мало бути %<__label__%>"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "мало бути %<@try%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "мало бути %<@synchronized%>"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "мало бути %<@throw%>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "мало бути %<__transaction_atomic%>"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "мало бути %<__transaction_relaxed%>"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "мало бути %<co_yield%>"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "мало бути %<::%>"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "мало бути %<...%>"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "мало бути %<*%>"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "мало бути %<~%>"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "мало бути %<:%> або %<::%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "мало бути %<class%>, %<typename%> або %<template%>"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "теґ %qs використано у назві %q#T"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
-msgstr ""
+msgstr "%q#T було раніше оголошено тут:"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr ""
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr ""
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr ""
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:34760
-#, fuzzy, gcc-internal-format
-#| msgid "unknown attribute %qE"
+#: cp/parser.c:34814
+#, gcc-internal-format
 msgid "unknown property attribute %qE"
-msgstr "невідомий атрибут %qE"
+msgstr "невідомий атрибут властивості %qE"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "мало бути використано список цілих значень"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "типи не можна визначати у типі ітератора"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:44801
-#, fuzzy, gcc-internal-format
-#| msgid "malformed %<#pragma options%>, ignoring"
+#: cp/parser.c:44854
+#, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
-msgstr "помилкове форматування %<#pragma options%>, ігноруємо"
+msgstr "помилкове форматування %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp requires%> можна використовувати лише на рівні файлів або просторів назв"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> має перебувати всередині функції"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> має перебувати всередині функції"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr ""
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  із оголошення %q#D"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "із оголошення %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr ""
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr ""
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "пропущено атрибути основного шаблона %s"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "пропущено атрибут основного шаблона %s"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr ""
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr ""
@@ -55269,142 +55141,142 @@ msgstr ""
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "оголошення friend тут:"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr ""
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
-msgstr ""
+msgstr "параметр шаблона %qD оголошено тут:"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr ""
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -55412,17 +55284,17 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -55431,47 +55303,47 @@ msgstr ""
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "оголошено шаблон %qD"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -55481,57 +55353,57 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -55539,7 +55411,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -55547,132 +55419,132 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
-msgstr ""
+msgstr "повторно оголошено тут як %q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr ""
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -55680,298 +55552,297 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "в аргументі шаблона для типу %qT"
 
-#: cp/pt.c:7379
-#, fuzzy, gcc-internal-format
-#| msgid "in template argument for type %qT"
+#: cp/pt.c:7403
+#, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
-msgstr "в аргументі шаблона для типу %qT"
+msgstr ""
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  мало бути %qD, втім, маємо %qD"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
@@ -55989,291 +55860,291 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "порожній ініціалізатор у захопленні під час ініціалізації лямбди"
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "скористайтеся краще %<this->%D%>"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "скористайтеся краще %<%T::%D%>"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
-msgstr ""
+msgstr "%qD оголошено тут, пізніше у модулі трансляції"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "помилкова кількість аргументів %<__builtin_convertvector%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не є класом або простором назв"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не є класом або простором назв"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT є змінним за змінними типом"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "інтегральний вираз %qE не є сталою"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr ""
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "специфікація виключення %qD залежить від самої себе"
@@ -56285,154 +56156,153 @@ msgstr "специфікація виключення %qD залежить ві
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некоректний шаблон нетипізованого параметра"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr ""
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
-#, fuzzy, gcc-internal-format
-#| msgid "in a call to function %qD declared here"
+#: cp/pt.c:29507
+#, gcc-internal-format
 msgid "explicit deduction guide declared here"
-msgstr "у виклику функції %qD, оголошено тут"
+msgstr ""
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "не вдалося вивести %qT з %qE"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "некоректне використання %qT в аргументі шаблона"
@@ -56567,531 +56437,531 @@ msgstr ""
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr ""
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, gcc-internal-format
 msgid "catching non-reference type %q#T"
 msgstr ""
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "у %qE пропущено аргументи шаблона"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr ""
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "визначення %q#T всередині списку шаблонних параметрів"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr ""
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr ""
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "пропущено аргументи шаблона"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "статичне значення %<gang%> має бути додатним"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "значення num %<gang%> має бути додатним"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "значення довжини %<vector%> має бути додатним"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "значення num %<worker%> має бути додатним"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "Вираз %<hint%> має бути сталим цілочисельним виразом"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr ""
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "аргумент, який не є вказівником, у %<__builtin_launder%>"
@@ -57099,22 +56969,22 @@ msgstr "аргумент, який не є вказівником, у %<__builti
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -57124,1054 +56994,1052 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "інструкція-вираз не є сталим виразом"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, gcc-internal-format
 msgid " declared here"
-msgstr " оголошено тут"
+msgstr " оголошено тут:"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr ""
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr ""
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr ""
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr ""
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr ""
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr ""
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr ""
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "Атрибут %qE не приймає аргументів"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "повторне оголошення %qD додає мітку abi %qE"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr ""
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2548
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<restrict%>"
+#: cp/typeck.c:2559
+#, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
-msgstr "некоректне використання %<restrict%>"
+msgstr "некоректне використання нестатичного члена даних %qE"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr ""
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr ""
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr ""
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
-#, fuzzy, gcc-internal-format
-#| msgid "comparison of integer expressions of different signedness: %qT and %qT"
+#: cp/typeck.c:5483 cp/typeck.c:5491
+#, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
-msgstr "порівняння цілочисельних виразів невід'ємного і різнознакового діапазонів: %qT і %qT"
+msgstr ""
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr ""
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr ""
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr ""
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr ""
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7956
+#: cp/typeck.c:7963
 #, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr ""
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr ""
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "некоректне перетворення з типу %qT до типу %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr ""
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr ""
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr ""
@@ -58363,10 +58231,9 @@ msgid "invalid use of template template parameter %qT"
 msgstr ""
 
 #: cp/typeck2.c:415
-#, fuzzy, gcc-internal-format
-#| msgid "invalid offset operand in %qs"
+#, gcc-internal-format
 msgid "invalid use of pack expansion %qT"
-msgstr "некоректний операнд зсуву у %qs"
+msgstr "некоректне використання розгортання пакета %qT"
 
 #: cp/typeck2.c:421
 #, gcc-internal-format
@@ -58436,107 +58303,102 @@ msgstr ""
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
-msgstr ""
+msgstr "пропущено ініціалізатор для члена %qD"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2213
-#, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr ""
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -58556,320 +58418,324 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
-#, fuzzy, gcc-internal-format
-#| msgid "opaque vector types cannot be initialized"
+#: d/dmd/dsymbolsem.c:306
+#, gcc-internal-format
 msgid "extern symbols cannot have initializers"
-msgstr "непрозорі типи векторів не може бути ініціалізовано"
+msgstr ""
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:407
-#, fuzzy, gcc-internal-format
-#| msgid "condition declares a function"
+#: d/dmd/dsymbolsem.c:409
+#, gcc-internal-format
 msgid "cannot be declared to be a function"
-msgstr "умова оголошує функцію"
+msgstr "не може бути оголошено як функцію"
 
-#: d/dmd/dsymbolsem.c:416
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in definition of macro %qs"
-msgid "no definition of struct %s"
-msgstr "у визначенні макросу %qs"
+#: d/dmd/dsymbolsem.c:418
+#, gcc-internal-format, gfc-internal-format
+msgid "no definition of struct `%s`"
+msgstr "немає визначення структури «%s»"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot open %s"
+#: d/dmd/dsymbolsem.c:624
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot be %s"
-msgstr "не вдалося відкрити %s"
+msgstr "не може бути %s"
 
-#: d/dmd/dsymbolsem.c:622
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot open %s"
+#: d/dmd/dsymbolsem.c:636
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot be `scope` and `%s`"
-msgstr "не вдалося відкрити %s"
+msgstr ""
 
-#: d/dmd/dsymbolsem.c:626
-#, fuzzy, gcc-internal-format
-#| msgid "%qD cannot be %qs"
+#: d/dmd/dsymbolsem.c:640
+#, gcc-internal-format
 msgid "field cannot be `scope`"
-msgstr "%qD не може бути %qs"
+msgstr "поле не може бути «scope»"
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, gcc-internal-format
 msgid "inout variables can only be declared inside inout functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, gcc-internal-format
 msgid "string expected for library name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1371
-#, fuzzy, gcc-internal-format
-#| msgid "unexpected text address:"
+#: d/dmd/dsymbolsem.c:1372
+#, gcc-internal-format
 msgid "function name expected for start address"
-msgstr "неочікувана текстова адреса:"
+msgstr "для початкової адреси мало бути вказано назву функцію"
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
-#, fuzzy, gcc-internal-format
-#| msgid "expected function name"
+#: d/dmd/dsymbolsem.c:1401
+#, gcc-internal-format
 msgid "string expected for mangled name"
-msgstr "мало бути вказано назву функції"
+msgstr ""
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting declaration %q#D"
+#: d/dmd/dsymbolsem.c:1465
+#, gcc-internal-format
+msgid "takes no argument"
+msgstr "не приймає аргументів"
+
+#: d/dmd/dsymbolsem.c:1526
+#, gcc-internal-format
 msgid "can only apply to a single declaration"
-msgstr "конфлікт оголошень %q#D"
+msgstr "може застосовуватися лише до одинарного оголошення"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "conflicting declaration %q#D"
+#: d/dmd/dsymbolsem.c:1573
+#, gcc-internal-format, gfc-internal-format
 msgid "incomplete mixin declaration (%s)"
-msgstr "конфлікт оголошень %q#D"
+msgstr ""
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, gcc-internal-format
 msgid "circular reference to enum member"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, gcc-internal-format
 msgid "template tuple parameter must be last one"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, gcc-internal-format
 msgid "recursive mixin instantiation"
 msgstr ""
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, gcc-internal-format
 msgid "recursive expansion"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, gcc-internal-format
 msgid "error instantiating"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "without `this` cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
-#, fuzzy, gcc-internal-format
-#| msgid "function attribute mismatch"
+#: d/dmd/dsymbolsem.c:2767
+#, gcc-internal-format
 msgid "functions cannot be scope"
-msgstr "невідповідність атрибутів функції"
+msgstr ""
 
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, gcc-internal-format
 msgid "cannot override a non-virtual function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, gcc-internal-format
 msgid "cannot be both final and abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -58877,211 +58743,202 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "overridden function is %qD"
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
-msgstr "перевизначеною функцією є %qD"
+msgstr "не може перевизначати остаточну функцію %s"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3103
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "incompatible register operand for '%%%c'"
+#: d/dmd/dsymbolsem.c:3170
+#, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
-msgstr "несумісний операнд регістру для «%%%c»"
+msgstr "несумісні коваріантні типи %s і %s"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
-#, fuzzy, gcc-internal-format
-#| msgid "overridden function is %qD"
+#: d/dmd/dsymbolsem.c:3195
+#, gcc-internal-format
 msgid "does not override any function"
-msgstr "перевизначеною функцією є %qD"
+msgstr "не перевизначає жодної функції"
 
-#: d/dmd/dsymbolsem.c:3149
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "overridden function is %qD"
+#: d/dmd/dsymbolsem.c:3216
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
-msgstr "перевизначеною функцією є %qD"
+msgstr "не може перевизначати остаточну функцію %s.%s"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "vector type expected in %qs"
+#: d/dmd/dsymbolsem.c:3763
+#, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
-msgstr "у %qs мало бути використано векторний тип"
+msgstr "мало бути вказано один аргумент типу void*, а не %s"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, gcc-internal-format
 msgid "structs, unions cannot be abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, gcc-internal-format
 msgid "circular inheritance"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, gcc-internal-format, gfc-internal-format
 msgid "inherits from duplicate interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4173
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot open profile file %s"
+#: d/dmd/dsymbolsem.c:4240
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot inherit from final class %s"
-msgstr "не вдалося відкрити файл профілювання %s"
+msgstr "не може успадковувати від остаточного класу %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
-#, fuzzy, gcc-internal-format
-#| msgid "missing template arguments"
+#: d/dmd/dsymbolsem.c:4956
+#, gcc-internal-format
 msgid "mixin templates are not regular templates"
-msgstr "пропущено аргументи шаблона"
+msgstr ""
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation %s forward references template declaration %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:5409
-#, fuzzy, gcc-internal-format
-#| msgid "Cannot read %s"
+#: d/dmd/dsymbolsem.c:5540
+#, gcc-internal-format
 msgid "cannot resolve"
-msgstr "Не вдалося прочитати %s"
+msgstr "не вдалося виконати визначення"
 
-#: d/dmd/dsymbolsem.c:5436
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in this expression"
+#: d/dmd/dsymbolsem.c:5567
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
-msgstr "у цьому виразі"
+msgstr ""
 
 #: d/dmd/semantic2.c:72
 #, gcc-internal-format
 msgid "\"%.*s\""
-msgstr ""
+msgstr "\"%.*s\""
 
 #: d/dmd/semantic2.c:78
 #, gcc-internal-format, gfc-internal-format
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, gcc-internal-format
 msgid "has forward references"
 msgstr ""
@@ -59097,10 +58954,9 @@ msgid "cannot have an in contract when overriden function %s does not have an in
 msgstr ""
 
 #: d/dmd/semantic3.c:449
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot open %s: %m"
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot be %s members"
-msgstr "не вдалося відкрити %s: %m"
+msgstr "не можуть бути членами %s"
 
 #: d/dmd/semantic3.c:476
 #, gcc-internal-format
@@ -59125,7 +58981,7 @@ msgstr ""
 #: d/dmd/semantic3.c:746
 #, gcc-internal-format, gfc-internal-format
 msgid "missing initializer for %s field %s"
-msgstr ""
+msgstr "пропущено ініціалізатор для %s, поле %s"
 
 #: d/dmd/semantic3.c:758
 #, gcc-internal-format, gfc-internal-format
@@ -59133,33 +58989,31 @@ msgid "field %s must be initialized but skipped"
 msgstr ""
 
 #: d/dmd/semantic3.c:775
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for _Literal with constructor"
+#, gcc-internal-format
 msgid "no match for implicit super() call in constructor"
-msgstr "некоректний тип для _Literal із конструктором"
+msgstr ""
 
 #: d/dmd/semantic3.c:779
 #, gcc-internal-format
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "return type of function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "тип значення, яке повертає функція"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr ""
@@ -59695,7 +59549,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -60788,12 +60642,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -60864,10 +60718,9 @@ msgid "Invalid initializer %s in Data statement at %C"
 msgstr ""
 
 #: fortran/decl.c:579
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in old style initialization of %s at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "BOZ at %L cannot appear in an old-style initialization"
-msgstr "Синтаксична помилка у ініціалізації у старому стилі %s, адреса — %C"
+msgstr ""
 
 #: fortran/decl.c:587
 #, gcc-internal-format
@@ -60974,7 +60827,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -63457,7 +63310,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63538,7 +63391,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -63673,12 +63526,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -63788,542 +63641,542 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Некоректний аргумент процедури у %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Неочікуваний специфікатор повернення з альтернативи у виклику підпрограми у %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Неочікуване NULL() всередині у %L до фіктивного %qs"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr ""
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr ""
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr ""
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr ""
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
@@ -64468,33 +64321,33 @@ msgstr ""
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr ""
@@ -64502,22 +64355,22 @@ msgstr ""
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -64894,10 +64747,9 @@ msgid "SIGN= at %L not allowed in Fortran 95"
 msgstr ""
 
 #: fortran/io.c:2416
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qs argument of %qs intrinsic at %L must be positive"
+#, gcc-internal-format, gfc-internal-format
 msgid "RECL in OPEN statement at %L must be positive"
-msgstr "аргумент %qs внутрішньої частини %qs у %L має бути додатним"
+msgstr ""
 
 #: fortran/io.c:2441
 #, gcc-internal-format
@@ -65054,7 +64906,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -66226,12 +66078,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -66386,147 +66238,147 @@ msgstr ""
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, gcc-internal-format
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr ""
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr ""
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "Не вдалося вилучити файл модуля %qs: %s"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Не вдалося перейменувати файл модуля %qs на %qs: %s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): не вдалося створити символ для %s"
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Символ %qs вже оголошено"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "внутрішній модуль ISO_FORTRAN_ENV у %C"
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "модуль ISO_C_BINDING у %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "модуль IEEE_FEATURES у %C"
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "модуль IEEE_EXCEPTIONS у %C"
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "модуль IEEE_ARITHMETIC у %C"
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, gcc-internal-format
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Не вдалося відкрити файл модуля %qs для читання у %C: %s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -66558,10 +66410,9 @@ msgid "%qs at %L should be of type integer(kind=omp_event_handle_kind)"
 msgstr ""
 
 #: fortran/openmp.c:479
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in OpenMP variable list at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in OpenMP detach clause at %C"
-msgstr "Синтаксична помилка у списку змінних OpenMP у %C"
+msgstr "Синтаксична помилка у команді від'єднання OpenMP у %C"
 
 #: fortran/openmp.c:551
 #, gcc-internal-format, gfc-internal-format
@@ -66594,10 +66445,9 @@ msgid "Syntax error in !$ACC DECLARE list at %C"
 msgstr "Синтаксична помилка у списку !$ACC DECLARE у %C"
 
 #: fortran/openmp.c:1026
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected %<data%>"
+#, gcc-internal-format, gfc-internal-format
 msgid "Comma expected at %C"
-msgstr "мало бути %<data%>"
+msgstr "Мало бути використано кому у %C"
 
 #: fortran/openmp.c:1138
 #, gcc-internal-format, gfc-internal-format
@@ -66890,10 +66740,9 @@ msgid "Sorry, %qs clause at %L on REQUIRES directive is not yet supported"
 msgstr ""
 
 #: fortran/openmp.c:3910
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected %<data%>"
+#, gcc-internal-format, gfc-internal-format
 msgid "Clause expected at %C"
-msgstr "мало бути %<data%>"
+msgstr "Мало бути використано команду у %C"
 
 #: fortran/openmp.c:3916
 #, gcc-internal-format
@@ -66911,10 +66760,9 @@ msgid "Expected INCLUSIVE or EXCLUSIVE clause at %C"
 msgstr ""
 
 #: fortran/openmp.c:3951
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected constant at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP SCAN at %C"
-msgstr "Неочікувана стала у %C"
+msgstr ""
 
 #: fortran/openmp.c:4130
 #, gcc-internal-format, gfc-internal-format
@@ -66957,10 +66805,9 @@ msgid "!$OMP ATOMIC UPDATE at %L incompatible with ACQ_REL or ACQUIRE clauses"
 msgstr ""
 
 #: fortran/openmp.c:4349
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Junk after MAP statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$ACC ATOMIC statement at %C"
-msgstr "Зайві команди після інструкції MAP у %C"
+msgstr "Неочікувані зайві дані після інструкції !$ACC ATOMIC у %C"
 
 #: fortran/openmp.c:4364
 #, gcc-internal-format, gfc-internal-format
@@ -67067,8 +66914,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -67226,16 +67073,14 @@ msgid "Array is not contiguous at %L"
 msgstr ""
 
 #: fortran/openmp.c:5228
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected alternate return specifier in subroutine call at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected substring reference in %s clause at %L"
-msgstr "Неочікуваний специфікатор повернення з альтернативи у виклику підпрограми у %L"
+msgstr ""
 
 #: fortran/openmp.c:5236
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected alternate return specifier in subroutine call at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected complex-parts designator reference in %s clause at %L"
-msgstr "Неочікуваний специфікатор повернення з альтернативи у виклику підпрограми у %L"
+msgstr ""
 
 #: fortran/openmp.c:5245 fortran/openmp.c:5263
 #, gcc-internal-format
@@ -67369,10 +67214,9 @@ msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
 #: fortran/openmp.c:5735
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "value %qE of type %qT is not a constant expression"
+#, gcc-internal-format, gfc-internal-format
 msgid "Value of HINT clause at %L shall be a valid constant hint expression"
-msgstr "значення %qE типу %qT не є сталим виразом"
+msgstr ""
 
 #: fortran/openmp.c:5745
 #, gcc-internal-format, gfc-internal-format
@@ -69094,7 +68938,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -69209,7 +69053,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -69281,10 +69125,9 @@ msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
 #: fortran/resolve.c:3410
-#, fuzzy, gcc-internal-format
-#| msgid "builtin %qF is deprecated."
+#, gcc-internal-format
 msgid "Using function %qs at %L is deprecated"
-msgstr "вбудований %qF вважається застарілим."
+msgstr "Використання функції %qs у %L вважається застарілим"
 
 #: fortran/resolve.c:3426
 #, gcc-internal-format
@@ -69342,10 +69185,9 @@ msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
 #: fortran/resolve.c:3758
-#, fuzzy, gcc-internal-format
-#| msgid "builtin %qF is deprecated."
+#, gcc-internal-format
 msgid "Using subroutine %qs at %L is deprecated"
-msgstr "вбудований %qF вважається застарілим."
+msgstr "Використання підпрограми %qs у %L вважається застарілим"
 
 #: fortran/resolve.c:3785
 #, gcc-internal-format, gfc-internal-format
@@ -69367,212 +69209,212 @@ msgstr ""
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, gcc-internal-format, gfc-internal-format
 msgid "Equality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, gcc-internal-format, gfc-internal-format
 msgid "Inequality comparison for %s at %L"
 msgstr ""
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -69581,12 +69423,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -69595,294 +69437,293 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is deprecated"
+#: fortran/resolve.c:5950
+#, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
-msgstr "%qs вважається застарілим"
+msgstr "Використання змінної %qs у %L вважається застарілим"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -69891,284 +69732,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Похідний тип %qs не можна використовувати як змінну у %L"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -70176,193 +70017,192 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12266
-#, fuzzy, gcc-internal-format
-#| msgid "Unused parameter %qs declared at %L"
+#: fortran/resolve.c:12275
+#, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
-msgstr "Невикористаний параметр %qs, оголошено у %L"
+msgstr ""
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -70370,965 +70210,964 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument %qs of MODULO at %L shall not be zero"
+#: fortran/resolve.c:16393
+#, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
-msgstr "Аргументом %qs MODULO у %L має бути ненульове число"
+msgstr ""
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -72192,17 +72031,17 @@ msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -72293,107 +72132,107 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Невикористану змінну %qs оголошено у рядку %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Невикористаний параметр %qs, оголошено у %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Невикористаний параметр %qs, який було явно імпортовано у %L"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -72445,16 +72284,14 @@ msgid "optional class parameter"
 msgstr "необов'язковий параметр класу"
 
 #: fortran/trans-openmp.c:3033
-#, fuzzy, gcc-internal-format
-#| msgid "invalid expression as operand"
+#, gcc-internal-format
 msgid "unhandled expression type"
-msgstr "некоректний вираз операнда"
+msgstr "непридатний до обробки тип виразів"
 
 #: fortran/trans-openmp.c:3187
-#, fuzzy, gcc-internal-format
-#| msgid "bad expression"
+#, gcc-internal-format
 msgid "unhandled expression"
-msgstr "помилковий вираз"
+msgstr "непридатний до обробки вираз"
 
 #: fortran/trans-openmp.c:6039
 #, gcc-internal-format
@@ -72546,7 +72383,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr ""
@@ -72619,7 +72456,7 @@ msgstr ""
 #: lto/lto-common.c:2263
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
-msgstr ""
+msgstr "не вдалося прочитати %<LTO_section_decls%> з %s"
 
 #: lto/lto-common.c:2384
 #, gcc-internal-format, gfc-internal-format
@@ -72673,7 +72510,7 @@ msgstr ""
 
 #: lto/lto-lang.c:898
 #, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr ""
 
 #: lto/lto-object.c:107
@@ -72749,7 +72586,7 @@ msgstr ""
 #: lto/lto-symtab.c:757
 #, gcc-internal-format
 msgid "%qD was previously declared here"
-msgstr ""
+msgstr "%qD було раніше оголошено тут:"
 
 #: lto/lto-symtab.c:760
 #, gcc-internal-format
@@ -72764,12 +72601,12 @@ msgstr ""
 #: lto/lto-symtab.c:853
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
-msgstr ""
+msgstr "функцію %qD повторно оголошено як змінну"
 
 #: lto/lto-symtab.c:865
 #, gcc-internal-format
 msgid "previously declared here"
-msgstr ""
+msgstr "раніше оголошено тут:"
 
 #: lto/lto.c:167
 #, gcc-internal-format
@@ -72920,34 +72757,29 @@ msgid "multiple property %qE methods specified, the latest one will be used"
 msgstr ""
 
 #: objc/objc-act.c:916
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration"
+#, gcc-internal-format
 msgid "previous specification"
-msgstr "попереднє оголошення"
+msgstr "попередня специфікація"
 
 #: objc/objc-act.c:931
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument value %qE is negative"
+#, gcc-internal-format
 msgid "%qE attribute conflicts with %qE attribute"
-msgstr "значення аргументу атрибута %qE, %qE, від'ємним"
+msgstr ""
 
 #: objc/objc-act.c:933
-#, fuzzy, gcc-internal-format
-#| msgid "%qD defined here"
+#, gcc-internal-format
 msgid "%qE specified here"
-msgstr "%qD визначено тут"
+msgstr "%qE вказано тут:"
 
 #: objc/objc-act.c:939
-#, fuzzy, gcc-internal-format
-#| msgid "duplicate %qD"
+#, gcc-internal-format
 msgid "duplicate %qE attribute"
-msgstr "дублювання %qD"
+msgstr "дублювання атрибута %qE"
 
 #: objc/objc-act.c:940
-#, fuzzy, gcc-internal-format
-#| msgid "defined here"
+#, gcc-internal-format
 msgid "first specified here"
-msgstr "визначено тут"
+msgstr "вперше визначено тут"
 
 #: objc/objc-act.c:967
 #, gcc-internal-format
@@ -72955,10 +72787,9 @@ msgid "%<readonly%> attribute conflicts with %<setter%> attribute"
 msgstr ""
 
 #: objc/objc-act.c:970
-#, fuzzy, gcc-internal-format
-#| msgid "%<-I-%> specified twice"
+#, gcc-internal-format
 msgid "%<setter%> specified here"
-msgstr "%<-I-%> вказано двічі"
+msgstr "%<setter%> вказано тут:"
 
 #: objc/objc-act.c:1049
 #, gcc-internal-format
@@ -73780,7 +73611,7 @@ msgstr ""
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr ""
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr ""
@@ -73798,15 +73629,15 @@ msgstr ""
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr ""
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr ""
@@ -73837,29 +73668,26 @@ msgid "%<-fhandle-exceptions%> has been renamed %<-fexceptions%> (and is now on
 msgstr ""
 
 #: c-family/c.opt:1728
-#, fuzzy, gcc-internal-format
-#| msgid "missing number"
+#, gcc-internal-format
 msgid "missing mapper"
-msgstr "не вказано числа"
+msgstr "пропущено засіб прив'язки"
 
 #: c-family/c.opt:1752
-#, fuzzy, gcc-internal-format
-#| msgid "missing number"
+#, gcc-internal-format
 msgid "missing header name"
-msgstr "не вказано числа"
+msgstr "пропущено назву заголовка"
 
 #: c-family/c.opt:1760
-#, fuzzy, gcc-internal-format
-#| msgid "missing number"
+#, gcc-internal-format
 msgid "missing module name"
-msgstr "не вказано числа"
+msgstr "пропущено назву модуля"
 
 #: c-family/c.opt:1807
 #, gcc-internal-format
 msgid "unrecognized ivar visibility value %qs"
 msgstr ""
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr ""
@@ -73892,7 +73720,7 @@ msgstr ""
 #: config/avr/avr.opt:26
 #, gcc-internal-format
 msgid "missing device or architecture after %qs"
-msgstr ""
+msgstr "пропущено пристрій або архітектуру після %qs"
 
 #: config/rs6000/rs6000.opt:316
 #, gcc-internal-format
@@ -73907,12 +73735,12 @@ msgstr "%<-mvrsave=yes%> є застарілим, замість нього сл
 #: config/rs6000/rs6000.opt:387
 #, gcc-internal-format
 msgid "using darwin64 ABI"
-msgstr ""
+msgstr "використовуємо двійковий інтерфейс darwin64"
 
 #: config/rs6000/rs6000.opt:390
 #, gcc-internal-format
 msgid "using old darwin ABI"
-msgstr ""
+msgstr "використовуємо старий двійковий інтерфейс darwin"
 
 #: config/fused-madd.opt:22
 #, gcc-internal-format
@@ -73942,101 +73770,100 @@ msgstr "%qs вважається застарілим"
 msgid "unknown linker output %qs"
 msgstr ""
 
-#: common.opt:1502
+#: common.opt:1506
 #, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr ""
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr ""
 
-#: common.opt:1902
+#: common.opt:1906
 #, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "невідома область IRA %qs"
 
-#: common.opt:1980
+#: common.opt:1984
 #, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "невідома модель поділу LTO %qs"
 
-#: common.opt:2082
+#: common.opt:2086
 #, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "пропущено параметри або цілі після %qs"
 
-#: common.opt:2090
+#: common.opt:2094
 #, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 #, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr ""
 
-#: common.opt:2248
+#: common.opt:2252
 #, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "невідомий метод оновлення профілю %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr "невідомий рівень інтерактивного латання, %qs"
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "невідомий алгоритм переупорядковування базових блоків %qs"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "невідома модель TLS %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "невідоме значення видимості %qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
 
 #: params.opt:134
-#, fuzzy, gcc-internal-format
-#| msgid "unknown TLS model %qs"
+#, gcc-internal-format
 msgid "unknown evrp mode %qs"
-msgstr "невідома модель TLS %qs"
+msgstr "невідомий режим evrp %qs"
 
 #~ msgid ""
 #~ "This is free software; see the source for copying conditions.\n"
diff --git a/gcc/po/vi.po b/gcc/po/vi.po
index 412bb7484713b..18d14bff2617d 100644
--- a/gcc/po/vi.po
+++ b/gcc/po/vi.po
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 7.1-b20170101\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2017-01-08 08:33+0700\n"
 "Last-Translator: Trần Ngọc Quân <vnwildman@gmail.com>\n"
 "Language-Team: Vietnamese <translation-team-vi@lists.sourceforge.net>\n"
@@ -1300,13 +1300,13 @@ msgstr "    trực tiếp từ %qs"
 msgid "this is the insn:"
 msgstr "đây là lệnh:"
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "không thể tạo ra việc nạp lại cho:"
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "không thể tạo ra việc nạp lại cho:"
 
@@ -1484,18 +1484,18 @@ msgstr "không nhận ra lệnh:"
 msgid "insn does not satisfy its constraints:"
 msgstr "lệnh không thỏa những ràng buộc của nó:"
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "được tạo và sử dụng với cài đặt khác nhau của “%s”"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "được tạo và sử dụng với cài đặt khác nhau của -fpic"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1535,7 +1535,7 @@ msgstr "%s%swarning: phiên bản phần đầu %s %s vẫn khác với phiên b
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC tìm ra: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1985,93 +1985,93 @@ msgstr "đồ sửa đổi chiều dài theo định dạng strfmon"
 msgid "<command-line>"
 msgstr "<dòng lệnh>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "toán hạng không hợp lệ đối với “%%%c”"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "hằng không hợp lệ"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "toán hạn dấu chấm động / thanh ghi véctơ không tương thích cho “%%%c”"
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 #| msgid "incompatible floating point / vector register operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "toán hạn dấu chấm động / thanh ghi véctơ không tương thích cho “%%%c”"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "toán hạng còn thiếu"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "hằng không hợp lệ"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "toán hạng không hợp lệ"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "tiền tố toán hạng không hợp lệ “%%%c”"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "sai đặt chế độ đặt địa chỉ"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "toán hạng không hợp lệ trong phép toán nhị phân"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "“%%&” bị sử dụng mà không có tham chiếu TLS năng động cục bộ"
@@ -2087,18 +2087,18 @@ msgid "invalid %%r value"
 msgstr "giá trị %%r sai"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "giá trị %%R sai"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "giá trị %%N sai"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "giá trị %%P sai"
@@ -2128,7 +2128,7 @@ msgstr "giá trị %%M sai"
 msgid "invalid %%U value"
 msgstr "giá trị %%U sai"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "giá trị %%s sai"
@@ -2138,7 +2138,7 @@ msgstr "giá trị %%s sai"
 msgid "invalid %%C value"
 msgstr "giá trị %%C sai"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "giá trị %%E sai"
@@ -2151,7 +2151,7 @@ msgstr "không rõ bỏ ghi rõ bố trí lại"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "mã %%xn sai"
@@ -2234,35 +2234,35 @@ msgstr "UNSPEC không hợp lệ như là toán hạng: %d"
 msgid "unrecognized supposed constant"
 msgstr "không nhận ra điều nên là hằng số"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "sai đặt toán hạng dời"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "lệnh Thumb căn cứ vào"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "gặp lệnh căn cứ vào trong dãy có điều kiện"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2270,13 +2270,13 @@ msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 msgid "invalid operand for code '%c'"
 msgstr "sai đặt toán hạng cho mã “%c”"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "lệnh chưa bao giờ thực hiện"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "định dạng mã Maverick đã cũ “%c”"
@@ -2410,8 +2410,8 @@ msgstr "gặp toán hạng bất thường"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2784,7 +2784,7 @@ msgstr "thao tác sai %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "gặp toán hạng %%P sai"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "gặp giá trị %%p sai"
@@ -2838,7 +2838,7 @@ msgid "post-increment address is not a register"
 msgstr "địa chỉ hậu gia không phải là một thanh ghi"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "địa chỉ sai"
 
@@ -2890,8 +2890,8 @@ msgstr "“%%%c” không phải là một tiền tố toán hạng đúng"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "sai sử dụng “%%%c”"
@@ -3037,324 +3037,324 @@ msgstr "Không đủ sức chứa trong ngăn xếp.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Hãy thử chạy “%s” trong trình bao để tăng giới hạn.\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 #| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx yêu cầu dấu chấm động loại phần cứng"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 #| msgid "-mvsx needs indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "-mvsx yêu cầu đặt địa chỉ một cách phụ lục"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx và -mno-altivec không tương thích với nhau"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 #, fuzzy
 #| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec thì tắt vsx"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "-mquad-memory yêu cầu chế độ 64-bit"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 #, fuzzy
 #| msgid "-mquad-memory-atomic requires 64-bit mode"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "-mquad-memory-atomic cần chế độ 64-bit"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 #, fuzzy
 #| msgid "-mquad-memory is not available in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "-mquad-memory không sẵn sàng trên chế độ little endian"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr "sai di chuyển"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr "Di chuyển 128-bit sai"
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "giá trị %%D sai"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, c-format
 msgid "invalid %%e value"
 msgstr "giá trị %%e sai"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "giá trị %%f sai"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "giá trị %%F sai"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "giá trị %%G sai"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "mã %%j sai"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "mã %%J sai"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "giá trị %%k sai"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "giá trị %%K sai"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "giá trị %%O sai"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "giá trị %%q sai"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "giá trị %%T sai"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "giá trị %%u sai"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "giá trị %%v sai"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "giá trị %%x sai"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "giá trị %%y sai, hãy thử sử dụng ràng buộc “Z”"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 #, fuzzy
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Bật sử dụng câu lệnh dấu số thực chấm động 128-bit IEEE."
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "đối số AltiVec bị gửi cho hàm không nguyên mẫu"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 msgid "Could not generate addis value for fusion"
 msgstr "Không thể tạo addis cho sát nhập"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Không thể tạo ra việc tải/lưu offset cho hợp nhất"
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr "Hợp nhất GPR sai"
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "không thể giải mã địa chỉ"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "hằng không hợp lệ cho bổ nghĩa kết xuất “%c”"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "hằng không hợp lệ - hãy thử dùng bổ nghĩa kết xuất"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "véc-tơ hằng không hợp lệ cho bổ nghĩa kết xuất “%c”"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "biểu thức không hợp lệ - hãy thử dùng bổ nghĩa kết xuất"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "biểu thức không hợp lệ cho bộ sửa đầu ra “%c”"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 #| msgid "Vector argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "Đối số véc-tơ bị gửi cho hàm không nguyên mẫu"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3617,8 +3617,8 @@ msgstr "({nặc danh})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "cần %<;%>"
@@ -3638,7 +3638,7 @@ msgstr "cần %<;%>"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "cần %<)%>"
@@ -3646,7 +3646,7 @@ msgstr "cần %<)%>"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "cần %<]%>"
@@ -3664,21 +3664,21 @@ msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "cần %<(%>"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "cần %<[%>"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "cần %<{%>"
@@ -3689,13 +3689,13 @@ msgstr "cần %<{%>"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "cần %<:%>"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "cần %<while%>"
@@ -3704,7 +3704,7 @@ msgstr "cần %<while%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "cần %<,%>"
@@ -3713,18 +3713,18 @@ msgstr "cần %<,%>"
 msgid "expected %<.%>"
 msgstr "cần %<.%>"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "cần %<@end%>"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "cần %<>%>"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "cần %<,%> hoặc %<)%>"
@@ -3732,28 +3732,28 @@ msgstr "cần %<,%> hoặc %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "cần %<=%>"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "cần %<}%>"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "cần %<#pragma omp section%> hoặc %<}%>"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(nặc danh)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "cần %<<%>"
@@ -3770,30 +3770,30 @@ msgstr "cần kênh"
 msgid "candidate:"
 msgstr "ứng cử 1:"
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 #| msgid "Enable user-defined instructions."
 msgid "  after user-defined conversion:"
 msgstr "Bật câu lệnh được người dùng xác định."
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ứng cử là:"
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "ứng cử 1:"
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "ứng cử 2:"
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "nhảy tới nhãn %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "nhảy tới nhãn lệnh case"
 
@@ -4020,33 +4020,33 @@ msgstr "%<this%> có lẽ không nên được dùng trong ngữ cảnh này"
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 #, fuzzy
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 msgid "%<using enum%> of dependent type %qT"
 msgstr ""
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 #| msgid "%qT is not an enumeration type"
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%qT không phải một kiểu enumeration"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 #| msgid "increment of pointer to an incomplete type %qT"
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "tăng con trỏ tới loại không hoàn toàn %qT"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "các ứng cử là:"
 
@@ -4090,48 +4090,48 @@ msgstr "việc chuyển đổi cũng bỏ trình trạng bất biến"
 msgid "source type is not polymorphic"
 msgstr "nguồn không có loại nhiều dạng"
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "đối số có loại sai đối với dấu trừ nguyên phân"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "đối số có loại sai đối với dấu cộng nguyên phân"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "đối số có loại sai đối với phần bù bit"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "đối số có loại sai đối với bộ tuyệt đối"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "đối số có loại sai đối với phần chia"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr "trong đối số tới bộ nguyên phân !"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr "không có toán tử tiền gia cho loại"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr "không có toán tử hậu gia cho loại"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr "không có toán tử giảm gia cho loại"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr "không có toán tử hậu giảm cho loại"
 
@@ -4234,7 +4234,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Đang điều khiển:"
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "tham số thực tế cho INTENT = OUT/INOUT"
 
@@ -4372,7 +4372,7 @@ msgstr "Toán tử sai"
 msgid "Bad type in constant expression"
 msgstr "Gặp loại saio trong biểu thức bất biến"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "Gặp kết thức mô-đun bất thường"
 
@@ -4400,11 +4400,11 @@ msgstr "IF (nếu) loại khối"
 msgid "implied END DO"
 msgstr "ngụ ý END DO (kết thúc làm)"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "sự gán"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "sự gán hàm trỏ"
 
@@ -4490,156 +4490,156 @@ msgstr ""
 msgid "bind(c) procedure"
 msgstr "thủ tục bind(c)"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Gặp ngữ cảnh sai cho hàm trỏ NULL() tại %%L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Tại %%L có một toán tử thuộc số nguyên phân “%s” với toán hạng %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Tại %%L có một toán tử thuộc số nhị phân “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử thuộc số nhị phân “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử ghép nối chuỗi với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử hợp lý “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Tại %%L có một toán tử .not. với toán hạng %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Không thể so sánh các số lượng PHỨC TẠP tại %L"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Tại %%L thì các bộ hợp lý phải được so sánh với %s thay cho %s"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử so sánh “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, fuzzy, c-format
 #| msgid "Unknown operator %%<%s%%> at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Không rõ toán tử %%<%s%%> tại %%L"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Không rõ toán tử %%<%s%%> tại %%L"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Các toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tại %%L và %%L có một toán tử với các phân hàng mâu thuẫn nhau"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr "Biến vòng lặp"
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 msgid "iterator variable"
 msgstr "biến iterator"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr "Biểu thức bắt đầu trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr "Biểu thức kết thúc trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr "Biểu thức bước trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 msgid "DEALLOCATE object"
 msgstr "đối tượng DEALLOCATE"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 msgid "ALLOCATE object"
 msgstr "đối tượng ALLOCATE"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 msgid "STAT variable"
 msgstr "biến STAT"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 msgid "ERRMSG variable"
 msgstr "Biến ERRMSG"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 msgid "item in READ"
 msgstr "mục tin trong READ"
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 msgid "ACQUIRED_LOCK variable"
 msgstr "biến ACQUIRED_LOCK"
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Bộ dựng mảng chứa các chiều dài KÝ_TỰ khác nhau (%ld/%ld)"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Chiều dài chuỗi thật không tương ứng với điều khai báo cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Chiều dài chuỗi thật vẫn nhỏ hơn điều khai báo cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr "Gán vô hướng cho mảng chưa cấp phát"
 
@@ -4766,27 +4766,27 @@ msgstr "Tham chiếu mảng ở ngoại phạm vi"
 msgid "Incorrect function return value"
 msgstr "Giá trị trả lại hàm không đúng"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 #| msgid "Memory allocation failed"
 msgid "Error allocating %lu bytes"
 msgstr "Lỗi cấp phát vùng nhớ"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "Đang cố cấp phát một biến đã được cấp phát rồi “%s”"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 msgid "Attempting to allocate already allocated variable"
 msgstr "Đang cố cấp phát một biến đã được cấp phát rồi"
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "Đang thử BỎ cấp phát một mảng đã bỏ cấp phát “%s”"
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -4989,15 +4989,15 @@ msgstr "hai tùy chọn -Xbind-now và -Xbind-lazy không tương thích với n
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr "sử dụng gprof(1) thì đề nghị bạn dùng \"-pg\" thay cho \"-p\""
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "không cho phép sử dụng đồng thời hai tùy chọn -EB và -EL"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-mfloat-abi=soft và -mfloat-abi=hard không được dùng cùng nhau"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "không cho phép sử dụng đồng thời hai tùy chọn -mbig-endian (về cuối lớn) và -mlittle-endian (về cuối nhỏ)"
 
@@ -5013,8 +5013,8 @@ msgstr "chưa ghi rõ loại bộ xử lý cần liên kết"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "không dùng đồng thời hai tùy chọn -march=… và -mcpu=…"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared và mdll không tương thích với nhau"
 
@@ -5184,10 +5184,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "Cảnh báo về sự tạo mục mảng tạm thời."
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Không làm gì. Giữ lại vì mục đích tương thích ngược."
@@ -5669,161 +5669,161 @@ msgstr "Đặt toàn bộ các mảng nội bộ vào stack."
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "Đặt thành PRIVATE (riêng) tình trạng truy cập của thực thể mô-đun."
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "Thử bố trí các loại có hướng một cách tóm gọn nhất có thể."
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "Bảo vệ dấu ngoặc đơn trong biểu thức."
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, no-c-format
 msgid "Enable range checking during compilation."
 msgstr "Bật chức năng kiểm tra phạm vi trong khi biên dịch."
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr "Biên dịch bất kỳ REAL(4) như là REAL(8)."
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr "Biên dịch bất kỳ REAL(4) như là REAL(10)."
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr "Biên dịch bất kỳ REAL(4) như là REAL(16)."
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr "Biên dịch bất kỳ REAL(8) như là REAL(4)."
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr "Biên dịch bất kỳ REAL(8) như là REAL(10)."
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr "Biên dịch bất kỳ REAL(8) như là REAL(16)."
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr "Tái cấp phát được LHS trong phép gán."
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "Có tập tin chưa định dạng thì sử dụng một ký hiệu đánh dấu mục ghi loại 4 byte."
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "Có tập tin chưa định dạng thì sử dụng một ký hiệu đánh dấu mục ghi loại 8 byte."
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr "Cấp phát các biến cúc bộ trên ngăn xếp để cho phép đệ quy một cách gián tiếp."
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "Vào thủ tục thì cũng sao chép các phần mảng vào một khối kề nhau."
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr "-fcoarray=<none|single|lib>\tChỉ định đồng mảng song song nào nên được dùng."
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr "-fcheck=[…]\tGhi rõ có nên thực hiện những hàm kiểm tra lúc chạy nào."
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, no-c-format
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "Tên đã chứa một dấu gạch dưới thì phụ thêm một dấu gạch dưới bổ sung."
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr "Có giá trị số không thì áp dụng ký hiệu trừ."
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, no-c-format
 msgid "Append underscores to externally visible names."
 msgstr "Có tên hiển thị bên ngoài thì phụ thêm dấu gạch dưới."
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Không làm gì. Dành cho mục đích tương thích ngược."
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr "Liên kết tĩnh thư viện bổ trợ Fortran của GNU (libgfortran)."
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, no-c-format
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "Làm cho hợp với tiêu chuẩn ISO Fortran 2003."
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "Làm cho hợp với tiêu chuẩn ISO Fortran 2008."
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "Làm cho hợp với tiêu chuẩn ISO Fortran 2008 bao gồm TS 29113."
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2008 standard."
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Làm cho hợp với tiêu chuẩn ISO Fortran 2008."
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, no-c-format
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "Làm cho hợp với tiêu chuẩn ISO Fortran 95."
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, no-c-format
 msgid "Conform to nothing in particular."
 msgstr "Làm cho hợp với không gì đặc biệt."
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, no-c-format
 msgid "Accept extensions to support legacy code."
 msgstr "Chấp nhận phần mở rộng để hỗ trợ mã nguồn cũ."
@@ -6528,7 +6528,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7156,8 +7156,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr ""
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr "không còn được hỗ trợ nữa."
@@ -7519,480 +7519,475 @@ msgstr ""
 
 #: c-family/c.opt:1878
 #, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
-#, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr ""
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "Bật chỉ thị OpenMP's SIMD."
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr ""
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, no-c-format
 msgid "Look for and use PCH files even when preprocessing."
 msgstr ""
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, no-c-format
 msgid "Downgrade conformance errors to warnings."
 msgstr ""
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr ""
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, no-c-format
 msgid "Treat the input file as already preprocessed."
 msgstr ""
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr ""
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr ""
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, no-c-format
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr ""
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 #| msgid "Deprecated.  This switch has no effect."
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "Đã lỗi thời. Tùy chọn này không có tác dụng gì."
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, no-c-format
 msgid "Generate run time type descriptor information."
 msgstr ""
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, no-c-format
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr ""
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, no-c-format
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr ""
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr ""
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, no-c-format
 msgid "Make \"char\" signed by default."
 msgstr "Làm cho \"char\" là có dấu theo mặc định."
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr ""
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, fuzzy, no-c-format
 #| msgid "-fsso-struct=[big-endian|little-endian]\tSet the default scalar storage order."
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr "-fsso-struct=[big-endian|little-endian]\tĐặt thứ tự lưu trữ vô hướng mặc định."
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, no-c-format
 msgid "Display statistics accumulated during compilation."
 msgstr ""
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr ""
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr ""
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr ""
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr ""
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, no-c-format
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr ""
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "Làm cho \"char\" là không dấu theo mặc định."
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, no-c-format
 msgid "Use __cxa_atexit to register destructors."
 msgstr ""
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr ""
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr ""
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr ""
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, no-c-format
 msgid "Emit common-like symbols as weak symbols."
 msgstr ""
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-fwide-exec-charset=<cset>\tChuyển đổi mọi chuỗi rộng và hằng ký tự rộng ra bộ mã <cset>."
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr ""
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr ""
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, no-c-format
 msgid "Dump declarations to a .decl file."
 msgstr ""
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr ""
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <thư_mục>\tPhụ thêm thư mục này vào đường dẫn bao gồm hệ thống."
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr ""
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr ""
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr ""
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr ""
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <thư_mục>\tĐặt <thư_mục> này vào đường dẫn gốc hệ thống."
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <thư_mục>\tThêm <thư_mục> này vào đầu đường dẫn bao gồm hệ thống."
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-iframework <thư_mục>\tPhụ thêm thư mục này vào đường dẫn bao gồm khuôn khổ hệ thống"
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <thư_mục>\tPhụ thêm thư mục này vào đường dẫn bao gồm hệ thống."
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <thư_mục>\tPhụ thêm thư mục này vào đường dẫn bao gồm chính."
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, no-c-format
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr ""
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, no-c-format
 msgid "Do not search standard system include directories for C++."
 msgstr ""
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, no-c-format
 msgid "Generate C header of platform-specific features."
 msgstr ""
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, no-c-format
 msgid "Remap file names when including files."
 msgstr ""
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "Làm cho hợp với chuẩn ISO 1998 C++ xem xét lại đính chính kỹ thuật năm 2003."
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "Làm cho hợp với chuẩn ISO 2011 C++."
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "Đã lạc hậu và được thay thế bằng -std=c++11."
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "Đã lạc hậu và được thay thế bằng -std=c++14."
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "Làm cho hợp với chuẩn ISO 2014 C++."
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c++11."
 msgid "Deprecated in favor of -std=c++17."
 msgstr "Đã lạc hậu và được thay thế bằng -std=c++11."
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C++ standard."
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "Làm cho hợp với chuẩn ISO 2011 C++."
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2017(?) C++ draft standard (experimental and incomplete support)."
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "Làm cho hợp với chuẩn nháp ISO 2017(?) C++ (thử nghiệm và hỗ trợ chưa đầy đủ)."
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2017(?) C++ draft standard (experimental and incomplete support)."
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "Làm cho hợp với chuẩn nháp ISO 2017(?) C++ (thử nghiệm và hỗ trợ chưa đầy đủ)."
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard."
 msgstr "Làm cho hợp với chuẩn ISO 2011 C++."
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "Đã lạc hậu và được thay thế bằng -std=c11."
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard."
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Làm cho hợp với chuẩn ISO 2011 C++."
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2017(?) C++ draft standard (experimental and incomplete support)."
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "Làm cho hợp với chuẩn nháp ISO 2017(?) C++ (thử nghiệm và hỗ trợ chưa đầy đủ)."
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard."
 msgstr "Làm cho hợp với chuẩn ISO 1990 C."
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard."
 msgstr "Làm cho hợp với chuẩn ISO 1999 C."
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, no-c-format
 msgid "Deprecated in favor of -std=c99."
 msgstr "Đã lạc hậu và được thay thế bằng -std=c99."
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "Làm cho hợp với chuẩn ISO 1998 C++ xem xét lại đính chính kỹ thuật năm 2003."
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, no-c-format
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "Làm cho hợp với chuẩn ISO 2011 C++ với phần mở rộng GNU."
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "Đã lạc hậu và được thay thế bằng -std=gnu++11."
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "Đã lạc hậu và được thay thế bằng -std=gnu++14."
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, no-c-format
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "Làm cho hợp với chuẩn ISO 2014 C++ với phần mở rộng GNU."
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu++11."
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "Đã lạc hậu và được thay thế bằng -std=gnu++11."
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "Làm cho hợp với chuẩn ISO 2011 C++ với phần mở rộng GNU."
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 201z(7?) C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "Làm cho hợp với chuẩn nháp ISO 201z(7?) C++ có phần mở rộng GNU (thử nghiệm và hỗ trợ chưa đầy đủ)."
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 201z(7?) C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "Làm cho hợp với chuẩn nháp ISO 201z(7?) C++ có phần mở rộng GNU (thử nghiệm và hỗ trợ chưa đầy đủ)."
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, no-c-format
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "Làm cho hợp với chuẩn ISO 2011 C với phần mở rộng GNU."
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "Đã lạc hậu và được thay thế bằng -std=gnu11."
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "Làm cho hợp với chuẩn ISO 2011 C với phần mở rộng GNU."
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 201z(7?) C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "Làm cho hợp với chuẩn nháp ISO 201z(7?) C++ có phần mở rộng GNU (thử nghiệm và hỗ trợ chưa đầy đủ)."
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "Làm cho hợp với chuẩn ISO 1990 C với phần mở rộng GNU."
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, no-c-format
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "Làm cho hợp với chuẩn ISO 1999 C với phần mở rộng GNU."
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "Đã lạc hậu và được thay thế bằng -std=gnu99."
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, no-c-format
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "Làm cho hợp với chuẩn ISO 1990 C như sửa đổi trong 1994."
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, no-c-format
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "Đã lạc hậu và được thay thế bằng -std=iso9899:1999."
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "Bật tiền xử lý theo kiểu cổ điển."
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\tHỗ trợ bộ ba ISO C."
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, no-c-format
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr ""
@@ -8254,6 +8249,11 @@ msgstr ""
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr ""
+
 #: d/lang.opt:346
 #, no-c-format
 msgid "Do not link the standard D library in the compilation."
@@ -9513,154 +9513,166 @@ msgstr "Hỗ trợ nhiều hơn 8192 mục nhập GOT trên ColdFire."
 msgid "Support TLS segment larger than 64K."
 msgstr "Hỗ trợ đoạn TLS lớn hơn 64K."
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr "Coi là CPU đích được cấu hình về cuối lớn."
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr "Coi là CPU đích được cấu hình về cuối nhỏ."
+
+#: config/riscv/riscv.opt:34
 #, fuzzy, no-c-format
 #| msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions."
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "-mbranch-cost=GIÁ\tĐặt giá của nhánh thành khoảng số các câu lệnh này."
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, fuzzy, no-c-format
 #| msgid "When generating -mabicalls code, allow executables to use PLTs and copy relocations."
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr "Khi tạo ra mã -mabicalls thì cho phép tập tin thực thi sử dụng PLT và sao chép sự định vị lại."
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 #| msgid "Specify the name of the target floating point configuration."
 msgid "Specify integer and floating-point calling convention."
 msgstr "Chỉ ra tên của cấu hình dấu chấm động đích."
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, no-c-format
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "Thử bảo tồn ngăn xếp được xếp hàng theo lũy thừa 2 này."
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, fuzzy, no-c-format
 #| msgid "Known ABIs (for use with the -mabi= option):"
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "Chưa biết ABIs (để dùng với tùy chọn -mabi=):"
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 #| msgid "Use hardware floating point square root instruction."
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "Dùng chỉ lệnh bình phương chấm động bằng phần cứng."
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 #| msgid "Use trap instructions to check for integer divide by zero."
 msgid "Use hardware instructions for integer division."
 msgstr "Sử dụng câu lệnh bẫy để kiểm tra có số nguyên chia cho số không."
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=BỘ_XỬ_LÝ\tTối ưu hóa kết xuất cho bộ xử lý này."
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 #| msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "-mtune=BỘ_XỬ_LÝ\tTối ưu hóa kết xuất cho bộ xử lý này."
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr ""
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues."
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "Sử dụng chương trình con cho đoạn mở/đóng hàm."
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, no-c-format
 msgid "Specify the code model."
 msgstr "Chỉ định mô hình mã."
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 #| msgid "Do not use unaligned memory references."
 msgid "Do not generate unaligned memory accesses."
 msgstr "Đừng sử dụng tham chiếu vùng nhớ tạm chưa xếp hàng."
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr "Không hiểu mô hinh mã (để dùng với tùy chọn -mcmodel=):"
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, no-c-format
 msgid "Use the given data alignment."
 msgstr "Dùng xếp hàng dữ liệu đã cho."
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr "Không hiểu lựa chọn cân chỉnh dữ liệu (để dùng với tùy chọn -malign-data=):"
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, fuzzy, no-c-format
 #| msgid "Valid arguments to -mfloat-gprs=:"
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Đối số hợp lệ cho -mfloat-gprs=:"
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, fuzzy, no-c-format
 #| msgid "Known C6X ISAs (for use with the -march= option):"
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "Không hiểu C6X ISAs (để dùng với tùy chọn -march=):"
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr ""
@@ -9795,12 +9807,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, no-c-format
-msgid "Assume target CPU is configured as big endian."
-msgstr "Coi là CPU đích được cấu hình về cuối lớn."
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -9822,12 +9828,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, no-c-format
-msgid "Assume target CPU is configured as little endian."
-msgstr "Coi là CPU đích được cấu hình về cuối nhỏ."
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -17201,2179 +17201,2179 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, no-c-format
 msgid "Align the start of functions."
 msgstr "Chỉnh đầu của hàm."
 
-#: common.opt:988
+#: common.opt:992
 #, no-c-format
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:995
+#: common.opt:999
 #, no-c-format
 msgid "Align all labels."
 msgstr "Cân chỉnh tất cả các nhãn."
 
-#: common.opt:1002
+#: common.opt:1006
 #, no-c-format
 msgid "Align the start of loops."
 msgstr "Chỉnh đầu của vòng lặp."
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing."
 msgid "Enable static analysis pass."
 msgstr "Bật tiền xử lý theo kiểu cổ điển."
 
-#: common.opt:1033
+#: common.opt:1037
 #, no-c-format
 msgid "Select what to sanitize."
 msgstr "Chọn cái gì để cải thiện."
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy, no-c-format
 #| msgid "Select what to sanitize."
 msgid "Select type of coverage sanitization."
 msgstr "Chọn cái gì để cải thiện."
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Cái chuyển này đã lạc hậu: hãy thay thế bằng -fsanitize-recover=."
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, no-c-format
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1069
+#: common.opt:1073
 #, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "Tạo ra câu lệnh auto-inc/dec."
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, no-c-format
 msgid "Generate code to check bounds before indexing arrays."
 msgstr ""
 
-#: common.opt:1091
+#: common.opt:1095
 #, no-c-format
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1095
+#: common.opt:1099
 #, no-c-format
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 #| msgid "Emit call graph information."
 msgid "Output callgraph information on a per-file basis."
 msgstr "Xuất thông tin về đồ thị gọi."
 
-#: common.opt:1115
+#: common.opt:1119
 #, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr ""
 
-#: common.opt:1119
+#: common.opt:1123
 #, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1123
+#: common.opt:1127
 #, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 #, no-c-format
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, no-c-format
 msgid "This switch is deprecated; do not use."
 msgstr "Cái chuyển này đã lạc hậu: đừng dùng."
 
-#: common.opt:1138
+#: common.opt:1142
 #, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "Kiểm tra giá trị trả về của new trong C++."
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, no-c-format
 msgid "Perform internal consistency checkings."
 msgstr ""
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 msgid "Enable code hoisting."
 msgstr "Bật khả năng tiền xử lý."
 
-#: common.opt:1154
+#: common.opt:1158
 #, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 #| msgid "%qD is used uninitialized in this function"
 msgid "Put uninitialized globals in the common section."
 msgstr "%qD được dùng để bỏ khởi tạo trong hàm này"
 
-#: common.opt:1166
+#: common.opt:1170
 #, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 #, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "Chỉ chạy biên dịch lần hai của tùy chọn -fcompare-debug."
 
-#: common.opt:1174
+#: common.opt:1178
 #, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 #, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 #, no-c-format
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 #, no-c-format
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1190
+#: common.opt:1194
 #, no-c-format
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1198
+#: common.opt:1202
 #, no-c-format
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1202
+#: common.opt:1206
 #, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1206
+#: common.opt:1210
 #, no-c-format
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1214
+#: common.opt:1218
 #, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1218
+#: common.opt:1222
 #, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1222
+#: common.opt:1226
 #, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1232
+#: common.opt:1236
 #, no-c-format
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1236
+#: common.opt:1240
 #, no-c-format
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, no-c-format
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1256
+#: common.opt:1260
 #, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1260
+#: common.opt:1264
 #, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr ""
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, fuzzy, no-c-format
 #| msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<pass>=vùng1+vùng2 tắt chuyển qua tối ưu hóa."
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, no-c-format
 #| msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<pass>=vùng1+vùng2 bật chuyển qua tối ưu hóa."
 
-#: common.opt:1423
+#: common.opt:1427
 #, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1430
+#: common.opt:1434
 #, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1434
+#: common.opt:1438
 #, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1438
+#: common.opt:1442
 #, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, no-c-format
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1455
+#: common.opt:1459
 #, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1459
+#: common.opt:1463
 #, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1467
+#: common.opt:1471
 #, no-c-format
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1475
+#: common.opt:1479
 #, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1479
+#: common.opt:1483
 #, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1483
+#: common.opt:1487
 #, no-c-format
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 #, no-c-format
 msgid "Enable exception handling."
 msgstr "Bật tiếp nhận ngoại lệ."
 
-#: common.opt:1495
+#: common.opt:1499
 #, no-c-format
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1499
+#: common.opt:1503
 #, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tChỉ định cách xử lý khi độ chính xác của dấu chấm động bị vượt quá."
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tChỉ định xem giá trị của FLT_EVAL_METHOD sẽ cho phép."
 
-#: common.opt:1530
+#: common.opt:1534
 #, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1534
+#: common.opt:1538
 #, no-c-format
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1546
+#: common.opt:1550
 #, no-c-format
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1554
+#: common.opt:1558
 #, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1558
+#: common.opt:1562
 #, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, no-c-format
 msgid "Allow function addresses to be held in registers."
 msgstr "Sử dụng địa chỉ hàm mà được giữ trong các thanh ghi."
 
-#: common.opt:1586
+#: common.opt:1590
 #, no-c-format
 msgid "Place each function into its own section."
 msgstr ""
 
-#: common.opt:1590
+#: common.opt:1594
 #, no-c-format
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1594
+#: common.opt:1598
 #, no-c-format
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1598
+#: common.opt:1602
 #, no-c-format
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1602
+#: common.opt:1606
 #, no-c-format
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1607
+#: common.opt:1611
 #, no-c-format
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1633
+#: common.opt:1637
 #, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1637
+#: common.opt:1641
 #, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, no-c-format
 msgid "Mark all loops as parallel."
 msgstr "Đánh dấu tất cả các vòng lặp là xử lý song song."
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 #| msgid "Enable clip instructions."
 msgid "Enable loop interchange on trees."
 msgstr "Bật các câu lệnh trích đoạn."
 
-#: common.opt:1667
+#: common.opt:1671
 #, no-c-format
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1671
+#: common.opt:1675
 #, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, no-c-format
 msgid "Enable the loop nest optimizer."
 msgstr "Bật sự tối ưu hóa vòng lặp lồng nhau."
 
-#: common.opt:1687
+#: common.opt:1691
 #, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, no-c-format
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1703
+#: common.opt:1707
 #, no-c-format
 msgid "Process #ident directives."
 msgstr ""
 
-#: common.opt:1707
+#: common.opt:1711
 #, no-c-format
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1711
+#: common.opt:1715
 #, no-c-format
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1743
+#: common.opt:1747
 #, no-c-format
 msgid "Do not generate .size directives."
 msgstr "Đừng tạo ra chỉ thị .size."
 
-#: common.opt:1747
+#: common.opt:1751
 #, no-c-format
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1757
 #, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1757
+#: common.opt:1761
 #, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1761
+#: common.opt:1765
 #, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1765
+#: common.opt:1769
 #, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1772
+#: common.opt:1776
 #, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1776
+#: common.opt:1780
 #, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1810
+#: common.opt:1814
 #, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1818
+#: common.opt:1822
 #, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1822
+#: common.opt:1826
 #, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1830
+#: common.opt:1834
 #, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1834
+#: common.opt:1838
 #, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 #, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 #, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, no-c-format
 msgid "Discover pure and const functions."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, no-c-format
 msgid "Discover read-only and non addressable static variables."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 #, no-c-format
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr ""
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, no-c-format
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1886
+#: common.opt:1890
 #, fuzzy, no-c-format
 #| msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm."
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority] Đặt dùng thuật toán IRA."
 
-#: common.opt:1899
+#: common.opt:1903
 #, fuzzy, no-c-format
 #| msgid "-fira-region=[one|all|mixed] Set regions for IRA."
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] Đặt vùng cho IRA."
 
-#: common.opt:1915
+#: common.opt:1919
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1920
+#: common.opt:1924
 #, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1937
+#: common.opt:1941
 #, no-c-format
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1941
+#: common.opt:1945
 #, no-c-format
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 #| msgid "type mismatch for case label in switch statement"
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "kiểu không khớp cho nhãn case trong câu lệnh switch"
 
-#: common.opt:1949
+#: common.opt:1953
 #, no-c-format
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Xuất hàm ngay cả khi chúng có thể chung dòng."
 
-#: common.opt:1953
+#: common.opt:1957
 #, no-c-format
 msgid "Generate code for static functions even if they are never called."
 msgstr "Xuất mã cho hàm tĩnh ngay cả khi chúng không bao giờ được gọi."
 
-#: common.opt:1957
+#: common.opt:1961
 #, no-c-format
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1961
+#: common.opt:1965
 #, no-c-format
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1977
+#: common.opt:1981
 #, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, fuzzy, no-c-format
 #| msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr "-flto-compression-level=<số>\tDùng mức nén zlib <số> cho IL."
 
-#: common.opt:2012
+#: common.opt:2016
 #, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:2016
+#: common.opt:2020
 #, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:2020
+#: common.opt:2024
 #, no-c-format
 msgid "Set errno after built-in math functions."
 msgstr ""
 
-#: common.opt:2024
+#: common.opt:2028
 #, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<số>\tSố lượng tối đa các lỗi cần thông báo."
 
-#: common.opt:2028
+#: common.opt:2032
 #, no-c-format
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:2032
+#: common.opt:2036
 #, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:2039
+#: common.opt:2043
 #, no-c-format
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 #, no-c-format
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 #, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:2051
+#: common.opt:2055
 #, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:2055
+#: common.opt:2059
 #, no-c-format
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:2059
+#: common.opt:2063
 #, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 #, no-c-format
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 #, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 #, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 #, no-c-format
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, no-c-format
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, no-c-format
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:2104
+#: common.opt:2108
 #, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<type>=tập-tin]\tĐổ chi tiết việc tối ưu hóa bộ dịch."
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, no-c-format
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:2124
+#: common.opt:2128
 #, no-c-format
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 #, no-c-format
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 #, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 #, no-c-format
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:2148
+#: common.opt:2152
 #, no-c-format
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:2152
+#: common.opt:2156
 #, no-c-format
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:2156
+#: common.opt:2160
 #, no-c-format
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:2160
+#: common.opt:2164
 #, no-c-format
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:2164
+#: common.opt:2168
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:2168
+#: common.opt:2172
 #, no-c-format
 msgid "Generate position-independent code if possible (small mode)."
 msgstr ""
 
-#: common.opt:2172
+#: common.opt:2176
 #, no-c-format
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, no-c-format
 msgid "Specify a plugin to load."
 msgstr "Chỉ định phần bổ sung cần nạp."
 
-#: common.opt:2184
+#: common.opt:2188
 #, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<tên>-<khóa>[=<giá trị>]\tChỉ định đối số <khóa>=<giá trị> cho plugin <tên>."
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2192
+#: common.opt:2196
 #, no-c-format
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2196
+#: common.opt:2200
 #, no-c-format
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2200
+#: common.opt:2204
 #, fuzzy, no-c-format
 #| msgid "Generate string instructions for block moves."
 msgid "Generate absolute source path names for gcov."
 msgstr "Tạo ra câu lệnh chuỗi để di chuyển khối."
 
-#: common.opt:2204
+#: common.opt:2208
 #, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2208
+#: common.opt:2212
 #, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr ""
 
-#: common.opt:2217
+#: common.opt:2221
 #, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2269
+#: common.opt:2273
 #, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2289
+#: common.opt:2293
 #, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2293
+#: common.opt:2297
 #, no-c-format
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2297
+#: common.opt:2301
 #, no-c-format
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2301
+#: common.opt:2305
 #, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 #| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "Tạo ra câu lệnh cld trong đoạn mở đầu hàm."
 
-#: common.opt:2312
+#: common.opt:2316
 #, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2326
+#: common.opt:2330
 #, no-c-format
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2368
+#: common.opt:2372
 #, no-c-format
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2372
+#: common.opt:2376
 #, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2376
+#: common.opt:2380
 #, no-c-format
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2397
+#: common.opt:2401
 #, no-c-format
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2401
+#: common.opt:2405
 #, no-c-format
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2409
+#: common.opt:2413
 #, no-c-format
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2413
+#: common.opt:2417
 #, no-c-format
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2417
+#: common.opt:2421
 #, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2421
+#: common.opt:2425
 #, no-c-format
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2425
+#: common.opt:2429
 #, no-c-format
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2429
+#: common.opt:2433
 #, no-c-format
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2433
+#: common.opt:2437
 #, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2437
+#: common.opt:2441
 #, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2445
+#: common.opt:2449
 #, no-c-format
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2449
+#: common.opt:2453
 #, no-c-format
 msgid "Reschedule instructions after register allocation."
 msgstr ""
 
-#: common.opt:2456
+#: common.opt:2460
 #, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2460
+#: common.opt:2464
 #, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2472
+#: common.opt:2476
 #, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2476
+#: common.opt:2480
 #, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2498
+#: common.opt:2502
 #, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 #, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2506
+#: common.opt:2510
 #, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 #, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2514
+#: common.opt:2518
 #, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 #, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2522
+#: common.opt:2526
 #, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 #, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 #, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 #, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 #, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, no-c-format
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2563
+#: common.opt:2567
 #, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2567
+#: common.opt:2571
 #, no-c-format
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2571
+#: common.opt:2575
 #, no-c-format
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "Tạo ra các khung ngăn xếp không liên tiếp."
 
-#: common.opt:2579
+#: common.opt:2583
 #, no-c-format
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr ""
 
-#: common.opt:2587
+#: common.opt:2591
 #, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, no-c-format
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 #, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\t Chèn mã kiểm tra ngăn xếp vào chương trình."
 
-#: common.opt:2607
+#: common.opt:2611
 #, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Chèn mã kiểm tra ngăn xếp vào chương trình. Giống với -fstack-check=specific."
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\tBẫy nếu ngăn xếp đi qua <register>."
 
-#: common.opt:2623
+#: common.opt:2627
 #, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<tên>\tBẫy nếu ngăn xếp đi qua ký hiệu <tên>."
 
-#: common.opt:2627
+#: common.opt:2631
 #, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "Bật chức năng bảo vệ ngăn xếp asan."
 
-#: common.opt:2631
+#: common.opt:2635
 #, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 #, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 #, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 #, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 #, no-c-format
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2659
+#: common.opt:2663
 #, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, no-c-format
 msgid "Check for syntax errors, then stop."
 msgstr "Kiểm tra lỗi cú pháp, sau đó dừng lại."
 
-#: common.opt:2671
+#: common.opt:2675
 #, no-c-format
 msgid "Create data files needed by \"gcov\"."
 msgstr "Tạo tập tin dữ liệu cần bởi \"gcov\"."
 
-#: common.opt:2675
+#: common.opt:2679
 #, no-c-format
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 #, no-c-format
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2706
+#: common.opt:2710
 #, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2710
+#: common.opt:2714
 #, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, no-c-format
 msgid "Assume floating-point operations can trap."
 msgstr ""
 
-#: common.opt:2726
+#: common.opt:2730
 #, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2730
+#: common.opt:2734
 #, no-c-format
 msgid "Enable SSA-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2734
+#: common.opt:2738
 #, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2742
+#: common.opt:2746
 #, no-c-format
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2750
+#: common.opt:2754
 #, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2758
+#: common.opt:2762
 #, no-c-format
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2766
+#: common.opt:2770
 #, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2774
+#: common.opt:2778
 #, no-c-format
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr ""
 
-#: common.opt:2778
+#: common.opt:2782
 #, no-c-format
 msgid "Enable dominator optimizations."
 msgstr ""
 
-#: common.opt:2782
+#: common.opt:2786
 #, no-c-format
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2786
+#: common.opt:2790
 #, no-c-format
 msgid "Enable dead store elimination."
 msgstr ""
 
-#: common.opt:2790
+#: common.opt:2794
 #, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2794
+#: common.opt:2798
 #, no-c-format
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2798
+#: common.opt:2802
 #, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr ""
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr ""
 
-#: common.opt:2819
+#: common.opt:2823
 #, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2823
+#: common.opt:2827
 #, no-c-format
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2831
+#: common.opt:2835
 #, no-c-format
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2835
+#: common.opt:2839
 #, no-c-format
 msgid "Enable loop optimizations on tree level."
 msgstr ""
 
-#: common.opt:2839
+#: common.opt:2843
 #, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2847
+#: common.opt:2851
 #, no-c-format
 msgid "Enable SSA-PRE optimization on trees."
 msgstr ""
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2859
+#: common.opt:2863
 #, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2867
+#: common.opt:2871
 #, no-c-format
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2871
+#: common.opt:2875
 #, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2875
+#: common.opt:2879
 #, no-c-format
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2879
+#: common.opt:2883
 #, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2883
+#: common.opt:2887
 #, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2887
+#: common.opt:2891
 #, no-c-format
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2908
+#: common.opt:2912
 #, no-c-format
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2923
+#: common.opt:2927
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2936
+#: common.opt:2940
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2940
+#: common.opt:2944
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2944
+#: common.opt:2948
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2956
+#: common.opt:2960
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2960
+#: common.opt:2964
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2964
+#: common.opt:2968
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2976
+#: common.opt:2980
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2990
+#: common.opt:2994
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2998
+#: common.opt:3002
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:3003
+#: common.opt:3007
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:3011
+#: common.opt:3015
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:3015
+#: common.opt:3019
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3111
+#: common.opt:3115
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3115
+#: common.opt:3119
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3119
+#: common.opt:3123
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3123
+#: common.opt:3127
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3127
+#: common.opt:3131
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3131
+#: common.opt:3135
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:3135
+#: common.opt:3139
 #, no-c-format
 msgid "Clear call-used registers upon function return."
 msgstr ""
 
-#: common.opt:3139
+#: common.opt:3143
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:3143
+#: common.opt:3147
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3147
+#: common.opt:3151
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3175
+#: common.opt:3179
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function."
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Tạo ra một điểm ra khỏi riêng lẻ cho mỗi hàm."
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3219
+#: common.opt:3223
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3223
+#: common.opt:3227
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3227
+#: common.opt:3231
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:3258
+#: common.opt:3262
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3262
+#: common.opt:3266
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3280
+#: common.opt:3284
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<định dạng>\tTạo phần gỡ lỗi nén theo định dạng <định dạng>."
 
-#: common.opt:3291
+#: common.opt:3295
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tĐặt <dir> cho thư mục phần bổ sung mặc định."
 
-#: common.opt:3295
+#: common.opt:3299
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <dir>\tĐặt <dir> để cho thư mục con bao gồm đa kiến trúc."
 
-#: common.opt:3320
+#: common.opt:3324
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <tập tin>\tĐặt kết xuất vào <tập tin>"
 
-#: common.opt:3324
+#: common.opt:3328
 #, no-c-format
 msgid "Enable function profiling."
 msgstr ""
 
-#: common.opt:3334
+#: common.opt:3338
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3374
+#: common.opt:3378
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3406
+#: common.opt:3410
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Bật kết xuất chi tiết."
 
-#: common.opt:3410
+#: common.opt:3414
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Hiển thị thông tin về phiên bản của bộ biên dịch."
 
-#: common.opt:3414
+#: common.opt:3418
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Thu hồi cảnh báo."
 
-#: common.opt:3424
+#: common.opt:3428
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Tạo thư viện dùng chung."
 
-#: common.opt:3472
+#: common.opt:3476
 #, fuzzy, no-c-format
 #| msgid "Don't create a position independent executable."
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Đừng tạo một bản thực hiện không phụ thuộc vào vị trí."
 
-#: common.opt:3476
+#: common.opt:3480
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable."
 msgid "Create a dynamically linked position independent executable."
 msgstr "Tạo một bản thực hiện không phụ thuộc vào vị trí."
 
-#: common.opt:3480
+#: common.opt:3484
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable."
 msgid "Create a static position independent executable."
 msgstr "Tạo một bản thực hiện không phụ thuộc vào vị trí."
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19521,1138 +19521,1148 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "Tỷ lệ ngưỡng của số đếm lần thực hiện cạnh tới hạn cũng cho phép thực hiện việc khử sự thừa sau khi nạp lại."
 
-#: params.opt:178
+#: params.opt:183
 #, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "Tỷ lệ ngưỡngg để thực hiện việc khử bộ phận sự thừa sau khi nạp lại."
 
-#: params.opt:182
+#: params.opt:187
 #, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr ""
 
-#: params.opt:186
+#: params.opt:191
 #, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr ""
 
-#: params.opt:190
+#: params.opt:195
 #, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "Sự mở rộng miền nhớ tối thiểu để gây ra tập hợp rác, theo phần trăm của kích cỡ miền nhớ hoàn toàn."
 
-#: params.opt:194
+#: params.opt:199
 #, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "Sự mở rộng miền nhớ tối thiểu (theo kilô-byte) trước khi bắt đầu tập hợp rác."
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 #| msgid "maximum number of arrays per scop."
 msgid "Maximum number of arrays per SCoP."
 msgstr "số tối đa các mảng trên một scop."
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP."
 msgid "Maximum number of parameters in a SCoP."
 msgstr "số tối đa các tham số trong một SCoP."
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot."
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "Chọn phân số của tần số tối đa lần thực hiện khối cơ bản trong hàm mà cũng quy định rằng khối cơ bản cần phải được thấy là nóng."
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot."
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "Chọn phân số của tần số tối đa lần thực hiện khối cơ bản trong hàm mà cũng quy định rằng khối cơ bản cần phải được thấy là nóng."
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, fuzzy, no-c-format
 #| msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-isnsns-auto."
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr "Tốc độ tăng lên ước tính tối thiểu cho phép chung dòng bỏ qua inline-insns-single và inline-isnsns-auto."
 
-#: params.opt:238
+#: params.opt:243
 #, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "Độ tăng lên (theo phần trăm) được phép cho đơn vị biên dịch đưa ra do việc chèn vào trực tiếp."
 
-#: params.opt:242
+#: params.opt:247
 #, no-c-format
 msgid "The upper bound for sharing integer constants."
 msgstr "Biên giới trên để chia sẻ hằng số nguyên."
 
-#: params.opt:246
+#: params.opt:251
 #, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr ""
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions."
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "Độ sâu tối đa của việc chèn vào trực tiếp một cách đệ quy cho hàm trực tiếp."
 
-#: params.opt:258
+#: params.opt:263
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "Chèn vào trực tiếp một cách đệ quy chỉ khi xác xuất cuộc gọi được thực hiện cũng vượt quá tham số."
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "Độ tăng lên (theo phần trăm) được phép cho đơn vị biên dịch đưa ra do sự lan truyền bất biến thuộc liên quá trình."
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large."
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "Kích cỡ đơn vị thông dịch cần thấy là lớn."
 
-#: params.opt:278
+#: params.opt:283
 #, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr ""
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, fuzzy, no-c-format
 #| msgid "Maximum number of conditional store pairs that can be sunk."
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "Số tối đa các cặp lưu điều kiện cái mà có thể hạ xuống."
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, fuzzy, no-c-format
 #| msgid "Maximum allowed growth of size of new parameters ipa-sra replaces a pointer to an aggregate with."
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr "Độ tăng lên tối đa được pháp của kích cỡ tham số mới ipa-sra thì thay thế một hàm trỏ theo một chiều rộng tập hợp."
 
-#: params.opt:314
+#: params.opt:319
 #, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr "Số các thanh ghi mỗi lớp còn lại chưa dùng do chuyển động bất biến vòng lặp."
 
-#: params.opt:318
+#: params.opt:323
 #, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr "Kích cỡ tối đa (theo MB) của bảng xung đột."
 
-#: params.opt:322
+#: params.opt:327
 #, no-c-format
 msgid "Max loops number for regional RA."
 msgstr "Số tối đa các vòng lặp cho RA thuộc miền."
 
-#: params.opt:326
+#: params.opt:331
 #, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "Nếu số lượng ứng cử trong một tập hợp nhỏ hơn, chúng tôi luôn thử gỡ bỏ iv chưa dùng nào trong khi tối ưu hóa nó."
 
-#: params.opt:330
+#: params.opt:335
 #, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "Đóng kết với số các điều ứng cử dưới đó tất cả các điều ứng cử được tính trong sự tối ưu hóa iv."
 
-#: params.opt:334
+#: params.opt:339
 #, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "Đóng kết với số các lần sử dụng iv trong vòng lặp được tối ưu hóa bằng sự tối ưu hóa iv."
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, no-c-format
 msgid "The size of L1 cache line."
 msgstr "Kích cỡ của đường vùng nhớ tạm cấp 1."
 
-#: params.opt:350
+#: params.opt:355
 #, no-c-format
 msgid "The size of L1 cache."
 msgstr "Kích cỡ của vùng nhớ tạm cấp 1."
 
-#: params.opt:354
+#: params.opt:359
 #, no-c-format
 msgid "The size of L2 cache."
 msgstr "Kích cỡ của vùng nhớ tạm cấp 2."
 
-#: params.opt:358
+#: params.opt:363
 #, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "Độ tăng lên tối đa (theo phần trăm) do chèn hàm lớn vào trực tiếp."
 
-#: params.opt:362
+#: params.opt:367
 #, no-c-format
 msgid "The size of function body to be considered large."
 msgstr "Kích cỡ thân hàm cần thấy là lớn."
 
-#: params.opt:366
+#: params.opt:371
 #, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "Kích cỡ khung ngăn xếp nên thấy là lớn."
 
-#: params.opt:370
+#: params.opt:375
 #, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "Độ tăng lên khung ngăn xếp tối đa (theo phần trăm) do chèn vào trực tiếp."
 
-#: params.opt:374
+#: params.opt:379
 #, no-c-format
 msgid "The size of translation unit to be considered large."
 msgstr "Kích cỡ đơn vị thông dịch cần thấy là lớn."
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "Giá tối thiểu của một biểu thức giá rất cao trong sự chuyển động bất biến vòng lặp."
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, fuzzy, no-c-format
 #| msgid "size of tiles for loop blocking."
 msgid "Size of tiles for loop blocking."
 msgstr "kích cỡ tile (đơn vị dữ liệu) để chặn vòng lặp."
 
-#: params.opt:394
+#: params.opt:399
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "Số tối đa các lệnh trung bình cần tính nên bỏ cuộn trong một vòng lặp bình quân."
 
-#: params.opt:398
+#: params.opt:403
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically."
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "Số tối đa các lần lặp lại vòng lặp dự đoán một cách tĩnh."
 
-#: params.opt:402
+#: params.opt:407
 #, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr "Số tối đa các khối cơ bản trong vòng lặp để chuyển động bất biến vòng lặp."
 
-#: params.opt:406
+#: params.opt:411
 #, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr ""
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in basic block to be considered for SLP vectorization."
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "Số tối đa các lệnh trong khối cơ bản cần tính để véc-tơ hóa SLP."
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop."
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "Số tối đa các lệnh cần tính nên bỏ cuộn trong một vòng lặp."
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:430
+#: params.opt:435
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP."
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr "số tối đa các tham số trong một SCoP."
 
-#: params.opt:434
+#: params.opt:439
 #, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr ""
 
-#: params.opt:438
+#: params.opt:443
 #, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr ""
 
-#: params.opt:442
+#: params.opt:447
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "Số tối đa các lệnh trung bình cần tính nên bỏ cuộn trong một vòng lặp bình quân."
 
-#: params.opt:446
+#: params.opt:451
 #, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr "Số tối đa các chỉ lệnh phối hợp cố phối hợp."
 
-#: params.opt:450
+#: params.opt:455
 #, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "Độ sâu tối đa của một bộ vòng lặp xếp lồng vào nhau được chúng ta lột hoàn toàn."
 
-#: params.opt:454
+#: params.opt:459
 #, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "Số tối đa các lần lột một vòng lặp riêng lẻ được lột hoàn toàn."
 
-#: params.opt:458
+#: params.opt:463
 #, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "Số tối đa các lệnh của một vòng lặp được lột hoàn toàn."
 
-#: params.opt:462
+#: params.opt:467
 #, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "Số tối đa các cạnh gửi đến cần tính để nhảy chéo"
 
-#: params.opt:466
+#: params.opt:471
 #, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr "Số tối đa các lệnh được CSE xử lý trước khi chuyển hết ra ngoài."
 
-#: params.opt:470
+#: params.opt:475
 #, no-c-format
 msgid "The maximum length of path considered in cse."
 msgstr "Chiều dài tối đa của đường dẫn được tính trong CSE."
 
-#: params.opt:474
+#: params.opt:479
 #, no-c-format
 msgid "The maximum memory locations recorded by cselib."
 msgstr "Số tối đa các vị trí bộ nhớ được thư viện cselib ghi lưu."
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "Số tối đa các lệnh cần tính để điền vào một khe đợi."
 
-#: params.opt:486
+#: params.opt:491
 #, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "Số tối đa các lệnh cần tính để tìm thông tin thanh ghi vẫn hiện thời và chính xác."
 
-#: params.opt:490
+#: params.opt:495
 #, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr ""
 
-#: params.opt:494
+#: params.opt:499
 #, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "Số tối đa các lần chèn vào trực tiếp loại gián tiếp lồng nhau được làm bởi bộ chèn vào trực tiếp sớm."
 
-#: params.opt:498
+#: params.opt:503
 #, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "Số tối đa các trường trong một cấu trúc trước khi tiến trình phân tích hàm trỏ thấy cấu trúc đó là một biến riêng lẻ."
 
-#: params.opt:502
+#: params.opt:507
 #, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr ""
 
-#: params.opt:514
+#: params.opt:519
 #, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "Tỷ lệ tối đa các của các lệnh chèn để xóa của biểu thức trong GCSE."
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE."
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "Vùng nhớ tối đa cho GCSE cấp phát."
 
-#: params.opt:522
+#: params.opt:527
 #, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr ""
 
-#: params.opt:526
+#: params.opt:531
 #, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "Hệ số mở rộng tối đa khi sao chép khối cơ bản"
 
-#: params.opt:530
+#: params.opt:535
 #, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr ""
 
-#: params.opt:534
+#: params.opt:539
 #, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "Số tối đa các lệnh khi tự động chèn vào trực tiếp."
 
-#: params.opt:538
+#: params.opt:543
 #, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "Số tối đa các lệnh đến đó hàm trực tiếp có thể tới bằng cách chèn vào trực tiếp một cách đệ quy."
 
-#: params.opt:542
+#: params.opt:547
 #, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "Số tối đa các lệnh đến đó hàm không phải trực tiếp có thể tới bằng cách chèn vào trực tiếp một cách đệ quy."
 
-#: params.opt:546
+#: params.opt:551
 #, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "Số tối đa các lệnh trong một lệnh riêng lẻ mà thích hợp với việc chèn vào trực tiếp."
 
-#: params.opt:550
+#: params.opt:555
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining."
 msgid "The maximum number of instructions when inlining for size."
 msgstr "Số tối đa các lệnh khi tự động chèn vào trực tiếp."
 
-#: params.opt:554
+#: params.opt:559
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining."
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "Số tối đa các lệnh khi tự động chèn vào trực tiếp."
 
-#: params.opt:558
+#: params.opt:563
 #, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "Độ sâu tối đa của việc chèn vào trực tiếp một cách đệ quy cho hàm trực tiếp."
 
-#: params.opt:562
+#: params.opt:567
 #, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "Độ sâu tối đa của việc chèn vào trực tiếp một cách đệ quy cho hàm không phải trực tiếp."
 
-#: params.opt:566
+#: params.opt:571
 #, fuzzy, no-c-format
 #| msgid "maximum number of isl operations, 0 means unlimited"
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "Số tối đa các thao tác isl, 0 là không giới hạn"
 
-#: params.opt:570
+#: params.opt:575
 #, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "Đóng kết với giá của một biểu thức để tính số các lần lặp lại."
 
-#: params.opt:574
+#: params.opt:579
 #, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "Đóng kết với số các lần lặp lại được ước lượng bởi thuật toán phân tích số sức mạnh vũ phu các lần lặp lại."
 
-#: params.opt:578
+#: params.opt:583
 #, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "Số tối đa các câu lệnh được phép trong một khối cần được nhân đôi khi sắp xếp bước nhảy theo nhánh."
 
-#: params.opt:582
+#: params.opt:587
 #, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "Số tối đa các nút RTL có thể ghi lưu như là giá trị cuối cùng của bộ kết hợp."
 
-#: params.opt:586
+#: params.opt:591
 #, fuzzy, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "Số tối đa các lệnh insns của một vòng lặp được lột."
 
-#: params.opt:590
+#: params.opt:595
 #, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr ""
 
-#: params.opt:594
+#: params.opt:599
 #, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr "Chiều dài tối đa của tập hợp antic bộ phận khi thực hiện sự tối ưu hóa sẵn cây."
 
-#: params.opt:598
+#: params.opt:603
 #, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "Số tối đa các nhánh trên đường dẫn xuyên suốt chuỗi vỏ bọc."
 
-#: params.opt:602
+#: params.opt:607
 #, no-c-format
 msgid "The maximum number of peelings of a single loop."
 msgstr "Số tối đa các lần lột một vòng lặp riêng lẻ."
 
-#: params.opt:606
+#: params.opt:611
 #, no-c-format
 msgid "The maximum number of insns of a peeled loop."
 msgstr "Số tối đa các lệnh insns của một vòng lặp được lột."
 
-#: params.opt:610
+#: params.opt:615
 #, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "Chiều dài tối đa của danh sách các thao tác còn treo."
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "Số tối đa các khối mỗi vùng cần tính để định thời giữa các khối."
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "Số tối đa các lệnh mỗi vùng cần tính để định thời giữa các khối."
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "Số tối đa các lần lặp lại vòng lặp dự đoán một cách tĩnh."
 
-#: params.opt:630
+#: params.opt:635
 #, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "Số tối đa các lệnh cần quét ngược khi tìm một sự nạp lại tương đương."
 
-#: params.opt:634
+#: params.opt:639
 #, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "Số tối đa các lệnh trong khối cơ bản cần để coi là cho if-conversion SLP."
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "Số tối đa các lần lặp lại qua CFG để kéo dài vùng."
 
-#: params.opt:650
+#: params.opt:655
 #, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "Khoảng đợi xung đột tối đa trước khi một lệnh được tính để di chuyển một cách lý thuyết có tính chất suy đoán."
 
-#: params.opt:654
+#: params.opt:659
 #, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "Số tối đa các câu lệnh sẵn sàng đưa ra cần được tính bởi bộ định thời trong lần đầu tiên chạy thủ tục định thời."
 
-#: params.opt:666
+#: params.opt:671
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr ""
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, fuzzy, no-c-format
 #| msgid "Maximum number of conditional store pairs that can be sunk."
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "Số tối đa các cặp lưu điều kiện cái mà có thể hạ xuống."
 
-#: params.opt:682
+#: params.opt:687
 #, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "Số tối đa các cặp lưu điều kiện cái mà có thể hạ xuống."
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "Số tối đa các lệnh trong danh sách sẵn sàng mà được thấy là thích hợp với chức năng thay đổi tên."
 
-#: params.opt:694
+#: params.opt:699
 #, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr ""
 
-#: params.opt:698
+#: params.opt:703
 #, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr ""
 
-#: params.opt:702
+#: params.opt:707
 #, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr ""
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, no-c-format
 msgid "The maximum number of unrollings of a single loop."
 msgstr "Số tối đa các lần bỏ cuộn một vòng lặp riêng lẻ."
 
-#: params.opt:714
+#: params.opt:719
 #, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "Số tối đa các lệnh cần tính nên bỏ cuộn trong một vòng lặp."
 
-#: params.opt:718
+#: params.opt:723
 #, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "Số tối đa các lệnh của một vòng lặp chưa chuyển đổi nhánh."
 
-#: params.opt:722
+#: params.opt:727
 #, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "Số tối đa các lần hủy chuyển đổi nhánh trong một vòng lặp riêng lẻ."
 
-#: params.opt:726
+#: params.opt:731
 #, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "Dùng -fvariable-expansion-in-unroller thì số tối đa các lần mở rộng một biến nào đó trong khi bỏ cuộn vòng lặp."
 
-#: params.opt:730
+#: params.opt:735
 #, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr ""
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr "Kích cỡ tối đa của bảng chuỗi duy nhất theo dõi var."
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "Số tối thiểu các lệnh tương ứng cần tính để nhảy chéo"
 
-#: params.opt:754
+#: params.opt:759
 #, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "Chèn vào trực tiếp một cách đệ quy chỉ khi xác xuất cuộc gọi được thực hiện cũng vượt quá tham số."
 
-#: params.opt:758
+#: params.opt:763
 #, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr "Tỷ lệ tối thiểu giữa các lệnh và các lần lấy sẵn để bật lấy sẵn cho một vòng lặp không rõ số đếm lần đi qua."
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr "UID tối thiểu cần sử dụng cho một lệnh không gỡ rối."
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "Xác xuất tối thiểu có thể tới một khối nguồn để định thời giữa các khối một cách lý thuyết có tính chất suy đoán."
 
-#: params.opt:778
+#: params.opt:783
 #, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "Dùng -ftree-vectorize thì biên giới vòng lặp tối thiểu của một vòng lặp cần tính để véc-tơ hóa."
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop."
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "Số tối đa các lệnh cần tính nên bỏ cuộn trong một vòng lặp."
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr ""
 
-#: params.opt:816
+#: params.opt:834
 #, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "Kết quả ước lượng tối đa của nhánh được thấy là dự đoán được."
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "Số các lệnh insn được thực hiện trước khi hoàn tất quá trình lấy sẵn (prefetch)."
 
-#: params.opt:828
+#: params.opt:846
 #, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr "Tỷ lệ tối thiểu giữa các lệnh và các thao tác vùng nhớ để bật lấy sẵn trong một vòng lặp."
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, fuzzy, no-c-format
 #| msgid "use internal function id in profile lookup."
 msgid "Use internal function id in profile lookup."
 msgstr "dùng mã số hàm nội tại trong tìm kiếm hồ sơ."
 
-#: params.opt:840
+#: params.opt:858
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of a loop nest we completely peel."
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "Độ sâu tối đa của một bộ vòng lặp xếp lồng vào nhau được chúng ta lột hoàn toàn."
 
-#: params.opt:844
+#: params.opt:862
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr ""
 
-#: params.opt:848
+#: params.opt:866
 #, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "Đóng kết với độ tinh vi của biểu thức được sử dụng trong bộ phân tích sự khai căn vô hướng."
 
-#: params.opt:852
+#: params.opt:870
 #, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "Đóng kết với kích cỡ biểu thức được sử dụng trong bộ phân tích sự khai căn vô hướng."
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr "Khoảng cách tối thiểu giữa vị trí lưu và nạp có thể xung đột với nhau."
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr "Thuật toán nào được áp dụng."
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "Xác xuất tối thiểu (theo phần trăm) có suy đoán đúng, để định thời lệnh thuộc lý thuyết có tính chất suy đoán."
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "Số tối đa các lệnh trong danh sách sẵn sàng mà được thấy là thích hợp với chức năng thay đổi tên."
 
-#: params.opt:880
+#: params.opt:898
 #, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr "Kích cỡ tối đa của cửa sổ nhìn trước của việc định thời lựa chọn."
 
-#: params.opt:884
+#: params.opt:902
 #, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "Số tối đa các lần có thể định thời một lệnh nào đó."
 
-#: params.opt:888
+#: params.opt:906
 #, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr "Số các quá trình lấy sẵn có thể chạy đồng thời."
 
-#: params.opt:892
+#: params.opt:910
 #, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr ""
 
-#: params.opt:896
+#: params.opt:914
 #, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "Số các chu kỳ được bộ định thời mô-đu-lô swing tính khi kiểm tra sự xung đột bằng DFA."
 
-#: params.opt:900
+#: params.opt:918
 #, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "Một ngưỡng trên số trung bình đếm vòng lặp được bộ định thời mô-đu-lô swing tính."
 
-#: params.opt:904
+#: params.opt:922
 #, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "Một hệ số để điều hưởng giới hạn trên được bộ định thời mô-đu-lô swing sử dụng để định thời một vòng lặp."
 
-#: params.opt:908
+#: params.opt:926
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr ""
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns combine tries to combine."
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "Số tối đa các chỉ lệnh phối hợp cố phối hợp."
 
-#: params.opt:928
+#: params.opt:946
 #, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "Biên giới dưới của một vùng đệm được tính để bảo vệ chống ngăn xếp bị đập tan ra."
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "Tỷ lệ tối đa giữa kích cỡ mảng và các nhánh chuyển đổi để chuyển đảo để lấy chỗ trống."
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP."
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "số tối đa các tham số trong một SCoP."
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP."
 msgid "Maximum number of references stored in each modref base."
 msgstr "số tối đa các tham số trong một SCoP."
 
-#: params.opt:960
+#: params.opt:978
 #, fuzzy, no-c-format
 #| msgid "The maximum number of branches on the path through the peeled sequence."
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "Số tối đa các nhánh trên đường dẫn xuyên suốt chuỗi vỏ bọc."
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 #| msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgid "Maximum number of tests performed by modref query."
 msgstr "Số tối đa các lần chèn vào trực tiếp loại gián tiếp lồng nhau được làm bởi bộ chèn vào trực tiếp sớm."
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr ""
 
-#: params.opt:976
+#: params.opt:994
 #, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr ""
 
-#: params.opt:980
+#: params.opt:998
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "Phần trăm hàm, tăng cấp theo tần số thực hiện, mà phải được bao quát bởi việc tạo vết. Được sử dụng khi hồ sơ phản hồi không sẵn có."
 
-#: params.opt:984
+#: params.opt:1002
 #, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "Phần trăm hàm, tăng cấp theo tần số thực hiện, mà phải được bao quát bởi việc tạo vết. Được sử dụng khi hồ sơ phản hồi sẵn có."
 
-#: params.opt:988
+#: params.opt:1006
 #, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "Độ tăng mã lên tối đa (theo phần trăm) do đuôi bị nhân đôi."
 
-#: params.opt:992
+#: params.opt:1010
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "Dừng tăng lên tiếp nếu xác xuất có cạnh tốt nhất vẫn nhỏ hơn ngưỡng này (theo phần trăm). Được sử dụng khi không có sẵn sàng thông tin phản hồi từ hồ sơ"
 
-#: params.opt:996
+#: params.opt:1014
 #, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "Dừng tăng lên tiếp nếu xác xuất có cạnh tốt nhất vẫn nhỏ hơn ngưỡng này (theo phần trăm). Được sử dụng khi có sẵn sàng thông tin phản hồi từ hồ sơ"
 
-#: params.opt:1000
+#: params.opt:1018
 #, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "Dừng tăng lên ngược nếu xác xuất ngược có cạnh tốt nhất vẫn nhỏ hơn ngưỡng này (theo phần trăm)."
 
-#: params.opt:1004
+#: params.opt:1022
 #, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr ""
 
-#: params.opt:1008
+#: params.opt:1026
 #, no-c-format
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr ""
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr ""
 
-#: params.opt:1020
+#: params.opt:1038
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues."
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "Sử dụng chương trình con cho đoạn mở/đóng hàm."
 
-#: params.opt:1024
+#: params.opt:1042
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues."
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "Sử dụng chương trình con cho đoạn mở/đóng hàm."
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, no-c-format
 msgid "Whether to use canonical types."
 msgstr "Có nên sử dụng loại hợp nguyên tắc hay không."
 
-#: params.opt:1056
+#: params.opt:1074
 #, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr ""
 
-#: params.opt:1060
+#: params.opt:1078
 #, fuzzy, no-c-format
 #| msgid "Maximum number of namespaces to search for alternatives when name lookup fails."
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr "Số tối đa các không gian tên để tìm kiếm cái thay thế khi việc tìm gặp lỗi."
 
-#: params.opt:1064
+#: params.opt:1082
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "Đóng kết với số các sự kiểm tra lúc chạy được chèn bởi việc kiểm tra phiên bản vòng lặp cho bí danh của bộ véc-tơ hóa."
 
-#: params.opt:1068
+#: params.opt:1086
 #, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Đóng kết với số các sự kiểm tra lúc chạy được chèn bởi việc kiểm tra phiên bản vòng lặp để xếp hàng của bộ véc-tơ hóa."
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -20683,7 +20693,7 @@ msgid "expected boolean type"
 msgstr "cần kiểu boolean"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Mong đợi một số nguyên"
@@ -20749,7 +20759,7 @@ msgstr "không đủ đối số"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "quá nhiều đối số"
@@ -21108,7 +21118,7 @@ msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "khai báo trước ở đây"
@@ -21164,7 +21174,7 @@ msgstr ""
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -21193,20 +21203,20 @@ msgstr ""
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -21217,8 +21227,8 @@ msgstr "thuộc tính %qE bị lờ đi"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "khai báo trước đây của %qD"
@@ -21228,60 +21238,60 @@ msgstr "khai báo trước đây của %qD"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr ""
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr ""
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr ""
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr ""
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared but never defined"
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "hàm chung dòng %q+D được khai báo nhưng chưa bao giờ được định nghĩa"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr ""
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr ""
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr ""
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr ""
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "%qD target declared here"
 msgstr "%qD đã được khai báo ở đây"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -21387,7 +21397,7 @@ msgstr "  đã được khai báo ở đây"
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -21413,604 +21423,604 @@ msgstr ""
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr ""
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 #| msgid "  declared here"
 msgid "source object declared here"
 msgstr "  đã được khai báo ở đây"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr ""
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 msgid "destination object declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 #| msgid "a function-definition is not allowed here"
 msgid "destination object allocated here"
 msgstr "không cho phép định nghĩa hàm tại đây"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "đối số không hợp lệ cho %qD"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "đối số không được hỗ trợ cho %D"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "cả hai đối số cho %<__builtin___clear_cache%> phải là các con trỏ"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr ""
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD đã đổi ngữ nghĩa trong GCC 4.4"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "đối số mô hình bộ nhớ không hợp lệ cho phần tích hợp"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "mô hình bộ nhớ không hợp lệ cho %<__atomic_compare_exchange%>"
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "mô hình bộ nhớ không hợp lệ cho %<__atomic_load%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "mô hình bộ nhớ không hợp lệ cho %<__atomic_store%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 1 to %qs"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to %qs"
 msgid "non-integer argument 1 to %qs"
 msgstr "thiếu đối số đối cho %qs"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_thread_pointer is not supported on this target"
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_thread_pointer không được hỗ trợ trên đích này"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_set_thread_pointer is not supported on this target"
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_set_thread_pointer không được hỗ trợ trên đích này"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s not supported: ignored"
 msgid "%qs only supported in OpenACC code"
 msgstr "-f%s không được hỗ trợ: lờ đi"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 0 to %qs"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to %qs"
 msgid "illegal argument 0 to %qs"
@@ -22018,127 +22028,127 @@ msgstr "thiếu đối số đối cho %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> đối số thứ hai phải là 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "định dạng đích không hỗ trợ vô cực"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr ""
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "sai số lượng đối số cho hàm %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> được gọi mà không có đối số"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "sai số lượng đối số cho hàm %<__builtin_next_arg%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "đối số thứ hai của %<va_start%> không là đối số có tên cuối"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "đối số %qd không phải hằng số"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "được khai báo ở đây"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 #| msgid "required from %q#D\n"
 msgid "returned from %qD"
 msgstr "được yêu cầu từ %q#D\n"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 #| msgid "required from %q#D\n"
 msgid "returned from %qT"
 msgstr "được yêu cầu từ %q#D\n"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "obtained here"
 msgstr "union được định nghĩa ở đây"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "assigned here"
 msgstr "struct được định nghĩa ở đây"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -22913,307 +22923,307 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing counts for called function %s/%i"
 msgid "missing direct call for speculation %i"
 msgstr "Thiếu số lượng cho cú gọi hàm %s/%i"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "thiếu chắn sau khối %i"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "yếu tố khởi tạo không phải hằng số"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 #| msgid "%<priority%> value must be non-negative"
 msgid "tp_first_run must be non-negative"
 msgstr "%<priority%> giá trị phải dương"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "ký hiệu cục bộ phải được định nghĩa"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "edge count is not compatible with function count"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to con trỏ là sai"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "nhiều bộ gọi chung dòng"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "con trỏ inlined_to chỉ đến chính nó"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node có clone_of sai"
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node có danh sách nhân bản sai"
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Bí danh có cạnh gọi"
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Bí danh có tham chiếu non-alias"
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt được chia sẻ:"
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node gặp lỗi"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: section %s is missing"
 msgid "%s: section %s.%d is missing"
@@ -23304,12 +23314,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -23383,7 +23393,7 @@ msgstr ""
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "kích thước của %q+D lớn hơn %wd byte"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr ""
@@ -23812,12 +23822,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr ""
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -23837,7 +23847,7 @@ msgstr "rtx dùng chung"
 msgid "internal consistency failure"
 msgstr "tính nhất quán nội tại gặp lỗi nghiêm trọng"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -23971,42 +23981,42 @@ msgstr ""
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "so sánh luôn là %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -24021,7 +24031,7 @@ msgstr ""
 msgid "total size of local objects exceeds maximum %wu"
 msgstr ""
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -24674,7 +24684,7 @@ msgstr ""
 msgid "function may return address of local variable"
 msgstr "hàm có thể trả về địa chỉ của biến cục bộ"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "hàm trả về địa chỉ của biến cục bộ"
@@ -25032,62 +25042,62 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "%s trong chuỗi định dạng tại %L"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 msgid "%Guse of %<alloca%>"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 msgid "%Gargument to variable-length array may be too large"
 msgstr "Cảnh báo nếu mảng có độ dài biến đổi được dùng."
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 msgid "%Gargument to variable-length array is too large"
 msgstr "Cảnh báo nếu mảng có độ dài biến đổi được dùng."
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 #, fuzzy
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 msgid "%Gargument to variable-length array is zero"
 msgstr "Cảnh báo nếu mảng có độ dài biến đổi được dùng."
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 msgid "%Gargument to %<alloca%> is zero"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
@@ -25191,7 +25201,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "array member %q#D declared here"
 msgid "array %qD declared here"
@@ -25218,11 +25228,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD được khai báo ở đây"
@@ -25300,316 +25310,316 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of asm flag output"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "sử dụng kết xuất cờ asm sai"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr ""
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing %s"
 msgid "enclosing region"
 msgstr "bao quanh %s"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D not declared in class"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%q#D chưa được khai báo trong lớp"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing %s"
 msgid "enclosing %qs"
 msgstr "bao quanh %s"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 #| msgid "SPE not supported in this target"
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "SPE không được hỗ trợ ở đích này"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing %s"
 msgid "enclosing %<target%>"
 msgstr "bao quanh %s"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr ""
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %<lastprivate%>"
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "%qD không phải một biến trong mệnh đề %<lastprivate%>"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, fuzzy, gcc-internal-format
 #| msgid "%qD in %<reduction%> clause is a zero size array"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "%qD trong mệnh đề %<reduction%> là một mạng cỡ không"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr ""
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gặp lỗi"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -26064,23 +26074,23 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s không thể được dùng trong asm ở đây"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr "cho %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr ""
@@ -26101,12 +26111,12 @@ msgstr ""
 msgid "unable to find a register to spill"
 msgstr ""
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr ""
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Maximum number of times that an insn could be scheduled."
 msgid "maximum number of generated reload insns per insn achieved (%d)"
@@ -26843,12 +26853,12 @@ msgstr "-malign-functions=%d không nằm giữa 0 và %d"
 msgid "unrecognized argument in option %qs"
 msgstr "không nhận ra đối số tới tùy chọn %qs"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
@@ -26980,7 +26990,7 @@ msgstr ""
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr ""
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
@@ -27535,22 +27545,22 @@ msgstr ""
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr ""
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr ""
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr ""
@@ -27613,13 +27623,13 @@ msgstr ""
 msgid "impossible register constraint in %<asm%>"
 msgstr ""
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "đích này không hỗ trợ %qs"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr ""
@@ -27649,53 +27659,53 @@ msgstr ""
 msgid "output operand is constant in %<asm%>"
 msgstr ""
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "kiểm tra RTL: cần elt %d kiểu “%c”, nhận “%c” (rtx %s) trong %s, tại %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "kiểm tra RTL: cần elt %d kiểu “%c” hoặc “%c”, nhận “%c” (rtx %s) trong %s, tại %s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "kiểm tra RTL: cần  mã “%s”, nhận “%s” trong %s, tại %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "kiểm tra RTL: cần  mã “%s” hoặc “%s”, nhận “%s” trong %s, tại %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "kiểm tra RTL: cần  mã “%s” hoặc “%s”, nhận “%s” trong %s, tại %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:937
+#: rtl.c:947
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr ""
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr ""
@@ -27740,23 +27750,23 @@ msgstr ""
 msgid "invalid punctuation %qc in constraint"
 msgstr ""
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr ""
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate member %q+D"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "thành viên trùng lặp %q+D"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr ""
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr ""
@@ -28470,9 +28480,9 @@ msgstr "sai đặt toán hạng tới %%R"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in parameter %i"
 msgid "type mismatch in %qs"
@@ -28512,7 +28522,7 @@ msgstr "sai toán hạng %%t “"
 msgid "invalid clique in %qs"
 msgstr "dùng %qD không hợp lệ"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
@@ -28726,380 +28736,380 @@ msgstr "toán hạng không hợp lệ trong phép toán tam nguyên"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "type is deprecated: %s"
 msgid "vector types expected in %qs"
 msgstr "kiểu đã lạc hậu: %s"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid mask type in %qs"
 msgstr "kiểu trừu tượng cho %q+D không hợp lệ"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "Hóa hợp không được hỗ trợ: %s"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid position or size in %qs"
 msgstr "chế độ con trỏ %qs không hợp lệ"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 #| msgid "shift of non-integer operand"
 msgid "%qs into non-mode-precision operand"
 msgstr "dịch của toán hạng không nguyên"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a directory"
 msgid "%qs not at element boundary"
 msgstr "%qs không phải là một thư mục"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number %qs"
 msgid "non-trivial conversion in %qs"
 msgstr "số thứ tự phiên bản không hợp lệ %qs"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "cần biểu thức"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "sai đặt toán hạng tới %%R"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for %q+D"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "tên thanh ghi cho %q+D không hợp lệ"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, fuzzy, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 #| msgid "different number of results"
 msgid "incorrect number of vector %qs elements"
 msgstr "khác số của kết quả"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr ""
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr ""
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr ""
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr ""
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, fuzzy, gcc-internal-format
 #| msgid "invalid CASE_CHAIN"
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "sai CASE_CHAIN"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "nhãn case không hợp lệ trong câu lệnh switch"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "kiểu không khớp cho nhãn case trong câu lệnh switch"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "các nhãn case không được sắp xếp trong câu lệnh switch"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "array notations cannot be used in declaration"
 msgid "label context is not the current function declaration"
 msgstr "Cảnh báo về lời khai báo kiểu cũ"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "kết quả PHI không hợp lệ"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "thiếu PHI def"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "sai tham số PHI"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in send"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "không tương thích kiểu trong bộ gửi"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple gặp lỗi"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "lệnh được đánh dấu cho throw, nhưng không phải vậy"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "lệnh được đánh dấu cho throw ở giữa một khối"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple gặp lỗi"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "nhãn không-cục-bộ"
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "nhãn"
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "nhãn cho case chưa được sắp xếp: "
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "thiếu edge %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> hàm trả về"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
@@ -30202,7 +30212,7 @@ msgstr ""
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
@@ -30367,7 +30377,7 @@ msgstr ""
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported mode %s\n"
 msgid "unsupported record layout"
@@ -31018,7 +31028,7 @@ msgstr "thuộc tính %qE theo %qE"
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -31038,7 +31048,7 @@ msgstr "%qD không tương thích với %qD"
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -31487,12 +31497,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh phép gán được dùng như là giá trị chân lý"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "dùng %<restrict%> không hợp lệ"
@@ -31653,13 +31663,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "quá ít đối số cho hàm %qE"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "quá nhiều đối số cho hàm %qE"
@@ -32619,7 +32629,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -32669,7 +32679,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -32684,17 +32694,17 @@ msgstr "biến iterator"
 msgid "%qE is not initialized"
 msgstr "%qE chưa được khởi tạo"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "thiếu biểu thức gia số"
@@ -32704,7 +32714,7 @@ msgstr "thiếu biểu thức gia số"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "biểu thức gia không hợp lệ"
@@ -32770,7 +32780,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -33363,8 +33373,8 @@ msgstr "<giá trị trả lại>"
 msgid "wrong type argument to %s"
 msgstr "sai kiểu đối số cho %s"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "tràn trong biểu thức hằng"
@@ -33873,17 +33883,17 @@ msgstr "số giảm của hàm %qD"
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr ""
@@ -34063,8 +34073,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -34141,160 +34151,160 @@ msgid "passing argument %i to %qs-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to %qs-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "union được định nghĩa ở đây"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as %s"
 msgstr "đã khai báo trước ở đây"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "Cảnh báo nếu mảng có độ dài biến đổi được dùng."
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as a pointer %s"
 msgstr "đã khai báo trước ở đây"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as an ordinary array %s"
 msgstr "đã khai báo trước ở đây"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr ""
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as an array %s"
 msgstr "đã khai báo trước ở đây"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qD with attribute noinline"
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "khai báo trước đây của %qD với không chung dòng thuộc tính"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr ""
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as %s with bound argument %E"
 msgstr "đã khai báo trước ở đây"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %<%c%s%>"
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "khai báo trước của %<%c%s%>"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr "khai báo trước đây %q#D"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -34309,7 +34319,7 @@ msgstr "“%qs” không phải là một tùy chọn hợp lệ cho bộ tiền
 msgid "too many input files"
 msgstr "quá nhiều tập tin nhập vào"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -34343,14 +34353,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ là: %s; có phải ý bạn là là: %qs?"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -34522,63 +34532,63 @@ msgstr "-mregparm=%d không nằm giữa 0 và %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%> không tương thích với ABI đã chọn"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
@@ -34754,85 +34764,85 @@ msgstr ""
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr ""
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr ""
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr ""
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr ""
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr ""
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr ""
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-sjlj-exceptions%> bị bỏ qua đối với %<-fgnu-runtime%>"
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "%<-mdynamic-no-pic%> đè lên %<-fpic%>, %<-fPIC%>, %<-fpie%> hay %<-fPIE%>"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr ""
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr ""
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr ""
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr ""
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, fuzzy, gcc-internal-format
 #| msgid "%s in CFString literal"
 msgid "non-ASCII character in CFString literal"
 msgstr "%s trong chuỗi văn CFString"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "%s in CFString literal"
 msgid "embedded NUL in CFString literal"
@@ -34840,7 +34850,7 @@ msgstr "%s trong chuỗi văn CFString"
 
 #: config/host-darwin.c:65
 #, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr ""
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -34983,391 +34993,391 @@ msgstr "%<#pragma GCC optimize%> không phải là một chuỗi hay số"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<for%> after %qs"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "cần %<for%> sau %qs"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs không tương thích với %s %s"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs không tương thích với %s %s"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the SPE ABI extensions."
 msgid "this operation requires the SVE ISA extension"
 msgstr "Không dùng lệnh mở rộng SPE ABI."
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Vector argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Đối số véc-tơ bị gửi cho hàm không nguyên mẫu"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%qE requires the SVE ISA extension"
 msgstr "Dùng lệnh mở rộng SPE ABI."
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid format of %s"
 msgid "invalid format for sve_width"
 msgstr "định dạng của %s không hợp lệ"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "giá trị %%h sai"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "không hiểu tùy chọn chỉnh (%s)"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s;"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in -mcpu=%qs"
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "thiếu cpu trong -mcpu=%qs"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "đối số không hợp lệ cho %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "đối số không hợp lệ cho %<__builtin_frame_address%>"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, fuzzy, gcc-internal-format
 #| msgid "missing arch name in -march=%qs"
 msgid "missing arch name in %<-march=%s%>"
 msgstr "thiếu tên kiến trúc trong -march=%qs"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -march"
 msgid "unknown value %qs for %<-march%>"
 msgstr "không hiểu giá trị %qs cho -march"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in -mtune=%qs"
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "thiếu tên cpu trong -mcpu=%qs"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "không hiểu giá trị %qs dành cho -mtune"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s xung đột với -march=%s"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "Assembler không hỗ trợ -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %<-f%s%>"
 msgstr "mô hình mã %qs với -f%s"
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<=%> (after %<getter%> attribute)"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "thiếu %<=%> (sau thuộc tính %<getter%>)"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> sai dạng"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%<no-custom-%s%> không chấp nhận đối số"
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported simdlen %d"
 msgid "unsupported simdlen %wd"
 msgstr "simdlen không được hỗ trợ %d"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -35434,7 +35444,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "giá trị sai %qs cho -mmemory-latency"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -35563,18 +35573,18 @@ msgstr ""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "đối số của thuộc tính %qE không hợp lệ"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -36018,234 +36028,240 @@ msgstr "CPU đích không hỗ trợ chỉ lệnh THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "CPU đích không hỗ trợ truy cập chưa cân chỉnh"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "-mcpu=%s conflicts with -march=%s"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "-mcpu=%s xung đột với -march=%s"
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check không tương thích với -mno-apcs-frame"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic và -mapcs-reent là xung khắc nhau"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC không tương thích với -msingle-pic-base"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= là vô ích nếu không có -fpic"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "không thể dùng “%s” cho thanh ghi PIC"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition không được hỗ trợ trên kiến trúc này"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable và -msdata=%s là không tương thích"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "CPU đích không hỗ trợ làm việc tương tác"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS không hỗ trợ -mcaller-super-interworking"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS không hỗ trợ -mcallee-super-interworking"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 và không ldrh"
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "CPU đích không hỗ trợ chỉ lệnh THUMB"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
+#: config/arm/arm.c:3864
 #, fuzzy, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
 msgstr "-mfloat-abi=hard và VFP"
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard và VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "non-AAPCS dẫn suất biến thể PCS"
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "biến thể PCS"
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 dấu-chấm-động-bằng-phần-cứng VFP ABI"
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "Thuộc tính %qE bị lờ đi với các kiểu"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd nằm ngoài vùng %wd - %wd"
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd nằm ngoài vùng %wd - %wd"
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific cho Thumb-1"
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid fpu for attribute(target(\"%s\"))"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -36254,23 +36270,23 @@ msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown target attribute or pragma %qs"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -36354,18 +36370,18 @@ msgstr "-fpie không được hỗ trợ"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIE không được hỗ trợ"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 #| msgid "-fwpa and -fltrans are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-fwpa và -fltrans loại trừ lẫn nhau"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs hàm không có đối số"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs hàm không trả về giá trị nào"
@@ -37140,133 +37156,133 @@ msgstr "đối số %d của %qE phải nằm trong vùng %d…%d"
 msgid "parameter to builtin not valid: %s"
 msgstr "đối số %qD đặt nhưng chưa được dùng"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 2-bít"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "đối số thứ ba phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 3-bít"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "chế độ so sánh không đúng"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE cần là tùy chọn %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 32-bít"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "đối số cuối phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "đối số thứ tư phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -37289,542 +37305,542 @@ msgstr "dwarf phiên bản %d không được hỗ trợ"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_thread_pointer không được hỗ trợ trên đích này"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "mô hình mã %s không hỗ trợ chế độ PIC"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %<target%> argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "sai đối số %s cho tùy chọn %s"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "sai đối số %s cho tùy chọn %s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "không hiểu hàm đặc tả %qs"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "không chỉ định tên lớp với %qs"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-Wabi=1%> không được hỗ trợ, dùng =2"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify -static with -fsanitize=address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "không thể chỉ định -static với -fsanitize=địa_chỉ"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fsanitize=address xung khắc với -fsanitize=kernel-address"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fsanitize=address xung khắc với -fsanitize=kernel-address"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel không được hỗ trợ trong cấu hình này"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "chế độ %i-bit chưa được biên dịch bên trong"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU bạn chọn không hỗ trợ chỉ lệnh x86-64"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored for Intel MCU psABI"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d không nằm giữa 0 và %d"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mrtd%> is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-mpreferred-stack-boundary không được hỗ trợ trên đích này"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d không ở giữa %d và 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "-mnop-mcount không được thực hiện cho -fPIC"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "%<-msseregparm%> used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "Chỉ lệnh SSE đặt là tắt, sử dụng số học 387"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry không hỗ trợ cho 32-bit trong tổ hợp cùng với -fpic"
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry không tương thích với SEH"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 #| msgid "cdecl and thiscall attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "thuộc tính regparam và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính fastcall và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and thiscall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -38299,7 +38315,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "Thuộc tính %qE cần tham số là chuỗi"
@@ -39393,61 +39409,61 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "không hiểu giá trị %qs dành cho -mtune"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr ""
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "%E requires %<-fgnu-tm%>"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "%E cần %<-fgnu-tm%>"
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "“%qs” không phải là một tên lớp đúng"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
@@ -39995,260 +40011,261 @@ msgstr "%qE được dùng với %<register%>"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 yêu cầu kiến trúc PowerPC64, đang bật"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 #| msgid "-mcall-aixdesc incompatible with -mabi=elfv2"
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mcall-aixdesc xung khắc với -mabi=elfv2"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires a PowerPC64 cpu"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 yêu cầu cpu PowerPC64"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "-mcmodel không tương thích với các tùy chọn toc khác"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported mode %s\n"
 msgid "%qs unsupported for this ABI"
 msgstr "không hỗ trợ chế độ %s\n"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec không được hỗ trợ ở đích này"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring không được hỗ trợ trên hệ thống lớn trước"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs không tương thích với %s %s"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT được coi là %qs"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "-mfloat128-hardware cần được ISA 3.0 hỗ trợ"
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "dùng phần mở rộng số nguyên chính đôi IEEE"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "dùng phần mở rộng số nguyên chính đôi IBM"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128 requires VSX support"
 msgid "%qs requires VSX support"
 msgstr "-mfloat128 cần hỗ trợ VSX"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgid "%qs requires full ISA 3.0 support"
 msgstr "-mfloat128-hardware cần được ISA 3.0 hỗ trợ"
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, fuzzy, gcc-internal-format
 #| msgid "Known vectorization library ABIs (for use with the -mveclibabi= option):"
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "Chưa biết thư viện véc-tơ-hóa ABIs (để dùng với tùy chọn -mveclibabi=):"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs needs a valid base register"
 msgstr "“%qs” không phải là một tên lớp đúng"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<%s=%s%>"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated and has no effect"
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs đã lỗi thời và không có tác động gì"
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
-msgstr ""
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "Use decimal floating point instructions."
+msgid "use of decimal floating-point types in AltiVec types is invalid"
+msgstr "Sử dụng câu lệnh dấu chấm động thập phân bằng phần cứng."
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 #| msgid "%<long long%> invalid for %qs"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> không hợp lệ với %qs"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "sai cpu \"%s\" cho %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s không hợp lệ"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -40441,7 +40458,7 @@ msgstr ""
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -40514,206 +40531,212 @@ msgstr "%qs đã lạc hậu"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "constant argument out of range for %qs"
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<chưa giải quyết loại hàm quá tải>"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "icode dựng sẵn sai"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "invalid argument %d for builtin %qF"
 msgstr "đối số không hợp lệ cho %qD"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float không được hỗ trợ trong tổ hợp"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mrtd%> is ignored in 64bit mode"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -41070,17 +41093,23 @@ msgstr "-fexcess-precision=standard cho Java"
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "insn contains an invalid address !"
+msgid "%s contains too many lines"
+msgstr "insn chứa một địa chỉ sai !"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "subprogram %q+F not marked %<Inline%>"
@@ -41150,8 +41179,8 @@ msgstr ""
 msgid "could not read the BRIG file"
 msgstr "không thể ghi vào tập tin đáp ứng %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -41211,7 +41240,7 @@ msgstr "biến %qD được đặt nhưng lại chưa được dùng"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "định nghĩa lần đầu ở đây"
@@ -41442,7 +41471,7 @@ msgstr ""
 msgid "declaration of %qD shadows a parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -41452,7 +41481,7 @@ msgstr ""
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
@@ -41462,214 +41491,214 @@ msgstr ""
 msgid "nested extern declaration of %qD"
 msgstr ""
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "khai báo ngầm của hàm %qE"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "khai báo ngầm của hàm %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qE"
 msgstr "tái khai báo không hợp lệ cho %q+D"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr ""
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr ""
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr ""
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr ""
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr ""
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr ""
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr ""
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr ""
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr ""
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "trùng nhãn %qD"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr ""
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr ""
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "switch bắt đầu ở đây"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr ""
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "Thuộc tính %qE cần kiểu trả về là void"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr ""
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr ""
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> trong khai báo trống rỗng"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<_Noreturn%> trong khai báo trống rỗng"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr ""
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of type %<void%> in parameter declaration"
 msgid "invalid use of attributes in empty declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "khai báo trống rỗng"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr ""
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr ""
@@ -41677,28 +41706,28 @@ msgstr ""
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D thường là một hàm"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr ""
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "hàm %qD được khởi tạo giống như là một biến"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "tham số %qD được khởi tạo"
@@ -41707,270 +41736,270 @@ msgstr "tham số %qD được khởi tạo"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "không thể khởi tạo một đối tượng có kích cỡ biến đổi"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr ""
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared weak"
 msgid "inline function %q+D given attribute %qs"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD cần được khởi tạo"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr ""
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "thiếu kích thước mảng trong %q+D"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "mảng có kích thước bằng không hay bị âm %q+D"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr ""
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, gcc-internal-format
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr ""
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr ""
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %q#D is invalid"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "độ rộng bằng không cho bit-field %qs"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr ""
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr ""
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array"
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "lặp lại %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "lặp lại %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "lặp lại %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "trùng lặp %<_Atomic%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "định nghĩa hàm được khai báo là %<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "định nghĩa hàm được khai báo là %<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -41978,712 +42007,712 @@ msgstr ""
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "sự khai báo của %qE như là mảng của void"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "sự khai báo của %qE như là mảng của các hàm"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "cỡ của mảng không tên là âm"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C cấm chỉ mảng có độ dài là không %qE"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C cấm chỉ mảng có độ dài là không"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "kích cỡ mảng %qE bị âm"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "cỡ của mảng không tên là âm"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "kích cỡ mảng %qE quá lớn"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "kích thước của mảng chưa đặt tên là quá lớn"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 không hỗ trợ thành viên mảng linh động"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr ""
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "định nghĩa hàm có kiểu trả về là void"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr ""
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr ""
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr ""
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D được khai báo %<inline%>"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "đối số %q+D được khai báo %<inline%>"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "đối số %q+D được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "trường %qE được khai báo như là một hàm"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr ""
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr ""
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 không hỗ trợ %<_Noreturn%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 không hỗ trợ %<_Noreturn%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "biến %q+D được khai báo %<inline%>"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "biến %q+D được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "đối số %u (%q+D) có kiểu void"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "tham số %u có kiểu void"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> phải là đối số duy nhất"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "kiểu enum được định nghĩa ở đây"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "struct được định nghĩa ở đây"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "union được định nghĩa ở đây"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "định nghĩa lại của %<union %E%>"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "định nghĩa lại của %<struct %E%>"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "định nghĩa lại bị lồng của %<union %E%>"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "định nghĩa lại bị lồng của %<struct %E%>"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "thành viên trùng lặp %q+D"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union không có thành viên nào"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union không có thành viên nào"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct không có thành viên nào"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "kiểu %qT quá lớn"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "khai báo lại của %<enum %E%>"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "tràn giá trị liệt kê"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared weak"
 msgid "inline function %qD given attribute %qs"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "kiểu trả về là một kiểu không hoàn toàn"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "trả về kiểu mặc định cho %<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "chưa có khai báo nguyên mẫu trước đây cho %qD"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "chưa có khai báo trước đây cho %qD"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr ""
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "định nghĩa hàm theo cách cũ"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD đã được định nghĩa là không có tham số"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "đối số %qD được khai báo với kiểu void"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "kiểu của %qD mặc định đến %<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "số lượng đối số không giống với nó khi khai báo mẫu hàm"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "khai báo mẫu trước"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "đối số %qD đặt nhưng chưa được dùng"
@@ -42691,259 +42720,259 @@ msgstr "đối số %qD đặt nhưng chưa được dùng"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 không hỗ trợ %<long long%>"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "cần các định danh khai báo"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> là quá dài đối với GCC"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 không hỗ trợ %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 không hỗ trợ kiểu complex"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C không hỗ trợ kiểu saturating"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "lặp lại %qE"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 không hỗ trợ kiểu lô-gíc"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm động hệ thập phân"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "kiểu dấu chấm cố định không được hỗ trợ trên đích này"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm cố định"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE không ở đầu của khai báo"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE được dùng với %<auto%>"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE được dùng với %<register%>"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 không hỗ trợ %qE"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 không hỗ trợ %qE"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> trước %<extern%>"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> trước %<static%>"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "trùng %<_Thread_local%> hay %<__thread%>"
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs được dùng với %qE"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> được dùng mà không có %<_Fract%> or %<_Accum%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "dịch trái của một giá trị âm"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "số lượng dịch phải  >= độ rộng của kiểu"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "số lượng dịch phải  >= độ rộng của kiểu"
@@ -42964,7 +42993,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "không khớp cho"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "cần kết thúc dòng"
@@ -42974,7 +43003,7 @@ msgstr "cần kết thúc dòng"
 msgid "ISO C forbids an empty translation unit"
 msgstr ""
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr ""
@@ -43010,7 +43039,7 @@ msgid "unknown type name %qE"
 msgstr "không hiểu tên kiểu %qE"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "cần các định danh khai báo"
@@ -43030,7 +43059,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "cần %<;%>, định danh hoặc %<(%>"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -43045,7 +43074,7 @@ msgstr ""
 msgid "unexpected attribute"
 msgstr "cần thuộc tính"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -43083,7 +43112,7 @@ msgstr "%<__auto_type%> cần một khai báo khởi tạo dữ liệu"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> có lẽ chỉ được dùng với khai báo đơn"
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "cần %<,%> hoặc %<;%>"
@@ -43142,7 +43171,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "thẩm tra tĩnh gặp lỗi"
@@ -43187,14 +43216,14 @@ msgstr ""
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "cần định danh"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "dấu phẩy ở cuối của danh dánh liệt kê"
@@ -43279,7 +43308,7 @@ msgstr "cần các định danh khai báo hay %<…%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string argument"
 msgid "%qE attribute does not take any arguments"
@@ -43341,7 +43370,7 @@ msgstr ""
 msgid "expected %<}%> before %<else%>"
 msgstr "cần %<}%> trước %<else%>"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> mà không có %<if%> ở trước"
@@ -43356,7 +43385,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "cần biểu thức"
@@ -43381,17 +43410,17 @@ msgstr "cần một định danh hoặc %<*%>"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr ""
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -43411,12 +43440,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -43432,8 +43461,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "trùng cv-qualifier"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -43462,12 +43491,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "type of field declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -43869,13 +43898,13 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "empty property attribute list"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -43887,55 +43916,55 @@ msgstr "Thiếu thuộc tính Code (mã)"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<for%> after %qs"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "cần %<for%> sau %qs"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected %qE selector name"
 msgstr "cần selection-statement"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
@@ -43946,18 +43975,18 @@ msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "cần câu lệnh for, while hoặc do"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> phải là đầu tiên"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "quá nhiều mệnh đề %qs"
@@ -43978,54 +44007,54 @@ msgstr "cần %<,%> hoặc %<)%>"
 msgid "%qD is not a variable"
 msgstr "%qD không phải là một biến"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD không phải là một biến trỏ"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "cần %<data%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -44047,114 +44076,114 @@ msgstr "%<num_threads%> giá trị phải dương"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%> giá trị phải dương"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%> giá trị phải dương"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%> giá trị phải dương"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> hoặc %<max%>"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "biểu thức %qs phải là số nguyên"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "quá nhiều đối số %<static%>"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "gặp tham số thừa"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%>"
 msgid "expected %<concurrent%>"
 msgstr "cần %<none%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> hoặc định danh"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "kiểu lịch biểu không hợp lệ"
@@ -44164,17 +44193,17 @@ msgstr "kiểu lịch biểu không hợp lệ"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%> giá trị phải dương"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%> giá trị phải dương"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -44194,23 +44223,23 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %qs"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%qs không tương thích với %qs"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "kiểu phụ thuộc không hợp lệ"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "kiểu ánh xạ không hợp lệ"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "kiểu dist_schedule không hợp lệ"
@@ -44226,82 +44255,82 @@ msgstr "kiểu proc_bind không hợp lệ"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "cần mệnh đề %<#pragma acc%>"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs phải là mệnh đề đầu tiên của %qs"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
@@ -44316,7 +44345,7 @@ msgstr "%qE chưa được khai báo"
 msgid "expected function name"
 msgstr "cần tên hàm"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD không phải là hàm thành viên mẫu"
@@ -44326,29 +44355,29 @@ msgstr "%qD không phải là hàm thành viên mẫu"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<allocator%>"
@@ -44359,91 +44388,91 @@ msgstr "cần %<operator%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable không còn được hỗ trợ nữa"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> hoặc định danh"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "sai dạng thức của %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "thao tác không hợp lệ cho %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> sử dụng hai biểu thức khác nhau cho bộ nhớ"
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "cần %<:%>, %<,%>, %<;%>, %<}%> hoặc %<__attribute__%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -44453,34 +44482,34 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "cần %<(%> hoặc xuống dòng"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "cần %<}%> trước %<else%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "cần câu lệnh for"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "cần khai báo nhắc lại hay sự khởi tạo"
@@ -44490,73 +44519,73 @@ msgstr "cần khai báo nhắc lại hay sự khởi tạo"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> với mệnh đề %<depend%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "cần %<for%> sau %qs"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "cần %<point%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -44572,64 +44601,64 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> phải xuất hiện trước khai báo của %D, đang lờ đi"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "cần selection-statement"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%<no-custom-%s%> không chấp nhận đối số"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L must be nonnegative"
 msgid "score argument must be non-negative"
 msgstr "%s tại %L phải là số nguyên"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "cần chuỗi văn chương"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "property must be constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -44641,13 +44670,13 @@ msgstr "cần %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -44657,32 +44686,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "cần %<target%>"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "cần %<declare%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -44737,45 +44766,45 @@ msgstr "cần tên-hàm %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "cần %<=%>, %<,%>, %<;%>, %<asm%> hay %<__attribute__%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 #| msgid "clause not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "mệnh đề vẫn chưa được hỗ trợ"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -44792,27 +44821,27 @@ msgstr "%<_Atomic%> %qE trong mệnh đề %<reduction%>"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %<reduction%>"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> nằm trong một %<__transaction_relaxed%>"
@@ -44823,7 +44852,7 @@ msgstr "%<__transaction_cancel%> nằm trong một %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> không nằm trong %<__transaction_atomic%>"
@@ -44838,7 +44867,7 @@ msgstr "tác vụ bao quanh"
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "sử dụng sai biểu thức void"
@@ -44879,127 +44908,127 @@ msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 msgid "function types not truly compatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr ""
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr ""
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr ""
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr ""
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr ""
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr ""
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT không có thành viên nào mang tên %qE"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr ""
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr ""
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr ""
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "chỉ số mảng không phải là số nguyên"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr ""
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr ""
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr ""
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr ""
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr ""
@@ -45007,1631 +45036,1631 @@ msgstr ""
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr ""
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr ""
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr ""
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr ""
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "quá nhiều đối số cho cho phương thức %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "quá nhiều đối số cho hàm %qE"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "quá ít đối số cho hàm %qE"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about use of multi-character character constants."
 msgid "comparison between pointer and zero character constant"
 msgstr "Cảnh báo về sử dụng hằng số ký tự đa ký tự."
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 #| msgid "did you mean to use logical not?"
 msgid "did you mean to dereference the pointer?"
 msgstr "ý bạn là dùng not lôgíc?"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "so sánh giữa %qT và %qT"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "con trỏ đến hàm được dùng trong phép trừ"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> trên một biểu thức lôgíc"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "ý bạn là dùng not lôgíc?"
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr ""
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "đối số có loại sai đối với bộ tuyệt đối"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "phép gia tăng giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "phép giảm giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "cần một biểu thức lôgíc"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "cần một biểu thức lôgíc"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr ""
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "đối số sai kiểu cho gia số"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "sai đối số kiểu để giảm"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "tăng con trỏ tới loại không hoàn toàn %qT"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "giảm con trỏ tới loại không hoàn toàn %qT"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr ""
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C cấm chỉ biểu thức điều kiện giữa %<void *%> với con trỏ hàm"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "kiểu không khớp trong biểu thức điều kiện"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "kiểu không khớp trong biểu thức điều kiện"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C cấm chỉ áp kiểu thành kiểu hỗn hợp"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "phép gán %qT cho %qT không tương thích kiểu"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "chuyển đổi enum trong bộ khởi tạo thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "mảng bị khởi tạo từ hằng số chuỗi nằm trong ngoặc đơn"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "cần %qT nhưng đối số là kiểu %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "built-in %qD declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in assignment is invalid in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "chuyển đổi enum trong bộ khởi tạo thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in initialization is invalid in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "chuyển đổi enum trong bộ khởi tạo thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in return is invalid in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "chuyển đổi enum trả về thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "implicit conversion from %qT to %qT"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 msgid "return discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr ""
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, gcc-internal-format
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr ""
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr ""
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "phép gán %qT cho %qT không tương thích kiểu"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "increment of pointer to an incomplete type %qT"
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "tăng con trỏ tới loại không hoàn toàn %qT"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "increment of pointer to an incomplete type %qT"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "tăng con trỏ tới loại không hoàn toàn %qT"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "increment of pointer to an incomplete type %qT"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "tăng con trỏ tới loại không hoàn toàn %qT"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "return with value in function with no return type"
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "trả về giá trị trong một hàm mà có kiểu không trả về"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "đối số %d của %qE phải là bội số của %d"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "kiểu không tương thích cho đối số %d của %qE"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "mảng loại không thích hợp bị khởi tạo từ hằng số chuỗi"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sai sử dụng mảng không phải lvalue"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "yếu tố khởi tạo không phải hằng số"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "mảng bị khởi tạo từ biểu tượng mảng không phải hằng số"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "yếu tố khởi tạo không tính được vào lúc nạp"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "bộ khởi tạo sai"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "gặp nhóm ngoặc móc thừa tại kết thúc của bộ khởi tạo"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "bộ phận mảng dẻo bị khởi tạo trong một ngữ cảnh lồng nhau"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "thiếu ngoặc móc chung quanh bộ khởi tạo"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr ""
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "bộ khởi tạo vô hướng vẫn trống"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo vô hướng"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "gặp chỉ mục mảng trong bộ khởi tạo không phải mảng"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "không có tên trường trong bộ khởi tạo hợp hoặc mục ghi"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không có loại số nguyên"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải là một biểu tượng hằng số nguyên"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải hằng số"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng vượt quá giới hạn mảng"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "bộ khởi tạo chứa phạm vi chỉ mục vẫn trống"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "bộ khởi tạo chứa một phạm vi chỉ mục mảng vượt quá giới hạn mảng"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "trường đã khởi tạo với hiệu ứng khác bị ghi đè"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "trường đã khởi tạo bị ghi đè"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "chuyển đổi enum trong bộ khởi tạo thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo mảng ký tự"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo cấu trúc"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "một bộ phận mảng dẻo bị khởi tạo một cách không phải tĩnh"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo mảng"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo véc-tơ"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo vô hướng"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C cấm %<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "hàm đã khai báo %<noreturn%> có một câu lệnh %<return%>"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> với một giá trị, trong hàm trả lại void (rỗng)"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "hàm trả về địa chỉ của biến cục bộ"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "câu lệnh “continue” nằm ở ngoài một vòng lặp"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "câu lệnh không có tác dụng"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C cấm chỉ việc so sánh của %<void *%> với con trỏ hàm"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma simd%> clause"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "cần mệnh đề %<#pragma simd%>"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %qs"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE không phải là thành viên của union"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD trong mệnh đề %qs"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in %qs"
 msgid "expected single pointer in %qs clause"
 msgstr "Gặp kết thúc tập tin bất thường tại %qs"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, fuzzy, gcc-internal-format
 #| msgid "%<vector%> length expression must be integral"
 msgid "for array function parameter length expression must be specified"
 msgstr "chiều dài %<vector%> phải là số nguyên"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr ""
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> applied to a qualified type"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "%<_Atomic%> áp dụng cho kiểu hạn định"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr ""
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression for output modifier '%c'"
 msgid "end expression refers to outer iterator %qD"
 msgstr "biểu thức không hợp lệ cho bộ sửa đầu ra “%c”"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 #| msgid "linear step expression must be integral"
 msgid "step expression refers to outer iterator %qD"
 msgstr "biểu thức bước thẳng phải là số nguyên"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected pointer in %qs clause"
 msgstr "cần con trỏ"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, fuzzy, gcc-internal-format
 #| msgid "%qD in %<reduction%> clause is a zero size array"
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "%qD trong mệnh đề %<reduction%> là một mạng cỡ không"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD trong mệnh đề %<reduction%> là một mạng cỡ không"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %<reduction%>"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer %qs in %s clause at %L"
 msgid "zero sized type %qT in %qs clause"
 msgstr "Con trỏ Cray %qs trong mệnh đề %s tại %L"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qD is used"
 msgid "variable sized type %qT in %qs clause"
 msgstr "mảng có độ dài biến đổi %qD được dùng"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE có kiểu không hợp lệ cho %<reduction(%s)%>"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE phải là %<threadprivate%> với %<copyin%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<depend%>"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not an argument in %<uniform%> clause"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<depend%>"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE không phải một kiểu ánh xạ được trong mệnh đề %qs"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE không phải một biến cũng không phải tên hàm trong mệnh đề %qs"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "nguồn không phải là một hàm trỏ"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -46863,7 +46892,7 @@ msgstr "  cho chuyển đổi từ %qT thành %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  không hiểu chuyển đổi cho đối số %d từ %qT thành %qT"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -46984,686 +47013,690 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%D(%A)%> chưa rõ ràng"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "cú gọi không khớp tới %<(%T) (%A)%>"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "cú gọi của %<(%T) (%A)%> chưa rõ ràng"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "quá tải chưa rõ ràng đối với"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, gcc-internal-format
 msgid "no match for "
 msgstr "không khớp cho"
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (các kiểu toán hạng là %qT, %qT, and %qT)"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (các kiểu toán hạng là %qT và %qT)"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (kiểu toán hạng là %qT)"
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "bộ tam nguyên %<operator?:%>"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "bộ tam nguyên %<operator?:%> trong %<%E ? %E : %E%>"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> trong %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> trong %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs trong %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%>"
 msgid "%<operator %s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator%s%> trong %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> trong %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> trong %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "cú gọi hàm không được xuất hiện trong biểu thức hằng"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "kiểu không khớp trong biểu thức điều kiện"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "kiểu không khớp trong biểu thức điều kiện"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "return type of %qD is not %qs"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "so sánh giữa %q#T và %q#T"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is a usual (non-placement) deallocation function"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "đã được khai báo ở đây"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "được khai báo bảo vệ ở đây"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D là không thể truy cập trong ngữ cảnh này"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  đã được khai báo ở đây"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  đang khởi tạo đối số %P của %qD"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr ""
+
+#: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind %qT lvalue to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "không thể buộc %qT lvalue thành %qT"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  trong gọi đến %qD"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, fuzzy, gcc-internal-format
 #| msgid "re-initialization of %qs at %L"
 msgid "; use copy-initialization instead"
 msgstr "khởi tạo lại của %qs tại %L"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%#qT declared here"
 msgstr "%qT được khai báo ở đây"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "cú gọi không khớp tới %<(%T) (%A)%>"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "không thể gọi cấu tử %<%T::%D%> một cách trực tiếp"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%s(%A)%> chưa rõ ràng"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "trả về một giá trị từ hủy tử"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "đóng %qD thông qua %qD"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  cho chuyển đổi từ %qT thành %qT"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " ứng cử 1: %q#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " ứng cử 2: %q#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -47687,1172 +47720,1172 @@ msgstr ""
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr ""
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr ""
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D inherited from %qT"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D kế thừa từ %qT"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "version inherited from %qT declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D không thể được quá tải"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "khai báo trước đây %q#D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  bởi vì phương thức nội bộ %q+#D có cùng tên"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  bởi vì thành viên nội bộ %q+#D có cùng tên"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 #| msgid "array member %q#D declared here"
 msgid "local member %q#D declared here"
 msgstr "thành viên mảng %q#D đã khai báo ở đây"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT được khai báo ở đây"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%q#D không thể được tạo đè"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%q+D bị ẩn"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  bởi %q+D"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr ""
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "độ rộng bị âm trong trường bít %q+D"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "trường bít %q+D có độ rộng là không"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, fuzzy, gcc-internal-format
 #| msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ref-qualifiers chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "đối số %qD được khai báo với kiểu void"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "đối số %qD được khai báo với kiểu void"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "next member %q#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "trường %q#D với cùng tên với lớp"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T có thành viên dữ liệu con trỏ"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  nhưng không đè %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  hoặc %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  nhưng không được ghi đè %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "next member %q#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T không là kiểu văn chương vì:"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  lớp cơ sở %qT của %q+T là non-literal"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu hay thay đổi"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "lớp cơ sở %q+T có một hủy tử non-trivial truy cập được"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "thành viên mảng %q#D đã khai báo ở đây"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "trong định nghĩa của %q#T"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "định nghĩa lại của %q#T"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "không đủ thông tin kiểu"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
 msgstr "khai báo lại ở đây như là %q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr ""
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr ""
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr ""
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T có lớp cơ sở ảo"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not an function argument"
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD không phải là đối số hàm"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E không phải biểu thức hằng"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "gọi hàm nội bộ"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 #| msgid "originally defined here"
 msgid "originally declared %<const%> here"
 msgstr "định nghĩa lần đầu ở đây"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 #| msgid "variable %D of type %<cb%> must be uninitialized"
 msgid "virtual table pointer is used uninitialized"
 msgstr "biến %D của kiểu %<cb%> phải không được khởi tạo"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 #| msgid "  %qT is an ambiguous base class of %qT"
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "  %qT là lớp cơ sở chưa rõ ràng của %qT"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "gọi hàm nội bộ"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "allocation performed here"
 msgstr "union được định nghĩa ở đây"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, fuzzy, gcc-internal-format
 #| msgid "Attempting to allocate already allocated variable"
 msgid "deallocation of already deallocated storage"
 msgstr "Đang cố cấp phát một biến đã được cấp phát rồi"
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, gcc-internal-format
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD được gọi trong một biểu thức hằng"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD được dùng trước khi nó được định nghĩa"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "toán hạng phải của biểu thức dịch %q+E là số âm"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "right operand of shift expression %q+E is negative"
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "toán hạng phải của biểu thức dịch %q+E là số âm"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%s không thể được dùng trong asm ở đây"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "con trỏ rỗng"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer is not an integer constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải là một biểu tượng hằng số nguyên"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "được khai báo ở đây"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD được dùng trong bộ khởi tạo của chính nó"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D không là const"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D là volatile"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD không được khởi tạo với một biểu thức hằng"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "Đổi giá trị trong chuyển đổi từ %qs sang %qs tại %L"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "cast from %qT is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "cần template-id"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<constexpr%> outside its class"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD được khai báo %<constexpr%> ngoài lớp của nó"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "cần AST thuộc kiểu %s"
@@ -48862,56 +48895,56 @@ msgstr "cần AST thuộc kiểu %s"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<concept%>"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "hủy tử không thể là %<concept%>"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD không phải là một kiểu"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have integral type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "evaluating %qs"
@@ -48961,7 +48994,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -49352,7 +49385,7 @@ msgstr "từ khai báo trước đây %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "khai báo trước đây %q#D"
@@ -49491,8 +49524,8 @@ msgstr ""
 msgid "%q#D previously defined here"
 msgstr "%q#D trước được định nghĩa ở đây"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D trước định nghĩa ở đây"
@@ -49528,58 +49561,58 @@ msgstr ""
 msgid "previous specification in %q#D here"
 msgstr "sau đặc tả trước đây trong %q#D"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 #| msgid "section type conflict with %D"
 msgid "declaration %qD conflicts with builtin"
 msgstr "kiểu phần xung đột với %D"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "section type conflict with %D"
 msgid "declaration %qD conflicts with import"
 msgstr "kiểu phần xung đột với %D"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 #| msgid "  declared here"
 msgid "import declared %q#D here"
 msgstr "  đã được khai báo ở đây"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "conflicting exporting declaration %qD"
 msgstr "khai báo xung đột %q+#D"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q#D"
 msgid "previous declaration %q#D here"
 msgstr "khai báo trước đây %q#D"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "định nghĩa trước đây của %q+D là đây"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "khai báo trước đây của %q+D ở đây"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared %<virtual%> inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr ""
@@ -49592,49 +49625,49 @@ msgstr ""
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "định nghĩa lại của %q#D"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D chưa được khai báo trong lớp"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD redeclared as inline"
 msgid "deduction guide %q+D redeclared"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline)"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -49642,2357 +49675,2373 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "khai báo lại của %q#D"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "tái khai báo không hợp lệ cho %q+D"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "khai báo trước"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  từ đây"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  thoát khỏi khối được cấu trúc OpenMP"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  sự khởi tạo chéo của %q+#D"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  vào khối try"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  vào khối catch"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  vào khối được cấu trúc OpenMP"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "cần biểu thức"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  bỏ qua sự khởi tạo của %q#D"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "%qD used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD không phải là một mẫu hàm"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T không phải là một lớp"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "không có kiểu có tên %q#T trong %q#T"
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-falign-labels=%d không được hỗ trợ"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> chỉ có thể được chỉ định trong một lớp"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> chỉ có thể được chỉ định cho cấu tử"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> chỉ có thể được chỉ định cho lớp và hàm"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> bị bỏ qua trong khai báo này"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "%qD được khởi tạo bằng chính nó"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D không phải là thành viên tĩnh của %q#T"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ không cho phép %<%T::%D%> được định nghĩa như là %<%T::%D%>"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "khởi tạo lặp lại cho %qD"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared %<virtual%> inside a union"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD được khai báo như là một tham chiếu nhưng lại chưa được khởi tạo"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "thiếu kích thước mảng trong %qD"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "uninitialized %<const %D%>"
 msgstr "lặp lại %<const%>"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "quá nhiều bộ khởi tạo cho %qT"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "kiểu trả về là một kiểu không hoàn toàn"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "đối số %q#D có kiểu chưa đầy đủ"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "một bộ phận mảng dẻo bị khởi tạo một cách không phải tĩnh"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "tham chiếu %qD được khởi tạo bằng chính nó"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to constructor %q#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "quá ít đối số cho hủy tử %q#D"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "nguồn là một hàm trỏ tới loại không hoàn toàn"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "không thể giải mã địa chỉ"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "nguồn có loại lớp không hoàn toàn"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "thiếu kích thước mảng trong %qT"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "mảng có kích thước không %qT"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD được khai báo là một biến %<virtual%>"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD được khai báo như là đối số %<virtual%>"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD được khai báo là một đối số %<inline%>"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD được khai báo như là kiểu %<virtual%>"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD được khai báo là một kiểu %<inline%>"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD được khai báo như là trường %<virtual%>"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD được khai báo là một trường %<inline%>"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "a function concept cannot be constrained"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD không phải là một hàm mẫu"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> phải trả về %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D đã là mặc định rõ ràng ở đây"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr ""
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "a variable concept cannot be constrained"
 msgstr "Biến vòng lặp tại %C không thể là một coarray"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ cấm mảng có kích thước bằng không"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ cấm biến có kích thước biến đổi %qD"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ cấm biến có kích thước biến đổi"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "mảng có độ dài biến đổi %qD được dùng"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tràn kích thước mảng"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD được khai báo là mảng của %qT"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "đang tạo mảng của %qT"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "sự khai báo của %qD như là mảng void"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "tạo mảng void"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "sự khai báo của %qD như là mảng của các hàm"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "tạo mảng hàm"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "sự khai báo của %qD như là mảng của các tham chiếu"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "tạo mảng tham chiếu"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "sự khai báo của %qD như là mảng của các thành viên hàm"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "tạo mảng của thành viên hàm"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 #| msgid "no processor type specified for linking"
 msgid "return type specified for deduction guide"
 msgstr "chưa ghi rõ loại bộ xử lý cần liên kết"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "biến hay trường được khai báo là void"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<::%D%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%T::%D%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%D::%D%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "sự khai báo của %qD như là non-member"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "định nghĩa hàm không khai báo đối số"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "sự khai báo của %qD như là %<typedef%>"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 #| msgid "%qs cannot appear in a constant-expression"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs không thể xuất hiện trong biểu thức hằng"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ không hỗ trợ %<__int%d%> cho %qs"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> và %<unsigned%> được chỉ định cùng với nhau cho %qs"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> và %<short%> được chỉ định cùng nhau với %qs"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qT"
 msgstr "%qs được dùng với %qE"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "số ảo không hợp lệ cho %qs"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> ngoài khai báo lớp"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "thuộc tính bị bỏ qua"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Mong đợi một dấu ngoặc đơn mở"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 #| msgid "@catch parameter can not be protocol-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "đối số @catch không thể là từ hạn định giao thức"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not have parameters"
 msgid "constructors may not be ref-qualified"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "không thể khai báo con trỏ cho thành viên %q#T"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD được dùng như bộ khai báo"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> ngoài khai báo lớp"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "typedef may not be a function definition"
 msgstr "định nghĩa hàm theo cách cũ"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "typedef may not be a member function definition"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef được khai báo %<auto%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD không phải là một mẫu hàm"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 không hỗ trợ thành viên mảng linh động"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "dùng %<::%> không hợp lệ"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "cấu tử không thể là %<concept%>"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "không thể mở %s"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 #| msgid "static data member %qD in unnamed class"
 msgid "static data member %qE declared %qs"
 msgstr "thành viên dữ liệu tĩnh %qD trong lớp không tên"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared with placeholder %qT"
 msgid "non-static data member %qE declared %qs"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> không sử dụng khi định nghĩa (như ngược với khai báo) một thành viên dữ liệu tĩnh"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "khai báo của %q#D chưa có bộ khởi tạo"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD không được khai báo như là tĩnh"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số của nó"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số thứ hai của nó"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "tiền tố %qD cần trả về %qT"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "hậu tố %qD cần trả về %qT"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD cần trả về bằng giá trị"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT được coi là %qs"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+T có một khai báo trước ở đây"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT được coi là enum"
@@ -52004,106 +52053,106 @@ msgstr "%qT được coi là enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT không phải một mẫu"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare %qD in a different module"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT được định nghĩa với cơ sở đa trực tiếp"
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT được định nghĩa cơ sở trực tiếp ảo"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "định nghĩa trước ở đây"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, gcc-internal-format
 msgid "cannot define %qD in different module"
 msgstr ""
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
@@ -52112,79 +52161,79 @@ msgstr "đối số %d của %qE phải là một địa chỉ"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "increment of enumeration value is invalid in C++"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "phép gia tăng giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "nhiều định nghĩa cho %q#T"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> cần trả về một tham chiếu đến %<*this%>"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD đã sẵn định nghĩa trong %qT"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -52224,7 +52273,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "cho khai báo hàm mẫu %q+D"
@@ -52234,7 +52283,7 @@ msgstr "cho khai báo hàm mẫu %q+D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -52570,24 +52619,24 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, fuzzy, gcc-internal-format
 #| msgid "converting far pointer to near pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "không thể chuyển đổi thành kiểu con trỏ"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "lệnh không thỏa những ràng buộc của nó:"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -52709,7 +52758,7 @@ msgstr ""
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
@@ -52720,7 +52769,7 @@ msgstr "%qD không phải là thành viên của %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD không phải là thành viên của %qD"
@@ -52910,411 +52959,411 @@ msgstr ""
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD được khởi tạo bằng chính nó"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D nên được khởi tạo"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD sẽ được khởi tạo sau"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  cơ sở %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  khi khởi tạo ở đây"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "kiểu %qT không là cơ sở trực tiếp của %qT"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "con trỏ cho trường bít %qD không hợp lệ"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "at offset %wi from %qD declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "tràn số nguyên trong kích thước mảng"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "kiểu không hợp lệ %<void%> cho new"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "bộ khởi tạo kết thúc bất ngờ"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr ""
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -53372,62 +53421,62 @@ msgstr ""
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr ""
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr ""
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -53619,323 +53668,323 @@ msgstr ""
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected signature: %qD"
 msgstr "cần con trỏ"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "một mẫu không thể là mặc định"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD không thể là mặc định"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "khai báo của %qD như là đối số"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D xung đột với khai báo trước"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 #| msgid "%d constructor found\n"
 #| msgid_plural "%d constructors found\n"
 msgid "%q#D hides constructor for %q#D"
 msgstr "Tìm thấy %d bộ cấu trúc\n"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "khai báo xung đột %q+#D"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr ""
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D previously declared here"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "%q#D trước định nghĩa ở đây"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "sự khai báo của các bóng %qD như là thành viên của %qT"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%q#D does not have external linkage"
 msgstr "%qE không có kiểu lớp"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D được khai báo ở đây"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> tên hủy tử"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%E%> is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%<::%E%> không phải là một lớp, namespace, hay enumeration"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "kiểu %qT không là cơ sở trực tiếp của %qT"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared in %qD"
 msgstr "%qD chưa được khai báo trong %qD"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of namespace %qD here"
 msgid "using-declaration may not name namespace %qD"
 msgstr "khai báo trước đây của không gian tên %qD ở đây"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> các tên cấu tử trong %qT"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD chưa được khai báo trong %qD"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "các khả năng được gợi ý:"
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "the macro %qs had not yet been defined"
 msgstr "%qD đã định nghĩa rồi"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "struct được định nghĩa ở đây"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fabi-version=1%> is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%<-fabi-version=1%> không còn tiếp tục được hỗ trợ nữa"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%qs tại %L phải là số nguyên"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr ""
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "định nghĩa trước ở đây"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX vào pop_everything ()\n"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -53961,7 +54010,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -53986,7 +54035,7 @@ msgstr "%<::%E%> chưa được khai báo"
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> chưa được khai báo"
@@ -54066,7 +54115,7 @@ msgstr "template-id không hợp lệ"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "cú gọi hàm không được xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -54208,7 +54257,7 @@ msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> chỉ sẵn sàng với -fconcepts"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, fuzzy, gcc-internal-format
 #| msgid "%<requires%> only available with -fconcepts"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -54335,7 +54384,7 @@ msgstr ""
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "cần khai báo"
@@ -54386,7 +54435,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "cần biểu thức cơ bản"
@@ -54416,7 +54465,7 @@ msgstr ""
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr ""
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
@@ -54438,12 +54487,12 @@ msgstr "phần khai báo của %<~%T%> là thành viên của %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "cần unqualified-id"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD không phải một mẫu"
@@ -54479,7 +54528,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr "cần nested-name-specifier"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
@@ -54494,7 +54543,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "sai số tham số cho %<__builtin_addressof%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "đối số sai số lượng cho %<__builtin_launder%>"
@@ -54509,1164 +54558,1170 @@ msgstr "ISO C++ cấm compound-literals"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "dùng %qD không hợp lệ"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> không phải là thành viên lớp"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "kiểu không-scalar"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined in %qs expressions"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr ""
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "dùng áp kiểu theo cách cũ"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "gợi ý bao quanh biểu thức %<>>%> bằng dấu ngoặc đơn"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ không cho phép ?: với toán hạng ở giữa bị bỏ qua"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+#| msgid "lambda-expression in a constant expression"
+msgid "lambda-expression in template parameter type"
+msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
+
+#: cp/parser.c:10819
 #, fuzzy, gcc-internal-format
 #| msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "cần kết thúc của capture-list"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, fuzzy, gcc-internal-format
 #| msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "chụp %<*this%> chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 #| msgid "%<@synthesize%> can not be used in categories"
 msgid "%<this%> cannot be captured by reference"
 msgstr "%<@synthesize%> không thể được dùng trong các-ta-lốc"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, fuzzy, gcc-internal-format
 #| msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "chụp %<*this%> chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate instance variable %q+D"
 msgid "capture of non-variable %qE"
 msgstr "trùng biến minh dụ %q+D"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr ""
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "lặp lại %<volatile%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "cần labeled-statement"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> tên cấu tử, không phải kiểu"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "cần selection-statement"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "hàm trả về một mảng"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "trường %qE được khai báo như là một hàm"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "cần bộ khởi tạo"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "Biến vòng lặp tại %C không thể là một coarray"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "cần iteration-statement"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "vòng lặp range-based %<for%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "vòng lặp range-based %<for%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ cấm tính toán gotos"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "cần jump-statement"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-name"
 msgid "expected module-name"
 msgstr "cần template-name"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, gcc-internal-format
 msgid "module-declaration not permitted in header-unit"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 #| msgid "volatile argument"
 msgid "private module fragment"
 msgstr "đối số hay thay đổi"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, gcc-internal-format
 msgid "import-declaration must be at global scope"
 msgstr ""
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 #| msgid "invalid linkage-specification"
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "đặc tả linkage không hợp lệ"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%qE may only occur once in an export declaration"
 msgstr "%<inline%> trong khai báo trống rỗng"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 #| msgid "weakref is not supported in this configuration"
 msgid "attributes are not permitted in this position"
 msgstr "weakref không được hỗ trợ trong cấu hình này"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored"
 msgid "attributes may be inserted here"
 msgstr "thuộc tính bị bỏ qua"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> mở rộng"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> không ở đầu của một khối"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "khai báo trống rỗng"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "khai báo hàm thành viên không hợp lệ"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> được dùng bên ngoài lớp"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> thay đổi ý nghĩa trong C++11; hãy bỏ nó đi"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD không hợp lệ trong lambda"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 #| msgid "%qD invalid in lambda"
 msgid "type-specifier invalid in lambda"
 msgstr "%qD không hợp lệ trong lambda"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "các mẫu không thể là %<virtual%>"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined in explicit-specifier"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "đặc tả linkage không hợp lệ"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "static_assert không có lời nhắn chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "cần định danh hậu tố"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "cần toán tử"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated and has no effect"
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "%qs đã lỗi thời và không có tác động gì"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr ""
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu mặc định"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "cần template-id"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template-id"
 msgid "invalid template-argument-list"
 msgstr "template-id không hợp lệ"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "cần template-argument"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "cần template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "cần template-argument"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr ""
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "cần bộ chỉ định kiểu"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "cần template-id cho kiểu"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "cần type-name (tên kiểu)"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE không phải tên một kiểu"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "concept defined here"
 msgstr "union được định nghĩa ở đây"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%> after %qE"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "cần %<,%> hoặc %<)%> sau %qE"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 #| msgid "expected nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "cần nested-name-specifier"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD là một mẫu liệt kê"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD không phải tên một kiểu enumeration trong %qT"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "cần %<;%> hoặc %<{%>"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "không cho phép từ hạn định mở rộng"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ cấm kiểu liệt kê nặc danh không tên trống rỗng"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qE không phải tên một kiểu"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD không là một namespace-name"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> không cho phép định nghĩa ở đây"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration here"
 msgid "opaque-enum-declaration here"
 msgstr "khai báo trước ở đây"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "trùng cv-qualifier"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT không phải là một namespace"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, gcc-internal-format
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr ""
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about implicit function declarations."
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "Cảnh báo về lời khai báo hàm ngầm."
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD redeclared as variable"
 msgid "add parentheses to declare a variable"
 msgstr "hàm %qD được định nghĩa lại thành một biến"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "không cho phép định nghĩa hàm tại đây"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> không phải một kiểu"
@@ -55675,440 +55730,440 @@ msgstr "%<%T::%E%> không phải một kiểu"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "bộ khai báo không hợp lệ"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "dùng %<%T::%D%> thay cho %<%T::%D%> cho tên của cấu tử trong tên hạn định"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "mã hạn định trong khai báo"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "cần câu khai báo"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD là một namespace"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "cần ptr-operator"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "trùng cv-qualifier"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "đa ref-qualifiers"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, fuzzy, gcc-internal-format
 #| msgid "%E requires %<-fgnu-tm%>"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%E cần %<-fgnu-tm%>"
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "trùng virt-specifier"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in template arguments"
 msgid "%qT not permitted in template argument"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "cách dùng không hợp lệ %qT"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "cần type-specifier"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "cần %<,%> hoặc %<…%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ không cho phép ?: với toán hạng ở giữa bị bỏ qua"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "cần class-name"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "cần %<;%> sau định nghĩa cấu trúc"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "cần %<;%> sau định nghĩa kiểu hỗn hợp"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "cần %<{%> hoặc %<:%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "không thể chỉ định %<override%> cho lớp"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "khai báo trước đây của %q+#T"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "cần class-key"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "cần %<;%> tại cuối khai báo thành viên"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "dùng %<auto%> không hợp lệ trong đặc tả ngoại lệ"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr ""
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "cần %<:%> hoặc %<…%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 #| msgid "expression must be integral"
 msgid "expression must be enclosed in parentheses"
 msgstr "chỉ số phải là số nguyên"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "result type is not a plain type-constraint"
 msgstr "đối số %qd không phải hằng số"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "yếu tố khởi tạo không phải hằng số"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "khai báo không hợp lệ của %<%T::%E%>"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -56117,628 +56172,628 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "đối số cho %<sizeof…%> phải được bao quanh bởi dấu ngoặc đơn"
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> trước %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "đã chỉ ra cả hai %<__thread%> và %<thread_local%>"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "trùng %qD"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "trùng %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "cần %<new%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "cần %<delete%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "cần %<return%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "cần %<extern%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "cần %<static_assert%>"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "cần %<decltype%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "cần %<operator%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "cần %<class%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "cần %<template%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "cần %<namespace%>"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "cần %<using%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "cần %<asm%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "cần %<try%>"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "cần %<catch%>"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "cần %<throw%>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>"
 msgid "expected %<auto%>"
 msgstr "cần %<data%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "cần %<__label__%>"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "cần %<@try%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "cần %<@synchronized%>"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "cần %<@throw%>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "cần %<__transaction_atomic%>"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "cần %<__transaction_relaxed%>"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "cần %<@end%>"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "cần %<::%>"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "cần %<…%>"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "cần %<*%>"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "cần %<~%>"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "cần %<:%> hoặc %<::%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T trước đã khai báo ở đây"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 #| msgid "expected class-key"
 msgid "replace the class-key with %qs"
 msgstr "cần class-key"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%qT được khai báo ở đây"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "kiểu không hợp lệ cho biến instance (minh dụ)"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "kiểu không hợp lệ cho thuộc tính"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown property attribute %qE"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "cần biểu thức nguyên"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "bộ khởi tạo sai"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined in iterator type"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "mệnh đề khởi tạo không hợp lệ"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "cần id-expression (các đối số)"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, fuzzy, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "%<#pragma omp declare reduction%> trước"
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  hoặc một hàm %<transaction_may_cancel_outer%>"
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma GCC pch_preprocess%> phải là đầu tiên"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma grainsize%> must be inside a function"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma grainsize%> phải ở bên trong một hàm"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "multi-source compilation not implemented for C++"
 msgstr "-mnop-mcount không được thực hiện cho -fPIC"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "%<this%> có lẽ không nên được dùng trong ngữ cảnh này"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "các mẫu ngầm không nên là %<virtual%>"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr ""
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  từ định nghĩa của %q#D"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q#D"
 msgid "from definition of %q#D"
@@ -56746,149 +56801,149 @@ msgstr "  từ định nghĩa của %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "%s %#D"
 msgid "%s %#qD"
 msgstr "%s %#D"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD không phải là một mẫu hàm"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD cho %q+D không khớp bất kỳ khai báo mẫu nào"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, fuzzy, gcc-internal-format
 #| msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing primary template attributes %s"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing primary template attribute %s"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "template-id %qD trong khai báo của mẫu nguyên gốc"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr ""
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD không phải là một hàm mẫu"
@@ -56901,161 +56956,161 @@ msgstr "%qD không phải là một hàm mẫu"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "khai báo trước ở đây"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr ""
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "cả hai đối số cho %<__builtin___clear_cache%> phải là các con trỏ"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "quá nhiều đối số cho hàm %qE"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -57064,47 +57119,47 @@ msgstr ""
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -57114,500 +57169,500 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "phần khai báo mẫu của %qD không hợp lệ"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "nhận được %d đối số mẫu cho %q#D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "nhận được %d đối số mẫu cho %q#T"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  nhưng cần %d"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 #| msgid "invalid explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT không phải là một kiểu mẫu"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "đối số mẫu %q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "khai báo lại ở đây như là %q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D with different type"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "định nghĩa lại của typedef %q+D với kiểu khác"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "định nghĩa nguyên bản xuất hiện ở đây"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "nhận được %d đối số mẫu cho %q#D"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  kiểu không khớp %qT và %qT"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE không tương đương với %qE"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  ứng cử cần ít nhất %d đối số, nhưng cung cấp %d"
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  không thể chuyển đổi %qE (kiểu %qT) thành kiểu %qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT là lớp cơ sở chưa rõ ràng của %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT không được dẫn xuất từ %qT"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "không thể giải mã địa chỉ"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "quá nhiều đối số cho cho phương thức %qE"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "in template argument for type %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "quá nhiều đối số cho cho phương thức %qE"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "dùng %qE để thay thế"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  cần hằng của kiểu %qT, nhưng lại nhận được %qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  cần kiểu, nhưng lại nhận %qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  cần một kiểu, nhưng lại nhận được %qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  cần mẫu kiểu %qD, nhưng lại nhận được %qT"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  cần %qD nhưng lại nhận %qD"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "sai số lượng đối số mẫu (%d, cần ít nhất phải là %d)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "được cung cấp cho %qD"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D không phải là hàm mẫu"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 #| msgid "template constraint failure"
 msgid "template constraint failure for %qD"
 msgstr "ràng buộc mẫu gặp lỗi nghiêm trọng"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE không ở đầu của khai báo"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
@@ -57625,298 +57680,298 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "biến %qD có kiểu hàm"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "kiểu đối số không hợp lệ %qT"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "trong khai báo %q+D"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "hàm trả về một mảng"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "hàm trả về hàm"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "đang tạo con trỏ đến thành viên của kiểu void"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT không phải có kiểu lớp, cấu trúc hay union"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "dùng %qs trong mẫu"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "đang dùng trường không hợp lệ %qD"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "dùng %<this->%D%> thay thế"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "dùng %<%T::%D%> thay thế"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "sai số lượng đối số cho %<__builtin_choose_expr%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD không phải là một lớp hay namespace"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT là/dùng kiểu nặc danh"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "biểu thức nguyên %qE không là hằng"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 #| msgid "%s %#S"
 msgid "%s %#qS"
 msgstr "%s %#D"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate instance variable %q+D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "trùng biến minh dụ %q+D"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "khai báo ngầm của hàm %qE"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD không phải là một thành viên dữ liệu tĩnh của một mẫu lớp"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 #| msgid "previous specification in %q#D here"
 msgid "exception specification of %qD depends on itself"
@@ -57929,157 +57984,157 @@ msgstr "sau đặc tả trước đây trong %q#D"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "a concept cannot be constrained"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace or unscoped enum"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT không phải là một namespace hay enum không hoạt vi"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "hàm không phải được tính để chèn vào trực tiếp"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in template argument"
 msgid "invalid use of %qT in template argument"
@@ -58222,552 +58277,552 @@ msgstr "%q+#D không thể được khai báo"
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared %<constexpr%>"
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "catching non-reference type %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, gcc-internal-format
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "%qE missing template arguments"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE không thể dùng như một hàm"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE không là kiểu %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "định nghĩa không hợp lệ của kiểu hạn định %qT"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "đặc tả lớp-cơ-sở không hợp lệ"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "không thể chụp thành viên %qD trong hỗn hợp nặc danh"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD không bị bắt"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 #| msgid "use of deleted function %qD"
 msgid "use of parameter outside function body"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing template arguments"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "không hiểu kiểu của %qE"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT không phải một kiểu enumeration"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "biểu thức bước thẳng phải là số nguyên"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD không phải một biến trong mệnh đề %<lastprivate%>"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "biểu thức tĩnh %<gang%> phải nguyên"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<gang%> static value must bepositive"
 msgid "%<gang%> static value must be positive"
 msgstr "giá trị tĩnh %<gang%> phải dương"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "biểu thức số %<gang%> phải nguyên"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "chiều dài %<vector%> phải là số nguyên"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "biểu thức số %<worker%> phải là số nguyên"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%> giá trị phải dương"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "%<vector%> length value must bepositive"
 msgid "%<vector%> length value must be positive"
 msgstr "chiều dài %<vector%> giá trị phải dương"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%<worker%> num value must bepositive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%> giá trị phải dương"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%> biểu thức phải nguyên"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%> biểu thức phải nguyên"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<depend%> clause"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD không phải một biến trong mệnh đề %<depend%>"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not an argument in %<uniform%> clause"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<aligned%> clause"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<aligned%> clause"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<depend%> clause"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD không phải một biến trong mệnh đề %<depend%>"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "target is not pointer or reference to complete type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "đích không phải là hàm trỏ hoặc tham chiếu đến loại hoàn toàn"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "%<tile%> value must be integral"
 msgid "%<tile%> argument needs integral type"
 msgstr "giá trị %<tile%> phải là số nguyên"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "thẩm tra tĩnh gặp lỗi: %s"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, gcc-internal-format
 msgid "%qE evaluates to false"
 msgstr ""
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "<chưa giải quyết loại hàm quá tải>"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
@@ -58775,22 +58830,22 @@ msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -58800,1100 +58855,1101 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "  declared here"
 msgid " declared here"
 msgstr "  đã được khai báo ở đây"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 #| msgid "  base class %qT of %q+T is non-literal"
 msgid "base class %qT is not public"
 msgstr "  lớp cơ sở %qT của %q+T là non-literal"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not captured"
 msgid "%qD is not public"
 msgstr "%qD không bị bắt"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD không phải là một biến"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD has a non-structural type"
 msgstr "%qD không phải là một kiểu"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "đối số thuộc tính phần không phải là một hằng chuỗi"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "%<typeof%> applied to a bit-field"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%<typeof%> được áp dụng cho một bit-field"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 #| msgid "the %qE attribute requires arguments"
 msgid "%qE attribute takes no arguments"
 msgstr "thuộc tính %qE cần tham số"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute doesn't apply to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "Thuộc tính %qE không được áp dụng cho các hàm"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer is not an integer constant expression"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải là một biểu tượng hằng số nguyên"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "thuộc tính %qE cần tham số"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* check: gặp lỗi trong %s, tại %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 has invalid type"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "đối số 2 có kiểu không hợp lệ"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "lấy địa chỉ của mảng tạm"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ cấm chuyển đổi hằng chuỗi thành %qT"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "việc chuyển đổi từ chuỗi thành %qT đã lỗi thời"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of non-static data member %qE"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T không có thành viên nào mang tên %qE"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> không phải là thành viên của %qT"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT không là cơ sở của %qT"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT không phải kiểu con trỏ đến đối tượng"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ cấm gọi %<::main%> từ bên trong chương trình"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE không thể dùng như một hàm"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD không thể được dùng như một hàm"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "quá nhiều đối số cho cấu tử %q#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "quá ít đối số cho hủy tử %q#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "quá nhiều đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "quá ít đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "quá nhiều đối số cho hàm %q#D"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "quá ít đối số cho hàm %q#D"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "quá nhiều đối số cho phương thức %q#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "quá ít đối số cho phương thức %q#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "quá nhiều đối số cho hàm"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "quá ít đối số cho hàm"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "trình biên dịch sẽ coi rằng địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL được dùng trong số học"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "các kiểu toán hạng là %qT và %qT"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr ""
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "Unrecognized option to floating-point init value: %qs"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "Không nhận ra tùy chọn để khởi tạo giá trị dấu chấm động: %qs"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "lấy địa chỉ của cấu tử %qE"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "lấy địa chỉ của hủy tử %qE"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  cần qualified-id"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "đang lấy địa chỉ của mẫu"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "không thể lấy địa chỉ của %qs"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of an immediate function %qD"
 msgstr "lấy địa chỉ của hủy tử %qE"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, fuzzy, gcc-internal-format
 #| msgid "%<~%> on a boolean expression"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> trên một biểu thức lôgíc"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "useless cast to type %qT"
 msgid "useless cast to type %q#T"
 msgstr "trừ phi ép thành kiểu %qT"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "%E qualifier ignored on asm"
 msgid "type qualifiers ignored on cast result type"
 msgstr "từ hạn định %E bị bỏ qua trên asm"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "đang chuyển đổi từ %qT thành %qT"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
-msgstr ""
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid conversion from %qT to %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
+msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "áp đổi kiểu tử %qT thành %qT làm mất độ chính xác"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "áp đổi kiểu tử %qT thành %qT yêu cầu tăng cân chỉnh của kiểu đích"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ cấm việc áp đổi kiểu của mảng %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  trong định giá %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "gán giá trị cho mảng từ một danh sách bộ khởi tạo"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "phép gán %qT cho %qT không tương thích kiểu"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "mảng được dùng như là bộ khởi tạo"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "gán mảng không hợp lệ"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 #| msgid "%qD cannot have default arguments"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in return"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "trong đối số chuyển qua %P của %qD"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "trả về tham chiếu đến tạm thời (temporary)"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "tham chiếu đến biến cục bộ %qD được trả về"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "địa chỉ của nhãn %qD được trả về"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "địa chỉ của biến cục bộ %q+D được trả về"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "too many values in return statement"
 msgid "redundant move in return statement"
 msgstr "quá nhiều giá trị trong lệnh trả về"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "trả về một giá trị từ hủy tử"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "trả về danh sách bộ khởi tạo"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function returning 'void'"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "biểu thức trả về với một giá trị, trong hàm trả lại “void”"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 #| msgid "using temporary as lvalue"
 msgid "using rvalue as lvalue"
@@ -60167,107 +60223,102 @@ msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "toán hạng cơ sở của %<->%> không phải là một con trỏ"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -60287,287 +60338,293 @@ msgstr "không thể mở tập tin nhật ký %<vtv_set_ptr_data.log%>: %m"
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr "không thể mở tập tin nhật ký %<vtv_count_data.log%>: %m"
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "extern symbols cannot have initializers"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of type void"
 msgid "variables cannot be of type void"
 msgstr "đang tạo con trỏ đến thành viên của kiểu void"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot be declared to be a function"
 msgstr "%qE không thể dùng như một hàm"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of %<struct %E%>"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "định nghĩa lại của %<struct %E%>"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be %s"
 msgstr "không thể mở %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be `scope` and `%s`"
 msgstr "không thể mở %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> can only be specified for functions"
 msgid "inout variables can only be declared inside inout functions"
 msgstr "%<inline%> chỉ có thể được chỉ định cho hàm"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "không thể khởi tạo hàm bạn %qs"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "manifest constants must have initializers"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải hằng số"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "braced spec body %qs is invalid"
 msgid "size of type %s is invalid"
 msgstr "thân của đặc tả giữa ngoặc móc %qs không hợp lệ"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "%s does not have a default initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "is not a static and cannot have static initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, gcc-internal-format
 msgid "static storage variables cannot have destructors"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "string expected for library name"
 msgstr "cần tên lớp"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 #| msgid "expected function name"
 msgid "string expected for mangled name"
 msgstr "cần tên hàm"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "không có đối số nào"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on primary template declaration."
 msgid "can only apply to a single declaration"
 msgstr "Cảnh báo về khai báo hàm mẫu sơ cấp."
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "incomplete mixin declaration (%s)"
 msgstr "khai báo xung đột %q+#D"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, gcc-internal-format
 msgid "base type must not be void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "circular reference to enum member"
 msgstr "trả về tham chiếu đến tạm thời (temporary)"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template tuple parameter must be last one"
 msgstr "các đối số tạm không thể là bạn"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "chèn vào trực tiếp một cách đệ quy"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "chèn vào trực tiếp một cách đệ quy"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "error instantiating"
 msgstr "lỗi ghi %qs"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs must be the first clause of %qs"
 msgid "%s must be a function instead of %s"
 msgstr "%qs phải là mệnh đề đầu tiên của %qs"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, gcc-internal-format, gfc-internal-format
 msgid "without `this` cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "functions cannot return __fp16 type"
 msgid "functions cannot be scope"
@@ -60576,45 +60633,55 @@ msgstr "hàm không thể trả lại loại __fp16"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%s functions cannot be abstract"
 msgstr "%qs hàm không có đối số"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about overloaded virtual function names."
 msgid "cannot override a non-virtual function"
 msgstr "Cảnh báo về các tên hàm ảo quá tải."
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify both -C and -o"
 msgid "cannot be both final and abstract"
 msgstr "không thể ghi rõ đồng thời hai tùy chọn --C và -o"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -60622,184 +60689,184 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overriding final function %q+D"
 msgid "cannot override final function %s"
 msgstr "đang dè lên hàm cuối %q+D"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "initializer provided for function"
 msgid "multiple overrides of same function"
 msgstr "bộ khởi tạo được cung cấp cho hàm"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr "%qs không tương thích với %s %s"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 msgid "does not override any function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overriding final function %q+D"
 msgid "cannot override final function %s.%s"
 msgstr "đang dè lên hàm cuối %q+D"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions"
 msgid "override only applies to class member functions"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn about overloaded virtual function names."
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "Cảnh báo về các tên hàm ảo quá tải."
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "first argument must be []byte"
 msgid "first argument must be type size_t, not %s"
 msgstr "đối số đầu tiên phải là []byte"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structs, unions cannot be abstract"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, gcc-internal-format
 msgid "circular inheritance"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "đang bỏ qua thư mục trùng \"%s\"\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot inherit from final class %s"
 msgstr "không thể tìm thấy tập tin cho lớp %s"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "base class %q#T has accessible non-virtual destructor"
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "lớp cơ sở %q+T có một hủy tử non-trivial truy cập được"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "template-id %qD cho %q+D không khớp bất kỳ khai báo mẫu nào"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot read %s"
 msgid "cannot resolve"
 msgstr "Không thể đọc %s"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot take address of %qs"
 msgid "cannot alias an expression %s"
@@ -60815,22 +60882,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "Alias has non-alias reference"
 msgid "has forward references"
@@ -60896,23 +60963,22 @@ msgstr ""
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "kiểu trả về hàm không thể là hàm"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "destructor priorities are not supported"
 msgid "naked assembly functions with contracts are not supported"
@@ -61457,7 +61523,7 @@ msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -62564,12 +62630,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
@@ -62750,7 +62816,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -65275,7 +65341,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -65359,7 +65425,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -65499,12 +65565,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -65615,546 +65681,546 @@ msgstr ""
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Đối số thủ tục không hợp lệ tại %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "Interface %qs at %L may not be a statement function"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Giao diện %qs tại %L không thể là hàm khai báo"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Chiều dài chuỗi thật vẫn nhỏ hơn điều khai báo cho đối số giả “%qs” (%lu/%lu) tại %L"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Đối số thực tế có chứa quá ít phần tử cho đối số giả “%qs” (%lu/%lu) tại %L"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Cần một con trỏ thủ tục cho đối số %qs tại %L"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr ""
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Thiếu đối số đối thực tế cho đối số %qs tại %L"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Mã thành phần sai"
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Danh sách không khớp"
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Danh sách không khớp"
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Thủ tục %qs được gọi tại %L không được khai báo rõ ràng"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Thủ tục %qs được gọi tại %L không được khai báo rõ ràng"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument %qs at %L"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "không thể tìm thấy ký hiệu %qs"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Kiểu giao diện sai"
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC %qs at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "không thể đè GENERIC %qs tại %L"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "thẻ %s tại %L phải là kiểu %s"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là các loại %d"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Đối số giả chưa dùng %qs tại %L"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Quá nhiều đối số cho %s tại %L"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Quá nhiều đối số cho %s tại %L"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Tham số %qs của thủ tục cơ bản tại %L phải là vô hướng"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Quá nhiều đối số trong cuộc gọi đến %qs tại %L"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Quá nhiều đối số trong cuộc gọi đến %qs tại %L"
@@ -66305,34 +66371,34 @@ msgstr "Hàm %qs được khởi tạo giống như là một biểu thức %L"
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Chuyển đổi từ %s sang %s tại %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Chuyển đổi từ %s sang %s tại %L"
@@ -66340,24 +66406,24 @@ msgstr "Chuyển đổi từ %s sang %s tại %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "Không thể chuyển đổi %s thành %s tại %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %qs to %qs at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Không thể chuyển đổi %qs thành %qs tại %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -66920,7 +66986,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -68121,12 +68187,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -68284,153 +68350,153 @@ msgstr ""
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t open %qs for writing: %m"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "can%'t mở %s để ghi: %m"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr ""
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot open source file %s\n"
 msgid "Cannot delete module file %qs: %s"
 msgstr "Không thể mở tập tin nguồn %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot open source file %s\n"
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "Không thể mở tập tin nguồn %s\n"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create temporary file"
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "không thể tạo tập tin tạm thời"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Ký hiệu %qs đã sẵn được khai báo"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Ký hiệu %qs đã sẵn được khai báo"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "mô đun ISO_C_BINDING tại %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name %qs at %C"
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "Không rõ tên thủ tục “%qs” tại %C"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot open source file %s\n"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "Không thể mở tập tin nguồn %s\n"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -68979,8 +69045,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -71023,7 +71089,7 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -71139,7 +71205,7 @@ msgstr "Không thể phân giải hàm đặc tả %qs tại %L"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%qE không phải tên một kiểu"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -71299,214 +71365,214 @@ msgstr "Trả lại giá trị của hàm %qs tại %L chưa đặt"
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "loại không hợp lệ cho %s tại %L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "loại không hợp lệ cho %s tại %L"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): intrinsic sai"
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -71515,12 +71581,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -71529,295 +71595,295 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qs đã lạc hậu"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Sai trong type-spec tại %L"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs tại %L phải là THỦ TỤC CON"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs tại %L phải là HÀM"
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): sai kiểu biểu thức"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s tại %L phải là một scalar"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -71826,285 +71892,285 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "tham số %u có kiểu void"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Gặp kiểu hạn chế không cần %qs tại %L"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ngữ cảnh sai cho hạn chế NULL() tại %L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Tham số %qs của thủ tục cơ bản tại %L phải là vô hướng"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -72112,194 +72178,194 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "cấu trúc BLOCK tại %C"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Kiểu khối sai"
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL không hợp lệ %L"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Không có biểu thức trên DO WHILE"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mã câu lệnh sai"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %qs declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Đối số chưa dùng %qs được khai báo tại %L"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -72307,969 +72373,969 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Chiều dài chuỗi tại %L là quá lớn"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s tại %L"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Đối số của thủ tục FINAL tại %L phải là kiểu %qs"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là kiểu dẫn xuất %qs"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là dẫn xuất kiểu %qs"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qE chưa được khai báo"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist '%s' can not be an argument at %L"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %L"
 msgid "Expecting definable entity near %L"
 msgstr "Cần câu lệnh %s tại %L"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nhãn %d tại %L đã định nghĩa nhưng chưa được dùng"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Chuỗi con tại %L có độ dài là không"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -74141,17 +74207,17 @@ msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -74242,107 +74308,107 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Trả lại giá trị của hàm %qs tại %L chưa đặt"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Đối số giả chưa dùng %qs tại %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Biến số chưa dùng %qs được khai báo tại %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Đối số chưa dùng %qs được khai báo tại %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Trả lại giá trị %sq của hàm %qs khai báo tại %L chưa đặt"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Không hiểu intrinsic op"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -74497,7 +74563,7 @@ msgstr "gfc_validate_kind(): Nhận kiểu sai"
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr "gfc_validate_kind(): Nhận loại sai"
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code(): Mã câu lệnh sai"
@@ -74629,7 +74695,7 @@ msgstr "-fwpa và -fltrans loại trừ lẫn nhau"
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
 #| msgid "-fwpa and -fltrans are mutually exclusive"
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-fwpa và -fltrans loại trừ lẫn nhau"
 
 #: lto/lto-object.c:107
@@ -75756,7 +75822,7 @@ msgstr "Không thừa nhận giá trị tùy chọn không phụ thuộc endian:
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "Không nhận ra tùy chọn để khởi tạo giá trị dấu chấm động: %qs"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "Không nhận ra tùy chọn: \"%qs\""
@@ -75774,15 +75840,15 @@ msgstr "thiếu tên macro sau %qs"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "thiếu tên tập tin sau %qs"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "thiếu đường dẫn sau %qs"
@@ -75836,7 +75902,7 @@ msgstr "thiếu paren mở"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "không nhận giá trị khả kiến ivar %qs"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "không nhận ra giá trị thứ tự kho vô hướng %qs"
@@ -75922,93 +75988,93 @@ msgstr "%qs đã lạc hậu"
 msgid "unknown linker output %qs"
 msgstr "không hiểu xuất bộ liên kết %qs"
 
-#: common.opt:1502
+#: common.opt:1506
 #, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "không hiểu kiểu chính xác bị vượt quá %qs"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 #, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "không hiểu thuật toán IRA %qs"
 
-#: common.opt:1902
+#: common.opt:1906
 #, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "không hiểu vùng IRA %qs"
 
-#: common.opt:1980
+#: common.opt:1984
 #, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "không hiểu mô hình phân vùng TLS %qs"
 
-#: common.opt:2082
+#: common.opt:2086
 #, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "thiếu tùy chọn hay đích sau %qs"
 
-#: common.opt:2090
+#: common.opt:2094
 #, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "không hiểu ABI offload %qs"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "không hiểu mô hình kích thước con trỏ %qs"
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "không hiểu mô hình kích thước con trỏ %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qE"
 msgid "unknown Live-Patching Level %qs"
 msgstr "không hiểu chế độ máy %qE"
 
-#: common.opt:2383
+#: common.opt:2387
 #, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "không hiểu thuật toán xếp lại khối cơ bản %qs"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "không hiểu mô hình TLS %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:3067
+#: common.opt:3071
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr ""
 
-#: common.opt:3086
+#: common.opt:3090
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
diff --git a/gcc/po/zh_CN.po b/gcc/po/zh_CN.po
index 9c99758817c0d..1ed37610ef881 100644
--- a/gcc/po/zh_CN.po
+++ b/gcc/po/zh_CN.po
@@ -33,7 +33,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 9.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2019-08-19 15:13-0400\n"
 "Last-Translator: Boyuan Yang <073plan@gmail.com>\n"
 "Language-Team: Chinese (simplified) <i18n-zh@googlegroups.com>\n"
@@ -1280,13 +1280,13 @@ msgstr "    内联自%qs"
 msgid "this is the insn:"
 msgstr "这是指令："
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "无法生成重新载入，为："
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "无法生成重新载入，为："
 
@@ -1467,18 +1467,18 @@ msgstr "无法识别的指令："
 msgid "insn does not satisfy its constraints:"
 msgstr "指令不满足其约束："
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "创建和使用时使用了不同的‘%s’设定"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "创建和使用时使用了不同的 -fpic 设定"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1518,7 +1518,7 @@ msgstr "%s%s警告：%s 头文件版本 %s 与库版本 %s 不同。\n"
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC 准则：--param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1971,90 +1971,90 @@ msgstr "strfmon 格式的长度修饰符"
 msgid "<command-line>"
 msgstr "<命令行>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, fuzzy, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "缺少操作数"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "%%R 代码的操作数无效"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "‘%%%c’不是一个有效的操作数前缀"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "无效寻址模式"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "二元操作中中操作数无效"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "使用‘%%&’ 时没有指定任何动态 TLS 引用"
@@ -2070,18 +2070,18 @@ msgid "invalid %%r value"
 msgstr "无效 %%r 值"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "无效 %%R 值"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "无效 %%N 值"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "无效 %%P 值"
@@ -2111,7 +2111,7 @@ msgstr "无效 %%M 值"
 msgid "invalid %%U value"
 msgstr "无效 %%U 值"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "无效 %%s 值"
@@ -2121,7 +2121,7 @@ msgstr "无效 %%s 值"
 msgid "invalid %%C value"
 msgstr "无效 %%C 值"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "无效 %%E 值"
@@ -2134,7 +2134,7 @@ msgstr "未指定未知的重定位方式"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "无效的 %%xn 代码"
@@ -2217,35 +2217,35 @@ msgstr "无效的 UNSPEC 用作操作数"
 msgid "unrecognized supposed constant"
 msgstr "预期的常量无法识别"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, c-format
 msgid "invalid shift operand"
 msgstr "无效的移位操作数"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "预测到的 Thumb 指令"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在条件序列中预测到的指令"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2253,13 +2253,13 @@ msgstr "代码‘%c’的操作数无效"
 msgid "invalid operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, c-format
 msgid "instruction never executed"
 msgstr "指令从不被执行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支持的算符用于编码‘%c’"
@@ -2400,8 +2400,8 @@ msgstr "非预期的操作数"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2773,7 +2773,7 @@ msgstr "对%<__fpreg%>的操作无效"
 msgid "invalid %%P operand"
 msgstr "无效的 %%P 操作数"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "无效的 %%p 值"
@@ -2827,7 +2827,7 @@ msgid "post-increment address is not a register"
 msgstr "后自增地址不是一个寄存器"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "错误地址"
 
@@ -2879,8 +2879,8 @@ msgstr "‘%%%c’不是一个有效的操作数前缀"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "对‘%%%c’的使用无效"
@@ -3021,325 +3021,325 @@ msgstr "堆栈溢出。\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "尝试在命令解释器中运行‘%s’以提升它的极限。\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 #| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx 需要硬件浮点"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 #| msgid "-mvsx needs indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "-mvsx 需要变址寻址"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx 与 -mno-altivec 互不兼容"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 #, fuzzy
 #| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec 禁用了 VSX"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "-mquad-memory 需要 64 位模式"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "-mquad-memory 需要 64 位模式"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 #, fuzzy
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "生成小端在前的代码"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 msgid "bad move"
 msgstr "错误的移动"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "无效 %%J 值"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "无效的 %%D 值"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, c-format
 msgid "invalid %%e value"
 msgstr "无效 %%e 值"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "无效 %%f 值"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "无效 %%F 值"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "无效 %%G 值"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "无效 %%j 代码"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "无效 %%J 代码"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "无效 %%k 值"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "无效 %%K 值"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "无效 %%O 值"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "无效 %%q 值"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, c-format
 msgid "invalid %%t value"
 msgstr "无效 %%t 值"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "无效 %%T 值"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "无效 %%u 值"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "无效 %%v 值"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, c-format
 msgid "invalid %%V value"
 msgstr "无效 %%V 值"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "无效 %%x 值"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, c-format
 msgid "invalid %%z value"
 msgstr "无效 %%z 值"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "无效 %%y 值，请试用“Z”约束"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 #, fuzzy
 #| msgid "Use decimal floating point instructions"
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "使用十进制浮点指令"
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "不为每个函数生成单一的退出点"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "无法生成重新载入，为："
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "向%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "向%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "向%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "向%<__fpreg%>的转换无效"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, fuzzy, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "符号内存参考是只有支持的于 z10 或稍后"
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "无法分解地址"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "‘o’修饰符的操作数无效"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "内存参考预期的用于‘S’输出修饰键"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "%s：无效的输出格式"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "暂存器或内存运算式预期的用于‘N’输出修饰键"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "暂存器或内存运算式预期的用于‘公尺’输出修饰键"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "CHARACTER 常量的种别 %d 无效，在%C处"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "无效的操作数输出代码"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "CHARACTER 常量的种别 %d 无效，在%C处"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "无效的最小左值表达式"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "返回指针时目标与指针符号不一致"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 #, fuzzy
 msgid "binary operator does not support vector bool operand"
 msgstr "目标格式不支持无限大浮点数"
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3608,8 +3608,8 @@ msgstr "({匿名})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要%<;%>"
@@ -3629,7 +3629,7 @@ msgstr "需要%<;%>"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "需要%<)%>"
@@ -3637,7 +3637,7 @@ msgstr "需要%<)%>"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "需要%<]%>"
@@ -3655,21 +3655,21 @@ msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "需要%<(%>"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "需要%<[%>"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要%<{%>"
@@ -3680,13 +3680,13 @@ msgstr "需要%<{%>"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "需要 %<:%>"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "需要 %<while%>"
@@ -3695,7 +3695,7 @@ msgstr "需要 %<while%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "需要 %<,%>"
@@ -3704,18 +3704,18 @@ msgstr "需要 %<,%>"
 msgid "expected %<.%>"
 msgstr "需要%<.%>"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "需要 %<@end%>"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "需要 %<>%>"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "需要 %<,%> 或 %<)%>"
@@ -3723,28 +3723,28 @@ msgstr "需要 %<,%> 或 %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要%<=%>"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "需要 %<}%>"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "需要%<<%>"
@@ -3762,30 +3762,30 @@ msgstr "需要通道"
 msgid "candidate:"
 msgstr "备选 1："
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 #| msgid "Enable user-defined instructions"
 msgid "  after user-defined conversion:"
 msgstr "启用用户自定义指令"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "备选是："
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "备选 1："
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "备选 2："
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "跳转至标号%qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "跳转至 case 标号"
 
@@ -4019,33 +4019,33 @@ msgstr "局部变量%qD不应出现在此上下文中"
 msgid "local variable %qD may not appear in this context"
 msgstr "局部变量%qD不应出现在此上下文中"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 #, fuzzy
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 #| msgid "invalid use of dependent type %qT"
 msgid "%<using enum%> of dependent type %qT"
 msgstr "对依赖类型%qT的使用无效"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%qD不是一个枚举名"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 #| msgid "invalid use of incomplete type %q#T"
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "对不完全的类型%q#T的非法使用"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "备选为："
 
@@ -4089,48 +4089,48 @@ msgstr "转换丢失了常量属性"
 msgid "source type is not polymorphic"
 msgstr "源类型不是多态的"
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "单目减的操作数类型错误"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "单目加的操作数类型错误"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的参数类型错误"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能对该类型的参数求绝对值"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能对该类型的参数求共轭"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 msgid "in argument to unary !"
 msgstr "单目 ! 的参数中"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 msgid "no pre-increment operator for type"
 msgstr "类型没有前自增运算符"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 msgid "no post-increment operator for type"
 msgstr "类型没有后自增运算符"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 msgid "no pre-decrement operator for type"
 msgstr "类型没有前自减运算符"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 msgid "no post-decrement operator for type"
 msgstr "类型没有后自减运算符"
 
@@ -4233,7 +4233,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "驱动："
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 #, fuzzy
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "实际参数到含义=出/INOUT"
@@ -4377,7 +4377,7 @@ msgstr "错误的运算符"
 msgid "Bad type in constant expression"
 msgstr "常量表达式中类型错误"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "非预期的模块结束"
 
@@ -4405,11 +4405,11 @@ msgstr "块 IF"
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "赋值"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "指针赋值"
 
@@ -4510,171 +4510,171 @@ msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 msgid "bind(c) procedure"
 msgstr "%C处带有 NAME 的 BIND(C)过程不能有 POINTER 属性"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "二元数值运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "二元数值运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字符串毗连运算符(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "逻辑运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L处的 .not. 运算符的操作数为 %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L处复数不能比较大小"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L处逻辑值必须与 %s 比较，而不是 %s"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "比较运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "未知的运算符‘%s’在 %%L处"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "未知的运算符‘%s’在 %%L处"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%%L和%%L处的操作数的秩不一致"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 msgid "Loop variable"
 msgstr "循环变量"
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 #, fuzzy
 msgid "iterator variable"
 msgstr "变量"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 msgid "Start expression in DO loop"
 msgstr "DO 循环中的开始表达式"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 msgid "End expression in DO loop"
 msgstr "DO 循环中结束表达式"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 msgid "Step expression in DO loop"
 msgstr "DO 循环中的步进表达式"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "试图 DEALLOCATE 未分配的‘%s’"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 #, fuzzy
 msgid "STAT variable"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 #, fuzzy
 msgid "item in READ"
 msgstr "读取概要："
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "无法锁定新归档文件"
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "数组构造函数中 CHARACTER 长度不同(%ld/%ld)"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 #, fuzzy
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "试图分配负数大小的内存。可能有整数溢出"
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "字符串的实际长度不匹配其虚参声明‘%s’(%ld/%ld)"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "字符串的实际长度短于其虚参声明‘%s’(%ld/%ld)"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目标的分级重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4801,28 +4801,28 @@ msgstr "对数组的引用超出范围"
 msgid "Incorrect function return value"
 msgstr "不正确的函数返回值"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 #| msgid "Memory allocation failed"
 msgid "Error allocating %lu bytes"
 msgstr "内存分配失败"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, fuzzy, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "试图分配已经分配的数组‘%s’"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 #, fuzzy
 msgid "Attempting to allocate already allocated variable"
 msgstr "试图分配已经分配的数组‘%s’"
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "试图 DEALLOCATE 未分配的‘%s’"
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -5035,15 +5035,15 @@ msgstr "-Xbind-now 与 -Xbind-lazy 不兼容"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr "与 gprof(1) 一起使用时请考虑使用‘-pg’以代替‘-p’"
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "不能同时使用 -EB 和 -EL"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-mfloat-abi=soft 和 -mfloat-abi=hard 不能一起使用"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian 和 -mlittle-endian 不能一起使用"
 
@@ -5060,8 +5060,8 @@ msgstr "没有指定链接用的处理器类型"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "请勿同时指定 -march=... 和 -mcpu=..."
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared 和 mdll 互不兼容"
 
@@ -5239,10 +5239,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "创建临时数组时给出警告"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
@@ -5771,179 +5771,179 @@ msgstr "置放所有本地数组于堆叠。"
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "将模块实体的默认访问权限设置为 PRIVATE。"
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, fuzzy, no-c-format
 #| msgid "Try to lay out derived types as compactly as possible"
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "为派生类型使用尽可能紧实的布局"
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 #| msgid "Protect parentheses in expressions"
 msgid "Protect parentheses in expressions."
 msgstr "尊重表达式中的括号"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, fuzzy, no-c-format
 #| msgid "Enable range checking during compilation"
 msgid "Enable range checking during compilation."
 msgstr "启用编译时范围检查"
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr "解译任何真实 (4) 作为真实 (8)"
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr "解译任何真实 (4) 作为真实 (10)"
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr "解译任何真实 (4) 作为真实 (16)"
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr "解译任何真实 (8) 作为真实 (4)"
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr "解译任何真实 (8) 作为真实 (10)"
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr "解译任何真实 (8) 作为真实 (16)"
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, fuzzy, no-c-format
 #| msgid "Reallocate the LHS in assignments"
 msgid "Reallocate the LHS in assignments."
 msgstr "在赋值中重分配左值"
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, fuzzy, no-c-format
 #| msgid "Use a 4-byte record marker for unformatted files"
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "对未格式化的文件，使用一个 4 字节的记录标记"
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, fuzzy, no-c-format
 #| msgid "Use an 8-byte record marker for unformatted files"
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "对未格式化的文件，使用一个 8 字节的记录格式"
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, fuzzy, no-c-format
 #| msgid "Allocate local variables on the stack to allow indirect recursion"
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr "在堆栈上分配局部变量以允许间接递归"
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, fuzzy, no-c-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "在过程入口处将数组段复制到一个连续的块中"
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, fuzzy, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr "-fcoarray=[...]\t指定要使用的集合数组并行化"
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, fuzzy, no-c-format
 #| msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed"
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr "-fcheck=[...]\t指定要进行哪种运行时检查"
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, fuzzy, no-c-format
 #| msgid "Append a second underscore if the name already contains an underscore"
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "当名字已经包含一个下划线时添加第二个下划线"
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, fuzzy, no-c-format
 #| msgid "Apply negative sign to zero values"
 msgid "Apply negative sign to zero values."
 msgstr "在零值前使用负号"
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, fuzzy, no-c-format
 #| msgid "Append underscores to externally visible names"
 msgid "Append underscores to externally visible names."
 msgstr "为外部可见的名字添加下划线"
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, fuzzy, no-c-format
 #| msgid "Statically link the GNU Fortran helper library (libgfortran)"
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr "静态链接 GNU Fortran 助手库(libgfortran)"
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "遵循 ISO Fortran 2003 标准"
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "遵循 ISO Fortran 2008 标准"
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2008 standard including TS 29113"
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "遵循 ISO Fortran 2008 标准，包括 TS 29113"
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "遵循 ISO Fortran 2008 标准"
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 95 standard"
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "遵循 ISO Fortran 95 标准"
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, fuzzy, no-c-format
 #| msgid "Conform to nothing in particular"
 msgid "Conform to nothing in particular."
 msgstr "不特别遵循任何标准"
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, fuzzy, no-c-format
 #| msgid "Accept extensions to support legacy code"
 msgid "Accept extensions to support legacy code."
@@ -6705,7 +6705,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7394,8 +7394,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr "可变参数函数必须使用基础的 AAPCS 变种"
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, no-c-format
 msgid "No longer supported."
 msgstr "不再支持。"
@@ -7782,536 +7782,531 @@ msgid "Specify default OpenACC compute dimensions."
 msgstr ""
 
 #: c-family/c.opt:1878
-#, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
 #, fuzzy, no-c-format
 #| msgid "Enable OpenMP (implies -frecursive in Fortran)"
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "启用 OpenMP(对 Fortran 而言也同时设定 -frecursive)"
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, fuzzy, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "启用 OpenMP(对 Fortran 而言也同时设定 -frecursive)"
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, fuzzy, no-c-format
 #| msgid "Recognize C++ keywords like \"compl\" and \"xor\""
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "识别“compl”、“xor”等 C++ 关键词"
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, fuzzy, no-c-format
 #| msgid "Look for and use PCH files even when preprocessing"
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "即使在预处理时也搜索并使用 PCH 文件"
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, fuzzy, no-c-format
 #| msgid "Downgrade conformance errors to warnings"
 msgid "Downgrade conformance errors to warnings."
 msgstr "将兼容性错误降格为警告"
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, fuzzy, no-c-format
 #| msgid "Enable Plan 9 language extensions"
 msgid "Enable Plan 9 language extensions."
 msgstr "启用九号计划语言扩展"
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, fuzzy, no-c-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "Treat the input file as already preprocessed."
 msgstr "将输入文件当作已经预处理过的"
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, fuzzy, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr "-ftrack-macro-expansion=<0|1|2> 轨段位置的字组来自宏展开和显示它们在中错误消息"
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, fuzzy, no-c-format
 #| msgid "-fno-pretty-templates Do not pretty-print template specializations as the template signature followed by the arguments"
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr "-fno-pretty-templates 不使用模板签名加实参的方式美化模板特例化的打印"
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, fuzzy, no-c-format
 #| msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime"
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "指定对象文件可能在运行时被换入以允许“修复并继续”调试模式"
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "已弃用。此开关不起作用。"
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, fuzzy, no-c-format
 #| msgid "Generate run time type descriptor information"
 msgid "Generate run time type descriptor information."
 msgstr "生成运行时类型描述信息"
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, fuzzy, no-c-format
 #| msgid "Use the narrowest integer type possible for enumeration types"
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "为枚举类型使用尽可能窄的整数类型"
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\""
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "强制指定“wchar_t”的内在类型为“unsigned short”"
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "没有给定“signed”或“unsigned”时将位段视作有符号的"
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, fuzzy, no-c-format
 #| msgid "Make \"char\" signed by default"
 msgid "Make \"char\" signed by default."
 msgstr "使“char”类型默认为有符号"
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, fuzzy, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "启用硬件十进制浮点支持"
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, fuzzy, no-c-format
 #| msgid "Display statistics accumulated during compilation"
 msgid "Display statistics accumulated during compilation."
 msgstr "显示编译过程中累计的统计数字"
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, fuzzy, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "假设该值的枚举类型类型是一律在之内最小范围的该类型"
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, fuzzy, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "单个循环最大的剥离数"
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, fuzzy, no-c-format
 #| msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth"
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "-ftemplate-depth=<N>\t指定模板实例化的最大深度"
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, fuzzy, no-c-format
 #| msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics"
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "-fno-threadsafe-statics\t不为局部静态变量生成线程安全的初始化代码"
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "未指定“signed”或“unsigned”时默认位段为无符号的"
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, no-c-format
 msgid "Make \"char\" unsigned by default."
 msgstr "使“char”类型默认为无符号。"
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, fuzzy, no-c-format
 #| msgid "Use __cxa_atexit to register destructors"
 msgid "Use __cxa_atexit to register destructors."
 msgstr "将 __cxa_atexit 而非 atexit 登记为析构函数"
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, fuzzy, no-c-format
 #| msgid "Use __cxa_get_exception_ptr in exception handling"
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "在异常处理中使用 __cxa_get_exception_ptr"
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, fuzzy, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "将所有内联函数标记为具有隐藏的可见性"
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, fuzzy, no-c-format
 #| msgid "Changes visibility to match Microsoft Visual Studio by default"
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "默认使用与 Microsoft Visual Studio 匹配的可见性"
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Emit common-like symbols as weak symbols"
 msgid "Emit common-like symbols as weak symbols."
 msgstr "将公共符号视作弱符号"
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, fuzzy, no-c-format
 #| msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>"
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-finput-charset=<字符集>\t将所有宽字符串和字符常量都转换为字符集"
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, fuzzy, no-c-format
 #| msgid "Generate a #line directive pointing at the current working directory"
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "生成一个指向当前工作目录的 #line 预处理指令"
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, fuzzy, no-c-format
 #| msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode"
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "为 Zero-Link 模式生成后期类查找(通过 objc_getClass())"
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Dump declarations to a .decl file"
 msgid "Dump declarations to a .decl file."
 msgstr "将声明转储到一个 .decl 文件中"
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, fuzzy, no-c-format
 #| msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs"
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "-femit-struct-debug-baseonly\t积极地缩减结构体的调试信息"
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, fuzzy, no-c-format
 #| msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs"
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "-femit-struct-debug-reduced\t保守地缩减结构体的调试信息"
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, fuzzy, no-c-format
 #| msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs"
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "-femit-struct-debug-detailed=<规格列表>\t详细指定如何缩减结构体的调试信息"
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, fuzzy, no-c-format
 #| msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path"
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <目录>\t将目录添加至系统包含路径末尾"
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, fuzzy, no-c-format
 #| msgid "-imacros <file>\tAccept definition of macros in <file>"
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "-imacros <文件>\t接受文件中定义的宏"
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory"
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-imultilib <目录>\t将目录设定为 multilib 的包含子目录"
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, fuzzy, no-c-format
 #| msgid "-include <file>\tInclude the contents of <file> before other files"
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "-include <文件>\t在包含其它文件之前先包含该文件的内容"
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, fuzzy, no-c-format
 #| msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options"
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "-iprefix <路径>\t将路径指定为下两个选项的前缀"
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, fuzzy, no-c-format
 #| msgid "-isysroot <dir>\tSet <dir> to be the system root directory"
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <目录>\t将目录设为系统根目录"
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, fuzzy, no-c-format
 #| msgid "-isystem <dir>\tAdd <dir> to the start of the system include path"
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <目录>\t将目录添加至系统包含路径开头"
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, fuzzy, no-c-format
 #| msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path"
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-iquote <目录>\t将目录添加至括起的包含路径末尾"
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, fuzzy, no-c-format
 #| msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path"
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <目录>\t将目录添加至系统包含路径末尾"
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, fuzzy, no-c-format
 #| msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path"
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <目录>\t将目录添加至主包含路径末尾"
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories (those specified with -isystem will still be used)"
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "不搜索标准系统头文件目录(但仍将使用由 -isystem 指定的目录)"
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories for C++"
 msgid "Do not search standard system include directories for C++."
 msgstr "不搜索 C++ 标准系统头文件目录"
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, fuzzy, no-c-format
 #| msgid "Generate C header of platform-specific features"
 msgid "Generate C header of platform-specific features."
 msgstr "生成有平台相关特性的 C 头文件"
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, fuzzy, no-c-format
 #| msgid "Remap file names when including files"
 msgid "Remap file names when including files."
 msgstr "包含文件时映射短文件名"
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "遵循 ISO 1998 C++ 标准于 2003 年的技术勘误版本"
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C++ standard"
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "遵循 ISO 2011 C++ 标准"
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "已弃用，请改用 -std=gnu99"
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "已弃用，请改用 -std=gnu99"
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C++ standard"
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "遵循 ISO 2011 C++ 标准"
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr "已弃用，请改用 -std=gnu99"
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C++ standard"
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "遵循 ISO 2011 C++ 标准"
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2017(?) C++ draft standard (experimental and incomplete support)"
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "遵循 ISO 2017(?) C++ 标准草案(试验性质的不完全支持)"
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2017(?) C++ draft standard (experimental and incomplete support)"
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "遵循 ISO 2017(?) C++ 标准草案(试验性质的不完全支持)"
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C++ standard"
 msgid "Conform to the ISO 2011 C standard."
 msgstr "遵循 ISO 2011 C++ 标准"
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "已弃用，请改用 -std=c99"
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2011 C++ standard"
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "遵循 ISO 2011 C++ 标准"
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 2017(?) C++ draft standard (experimental and incomplete support)"
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "遵循 ISO 2017(?) C++ 标准草案(试验性质的不完全支持)"
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 1990 C standard."
 msgstr "遵循 ISO 1990 C 标准"
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard"
 msgid "Conform to the ISO 1999 C standard."
 msgstr "遵循 ISO 1999 C 标准"
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c99."
 msgstr "已弃用，请改用 -std=c99"
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "遵循 ISO 1998 C++ 标准于 2003 年的技术勘误版本"
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 标准，也支持 GNU 扩展"
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "已弃用，请改用 -std=gnu++11。"
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "已弃用，请改用 -std=gnu++14。"
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 标准，也支持 GNU 扩展"
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "已弃用，请改用 -std=gnu+17。"
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 标准，也支持 GNU 扩展"
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 201z(7?) C++ draft standard with GNU extensions (experimental and incomplete support)"
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "遵循 ISO 201z(7?) C++ 标准草案和 GNU 扩展(试验性质的不完全支持)"
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 201z(7?) C++ draft standard with GNU extensions (experimental and incomplete support)"
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "遵循 ISO 201z(7?) C++ 标准草案和 GNU 扩展(试验性质的不完全支持)"
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 标准，也支持 GNU 扩展"
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "已弃用，请改用 -std=gnu11。"
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "遵循 ISO 1990 C 标准，也支持 GNU 扩展"
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 201z(7?) C++ draft standard with GNU extensions (experimental and incomplete support)"
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "遵循 ISO 201z(7?) C++ 标准草案和 GNU 扩展(试验性质的不完全支持)"
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 标准，也支持 GNU 扩展"
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard with GNU extensions"
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "遵循 ISO 1999 C 标准，也支持 GNU 扩展"
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "已弃用，请改用 -std=gnu99"
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "遵循 ISO 1990 C 标准于 1994 年修订的版本"
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=iso9899:1999"
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "已弃用，为 -std=iso9899:1999 所取代"
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, no-c-format
 msgid "Enable traditional preprocessing."
 msgstr "启用传统预处理。"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\t支持 ISO C 三元符。"
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Do not predefine system-specific and GCC-specific macros"
 msgid "Do not predefine system-specific and GCC-specific macros."
@@ -8575,6 +8570,12 @@ msgstr ""
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+#| msgid "Emit implicit instantiations of templates"
+msgid "Emit template instantiations as weak symbols."
+msgstr "允许模板隐式实例化"
+
 #: d/lang.opt:346
 #, fuzzy, no-c-format
 #| msgid "Do not assume that standard C libraries and \"main\" exist"
@@ -9932,157 +9933,171 @@ msgstr "在 ColdFire 上支持超过 8192 个 GOT 条目"
 msgid "Support TLS segment larger than 64K."
 msgstr "支持大于 64K 的 TLS 段"
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as big endian"
+msgid "Assume target CPU is configured as big endian."
+msgstr "假定目标 CPU 被配置为大端在前"
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as little endian"
+msgid "Assume target CPU is configured as little endian."
+msgstr "假定目标 CPU 被配置为小端在前"
+
+#: config/riscv/riscv.opt:34
 #, fuzzy, no-c-format
 #| msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions"
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "-mbranch-cost=COST\t将分支的开销大致设定为 COST 条指令"
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, fuzzy, no-c-format
 #| msgid "When generating -mabicalls code, allow executables to use PLTs and copy relocations"
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr "生成 -mabicalls 代码时，允许可执行程序使用 PLT 和复制重定位"
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 #| msgid "Specify the name of the target floating point hardware/format"
 msgid "Specify integer and floating-point calling convention."
 msgstr "指定目标浮点硬件/格式的名称"
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, fuzzy, no-c-format
 #| msgid "Attempt to keep stack aligned to this power of 2"
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "试图让栈保持对齐到 2 的此次方上"
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, fuzzy, no-c-format
 #| msgid "Known ABIs (for use with the -mabi= option):"
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "已知 ABI (用于 -mabi= 选项)："
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 #| msgid "Use hardware floating point square root instruction"
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "使用浮点平方根指令"
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 #| msgid "Use trap instructions to check for integer divide by zero"
 msgid "Use hardware instructions for integer division."
 msgstr "使用陷阱指令检测整数零除"
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, fuzzy, no-c-format
 #| msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR"
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=处理器\t为指定的处理器优化输出"
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 #| msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR"
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "-mtune=处理器\t为指定的处理器优化输出"
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, fuzzy, no-c-format
 #| msgid "-G<number>\tPut global and static data smaller than <number> bytes into a special section (on some targets)"
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "-G<N>\t将小于 N 字节的全局和静态数据放入一个特殊的节中(在某些目标机上)"
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "使用子程序完成函数前言/尾声"
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, fuzzy, no-c-format
 msgid "Specify the code model."
 msgstr "使用给定的 x86-64 代码模式"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 #| msgid "Do not use unaligned memory references"
 msgid "Do not generate unaligned memory accesses."
 msgstr "不使用未对齐的内存引用"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr "已知编码模型 (用于 -mcmodel= 选项)："
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, fuzzy, no-c-format
 msgid "Use the given data alignment."
 msgstr "使用 H8/300 对齐规则"
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, fuzzy, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr "无效的 __fp16 浮点选项：-mfp16-format=%s"
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, fuzzy, no-c-format
 msgid "Use given stack-protector guard."
 msgstr "使用 propolice 来保护堆栈"
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, fuzzy, no-c-format
 #| msgid "Valid arguments to -mfloat-gprs=:"
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "-mfloat-gprs 的有效参数为："
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, fuzzy, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "使用 propolice 来保护堆栈"
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, fuzzy, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "使用 propolice 来保护堆栈"
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, fuzzy, no-c-format
 #| msgid "Known ABIs (for use with the -mabi= option):"
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "已知 ABI (用于 -mabi= 选项)："
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, fuzzy, no-c-format
 msgid "Set the version of RISC-V ISA spec."
 msgstr "ELF 文件 ABI 版本无效"
@@ -10224,13 +10239,6 @@ msgstr "假定大的线程局部存储段"
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as big endian"
-msgid "Assume target CPU is configured as big endian."
-msgstr "假定目标 CPU 被配置为大端在前"
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -10252,13 +10260,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as little endian"
-msgid "Assume target CPU is configured as little endian."
-msgstr "假定目标 CPU 被配置为小端在前"
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -18232,2426 +18233,2426 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <目录>\t设定内存转储使用的目录名"
 
-#: common.opt:970
+#: common.opt:974
 #, fuzzy, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr "ELF 文件 ABI 版本无效"
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "对齐函数入口"
 
-#: common.opt:988
+#: common.opt:992
 #, fuzzy, no-c-format
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "对齐只能为跳转所到达的标号"
 
-#: common.opt:995
+#: common.opt:999
 #, fuzzy, no-c-format
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "对齐所有的标号"
 
-#: common.opt:1002
+#: common.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "对齐循环入口"
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing."
 msgid "Enable static analysis pass."
 msgstr "启用传统预处理。"
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy, no-c-format
 msgid "Select what to sanitize."
 msgstr "要显示什么以代替标记"
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr "要显示什么以代替标记"
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, fuzzy, no-c-format
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "已弃用此开关；请改用 -Wextra"
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, fuzzy, no-c-format
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "生成精确到每条指令边界的堆栈展开表"
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 #| msgid "Generate auto-inc/dec instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "生成 auto-inc/dec指令"
 
-#: common.opt:1073
+#: common.opt:1077
 #, fuzzy, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "为分支概率使用取样信息"
 
-#: common.opt:1078
+#: common.opt:1082
 #, fuzzy, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "为分支概率使用取样信息"
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "生成检查数组访问是否越界的代码"
 
-#: common.opt:1091
+#: common.opt:1095
 #, fuzzy, no-c-format
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "将加/减法、比较、跳转指令序列替换为根据计数寄存器跳转指令"
 
-#: common.opt:1095
+#: common.opt:1099
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "为分支概率使用取样信息"
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr "为每个函数重用 r30"
 
-#: common.opt:1115
+#: common.opt:1119
 #, fuzzy, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "为每个函数重用 r30"
 
-#: common.opt:1119
+#: common.opt:1123
 #, fuzzy, no-c-format
 #| msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<寄存器>\t认为寄存器在函数调用后值不变"
 
-#: common.opt:1123
+#: common.opt:1127
 #, fuzzy, no-c-format
 #| msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<寄存器>\t认为寄存器的值将被函数调用所改变"
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "函数调用前后保存/恢复寄存器值"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy, no-c-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "已弃用此开关；请改用 -Wextra"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy, no-c-format
 msgid "Check the return value of new in C++."
 msgstr "检查 new 的返回值"
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, fuzzy, no-c-format
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "内部一致性错误"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Enable code hoisting."
 msgstr "删除死存储"
 
-#: common.opt:1154
+#: common.opt:1158
 #, fuzzy, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "找寻机会到缩小堆叠调整和堆叠参考。"
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Put uninitialized globals in the common section."
 msgstr "不将未初始化的全局数据放在公共节中"
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy, no-c-format
 #| msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<选项>]\t分别在带与不带“选项”，例如 -gtoggle，的情况下编译，然后比较最后的指令输出"
 
-#: common.opt:1170
+#: common.opt:1174
 #, fuzzy, no-c-format
 #| msgid "Run only the second compilation of -fcompare-debug"
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "只为 -fcompare-debug 运行第二遍编译"
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "在分配寄存器后进行全局公共子表达式消除"
 
-#: common.opt:1178
+#: common.opt:1182
 #, fuzzy, no-c-format
 #| msgid "Do not perform optimizations increasing noticeably stack usage"
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "不进行可能导致堆栈使用明显增长的优化"
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy, no-c-format
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "进行一趟寄存器副本传递优化"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy, no-c-format
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "进行跨跳转优化"
 
-#: common.opt:1190
+#: common.opt:1194
 #, fuzzy, no-c-format
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "进行 CSE 时，跟随跳转至目标"
 
-#: common.opt:1198
+#: common.opt:1202
 #, fuzzy, no-c-format
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "当进行复数除法时省略缩减范围的步骤"
 
-#: common.opt:1202
+#: common.opt:1206
 #, fuzzy, no-c-format
 #| msgid "Complex multiplication and division follow Fortran rules"
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "复数乘除遵循 Fortran 规则"
 
-#: common.opt:1206
+#: common.opt:1210
 #, fuzzy, no-c-format
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "将每个数据项分别放在它们各自的节中"
 
-#: common.opt:1210
+#: common.opt:1214
 #, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr "列出所有可用的调试计数器及其极限和计数。"
 
-#: common.opt:1214
+#: common.opt:1218
 #, fuzzy, no-c-format
 #| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<计数器>:<极限>[,<计数器>:<极限>,...]\t设定调试计数器极限。"
 
-#: common.opt:1218
+#: common.opt:1222
 #, fuzzy, no-c-format
 #| msgid "Map one directory name to another in debug information"
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr "在调试信息中将一个目录名映射到另一个"
 
-#: common.opt:1222
+#: common.opt:1226
 #, fuzzy, no-c-format
 #| msgid "Map one directory name to another in debug information"
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr "在调试信息中将一个目录名映射到另一个"
 
-#: common.opt:1226
+#: common.opt:1230
 #, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "使用 DWARF v4 debuginfo 时输出 .debug_types 区段。"
 
-#: common.opt:1232
+#: common.opt:1236
 #, fuzzy, no-c-format
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "延迟将函数实参弹栈"
 
-#: common.opt:1236
+#: common.opt:1240
 #, fuzzy, no-c-format
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "尝试填充分支指令的延迟槽"
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, fuzzy, no-c-format
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "删除无用的空指针检查"
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, fuzzy, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr "允许非载入的投机移动"
 
-#: common.opt:1256
+#: common.opt:1260
 #, fuzzy, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr "允许链接器将 PIC 调用转化为直接调用"
 
-#: common.opt:1260
+#: common.opt:1264
 #, fuzzy, no-c-format
 #| msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\t指定在自动换行的诊断信息开始给出源位置的频率"
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, fuzzy, no-c-format
 #| msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "在诊断信息后输出控制它们的命令行选项"
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, fuzzy, no-c-format
 #| msgid "-ftabstop=<number>\tDistance between tab stops for column reporting"
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "-ftabstop=<N>\t指定报告列号时制表位间的距离"
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, fuzzy, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr "-fdisable-[ 树|rtl|ipa ]-<pass>=range1+range2 停用最佳化回合"
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr "-fenable-[ 树|rtl|ipa ]-<pass>=range1+range2 启用最佳化回合"
 
-#: common.opt:1423
+#: common.opt:1427
 #, fuzzy, no-c-format
 #| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<类型>\t将一些编译器内部信息转储到一个文件里"
 
-#: common.opt:1430
+#: common.opt:1434
 #, fuzzy, no-c-format
 #| msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=文件名\t在翻译完毕后将指令输出到文件中"
 
-#: common.opt:1434
+#: common.opt:1438
 #, fuzzy, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=文件名\t写入所有声明到文件作为前往编码"
 
-#: common.opt:1438
+#: common.opt:1442
 #, fuzzy, no-c-format
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "在调试转储中不输出地址"
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, fuzzy, no-c-format
 msgid "Dump optimization passes."
 msgstr "调出基本的文件信息"
 
-#: common.opt:1455
+#: common.opt:1459
 #, fuzzy, no-c-format
 #| msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "在调试转储中不输出指令数、行号标记和地址"
 
-#: common.opt:1459
+#: common.opt:1463
 #, fuzzy, no-c-format
 #| msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "在调试转储中不输出前一条和后一条指令号码"
 
-#: common.opt:1463
+#: common.opt:1467
 #, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "用 GAS 汇编指示来启用 CFI 表"
 
-#: common.opt:1467
+#: common.opt:1471
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "进行早内联"
 
-#: common.opt:1475
+#: common.opt:1479
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural reduction of aggregates"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "为聚合类型进行跨进程标量替换"
 
-#: common.opt:1479
+#: common.opt:1483
 #, fuzzy, no-c-format
 msgid "Perform unused symbol elimination in debug info."
 msgstr "在调试信息中进行无用类型消除"
 
-#: common.opt:1483
+#: common.opt:1487
 #, fuzzy, no-c-format
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "在调试信息中进行无用类型消除"
 
-#: common.opt:1487
+#: common.opt:1491
 #, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "保留 C++ 类调试信息。"
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "启用异常处理"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy, no-c-format
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "进行一些细微的、代价高昂的优化"
 
-#: common.opt:1499
+#: common.opt:1503
 #, fuzzy, no-c-format
 #| msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\t指定如何处理有额外精度的浮点数"
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, fuzzy, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "输出 lto 对象包含两者中介语言和二进制输出。"
 
-#: common.opt:1534
+#: common.opt:1538
 #, fuzzy, no-c-format
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "假定结果不会是 NaN 或无穷大浮点数"
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, fuzzy, no-c-format
 #| msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<寄存器>\t认为寄存器对编译器而言不可用"
 
-#: common.opt:1546
+#: common.opt:1550
 #, fuzzy, no-c-format
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "不将单精度和双精度浮点数分配到扩展精度的寄存器中"
 
-#: common.opt:1554
+#: common.opt:1558
 #, fuzzy, no-c-format
 #| msgid "Perform a forward propagation pass on RTL"
 msgid "Perform a forward propagation pass on RTL."
 msgstr "进行 RTL 上的前向传递"
 
-#: common.opt:1558
+#: common.opt:1562
 #, fuzzy, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[关闭|于|快速] 施行浮点运算式合约。"
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, fuzzy, no-c-format
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "允许将函数地址保存在寄存器中"
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "将每个函数分别放在它们各自的节中"
 
-#: common.opt:1590
+#: common.opt:1594
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "进行全局公共子表达式消除"
 
-#: common.opt:1594
+#: common.opt:1598
 #, fuzzy, no-c-format
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "在全局公共子表达式消除中进行增强的读转移优化"
 
-#: common.opt:1598
+#: common.opt:1602
 #, fuzzy, no-c-format
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "在全局公共子表达式消除后进行存储转移"
 
-#: common.opt:1602
+#: common.opt:1606
 #, fuzzy, no-c-format
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "在全局公共子表达式消除中进行冗余的写后读消除"
 
-#: common.opt:1607
+#: common.opt:1611
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "在分配寄存器后进行全局公共子表达式消除"
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, fuzzy, no-c-format
 #| msgid "Enable in and out of Graphite representation"
 msgid "Enable in and out of Graphite representation."
 msgstr "启用 Graphite 表示的输入输出"
 
-#: common.opt:1633
+#: common.opt:1637
 #, fuzzy, no-c-format
 #| msgid "Enable Graphite Identity transformation"
 msgid "Enable Graphite Identity transformation."
 msgstr "启用 Graphite 身份转换"
 
-#: common.opt:1637
+#: common.opt:1641
 #, fuzzy, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "为条件指针外提内存读取操作。"
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, fuzzy, no-c-format
 #| msgid "Mark all loops as parallel"
 msgid "Mark all loops as parallel."
 msgstr "将所有循环标记为并行"
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, fuzzy, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "启用循环交换转换"
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "启用树上的循环不变量转移"
 
-#: common.opt:1667
+#: common.opt:1671
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "展开所有循环"
 
-#: common.opt:1671
+#: common.opt:1675
 #, fuzzy, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr "启用支持用于 GNU transactional 内存"
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, fuzzy, no-c-format
 #| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "启用标号对齐优化"
 
-#: common.opt:1687
+#: common.opt:1691
 #, fuzzy, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr "强制 bitfield 访问到匹配它们的类型宽度"
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, fuzzy, no-c-format
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "启用分支概率猜测"
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "处理 #ident 指令"
 
-#: common.opt:1707
+#: common.opt:1711
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "将条件跳转替换为没有跳转的等值表示"
 
-#: common.opt:1711
+#: common.opt:1715
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "将条件跳转替换为条件执行"
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, fuzzy, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "将条件跳转替换为没有跳转的等值表示"
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "不生成 .size 伪指令"
 
-#: common.opt:1747
+#: common.opt:1751
 #, fuzzy, no-c-format
 #| msgid "Perform indirect inlining"
 msgid "Perform indirect inlining."
 msgstr "进行间接内联"
 
-#: common.opt:1753
+#: common.opt:1757
 #, fuzzy, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "启用内联的函数声明“内联”，停用全部停用内联"
 
-#: common.opt:1757
+#: common.opt:1761
 #, fuzzy, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "在不导致代码膨胀的情况下将简单函数集成到它们的调用者中"
 
-#: common.opt:1761
+#: common.opt:1765
 #, fuzzy, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "将只被调用一次的函数集成到它们的调用者中"
 
-#: common.opt:1765
+#: common.opt:1769
 #, fuzzy, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "将只被调用一次的函数集成到它们的调用者中"
 
-#: common.opt:1772
+#: common.opt:1776
 #, fuzzy, no-c-format
 #| msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<N>\t将内联函数的大小限制在 N 以内"
 
-#: common.opt:1776
+#: common.opt:1780
 #, fuzzy, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "内联 __atomic 计算时锁定自由指令串行是可用。"
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, fuzzy, no-c-format
 #| msgid "Instrument function entry and exit with profiling calls"
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "在函数入口和出口加入取样调用"
 
-#: common.opt:1810
+#: common.opt:1814
 #, fuzzy, no-c-format
 #| msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=函数名,...  取样时排除列出的函数"
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, no-c-format
 #| msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=文件名,...  取样时排除列出的文件中的函数"
 
-#: common.opt:1818
+#: common.opt:1822
 #, fuzzy, no-c-format
 msgid "Perform interprocedural constant propagation."
 msgstr "进行进程间的复写传递"
 
-#: common.opt:1822
+#: common.opt:1826
 #, fuzzy, no-c-format
 #| msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "进行复制以使跨进程常量传递更有效"
 
-#: common.opt:1830
+#: common.opt:1834
 #, fuzzy, no-c-format
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "进行进程间的复写传递"
 
-#: common.opt:1834
+#: common.opt:1838
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform interprocedural modref analysis."
 msgstr "进行进程间的指向分析"
 
-#: common.opt:1838
+#: common.opt:1842
 #, fuzzy, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr "进行进程间的复写传递"
 
-#: common.opt:1842
+#: common.opt:1846
 #, fuzzy, no-c-format
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform interprocedural points-to analysis."
 msgstr "进行进程间的指向分析"
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "发现纯函数和常函数"
 
-#: common.opt:1850
+#: common.opt:1854
 #, fuzzy, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "展开所有循环"
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr "展开所有循环"
 
-#: common.opt:1858
+#: common.opt:1862
 #, fuzzy, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr "展开所有循环"
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only and non addressable static variables."
 msgstr "发现只读和不可寻址静态变量"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "发现只读和不可寻址静态变量"
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "进行树上的值域传递"
 
-#: common.opt:1886
+#: common.opt:1890
 #, fuzzy, no-c-format
 #| msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=|CB|priority] 设置使用的 IRA 算法"
 
-#: common.opt:1899
+#: common.opt:1903
 #, fuzzy, no-c-format
 #| msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] 设置 IRA 的区域"
 
-#: common.opt:1915
+#: common.opt:1919
 #, fuzzy, no-c-format
 #| msgid "Use IRA based register pressure calculation"
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "使用基于 IRA 的寄存器压力计算"
 
-#: common.opt:1920
+#: common.opt:1924
 #, fuzzy, no-c-format
 #| msgid "Use IRA based register pressure calculation"
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "使用基于 IRA 的寄存器压力计算"
 
-#: common.opt:1925
+#: common.opt:1929
 #, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr "为保存不同的硬寄存器的共享槽。"
 
-#: common.opt:1929
+#: common.opt:1933
 #, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "为溢出的伪寄存器共享堆栈槽。"
 
-#: common.opt:1933
+#: common.opt:1937
 #, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<N>\t控制 IRA 诊断信息的级别。"
 
-#: common.opt:1937
+#: common.opt:1941
 #, fuzzy, no-c-format
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "在树上优化归纳变量"
 
-#: common.opt:1941
+#: common.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "为足够大的 switch 语句使用跳转表"
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "为足够大的 switch 语句使用跳转表"
 
-#: common.opt:1949
+#: common.opt:1953
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "为完全内联的函数生成代码"
 
-#: common.opt:1953
+#: common.opt:1957
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "为完全内联的函数生成代码"
 
-#: common.opt:1957
+#: common.opt:1961
 #, fuzzy, no-c-format
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "保留未用到的静态常量"
 
-#: common.opt:1961
+#: common.opt:1965
 #, fuzzy, no-c-format
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "给外部符号添加起始的下划线"
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, no-c-format
 msgid "Enable link-time optimization."
 msgstr "启用链接时优化。"
 
-#: common.opt:1977
+#: common.opt:1981
 #, fuzzy, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Link-time 最佳化与平行工作编号的或 jobserver。"
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, fuzzy, no-c-format
 #| msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr "-flto-compression-level=<N>\t为 IL 使用 zlib 压缩级别 N"
 
-#: common.opt:2012
+#: common.opt:2016
 #, fuzzy, no-c-format
 #| msgid "Report various link-time optimization statistics"
 msgid "Report various link-time optimization statistics."
 msgstr "报告各种链接时优化统计"
 
-#: common.opt:2016
+#: common.opt:2020
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "报告各种链接时优化统计"
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "执行内建数学函数后设置 errno"
 
-#: common.opt:2024
+#: common.opt:2028
 #, fuzzy, no-c-format
 #| msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<n>\t报告错误数量的上限值"
 
-#: common.opt:2028
+#: common.opt:2032
 #, fuzzy, no-c-format
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "报告永久性内存分配"
 
-#: common.opt:2032
+#: common.opt:2036
 #, fuzzy, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "报告永久性内存分配"
 
-#: common.opt:2039
+#: common.opt:2043
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "试图合并相同的常量和常变量"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "试图合并不同编译单元中的相同常量"
 
-#: common.opt:2047
+#: common.opt:2051
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical debug strings across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "试图合并不同编译单元中的相同调试字符串"
 
-#: common.opt:2051
+#: common.opt:2055
 #, fuzzy, no-c-format
 #| msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<N>\t将诊断信息限制在每行 N 个字符。0 取消自动换行"
 
-#: common.opt:2055
+#: common.opt:2059
 #, fuzzy, no-c-format
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "在首趟调度前进行基于 SMS 的模调度"
 
-#: common.opt:2059
+#: common.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "进行基于 SMS 且允许寄存器转移的模调度"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy, no-c-format
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "将每次循环中不变的计算外提"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy, no-c-format
 #| msgid "Use the RTL dead code elimination pass"
 msgid "Use the RTL dead code elimination pass."
 msgstr "使用 RTL 死代码清除"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy, no-c-format
 #| msgid "Use the RTL dead store elimination pass"
 msgid "Use the RTL dead store elimination pass."
 msgstr "使用 RTL 死存储清除"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy, no-c-format
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "启用/禁用已经通过模调度的循环中的传统调度"
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "支持同步非调用异常"
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, fuzzy, no-c-format
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "尽可能不生成栈帧"
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "在树级别进行循环优化"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, fuzzy, no-c-format
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "优化同级递归和尾递归"
 
-#: common.opt:2124
+#: common.opt:2128
 #, fuzzy, no-c-format
 #| msgid "Perform partial inlining"
 msgid "Perform partial inlining."
 msgstr "进行部分内联"
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, fuzzy, no-c-format
 #| msgid "Report on memory allocation before interprocedural optimization"
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "在跨进程优化前报告内存分配"
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy, no-c-format
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "将结构成员不带间隔地紧实存放"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy, no-c-format
 #| msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<N>\t设定结构成员最大对齐边界的初始值"
 
-#: common.opt:2144
+#: common.opt:2148
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "在内存而不是寄存器中返回小聚合"
 
-#: common.opt:2148
+#: common.opt:2152
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "进行循环剥离"
 
-#: common.opt:2152
+#: common.opt:2156
 #, fuzzy, no-c-format
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "启用机器相关的窥孔优化"
 
-#: common.opt:2156
+#: common.opt:2160
 #, fuzzy, no-c-format
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "在 sched2 前进行一趟 RTL 窥孔优化"
 
-#: common.opt:2160
+#: common.opt:2164
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "尽可能生成与位置无关的代码(大模式)"
 
-#: common.opt:2164
+#: common.opt:2168
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "为可执行文件尽可能生成与位置无关的代码(大模式)"
 
-#: common.opt:2168
+#: common.opt:2172
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "尽可能生成与位置无关的代码(小模式)"
 
-#: common.opt:2172
+#: common.opt:2176
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "为可执行文件尽可能生成与位置无关的代码(小模式)"
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, fuzzy, no-c-format
 #| msgid "Specify a plugin to load"
 msgid "Specify a plugin to load."
 msgstr "指定要加载的插件"
 
-#: common.opt:2184
+#: common.opt:2188
 #, fuzzy, no-c-format
 #| msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<插件>-<键>[=<值>]\t为插件指定参数键=值"
 
-#: common.opt:2188
+#: common.opt:2192
 #, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr "启用预测公因子优化。"
 
-#: common.opt:2192
+#: common.opt:2196
 #, fuzzy, no-c-format
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "如果可用，为循环中的数组生成预取指令"
 
-#: common.opt:2196
+#: common.opt:2200
 #, fuzzy, no-c-format
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "启用基本程序取样代码"
 
-#: common.opt:2200
+#: common.opt:2204
 #, fuzzy, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr "生成快速间接调用"
 
-#: common.opt:2204
+#: common.opt:2208
 #, fuzzy, no-c-format
 #| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "插入基于弧的程序取样代码"
 
-#: common.opt:2208
+#: common.opt:2212
 #, fuzzy, no-c-format
 #| msgid "Set the top-level directory for storing the profile data."
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "指定存储的取样数据的顶级目录"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy, no-c-format
 #| msgid "Set the top-level directory for storing the profile data."
 msgid "Select the name for storing the profile note file."
 msgstr "指定存储的取样数据的顶级目录"
 
-#: common.opt:2217
+#: common.opt:2221
 #, fuzzy, no-c-format
 #| msgid "Enable correction of flow inconsistent profile data input"
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "启用对流不一致取样数据输入的修正"
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, fuzzy, no-c-format
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "启用一些公共选项来生成样本文件，以便进行基于取样的优化"
 
-#: common.opt:2269
+#: common.opt:2273
 #, fuzzy, no-c-format
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "启用生成取样信息的公共选项以支持基于取样反馈的优化，同时设置 -fprofile-dir="
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, fuzzy, no-c-format
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "启用一些公共选项以进行基于取样的优化"
 
-#: common.opt:2289
+#: common.opt:2293
 #, fuzzy, no-c-format
 #| msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "启用公共选项以进行基于取样反馈的优化，同时设置 -fprofile-dir="
 
-#: common.opt:2293
+#: common.opt:2297
 #, fuzzy, no-c-format
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "为取样表达式的值插入相关代码"
 
-#: common.opt:2297
+#: common.opt:2301
 #, fuzzy, no-c-format
 msgid "Report on consistency of profile."
 msgstr "内部一致性错误"
 
-#: common.opt:2301
+#: common.opt:2305
 #, fuzzy, no-c-format
 msgid "Enable function reordering that improves code placement."
 msgstr "函数重新排序以改善代码布局"
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 #| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "在函数序言中生成 cld 指令"
 
-#: common.opt:2312
+#: common.opt:2316
 #, fuzzy, no-c-format
 #| msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<数字>\t使用 <数字> 以使编译可复现"
 
-#: common.opt:2322
+#: common.opt:2326
 #, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr "在目标文件中记录 gcc 命令行开关。"
 
-#: common.opt:2326
+#: common.opt:2330
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "在寄存器中返回小聚合"
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, fuzzy, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "启用对寄存器压力敏感的指令调度"
 
-#: common.opt:2368
+#: common.opt:2372
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "进行寄存器重命名优化"
 
-#: common.opt:2372
+#: common.opt:2376
 #, fuzzy, no-c-format
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "进行寄存器重命名优化"
 
-#: common.opt:2376
+#: common.opt:2380
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "基本块重新排序以改善代码布局"
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks and partition into hot and cold sections"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "对基本块重新排序并划分为热区和冷区"
 
-#: common.opt:2397
+#: common.opt:2401
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "函数重新排序以改善代码布局"
 
-#: common.opt:2401
+#: common.opt:2405
 #, fuzzy, no-c-format
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "在循环优化结束后增加一趟公共子表达式消除"
 
-#: common.opt:2409
+#: common.opt:2413
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "禁用假定默认浮点舍入行为的优化"
 
-#: common.opt:2413
+#: common.opt:2417
 #, fuzzy, no-c-format
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "启用基本块间的调度"
 
-#: common.opt:2417
+#: common.opt:2421
 #, fuzzy, no-c-format
 #| msgid "Enable register pressure sensitive insn scheduling"
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "启用对寄存器压力敏感的指令调度"
 
-#: common.opt:2421
+#: common.opt:2425
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "允许非载入的投机移动"
 
-#: common.opt:2425
+#: common.opt:2429
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "允许一些载入的投机移动"
 
-#: common.opt:2429
+#: common.opt:2433
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "允许更多载入的投机移动"
 
-#: common.opt:2433
+#: common.opt:2437
 #, fuzzy, no-c-format
 #| msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<N>\t指定调度器的冗余级别"
 
-#: common.opt:2437
+#: common.opt:2441
 #, fuzzy, no-c-format
 #| msgid "If scheduling post reload, do superblock scheduling"
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "在重载后调度中使用跨基本块调度"
 
-#: common.opt:2445
+#: common.opt:2449
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "分配寄存器前重新调度指令"
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "分配寄存器后重新调度指令"
 
-#: common.opt:2456
+#: common.opt:2460
 #, fuzzy, no-c-format
 #| msgid "Schedule instructions using selective scheduling algorithm"
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "用选择性调度算法调度指令"
 
-#: common.opt:2460
+#: common.opt:2464
 #, fuzzy, no-c-format
 #| msgid "Run selective scheduling after reload"
 msgid "Run selective scheduling after reload."
 msgstr "在重加载后使用选择性调度"
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, fuzzy, no-c-format
 #| msgid "Perform software pipelining of inner loops during selective scheduling"
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "在选择性调度中对内层循环进行软件流水化"
 
-#: common.opt:2472
+#: common.opt:2476
 #, fuzzy, no-c-format
 #| msgid "Perform software pipelining of outer loops during selective scheduling"
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "在选择性调度中对外层循环进行软件流水化"
 
-#: common.opt:2476
+#: common.opt:2480
 #, fuzzy, no-c-format
 #| msgid "Reschedule pipelined regions without pipelining"
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "重新调度没有被流水线化的流水线区域"
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy, no-c-format
 #| msgid "Allow premature scheduling of queued insns"
 msgid "Allow premature scheduling of queued insns."
 msgstr "允许对队列中的指令进行早调度"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy, no-c-format
 #| msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<N>\t指定能被早期调度的在排队中的指令的最大数量"
 
-#: common.opt:2498
+#: common.opt:2502
 #, fuzzy, no-c-format
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "设置排队中指令的进行早调度的依赖距离检查"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy, no-c-format
 #| msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<N>\t设置排队中指令的进行早调度的依赖距离检查"
 
-#: common.opt:2506
+#: common.opt:2510
 #, fuzzy, no-c-format
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the group heuristic in the scheduler."
 msgstr "在调度器中启用组启发"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy, no-c-format
 #| msgid "Enable the critical path heuristic in the scheduler"
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "为调度器启用关键路径启发式发现"
 
-#: common.opt:2514
+#: common.opt:2518
 #, fuzzy, no-c-format
 #| msgid "Enable the speculative instruction heuristic in the scheduler"
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "为调度器启用投机指令启发式发现"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy, no-c-format
 #| msgid "Enable the rank heuristic in the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "在调度器中启用秩启发"
 
-#: common.opt:2522
+#: common.opt:2526
 #, fuzzy, no-c-format
 #| msgid "Enable the last instruction heuristic in the scheduler"
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "为调度器启用最近指令启发式发现"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy, no-c-format
 #| msgid "Enable the dependent count heuristic in the scheduler"
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "为调度器启用依赖计数启发式发现"
 
-#: common.opt:2530
+#: common.opt:2534
 #, fuzzy, no-c-format
 #| msgid "Access data in the same section from shared anchor points"
 msgid "Access data in the same section from shared anchor points."
 msgstr "从共享的锚点访问在同样的节中的数据"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "打开冗余延伸 Elimination 回合。"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy, no-c-format
 #| msgid "Show column numbers in diagnostics, when available.  Default on"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "诊断信息中给出行号。默认打开"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Emit 函数 prologues 只有之前零件的函数该需要它，"
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "禁用为 IEEE NaN 可见的优化"
 
-#: common.opt:2563
+#: common.opt:2567
 #, fuzzy, no-c-format
 #| msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "禁用忽略 IEEE 中零的符号的浮点优化"
 
-#: common.opt:2567
+#: common.opt:2571
 #, fuzzy, no-c-format
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "将浮点常量转换为单精度常量"
 
-#: common.opt:2571
+#: common.opt:2575
 #, fuzzy, no-c-format
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "展开循环时分离归纳变量的生存期"
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "生成与 APCS 相容的栈帧"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy, no-c-format
 #| msgid "Split wide types into independent registers"
 msgid "Split wide types into independent registers."
 msgstr "将宽类型分割到独立的寄存器中"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy, no-c-format
 #| msgid "Split wide types into independent registers"
 msgid "Split wide types into independent registers earlier."
 msgstr "将宽类型分割到独立的寄存器中"
 
-#: common.opt:2587
+#: common.opt:2591
 #, fuzzy, no-c-format
 #| msgid "Enable forward propagation on trees"
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "在树级别进行前向复写传递"
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "用以传递整数参数的寄存器个数"
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy, no-c-format
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "展开循环时也展开变量"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy, no-c-format
 #| msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\t在程序中插入检查栈溢出的代码"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy, no-c-format
 #| msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "在程序中插入检查栈溢出的代码。与 fstack-check=specific 相同"
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy, no-c-format
 #| msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-symbol=<寄存器>\t当堆栈越过寄存器时引发陷阱"
 
-#: common.opt:2623
+#: common.opt:2627
 #, fuzzy, no-c-format
 #| msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<符号>\t当堆栈越过符号时引发陷阱"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy, no-c-format
 #| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "使用 propolice 来保护堆栈"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy, no-c-format
 #| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "为每个函数使用堆栈保护机制"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "为每个函数使用堆栈保护机制"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "为每个函数使用堆栈保护机制"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr "为每个函数重用 r30"
 
-#: common.opt:2655
+#: common.opt:2659
 #, fuzzy, no-c-format
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "假定应用强重叠规则"
 
-#: common.opt:2659
+#: common.opt:2663
 #, fuzzy, no-c-format
 #| msgid "Treat signed overflow as undefined"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "将有符号数溢出的行为视为未定义的"
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, fuzzy, no-c-format
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "检查语法错误，然后停止"
 
-#: common.opt:2671
+#: common.opt:2675
 #, fuzzy, no-c-format
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "生成“gcov”需要的数据文件"
 
-#: common.opt:2675
+#: common.opt:2679
 #, fuzzy, no-c-format
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "进行跳转线程优化"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy, no-c-format
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "报告每趟汇编的耗时"
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, fuzzy, no-c-format
 #| msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\t设定默认的线程局部存储代码生成模式"
 
-#: common.opt:2706
+#: common.opt:2710
 #, fuzzy, no-c-format
 #| msgid "Reorder top level functions, variables, and asms"
 msgid "Reorder top level functions, variables, and asms."
 msgstr "重新排序文件作用域的函数、变量和汇编"
 
-#: common.opt:2710
+#: common.opt:2714
 #, fuzzy, no-c-format
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "通过尾复制进行超块合成"
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "假定浮点运算可能引发陷阱"
 
-#: common.opt:2726
+#: common.opt:2730
 #, fuzzy, no-c-format
 #| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "加法、减法或乘法溢出时激活陷阱"
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "启用树上的 SSA-CCP 优化"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "启用树上的 SSA-CCP 优化"
 
-#: common.opt:2742
+#: common.opt:2746
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "启用树上的循环不变量转移"
 
-#: common.opt:2750
+#: common.opt:2754
 #, fuzzy, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "进行变量追踪并且标记未被初始化的变量"
 
-#: common.opt:2758
+#: common.opt:2762
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "在树级别进行复写传递"
 
-#: common.opt:2766
+#: common.opt:2770
 #, fuzzy, no-c-format
 #| msgid "Transform condition stores into unconditional ones"
 msgid "Transform condition stores into unconditional ones."
 msgstr "将条件存储转换为非条件存储"
 
-#: common.opt:2770
+#: common.opt:2774
 #, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr "转换开关初始化"
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "启用树上的 SSA 死代码消除优化"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "启用主导优化"
 
-#: common.opt:2782
+#: common.opt:2786
 #, fuzzy, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "在树级别进行复写传递"
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "删除死存储"
 
-#: common.opt:2790
+#: common.opt:2794
 #, fuzzy, no-c-format
 #| msgid "Enable forward propagation on trees"
 msgid "Enable forward propagation on trees."
 msgstr "在树级别进行前向复写传递"
 
-#: common.opt:2794
+#: common.opt:2798
 #, fuzzy, no-c-format
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "启用树上的完全冗余消除(FRE)"
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "启用树上的 SSA-CCP 优化"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 #| msgid "Enable loop distribution on trees"
 msgid "Enable loop distribution on trees."
 msgstr "在树上进行循环分配"
 
-#: common.opt:2819
+#: common.opt:2823
 #, fuzzy, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "在树上进行循环分配"
 
-#: common.opt:2823
+#: common.opt:2827
 #, fuzzy, no-c-format
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "启用树上的循环不变量转移"
 
-#: common.opt:2831
+#: common.opt:2835
 #, fuzzy, no-c-format
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "在循环中生成正规的归纳变量"
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "在树级别进行循环优化"
 
-#: common.opt:2839
+#: common.opt:2843
 #, fuzzy, no-c-format
 #| msgid "Enable automatic parallelization of loops"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "启用循环的自动并行化"
 
-#: common.opt:2843
+#: common.opt:2847
 #, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "为条件指针外提内存读取操作。"
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "启用树上的 SSA-PRE 优化"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr "在树上进行函数内的指向分析。"
 
-#: common.opt:2859
+#: common.opt:2863
 #, fuzzy, no-c-format
 #| msgid "Enable reassociation on tree level"
 msgid "Enable reassociation on tree level."
 msgstr "在树级别进行重结合"
 
-#: common.opt:2867
+#: common.opt:2871
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "启用树上的 SSA 代码下沉优化"
 
-#: common.opt:2871
+#: common.opt:2875
 #, fuzzy, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr "进行强度削减最佳化"
 
-#: common.opt:2875
+#: common.opt:2879
 #, fuzzy, no-c-format
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "为聚合类型进行标量替换"
 
-#: common.opt:2879
+#: common.opt:2883
 #, fuzzy, no-c-format
 #| msgid "Replace temporary expressions in the SSA->normal pass"
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "在 SSA->normal 过程中替换临时表达式"
 
-#: common.opt:2883
+#: common.opt:2887
 #, fuzzy, no-c-format
 #| msgid "Perform live range splitting during the SSA->normal pass"
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "在 SSA->normal 过程中分离活动范围"
 
-#: common.opt:2887
+#: common.opt:2891
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "进行树上的值域传递"
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "一次编译一整个编译单元"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "展开所有迭代次数已知的循环"
 
-#: common.opt:2908
+#: common.opt:2912
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "展开所有循环"
 
-#: common.opt:2923
+#: common.opt:2927
 #, fuzzy, no-c-format
 #| msgid "Allow optimization for floating-point arithmetic which may change the"
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "允许可能因不同舍入模式而改变结果的浮点算术优化。"
 
-#: common.opt:2928
+#: common.opt:2932
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "与 -fassociative-math 相同，作用于包含除法的表达式。"
 
-#: common.opt:2936
+#: common.opt:2940
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "允许可能违反 IEEE 或 ISO 标准的优化"
 
-#: common.opt:2940
+#: common.opt:2944
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "外提循环内的测试语句"
 
-#: common.opt:2944
+#: common.opt:2948
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "进行循环剥离"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "仅为异常处理生成堆栈展开表"
 
-#: common.opt:2956
+#: common.opt:2960
 #, fuzzy, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2960
+#: common.opt:2964
 #, fuzzy, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2964
+#: common.opt:2968
 #, fuzzy, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2976
+#: common.opt:2980
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "进行变量跟踪"
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking by annotating assignments"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "评注赋值以进行变量跟踪"
 
-#: common.opt:2990
+#: common.opt:2994
 #, fuzzy, no-c-format
 #| msgid "Toggle -fvar-tracking-assignments"
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "切换 -fvar-tracking-assignments"
 
-#: common.opt:2998
+#: common.opt:3002
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "进行变量追踪并且标记未被初始化的变量"
 
-#: common.opt:3003
+#: common.opt:3007
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "在树上进行循环向量化"
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "在树上进行循环向量化"
 
-#: common.opt:3015
+#: common.opt:3019
 #, fuzzy, no-c-format
 #| msgid "Enable basic block vectorization (SLP) on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "在树上进行基本块向量化(SLP)"
 
-#: common.opt:3019
+#: common.opt:3023
 #, fuzzy, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr "启用向量化开销模型"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "启用向量化开销模型"
 
-#: common.opt:3042
+#: common.opt:3046
 #, fuzzy, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
-#: common.opt:3050
+#: common.opt:3054
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "为标量演化信息进行复写传递。"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "为汇编输出添加额外注释"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 #| msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\t设置符号的默认可见性"
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "在优化中使用表达式值样本提供的信息"
 
-#: common.opt:3111
+#: common.opt:3115
 #, fuzzy, no-c-format
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "建立关系网并且分离对同一变量的无关应用"
 
-#: common.opt:3115
+#: common.opt:3119
 #, fuzzy, no-c-format
 #| msgid "Enable conditional dead code elimination for builtin calls"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "为内建函数启用有条件的死代码消除优化"
 
-#: common.opt:3119
+#: common.opt:3123
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "进行全程序优化"
 
-#: common.opt:3123
+#: common.opt:3127
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "假定有符号运算溢出时回绕"
 
-#: common.opt:3127
+#: common.opt:3131
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "假定有符号运算溢出时回绕"
 
-#: common.opt:3131
+#: common.opt:3135
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "将初始化为零的数据存放在 bss 节中"
 
-#: common.opt:3135
+#: common.opt:3139
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Clear call-used registers upon function return."
 msgstr "函数调用前后保存/恢复寄存器值"
 
-#: common.opt:3139
+#: common.opt:3143
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:3143
+#: common.opt:3147
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%>需要汇编器支持 CFI 伪指令"
 
-#: common.opt:3147
+#: common.opt:3151
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%>需要汇编器支持 CFI 伪指令"
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, fuzzy, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "生成 DWARF v2(或更新)格式的调试信息"
 
-#: common.opt:3175
+#: common.opt:3179
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in DWARF v2 (or later) format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "生成 DWARF v2(或更新)格式的调试信息"
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "生成默认扩展格式的调试信息"
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "为每个函数生成单一的退出点"
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, fuzzy, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "在目标文件中记录 gcc 命令行开关。"
 
-#: common.opt:3219
+#: common.opt:3223
 #, fuzzy, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:3223
+#: common.opt:3227
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "生成 STABS 格式的调试信息"
 
-#: common.opt:3227
+#: common.opt:3231
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "生成扩展 STABS 格式的调试信息"
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, fuzzy, no-c-format
 #| msgid "Don't emit DWARF additions beyond selected version"
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "不生成较所选版本更先进的 DWARF 附加信息"
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, fuzzy, no-c-format
 #| msgid "Toggle debug information generation"
 msgid "Toggle debug information generation."
 msgstr "切换调试信息生成"
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "生成 VMS 格式的调试信息"
 
-#: common.opt:3258
+#: common.opt:3262
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "生成 XCOFF 格式的调试信息"
 
-#: common.opt:3262
+#: common.opt:3266
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "生成 XCOFF 扩展格式的调试信息"
 
-#: common.opt:3280
+#: common.opt:3284
 #, fuzzy, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "生成 VMS 格式的调试信息"
 
-#: common.opt:3284
+#: common.opt:3288
 #, fuzzy, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:3291
+#: common.opt:3295
 #, fuzzy, no-c-format
 #| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<目录>\t将目录设定为默认的插件子目录"
 
-#: common.opt:3295
+#: common.opt:3299
 #, fuzzy, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <目录>\t将目录设定为 multilib 的包含子目录"
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 #| msgid "-o <file>\tPlace output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <文件>\t将输出写入文件"
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "启用函数取样"
 
-#: common.opt:3334
+#: common.opt:3338
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "与 -pedantic 类似，但将它们视作错误"
 
-#: common.opt:3374
+#: common.opt:3378
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "不显示编译的函数或逝去的时间"
 
-#: common.opt:3406
+#: common.opt:3410
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "启用详细输出"
 
-#: common.opt:3410
+#: common.opt:3414
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "显示编译器版本"
 
-#: common.opt:3414
+#: common.opt:3418
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "不显示警告"
 
-#: common.opt:3424
+#: common.opt:3428
 #, fuzzy, no-c-format
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "生成一个共享库"
 
-#: common.opt:3472
+#: common.opt:3476
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:3476
+#: common.opt:3480
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:3480
+#: common.opt:3484
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -20799,1231 +20800,1241 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload"
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "重新载入后允许进行冗余消除的关键边执行次数的比例阈值"
 
-#: params.opt:178
+#: params.opt:183
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio for performing partial redundancy elimination after reload"
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "重新载入后进行部分冗余消除的比例阈值"
 
-#: params.opt:182
+#: params.opt:187
 #, fuzzy, no-c-format
 #| msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations"
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr "计算一个表达式被 GCSE 优化移动的最大距离时的比例因子"
 
-#: params.opt:186
+#: params.opt:191
 #, fuzzy, no-c-format
 #| msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel"
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr "指定 GCSE 优化不约束一个表达式能被移动的距离时的代价"
 
-#: params.opt:190
+#: params.opt:195
 #, fuzzy, no-c-format
 #| msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap"
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "引发垃圾收集的堆展开的最小值，以占堆总大小的百分比给出"
 
-#: params.opt:194
+#: params.opt:199
 #, fuzzy, no-c-format
 #| msgid "Minimum heap size before we start collecting garbage, in kilobytes"
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "开始垃圾回收时最小的堆大小，以千字节表示"
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP"
 msgid "Maximum number of arrays per SCoP."
 msgstr "一个静态控制部分(ScoP)中参数的最大数量"
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP"
 msgid "Maximum number of parameters in a SCoP."
 msgstr "一个静态控制部分(ScoP)中参数的最大数量"
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot"
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "当某基本块执行频率超过函数中基本块执行的最大频率的指定百分比时，该基本块可被考虑为热点代码"
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, fuzzy, no-c-format
 #| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot"
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "当某基本块执行频率超过函数中基本块执行的最大频率的指定百分比时，该基本块可被考虑为热点代码"
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, fuzzy, no-c-format
 #| msgid "How much can given compilation unit grow because of the inlining (in percent)"
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "给定的编译单元因内联造成的体积膨胀上限(以百分数表示)"
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 #| msgid "The upper bound for sharing integer constants"
 msgid "The upper bound for sharing integer constants."
 msgstr "共享整型常量的上界"
 
-#: params.opt:246
+#: params.opt:251
 #, fuzzy, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr "临界值 ipa-cp 机会求值该仍然是认为的 beneficial 到仿本。"
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "内联函数中嵌套内联的最大深度"
 
-#: params.opt:258
+#: params.opt:263
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "仅当被执行的调用的概率超过此参数时方进行递归地内联"
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, fuzzy, no-c-format
 #| msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)"
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "给定的编译单元因跨进程常量传递造成的编译单元体积膨胀上限(以百分数表示)"
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "超过这个大小的翻译单元被认为是大的"
 
-#: params.opt:278
+#: params.opt:283
 #, fuzzy, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr "最大容量的值清单的关联的与每个参数用于 interprocedural 常数传用"
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, fuzzy, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "指定一条指令最多能被调度几次"
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, fuzzy, no-c-format
 #| msgid "Maximum allowed growth of size of new parameters ipa-sra replaces a pointer to an aggregate with"
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr "IPA-SRA 考虑将指向的聚合的指针替换为参数时这些参数总和大小相对原指针参数大小倍数的最大值"
 
-#: params.opt:314
+#: params.opt:319
 #, fuzzy, no-c-format
 #| msgid "The number of registers in each class kept unused by loop invariant motion"
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr "保留不为循环不变量转移使用的各种寄存器的数量"
 
-#: params.opt:318
+#: params.opt:323
 #, fuzzy, no-c-format
 #| msgid "Max size of conflict table in MB"
 msgid "Max size of conflict table in MB."
 msgstr "以 MB 表示的冲突表大小上限"
 
-#: params.opt:322
+#: params.opt:327
 #, fuzzy, no-c-format
 #| msgid "Max loops number for regional RA"
 msgid "Max loops number for regional RA."
 msgstr "用作区域寄存器分配的最大循环数"
 
-#: params.opt:326
+#: params.opt:331
 #, fuzzy, no-c-format
 #| msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization"
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "当备选归纳变量少于设定值时总是设法在优化过程中消除未使用的归纳变量"
 
-#: params.opt:330
+#: params.opt:335
 #, fuzzy, no-c-format
 #| msgid "Bound on number of candidates below that all candidates are considered in iv optimizations"
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "当备选少于此设定值时所有备选都将为归纳变量优化所考虑"
 
-#: params.opt:334
+#: params.opt:339
 #, fuzzy, no-c-format
 #| msgid "Bound on number of iv uses in loop optimized in iv optimizations"
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "对归纳变量数少于设定值的循环进行归纳变量优化"
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, fuzzy, no-c-format
 #| msgid "The size of L1 cache line"
 msgid "The size of L1 cache line."
 msgstr "一级缓存列长度"
 
-#: params.opt:350
+#: params.opt:355
 #, fuzzy, no-c-format
 #| msgid "The size of L1 cache"
 msgid "The size of L1 cache."
 msgstr "一级缓存大小"
 
-#: params.opt:354
+#: params.opt:359
 #, fuzzy, no-c-format
 #| msgid "The size of L2 cache"
 msgid "The size of L2 cache."
 msgstr "二级缓存大小"
 
-#: params.opt:358
+#: params.opt:363
 #, fuzzy, no-c-format
 #| msgid "Maximal growth due to inlining of large function (in percent)"
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "内联大函数造成的代码膨胀的上限(以百分数的形式给出)"
 
-#: params.opt:362
+#: params.opt:367
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of function body to be considered large."
 msgstr "超过这个大小的函数体被认为是大的"
 
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 #| msgid "The size of stack frame to be considered large"
 msgid "The size of stack frame to be considered large."
 msgstr "超过这个大小的栈帧被认为是大的"
 
-#: params.opt:370
+#: params.opt:375
 #, fuzzy, no-c-format
 #| msgid "Maximal stack frame growth due to inlining (in percent)"
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "内联造成的栈帧膨胀的上限(以百分数的形式给出)"
 
-#: params.opt:374
+#: params.opt:379
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit to be considered large."
 msgstr "超过这个大小的翻译单元被认为是大的"
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, fuzzy, no-c-format
 #| msgid "The minimum cost of an expensive expression in the loop invariant motion"
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "循环不变量转移时一条昂贵的表达式的最小开销"
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, fuzzy, no-c-format
 #| msgid "size of tiles for loop blocking"
 msgid "Size of tiles for loop blocking."
 msgstr "循环分块中每小块的大小"
 
-#: params.opt:394
+#: params.opt:399
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "单个循环中考虑展开的平均最大指令数"
 
-#: params.opt:398
+#: params.opt:403
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically"
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr "静态预测时的最多循环次数"
 
-#: params.opt:402
+#: params.opt:407
 #, fuzzy, no-c-format
 #| msgid "Max basic blocks number in loop for loop invariant motion"
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr "用作循环不变量转移的循环中基本块的最大数量"
 
-#: params.opt:406
+#: params.opt:411
 #, fuzzy, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr "最大值 datarefs 数量循环用于创建循环数据依存性"
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in basic block to be considered for SLP vectorization"
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "考虑进行基本块向量化的基本块能包含的指令数上限"
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "单个循环中考虑展开的最大指令数"
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, fuzzy, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr "最少大小的分割用于 LTO (在中估计的指令)"
 
-#: params.opt:430
+#: params.opt:435
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP"
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr "一个静态控制部分(ScoP)中参数的最大数量"
 
-#: params.opt:434
+#: params.opt:439
 #, fuzzy, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr "最少大小的分割用于 LTO (在中估计的指令)"
 
-#: params.opt:438
+#: params.opt:443
 #, fuzzy, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr "分割区数量程序应该是分割到"
 
-#: params.opt:442
+#: params.opt:447
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "单个循环中考虑展开的平均最大指令数"
 
-#: params.opt:446
+#: params.opt:451
 #, fuzzy, no-c-format
 msgid "The maximum number of insns combine tries to combine."
 msgstr "考虑进行交叉跳转的最大入边数量"
 
-#: params.opt:450
+#: params.opt:455
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of a loop nest we completely peel"
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "一个完全剥离的循环嵌套所能有的最大深度"
 
-#: params.opt:454
+#: params.opt:459
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop that is peeled completely"
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "一个完全剥离的单个循环最大的剥离数"
 
-#: params.opt:458
+#: params.opt:463
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "一个完全剥离的循环所能有的最大指令数"
 
-#: params.opt:462
+#: params.opt:467
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "考虑进行交叉跳转的最大入边数量"
 
-#: params.opt:466
+#: params.opt:471
 #, fuzzy, no-c-format
 #| msgid "The maximum instructions CSE process before flushing"
 msgid "The maximum instructions CSE process before flushing."
 msgstr "清空前公因式消去处理的最大指令数"
 
-#: params.opt:470
+#: params.opt:475
 #, fuzzy, no-c-format
 #| msgid "The maximum length of path considered in cse"
 msgid "The maximum length of path considered in cse."
 msgstr "公因式消去时考虑的最大路径长度"
 
-#: params.opt:474
+#: params.opt:479
 #, fuzzy, no-c-format
 #| msgid "The maximum memory locations recorded by cselib"
 msgid "The maximum memory locations recorded by cselib."
 msgstr "cselib 最多记录的内存位置"
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to fill a delay slot"
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "考虑填充入延迟槽中的最大指令数"
 
-#: params.opt:486
+#: params.opt:491
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to find accurate live register information"
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "用以发现准确的活动寄存器信息的最大指令数量"
 
-#: params.opt:490
+#: params.opt:495
 #, fuzzy, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr "最大值现用本地保存数量在中 RTL 无作用保存体 elimination"
 
-#: params.opt:494
+#: params.opt:499
 #, fuzzy, no-c-format
 #| msgid "The maximum number of nested indirect inlining performed by early inliner"
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "早期内联器可以进行的嵌套间接内联的最大数量"
 
-#: params.opt:498
+#: params.opt:503
 #, fuzzy, no-c-format
 #| msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable"
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "在指针分析将该结构视为单一变量前结构包含的最大字段数"
 
-#: params.opt:502
+#: params.opt:507
 #, fuzzy, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr "Graphite 可分析的每函数所包含的基本块数量上限"
 
-#: params.opt:506
+#: params.opt:511
 #, fuzzy, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr "Graphite 可分析的每函数所包含的基本块数量上限"
 
-#: params.opt:510
+#: params.opt:515
 #, fuzzy, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "为实现跳转提示插入的 nop 的最大数(默认 2)"
 
-#: params.opt:514
+#: params.opt:519
 #, fuzzy, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "单个循环中考虑展开的最大指令数"
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE"
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "GCSE 可分配的最大内存量"
 
-#: params.opt:522
+#: params.opt:527
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns to duplicate when unfactoring computed gotos"
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "分解计算转移时复制指令的数量上限"
 
-#: params.opt:526
+#: params.opt:531
 #, fuzzy, no-c-format
 #| msgid "The maximum expansion factor when copying basic blocks"
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "复制基本块时最大的展开因子"
 
-#: params.opt:530
+#: params.opt:535
 #, fuzzy, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr "最大值深度的搜索在中 dominator 树用于运算式到 hoist"
 
-#: params.opt:534
+#: params.opt:539
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "自动内联时指令的最大数量"
 
-#: params.opt:538
+#: params.opt:543
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "由于嵌套内联造成的内联函数代码膨胀的上限值(指令数)"
 
-#: params.opt:542
+#: params.opt:547
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions non-inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "由于嵌套内联造成的非内联函数代码膨胀的上限值(指令数)"
 
-#: params.opt:546
+#: params.opt:551
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "单个可内联的函数体最多能包含的指令数"
 
-#: params.opt:550
+#: params.opt:555
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when inlining for size."
 msgstr "自动内联时指令的最大数量"
 
-#: params.opt:554
+#: params.opt:559
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "自动内联时指令的最大数量"
 
-#: params.opt:558
+#: params.opt:563
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "内联函数中嵌套内联的最大深度"
 
-#: params.opt:562
+#: params.opt:567
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for non-inline functions"
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "非内联函数中嵌套内联的最大深度"
 
-#: params.opt:566
+#: params.opt:571
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of an unswitched loop"
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "去开关后的循环所能有的最大指令数"
 
-#: params.opt:570
+#: params.opt:575
 #, fuzzy, no-c-format
 #| msgid "Bound on the cost of an expression to compute the number of iterations"
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "用于计算迭代次数的表达式的开销的上限值"
 
-#: params.opt:574
+#: params.opt:579
 #, fuzzy, no-c-format
 #| msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates"
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "暴力迭代次数分析算法评估迭代次数的上限"
 
-#: params.opt:578
+#: params.opt:583
 #, fuzzy, no-c-format
 #| msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps"
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "线索化跳转时一个以被复制的块中所能包含的最大语句数"
 
-#: params.opt:582
+#: params.opt:587
 #, fuzzy, no-c-format
 #| msgid "The maximum number of RTL nodes that can be recorded as combiner's last value"
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "可以被记作组合器的最终值的最大 RTL 节点数"
 
-#: params.opt:586
+#: params.opt:591
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns to duplicate when unfactoring computed gotos"
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "分解计算转移时复制指令的数量上限"
 
-#: params.opt:590
+#: params.opt:595
 #, fuzzy, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "单个循环中考虑展开的最大指令数"
 
-#: params.opt:594
+#: params.opt:599
 #, fuzzy, no-c-format
 #| msgid "Maximum length of partial antic set when performing tree pre optimization"
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr "进行树上部分冗余消除时部分可预期集的最大长度"
 
-#: params.opt:598
+#: params.opt:603
 #, fuzzy, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "通过 CFG 以扩展区域的最大循环次数"
 
-#: params.opt:602
+#: params.opt:607
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop"
 msgid "The maximum number of peelings of a single loop."
 msgstr "单个循环最大的剥离数"
 
-#: params.opt:606
+#: params.opt:611
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a peeled loop"
 msgid "The maximum number of insns of a peeled loop."
 msgstr "剥离后的循环所能有的最大指令数"
 
-#: params.opt:610
+#: params.opt:615
 #, fuzzy, no-c-format
 #| msgid "The maximum length of scheduling's pending operations list"
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "调度候选操作列表的最大长度"
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, fuzzy, no-c-format
 #| msgid "The maximum number of blocks in a region to be considered for interblock scheduling"
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "一个区域中考虑进行块间调度的最大块数"
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "一个区域中考虑进行块间调度的最大指令数"
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically"
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "静态预测时的最多循环次数"
 
-#: params.opt:630
+#: params.opt:635
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to search backward when looking for equivalent reload"
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "后向搜索以寻找等价重载入时要搜索的最大指令数量"
 
-#: params.opt:634
+#: params.opt:639
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in basic block to be considered for SLP vectorization"
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "考虑进行基本块向量化的基本块能包含的指令数上限"
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, fuzzy, no-c-format
 #| msgid "The maximum number of iterations through CFG to extend regions"
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "通过 CFG 以扩展区域的最大循环次数"
 
-#: params.opt:650
+#: params.opt:655
 #, fuzzy, no-c-format
 #| msgid "The maximum conflict delay for an insn to be considered for speculative motion"
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "考虑进行投机移动的指令的最大冲突延迟数"
 
-#: params.opt:654
+#: params.opt:659
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass"
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "首趟调度考虑准备生成的指令的最大数量"
 
-#: params.opt:666
+#: params.opt:671
 #, fuzzy, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr "进行强度削减最佳化"
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, fuzzy, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "最大值现用本地保存数量在中 RTL 无作用保存体 elimination"
 
-#: params.opt:682
+#: params.opt:687
 #, fuzzy, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "指定一条指令最多能被调度几次"
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "最大值现用本地保存数量在中 RTL 无作用保存体 elimination"
 
-#: params.opt:694
+#: params.opt:699
 #, fuzzy, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr "最大值数目的类似的 bbs 到比较 bb 与"
 
-#: params.opt:698
+#: params.opt:703
 #, fuzzy, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr "最大值数目的反复运算的回合之上函数"
 
-#: params.opt:702
+#: params.opt:707
 #, fuzzy, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr "最大值字串数量用于该项 strlen 最佳化回合将轨段字串长度"
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unrollings of a single loop"
 msgid "The maximum number of unrollings of a single loop."
 msgstr "单个循环最多可以被展开的次数"
 
-#: params.opt:714
+#: params.opt:719
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "单个循环中考虑展开的最大指令数"
 
-#: params.opt:718
+#: params.opt:723
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of an unswitched loop"
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "去开关后的循环所能有的最大指令数"
 
-#: params.opt:722
+#: params.opt:727
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unswitchings in a single loop"
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "单个循环中考虑去开关的最大指令数"
 
-#: params.opt:726
+#: params.opt:731
 #, fuzzy, no-c-format
 #| msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling"
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "如果使用了 -fvariable-expansion-in-unroller，即指单个变量在循环展开时可以同时被展开的次数"
 
-#: params.opt:730
+#: params.opt:735
 #, fuzzy, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr "最大递归深度用于展开 var 追踪运算式"
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, fuzzy, no-c-format
 #| msgid "Max. size of var tracking hash tables"
 msgid "Max. size of var tracking hash tables."
 msgstr "变量跟踪散列表的最大尺寸"
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, fuzzy, no-c-format
 #| msgid "The minimum number of matching instructions to consider for crossjumping"
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "考虑进行交叉跳转的最小匹配指令数量"
 
-#: params.opt:754
+#: params.opt:759
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "仅当被执行的调用的概率超过此参数时方进行递归地内联"
 
-#: params.opt:758
+#: params.opt:763
 #, fuzzy, no-c-format
 #| msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count"
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr "为有未知路程计数的循环启用预取时最小的指令/预取比"
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, fuzzy, no-c-format
 #| msgid "The minimum UID to be used for a nondebug insn"
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr "非调试指令所使用的最小 UID"
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, fuzzy, no-c-format
 #| msgid "The minimum probability of reaching a source block for interblock speculative scheduling"
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "块间投机调度时到达一个源块的最小概率"
 
-#: params.opt:778
+#: params.opt:783
 #, fuzzy, no-c-format
 #| msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization"
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "使用 -ftree-vectorize 时考虑进行向量化的循环次数下限"
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "单个循环中考虑展开的最大指令数"
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, fuzzy, no-c-format
 #| msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen"
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr "进行部分内联时分离区域入口基本块占函数入口基本块的百分比概率的上限"
 
-#: params.opt:816
+#: params.opt:834
 #, fuzzy, no-c-format
 #| msgid "Maximal estimated outcome of branch considered predictable"
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "被认为可以预测的分支的最大估算结果"
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, fuzzy, no-c-format
 #| msgid "The number of insns executed before prefetch is completed"
 msgid "The number of insns executed before prefetch is completed."
 msgstr "预取操作完成前执行指令的数目"
 
-#: params.opt:828
+#: params.opt:846
 #, fuzzy, no-c-format
 #| msgid "Min. ratio of insns to mem ops to enable prefetching in a loop"
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr "为循环启用预取时最小的指令/内存操作比"
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, fuzzy, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr "gimple 调用中有非法函数"
 
-#: params.opt:840
+#: params.opt:858
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of a loop nest we completely peel"
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "一个完全剥离的循环嵌套所能有的最大深度"
 
-#: params.opt:844
+#: params.opt:862
 #, fuzzy, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr "最大值条件保存对数量该可以是 sunk"
 
-#: params.opt:848
+#: params.opt:866
 #, fuzzy, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "用在标量演化分析器中的表达式的大小上限"
 
-#: params.opt:852
+#: params.opt:870
 #, fuzzy, no-c-format
 #| msgid "Bound on size of expressions used in the scalar evolutions analyzer"
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "用在标量演化分析器中的表达式的大小上限"
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, fuzzy, no-c-format
 #| msgid "Minimal distance between possibly conflicting store and load"
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr "可能冲突的存储和装载之间的最小距离"
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "以百分比表示的投机成功的最小概率，影响对投机指令的调度"
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, fuzzy, no-c-format
 #| msgid "Maximum number of instructions in the ready list that are considered eligible for renaming"
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "在适合行重命名的就绪列表中最多的指令数"
 
-#: params.opt:880
+#: params.opt:898
 #, fuzzy, no-c-format
 #| msgid "The maximum size of the lookahead window of selective scheduling"
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr "进行选择调度时前瞻窗口的最大尺寸"
 
-#: params.opt:884
+#: params.opt:902
 #, fuzzy, no-c-format
 #| msgid "Maximum number of times that an insn could be scheduled"
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "指定一条指令最多能被调度几次"
 
-#: params.opt:888
+#: params.opt:906
 #, fuzzy, no-c-format
 #| msgid "The number of prefetches that can run at the same time"
 msgid "The number of prefetches that can run at the same time."
 msgstr "可以同时运行的预取操作数目"
 
-#: params.opt:892
+#: params.opt:910
 #, fuzzy, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr "目标区块相对的运行频率 (作为百分比) 必要项到槽叙述"
 
-#: params.opt:896
+#: params.opt:914
 #, fuzzy, no-c-format
 #| msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA"
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "使用 DFA 检查冲突时摆动模调度器考虑的周期数"
 
-#: params.opt:900
+#: params.opt:918
 #, fuzzy, no-c-format
 #| msgid "A threshold on the average loop count considered by the swing modulo scheduler"
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "由摆动模调度程序考虑的关于平均循环计数的阈值 "
 
-#: params.opt:904
+#: params.opt:922
 #, fuzzy, no-c-format
 #| msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop"
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "调整摆动模调度器调度循环时使用的上限的一个因素"
 
-#: params.opt:908
+#: params.opt:926
 #, fuzzy, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr "最小值的阶段计数该 Swing 类别 modulo 调度程序将产生。"
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "单个循环中考虑展开的平均最大指令数"
 
-#: params.opt:928
+#: params.opt:946
 #, fuzzy, no-c-format
 #| msgid "The lower bound for a buffer to be considered for stack smashing protection"
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "考虑预防堆栈溢出的缓冲区的下限值"
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, fuzzy, no-c-format
 #| msgid "The maximum ratio between array size and switch branches for a switch conversion to take place"
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "当数组大小与开关分支的比率大于此值时开关转换不会发生"
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP"
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "一个静态控制部分(ScoP)中参数的最大数量"
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 #| msgid "maximum number of parameters in a SCoP"
 msgid "Maximum number of references stored in each modref base."
 msgstr "一个静态控制部分(ScoP)中参数的最大数量"
 
-#: params.opt:960
+#: params.opt:978
 #, fuzzy, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "最大值现用本地保存数量在中 RTL 无作用保存体 elimination"
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr "最大值条件保存对数量该可以是 sunk"
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, fuzzy, no-c-format
 #| msgid "Maximum number of times that an insn could be scheduled"
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "指定一条指令最多能被调度几次"
 
-#: params.opt:976
+#: params.opt:994
 #, fuzzy, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr "大小在中字节之后该项 thread-local 汇总应该被器具与记录档函数以代替保存/还原对"
 
-#: params.opt:980
+#: params.opt:998
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "必须被踪迹形成所覆盖的函数百分比，以执行频率加权。当取样反馈不可用时使用"
 
-#: params.opt:984
+#: params.opt:1002
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "必须被踪迹形成所覆盖的函数百分比，以执行频率加权。当取样反馈可用时使用"
 
-#: params.opt:988
+#: params.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Maximal code growth caused by tail duplication (in percent)"
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "以百分比表示的尾复制所引起的最大代码膨胀"
 
-#: params.opt:992
+#: params.opt:1010
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "当最优边的概率小于此限值(以百分数表示)时，停止前向增长。当取样反馈不可用时使用。"
 
-#: params.opt:996
+#: params.opt:1014
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "当最优边的概率小于此限值(以百分数表示)时，停止前向增长。当取样反馈可用时使用。"
 
-#: params.opt:1000
+#: params.opt:1018
 #, fuzzy, no-c-format
 #| msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)"
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "当最优边的反向概率小于此阈值(以百分数表示)时停止反向增长"
 
-#: params.opt:1004
+#: params.opt:1022
 #, fuzzy, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr "设置最大值指令数量运行的在中平行在中 reassociated 树。如果 0, 使用目标附属试探。"
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 #| msgid "Emit implicit instantiations of templates"
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "允许模板隐式实例化"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, fuzzy, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr "为实现跳转提示插入的 nop 的最大数(默认 2)"
 
-#: params.opt:1020
+#: params.opt:1038
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "使用子程序完成函数前言/尾声"
 
-#: params.opt:1024
+#: params.opt:1042
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "使用子程序完成函数前言/尾声"
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, fuzzy, no-c-format
 #| msgid "Whether to use canonical types"
 msgid "Whether to use canonical types."
 msgstr "是否使用合乎规范的类型"
 
-#: params.opt:1056
+#: params.opt:1074
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "在树上进行循环向量化"
 
-#: params.opt:1060
+#: params.opt:1078
 #, fuzzy, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr "为实现跳转提示插入的 nop 的最大数(默认 2)"
 
-#: params.opt:1064
+#: params.opt:1082
 #, fuzzy, no-c-format
 #| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check"
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "向量循环版本化插入的运行时别名检查次数的上限"
 
-#: params.opt:1068
+#: params.opt:1086
 #, fuzzy, no-c-format
 #| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check"
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "向量循环版本化插入的运行时对齐检查次数的上限"
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -22056,7 +22067,7 @@ msgid "expected boolean type"
 msgstr "需要整数或布尔类型"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -22128,7 +22139,7 @@ msgstr "实参太少"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "实参太多"
@@ -22533,7 +22544,7 @@ msgstr "%qE属性与 %s 属性冲突"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "%q+T先前在此处有过声明"
@@ -22589,7 +22600,7 @@ msgstr "类型属性在定义后被忽略"
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -22618,20 +22629,20 @@ msgstr "类型属性在定义后被忽略"
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -22643,8 +22654,8 @@ msgstr "%qE属性被忽略"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "%qD先前没有声明"
@@ -22654,60 +22665,60 @@ msgstr "%qD先前没有声明"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D已被声明为具有 dllexport 属性：忽略 dllimport"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D重声明时没有 dllimport 属性，但已被作为 dllimport 链接引用过"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D重声明时没有 dllimport 属性：忽略先前的 dllimport"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared as  dllimport: attribute ignored"
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "内联函数%q+D声明为 dllimport：忽略此属性"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "函数%q+D的定义被标记为 dllimport"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "变量%q+D的定义被标记为 dllimport"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "符号%q+D需要外部链接，因为%qE属性"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qE意味着默认可见性；但%qD已经被声明为有不同的可见性"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "%qD target declared here"
 msgstr "%qD在此声明"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -22812,7 +22823,7 @@ msgstr "模板形参类型%qT声明为%<friend%>"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "偏移量越过字符串常量界"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -22838,614 +22849,614 @@ msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "%<__builtin_prefetch%>的第三个实参无效；使用 0"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr ""
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr ""
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr ""
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "source object declared here"
 msgstr "在此声明"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, gcc-internal-format
 msgid "source object allocated here"
 msgstr ""
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr "数组%qE的大小为负"
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr ""
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "destination object declared here"
 msgstr "%qD在此声明"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 msgid "destination object allocated here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "给函数%<va_start%>的参数太少"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "%<...%>作为实参。)"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "%<__builtin___clear_cache%>的两个参数必须都是指针"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD在 GCC 4.4 中语义已经改变"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "未知的架构‘%s’"
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "%<__builtin_frame_address%>的实参无效"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, fuzzy, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "失败内存式样无法 stronger 比成功内存式样用于 %<__atomic_compare_exchange%>"
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, fuzzy, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "无效的失败内存式样用于 %<__atomic_compare_exchange%>"
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "错误地使用了%<auto%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "gimple 内存存储中右操作数无效"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 1 to %qs"
 msgstr "常量实参超过%qs的范围"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-integer argument 1 to %qs"
 msgstr "常量实参超过%qs的范围"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_saveregs 不为此目标所支持"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return 在此目标机上不受支持"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelax is only supported for RTP PIC"
 msgid "%qs only supported in OpenACC code"
 msgstr "-mrelax 只在 RTP PIC 上受支持"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 0 to %qs"
 msgstr "常量实参超过%qs的范围"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to %qs"
 msgid "illegal argument 0 to %qs"
@@ -23453,128 +23464,128 @@ msgstr "%qs缺少参数"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K对%<__builtin_va_arg_pack ()%>的使用无效"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%K对%<__builtin_va_arg_pack_len ()%>的使用无效"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%>的第二个实参必须是 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "目标格式不支持无限大浮点数"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "在定参数的函数中使用了%<va_start%>"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "给函数%<va_start%>的参数数目不对"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "调用%<__builtin_next_arg%>时没有给定实参"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>的第二个参数不是最后一个有名参数"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "当%<va_start%>的第二个参数有%<register%>存储时行为未经定义"
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%K%D 的最后一个实参不是一个 0 到 3 之间的整常量"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, gcc-internal-format
 msgid "declared here"
 msgstr "在此声明"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 msgid "returned from %qD"
 msgstr "与先前的声明%q+D不同"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 msgid "returned from %qT"
 msgstr "与先前的声明%q+D不同"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "obtained here"
 msgstr "联合在此定义"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "assigned here"
 msgstr "联合在此定义"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -24358,305 +24369,305 @@ msgstr "基本块不连贯"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "指令链中记录的基本块数 (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "调用边计数为负"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "函数‘%s’在%C处缺少参数列表"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "块 %i 后缺少屏障"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "为边 %s->%s 设定辅助域"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "节点是单独在中 comdat 群组"
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "需要内联克隆"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "%<num_threads%>值必须为正"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "强制公共符号必须定义"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, fuzzy, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "为外部可见的名字添加下划线"
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, fuzzy, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "已取地址，但是 ADDRESSABLE 位未被设置"
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "需要内联克隆"
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "在有返回值的的函数中，%<return%>不带返回值"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "为边 %s->%s 设定辅助域"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "edge count is not compatible with function count"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "间接边缘从 %s 未被标记为间接或已关联的 indirectinfo(_I)，相应叙述是："
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to pointer 错误"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "多个内联调用者"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "为非内联的调用者设定了 inlined_to pointer"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "调用边频率 %i 与基本块频率 %i 不匹配"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, fuzzy, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "调用边频率 %i 与基本块频率 %i 不匹配"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "设定了 inlined_to 指针却找不到前驱"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "节点有错误的 clone_of"
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "节点的克隆列表不正确"
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "节点的 prev_clone 指针错误"
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "双向克隆链接列表已损坏"
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, fuzzy, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "基本块 %i 有多个 EH 边"
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, fuzzy, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "别名有 non-alias 参考"
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, fuzzy, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "别名有超过一个别名参考"
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, fuzzy, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "%qE有%qs的引用类型"
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, fuzzy, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "没有边缘超出 thunk 节点"
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, fuzzy, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "超过一个边缘超出 thunk 节点"
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, fuzzy, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "广义常表达式构造函数体不为空"
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "共享的 call_stmt："
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "边指向错误的声明："
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, fuzzy, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "间接边缘与未知被调用端相应到 callstmt 与已知声明(_S)："
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "调用语句缺少 callgraph 边："
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "删除死存储"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "边 %s->%s 没有对应的 call_stmt"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "边 %s->%s 没有对应的 call_stmt"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, fuzzy, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "将一个指针转换为大小不同的整数"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node 失败"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "在 %s %s 中有缺失的“%s”\n"
@@ -24741,12 +24752,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%qE属性被忽略，因为%qT已被定义"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F使用过但从未定义"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F声明为%<static%>却从未定义过"
@@ -24822,7 +24833,7 @@ msgstr "%q+D返回值的大小为 %u 字节"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "%q+D返回值的大小超过 %wd 字节"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "找到未释放内存的节点"
@@ -25240,12 +25251,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr "多个 EH 个性需要汇编器支持 .cfi.personality 指示。"
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "变量位置处发现未被非法化的 UNSPEC %d"
@@ -25265,7 +25276,7 @@ msgstr "共享的 rtx"
 msgid "internal consistency failure"
 msgstr "内部一致性错误"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE：需要 emit_jump_insn 时使用了 emit_insn：\n"
@@ -25404,42 +25415,42 @@ msgstr "无法关闭最终指令转储文件%qs：%s"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "大定点常量隐式截断为定点类型"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由于位段宽度所限，比较结果永远为 %d"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "简化范围检查时假定有符号数从不溢出"
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比较结果始终为 %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "对两个不匹配的不等比较取%<or%>的结果总为 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "对两个互斥的相等比较取%<and%>的结果永远是 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "在比较中归约常量时假定有符号数从不溢出"
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "在比较周围组合变量时假定有符号数从不溢出"
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折叠检查: 原始树因折叠而改变 "
@@ -25456,7 +25467,7 @@ msgstr "局部对象的总大小太大"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "局部对象的总大小太大"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%>中不可能的约束"
@@ -26098,7 +26109,7 @@ msgstr "空指针"
 msgid "function may return address of local variable"
 msgstr "函数可能返回局部变量的地址"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "函数返回局部变量的地址"
@@ -26458,69 +26469,69 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "%s 出现在%L处的格式字符串中"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 #| msgid "invalid use of %<auto%>"
 msgid "%Guse of %<alloca%>"
 msgstr "错误地使用了%<auto%>"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 #| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array may be too large"
 msgstr "使用变长数组时警告"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "%qE属性的实参大于 %d"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 #| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array is too large"
 msgstr "使用变长数组时警告"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "%qE属性的实参大于 %d"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 #| msgid "ISO C90 forbids variable length array"
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C90 不允许变长数组"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 #| msgid "invalid use of %<auto%>"
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "错误地使用了%<auto%>"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 #, fuzzy
 #| msgid "invalid use of %<auto%>"
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "错误地使用了%<auto%>"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 #| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array is zero"
 msgstr "使用变长数组时警告"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 #| msgid "Second argument of MOD at %L is zero"
 msgid "%Gargument to %<alloca%> is zero"
@@ -26625,7 +26636,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "array %qD declared here"
@@ -26653,11 +26664,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD在此声明"
@@ -26740,317 +26751,317 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr "使用返回%<void%>的函数的结果"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-memory input %d must stay in memory"
 msgid "non-memory output %d must stay in memory"
 msgstr "非内存输入 %d 必须在内存中"
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "汇编输出 %d 中左值无效"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "非内存输入 %d 必须在内存中"
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "内存输入 %d 不可直接寻址"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 msgid "enclosing region"
 msgstr "括入并行"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "括入并行"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, fuzzy, gcc-internal-format
 msgid "enclosing task"
 msgstr "括入并行"
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "括入并行"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, fuzzy, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "括入并行"
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE未声明(在此函数内第一次使用)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr "括入并行"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "迭代变量%qE不应当是 reduction"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "迭代变量%qE不应当是 firstprivate"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "迭代变量%qE不应当是 reduction"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %<lastprivate%>"
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %<lastprivate%>"
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "尚未支持代码模式 %<large%>"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD模板声明无效"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, fuzzy, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "主要区域不可以紧密嵌套在工作共享或显式的任务区域内"
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, fuzzy, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "主要区域不可以紧密嵌套在工作共享或显式的任务区域内"
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "有序区域必须紧密嵌套在一个有次序分句的循环内"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "返回值的数量不匹配值的数量"
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失败"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "通过%<...%>传递时%qT被提升为%qT"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您应该向%<va_arg%>传递%qT而不是%qT)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果执行到这段代码，程序将中止"
@@ -27498,23 +27509,23 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s 不能在这里用于 asm"
 
-#: ira.c:5920
+#: ira.c:5921
 #, fuzzy, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr "为叶函数(不调用其他函数的函数)忽略框架指针"
 
-#: ira.c:5921
+#: ira.c:5922
 #, gcc-internal-format
 msgid "for %qD"
 msgstr "为 %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "对可靠的堆栈检查来说框架太大了"
@@ -27534,12 +27545,12 @@ msgstr "%<asm%>操作数中有不可能的约束"
 msgid "unable to find a register to spill"
 msgstr "在类%qs中找不到可溢出的寄存器"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "%<asm%>中操作数约束不一致"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "最大值条件保存对数量该可以是 sunk"
@@ -28282,12 +28293,12 @@ msgstr "-malign-functions=%d 不在 0 和 %d 之间"
 msgid "unrecognized argument in option %qs"
 msgstr "memusage：无法识别的选项“$1”"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs对%qs而言无效"
@@ -28418,7 +28429,7 @@ msgstr "-static-libgfortran 在此配置下不受支持"
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr "当文件作用域重排序被禁用时也必须禁用节中锚点"
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work with exceptions on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
@@ -28970,25 +28981,25 @@ msgstr "隐式弹栈的寄存器必须集中在栈顶"
 msgid "output operand %d must use %<&%> constraint"
 msgstr "输出操作数 %d 必须使用%<&%>约束"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "validate_value_data：[%u]  空链(%u) 的 next_regno 错误"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: Loop in regno chain (%u)"
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "validate_value_data：在 regno 链(%u)中的循环"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "validate_value_data：[%u] 错误的 oldest_regno (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
@@ -29054,13 +29065,13 @@ msgstr "不能在%<asm%>中重新加载整数常量操作数"
 msgid "impossible register constraint in %<asm%>"
 msgstr "%<asm%>中不可能的寄存器约束"
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "此目标机不支持 %qs"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "%<&%>约束未与寄存器类型一起使用"
@@ -29090,53 +29101,53 @@ msgstr "%<asm%>操作数的约束与操作数大小不兼容"
 msgid "output operand is constant in %<asm%>"
 msgstr "%<asm%>的输出操作数是常量"
 
-#: rtl.c:850
+#: rtl.c:860
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "RTL 检查：在 %4$s 中访问了‘%2$s’的 elt %1$d，最后的 elt %3$d，于 %5$s:%6$d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL 检查：在 %5$s 中需要 elt %1$d 类型‘%2$c’，得到了‘%3$c’(rtx %4$s)，于 %6$s:%7$d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL 检查：在 %6$s 中需要 elt %1$d 类型‘%2$c’或‘%3$c’，得到了‘%4$c’(rtx %5$s)，于 %7$s:%8$d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL 检查：需要代码‘%s’，却得到‘%s’在 %s，于 %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL 检查：需要代码‘%s’或‘%s’，却得到‘%s’在 %s，于 %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL 检查：需要代码‘%s’或‘%s’，却得到‘%s’在 %s，于 %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "RTL 检查：在 %s 中试图将非块符号处理为块符号，于 %s:%d"
 
-#: rtl.c:937
+#: rtl.c:947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL 检查：在 %3$s 中访问了向量 elt %1$d，最后的 elt %2$d，于 %4$s:%5$d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL 检查：在 %3$s 中访问了向量 elt %1$d，最后的 elt %2$d，于 %4$s:%5$d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "RTL 标记检查：%3$s 中与非预期 rtx 代码‘%2$s’一起使用的 %1$s，于 %4$s:%5$d"
@@ -29181,23 +29192,23 @@ msgstr "匹配的约束引用了无效的操作数号"
 msgid "invalid punctuation %qc in constraint"
 msgstr "约束中出现无效的标点%qc"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "匹配的约束不允许使用寄存器"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate asm operand name %qs"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "重复的汇编操作数名%qs"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "有名操作数后缺少右花括号"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "未定义的有名操作数%qs"
@@ -29908,9 +29919,9 @@ msgstr "%%R 的操作数无效"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "非类型参数包中类型不匹配"
@@ -29946,7 +29957,7 @@ msgstr "BIT_FIELD_REF 位置或大小操作数无效"
 msgid "invalid clique in %qs"
 msgstr "错误地使用了%qD"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
@@ -30159,379 +30170,379 @@ msgstr "二元操作中中操作数无效"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "需要整数表达式"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, fuzzy, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "矢量与不同的组件号码找到在中矢量 permute 运算式"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "表格类型   ：%s\n"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "不支持的组合：%s"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size in %qs"
 msgstr "BIT_FIELD_REF 位置或大小操作数无效"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "无效的移位操作数"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "常量实参超过%qs的范围"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a directory"
 msgid "%qs not at element boundary"
 msgstr "%qs 不是目录"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial conversion at assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "赋值时不平凡的转换"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "in statement"
 msgid "%qs LHS in clobber statement"
 msgstr "在语句中"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "%%R 的操作数无效"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rhs for gimple memory store"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "gimple 内存存储中右操作数无效"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "incorrect type of vector %qs elements"
 msgstr "左移次数大于或等于类型宽度"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "提供给函数%qE的实参太多"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, fuzzy, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "PHI 参数不是 GIMPLE 变量"
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, fuzzy, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "向量初始值设定项中有多余元素"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR 具有一个总是假的条件"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "返回语句操作数无效"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "返回语句转换无效"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "goto 的目标既非标号亦非指针"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "开关语句操作数无效"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "位段%qD非整型"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, fuzzy, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "gimple 调用中静态链无效"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, fuzzy, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case 标号未排序： "
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "make_local_variable: 当前作用域中没有函数上下文"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect entry in label_to_block_map"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "label_to_block_map 中条目不正确"
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "着陆场号码设置不正确"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "gimple 条件中比较代码无效"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "gimple 条件中的标号无效"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "无效的 PHI 结果"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "缺少 PHI 定义"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "无效的 PHI 实参"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "PHI 实参 %u 类型不兼容"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple 失败"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, fuzzy, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "在 EH 表中死了的 STMT"
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "local declaration from a different function"
 msgstr "隐式声明函数%qE"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) 设置为一个错误的基本块"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, fuzzy, gcc-internal-format
 msgid "PHI node with location"
 msgstr " (位置列表)"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "对树结节的共享不正确"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, fuzzy, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "PHI 参数不是 SSA_NAME 或不变量"
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) 设置为一个错误的基本块"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "语句被标记为抛出异常，但实际上并未抛出"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "语句在块中被标记为抛出"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple 失败"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK 有与之关联的 IL"
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK 有与之关联的 IL"
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "直通边从基本块 %d 退出"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "非局部标号"
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH 着陆场标号"
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, gcc-internal-format
 msgid "label "
 msgstr "标号"
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "基本块 %d 中出现流程控制"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "在基本块 %d 中控制语句后的直通边"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "基本块 %d 中非 GIMPLE_COND 后的真假边"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "基本块 %d 结尾处有错误的出边标记"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "基本块 %d 末尾显式的 goto"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "基本块 %d 中，返回边并不指向退出"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "默认 case 不在 case 向量的开头"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "case 标号未排序： "
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "多余的出边 %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "缺少边 %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>函数返回了"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "在有返回值的函数中，控制流程到达函数尾"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -31646,7 +31657,7 @@ msgstr "线程局部的 COMMON 数据没有实现"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%q+D需要的对齐边界大于实现的对齐边界 %wu"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D的存储大小未知"
@@ -31813,7 +31824,7 @@ msgstr "字节码流：需要标记 %s 而非 %s"
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "字节码流：标记 %s 不在预期的范围[%s，%s]内"
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 msgid "unsupported record layout"
 msgstr "不支持的组合：%s"
@@ -32465,7 +32476,7 @@ msgstr "%qE属性为%qE所忽略"
 msgid "type was previously declared %qE"
 msgstr "以前在此声明过"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -32486,7 +32497,7 @@ msgstr "选择%qD而不是%qD"
 msgid "%qE argument is not a function"
 msgstr "属性%qE的参数无效"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "过时消息不是一个字符串"
@@ -32942,12 +32953,12 @@ msgstr "枚举常量在此定义"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD的地址总是等价为%<true%>"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建议在用作真值的赋值语句前后加上括号"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "错误地使用了%<restrict%>"
@@ -33111,13 +33122,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "为 lambda 形参指定了默认参数"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "提供给函数%qE的实参太少"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "提供给函数%qE的实参太多"
@@ -34097,7 +34108,7 @@ msgstr "不受支持的非标准字面字符串毗连"
 msgid "traditional C rejects string constant concatenation"
 msgstr "传统 C 不接受字符串常量毗连"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -34149,7 +34160,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "迭代变量%qE类型无效"
@@ -34165,17 +34176,17 @@ msgstr "迭代变量%qE类型无效"
 msgid "%qE is not initialized"
 msgstr "%qE未经初始化"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制谓词"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "无效的控制谓词"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少自增语句"
@@ -34185,7 +34196,7 @@ msgstr "缺少自增语句"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "无效的自增语句"
@@ -34254,7 +34265,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -34860,8 +34871,8 @@ msgstr "<返回值>"
 msgid "wrong type argument to %s"
 msgstr "不能对该类型的参数求绝对值"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常量表达式溢出"
@@ -35373,17 +35384,17 @@ msgstr "令函数%qD自减"
 msgid "function %qD used as %<asm%> output"
 msgstr "函数%qD用作%<asm%>的输出"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "向只读位置%qE赋值"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "令只读位置%qE自增"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "令只读位置%qE自减"
@@ -35564,8 +35575,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
@@ -35648,163 +35659,163 @@ msgid "passing argument %i to %qs-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to %qs-qualified parameter aliases with arguments %Z"
 msgstr[0] "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "联合在此定义"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as %s"
 msgstr "以前在此声明过"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn if a variable length array is used"
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "使用变长数组时警告"
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as a pointer %s"
 msgstr "以前在此声明过"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as an ordinary array %s"
 msgstr "以前在此声明过"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C90 forbids variable length array"
 msgid "previously declared as a variable length array %s"
 msgstr "ISO C90 不允许变长数组"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as an array %s"
 msgstr "以前在此声明过"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "%q+D带有 noinline 属性的声明出现在其内联声明之后"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr ""
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared as %s with bound argument %E"
 msgstr "以前在此声明过"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %<%c%s%>"
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "%<%c%s%>的上一个声明"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %qs"
 msgstr "先前的声明%q+D"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -35819,7 +35830,7 @@ msgstr "%qs对%qs而言无效"
 msgid "too many input files"
 msgstr "输入文件太多"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -35853,14 +35864,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "%qs对%qs而言无效"
@@ -36022,64 +36033,64 @@ msgstr "-mregparm=%d 不在 0 和 %d 之间"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%s%s：未知的主机。\n"
@@ -36257,83 +36268,83 @@ msgstr "-mcpu=%s 与 -march=%s 冲突"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "打开临时头文件失败：%s"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "%qE 2.95 虚表兼容属性只在编译内核扩展时有效"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "%qE 2.95 虚表兼容属性只对 C++ 类有效"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "可见性属性在此配置下不受支持；已忽略"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "打开临时头文件失败：%s"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, fuzzy, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> >= 2 只在%<-m64%>目标下支持%<-fnext-runtime%>"
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, fuzzy, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%> >= 2 只在%<-m64%>目标下支持%<-fnext-runtime%>"
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "%<-mdynamic-no-pic%> 覆盖了 %<-fpic%>, %<-fPIC%>, %<-fpie%> 及 %<-fPIE%>"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "内建函数%qD只需要一个实参"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "缺少 CFString 字面量"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "CFString 字面表达式不是一个字符串常量"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, fuzzy, gcc-internal-format
 #| msgid "%s in CFString literal"
 msgid "non-ASCII character in CFString literal"
 msgstr "CFString 字面量里有 %s"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "%s in CFString literal"
 msgid "embedded NUL in CFString literal"
@@ -36341,7 +36352,7 @@ msgstr "CFString 字面量里有 %s"
 
 #: config/host-darwin.c:65
 #, fuzzy, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "无法 unmap pch_address_space: %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -36483,372 +36494,372 @@ msgstr "%<#pragma GCC optimize%>不是字符串或数字"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "未知的 #pragma GCC coprocessor %E"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new 不能用于函数类型"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "不使用位段指令"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "操作无效的对象"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "无效 %%h 值"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "%s: 不适用的选项 -- %c\n"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "spec 函数名格式错误"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs对%qs而言无效"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "%qs对%qs而言无效"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "%X%P: 未知特征 %s\n"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "%<...%>作为实参。)"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, gcc-internal-format
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "内建函数实参无效"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "内建函数实参无效"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "内建函数实参无效"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "未知的 TLS 模型%qs"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mtune 参数的值 %qs 未知"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "开关 -mcpu=%s 与 -march=%s 冲突"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "汇编器不支持 -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%qs后断言"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "异常的 URL"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s 只接受 2 个参数"
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "目标系统不支持调试输出"
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "异常的 URL"
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "不支持的真理哈希类型 %d。\n"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -36918,7 +36929,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "-mmemory-latency 开关的值%qs错误"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -37044,18 +37055,18 @@ msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -37498,240 +37509,247 @@ msgstr "目标 CPU 不支持 THUMB 指令"
 msgid "target CPU does not support unaligned accesses"
 msgstr "目标 CPU 不支持未对齐的访问"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+#| msgid "switch -mcpu=%s conflicts with -march=%s switch"
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "开关 -mcpu=%s 与 -march=%s 冲突"
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check 和 -mno-apcs-frame 互不兼容"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic 和 -mapcs-reent 互不兼容"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "不支持 APCS 重入代码。已忽略"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "结构大小边界只能被设定为 %s"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "结构大小边界只能被设定为 %s"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC 与 -msingle-pic-base 不兼容"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= 不与 -fpic 并用时不起作用"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "‘%s’不能被用作 PIC 寄存器"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition 不能在此架构下工作"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable 与 -msdata=%s 互不兼容"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt 需要与 AAPCS 兼容的 ABI 方能正确操作"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi 需要相应 CPU 的支持"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "目标 CPU 不支持交互工作"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS 不支持 -mcaller-super-interworking"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS 不支持 -mcallee-super-interworking"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 而无 ldrh"
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "目标 CPU 不支持 THUMB 指令"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
-#, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
-msgstr ""
+#: config/arm/arm.c:3864
+#, fuzzy, gcc-internal-format
+#| msgid "-mfloat-abi=hard and VFP"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
+msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, fuzzy, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "不是从 AAPCS 派生出的 PCS 变种"
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, fuzzy, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "可变参数函数必须使用基础的 AAPCS 变种"
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS 变动"
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 硬件浮点 VFP ABI"
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE属性只能用于函数而非 %s"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE属性只能用于函数而非 %s"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE属性只能用于函数"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE属性只能用于函数类型"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, fuzzy, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, fuzzy, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "无法计算出栈中参数的真实地址"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "非预期的模块结束"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高寄存器弹栈时没有可用的低寄存器"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid element type for attribute %qs"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -37740,24 +37758,24 @@ msgstr "属性%qs的元素类型无效"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "属性%qE的向量类型无效"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes SPE ABI"
 msgid "unknown target attribute or pragma %qs"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
@@ -37838,17 +37856,17 @@ msgstr "不支持"
 msgid "%<-fPIE%> is not supported"
 msgstr "不支持"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-flto and -fwhopr 互斥"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD不能有默认参数"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "不正确的函数返回值"
@@ -38626,134 +38644,134 @@ msgstr ""
 "\n"
 "错误：“%s”并非有效新闻群组！\n"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最后一个实参必须是一个 2 位立即数"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最后一个实参必须是一个 3 位立即数"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "倒数第二个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "不正确的格式：%s\n"
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "控制生成的浮点舍入模式"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE需要未知的 ISA 选项"
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE需要 ISA 选项 %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最后一个参数必须是一个 32 位立即数"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最后一个实参必须是一个立即数"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "左实参必须是一个切片"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "(提示略过)"
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 #| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -38774,554 +38792,554 @@ msgstr "联合成员函数%qD被声明为虚函数"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "代码模式 %s 在 PIC 模式下不受支持"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 #| msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "%C处 SEQUENCE 属性已经在 TYPE 语句中指定"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "错误的选项于环境变量 MINICOM=“%s”\n"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%q+D的寄存器名无效"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%q+D的寄存器名无效"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%s：未知选项 -%c\n"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs没有指定类名"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, fuzzy, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "%L处参数列表函数未知"
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-Wabi=1%> 不受支持，将使用 =2"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-fsanitize=address 与 -fsanitize=kernel-address 不兼容"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fsanitize=address 与 -fsanitize=kernel-address 不兼容"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify -static with -fsanitize=thread"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "不能同时指定 -static 及 -fsanitize=thread"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel 在此配置下不受支持"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未编译入对 %i 位模式的支持"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您选择的 CPU 不支持 x86-64 指令集"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-march= 的值(%s)不正确"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "%2$sarch=%3$s %4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune= 开关的值 (%s) 错误"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "%2$stune=%3$s%4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之间"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 不在 %d 和 12 之间"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "模块间优化未为 C++ 实现"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已禁用，使用 387 指令"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已禁用，使用 SSE 指令"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry 在 32 位下不能和 -fpic 同时使用"
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry 与 SEH 不兼容"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "未知的选项：%s %s %s"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 字节 cop 指针不允许被用在 VLIW 模式中"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 属性互不兼容"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 属性互不兼容"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 属性互不兼容"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 属性互不兼容"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt function must have no arguments"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "中断函数不能有参数"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -39799,7 +39817,7 @@ msgstr "%qE不能同时有%<mips16%>和%<nomips16%>属性"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE重声明有冲突的属性%qs"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -40884,61 +40902,61 @@ msgstr "%qE属性需要一个整常量作为实参"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mtune 参数的值 %qs 未知"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfpxx%> requires %<-mlra%>"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs没有指定类名"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs对%qs而言无效"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD不能有默认参数"
@@ -41476,254 +41494,255 @@ msgstr "ISO C90 不允许可变数组成员"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma GCC target 在此目标机上不受支持"
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 需要 PowerPC64 架构，正在启用"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 #| msgid "-mcall-aixdesc incompatible with -mabi=elfv2"
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mcall-aixdesc 与 -mabi=elfv2 不兼容"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires a PowerPC64 cpu"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 需要 PowerPC64 CPU"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "-mcmodel incompatible 与其他 toc 选项不兼容"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "不支持的组合：%s"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 在 64 位 Darwin 下不受支持；它与已安装的 C 和 C++ 库不兼容"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec 在此目标机上不受支持"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring 在小端在前的系统上不受支持"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs必须与%qs一起使用"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT作为%qs被引用"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes long double size"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "目标属性或 pragma 改变了 long double 的大小"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "使用 IEEE 扩展精度 long double"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "使用 IBM 扩展精度 long double"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s 不支持 %s"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "%2$sveclibabi=%3$s %4$s向量库 ABI 类型(%1$s)未知"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "目标属性或 pragma 改变了 AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "目标属性或 pragma 改变了 darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "调用篡改寄存器用作全局寄存器变量"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "未知的选项：%s %s %s"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "已弃用。此开关不起作用。"
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支持取样 64 位代码"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您无法需地址的嵌套的函数如果您使用 -mno-pointers-to-nested-functions 选项。"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<long double%>无效"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用布尔类型无效"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<complex%>无效"
 
-#: config/rs6000/rs6000.c:20055
-#, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+#: config/rs6000/rs6000.c:20172
+#, fuzzy, gcc-internal-format
+#| msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用十进制浮点类型无效"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "已弃用在 AltiVec 类型中使用%<long%>；请改用%<int%>"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long long%>无效"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<double%>无效"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%s：无效的目的：%s\n"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s：不允许空权字符串"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "无效的 %s 字组：%s\n"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -41914,7 +41933,7 @@ msgstr "RX FPU  指令不支持 NaN 和无限"
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, fuzzy, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "%<__builtin_frame_address%>的实参无效"
@@ -41988,212 +42007,218 @@ msgstr "已弃用%qE"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "constant argument out of range for %qs"
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "常量实参超过%qs的范围"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<未解决的重载函数类型>"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "错误的内建 fcode"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "内建函数实参无效"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, fuzzy, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部变量大小总和超过架构极限。"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "影格大小的函数 %qs 是 %wd 字节超出用户提供的堆叠限制的 %d 字节。 unconditional 陷阱被已加入。"
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "影格大小的函数 %qs 是 %wd 字节该项是超过半堆叠大小。动态检查会无法是 reliable。没有检查发出用于这个函数。"
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "栈帧大小不是 8 字节的倍数：%wd"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs使用动态栈分配"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "嵌套函数%qs被声明为%<extern%>"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, fuzzy, gcc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "硬件十进制浮点指令在 ESA/390 模式下不可用"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支持"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "栈大小必须大于栈防护值"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "栈大小不能大于 64K"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard 意味着使用 -mstack-size"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE属性只为 SH2A 所支持"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "“%s”的实参应该是一个非负整数"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\"))未知"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "嵌套函数在此目标机上不受支持"
@@ -42543,17 +42568,23 @@ msgstr "对 Ada 而言 -fexcess-precision=standard"
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "insn contains an invalid address !"
+msgid "%s contains too many lines"
+msgstr "指令包含无效地址！"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "subprogram %q+F not marked %<Inline%>"
@@ -42625,8 +42656,8 @@ msgstr "%qs属性只能为数组类型使用"
 msgid "could not read the BRIG file"
 msgstr "无法写入响应文件 %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如预期地被忽略"
@@ -42686,7 +42717,7 @@ msgstr "变量%qD被设定但未被使用"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "数组%q+D类型与隐式初始化不兼容"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "原先在这里定义"
@@ -42919,7 +42950,7 @@ msgstr "%q+D的声明隐藏了先前的一个非变量声明"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD的声明隐藏了一个全局声明"
@@ -42929,7 +42960,7 @@ msgstr "%qD的声明隐藏了一个全局声明"
 msgid "declaration of %qD shadows a previous local"
 msgstr "%qD的声明隐藏了先前的一个局部变量"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "被隐藏的声明在这里"
@@ -42939,216 +42970,216 @@ msgstr "被隐藏的声明在这里"
 msgid "nested extern declaration of %qD"
 msgstr "对%qD的嵌套的外部声明"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "隐式声明函数%qE"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "隐式声明函数%qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qE"
 msgstr "对%q+#D无效的重声明"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "隐式声明与内建函数%qD不兼容"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
 msgstr "对%q+#D无效的重声明"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "隐式声明与函数%qD不兼容"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE未声明(不在函数内)"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE未声明(不在函数内)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE未声明(在此函数内第一次使用)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE未声明(在此函数内第一次使用)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每个未声明的标识符在其出现的函数内只报告一次"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "标号%qE在所有函数外被引用"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "跳至具有可变类型的标识符的作用域中"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "跳转略过了变量初始化"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "标号%qD在此定义"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "跳转至语句表达式中"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "重复的标号定义%qE"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重复的标号%qD"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "传统 C 不为标号提供一个单独的命名空间，标识符%qE冲突"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "switch 跳过了变量初始化"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, gcc-internal-format
 msgid "switch starts here"
 msgstr "开关语句从此开始"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "开关跳转至语句表达式中"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE定义为类型错误的标记"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "只能为类定义应用%qE属性"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "未定义任何实例的无名结构/联合"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "带有存储类的空声明没有重声明标记"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "带有类型限定的空声明没有重声明标记"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "带有类型限定的空声明没有重声明标记"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "空声明中类型名无用"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "文件作用域中出现%<auto%>空声明"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "文件作用域中出现%<register%>空声明"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "空声明中指定存储类无用"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "空声明中类型名无用"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "空声明中类型限定无用"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "空声明中类型限定无用"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attributes in empty declaration"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "空声明"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 不支持在形参数组声明中使用%<static%>或类型限定符"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 不支持%<[*]%>数组声明"
@@ -43156,29 +43187,29 @@ msgstr "ISO C90 不支持%<[*]%>数组声明"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不能用于函数原型以外"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D通常是一个函数"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef%qD被初始化(改用 __typeof__)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "函数%qD像变量一样被初始化"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "形参%qD已初始化"
@@ -43187,273 +43218,273 @@ msgstr "形参%qD已初始化"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "可变大小的对象不能被初始化"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "变量%qD有初始值设定但类型不完全"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %q+D given attribute %qs"
 msgstr "为内联函数%q+D给定了 noinline 属性"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "未初始化的常量%qD在C++中是无效的"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD应当被赋值"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "初始值设定无法决定%q+D的大小"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "在%q+D中缺少数组大小"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "数组%q+D大小为 0 或负"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "%q+D的存储大小不是常量"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "为非静态局部变量%q+D忽略了 asm 限定符"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "不能将带有 volatile 字段的对象放入寄存器"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD is invalid in C++"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "未初始化的常量%qD在C++中是无效的"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C 不允许前向参数声明"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "C++ 不允许在组合字面常量中定义类型"
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "位段%qs的宽度不是一个整数常量"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "位段%qs的宽度不是一个整数常量表达式"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "位段%qs宽度为负"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "位段%qs宽度为 0"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "位段%qs类型无效"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "不能将位段%qD声明为函数类型"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "位段类型%qs是一个 GCC 扩展"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs的宽度超过它自身的类型"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs比其类型的值要窄"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 不允许数组%qE，因为不能计算其大小"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 不允许任何不能确定大小的数组"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 不允许变长数组%qE"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 不允许变长数组"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "文件域中的动态可变的%qE"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "文件域中的动态可变字段"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "在%qE的声明中，类型默认为%<int%>"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "类型名中类型默认为%<int%>"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "重复的%<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "重复的%<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "重复的%<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "重复键值"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "冲突的有名地址空间(%s和%s)"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "%<#pragma omp atomic%>表达式类型无效"
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "函数声明定义为%<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "函数声明定义为%<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "函数声明定义为%<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "函数声明定义为%<auto%>"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "为结构字段%qE指定了存储类"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "为结构字段指定了存储类"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "为形参%qE指定了存储类"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "为无名形参指定了存储类"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "为类型名指定了存储类"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE已初始化，却又被声明为%<extern%>"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE既有%<extern%>又有初始值设定"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "文件作用域声明%qE指定了%<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "文件作用域声明%qE指定了%<register%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "嵌套函数%qE被声明为%<extern%>"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "函数作用域的%qs隐式为 auto，却被声明为%<__thread%>"
@@ -43461,719 +43492,719 @@ msgstr "函数作用域的%qs隐式为 auto，却被声明为%<__thread%>"
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static 或类型限定符出现在非形参数组声明中"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "%qE声明为 void 的数组"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "类型名声明为 void 的数组"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "%qE声明为函数的数组"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "类型名声明为函数的数组"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "对包含可变数组成员的结构的无效使用"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "数组%qE的大小的类型不是整数"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "无名数组的大小的类型不是整数"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "size of array %qE has incomplete type"
 msgstr "数组%qE的大小的类型不是整数"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 #| msgid "size of unnamed array has non-integer type"
 msgid "size of unnamed array has incomplete type"
 msgstr "无名数组的大小的类型不是整数"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C 不允许大小为 0 的数组%qE"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C 不允许大小为 0 的数组"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "数组%qE的大小为负"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "无名数组的大小为负"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "数组%qE太大"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "无名数组太大"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 不允许可变数组成员"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "%2$qD的第 %1$P 个形参的类型%3$qT不完全"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE声明为返回一个函数的函数"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "类型名声明为返回一个数组的函数"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE声明为返回一个数组的函数"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "类型名声明为返回一个数组的函数"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "函数定义有限定的 void 返回类型"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs和%<auto%>限定符同时用于%qE"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs和%<register%>限定符同时用于%qE"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "为 auto 变量%2$qE指定了%1$qs"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "为形参%2$qE指定了%1$qs"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "为无名形参指定了%qs"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "为结构字段指定了%qs"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "位段%qs类型无效"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "不能为%q+D指定对齐"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "为形参%2$qE指定了%1$qs"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "为形参%2$qE指定了%1$qs"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "为无名形参指定了%qs"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "为无名形参指定了%qs"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "不能为%q+D指定对齐"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<Alignas%(_A)>说明符无法缩小对齐的 %qE"
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<Alignas%(_A)>说明符无法缩小对齐的未命名字段"
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "结构或联合成员不能具有可变类型"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "变量或字段%qE声明为 void"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "出现在形参数组声明中的属性被忽略"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "形参%q+D声明为%<inline%>"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "形参%q+D声明为%<inline%>"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "字段%qE声明为一个函数"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "无名字段类型不完全"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "函数%qE存储类无效"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "不能内联%<main%>函数"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qE已初始化，却又被声明为%<extern%>"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 不支持 %<_Noreturn%>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 不支持 %<_Noreturn%>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "先前被声明为%<static%>的变量重声明为%<extern%>"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "非嵌套函数有动态可变类型"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "可变类型对象不能有外部链接"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "函数声明不是一个原型"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "函数声明中出现形参名却未指定类型"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "形参 %u (%q+D) 的类型不完全"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "形参 %u 的类型不完全"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "形参 %u (%q+D)类型为 void"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "第 %u 个参数类型为 void"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%>必须是仅有的形参"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "形参%q+D有一个前向声明"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "枚举类型在此定义"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "结构在此定义"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "联合在此定义"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%>重定义"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%>重定义"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "嵌套的%<union %E%>重定义"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "嵌套的%<struct %E%>重定义"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "没有声明任何东西"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 不支持无名结构/联合"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 不支持无名结构/联合"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "重复的成员%q+D"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "联合包含无名成员"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "联合体没有成员"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "结构不包含任何有名成员"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "结构体没有成员"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "联合和可变数组成员"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "联合和可变数组成员"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "对已定义的数据类型来说值过大"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "联合不能成为透明的"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "嵌套的%<enum %E%>重定义"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>重声明"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "指定的模式对枚举值来说太小"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "枚举值超过了最大整数类型可表示的范围"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "枚举值溢出"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 将枚举值限制在%<int%>范围内"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "内联函数%qD给定了非内联属性"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "返回不完全的类型"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "返回类型默认为%<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "嵌套函数%q+D声明过但从未定义"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%qD先前没有原型"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD先前没有声明"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "使用%qD时先前既没有声明也没有定义"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD的返回类型不是%<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD通常不是一个静态函数"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "原型函数定义中使用了旧式参数声明"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "传统 C 不接受 ISO C 风格的函数定义"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "ISO C90 不支持%<_Static_assert%>"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "旧式的函数定义"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "形参列表中缺少形参名"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD没有声明为一个参数"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "多个名为%qD的形参"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD的类型默认为%<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "形参%qD类型不完全"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "声明的形参%qD不存在"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "实参个数与内建原型不符"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "实参数目与原型不符"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "原型声明"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "提升后的实参%qD与内建原型不符"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "提升后的实参%qD与原型不符"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "实参%qD与内建原型不符"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "实参%qD与原型不符"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "形参%qD被设定但未被使用"
@@ -44181,263 +44212,263 @@ msgstr "形参%qD被设定但未被使用"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "只允许在 C99 模式下使用%<for%>循环初始化声明"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "使用 -std=c99 或 -std=gnu99 来编译您的代码"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 不支持%<[*]%>数组声明"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了静态变量%qD"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了非变量%qD"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "需要指定声明"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "声明指定了两个以上的数据类型"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%>对 GCC 来说太长了"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支持%<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支持复数类型"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支持饱和类型"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重复的%qE"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C 不支持 %<__int%d%> 类型"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支持布尔类型"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int%d%> types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C 不支持 %<__int%d%> 类型"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C 不支持十进制浮点数"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定点类型在此目标机上不受支持"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支持定点类型"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "%qD的 C++ 查询会返回一个字段而非类型"
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE没有出现在声明的开头"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE不能用作函数"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "无效的协寄存器%qE"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 不支持 %qE"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支持 %qE"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%>出现在%<extern%>之前"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%>出现在%<static%>之前"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "声明指定了多个存储类"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>使用时缺少%<_Fract%>或%<_Accum%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支持单独用%<complex%>表示%<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支持复整数"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次数为负"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次数为负"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次数为负"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次数大于或等于类型宽度"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次数大于或等于类型宽度"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "左移次数大于或等于类型宽度"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -44458,7 +44489,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "没有匹配"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "需要行尾"
@@ -44468,7 +44499,7 @@ msgstr "需要行尾"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C 不允许翻译单元为空"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
@@ -44505,7 +44536,7 @@ msgid "unknown type name %qE"
 msgstr "未知的类型名%qE"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定声明"
@@ -44526,7 +44557,7 @@ msgstr "%q+D不能有 section 属性"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "属性在未初始化类型上被忽略"
@@ -44541,7 +44572,7 @@ msgstr "属性在模板实例化上被忽略"
 msgid "unexpected attribute"
 msgstr "非预期的属性"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -44580,7 +44611,7 @@ msgstr "文件作用域中出现%<auto%>空声明"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用于变量或函数声明"
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要%<,%>或%<;%>"
@@ -44639,7 +44670,7 @@ msgstr "静态断言中出现非常量条件"
 msgid "static assertion failed: %E"
 msgstr "静态断言错误：%E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -44686,14 +44717,14 @@ msgstr "模板第 %d 个参数无效"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要标识符"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "枚举表以逗号结尾"
@@ -44778,7 +44809,7 @@ msgstr "需要指定声明或%<...%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "%qE属性需要带有名实参的原型"
@@ -44839,7 +44870,7 @@ msgstr "ISO C90 不允许混合使用声明和代码"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<else%>前需要%<}%>"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%>之前没有%<if%>"
@@ -44854,7 +44885,7 @@ msgstr "标号位于复合语句末尾"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "需要语句"
@@ -44879,17 +44910,17 @@ msgstr "需要标识符或%<*%>"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "只能为类定义应用%qE属性"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建议在空的%<if%>语句体周围加上花括号"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建议在空的%<else%>语句体周围加上花括号"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "建议显式地使用花括号以避免出现有歧义的%<else%>"
@@ -44909,12 +44940,12 @@ msgstr "不允许多个中断属性"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "此指令中寄存器无效"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -44930,8 +44961,8 @@ msgstr "快速枚举在 Objective-C 1.0 里不可用"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "重复的 cv 限定"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -44960,12 +44991,12 @@ msgstr "ISO C 不允许省略 ?: 表达式中的第二项"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -45371,12 +45402,12 @@ msgstr "%C处数组声明需要另外一维"
 msgid "no type or storage class may be specified here,"
 msgstr "为%qs指定了存储类"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, fuzzy, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -45387,55 +45418,55 @@ msgstr "缺少 Code 属性"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected %qE selector name"
 msgstr "需要选择语句"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, fuzzy, gcc-internal-format
 #| msgid "setter name must terminate with %<:%>"
 msgid "setter method names must terminate with %<:%>"
 msgstr "setter 的名字必须以%<:%>结尾"
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%>只能用在复合语句中"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "Objective-C 声明只能出现在全局作用域中"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
@@ -45446,18 +45477,18 @@ msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "需要语句"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%>必须是第一个"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多的%qs子句"
@@ -45478,58 +45509,58 @@ msgstr "需要 %<,%> 或 %<)%>"
 msgid "%qD is not a variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "需要%<catch%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -45551,115 +45582,115 @@ msgstr "%<num_threads%>值必须为正"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "需要整数表达式"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "启用最小/最大值指令"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多 %<static%> 参数"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "非预期的参数"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<concurrent%>"
 msgstr "需要%<new%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<runtime%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<auto%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "无效的调度类型"
@@ -45669,17 +45700,17 @@ msgstr "无效的调度类型"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -45699,22 +45730,22 @@ msgstr "%H折叠变量需要正整常数表达式"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%qs必须与%qs一起使用"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "无效的实型种别 %d，在%C处"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "无效的调度类型"
@@ -45730,84 +45761,84 @@ msgstr "无效的调度类型"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs对%qs而言无效"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD的声明隐藏了一个全局声明"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "文件域中的动态可变字段"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -45823,7 +45854,7 @@ msgstr "%qE未声明"
 msgid "expected function name"
 msgstr "需要函数"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -45834,27 +45865,27 @@ msgstr "%qD不是一个成员模板函数"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<allocator%>"
@@ -45865,89 +45896,89 @@ msgstr "需要%<operator%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable 不再受支持"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "整型表达式%qE不是常量"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -45957,34 +45988,34 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "需要%<(%>或行尾"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "需要迭代声明或初始化"
@@ -45994,74 +46025,74 @@ msgstr "需要迭代声明或初始化"
 msgid "not enough perfectly nested loops"
 msgstr "不够完美的嵌套循环"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "折叠的循环没有完美的嵌套"
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代变量%qD不应当是 firstprivate"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -46076,62 +46107,62 @@ msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "需要选择语句"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s 只接受 2 个参数"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%qs必须与%qs一起使用"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "需要字面字符串"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "需要整数表达式"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, fuzzy, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "内容 %qs 已经指定的在中 %<@synthesize%>"
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -46142,13 +46173,13 @@ msgstr "需要%<catch%>"
 msgid "variant %qD is not a function"
 msgstr "在函数%qs中"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s 和 -msdata=%s 互不兼容"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -46158,32 +46189,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
@@ -46238,43 +46269,43 @@ msgstr "需要函数"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "尚未支持代码模式 %<large%>"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -46289,27 +46320,27 @@ msgstr "使用了变长数组"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE在其首次使用后被声明为%<threadprivate%>"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%>%qE的类型不完全"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而无需 transactional 内存支持已启用"
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之内 %<__transaction_relaxed%>"
@@ -46319,7 +46350,7 @@ msgstr "%<__transaction_cancel%>在之内 %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> 函数调用无法在之内外异动作业或 %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>无法在之内 %<__transaction_atomic%>"
@@ -46335,7 +46366,7 @@ msgstr "括入并行"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "对 void 表达式的使用无效"
@@ -46379,131 +46410,131 @@ msgstr "%qD不能带可变数量的实参"
 msgid "function types not truly compatible in ISO C"
 msgstr "函数类型与 ISO C 不完全兼容"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and vector types"
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "十进制浮点和向量类型不能同时作操作数"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and complex types"
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "十进制浮点和复数类型不能同时作操作数"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t mix operands of decimal float and other float types"
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "十进制浮点与其他浮点类型不能同时作操作数"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, fuzzy, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "指针目标类型在 C++ 中不兼容"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "类型不完全兼容"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "指针目标类型在 C++ 中不兼容"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "由于%<volatile%>，函数返回类型不兼容"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, fuzzy, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "C++ 不允许在组合字面常量中定义类型"
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT没有名为%qE的成员"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT没有名为%qE的成员"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, fuzzy, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "在非结构或联合中请求成员%qE"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "提领%<void *%>指针"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, fuzzy, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "数组下标不是一个整数"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "下标运算的左操作数是函数指针"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C 不允许按下标访问%<register%>数组"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C90 不允许非左值的数组作为下标运算的左操作数"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, gcc-internal-format
 msgid "enum constant defined here"
 msgstr "枚举常量在此定义"
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "被调用的对象%qE不是一个函数"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "被调用的对象%qE不是一个函数"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "被调用的对象%qE不是一个函数"
@@ -46511,1656 +46542,1656 @@ msgstr "被调用的对象%qE不是一个函数"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "函数经由不兼容的类型调用"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "实参 %d 的类型不完全"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作为整数而不是浮点数传递"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作为整数而不是复数传递"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作为复数而不是浮点数传递"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作为浮点数而不是整数传递"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作为复数而不是整数传递"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作为浮点数而不是复数传递"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作为%<float%>而不是%<double%>传递"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "根据原型，实参 %d (%qE)将作为%qT而不是%qT传递"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将以不同的宽度传递"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作用无符号数传递"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "根据原型，实参 %d (%qE) 将作为有符号数传递"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "提供给函数%qE的实参太多"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "提供给函数%qE的实参太多"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "提供给函数%qE的实参太少"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "与字面字符串比较的结构是不可预测的"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "比较指针和整数"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
 msgstr "从%qT转换到%qT并未提领指针"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "在%qT和%qT间比较"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "在减法中使用类型为%<void *%>的指针"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "函数指针不能相减"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在指向不完全类型的指针上执行算术运算"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "在指向不完全类型的指针上执行算术运算"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "%<~%> on a boolean expression"
 msgstr "需要布尔表达式"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C 不支持用%<~%>求共轭复数"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "不能对该类型的参数求绝对值"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "单目 ! 的实参类型无效"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "C++ 中枚举自增操作无效"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "C++ 中枚举自减操作无效"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "increment of a boolean expression"
 msgstr "需要布尔表达式"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "decrement of a boolean expression"
 msgstr "需要布尔表达式"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C 不支持对复数类型进行%<++%>或%<--%>操作"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "该类型不支持自增"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "该类型不支持自减"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自增"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "取一个类型为%<void%>的表达式的地址"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "无法取得位段%qD的地址"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "无法取右值表达式%<this%>的地址"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "要求寄存器变量%qD的地址。"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "嵌套函数中使用了全局寄存器变量%qD"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "要求全局寄存器变量%qD的地址"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "要求寄存器变量%qD的地址。"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "非左值数组出现在条件表达式中"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C 不允许条件表达式仅有一边为空"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "条件表达式中使用了指向不相交地址空间的指针"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "条件表达式指针类型不匹配"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C 不允许在条件表达式中同时使用%<void *%>和函数指针"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "条件表达式指针类型不匹配"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "条件表达式指针类型不匹配"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "条件表达式中指针/整数类型不匹配"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "条件表达式中类型不匹配"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "in call to %qD, declared here"
 msgstr "%qD在此声明"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, fuzzy, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 #, fuzzy
 msgid "cast adds %q#v qualifier to function type"
 msgstr "类型转换为函数类型添加了新的限定"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 #, fuzzy
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "类型转换丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, fuzzy, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "要是安全所有中介指标在中演员阵容从 %qT 到 %qT 必须是 %<const%> 经资格修饰"
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "类型转换指定了数组类型"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "类型转换指定了函数类型"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C 不允许将非标量转换为其自身类型"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C 不允许转换为联合类型"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "类型转换的源类型未出现在联合中"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "将不相交的普通地址空间指针转换为 %s 地址空间指针"
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "将不相交的 %s 地址空间指针转换为普通地址空间指针"
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "将不相交的 %2$s 地址空间指针转换为 %1$s 地址空间指针"
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "类型转换增大了目标类型的对齐需求"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "将一个指针转换为大小不同的整数"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "从类型为%qT的函数调用转换到不匹配的类型%qT"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "将一个整数转换为大小不同的指针"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C 不允许将一个函数指针转换为一个对象指针"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C 不允许将一个对象指针转换为一个函数指针"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "无法从不完全类型%qT转换到%qT"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "C++ 禁止在类型转换中定义类型"
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, fuzzy, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "无效的数组赋值"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "C++ 禁止在赋值时进行枚举转换"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(在%qs的初始化附近)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "用括号中的字符串常量初始化数组"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "built-in %qD declared here"
 msgstr "%qD在此声明"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "C++ 禁止在传递%2$qE的第 %1$d 个参数时进行枚举转换"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in assignment is invalid in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "C++ 禁止在赋值时进行枚举转换"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in initialization is invalid in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "C++ 禁止在初始化时进行枚举转换"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in return is invalid in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "C++ 禁止在返回时进行枚举转换"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %q#T to %q#T"
 msgid "implicit conversion from %qT to %qT"
 msgstr "从%q#T到%q#T的转换"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "传递%2$qE的第 %1$d 个实参时从未限定的函数指针构造了限定的函数指针"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 #, fuzzy
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "将未限定的函数指针赋予限定的函数指针"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "返回时将未限定的函数指针赋给限定的函数指针"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 #, fuzzy
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "返回时将未限定的函数指针赋给限定的函数指针"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 #, fuzzy
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "赋值丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "初始化丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 #, fuzzy
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "返回时丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C 不允许将实参转换为联合"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "传递%2$qE的第 %1$d 个参数时从指针转换为未被包围的地址空间"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "将指针赋值给未被包围的地址空间"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "从指针向未被包围的地址空间初始化"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "返回时将指针赋值给未被包围的地址空间"
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "赋值的左手边可能是 format 属性的备选时"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "传递%2$qE的第 %1$d 个参数时在不兼容的指针类型间转换"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "指向不完全类型%qT的指针不能自增"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "从不兼容的指针类型初始化"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "在无返回值的函数中，%<return%>带返回值"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C 不允许将%2$qE的第 %1$d 个实参在函数指针和%<void *%>间传递"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C 不允许在函数指针和%<void *%>间赋值"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C 不允许在函数指针和%<void *%>间初始化"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C 不允许在函数指针和%<void *%>间返回"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "传递%2$qE的第 %1$d 个参数给指针时，目标与指针符号不一致"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "对指针赋值时目标与指针符号不一致"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "初始化指针时目标与指针符号不一致"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "传递%2$qE的第 %1$d 个参数给指针时，目标与指针符号不一致"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "传递%2$qE的第 %1$d 个参数时在不兼容的指针类型间转换"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "指向不完全类型%qT的指针不能自增"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "从不兼容的指针类型赋值"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "从不兼容的指针类型初始化"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "从不兼容的指针类型初始化"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "成员指针类型%qT与对象类型%qT不兼容"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "在无返回值的函数中，%<return%>带返回值"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "传递%2$qE的第 %1$d 个参数时将整数赋给指针，未作类型转换"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "赋值时将整数赋给指针，未作类型转换"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "初始化时将整数赋给指针，未作类型转换"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "传递%2$qE的第 %1$d 个参数时将整数赋给指针，未作类型转换"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "传递%2$qE的第 %1$d 个参数时将指针赋给整数，未作类型转换"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "赋值时将指针赋给整数，未作类型转换"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "初始化将指针赋给整数，未作类型转换"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "传递%2$qE的第 %1$d 个参数时将指针赋给整数，未作类型转换"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "将%2$qT赋值给%1$qT时类型不兼容"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "用%2$qT初始化%1$qT时类型不兼容"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "将%qT返回为%qT时类型不兼容"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "传统 C 不接受自动的聚合初始化"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "对可变数组成员的初始化"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "用字符串常量初始化的数组类型不合适"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "对非左值数组的使用无效"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "初始值设定元素不是常量"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "用非常量的数组表达式初始化数组"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "初始值设定中的元素在载入时无法被计算出"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "无效的初始值设定"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量类型不能被初始化"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "初始值设定项末尾有多余的花括号组"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "标量初始化带花括号"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在嵌套的上下文中初始化可变数组成员"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "初始值设定周围缺少花括号"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "成员%qD缺少初始值设定"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "空的标量初始值设定项"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "标量初始值设定中有多余元素"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "在非数组初始值设定项中出现数组索引"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "字段名不在记录或联合初始值设定中"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "初始值设定中数组索引不是整型"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "初始值设定中数组索引不是整型常量表达式"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "初始值设定中数组索引不是常数"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "初始化时数组索引越界"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "初始值设定项中索引范围为空"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "初始值设定中数据索引范围超出数组边界"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "带副作用的字段初始值设定被覆盖"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "已初始化的字段被覆盖"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "C++ 禁止在初始化时进行枚举转换"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "字符数组初始值设定项中有多余元素"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "结构初始值设定项中有多余元素"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "对可变数组成员非静态地初始化"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "联合初始值设定项中有多余元素"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "传统 C 不接受对联合的初始化"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "数组初始值设定项中有多余的元素"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "向量初始值设定项中有多余元素"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "标量初始值设定项中有多余元素"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允许%<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被声明为%<noreturn%>的函数却有%<return%>语句"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "在有返回值的的函数中，%<return%>不带返回值"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "在无返回值的函数中，%<return%>带返回值"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C 不允许在无返回值的函数中%<return%>带返回值"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 msgid "function returns address of label"
 msgstr "函数返回局部变量的地址"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch 语句中的值不是一个整数"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "在 ISO C 中，%<long%>开关表达式不被转换为%<int%>"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case 标号不是一个整数常量表达式"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>标号未出现在 switch 语句内"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 语句不在循环或开关语句内"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "OpenMP 结构块出口无效"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP for 循环中使用了 break 语句"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 语句出现在循环以外"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "语句不起作用"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "表达式语句类型不完全"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "对不同枚举类型之间的比较给出警告"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "形参数量不同"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到类%qE的接口"
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "使用 == 或 != 比较浮点数是不安全的"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "比较将一律评估作为 %<false%> 用于地址的 %qD 将永不是空值"
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "比较将一律评估作为 %<true%> 用于地址的 %qD 将永不是空值"
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "比较指向不相交的地址空间的指针"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C 不允许在%<void *%>和函数指针间比较"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "比较不相关的指针时缺少类型转换"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "比较指针和整数"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "在完全和不完全指针间比较"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C 不允许函数指针间比较大小"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "指针与整数 0 比较大小"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指针与整数 0 比较大小"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "需要标量时使用了不能被转换为指针的数组"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "需要标量时使用了结构类型"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "需要标量时使用了联合类型"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, fuzzy, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "需要标量时使用了联合类型"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD不是一个成员模板函数"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, fuzzy, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "for 循环増量表达式不起作用"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "for 循环増量表达式不起作用"
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "在过程入口处将数组段复制到一个连续的块中"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE不是一个类"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "抛出 NULL，它的类型是整数而不是指针"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "%<#pragma omp atomic%>表达式类型无效"
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "形参%qD类型不完全"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "位段%qD非整型"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "end expression refers to outer iterator %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "step expression refers to outer iterator %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected pointer in %qs clause"
 msgstr "需要指针"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "尚未支持代码模式 %<large%>"
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "尚未支持代码模式 %<large%>"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, fuzzy, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE的类型对%<reduction(%s)%>无效"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, fuzzy, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE必须是%<threadprivate%>方可%<copyin%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, fuzzy, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "在 %L 处的推迟数组“%1$s”在初始化表达式中不被允许"
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 #| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "源不是一个指针"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "-frepo 必须与 -c 一起使用"
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "太多的%qs子句"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, fuzzy, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "给%<va_arg%>的第一个参数的类型不是%<va_list%>"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ 在%<va_arg%>中需要提升后的类型而不是枚举"
@@ -48392,7 +48423,7 @@ msgstr "以从%qT转换为%qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -48513,708 +48544,714 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "调用重载的%<%D(%A)%>有歧义"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "没有对象不能调用成员函数指针 %E，考虑使用 .* 或 ->*"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "对%<(%T) (%A)%>的调用没有匹配"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "对%<(%T) (%A)%>的调用有歧义"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "调用重载的%<%D(%A)%>有歧义"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "没有匹配"
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "将%qT赋值给%qT时类型不兼容"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "需要%<operator%>"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E::%E%>既不是类也不是命名空间"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "错误的运算符"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E::%E%>不是一个类型"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "重复的%qs"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "在协议中找到%<-%E%>而非%<+%E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C 不允许省略 ?: 表达式中的第二项"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, fuzzy, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "找不到类%qE的接口"
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 #, fuzzy
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "从%qT到%qT的转换有歧义"
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "条件运算符的第二个操作数类型为%<void%>，但第三个操作数既不是异常表达式，也不拥有%<void%>类型"
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "条件运算符的第三个操作数类型为%<void%>，但第二个操作数既不是异常表达式，也不拥有%<void%>类型"
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "?: 的操作数类型不一致，分别为%qT和%qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "条件表达式中枚举不匹配：%qT对%qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%>没有出现在后缀%qs中，尝试使用前缀运算符"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "没有为后缀%2$qs声明%<%1$D(int)%>"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "%qD的返回类型不是%<int%>"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在%q#T和%q#T间比较"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "非预定位的释放函数%q+D"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "非预定位的释放函数%q+D"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "%qD没有相应的释放函数"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "没有合适的%<operator %s%>给%qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "在此声明"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "在此声明"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D无法访问"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "将 NULL 作为非指针实参 %P 传递给%qD"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "  declared here"
 msgstr "在此声明"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "将 NULL 转换到非指针类型%qT"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化%2$qD的实参 %1$P"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "显式转换运算符只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT的初始值设定周围花括号太多"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "从初始化列表转换为%qT将使用显式构造函数%qD"
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "将类型为%2$qT的右值转换为%1$qT的 volatile 引用"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+#| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
+
+#: cp/call.c:7911
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "将类型为%2$qT的右值转换为%1$qT的 volatile 引用"
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "将%qT作为%q#D的%<this%>实参时丢弃了类型限定"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "无法将位段%qE绑定到%qT"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能将紧实的字段%qE绑定到%qT"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "无法将右值%qE绑定到%qT"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "不能通过%<...%>传递有不能平凡复制的类型%q#T"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "递归计算%q#D的默认参数"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD的第 %1$d 个形参的默认实参尚未被解析到"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "在调用%qD时"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT是%qT的一个不可访问的基类"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "(在%qs的初始化附近)"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "在此声明"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "不能将%qT转换为%qT"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "不能直接调用构造函数%<%T::%D%>"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "对于函数类型的类型转换，移除冗余的%<::%D%>"
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "对重载的%<%s(%A)%>的调用有歧义"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "没有对象无法调用成员函数%qD"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "传递%qT时选择%qT而不是%qT"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "选择%qD而不是%qD"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "因为前者的实参类型转换序列更好"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "重载解决时默认参数不匹配"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr "备选 1: %q+#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr "备选 2: %q+#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 认为有歧义，尽管第一个备选的最差类型转换要好于第二个备选的最差类型转换"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暂时的约束到 %qD 只有持续直到建构子离开"
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -49240,1177 +49277,1177 @@ msgstr "无法从基类%qT转换到派生类%qT，通过虚基类%qT"
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "无法从基类%qT转换到派生类%qT，通过虚基类%qT"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "无法从基类%qT转换到派生类%qT，通过虚基类%qT"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "与先前此处的声明冲突"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "version inherited from %qT declared here"
 msgstr "%qD在此声明"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D无法被重载"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "先前的声明%q+D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "方法%q+D的权限设定冲突，已忽略"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "字段%qE的权限设定冲突，已忽略"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr " 因为局部方法%q+#D与之重名"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr " 因为局部成员%q+#D与之重名"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "在此声明"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, fuzzy, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "无法从基类%qT转换到派生类%qT，通过虚基类%qT"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "类%qT中所有成员函数都是私有的"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T仅定义了一个私有析构函数且没有友元"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T仅定义了一个私有构造函数且没有友元"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD的最终重载在%qT中不唯一"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "函数%q+D的定义被标记为 dllimport"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+D定义后未使用"
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D为"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "%q+D所隐藏"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "当继承来的方法未被实现时给出警告"
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "位段%q+#D有非整数的类型"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "位段%q+D的宽度不是一个整数常量"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "位段%q+D宽度为负"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "位段%q+D宽度为 0"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D的宽度超过了它的类型"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D太小而不能存放%q#T的所有可能值"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "有构造函数的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "有析构函数的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D不能是静态的，因为它是联合的成员"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "字段%q+D无效地声明为函数类型"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "为非紧实的非简单旧数据字段%q+#D忽略 packed 属性"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "初始化了联合%qT中的多个字段"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "字段%q+#D与类重名"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T有指针数据成员"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "但没有重载%<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "或者%<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "但没有重载%<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "%qD的对齐"
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "%qD的对齐"
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "为非虚方法%q+D指定了初始值设定项"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, fuzzy, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "方法强制变更两者 %<transaction_pure%> 和 %qE 方法"
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "为不存在的方法%qE创建选择子"
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "在%q#T和%q#T间比较"
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基类%q#T有一个非虚析构函数"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, fuzzy, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T 不是汇总，没有 trivial 缺省构造函数，而没有任何 constexpr 建构子该并非复制或移动建构子"
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "%q#T有虚函数和可访问的非虚拟析构函数"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "类中有非静态引用%q+#D，却没有提供构造函数"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "类中有非静态常量成员%q+#D却没有构造函数"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，直接基类%qT在%qT中无法访问"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，虚基类%qT在%qT中无法访问"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D的偏移量与 ABI 不兼容，并且在 GCC 的未来版本中可能会有变化"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "数组%qE太大"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "对非左值数组的使用无效"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "对包含可变数组成员的结构的无效使用"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "可变数组是结构中的唯一成员"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T重定义"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "可变数组是结构中的唯一成员"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T重定义"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T有虚函数和可访问的非虚拟析构函数"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "类型%qT大小未知"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "类型透明类别 %qT 有基础类别"
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "类型%qE有虚成员函数"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "试图完成结构，但为先前的解析错误所中断"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "语言字符串%<\"%E\"%>不可识别"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "无法解析重载函数%qD，基于向类型%qT的转换"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "没有可将函数%qD转换到类型%q#T的匹配项"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "将重载函数%qD转换为类型%q#T有歧义"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成员指针%qD"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成员指针只能用%<&%E%>构成)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "类型信息不充分"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
 msgstr "在这里又被声明为%q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, fuzzy, gcc-internal-format
 #| msgid "the type %qT of constexpr variable %qD is not literal"
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "广义常变量%2$qD的类型%1$qT不是字面常量"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, fuzzy, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "广义常变量%2$qD的类型%1$qT不是字面常量"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type %qT"
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "参数不能具有可变类型%qT"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "广义常表达式构造函数体不为空"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "函数%q+#D的抽象返回类型无效"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "函数%q+#D的抽象返回类型无效"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T不是一个类"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr constructor does not have empty body"
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr "广义常表达式构造函数体不为空"
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "成员%qD在%<constexpr%>构造函数里未初始化"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, fuzzy, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr "返回语句转换无效"
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD不是一个广义常函数"
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "调用这些函数时给出警告"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E不是一个常量表达式"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "内部函数"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 #| msgid "originally defined here"
 msgid "originally declared %<const%> here"
 msgstr "原先在这里定义"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a base type for type %qT"
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "类型%qT不是类型%qT的基类"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 #| msgid "variable %D of type %<io%> must be uninitialized"
 msgid "virtual table pointer is used uninitialized"
 msgstr "类型为%<io%>的变量 %D 不能被初始化"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "%qT是%qT的有歧义的基类"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, fuzzy, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr "-client_name 不能和 -dynamiclib 一起使用"
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "allocation performed here"
 msgstr "原始定义在此"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, fuzzy, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr "-client_name 不能和 -dynamiclib 一起使用"
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, fuzzy, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr "试图分配已经分配的数组‘%s’"
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a previous local"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "%qD的声明隐藏了先前的一个局部变量"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "调用存在循环依赖"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "%q+E不是一个常量表达式"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提领%<void *%>指针"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "初始值设定中数组索引不是整型常量表达式"
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, fuzzy, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "提领%<void *%>指针"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "在此声明"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD用在其自身的初始值设定中"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D不是 const"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D是 volatile"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD在其类外被声明为%<constexpr%>"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "%s：不允许空权字符串"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "需要模板 ID"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "function concept must be called"
 msgstr "内建函数%qD只需要一个实参"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "KIND 参数 %s 在%L处必须是初始化表达式"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "从具有类型%qT的右值表达式到类型%qT中的转换无效"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "赋值时将整数赋给指针，未作类型转换"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 对象 %qE 与线程本地或自动贮藏体并非常数运算式"
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "虚函数不能是友元"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%L处被零除"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "%L处非常量初始化表达式"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "%2$L处 %1$s 种别无效"
@@ -50420,55 +50457,55 @@ msgstr "%2$L处 %1$s 种别无效"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD的地址总是等价为%<true%>"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD不是一个类型"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT不是一个类"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE不是一个类"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "括入并行"
@@ -50517,7 +50554,7 @@ msgstr "将类型为%2$qT的右值转换为非常量引用类型%1$q#T"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "从%qT转换到%qT并未提领指针"
@@ -50918,7 +50955,7 @@ msgstr "从先前的声明%q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "先前的声明%q+D"
@@ -51055,8 +51092,8 @@ msgstr "先前对于%q+#D的非函数声明"
 msgid "%q#D previously defined here"
 msgstr "%q+#D已在此定义过"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q+#D已在此定义过"
@@ -51091,58 +51128,58 @@ msgstr "为%2$q#D的第 %1$d 个形参指定了默认实参"
 msgid "previous specification in %q#D here"
 msgstr "%q+D的上一个定义在此"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with builtin"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD conflicts with import"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "import declared %q#D here"
 msgstr "在此声明"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting declaration %qD"
 msgstr "相互冲突的声明%q#D"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration %q#D here"
 msgstr "%q+D的上一个声明在此"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "%q+D的上一个定义在此"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "%q+D的上一个声明在此"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "同一作用域中%qD冗余的重声明"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %qD is not first declaration"
@@ -51156,49 +51193,49 @@ msgstr "删除了%qD的定义"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "在初次使用后显式特例化%qD"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D的数据区域与先前的声明冲突"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "%q#D 重定义"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD与已用的函数冲突"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D未在类中声明"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D重声明内联并有%<gnu_inline%>属性"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D重声明为内联而没有%<gnu_inline%>属性"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %q+D redeclared"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -51206,2406 +51243,2423 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "友元%q#D的重声明不能有默认模板参数"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%q#D的线程局部声明出现在其非线程局部声明之后"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%q#D的非线程局部声明出现在其线程局部声明之后"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "%q#D重声明"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "同一作用域中%qD冗余的重声明"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "上一个声明"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "从这里"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "退出了 OpenMP 结构块"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "跳过了%q+#D的初始化"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "进入了有不平凡析构函数的%q+#D的作用域"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "进入了 try 块"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "进入了 catch 块"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "进入了 OpenMP 结构块"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "需要语句"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "跳过了%q+#D的初始化"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "进入了有不平凡析构函数的%q+#D的作用域"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD使用时未带模板参数"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD不是一个函数模板"
+
+#: cp/decl.c:4072
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T不是一个类"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "在%2$qT中查询%1$qT有歧义"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类模板"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类型"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "不支持 -falign-labels=%d"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有构造函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有构构函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T的属性必须跟在%qs关键字后面"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一个声明指定了多个类型"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "对 C++ 内建类型%qT的重声明"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 声明中缺少类型名"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允许匿名结构"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%>只能在类中指定"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能为构造函数指定%<explicit%>"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "此声明中的%<typedef%>被忽略"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%>不能被用作类型声明"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略在定义之外为类类型%qT应用的属性"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略在关联定义之外为依赖类类型%qT应用的属性"
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef%qD被初始化(改用 decltype)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D声明有%<extern%>并被初始化"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允许将%<%T::%D%>定义为%<%T::%D%>"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允许成员%qD的初始化"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "变量%q#D有初始值设定，但是类型不完全"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "数组%q#D的元素类型不完全"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名字被用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值设定不受支持"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD的存储大小未知"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD的存储大小不是常量"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr " 变通的作法是删除初始值设定"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "未初始化的常量%qD"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T没有用户提供的默认构造函数"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建构子未被 user-provided 因为它是明确的缺席在中类别本体"
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建构子不初始化 %q+#D"
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "无效类型%qT被用作类型为%qT的向量的初始值设定"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT没有名为%qD的非静态数据成员"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "初始值设定无法决定%q+D的大小"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示项 %qE 外侧汇总初始设置式"
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT的初始值设定项太多"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT的初始值设定周围缺少花括号"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "数组%q#T的元素类型不完全"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "变长复合字面量"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q+D类型不完全"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "标量对象%qD在初始值设定中需要一个元素"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在 C++98 中%qD必须由构造函数而不是%<{...}%>初始化"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "数组%qD被有括号的字面字符串%qE所初始化"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "构造函数中对静态成员的初始化无效"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一个类外的初始化)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "对成员的使用无效(您是否遗忘了%<&%>？)"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可变大小的对象不能被初始化"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隐藏了早先的类型声明%q#D"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE属性只能为变量或函数所使用"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函数%q#D像变量一样被初始化"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "不能在%q+D使用过时的绑定，因为它有析构函数"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT是%qT不可访问的基类"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 不允许变长数组%qE"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "为结构字段指定了%qs"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "无法分解地址"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "源有不完全的类类型"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "不能对静态数据成员%qD取%<offsetof%>"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解构式"
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的析构函数不能用作成员"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的构造函数不能用作成员"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD声明为%<virtual%>变量"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD声明为%<virtual%>参数"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD声明为%<inline%>参数"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD声明为%<virtual%>类型"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD声明为%<inline%>类型"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD声明为%<virtual%>字段"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD声明为%<inline%>字段"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D声明为友元"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D声明时带有异常规范"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD的定义不在包含%qT的命名空间中"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "静态成员函数%q#D的声明带有类型限定符"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD没有声明为一个参数"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法%qD返回非 Java 类型%qT"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "-fmit-class-file 的别名"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "不能内联%<main%>函数"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD不是一个模板函数"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在友元声明中定义显式特例化%qD"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本模板的声明中对模板标识符%qD的使用无效"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "友元模板特例化%qD中不允许出现默认参数"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%>不允许用于友元模板特例化%qD的声明"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能将%<::main%>声明为 inline"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "不能将%<::main%>声明为 static"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能将%<::main%>声明为 static"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 带有无效参数列表"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, fuzzy, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "浮点数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "实字运算符后缀无法前继的由 %<_%>被保留的用于未来标准化"
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%>必须返回%<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隐式声明的%qD的定义"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成员函数%q#D未在类%qT中声明"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+#| msgid "specialization of %qD must appear at namespace scope"
+msgid "concept must be defined at namespace scope"
+msgstr "%qD的特例化必须出现在命名空间内"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "可变大小的对象不能被初始化"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允许在类内初始化非常量静态成员%qD"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允许初始化成员常量%qD，因为它有非整数的类型%qT"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "数组%qD的大小具有非整数类型%qT"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允许大小为 0 的数组"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ 不允许变长数组%qD"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ 不允许变长数组"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "使用了变长数组%qD"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "使用了变长数组"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "数组维数溢出"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "生成%qT的数组"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD声明为 void 的数组"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "创建 void 数组"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD声明为函数的数组"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "创建函数的数组"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD声明为引用的数组"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "创建引用的数组"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD声明为函数成员的数组"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "创建函数成员的组织"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "声明多维数组必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "为构造函数指定返回值无效"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "为%<operator %T%>指定了返回值"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%qs的声明中有相互冲突的限定符"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "无名变量或字段声明为 void"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "变量或字段声明为 void"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "对限定名%<::%D%>的使用无效"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "对限定名%<%T::%D%>的使用无效"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "对限定名%<%D::%D%>的使用无效"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "%qD未声明为成员"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少声明标识符：使用了保留字%qD"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函数定义未声明形参"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "声明的形参%qD不存在"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%>不能被用于 typedef 声明"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs的声明指定了两个以上的数据类型"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "%qs的声明中有相互冲突的限定符"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ 不支持单独以 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允许声明无类型的%qs"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 对 %2$qs 不支持 %<__int%1$d%>"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "为%qs同时给定了%<signed%>和%<unsigned%>"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "为%qs同时给定了%<long%>和%<short%>"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "对%qs而言无效的复数"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "为模板参数%qs指定了存储类"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "为形参%qs指定了存储类"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "无效的函数声明"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "嵌套函数%qs被声明为%<extern%>"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在文件层将%qs声明为%<auto%>"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函数作用域的%qs隐式为 auto，却被声明为%<__thread%>"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "为友元函数声明指定了无效的存储类"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "忽略%qs属性"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "需要左圆括号"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs函数使用了%<auto%>类型限定却没有迟返回类型"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "错误地使用了%<auto%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs函数使用了迟返回类型却未用%<auto%>类型限定声明"
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs声明为返回一个函数的函数"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs声明为返回一个数组的函数"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "构造函数不能被声明为虚函数"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "友元声明不在类定义内"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "局部类定义中不能定义友元函数%qs"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "析构函数不能有参数"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "无法声明指向%q#T成员的指针"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "无法声明对%q#T的引用，因为它不是 typedef 或者模板类型实参"
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "模板标识符%qD用作声明"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成员函数隐式地成为所属类的友元"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多余的限定%<%T::%>在成员%qs上"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "无法定义成员函数%<%T::%s%>，在%<%T%>中"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非形参%qs不能是一个参数包"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "数据成员不能具有可变类型%qT"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "参数不能具有可变类型%qT"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有构造函数才能被声明为%<explicit%>"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非对象成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "静态%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允许嵌类的类型%qD与其所属的类重名"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "友元函数声明中出现了%<inline%>"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "模板参数不能是友元"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "友元声明需要 class，即%<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "友元声明需要 class，即%<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "试图让%qT成为全局域的友元"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成员函数类型上的限定符无效"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象声明%qT被用作声明"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在参数声明中使用%<::%>"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD不是一个函数模板"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用模板名%qE时不带实参表无效"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 不允许可变数组成员"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "错误地使用了%<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%qD模板声明无效"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD不能声明为虚函数，因为它总是静态的"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在析构函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "在构造函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "不能打开 %s"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "模板声明%q#D"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名字%qT类型不完全"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %qs"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函数%qs的存储类%<auto%>无效"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函数%qs的存储类%<register%>无效"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<static%>无效"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虚函数%qs不是类成员"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能将成员函数%qD声明为有静态链接"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一个函数中声明一个静态函数"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "与声明不同，定义静态数据成员时不能使用%<static%>"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "静态成员%qD声明为%<register%>"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能显式地将成员%q#D声明为有外部链接"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D声明有缺少初始值设定"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs已初始化，却又被声明为%<extern%>"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs既有%<extern%>又有初始值设定"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C 不允许前向参数声明"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的指针"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的引用"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "无效的构造函数：您要的可能是%<%T (const %T&)%>"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD不能被声明为静态的"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD必须是一个非静态成员函数或非成员函数"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD的实参必须有类或枚举类型"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ 不允许重载 ?: 运算符"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD必须带 0 或 1 个实参"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD必须带 1 或 2 个实参"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "后缀%qD必须使用%<int%>作为它的参数"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "后缀%qD必须使用%<int%>作为它的第二个参数"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD带且仅带 1 个实参"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD不能有默认参数"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "向 void 的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "向具有相同类型的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "向相同类型的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "向指向基类的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "向基类的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "前缀%qD应当返回%qT"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "后缀%qD应当返回%qT"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD应当返回值而非引用"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名%qD，在%qs后"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT作为%qs被引用"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT作为枚举被引用"
@@ -53617,108 +53671,108 @@ msgstr "%qT作为枚举被引用"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%>需要模板参数"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD与其声明所在的类重名"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT不是一个模板"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用枚举%q#D前没有给出声明"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT重声明为非模板"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "不能将%qD声明为位段类型"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "派生联合%qT无效"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "此函数中的%qD在使用前未初始化"
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基类型%qT不是结构或类"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "递归的类型%qT未定义"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重复的基类型%qT无效"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "范围/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "先前的定义在这里"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "条件表达式中类型不匹配"
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下层的输入 enum %q#T"
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "cannot define %qD in different module"
 msgstr "在不同命名空间内对%qD的特例化"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -53728,79 +53782,79 @@ msgstr "%<%2$T%>的内在类型%<%1$T%>必须是整型"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "没有一个整数类型可以表示%qT的所有枚举值"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD处枚举值溢出"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T多次定义"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>应当返回一个对%<*this%>的引用"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由于%<volatile%>，函数返回类型不兼容"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD已在类%qT中定义过"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD的类型默认为%<int%>"
@@ -53840,7 +53894,7 @@ msgstr "不能 delete 一个函数。只有指向对象的指针才是%<delete%>
 msgid "deleting %qT is undefined"
 msgstr "删除%qT未定义"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D声明为模板"
@@ -53850,7 +53904,7 @@ msgstr "%q#D声明为模板"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "提供的模板参数列表与 %qD 的模板不符"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "析构函数%qD被声明为一个成员模板"
@@ -54194,24 +54248,24 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "将使用了%<...%>的 Lambda 转换为函数指针"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用了被删除的函数%qD"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -54318,7 +54372,7 @@ msgstr "对%<%T::%D%>的引用有歧义"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD不是%qT的成员"
@@ -54329,7 +54383,7 @@ msgstr "%qD不是%qT的成员"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD不是%qD的成员"
@@ -54520,418 +54574,418 @@ msgstr "生成指向引用类型%qT的引用"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "成员函数%q+#D的抽象返回类型无效"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD应该在成员初始化列表中被初始化"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "形参%qD已初始化"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "成员函数%q+#D的抽象返回类型无效"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D将在"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D将在"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "基类%qT将在"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "%q+#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "基类%qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "在此处初始化后被初始化"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "为%qD给定了多个初始值设定"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "为基类%qT给定了多个初始值设定"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "初始化%qT的多个成员"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "基类%q#T应该在复制构造函数中显式地初始化"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "类%qT没有名为%qD的字段"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D是一个静态数据成员；它只能在定义时被初始化"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "对没有基类的%qT的无名初始化"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "对使用了多继承的%qT的无名初始化"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD既是一个直接基类又是一个间接虚基类"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "类型%qT不是%qT的直接基类"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "数组必须为一个由花括号包围的初始值设定所初始化"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT不是一个类"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "不完全类型%qT没有成员%qD"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "指向位段%qD指针无效"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "对非静态数据成员%qD的无效使用"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "未初始化的引用成员%qD"
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "未初始化的引用成员%qD"
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "at offset %wi from %qD declared here"
 msgstr "%qD在此声明"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "%qD在此声明"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "表达式中整复数溢出"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "文件域中的动态可变字段"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "对 new 而言类型%<void%>无效"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "找不到合适的%qD，在类%qT中"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "对成员%qD的请求有歧义"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "类%qT没有名为%qD的字段"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new 不能用于引用类型"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new 不能用于函数类型"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "检测到调用 delete 运算符时可能出现的问题："
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值设定在完成之前结束"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 时数组大小未知"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "检测到调用 delete 运算符时可能出现的问题："
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, fuzzy, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "删除对象的抽象类别类型 %qT 该项有 non-virtual 解构式将造成未定义的行为"
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, fuzzy, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "删除对象的 polymorphic 类别类型 %qT 该项有 non-virtual 解构式也许造成未定义的行为"
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, fuzzy, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "复合字面量有可变的大小"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "无法通过引用捕获%qE"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "向 void 的类型转换不会访问具有不完全类型%qT的对象"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "lambda 函数中无法捕获%<this%>"
@@ -54990,63 +55044,63 @@ msgstr "%qD的实参不依赖模板参数，所以%qD的声明必须可用"
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(如果您使用%<-fpermissive%>，G++ 会接受您的代码，但是允许使用未定义的名称是已弃用的风格)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, fuzzy, gcc-internal-format
 #| msgid "mangling typeof, use decltype instead"
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr "修饰 typeof，请改用 decltype"
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, fuzzy, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr "修饰未知的定点类型"
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "修饰未知的定点类型"
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "修饰 %C"
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "省略的%<?:%>中操作数不能被修饰"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
@@ -55235,324 +55289,324 @@ msgstr "%q+#D 是隐含地删除的因为缺省定义会被不当形式的："
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "does not match expected signature %qD"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "不匹配%qD预期的签名"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 #| msgid "does not match expected signature %qD"
 msgid "expected signature: %qD"
 msgstr "不匹配%qD预期的签名"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, fuzzy, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "明确的缺席函数 %q+D 无法声明的作为 constexpr 因为蕴含声明不是 constexpr："
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "%qD不能被默认化"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD不能被默认化"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "默认化函数%q+D有默认参数"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D隐藏了%q#T的构造函数"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "相互冲突的声明%q#D"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "因为异常规范不一致"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D的声明隐藏了一个形参"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "本地类中的友元声明%qD没有先前声明"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%>指定了析构函数"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "在类作用域使用非成员的 using 声明"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, fuzzy, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE不是一个类、命名空间或枚举"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "在类作用域使用非成员的 using 声明"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "类型%qT不是%qT的直接基类"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qE未声明"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "不允许在 using 声明中使用命名空间%qD"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%>在%qT内指定了构造函数"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD的声明不在包含%qD的命名空间中"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD的声明中有显式的限定"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD应当先在%qD内声明"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qE未声明"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D声明为友元"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD属性需要一个 NTBS 作为实参"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD属性无意义，因为匿名命名空间的成员拥有局部符号"
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定%qD属性被忽略"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空间搜索的用于 %qE"
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建议的替代："
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "静态成员函数中不能使用%<this%>"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "结构在此定义"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "开关%qs不再被支持"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "‘%s’(位于 %L)有歧义"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "这里不允许命名空间别名%qD，假定为%qD"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法属性必须被指定的于结束只有"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "标号%qD在此定义"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 #| msgid "%qD conflicts with used function"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD与已用的函数冲突"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "先前的定义在这里"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX 进入 pop_everything ()\n"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -55578,7 +55632,7 @@ msgstr "标识符%qE与 C++ 关键字冲突"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
@@ -55603,7 +55657,7 @@ msgstr "%<::%E%>尚未声明"
 msgid "request for member %qE in non-class type %qT"
 msgstr "在非类类型%2$qT中请求成员%1$qE"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>尚未声明"
@@ -55684,7 +55738,7 @@ msgstr "无效的模板 ID"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮点字面量不能出现在常量表达式中"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "常量表达式中不能出现目标不是整型或枚举型的类型转换"
@@ -55822,7 +55876,7 @@ msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
@@ -55949,7 +56003,7 @@ msgstr "无法找到字串实字运算符 %qD 与 %qT，%qT 参数"
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "需要声明"
@@ -56002,7 +56056,7 @@ msgstr "语句表达式只能用于函数或模板实参列表内"
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "需要元表达式"
@@ -56032,7 +56086,7 @@ msgstr "%<~%>前的作用域%qT不是一个类名"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "形参声明为%<auto%>"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
@@ -56053,12 +56107,12 @@ msgstr "%<~%T%>声明为%qT的一个成员"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名%qD用于析构函数声明"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD不是一个模板"
@@ -56093,7 +56147,7 @@ msgstr "%C 期待访问指定符"
 msgid "expected nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "类型不能定义在类型转换中"
@@ -56108,7 +56162,7 @@ msgstr "类型不能定义在%<typeid%>表达式中"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -56123,1156 +56177,1161 @@ msgstr "ISO C++ 不允许复合字面量"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "错误地使用了%qD"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%>不是%qT的成员"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "非标准类型"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ 不允许对非类型使用%<alignof%>"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr "__builtin_saveregs 不为此目标所支持"
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "括起的类型标识符后面不能出现数组边界"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "需要表达式类型"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "类型不能定义在 new-type-id 中"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "使用旧式的类型转换"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%<>>%>运算符在 C++0x 中将被认为是两个右尖括号"
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "建议%<>>%>表达式周围加上括号"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ 不允许省略 ?: 的中间操作数"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr "为 lambda 形参指定了默认参数"
+
+#: cp/parser.c:10819
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, fuzzy, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "捕获列表应在此结束"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "明确的 by-copy 截取的 %<this%> 冗余与 by-copy 截取缺省"
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "已经在 Lambda 表达式中捕获了%<this%>"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 #| msgid "cannot capture %qE by reference"
 msgid "%<this%> cannot be captured by reference"
 msgstr "无法通过引用捕获%qE"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, fuzzy, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "%qD不是一个变量"
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "截取的变量 %qD 与 non-automatic 贮藏体持续时间"
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "太多的%qs子句"
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "明确的 by-copy 截取的 %qD 冗余与 by-copy 截取缺省"
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, fuzzy, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "明确的 by-reference 截取的 %qD 冗余与 by-reference 截取缺省"
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重复的%<volatile%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "需要标号语句"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case 标号%qE未出现在 switch 语句中"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%qE之前需要%<typename%>，因为%qT是一个有依赖的作用域"
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%>命名了一个构造函数而非类型"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "标号位于复合语句末尾"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "需要选择语句"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "函数返回了一个数组"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "字段%qE声明为一个函数"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "类型不能定义在条件表达式中"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "需要初始值设定"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "表达式语句类型不完全"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "需要循环语句"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "前往目录:"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允许计算转移"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "需要跳转语句"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-name"
 msgid "expected module-name"
 msgstr "需要模板名"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "method declaration not in @interface context"
 msgid "module-declaration not permitted in header-unit"
 msgstr "方法声明不在@interface 上下文中"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 msgid "private module fragment"
 msgstr "重复的%<volatile%>"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "import-declaration must be at global scope"
 msgstr "在类作用域使用非成员的 using 声明"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "%qE may only occur once in an export declaration"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 msgid "attributes are not permitted in this position"
 msgstr "形参声明为%<auto%>"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr "忽略%qs属性"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多余的%<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>未出现在块起始"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合声明和函数定义"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "初始值设定项中索引范围为空"
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration"
 msgid "empty structured binding declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for member function %qD"
 msgid "invalid initializer for structured binding declaration"
 msgstr "成员函数%qD的初始值设定无效"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%>用在类外"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%>的语义在 C++0x 中将被改变；请考虑删除它"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%s：无效的新列指定符号“%s”\n"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D无效，在%q#T中"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "%s：无效的新列指定符号“%s”\n"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "类定义不能被声明为友元"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in an exception-specification"
 msgid "types may not be defined in explicit-specifier"
 msgstr "类型不能定义在异常规范中"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, fuzzy, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "类型不能定义在 new-type-id 中"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有构造函数才能有基类初始值设定"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "无法从成员%<%D%>中扩展初始值"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "对%qD的静态声明出现在非静态声明之后"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建构子 delegation 追随 mem-initializer 用于 %qD"
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代错误的旧式基类初始值设定"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(限定的初始值设定隐式地是一个类型)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介于 %<“”%>和后缀识别码"
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "需要标识符或%<(%>"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "二元操作中中操作数无效"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "需要操作符"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "关键字%<export%>未实现，将被忽略"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<export%> not implemented, and will be ignored"
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "关键字%<export%>未实现，将被忽略"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, fuzzy, gcc-internal-format
 #| msgid "-mexr is used without -ms"
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr "-mexr 未与 -ms 一起使用"
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以%<<::%>开始一个模板实参列表"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%>是%<[%>的另一种拼法。请在%<<%>和%<::%>间加上空格"
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用%<-fpermissive%>G++ 会接受您的代码)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "需要模板实参"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "模板实参表语法错误"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "需要模板名"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非模板%qD用作模板"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用%<%T::template %D%>来表示这是一个模板"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "需要模板实参"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "显式实例化不应当使用%<inline%>限定符"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "显式实例化不应当使用%<constexpr%>限定符"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "显式实例化不应当使用%<constexpr%>限定符"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "需要类型名"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE不是一个类型名"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "concept defined here"
 msgstr "联合在此定义"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "elaborated-type-specifier 用于范围的 enum 必须不使用 %<%D%>关键字"
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 #| msgid "typedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "声明%qD没有声明任何东西"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "属性在未初始化类型上被忽略"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD不是一个枚举模板"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "启用模板自动实例化"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qD声明出现在命名空间%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD声明出现在%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "不允许有多余的限定"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而无需名称"
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必须使用简单的识别码"
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD不是一个命名空间名"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD不是一个命名空间名"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, fuzzy, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace name required"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "模板标识符不允许出现在 using 声明中"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "访问声明被不宜用在中 favour 的 using-declarations；建议：加入 %<using%> 关键字"
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT不是一个命名空间"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD在函数作用域外未被定义"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "函数声明中出现形参名却未指定类型"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "函数声明中出现形参名却未指定类型"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD redeclared as variable"
 msgid "add parentheses to declare a variable"
 msgstr "函数%qD重声明为变量"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函数定义中不允许有属性"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "预期的建构子、解构式，或类型转换"
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "为函数提供了初始值设定"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "函数%q+D重声明为内联的"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "数组边界不是一个整数常量"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>不是一个类型"
@@ -57281,443 +57340,443 @@ msgstr "%<%T::%E%>不是一个类型"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "无效的声明"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "将构造函数用作模板无效"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "需要一个限定的标识符"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "需要声明"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD是一个命名空间"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "%q+D的类型限定冲突"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfpxx%> requires %<-mlra%>"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "%C处重复访问限定符"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "%qT not permitted in template argument"
 msgstr "参数不匹配"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "对%qT的使用非法"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "不能在模板实参中定义类型"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "需要%<,%>或%<...%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "类型不能定义在参数类型中"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "默认参数只允许出现在函数参数中"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "需要类名"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "结构定义后需要%<;%>"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "联合定义后需要%<;%>"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "需要%<{%>或%<:%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "不能为类指定 %<override%>"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函数模板%qD重声明为类模板"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T的前一个定义"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "声明友元时必须使用 class 关键字"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "为无名形参指定了%qs"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "位段%qD非整型"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函数定义上有 pure 指定"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "指定了无效的 AE 类型(%s)\n"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> specified more than once in base-specified"
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "在基类限定中指定了多于一次的%<virtual%>"
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "超过一个访问说明符在中 base-specified"
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(基类隐式地是一个类型)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "类型不能定义在异常规范中"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "因为异常规范不一致"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "动态异常规格被不宜用在中 C++0x; 使用 %<noexcept%> 作为替代"
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要标识符"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr "不能为局部变量指定节属性"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "要求的位置不是一个整数常量"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求的位置不是一个整数常量"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "特例化成员%<%T::%E%>需要%<template<>%>语法"
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "%<%T::%E%>声明无效"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "模板参数表太少"
@@ -57726,628 +57785,628 @@ msgstr "模板参数表太少"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "模板参数表太多"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "有名返回值不再被支持"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "局部类中对成员模板的声明无效"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "模板有 C 链接"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "没有声明任何东西"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "显式特例化不能有存储类型"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "在嵌套模板实参列表中应当使用%<> >%>而非%<>>%>"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的%<>>%>，使用%<>%>来结束模板实参列表"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>出现在%qD之前"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 不支持%<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重复的标号%qD"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重复的%qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "需要%<new%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "需要%<delete%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "需要%<return%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "需要%<extern%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "需要%<static_assert%>"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "需要%<decltype%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "需要%<template%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "需要%<namespace%>"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "需要%<using%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "需要%<asm%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "需要%<try%>"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "需要%<throw%>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<auto%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "需要%<__label__%>"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "需要%<@try%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "需要%<@synchronized%>"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "需要%<@throw%>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "对 rpmtxn 数据库异动作业进行除错"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "于 %s 等待异动作业锁定\n"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "需要 %<@end%>"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "需要%<::%>"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "需要%<...%>"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "需要%<*%>"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "需要%<~%>"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "需要%<:%>或%<::%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了%qs标记，在命名%q#T时"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "以前在此声明过"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT被声明为比其基类%qT有更高的可见性"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "标号%qD在此定义"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "在此声明"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD重声明时有不同的可访问性"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "用作消歧义的%<template%>只能用于模板内"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "文件在默认参数处结束"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "需要指定声明"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 消息参数被预期"
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%>必须指定一个类型作为实参"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "无效的 Objective-C++ 选择子名"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "%C处数组声明需要另外一维"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "不能为局部变量指定节属性"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介于 Objective-C++ 方法"
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "不一致的实例变量指定"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%>需要标识符"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "属性可能无法被指定的之前 %<@%D%>Objective-C++ 关键字"
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "不能设置只读属性"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "不能设置只读属性"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "需要整数表达式"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "无效还原标识符"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in parameter types"
 msgid "types may not be defined in iterator type"
 msgstr "类型不能定义在参数类型中"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代变量%qD不应当是 reduction"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "%L处折叠的 !$OMP DO 没有足够的 DO 循环"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "无效的初始值设定"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "? 预期于运算式中"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, fuzzy, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "上一个声明"
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>无法在之内外 %<__transaction_atomic%>"
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函数"
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC coprocessor"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC coprocessor 格式错误"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "模块间优化未为 C++ 实现"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "此上下文中不允许标准转换"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "数据成员%qD不能是成员模板"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "显式特例化出现在非命名空间作用域%qD中"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "所包含的类模板并未被显式特例化"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "在不同命名空间内对%qD的特例化"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  从%q+#D的定义"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qD的显式实例化出现在命名空间%qD中，而后者并不包含命名空间%qD"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "类名隐藏了模板的模板形参%qD"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "%qT的实例化在特例化之后"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -58355,148 +58414,148 @@ msgstr "  从%q+#D的定义"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "%qT的实例化在%qT的特例化之后"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "友元模板特例化%qD中不允许出现默认参数"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s%#D"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD不是一个函数模板"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD不是一个模板"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "%2$q+D的模板标识符%1$qD不匹配任何模板声明"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "发现 %d 个%<template<>%>，需要 %d 来特例化一个成员函数模板"
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "在初次使用后显式特例化%qD"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%qD的显式实例化出现在命名空间%qD中，而后者并不包含命名空间%qD"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "在初次使用后显式特例化%qD"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "模板标识符%qD出现在基本模板的声明中"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "显式初始化中出现了模板参数列表"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "为显式实例化提供的定义"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD声明时模板参数表太少"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD的显式特例化必须由%<template <>%>引入"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "函数模板部分特例化%qD是不允许的"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, fuzzy, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "函数模板部分特例化%qD是不允许的"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "显式特例化时指定了默认参数"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD不是一个模板函数"
@@ -58509,168 +58568,168 @@ msgstr "%qD不是一个模板函数"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "特例化了隐式声明的特殊成员函数"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "友元%q#D的重声明不能有默认模板参数"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "基类初始值设定展开%<%T%>不包括参数包"
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "展开样式%<%T%>不包括参数包"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "展开样式%<%E%>不包括参数包"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "参数包未能在%<...%>中被展开："
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "       %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "模板形参类型%qT声明为%<friend%>"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到模板参数："
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "提供给函数%qE的实参太多"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "参数包实参%qT必须出现在模板实参表末尾"
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "模板实参%2$qE的类型%1$qT取决于模板参数"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD没有默认参数"
@@ -58679,49 +58738,49 @@ msgstr "%qD没有默认参数"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "只有指定了 -std=c++0x 或 -std=gnu++0x 时才能在函数模板中使用默认参数"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "默认参数不能用在部分特例化中"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "形参%qD被声明为 void"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "模板类没有名字"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
@@ -58731,64 +58790,64 @@ msgstr "非成员函数%qD不能拥有 cv 限定符"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD模板声明无效"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "对非模板%q#D的模板定义"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 级的%q#D模板参数，却给出了 %d 级"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 个模板参数，为%q#D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%2$q#T得到了 %1$d 个模板参数"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "但实际需要 %d 个"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用 template<> 来显式特例化"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT不是一个模板类型"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD的声明中没有 template 限定"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "重声明为具有 %d 个模板参数"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -58796,444 +58855,444 @@ msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "先前的声明%q+D使用了 %d 个模板参数"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "模板形参%q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在这里又被声明为%q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定义%q#D的默认参数"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %q#D with different constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板参数"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必须是格式为‘&X::Y’的成员指针"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD不是%qT的成员"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  类型 %qT 和 %qT 有不兼容的 cv-qualifiers"
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 冲突值用于 non-type 参数 %qE (%qE 和 %qE)"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] " 备选需要 %d 实参，但提供了 %d 个"
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT是%qT的有歧义的基类"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "派生联合%qT无效"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板参数的模板模板参数是不一致与其他 deduced 模板参数"
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD不是一个有效模板实参，因为%qD是一个变量，而非变量的地址"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE不是类型%qT的有效模板实参，因为字面字符串不能用在此上下文中"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE不是类型%qT的有效模板实参，因为 cv 限定冲突"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE不是类型%qT的有效模板实参，因为它不是一个左值"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D不是类型%qT的有效模板参数，因为一个引用变量没有常量地址"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE不是类型%qT的有效模板实参，因为它是一个指针"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "尝试使用%qE代替"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "注入的类名%qD被用作模板的模板参数"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "将析构函数%qD用作类型无效"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某个模板参数的类型成员时，请使用%<typename %E%>"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "需要一个%qT类型的常量，却给出了%qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "需要一个类型，却给出了%qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "需要一个类模板，却给出了%qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "需要有%qD类型的模板，却得到了%qT"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供给%q+D"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D声明为模板"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非模板类型%qT用作模板"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "对于模板声明%q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "内部一致性错误"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD不是一个模板"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "联合和可变数组成员"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE没有出现在声明的开头"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "展开%<%T%>时参数包长度不匹配"
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "展开%<%E%>时参数包长度不匹配"
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定义%q#D的默认参数"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "生成非类类型%qT的成员函数指针"
@@ -59251,296 +59310,296 @@ msgstr "生成非类类型%qT的成员函数指针"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "变量%qD有函数类型"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "无效的参数类型%qT"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在声明%q+D中"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函数返回了一个数组"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函数返回了一个函数"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成对 void 的引用"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "生成指向引用类型%qT的指针"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "创建指向 void 类型的成员指针"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT不是类、结构或联合类型"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT被解析到非类类型%qT"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在模板中使用%qs"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依赖名%qE被解析为非类型，但实例化却产生了一个类型"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用无效字段%qD"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "对集展开表达式的无效使用"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用%<...%>来展开实参集"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被声明在中这个范围，而找不到任何声明是由 argument-dependent 查找于点的实体化"
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "声明在中附属基底 %qT 找不到由资格不符的查找"
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD既不是类也不是命名空间"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT是/使用了匿名类型"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD的模板实参使用了局部类型%qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT是一个可变类型"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  试图实例化%qD"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 msgid "%s %#qS"
 msgstr "张贴被搁置的文章 [%%s]？(%s/%s/%s/%s/%s)："
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "对非模板%q#D的显式实例化"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "类型%qT用于显式实例化%qD时不匹配声明的类型%qT"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "对%q#D的显式实例化"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "对%q#D重复的显式实例化"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 不允许在显式实例化时使用%<extern%>"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "为模板实例化化应用了存储类型%qD"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允许在显式实例化时使用%qE"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -59553,162 +59612,162 @@ msgstr "在初次使用后显式特例化%qD"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "显式实例化%qD时没有可用的定义"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "在实例化%2$q+D时模板实例化深度超过了最大值 %1$d，可能是由于生成虚函数表所致(使用 -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qT作为枚举被引用"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非模板%qD用作模板"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考虑内联函数"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weakref"
 msgid "explicit deduction guide declared here"
 msgstr "内联函数%q+D不能声明为有弱链接"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "模板第 %d 个参数无效"
@@ -59857,544 +59916,544 @@ msgstr "无法声明%q+#D"
 msgid "  since %q+#D declared in base class"
 msgstr "因为%q+#D已在基类中声明过"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%qD在其类外被声明为%<constexpr%>"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "建议在%<do%>的空语句体周围显式地加上花括号"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "catching non-reference type %q#T"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 #| msgid "type of asm operand %qE could not be determined"
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "无法确定 asm 操作数%qE的类型"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "__label__ declarations are only allowed in function scopes"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "__label__ 声明只能出现在函数作用域中"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "%qE missing template arguments"
 msgstr "参数不匹配"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "析构函数不能有参数"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "静态成员函数中不能使用%<this%>"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "在非成员函数中使用%<this%>无效"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "在文件作用域使用%<this%>无效"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "伪析构函数名的限定作用域无效"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE的类型不是%qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "非对象类型%qT的复合字面常量"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "模板形参必须使用%<class%>或%<typename%>关键字"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "将类型%qT用作模板的模板参数的默认值无效"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "模板的模板形参的默认实参无效"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "在模板参数列表中定义了%q#T"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "对限定类型%qT的定义无效"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "无效的基类"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD未被捕获"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, fuzzy, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函数中使用%<auto%>变量"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, fuzzy, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "参数不匹配"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "模板参数%qD(类型为%qT)不允许出现在整数表达式中，因为它的类型不是整数或枚举"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "将类模板%qT用作表达式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多继承网格中对%qD的访问有歧义"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE的类型未知"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qD不是一个枚举名"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "为形参声明指定了无效的存储类"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "不能为析构函数%<~%T%>使用%<offsetof%>"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, fuzzy, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE的类型对%<reduction%>无效"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD在%<firstprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, fuzzy, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "太多的%qs子句"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%>%qD不是一个文件、命名空间或块作用域变量"
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%>%qE指示不在%qT定义中"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%qE和%qD之间的差不具有整数类型"
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "%qE evaluates to false"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "静态断言中出现非常量条件"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -60402,22 +60461,22 @@ msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -60427,1114 +60486,1115 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV限定符不能应用到%qT上"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid " declared here"
 msgstr "在此声明"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not captured"
 msgid "%qD is not public"
 msgstr "%qD未被捕获"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD不是一个变量"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD has a non-structural type"
 msgstr "%qD不是一个类型"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "%qE属性需要带有名实参的原型"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "不能向类型添加属性%qE"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "请求的 init_priority 不是一个整数常数"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能将%qE属性用于某个类的对象的文件作用域定义"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "请求的 init_priority 越界"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "请求的 init_priority 保留为内部使用"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE属性在此平台上不受支持"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE属性需要带有名实参的原型"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%>不是一个有效的声明"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "请输入有效字符"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "PRINT_OPERAND 空指针"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失败，于 %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "在不同的指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "在不同的指针类型%qT和%qT之间的转换要一个类型转换"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ 不允许在%<void *%>和函数指针间比较"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ 不允许在%<void *%>和函数指针间转换"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ 不允许%<void *%>和函数指针组成的条件表达式"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "在不同的成员指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "在不同的成员指针类型%qT和%qT之间的转换需要一个类型转换"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "不同的成员指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "canonical types differ for identical types %T and %T"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "相同类型 %T 和 %T 的正规类型不同"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "不同类型 %T 和 %T 有相同的正规类型节点"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%qs用于成员函数无效"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "对位段使用%<sizeof%>无效"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ 不允许将%<sizeof%>应用到函数类型的表达式上"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "对位段使用%<__alignof%>无效"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ 不允许将%<__alignof%>应用到函数类型的表达式上"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "取临时变量的地址"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "已弃用从字符串常量到%qT的转换"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "已弃用从字符串常量到%qT的转换"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "对成员%qD的请求出现在%qE中，而后者具有非类类型%qT"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "对成员%qD的请求出现在%qE中，而后者具有非类类型%qT"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "对非静态数据成员%qE的使用无效"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "对 NULL 对象非静态数据成员%qD的访问无效"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "对象类型%qT的析构函数名~%qT不匹配"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "被析构的类型是%qT，但析构函数却使用了%qT"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%>不是%qT的成员"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT不是%qT的基类"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD不是一个成员模板函数"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT不是一个指向对象的类型"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "对成员指针数组索引的使用无效"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "对成员指针使用一元%<*%>非法"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "隐式转换成员指针用法无效"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "数组引用缺少下标"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下标访问声明为%<register%>的数组"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用%qE时缺少对象"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允许在程序里调用%<::main%>"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必须用%<.*%>or%<->*%>调用%<%E (...)%>中的成员函数指针，例如%<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太多"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太少"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD的第 %1$P 个形参的类型%3$qT不完全"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "形参 %P 的类型%qT不完全"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD的地址永远不会为 NULL"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "比较将一律评估作为 %<true%> 用于地址的 %qD 将永不是空值"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 #| msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "在不同的指针类型%qT和%qT之间的转换要一个类型转换"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "在不同的指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定从重载函数转换到类型%qT"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算术表达式中使用了 NULL"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允许比较指针和整数的值"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "指针与整数 0 比较大小"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮点实参间的无效比较"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "操作数类型%qT和%qT对双目%qO而言无效"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允许在减法中使用类型为%<void *%>的指针"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允许在减法中使用函数指针"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允许在减法中使用指向方法的指针"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指针算术中使用指向不完全类型的指针无效"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "取构造函数%qE的地址"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用%qE形成成员函数指针的用法无效"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "需要一个限定的标识符"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "%qE两边的括号不能用来构造一个成员函数指针"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过提取一个未限定的或带括号的非静态成员函数的地址来形成一个成员函数指针。请使用%<&%T::%D%>"
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过取已绑定的成员函数的地址来构造成员函数指针。请改用%<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "取临时变量的地址"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允许取函数%<::main%>的地址"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能创建指向引用成员%qD的指针"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "无法取得位段%qD的地址"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of an immediate function %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "取一个类型为%<void%>的表达式的地址"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ 不允许枚举自增"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自增"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自增"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自减"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "无法取右值表达式%<this%>的地址"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求显式寄存器变量%qD的地址。"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "请求声明为%<register%>的%qD的地址"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的类型转换丢失了限定符"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 static_cast 丢失了限定符"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 reinterpret_cast 丢失了限定符"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 static_cast 无效"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "源有不完全的类类型"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "从%qT转换到%qT"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "从具有类型%qT的右值表达式到类型%qT中的转换无效"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "从%qT到%qT的转换损失精度"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 #, fuzzy
 #| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "在不同的成员指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "从%qT到%qT的转换增大了目标类型的对齐需求"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允许在函数指针和对象指针间进行转换"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它既不是指针，也不是引用，也不是数据成员指针"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它是一个指针函数类型的指针或引用"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允许转换为数组类型%qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "在求%<%Q(%#T, %#T)%>值时"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "初始值设定中数组索引不是常数"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "将%qT赋值给%qT时类型不兼容"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "数组被用作初始值设定"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "无效的数组赋值"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "在成员函数指针转换中"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成员指针转换经由虚基类%qT"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "在成员指针转换中"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "不能在参数默认时将%qT转换为%qT"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "不能在传参时将%qT转换为%qT"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
 msgstr "不能在返回时将%qT转换为%qT"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "不能在赋值时将%qT转换为%qT"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "赋值的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在传递%2$q+D的第 %1$P 个实参时"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "返回临时变量的引用"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "返回了对局部变量的%q+D的引用"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "too many values in return statement"
 msgid "redundant move in return statement"
 msgstr "返回语句中值太多"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "析构函数返回值"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能从构造函数的异常处理中返回"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "构造函数返回值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<花括号内的初始值列表>"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%>不能返回 NULL，除非它被声明为%<throw()%>(或 -fcheck-new 起作用)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "右值的引用用作左值"
@@ -61807,108 +61867,103 @@ msgstr "标量初始化带花括号"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "无法用复合字面常量初始化类型为%qT的聚集"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成员%qD缺少初始值设定"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "类型%qD不匹配原先的声明"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的联合中找不到字段%qD"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在联合初始值设定中出现了索引值而不是字段名"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "检测到循环指针代理"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%>的基操作数具有非指针类型%qT"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%>的结果给出了非指针的结果"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%>的左操作数不是一个指针"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE不能用作成员指针，因为它的类型为%qT"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "无法将成员指针%qE应用到%qE上，因为后者的类型%qT不是一个类"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成员指针类型%qT与对象类型%qT不兼容"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "引用类型的非法值初始化"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "调用的函数%qD会抛出不完全的类型%q#T"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "调用的函数会抛出不完全的类型%q#T"
@@ -61928,283 +61983,289 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 msgid "extern symbols cannot have initializers"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, fuzzy, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 msgid "variables cannot be of type void"
 msgstr "迭代变量%qE类型无效"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "cannot be declared to be a function"
 msgstr "new 不能用于函数类型"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of %<struct %E%>"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "%<struct %E%>重定义"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be %s"
 msgstr "不能打开 %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be `scope` and `%s`"
 msgstr "不能打开 %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 msgid "field not allowed in interface"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "inout variables can only be declared inside inout functions"
 msgstr "只能为函数指定%qs"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, fuzzy, gcc-internal-format
 msgid "reference to scope class must be scope"
 msgstr "删除死存储"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in a .bss section"
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "只有未初始化的变量才能放在 .bss 节中"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr "只有构造函数才能有基类初始值设定"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr "花括号中的 spec 体‘%s’无效"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s does not have a default initializer"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 msgid "is not a static and cannot have static initializer"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "static storage variables cannot have destructors"
 msgstr "Java 类%qT不能有析构函数"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "string expected for library name"
 msgstr "需要类名"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, gcc-internal-format
 msgid "function name expected for start address"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 #| msgid "expected function"
 msgid "string expected for mangled name"
 msgstr "需要函数"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "没有参数"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration %q+D"
 msgid "can only apply to a single declaration"
 msgstr "对于模板声明%q+D"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "incomplete mixin declaration (%s)"
 msgstr "相互冲突的声明%q#D"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, fuzzy, gcc-internal-format
 msgid "base type must not be void"
 msgstr "选择子必须是立即数"
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr "%2$L处有 PASS 的过程‘%1$s’必须至少带一个参数"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "circular reference to enum member"
 msgstr "返回临时变量的引用"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgid "template tuple parameter must be last one"
 msgstr "模板形参必须使用%<class%>或%<typename%>关键字"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "递归内联"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "递归内联"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "error instantiating"
 msgstr "写入%qs时错误"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "虚函数不能是友元"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 msgid "functions cannot be scope"
 msgstr "不能内联%<main%>函数"
@@ -62212,44 +62273,54 @@ msgstr "不能内联%<main%>函数"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s functions cannot be abstract"
 msgstr "不能内联%<main%>函数"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot override a non-virtual function"
 msgstr "重载虚函数名时给出警告"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify both -C and -o"
 msgid "cannot be both final and abstract"
 msgstr "不能同时指定 -C 和 -o"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -62257,180 +62328,180 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr "隐藏了被删除的函数%q+D"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr "给予函数的实参太少"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qE incompatible attribute ignored"
 msgid "incompatible covariant types %s and %s"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "does not override any function"
 msgstr "%qD不是一个成员模板函数"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "隐藏了被删除的函数%q+D"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "%qs属性只能应用于函数"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "重载虚函数名时给出警告"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr "字节编号必须是非负数"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr "%2$L处 %1$s 函数的参数是负的"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 msgid "structs, unions cannot be abstract"
 msgstr "不能内联%<main%>函数"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr "数组边界不是一个整数常量"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "circular pointer delegation detected"
 msgid "circular inheritance"
 msgstr "检测到循环指针代理"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr "数组边界不是一个整数常量"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "忽略重复的目录“%s”\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot inherit from final class %s"
 msgstr "无法为类 %s 找到文件"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "类型%qE有虚成员函数"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 msgid "mixin templates are not regular templates"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "%2$q+D的模板标识符%1$qD不匹配任何模板声明"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot read %s"
 msgid "cannot resolve"
 msgstr "无法读取 %s"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr "复数表达式类型不匹配"
@@ -62445,22 +62516,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr ""
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 msgid "has forward references"
 msgstr "别名有 non-alias 参考"
@@ -62524,23 +62595,22 @@ msgstr "构造函数中对静态成员的初始化无效"
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "函数不能返回函数"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "destructor priorities are not supported"
 msgid "naked assembly functions with contracts are not supported"
@@ -63089,7 +63159,7 @@ msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "‘我’于 %L 和‘J’于 %L 无法两者是 BOZ 实字常数"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "%2$C处 DATA 语句初始值设定 %1$s 无效"
@@ -64188,12 +64258,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "初始化字符串被截断，以匹配%L处的变量"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L处的子字符串起始索引小于 1"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "%L处的子字符串终止索引超过了字符串长度"
@@ -64386,7 +64456,7 @@ msgstr "%C处错误的 INTENT 规格"
 msgid "deferred type parameter at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -66918,7 +66988,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -67001,7 +67071,7 @@ msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -67137,12 +67207,12 @@ msgstr "%L处定义赋值的第一个参数必须是 INTENT(OUT) 或 INTENT(INOU
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L处定义赋值的第二个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第一个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第二个参数必须是 INTENT(IN)"
@@ -67252,549 +67322,549 @@ msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "INTENT(%s) %L处的实参可能干涉%L处的实参。"
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "%2$L处实参‘%1$s’类型不匹配；将 %3$s 传递给 %4$s"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "%L处假定外形的实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参类型必须相同"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "实际参数到 non-INTENT (INOUT) 虚设‘%s’于 %L, 该项是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "实际参数到 non-INTENT (INOUT) 虚设‘%s’于 %L, 该项是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "虚参数‘%s’必须是指标或 assumed-shape 数组而无需 CONTIGUOUS 属性 - 作为实际参数于 %L 不是仅需 contiguous 和两者是异步或易变的"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "传递 coarray 于 %L 到 allocatable、noncoarray，含义 (出) 虚参数‘%s’"
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "传递 coarray 于 %L 到 allocatable，noncoarray 虚参数‘%s’，该项无效如果配额状态被已修改"
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "%2$L 处假定外形的数组的元素传递给哑参数“%1$s”"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "%2$L处假定外形的数组的元素传递给虚参‘%1$s’"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "%2$L处假定外形的数组的元素传递给虚参‘%1$s’"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003：%2$L处标量 CHARACTER 实参带有数组虚参‘%1$s’"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003：%2$L处标量 CHARACTER 实参带有数组虚参‘%1$s’"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "%2$L处关键字参数‘%1$s’已经与另一个实参相关联"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "%L处调用过程时实参比形参多"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "%L处子进程调用缺少替代返回限定"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "%L处子进程调用中的替代返回限定与预期不符"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008:空指标于 %L 到 non-pointer 虚设‘%s’"
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "%4$L处实参和指针或可分配虚参‘%3$s’之间字符长度失配(%1$ld/%2$ld)"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "%4$L处实参和假定外形虚参‘%3$s’之间字符长度失配(%1$ld/%2$ld)"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "实际参数于 %L 到 allocatable 或指标虚参数‘%s’必须有已推迟长度类型参数如果和只有如果虚设有一个"
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "%4$L处实参的字符长度短于虚参‘%1$s’(%2$lu/%3$lu)"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "%4$L处实参包含的元素对于虚参‘%1$s’(%2$lu/%3$lu)而言太少"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "‘%s’的实参在%L处必须不是一个假定大小的数组"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008:Non-pointer 实际参数于 %L 到指标虚设‘%s’"
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, fuzzy, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Coindexed 异步或易变的实际参数于 %L 需求该虚设‘%s’有 neither 异步 nor 易变的"
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "%L处带有向量下标的数组节实际参数与虚参‘%s’的 INTENT(OUT)、INTENT(INOUT) 或 VOLATILE 属性不兼容"
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处假定外形的实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处数组节实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处指针数组的实参由于 VOLATILE 属性要求一个假定外形或指针数组虚参‘%s’"
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "%L处子进程调用缺少替代返回限定"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "%C处的实参数列中缺少关键字名"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, fuzzy, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "%5$L处同样的实际参数与 INTENT(%1$s) 实参‘%2$s’和 INTENT(%3$s)实参‘%4$s’相关联"
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "%L处的过程参数对于 PURE 过程是局部的，但是有 POINTER 属性"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "%2$L处调用的过程‘%1$s’不是显式声明的"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "%2$L处调用的过程‘%1$s’不是显式声明的"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "调用过程‘%s’带隐式接口，位于 %L"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "%2$L处的自动字符长度函数‘%1$s’必须有一个显式的接口"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "%2$L处过程‘%1$s’的关键字参数要求显式的接口"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "符号‘%s’在%L处已经有了显式接口"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "铸型参数到空值必要项于 %L"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "%2$L处过程‘%1$s’的关键字参数要求显式的接口"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "%2$L调用过程指针组件‘%1$s’时有隐式接口"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "%2$L处过程指针组件‘%1$s’的关键字实参需要显式接口"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "铸型=必要项在中空值() 参数于 %L:模棱两可介于特定的函数 %s 和 %s"
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "在类%qs中找不到可溢出的寄存器"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "%2$C处实体‘%1$s’已经出现在接口中"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "不能覆盖%2$L处的 GENERIC‘%1$s’"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%2$L处的‘%1$s’覆盖了一个绑定声明为 NON_OVERRIDABLE 的过程"
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%2$L处的‘%1$s’不能被 DEFERRED，因为它覆盖了一个非 DEFERRED 绑定"
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 PURE 过程因此必须也是 PURE"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%2$L处的‘%1$s’覆盖了一个 ELEMENTAL 过程因此也必须是 ELEMENTAL"
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%2$L处的‘%1$s’覆盖了一个非 ELEMENTAL 过程因此必须也不是 ELEMENTAL"
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 SUBROUTINE 因此也必须是 SUBROUTINE"
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 PUBLIC 过程因此必须不是 PRIVATE"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%2$L处的‘%1$s’必须有与被覆盖的过程相同数量的形式参数"
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%2$L处的‘%1$s’覆盖了一个 NOPASS 绑定因此必须也是 NOPASS"
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%2$L处的‘%1$s’覆盖了一个具有 PASS 的绑定因此也必须是 PASS"
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "%2$L处的‘%1$s’的传递对象虚参必须与被覆盖的过程传递对象的虚参位置相同"
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s 标记在%L处必须具有类型 %s"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "%3$L处有字符值的 %1$s‘%2$s’不能是假定长度的"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "DATA 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "过程‘%s’(在 %s 中，位于 %L) 既不是函数也不是子进程"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "给予函数 %s 的参数太多，于 %L"
@@ -67939,34 +68009,34 @@ msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fortran 2003：作为初始表达式的基本函数在%L处使用了非整数或非字符的参数"
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "在%2$L处调用内建‘%1$s’的子例程不是 PURE"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "在%2$L处调用内建‘%1$s’的子例程不是 PURE"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "从 %s 转换到 %s，位于 %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "从 %s 转换到 %s，位于 %L"
@@ -67974,23 +68044,23 @@ msgstr "从 %s 转换到 %s，位于 %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "不能将 %s 转换为 %s，于 %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "不能将 %s 转换为 %s，于 %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, fuzzy, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "%2$L处声明的‘%1$s’可能遮盖同名内建函数。为了调用内建函数，可能需要显式的 INTRINSIC 声明。"
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, fuzzy, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "%2$L处声明的‘%1$s’也是一个内建函数的名字。它只能通过一个显式接口或声明 EXTERNAL 来调用。"
@@ -68556,7 +68626,7 @@ msgstr "名称表列‘%s’在中读取叙述于 %L 含有符号‘%s’该项
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有 POINTER 组件"
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
@@ -69758,12 +69828,12 @@ msgstr "错误的运算符"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, fuzzy, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, fuzzy, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "错误的条件码"
@@ -69921,147 +69991,147 @@ msgstr "%2$L处引用的内建运算符‘%1$s’在模块‘%3$s’中找不到
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "不能打开模块文件‘%s’写入，在%C处：%s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "写入到输出文件 '%s' 时出错\n"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "%s：无法找到模块文件 %s\n"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "无法将模块文件‘%s’重命名为‘%s’：%s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "无法删除临时模块文件‘%s’：%s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "`%.*s' 已被定义为对照符号"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "%2$L处引用的符号‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "%2$L处引用的符号‘%1$s’在内建模块 ISO_C_BINDING 中找不到"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "`%.*s' 已被定义为对照符号"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, fuzzy, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "%2$C处对内建模块‘%1$s’的使用与以前使用的非内建模块名字冲突"
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, fuzzy, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "%C处在内建模块 ISO_FORTRAN_ENV 中对 NUMERIC_STORAGE_SIZE 命名常数的使用与选项 %s 不兼容"
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "%C处在内建模块 ISO_FORTRAN_ENV 中对 NUMERIC_STORAGE_SIZE 命名常数的使用与选项 %s 不兼容"
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "%2$L处引用的符号‘%1$s’在内建模块 ISO_FORTRAN_ENV 中找不到"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003：%C 处的 ISO_FORTRAN_ENV 内建模块"
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "%C处需要绑定名"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "%2$C处无法找到名为‘%1$s’的内建模块"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "使用了传统 C 不支持的特性时给出警告"
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "模块间优化未为 C++ 实现"
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "模块间优化未为 C++ 实现"
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "无法打开模块文件‘%s’读取，在%C处：%s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, fuzzy, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "%2$C处对非内建模块‘%1$s’的使用与之前对内建模块名字的使用相冲突"
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, fuzzy, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "%2$C处打开的文件的‘%1$s’并非一个 GFORTRAN 模块文件"
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -70604,8 +70674,8 @@ msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
@@ -72657,7 +72727,7 @@ msgstr "在%2$L处由内建函数‘%1$s’声明的 INTRINSIC 在当前的标
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "%2$L处非 RECURSIVE 过程‘%1$s’可能递归地调用它自己。请将它声明为 RECURSIVE 或使用 -frecursive"
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "标号 %d(引用自 %L)从未被定义"
@@ -72772,7 +72842,7 @@ msgstr "不能解析 %2$L处的函数‘%1$s’"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
@@ -72929,215 +72999,215 @@ msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 msgid "Impure function at %L might not be evaluated"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "%L处按值传递的实参不能是数组或数组段"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr ""
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, fuzzy, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零间隔非法"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "%L处数组引用错误"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "%L处未指定假定大小数组段的最右端上限"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L处数组索引必须是标量"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L处数组索引必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "%L处数组索引是一个秩为 %d 的数组"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, fuzzy, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L处数组索引是一个秩为 %d 的数组"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L处的子字符串起始索引类型必须为 INTEGER"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L处的子字符串起始索引必须是标量"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L处的子字符串终止索引类型必须为 INTEGER"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L处的子字符串终止索引必须是标量"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "%L处子串结束索引太大"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L处数组引用错误"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 POINTER 属性"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 ALLOCATABLE 属性"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L处不能指定两个或以上秩不为零的部分引用"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "假定外形的数组在 %L 处必须是哑参数"
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -73146,12 +73216,12 @@ msgstr "%L处假定外形的数组必须是一个虚参"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -73160,294 +73230,294 @@ msgstr "%L处假定外形的数组必须是一个虚参"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "“%s”是必须是一个模块过程或有显式接口的外部过程于 %L 处"
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "用在一个规格说明表达式中的变量‘%s’在%L处的引用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "变量‘%s’在%L处的使用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "%2$L处非多态的传递对象哑元实参‘%1$s’"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 对象与 polymorphic allocatable subcomponent 于 %L"
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "已弃用%qE"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "%C处类型指定无效"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "%L处传递的对象必须是标量"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "%L处类型限定过程调用的基类型是 ABSTRACT 类型‘%s’"
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%2$L处对 GENERIC‘%1$s’的调用没有找到匹配特别的限定"
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%L处的运算符接口必须是一个 SUBROUTINE"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要表达式类型"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L处)必须是一个标量"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 起始表达式必须是一个标量整数"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 结束表达式必须是一个标量整数"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L处 FORALL 间隔表达式必须是一个标量 %s"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L处 FORALL 间隔表达式不能是零"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引‘%s’不能出现在%L处的三元组规格说明中"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "%L处的源表达式必须是标量或者与%L处的分配对象有相同的秩"
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "%L处实体的类型与%L处的源表达式类型不兼容"
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "%L处的分配对象和%L处的源表达式应该有相同的种别类型参数"
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "%2$L处分配具有 ABSTRACT 基类型的 %1$s 需要一个类型指定或 SOURCE="
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 于 %L 与 type-spec 需求相同 character-length 参数作为在中声明"
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’不能出现在%L处其自身被分配的 ALLOCATE 语句的数组规格说明中"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "%L处的 ERRMSG 没有 STAT 标记所以不起作用"
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "%L处分配的对象也出现在%L处"
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
@@ -73456,285 +73526,285 @@ msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L 处 CASE 语句中的表达式种别必须为 %d"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L处 CASE 语句中的表达式必须为标量"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L处 SELECT 语句的实参不能是 %s"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L处的 DEFAULT CASE 为%L处的第二个 DEFAULT CASE 所跟随"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L 处 CASE 语句中的常量逻辑值被重复了"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L处范围规格无法匹配"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L处逻辑 SELECT CASE 块有多于两个的情况"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "名字‘%s’在%C处不能用作已定义的运算符"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%C处 SELECT TYPE 语句中的选择子应该是多态的"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "%2$L处派生类型‘%1$s’必须是‘%3$s’的一个扩展"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "%L处 SELECT TYPE 语句中有双重的 CLASS IS 块"
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L处的表达式必须具有标量类型"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "数据转移组件于 %L 无法 polymorphic 除非它被处理由定义的输入/输出进程"
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 ALLOCATABLE 组件"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L处数据传输元素不能是对一个假定大小数组的全引用"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L处的语句对%L处的分支语句而言不是一个有效的分支目标语句"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "%L处的分支可能导致无穷循环"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往叙述于 %L 树叶重要建构用于标贴于 %L"
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
@@ -73742,198 +73812,198 @@ msgstr "%s 语句在%C处离开 OpenMP 结构块"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L处的标号与%L处 GOTO 语句不在相同的块中"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L处的 WHERE 掩码外形不一致"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L处 WHERE 赋值目标外形不一致"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "%L处 WHERE 中用户定义的非 ELEMENTAL 用户赋值"
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L处在 WHERE 内不支持的语句"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "%2$L处带索引‘%1$s’的 FORALL 没有被用在赋值的左侧，所以可能导致对这个对象的多个赋值"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "%L处外部 FORALL 构造已经有一个同名的索引"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L处的 WHERE/ELSEWHERE 子句需要一个 LOGICAL 数组"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER 表达式在%3$L处赋值时将被截断(%1$d/%2$d)"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L处一个非纯变量在 PURE 过程中被赋值给带有 POINTER 组件派生类型变量(12.6)"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L处赋值中的变量类型是 UNKNOWN"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "变量必须不是 polymorphic 在中 intrinsic 指派于 %L - 检查该有匹配特定的副常式用于‘=’运算符"
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "%L处赋值中的变量类型不能是多态的"
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO 语句在%L处需要一个 INTEGER 变量"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "变量‘%s’在 %L 尚未指派目标标号"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "%L处的替代 RETURN 语句需要一个 SCALAR-INTEGER 返回限定符"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L处的 ASSIGN 语句需要一个默认标量 INTEGER 变量"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L处的算术 IF 语句要求一个数字表达式"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L处 DO WHILE 循环的退出条件必须是一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：错误的语句代码"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "%2$L处声明了未使用的参数‘%1$s’"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
@@ -73941,975 +74011,975 @@ msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "%L处字符串太长"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可分配的数组‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "%2$L处标量对象‘%1$s’不能为 ALLOCATABLE"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "%2$L处的 CLASS 变量‘%1$s’必须是哑元、可分配的或者指针"
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "‘%s’在%L处不能是主机相关的，因为它被在%L处声明的一个不兼容的同名对象所阻碍"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008：%2$L处模块变量‘%1$s’隐含使用了 SAVE，因为默认初始化有此需求"
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "%2$L处的模块或主程序数组‘%1$s’必须有常量外形"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L处假定字符长度的实体必须是个虚参或是个 PARAMETER"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可分配的‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "内建函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自动数组‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，于 %s:%d"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%2$L处有字符值的语句函数‘%1$s’必须有常量长度"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处‘%1$s’是 PRIVATE 类型因而不能是 PUBLIC 类型‘%2$s’的虚参"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: %3$L处 PUBLIC 接口‘%2$s’中的过程‘%1$s’有 PRIVATE 的虚参‘%4$s’"
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%2$L处 ELEMENTAL 函数‘%1$s’必须有一个标量返回值"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为数组值"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为纯函数"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能是递归的"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "哑过程‘%s’在%C处不能有泛型接口"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%L处 PURE 过程不能指定 SAVE 属性"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 INTENT 属性冲突"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与在%2$L处‘%1$s’中的 RESULT 属性冲突"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL 属性与在%2$L处‘%1$s’中的 FUNCTION 属性冲突"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "%2$L处过程指针结果‘%1$s’缺少指针属性"
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%L处的 FINAL 过程有且只有一个参数"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L处 FINAL 过程的参数必须不是 INTENT(OUT)"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "%L处的非标量 FINAL 过程应当有假定外形的参数"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "%2$L处声明的 FINAL 过程‘%1$s’有与‘%4$s’相同的秩(%3$d)"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "仅为定义在%2$L处的派生类型‘%1$s’声明了数组 FINAL 过程，建议也定义一个标量过程"
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%4$L处‘%1$s’和‘%2$s’对 GENERIC‘%3$s’不能是混合的 FUNCTION/SUBROUTINE"
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "引用%qs有歧义：出现在接口%qs和接口%qs中"
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定义的指定绑定‘%1$s’用作%3$L处的 GENERIC‘%2$s’的目标"
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "%2$L处 GENERIC‘%1$s’必须定位一个特定的绑定，‘%3$s’也是 GENERIC"
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "%2$L处 GENERIC‘%1$s’无法覆盖同名的特定绑定"
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%L处类型限定的操作数不能是 NOPASS"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%2$L处的‘%1$s’必须是一个模块过程或带有显式接口的外部过程"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处有 PASS(%2$s)的过程‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处有 PASS 的过程‘%1$s’必须至少带一个参数"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%2$L处非多态的传递对象虚参‘%1$s’"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr " %4$L处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须具有派生类型‘%5$s’"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%2$L处‘%1$s’的传递对象虚参必须是标量"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 POINTER"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的组件重名"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的继承组件重名"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "%2$L处声明的派生类型‘%1$s’必须是 ABSTRACT，因为‘%3$s’是 DEFERRED 且没有被覆盖"
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L处 ICHAR 的参数长度必须为 1"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处带有 PASS(%2$s)的过程指针组件‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "%4$L处具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须有派生类型‘%5$s’"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%4$L 处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须是标量"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能有 POINTER 属性"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "%2$L处组件‘%1$s’的字符长度必须是一个常量规格表达式"
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字符成分‘%s’的‘%s’于 %L 与已推迟长度必须是指标或 ALLOCATABLE"
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处组合‘%1$s’是一个 PRIVATE 类型，因此不能是 PUBLIC‘%2$s’的组合"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 于 %L 在中串行或绑定©类型 %s"
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "%2$L处声明的有 SEQUENCE 类型的组件 %1$s 没有 SEQUENCE 属性"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-constant initialization expression at %L"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%L处非常量初始化表达式"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "作为延伸类型‘%s’于 %L 有 coarray 成分，亲代类型‘%s’应该也有一个"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "%2$L处不能扩展的派生类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "不允许 %3$L 处 %2$s 名字列表中假定大小的数组“%1$s”"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有假定外形"
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’声明为 PRIVATE 因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有使用相关的 PRIVATE 组件因此不能是 NAMELIST‘%2$s’的成员"
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有 PRIVATE 组件因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 NAMELIST 属性冲突"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "%2$L处的参数数组‘%1$s’不能是自动的或有延迟的外形"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "%2$L处隐式类型的 PARAMETER‘%1$s’与随后的 IMPLICIT 类型不匹配"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C处假定大小数组的规格说明错误"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%2$L处带 VALUE 属性的字符哑元‘%1$s’必须具有常数长度"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%2$L处带 VALUE 属性与 C 可互操作的字符哑元‘%1$s’长度必须为 1"
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "%2$L处派生类型‘%1$s’的类型‘%3$s’尚未定义"
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "%2$L处假定外形数组‘%1$s’不能用在初始化表达式中"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "%2$L处变量‘%1$s’不能是 BIND(C) 因为它既不是一个 COMMON 块也不是于模块级作用域声明的"
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003：%3$L处 PUBLIC %1$s‘%2$s’具有 PRIVATE 派生类型‘%4$s’"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "%2$L处INTENT(OUT) 虚参‘%1$s’是 ASSUMED SIZE，所以不能有一个默认初始值设定"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "变量‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "变量‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "变量‘%s’于 %L 是 coarray 和不是 ALLOCATABLE，保存 nor 虚参数"
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "%L处的线程私有变量未被保存"
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "%C处需要有名实体列表"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必须在 COMMON 中"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必在前一个声明中指定"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "%2$L处的 DATA 元素‘%1$s’是一个指针所以必须是一个完全的数组"
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "在 %2$L 处基本过程的参数“%1$s”不能有 POINTER 属性"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "%L处 DATA 语句中有非常量数组段"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L处的 DATA 语名中变量比值多"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "开始的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "结束的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L处的 DATA 语句中值比变量多"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "标号 %d 于 %L 经定义但未被使用"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "标号 %d 于 %L 经定义但无法被使用"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须有 SEQUENCE 属性方能成为 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须没有 ALLOCATABLE 组件方能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "%2$L处的默认初始化的派生类型变量‘%1$s’不能成为 EQUIVALENCE 对象，因为它在 COMMON 中有变量"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "%2$L处的带指针组件的派生类型变量‘%1$s’不能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L处 EQUIVALENCE 语句语法错误"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "%L处 EQUIVALENCE 集中的对象必须都带有或者都不带有 PROTECTED 属性"
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%2$L处的公共块成员‘%1$s’不能在纯过程‘%3$s’中成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处的有名常量‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "%2$L处有非常量界限的数组‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处结构组件‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字符串长度为零"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C处字符长度规格语法错误"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003：%2$L处 PRIVATE 类型‘%3$s’的 PUBLIC 函数‘%1$s’"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的 ENTRY‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "%2$L处的用户运算符‘%1$s’必须是一个 FUNCTION"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "%2$L处用户运算符过程‘%1$s’不能有假定字符长度"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "%2$L处的用户运算符‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第二个参数不能是可选的"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L处的运算符接口必须有至多两个实参"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "%2$L处 PURE 过程中包含的过程‘%1$s’必须也是 PURE"
@@ -75789,17 +75859,17 @@ msgstr "%L 处  EQUIVALENCE 中不等的初始值设定重叠"
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, fuzzy, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "%L处数组构造函数中的元素数超过容许的上限 %d。请参见 -fmax-array-constructor 选项"
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "在%L处建立临时数组"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "走过错误的表达式类型(%d)"
@@ -75892,107 +75962,107 @@ msgstr "%L处非常量初始化表达式"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "内建函数变量不是一个过程"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "%2$L处函数‘%1$s’的返回值没有设置"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, fuzzy, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "模块变量 %s 的后端声明已存在"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "%2$L处声明了未使用的变量‘%1$s’"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "%2$L处的虚参‘%1$s’被声明为 INTENT(OUT)，但没有设置"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, fuzzy, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "%2$L处的虚参‘%1$s’被声明为 INTENT(OUT)，但没有设置"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "%2$L处声明了未使用的变量‘%1$s’"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "%2$L处声明了未使用的变量‘%1$s’"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "%2$L处声明了未使用的参数‘%1$s’"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "%2$L处声明了未使用的参数‘%1$s’"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "%3$L处声明的的函数‘%2$s’的返回值‘%1$s’没有设置"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "未知的内建操作"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "%L处参数列表函数未知"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -76147,7 +76217,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code()：错误的语句代码"
@@ -76281,7 +76351,7 @@ msgstr "-fwpa 和 -fltrans 互斥"
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
 #| msgid "-fwpa and -fltrans are mutually exclusive"
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-fwpa 和 -fltrans 互斥"
 
 #: lto/lto-object.c:107
@@ -77402,7 +77472,7 @@ msgstr "-finit-real 选项无法识别：-%s"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "-finit-real 选项无法识别：-%s"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 msgid "Unrecognized option: %qs"
 msgstr "无法识别的选项"
@@ -77420,15 +77490,15 @@ msgstr "%qs后缺少宏名"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "%qs后缺少文件名"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "%qs后缺少路径"
@@ -77483,7 +77553,7 @@ msgstr "缺少左括号"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "无效的 --param 值%qs"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "无效的 --param 值%qs"
@@ -77568,94 +77638,94 @@ msgstr "%qs 已弃用"
 msgid "unknown linker output %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "未知的额外精度风格“%s”"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, fuzzy, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "在 TOC 中存放浮点常量"
 
-#: common.opt:1718
+#: common.opt:1722
 #, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "未知的栈重用级别%qs"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy, gcc-internal-format
 #| msgid "unknown Stack Reuse Level %qs"
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "未知的栈重用级别%qs"
 
-#: common.opt:1889
+#: common.opt:1893
 #, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "未知的 IRA 算法 %qs"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 msgid "options or targets missing after %qs"
 msgstr "%qs后缺少文件名"
 
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "，未知 ABI"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 #| msgid "unknown Stack Reuse Level %qs"
 msgid "unknown Live-Patching Level %qs"
 msgstr "未知的栈重用级别%qs"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2690
+#: common.opt:2694
 #, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "未知的 TLS 模型 %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:3067
+#: common.opt:3071
 #, fuzzy, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "不可识别的寄存名%qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(在%qs的初始化附近)"
@@ -78611,6 +78681,10 @@ msgstr "未知的 TLS 模型 %qs"
 #~ msgid "right rotate count >= width of type"
 #~ msgstr "循环右移次数大于或等于类型宽度"
 
+#, fuzzy
+#~ msgid "cannot deduce template arguments for %qT from ()"
+#~ msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
+
 #, fuzzy
 #~ msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 #~ msgstr "%2$L处变量‘%1$s’不能有 ALLOCATABLE 属性，因为过程‘%3$s’是 BIND(C)"
@@ -80211,11 +80285,6 @@ msgstr "未知的 TLS 模型 %qs"
 #~ msgid "-fPIC and -mcall-%s are incompatible"
 #~ msgstr "-fPIC 与 -mcall-%s 互不兼容"
 
-#, fuzzy
-#~| msgid "constant argument out of range for %qs"
-#~ msgid "constant argument %d for builtin %qF is out of range ("
-#~ msgstr "常量实参超过%qs的范围"
-
 #~ msgid "z/Architecture mode not supported on %s"
 #~ msgstr "z/Architecture 模式在 %s 上不受支持"
 
@@ -80735,10 +80804,6 @@ msgstr "未知的 TLS 模型 %qs"
 #~ msgid "lambda-expression in unevaluated context"
 #~ msgstr "已经在 Lambda 表达式中捕获了%<this%>"
 
-#, fuzzy
-#~ msgid "lambda-expression in template-argument"
-#~ msgstr "为 lambda 形参指定了默认参数"
-
 #, fuzzy
 #~ msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 #~ msgstr "range-based %<for%> 运算式的类型 %qT 有 %<end%>成员并不是 %<begin%>"
diff --git a/gcc/po/zh_TW.po b/gcc/po/zh_TW.po
index 9f27ea2fabb4d..84879751b57aa 100644
--- a/gcc/po/zh_TW.po
+++ b/gcc/po/zh_TW.po
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2021-03-19 21:31+0000\n"
+"POT-Creation-Date: 2021-04-20 18:19+0000\n"
 "PO-Revision-Date: 2020-11-19 00:56+0800\n"
 "Last-Translator: Yi-Jyun Pan <pan93412@gmail.com>\n"
 "Language-Team: Chinese (traditional) <zh-l10n@lists.linux.org.tw>\n"
@@ -1257,13 +1257,13 @@ msgstr "    從 %qs 內聯"
 msgid "this is the insn:"
 msgstr "這是指令："
 
-#: lra-constraints.c:3103
+#: lra-constraints.c:3108
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "無法產生重新載入，為："
 
-#: lra-constraints.c:4133 reload.c:3862
+#: lra-constraints.c:4138 reload.c:3868
 msgid "unable to generate reloads for:"
 msgstr "無法產生重新載入，為："
 
@@ -1440,18 +1440,18 @@ msgstr "無法辨識的指令："
 msgid "insn does not satisfy its constraints:"
 msgstr "指令不滿足其約束："
 
-#: targhooks.c:2075
+#: targhooks.c:2089
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "建立和使用時使用了不同的「%s」設定"
 
-#: targhooks.c:2090
+#: targhooks.c:2104
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "建立和使用時使用了不同的 -fpic 設定"
 
-#: targhooks.c:2092
+#: targhooks.c:2106
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -1491,7 +1491,7 @@ msgstr "%s%s警告：%s 標頭檔版本 %s 與函式庫版本 %s 不同。\n"
 msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 msgstr "%s%sGGC 準則：--param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:6041 c/c-typeck.c:7780 cp/error.c:1111
+#: tree-diagnostic.c:299 c/c-decl.c:6040 c/c-typeck.c:7840 cp/error.c:1111
 #: tree-diagnostic-path.cc:257 c-family/c-pretty-print.c:424
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1950,86 +1950,86 @@ msgstr "strfmon 格式的長度修飾符"
 msgid "<command-line>"
 msgstr "<命令列>"
 
-#: config/aarch64/aarch64.c:10259
+#: config/aarch64/aarch64.c:10663
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "「%c」代碼不支援的運算元"
 
-#: config/aarch64/aarch64.c:10268 config/aarch64/aarch64.c:10281
-#: config/aarch64/aarch64.c:10293 config/aarch64/aarch64.c:10304
-#: config/aarch64/aarch64.c:10320 config/aarch64/aarch64.c:10334
-#: config/aarch64/aarch64.c:10354 config/aarch64/aarch64.c:10428
-#: config/aarch64/aarch64.c:10439 config/aarch64/aarch64.c:10453
-#: config/aarch64/aarch64.c:10675 config/aarch64/aarch64.c:10693
+#: config/aarch64/aarch64.c:10672 config/aarch64/aarch64.c:10685
+#: config/aarch64/aarch64.c:10697 config/aarch64/aarch64.c:10708
+#: config/aarch64/aarch64.c:10724 config/aarch64/aarch64.c:10738
+#: config/aarch64/aarch64.c:10758 config/aarch64/aarch64.c:10832
+#: config/aarch64/aarch64.c:10843 config/aarch64/aarch64.c:10857
+#: config/aarch64/aarch64.c:11079 config/aarch64/aarch64.c:11097
 #: config/pru/pru.c:1669 config/pru/pru.c:1679 config/pru/pru.c:1710
 #: config/pru/pru.c:1721 config/pru/pru.c:1793
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "「%%%c」的運算元無效"
 
-#: config/aarch64/aarch64.c:10372 config/aarch64/aarch64.c:10383
-#: config/aarch64/aarch64.c:10535 config/aarch64/aarch64.c:10546
+#: config/aarch64/aarch64.c:10776 config/aarch64/aarch64.c:10787
+#: config/aarch64/aarch64.c:10939 config/aarch64/aarch64.c:10950
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "無效指令："
 
-#: config/aarch64/aarch64.c:10395 config/aarch64/aarch64.c:10407
+#: config/aarch64/aarch64.c:10799 config/aarch64/aarch64.c:10811
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10421
+#: config/aarch64/aarch64.c:10825
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "「%%%c」的寄存器運算元不相容"
 
-#: config/aarch64/aarch64.c:10487 config/arm/arm.c:24289
+#: config/aarch64/aarch64.c:10891 config/arm/arm.c:24308
 #, c-format
 msgid "missing operand"
 msgstr "缺少運算元"
 
-#: config/aarch64/aarch64.c:10572
+#: config/aarch64/aarch64.c:10976
 #, c-format
 msgid "invalid constant"
 msgstr "常數無效"
 
-#: config/aarch64/aarch64.c:10575
+#: config/aarch64/aarch64.c:10979
 #, c-format
 msgid "invalid operand"
 msgstr "運算元無效"
 
-#: config/aarch64/aarch64.c:10701 config/aarch64/aarch64.c:10706
+#: config/aarch64/aarch64.c:11105 config/aarch64/aarch64.c:11110
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "無效的運算元前綴「%%%c」"
 
-#: config/aarch64/aarch64.c:10726
+#: config/aarch64/aarch64.c:11130
 #, c-format
 msgid "invalid address mode"
 msgstr "無效的定址模式"
 
-#: config/aarch64/aarch64.c:23568 config/arm/arm.c:33644
+#: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/aarch64/aarch64.c:23570 config/arm/arm.c:33646
+#: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/aarch64/aarch64.c:23585 config/aarch64/aarch64.c:23601
-#: config/arm/arm.c:33661 config/arm/arm.c:33677
+#: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
+#: config/arm/arm.c:33677 config/arm/arm.c:33693
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23609
+#: config/aarch64/aarch64.c:25252
 #, fuzzy
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "無效的運算元在中二進運算"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
-#: config/rs6000/rs6000.c:14054 config/sparc/sparc.c:9323
+#: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
 #, fuzzy, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "『%%&』使用的而無需任何本地動態 TLS 參考"
@@ -2045,18 +2045,18 @@ msgid "invalid %%r value"
 msgstr "無效 %%r 值"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:13748 config/xtensa/xtensa.c:2459
+#: config/rs6000/rs6000.c:13841 config/xtensa/xtensa.c:2459
 #, c-format
 msgid "invalid %%R value"
 msgstr "無效 %%R 值"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13668
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13761
 #: config/xtensa/xtensa.c:2426
 #, c-format
 msgid "invalid %%N value"
 msgstr "無效 %%N 值"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13696
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13789
 #, c-format
 msgid "invalid %%P value"
 msgstr "無效 %%P 值"
@@ -2086,7 +2086,7 @@ msgstr "無效 %%M 值"
 msgid "invalid %%U value"
 msgstr "無效 %%U 值"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13756
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13849
 #, c-format
 msgid "invalid %%s value"
 msgstr "無效 %%s 值"
@@ -2096,7 +2096,7 @@ msgstr "無效 %%s 值"
 msgid "invalid %%C value"
 msgstr "無效 %%C 值"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13532
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:13625
 #, c-format
 msgid "invalid %%E value"
 msgstr "無效 %%E 值"
@@ -2109,7 +2109,7 @@ msgstr "不明的不可預期重定位"
 #: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5799
 #: config/gcn/gcn.c:5808 config/gcn/gcn.c:5868 config/gcn/gcn.c:5876
 #: config/gcn/gcn.c:5892 config/gcn/gcn.c:5910 config/gcn/gcn.c:5961
-#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14059
+#: config/gcn/gcn.c:6080 config/gcn/gcn.c:6191 config/rs6000/rs6000.c:14152
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無效的 %%xn 程式碼"
@@ -2197,35 +2197,35 @@ msgstr "無效的 UNSPEC 做為運算元"
 msgid "unrecognized supposed constant"
 msgstr "預期的常數無法識別"
 
-#: config/arm/arm.c:20653 config/arm/arm.c:20678 config/arm/arm.c:20688
-#: config/arm/arm.c:20697 config/arm/arm.c:20706
+#: config/arm/arm.c:20672 config/arm/arm.c:20697 config/arm/arm.c:20707
+#: config/arm/arm.c:20716 config/arm/arm.c:20725
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "無效的 Shift 運算元"
 
-#: config/arm/arm.c:23562 config/arm/arm.c:23580
+#: config/arm/arm.c:23581 config/arm/arm.c:23599
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "預測到的 Thumb 指令"
 
-#: config/arm/arm.c:23568
+#: config/arm/arm.c:23587
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在條件序列中預測到的指令"
 
-#: config/arm/arm.c:23686 config/arm/arm.c:23699 config/arm/arm.c:23724
+#: config/arm/arm.c:23705 config/arm/arm.c:23718 config/arm/arm.c:23743
 #: config/nios2/nios2.c:3080
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
 
-#: config/arm/arm.c:23801 config/arm/arm.c:23823 config/arm/arm.c:23833
-#: config/arm/arm.c:23843 config/arm/arm.c:23853 config/arm/arm.c:23892
-#: config/arm/arm.c:23910 config/arm/arm.c:23935 config/arm/arm.c:23950
-#: config/arm/arm.c:23977 config/arm/arm.c:23984 config/arm/arm.c:24002
-#: config/arm/arm.c:24009 config/arm/arm.c:24017 config/arm/arm.c:24038
-#: config/arm/arm.c:24045 config/arm/arm.c:24236 config/arm/arm.c:24243
-#: config/arm/arm.c:24270 config/arm/arm.c:24277 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23820 config/arm/arm.c:23842 config/arm/arm.c:23852
+#: config/arm/arm.c:23862 config/arm/arm.c:23872 config/arm/arm.c:23911
+#: config/arm/arm.c:23929 config/arm/arm.c:23954 config/arm/arm.c:23969
+#: config/arm/arm.c:23996 config/arm/arm.c:24003 config/arm/arm.c:24021
+#: config/arm/arm.c:24028 config/arm/arm.c:24036 config/arm/arm.c:24057
+#: config/arm/arm.c:24064 config/arm/arm.c:24255 config/arm/arm.c:24262
+#: config/arm/arm.c:24289 config/arm/arm.c:24296 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2233,13 +2233,13 @@ msgstr "不受支援的運算元用於編碼『%c』"
 msgid "invalid operand for code '%c'"
 msgstr "程式碼「%c」的運算元無效"
 
-#: config/arm/arm.c:23905
+#: config/arm/arm.c:23924
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "指令永不執行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23926
+#: config/arm/arm.c:23945
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
@@ -2366,8 +2366,8 @@ msgstr "非預期的運算元"
 
 #: config/cris/cris.c:775 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3625 final.c:3627 fold-const.c:267 gcc.c:6030 gcc.c:6044
-#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6928
-#: d/dmd/dsymbolsem.c:1450 d/dmd/semantic2.c:75 lto/lto-object.c:184
+#: rtl-error.c:101 toplev.c:327 vr-values.c:2370 cp/typeck.c:6939
+#: d/dmd/dsymbolsem.c:1451 d/dmd/semantic2.c:75 lto/lto-object.c:184
 #: lto/lto-object.c:281 lto/lto-object.c:338 lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
 msgid "%s"
@@ -2735,7 +2735,7 @@ msgstr "對 %<__fpreg%> 的作業無效"
 msgid "invalid %%P operand"
 msgstr "無效的 %%P 運算元"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13686
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13779
 #, c-format
 msgid "invalid %%p value"
 msgstr "無效的 %%p 值"
@@ -2792,7 +2792,7 @@ msgid "post-increment address is not a register"
 msgstr "後自增位址不是一個暫存器"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:20528
+#: config/rs6000/rs6000.c:20645
 msgid "bad address"
 msgstr "錯誤位址"
 
@@ -2845,8 +2845,8 @@ msgstr "『%%%c』並非有效運算元前綴"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3326 config/riscv/riscv.c:3441
-#: config/riscv/riscv.c:3447 config/riscv/riscv.c:3456
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3335 config/riscv/riscv.c:3450
+#: config/riscv/riscv.c:3456 config/riscv/riscv.c:3465
 #, fuzzy, c-format
 msgid "invalid use of '%%%c'"
 msgstr "無效的使用的『%%%c』"
@@ -2986,317 +2986,317 @@ msgstr "堆疊溢出。\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "嘗試在命令解譯器中執行「%s」以提升它的極值。\n"
 
-#: config/rs6000/rs6000.c:3851
+#: config/rs6000/rs6000.c:3855
 #, fuzzy
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx 需求硬體浮點數"
 
-#: config/rs6000/rs6000.c:3859
+#: config/rs6000/rs6000.c:3863
 #, fuzzy
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "-mvsx 需要索引的定址"
 
-#: config/rs6000/rs6000.c:3864
+#: config/rs6000/rs6000.c:3868
 #, fuzzy
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx 和 -mno-altivec 是不相容的"
 
-#: config/rs6000/rs6000.c:3866
+#: config/rs6000/rs6000.c:3870
 #, fuzzy
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec 停用 vsx"
 
-#: config/rs6000/rs6000.c:4006
+#: config/rs6000/rs6000.c:4010
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<-mquad-memory%> 需要 64 位元模式"
 
-#: config/rs6000/rs6000.c:4009
+#: config/rs6000/rs6000.c:4013
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> 需要 64 位元模式"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4025
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> 無法在低位位元組在前模式中使用"
 
-#: config/rs6000/rs6000.c:10752
+#: config/rs6000/rs6000.c:10845
 #, fuzzy
 msgid "bad move"
 msgstr "不當的移動"
 
-#: config/rs6000/rs6000.c:13316
+#: config/rs6000/rs6000.c:13409
 msgid "Bad 128-bit move"
 msgstr "錯誤 128 位元移動"
 
-#: config/rs6000/rs6000.c:13496
+#: config/rs6000/rs6000.c:13589
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "無效 %%J 值"
 
-#: config/rs6000/rs6000.c:13505 config/xtensa/xtensa.c:2402
+#: config/rs6000/rs6000.c:13598 config/xtensa/xtensa.c:2402
 #, c-format
 msgid "invalid %%D value"
 msgstr "無效的 %%D 值"
 
-#: config/rs6000/rs6000.c:13520
+#: config/rs6000/rs6000.c:13613
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:13541
+#: config/rs6000/rs6000.c:13634
 #, c-format
 msgid "invalid %%f value"
 msgstr "無效 %%f 值"
 
-#: config/rs6000/rs6000.c:13550
+#: config/rs6000/rs6000.c:13643
 #, c-format
 msgid "invalid %%F value"
 msgstr "無效 %%F 值"
 
-#: config/rs6000/rs6000.c:13559
+#: config/rs6000/rs6000.c:13652
 #, c-format
 msgid "invalid %%G value"
 msgstr "無效 %%G 值"
 
-#: config/rs6000/rs6000.c:13594
+#: config/rs6000/rs6000.c:13687
 #, c-format
 msgid "invalid %%j code"
 msgstr "無效 %%j 程式碼"
 
-#: config/rs6000/rs6000.c:13604
+#: config/rs6000/rs6000.c:13697
 #, c-format
 msgid "invalid %%J code"
 msgstr "無效 %%J 程式碼"
 
-#: config/rs6000/rs6000.c:13614
+#: config/rs6000/rs6000.c:13707
 #, c-format
 msgid "invalid %%k value"
 msgstr "無效 %%k 值"
 
-#: config/rs6000/rs6000.c:13629 config/xtensa/xtensa.c:2445
+#: config/rs6000/rs6000.c:13722 config/xtensa/xtensa.c:2445
 #, c-format
 msgid "invalid %%K value"
 msgstr "無效 %%K 值"
 
-#: config/rs6000/rs6000.c:13676
+#: config/rs6000/rs6000.c:13769
 #, c-format
 msgid "invalid %%O value"
 msgstr "無效 %%O 值"
 
-#: config/rs6000/rs6000.c:13723
+#: config/rs6000/rs6000.c:13816
 #, c-format
 msgid "invalid %%q value"
 msgstr "無效 %%q 值"
 
-#: config/rs6000/rs6000.c:13765
+#: config/rs6000/rs6000.c:13858
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:13782
+#: config/rs6000/rs6000.c:13875
 #, c-format
 msgid "invalid %%T value"
 msgstr "無效 %%T 值"
 
-#: config/rs6000/rs6000.c:13794
+#: config/rs6000/rs6000.c:13887
 #, c-format
 msgid "invalid %%u value"
 msgstr "無效 %%u 值"
 
-#: config/rs6000/rs6000.c:13808 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:13901 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%v value"
 msgstr "無效 %%v 值"
 
-#: config/rs6000/rs6000.c:13858
+#: config/rs6000/rs6000.c:13951
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:13875 config/xtensa/xtensa.c:2466
+#: config/rs6000/rs6000.c:13968 config/xtensa/xtensa.c:2466
 #, c-format
 msgid "invalid %%x value"
 msgstr "無效的 %%x 值"
 
-#: config/rs6000/rs6000.c:13932
+#: config/rs6000/rs6000.c:14025
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:14001
+#: config/rs6000/rs6000.c:14094
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無效的 %%y 值，嘗試使用『Z』條件約束"
 
-#: config/rs6000/rs6000.c:14845
+#: config/rs6000/rs6000.c:14962
 #, fuzzy
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "啟用 32-bit multiply 指令"
 
-#: config/rs6000/rs6000.c:23803
+#: config/rs6000/rs6000.c:23920
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/rs6000/rs6000.c:26952
+#: config/rs6000/rs6000.c:27071
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "不為每個函式產生單一的離開點"
 
-#: config/rs6000/rs6000.c:27021
+#: config/rs6000/rs6000.c:27140
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "無法產生重新載入，為："
 
-#: config/rs6000/rs6000.c:27097
+#: config/rs6000/rs6000.c:27216
 msgid "Bad GPR fusion"
 msgstr "錯誤 GPR 融合"
 
-#: config/rs6000/rs6000.c:27657
+#: config/rs6000/rs6000.c:27776
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/rs6000/rs6000.c:27659
+#: config/rs6000/rs6000.c:27778
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/rs6000/rs6000.c:27661
+#: config/rs6000/rs6000.c:27780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "從 %<__fpreg%> 的轉換無效"
 
-#: config/rs6000/rs6000.c:27663
+#: config/rs6000/rs6000.c:27782
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "向 %<__fpreg%> 的轉換無效"
 
-#: config/rs6000/rs6000.c:27678
+#: config/rs6000/rs6000.c:27797
 #, fuzzy
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/rs6000/rs6000.c:27680
+#: config/rs6000/rs6000.c:27799
 #, fuzzy
 msgid "invalid conversion to type %<* __vector_quad%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/rs6000/rs6000.c:27682
+#: config/rs6000/rs6000.c:27801
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "從 %<__fpreg%> 的轉換無效"
 
-#: config/rs6000/rs6000.c:27684
+#: config/rs6000/rs6000.c:27803
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "向 %<__fpreg%> 的轉換無效"
 
-#: config/s390/s390.c:7884
+#: config/s390/s390.c:7907
 #, fuzzy, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "符號記憶體參考是只有支援的於 z10 或稍後"
 
-#: config/s390/s390.c:7895
+#: config/s390/s390.c:7918
 #, c-format
 msgid "cannot decompose address"
 msgstr "無法分解位址"
 
-#: config/s390/s390.c:7976
+#: config/s390/s390.c:7999
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "無效的比較運算子用於『E』輸出修飾鍵"
 
-#: config/s390/s390.c:7999
+#: config/s390/s390.c:8022
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "無效的參考用於『J』輸出修飾鍵"
 
-#: config/s390/s390.c:8017
+#: config/s390/s390.c:8040
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "無效的位址用於『O』輸出修飾鍵"
 
-#: config/s390/s390.c:8039
+#: config/s390/s390.c:8062
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "無效的位址用於『R』輸出修飾鍵"
 
-#: config/s390/s390.c:8057
+#: config/s390/s390.c:8080
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "記憶體參考預期的用於『S』輸出修飾鍵"
 
-#: config/s390/s390.c:8067
+#: config/s390/s390.c:8090
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "無效的位址用於『S』輸出修飾鍵"
 
-#: config/s390/s390.c:8088
+#: config/s390/s390.c:8111
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "暫存器或記憶體運算式預期的用於『N』輸出修飾鍵"
 
-#: config/s390/s390.c:8099
+#: config/s390/s390.c:8122
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "暫存器或記憶體運算式預期的用於『公尺』輸出修飾鍵"
 
-#: config/s390/s390.c:8185 config/s390/s390.c:8206
+#: config/s390/s390.c:8208 config/s390/s390.c:8229
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "無效的常數用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.c:8203
+#: config/s390/s390.c:8226
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "無效的常數 - 嘗試使用輸出修飾鍵"
 
-#: config/s390/s390.c:8240
+#: config/s390/s390.c:8263
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "無效的常數用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.c:8247
+#: config/s390/s390.c:8270
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "無效的運算式 - 嘗試使用輸出修飾鍵"
 
-#: config/s390/s390.c:8250
+#: config/s390/s390.c:8273
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "無效的運算式用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.c:12029
+#: config/s390/s390.c:12052
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/s390/s390.c:16403
+#: config/s390/s390.c:16426
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "回傳指標時目的與指標有/無號不一致"
 
-#: config/s390/s390.c:16413
+#: config/s390/s390.c:16436
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16416
+#: config/s390/s390.c:16439
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16424
+#: config/s390/s390.c:16447
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3567,8 +3567,8 @@ msgstr "({匿名})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3274 c/c-parser.c:3461
 #: c/c-parser.c:3494 c/c-parser.c:11268 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:14380 cp/parser.c:31016
-#: cp/parser.c:31626
+#: c/gimple-parser.c:2066 cp/parser.c:14404 cp/parser.c:31070
+#: cp/parser.c:31680
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要 %<;%>"
@@ -3588,7 +3588,7 @@ msgstr "需要 %<;%>"
 #: c/gimple-parser.c:1470 c/gimple-parser.c:1492 c/gimple-parser.c:1522
 #: c/gimple-parser.c:1548 c/gimple-parser.c:1756 c/gimple-parser.c:1949
 #: c/gimple-parser.c:1969 c/gimple-parser.c:2103 c/gimple-parser.c:2266
-#: c/c-parser.c:7110 cp/parser.c:31674
+#: c/c-parser.c:7110 cp/parser.c:31728
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "預期 %<)%>"
@@ -3596,7 +3596,7 @@ msgstr "預期 %<)%>"
 #: c/c-parser.c:4103 c/c-parser.c:4835 c/c-parser.c:4976 c/c-parser.c:5002
 #: c/c-parser.c:5003 c/c-parser.c:5417 c/c-parser.c:5453 c/c-parser.c:7209
 #: c/c-parser.c:9233 c/c-parser.c:10123 c/c-parser.c:10412 c/c-parser.c:13085
-#: c/gimple-parser.c:1733 cp/parser.c:31638
+#: c/gimple-parser.c:1733 cp/parser.c:31692
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "預期 %<]%>"
@@ -3615,21 +3615,21 @@ msgstr "預期 %<;%>，%<,%>或 %<)%>"
 #: c/gimple-parser.c:1428 c/gimple-parser.c:1488 c/gimple-parser.c:1506
 #: c/gimple-parser.c:1541 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13443 cp/parser.c:31629
+#: c/c-parser.c:13443 cp/parser.c:31683
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "預期 %<(%>"
 
-#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31641
-#: cp/parser.c:35326
+#: c/c-parser.c:4972 c/c-parser.c:4974 c/c-parser.c:13013 cp/parser.c:31695
+#: cp/parser.c:35379
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "預期 %<[%>"
 
 #: c/c-parser.c:5588 c/c-parser.c:11611 c/c-parser.c:18127 c/c-parser.c:18941
 #: c/c-parser.c:22005 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19941
-#: cp/parser.c:31635
+#: c/c-parser.c:3262 c/c-parser.c:3484 c/c-parser.c:11163 cp/parser.c:19978
+#: cp/parser.c:31689
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要 %<{%>"
@@ -3640,13 +3640,13 @@ msgstr "需要 %<{%>"
 #: c/c-parser.c:15155 c/c-parser.c:15468 c/c-parser.c:15595 c/c-parser.c:20368
 #: c/c-parser.c:21010 c/c-parser.c:21069 c/gimple-parser.c:568
 #: c/gimple-parser.c:872 c/gimple-parser.c:2317 c/gimple-parser.c:2344
-#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31668
-#: cp/parser.c:33316 cp/parser.c:36125 cp/parser.c:36909
+#: c/c-parser.c:7117 c/c-parser.c:13546 c/c-parser.c:14793 cp/parser.c:31722
+#: cp/parser.c:33370 cp/parser.c:36178 cp/parser.c:36962
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "預期 %<:%>"
 
-#: c/c-parser.c:6667 cp/parser.c:31555
+#: c/c-parser.c:6667 cp/parser.c:31609
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "預期 %<while%>"
@@ -3655,7 +3655,7 @@ msgstr "預期 %<while%>"
 #: c/c-parser.c:9304 c/c-parser.c:10015 c/c-parser.c:14374 c/c-parser.c:15551
 #: c/gimple-parser.c:1022 c/gimple-parser.c:1048 c/gimple-parser.c:1176
 #: c/gimple-parser.c:1179 c/gimple-parser.c:1510 c/gimple-parser.c:1516
-#: cp/parser.c:31014 cp/parser.c:31644
+#: cp/parser.c:31068 cp/parser.c:31698
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "預期 %<,%>"
@@ -3665,18 +3665,18 @@ msgstr "預期 %<,%>"
 msgid "expected %<.%>"
 msgstr "預期 %<.%>"
 
-#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33890
-#: cp/parser.c:33911
+#: c/c-parser.c:10834 c/c-parser.c:10866 c/c-parser.c:11106 cp/parser.c:33944
+#: cp/parser.c:33965
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "預期 %<@end%>"
 
-#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31653
+#: c/c-parser.c:11524 c/gimple-parser.c:1346 cp/parser.c:31707
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "預期 %<>%>"
 
-#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31677
+#: c/c-parser.c:14882 c/c-parser.c:15832 cp/parser.c:31731
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "預期 %<,%>或 %<)%>"
@@ -3684,29 +3684,29 @@ msgstr "預期 %<,%>或 %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15460 c/c-parser.c:17592 c/c-parser.c:17636 c/c-parser.c:17868
 #: c/c-parser.c:18311 c/c-parser.c:20575 c/c-parser.c:21207
-#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31656
+#: c/gimple-parser.c:726 c/c-parser.c:5476 cp/parser.c:31710
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要 %<=%>"
 
 #: c/c-parser.c:17884 c/c-parser.c:18175 c/gimple-parser.c:1564
 #: c/gimple-parser.c:1596 c/gimple-parser.c:1606 c/gimple-parser.c:2354
-#: cp/parser.c:31632 cp/parser.c:34100
+#: cp/parser.c:31686 cp/parser.c:34154
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "預期 %<}%>"
 
-#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40913
+#: c/c-parser.c:18984 c/c-parser.c:18974 cp/parser.c:40966
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8430
 #, fuzzy
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:1335 cp/parser.c:17360 cp/parser.c:31650
+#: c/gimple-parser.c:1335 cp/parser.c:17388 cp/parser.c:31704
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "預期 %<<%>"
@@ -3723,30 +3723,30 @@ msgstr "預期的頻道"
 msgid "candidate:"
 msgstr "備選 1："
 
-#: cp/call.c:7407
+#: cp/call.c:7411
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "啟用使用者定義的指令"
 
-#: cp/call.c:7545 cp/pt.c:2044 cp/pt.c:25058
+#: cp/call.c:7549 cp/pt.c:2046 cp/pt.c:25145
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "candidate 是："
 
-#: cp/call.c:12092
+#: cp/call.c:12113
 msgid "candidate 1:"
 msgstr "備選 1："
 
-#: cp/call.c:12093
+#: cp/call.c:12114
 msgid "candidate 2:"
 msgstr "備選 2："
 
-#: cp/decl.c:3392
+#: cp/decl.c:3374
 msgid "jump to label %qD"
 msgstr "跳轉至標籤 %qD"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3375
 msgid "jump to case label"
 msgstr "跳轉至 case 標籤"
 
@@ -4000,31 +4000,31 @@ msgstr "局部變數 %qD 不應出現在此上下文中"
 msgid "local variable %qD may not appear in this context"
 msgstr "局部變數 %qD 不應出現在此上下文中"
 
-#: cp/parser.c:20737
+#: cp/parser.c:20774
 #, fuzzy
 msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:20740
+#: cp/parser.c:20777
 #, fuzzy
 msgid "%<using enum%> of dependent type %qT"
 msgstr "無效的使用的附屬型態 %qT"
 
-#: cp/parser.c:20742
+#: cp/parser.c:20779
 #, fuzzy
 msgid "%<using enum%> of non-enumeration type %q#T"
 msgstr "%qT 不是列舉類型型態"
 
-#: cp/parser.c:20744
+#: cp/parser.c:20781
 #, fuzzy
 msgid "%<using enum%> of incomplete type %qT"
 msgstr "無效的使用的不完整型態 %q#T"
 
-#: cp/parser.c:20746
+#: cp/parser.c:20783
 msgid "%<using enum%> of %qT before its enum-specifier"
 msgstr ""
 
-#: cp/pt.c:2042 cp/semantics.c:5713
+#: cp/pt.c:2044 cp/semantics.c:5741
 msgid "candidates are:"
 msgstr "備選為："
 
@@ -4078,52 +4078,52 @@ msgstr "轉換演員陣容暫離 constness"
 msgid "source type is not polymorphic"
 msgstr "來源型態不是 polymorphic"
 
-#: cp/typeck.c:6633 c/c-typeck.c:4406
+#: cp/typeck.c:6644 c/c-typeck.c:4466
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "單位元減的運算元類型錯誤"
 
-#: cp/typeck.c:6634 c/c-typeck.c:4393
+#: cp/typeck.c:6645 c/c-typeck.c:4453
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "單位元加的運算元類型錯誤"
 
-#: cp/typeck.c:6661 c/c-typeck.c:4450
+#: cp/typeck.c:6672 c/c-typeck.c:4510
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的引數類型錯誤"
 
-#: cp/typeck.c:6678 c/c-typeck.c:4458
+#: cp/typeck.c:6689 c/c-typeck.c:4518
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能對該類型的引數求絕對值"
 
-#: cp/typeck.c:6690 c/c-typeck.c:4480
+#: cp/typeck.c:6701 c/c-typeck.c:4540
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能對該類型的引數求共軛"
 
-#: cp/typeck.c:6708
+#: cp/typeck.c:6719
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "在中引數到一元！"
 
-#: cp/typeck.c:6754
+#: cp/typeck.c:6765
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "沒有 pre-increment 運算子用於型態"
 
-#: cp/typeck.c:6756
+#: cp/typeck.c:6767
 #, fuzzy
 msgid "no post-increment operator for type"
 msgstr "沒有 post-increment 運算子用於型態"
 
-#: cp/typeck.c:6758
+#: cp/typeck.c:6769
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "沒有 pre-decrement 運算子用於型態"
 
-#: cp/typeck.c:6760
+#: cp/typeck.c:6771
 #, fuzzy
 msgid "no post-decrement operator for type"
 msgstr "沒有 post-decrement 運算子用於型態"
@@ -4230,7 +4230,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "驅動："
 
-#: fortran/interface.c:3421 fortran/intrinsic.c:4498
+#: fortran/interface.c:3427 fortran/intrinsic.c:4498
 #, fuzzy
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "實際引數到含義=出/INOUT"
@@ -4375,7 +4375,7 @@ msgstr "錯誤的運算子"
 msgid "Bad type in constant expression"
 msgstr "常數運算式中類型錯誤"
 
-#: fortran/module.c:7303
+#: fortran/module.c:7314
 msgid "Unexpected end of module"
 msgstr "非預期的模組結束"
 
@@ -4403,11 +4403,11 @@ msgstr "區塊 IF"
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:2139 fortran/resolve.c:11928
+#: fortran/parse.c:2139 fortran/resolve.c:11936
 msgid "assignment"
 msgstr "賦值"
 
-#: fortran/parse.c:2142 fortran/resolve.c:11980 fortran/resolve.c:11983
+#: fortran/parse.c:2142 fortran/resolve.c:11988 fortran/resolve.c:11991
 msgid "pointer assignment"
 msgstr "指標賦值"
 
@@ -4513,172 +4513,172 @@ msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 msgid "bind(c) procedure"
 msgstr "模組程序"
 
-#: fortran/resolve.c:4050
+#: fortran/resolve.c:4052
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4069
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "單位元數值運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.c:4083
+#: fortran/resolve.c:4086
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4088
+#: fortran/resolve.c:4091
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "二元數值運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4103
+#: fortran/resolve.c:4106
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字串粘貼運算子(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4149
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "邏輯運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4168
+#: fortran/resolve.c:4172
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "運算元的.not。運算子於 %%L 是 %s"
 
-#: fortran/resolve.c:4182
+#: fortran/resolve.c:4186
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L 處複數不能比較大小"
 
-#: fortran/resolve.c:4280
+#: fortran/resolve.c:4284
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L 處邏輯值必須與 %s 比較，而不是 %s"
 
-#: fortran/resolve.c:4286
+#: fortran/resolve.c:4290
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "比較運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4299
+#: fortran/resolve.c:4304
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "不明運算子『%s』於 %%L"
 
-#: fortran/resolve.c:4302
+#: fortran/resolve.c:4307
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "不明運算子『%s』於 %%L"
 
-#: fortran/resolve.c:4305
+#: fortran/resolve.c:4312
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.c:4309
+#: fortran/resolve.c:4317
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4395
+#: fortran/resolve.c:4403
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "不一致分級用於運算子於 %%L 和 %%L"
 
-#: fortran/resolve.c:7234
+#: fortran/resolve.c:7242
 #, fuzzy
 msgid "Loop variable"
 msgstr "迴圈變數"
 
-#: fortran/resolve.c:7238
+#: fortran/resolve.c:7246
 #, fuzzy
 msgid "iterator variable"
 msgstr "迭代器變數"
 
-#: fortran/resolve.c:7242
+#: fortran/resolve.c:7250
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "開始運算式在中做迴圈"
 
-#: fortran/resolve.c:7246
+#: fortran/resolve.c:7254
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "結束運算式在中做迴圈"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7258
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "步驟運算式在中做迴圈"
 
-#: fortran/resolve.c:7536 fortran/resolve.c:7539
+#: fortran/resolve.c:7544 fortran/resolve.c:7547
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "取消配置物件"
 
-#: fortran/resolve.c:7916 fortran/resolve.c:7919
+#: fortran/resolve.c:7924 fortran/resolve.c:7927
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "配置物件"
 
-#: fortran/resolve.c:8152 fortran/resolve.c:10105
+#: fortran/resolve.c:8160 fortran/resolve.c:10113
 #, fuzzy
 msgid "STAT variable"
 msgstr "STAT 變數"
 
-#: fortran/resolve.c:8196 fortran/resolve.c:10117
+#: fortran/resolve.c:8204 fortran/resolve.c:10125
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "ERRMSG 變數"
 
-#: fortran/resolve.c:9911
+#: fortran/resolve.c:9919
 #, fuzzy
 msgid "item in READ"
 msgstr "項目在中讀取"
 
-#: fortran/resolve.c:10129
+#: fortran/resolve.c:10137
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK 變數"
 
-#: fortran/trans-array.c:1750
+#: fortran/trans-array.c:1778
 #, fuzzy, c-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "不同的字元長度 (%ld/%ld) 在中陣列建構子"
 
-#: fortran/trans-array.c:6023
+#: fortran/trans-array.c:5990
 #, fuzzy
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "整數溢位時計算數目的記憶體到配置"
 
-#: fortran/trans-array.c:9788
+#: fortran/trans-array.c:9755
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6235
+#: fortran/trans-decl.c:6240
 #, fuzzy, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "實際的字串長度不匹配宣告的一個用於虛引數『%s』(%ld/%ld)"
 
-#: fortran/trans-decl.c:6243
+#: fortran/trans-decl.c:6248
 #, fuzzy, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "實際的字串長度是短於宣告的一個用於虛引數『%s』(%ld/%ld)"
 
-#: fortran/trans-expr.c:9796
+#: fortran/trans-expr.c:9845
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目標的分級重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.c:11270
+#: fortran/trans-expr.c:11322
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4808,27 +4808,27 @@ msgstr "對陣列的參照超出範圍"
 msgid "Incorrect function return value"
 msgstr "不正確的函式回傳值"
 
-#: fortran/trans.c:714 fortran/trans.c:789
+#: fortran/trans.c:724 fortran/trans.c:799
 #, fuzzy, c-format
 msgid "Error allocating %lu bytes"
 msgstr "記憶體配置失敗"
 
-#: fortran/trans.c:998
+#: fortran/trans.c:1008
 #, fuzzy, c-format
 msgid "Attempting to allocate already allocated variable '%s'"
 msgstr "試圖配置已經配置的變數『%s』"
 
-#: fortran/trans.c:1004
+#: fortran/trans.c:1014
 #, fuzzy
 msgid "Attempting to allocate already allocated variable"
 msgstr "試圖配置已經配置的變數"
 
-#: fortran/trans.c:1454 fortran/trans.c:1613
+#: fortran/trans.c:1464 fortran/trans.c:1623
 #, fuzzy, c-format
 msgid "Attempt to DEALLOCATE unallocated '%s'"
 msgstr "試圖到取消配置 unallocated『%s』"
 
-#: fortran/trans.c:1771
+#: fortran/trans.c:1781
 #, c-format
 msgid "Error reallocating to %lu bytes"
 msgstr ""
@@ -5061,16 +5061,16 @@ msgstr "-Xbind-now 與 -Xbind-lazy 不相容"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
 msgstr "認為使用『-pg』以代替『-p』與 gprof (1)"
 
-#: config/arc/arc.h:68 config/mips/mips.h:1452
+#: config/arc/arc.h:68 config/mips/mips.h:1453
 msgid "may not use both -EB and -EL"
 msgstr "不能同時使用 -EB 和 -EL"
 
-#: config/arm/arm.h:93
+#: config/arm/arm.h:94
 #, fuzzy
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
 msgstr "-mfloat-abi=軟式和 -mfloat-abi=硬可能無法一起使用"
 
-#: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
+#: config/arm/arm.h:96 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
 msgstr "-mbig-endian 和 -mlittle-endian 不能一起使用"
 
@@ -5089,8 +5089,8 @@ msgstr "沒有處理器型態指定的用於鏈結"
 msgid "do not specify both -march=... and -mcpu=..."
 msgstr "不指定兩者 -march=...和 -mcpu=…"
 
-#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:141
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:138
+#: config/i386/mingw-w64.h:95 config/i386/mingw32.h:153
 msgid "shared and mdll are not compatible"
 msgstr "shared 和 mdll 互不相容"
 
@@ -5269,10 +5269,10 @@ msgid "Warn about creation of array temporaries."
 msgstr "警告關於建立的陣列暫時的"
 
 #: fortran/lang.opt:214 fortran/lang.opt:522 config/alpha/alpha.opt:31
-#: common.opt:653 common.opt:791 common.opt:1017 common.opt:1021
-#: common.opt:1025 common.opt:1029 common.opt:1679 common.opt:1735
-#: common.opt:1874 common.opt:1878 common.opt:2116 common.opt:2330
-#: common.opt:3046
+#: common.opt:653 common.opt:791 common.opt:1021 common.opt:1025
+#: common.opt:1029 common.opt:1033 common.opt:1683 common.opt:1739
+#: common.opt:1878 common.opt:1882 common.opt:2120 common.opt:2334
+#: common.opt:3050
 #, fuzzy, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "沒做任何事。保留的用於回溯相容性。"
@@ -5775,164 +5775,164 @@ msgstr "置放所有本地陣列於堆疊。"
 msgid "Set default accessibility of module entities to PRIVATE."
 msgstr "設定預設輔助工具的模組實體到私人的。"
 
-#: fortran/lang.opt:708
+#: fortran/lang.opt:704
 #, fuzzy, no-c-format
 msgid "Try to lay out derived types as compactly as possible."
 msgstr "試著紙規出衍生類型做為壓縮儘可能地"
 
-#: fortran/lang.opt:716
+#: fortran/lang.opt:712
 #, fuzzy, no-c-format
 msgid "Protect parentheses in expressions."
 msgstr "保護 parentheses 在中運算式"
 
-#: fortran/lang.opt:720
+#: fortran/lang.opt:716
 #, no-c-format
 msgid "Path to header file that should be pre-included before each compilation unit."
 msgstr ""
 
-#: fortran/lang.opt:724
+#: fortran/lang.opt:720
 #, fuzzy, no-c-format
 msgid "Enable range checking during compilation."
 msgstr "啟用範圍檢查在的期間編譯"
 
-#: fortran/lang.opt:728
+#: fortran/lang.opt:724
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(4) as a REAL(8)."
 msgstr "解譯任何真實 (4) 做為真實 (8)"
 
-#: fortran/lang.opt:732
+#: fortran/lang.opt:728
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(4) as a REAL(10)."
 msgstr "解譯任何真實 (4) 做為真實 (10)"
 
-#: fortran/lang.opt:736
+#: fortran/lang.opt:732
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(4) as a REAL(16)."
 msgstr "解譯任何真實 (4) 做為真實 (16)"
 
-#: fortran/lang.opt:740
+#: fortran/lang.opt:736
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(8) as a REAL(4)."
 msgstr "解譯任何真實 (8) 做為真實 (4)"
 
-#: fortran/lang.opt:744
+#: fortran/lang.opt:740
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(8) as a REAL(10)."
 msgstr "解譯任何真實 (8) 做為真實 (10)"
 
-#: fortran/lang.opt:748
+#: fortran/lang.opt:744
 #, fuzzy, no-c-format
 msgid "Interpret any REAL(8) as a REAL(16)."
 msgstr "解譯任何真實 (8) 做為真實 (16)"
 
-#: fortran/lang.opt:752
+#: fortran/lang.opt:748
 #, fuzzy, no-c-format
 msgid "Reallocate the LHS in assignments."
 msgstr "Reallocate LHS 在中指派"
 
-#: fortran/lang.opt:756
+#: fortran/lang.opt:752
 #, fuzzy, no-c-format
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "使用 4-byte 條目標記用於 unformatted 檔案"
 
-#: fortran/lang.opt:760
+#: fortran/lang.opt:756
 #, fuzzy, no-c-format
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "使用 8-byte 條目標記用於 unformatted 檔案"
 
-#: fortran/lang.opt:764
+#: fortran/lang.opt:760
 #, fuzzy, no-c-format
 msgid "Allocate local variables on the stack to allow indirect recursion."
 msgstr "配置區域變數在之上堆疊到允許間接遞迴"
 
-#: fortran/lang.opt:768
+#: fortran/lang.opt:764
 #, fuzzy, no-c-format
 msgid "Copy array sections into a contiguous block on procedure entry."
 msgstr "複製陣列區段進入 contiguous 區塊於程序條目"
 
-#: fortran/lang.opt:772
+#: fortran/lang.opt:768
 #, fuzzy, no-c-format
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
 msgstr "-fcoarray=[...]\t指定該項 coarray parallelization 應該被使用"
 
-#: fortran/lang.opt:788
+#: fortran/lang.opt:784
 #, fuzzy, no-c-format
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
 msgstr "-fcheck=[...]\t指定該項執行時檢查是要被施行"
 
-#: fortran/lang.opt:792
+#: fortran/lang.opt:788
 #, fuzzy, no-c-format
 #| msgid "Append a second underscore if the name already contains an underscore"
 msgid "Append a second underscore if the name already contains an underscore."
 msgstr "當名稱已經包含一個底線時加入第二個底線"
 
-#: fortran/lang.opt:800
+#: fortran/lang.opt:796
 #, fuzzy, no-c-format
 msgid "Apply negative sign to zero values."
 msgstr "套用負符號到零值"
 
-#: fortran/lang.opt:807
+#: fortran/lang.opt:803
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
 msgstr ""
 
-#: fortran/lang.opt:811
+#: fortran/lang.opt:807
 #, fuzzy, no-c-format
 #| msgid "Append underscores to externally visible names"
 msgid "Append underscores to externally visible names."
 msgstr "為外部可見的名稱加入底線"
 
-#: fortran/lang.opt:815 c-family/c.opt:1539 c-family/c.opt:1571
-#: c-family/c.opt:1579 c-family/c.opt:1903 config/pa/pa.opt:42
-#: config/pa/pa.opt:74 common.opt:615 common.opt:1099 common.opt:1103
-#: common.opt:1107 common.opt:1194 common.opt:1471 common.opt:1550
-#: common.opt:1826 common.opt:1965 common.opt:2008 common.opt:2405
-#: common.opt:2441 common.opt:2534 common.opt:2538 common.opt:2647
-#: common.opt:2738 common.opt:2746 common.opt:2754 common.opt:2762
-#: common.opt:2863 common.opt:2919 common.opt:3007 common.opt:3151
-#: common.opt:3155 common.opt:3159 common.opt:3163
+#: fortran/lang.opt:811 c-family/c.opt:1539 c-family/c.opt:1571
+#: c-family/c.opt:1579 c-family/c.opt:1890 config/pa/pa.opt:42
+#: config/pa/pa.opt:74 common.opt:615 common.opt:1103 common.opt:1107
+#: common.opt:1111 common.opt:1198 common.opt:1475 common.opt:1554
+#: common.opt:1830 common.opt:1969 common.opt:2012 common.opt:2409
+#: common.opt:2445 common.opt:2538 common.opt:2542 common.opt:2651
+#: common.opt:2742 common.opt:2750 common.opt:2758 common.opt:2766
+#: common.opt:2867 common.opt:2923 common.opt:3011 common.opt:3155
+#: common.opt:3159 common.opt:3163 common.opt:3167
 #, fuzzy, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "沒做任何事。 保留的用於回溯相容性。"
 
-#: fortran/lang.opt:855
+#: fortran/lang.opt:851
 #, fuzzy, no-c-format
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
 msgstr "Statically 鏈結 GNU Fortran 輔助程式函式庫 (libgfortran)"
 
-#: fortran/lang.opt:859
+#: fortran/lang.opt:855
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "遵循 ISO Fortran 2003 標準"
 
-#: fortran/lang.opt:863
+#: fortran/lang.opt:859
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "符合到 ISO Fortran 2008 標準"
 
-#: fortran/lang.opt:867
+#: fortran/lang.opt:863
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "符合到 ISO Fortran 2008 標準包含 TS 29113"
 
-#: fortran/lang.opt:871
+#: fortran/lang.opt:867
 #, fuzzy, no-c-format
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "符合到 ISO Fortran 2008 標準"
 
-#: fortran/lang.opt:875
+#: fortran/lang.opt:871
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO Fortran 95 standard"
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "遵循 ISO Fortran 95 標準"
 
-#: fortran/lang.opt:879
+#: fortran/lang.opt:875
 #, fuzzy, no-c-format
 msgid "Conform to nothing in particular."
 msgstr "符合到沒有任何東西尤其"
 
-#: fortran/lang.opt:883
+#: fortran/lang.opt:879
 #, fuzzy, no-c-format
 #| msgid "Accept extensions to support legacy code"
 msgid "Accept extensions to support legacy code."
@@ -6672,7 +6672,7 @@ msgstr ""
 
 #: c-family/c.opt:803
 #, no-c-format
-msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr ""
 
 #: c-family/c.opt:808
@@ -7349,8 +7349,8 @@ msgstr ""
 msgid "Allow variadic functions without named parameter."
 msgstr "允許 variadic 函式而無需具名參數"
 
-#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2068
-#: c-family/c.opt:2072 c-family/c.opt:2088
+#: c-family/c.opt:1408 c-family/c.opt:1672 c-family/c.opt:2055
+#: c-family/c.opt:2059 c-family/c.opt:2075
 #, fuzzy, no-c-format
 msgid "No longer supported."
 msgstr "不再支援"
@@ -7733,505 +7733,500 @@ msgid "Specify default OpenACC compute dimensions."
 msgstr ""
 
 #: c-family/c.opt:1878
-#, no-c-format
-msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr ""
-
-#: c-family/c.opt:1891
 #, fuzzy, no-c-format
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "啟用 OpenMP (意味著 -frecursive 在中 Fortran)"
 
-#: c-family/c.opt:1895
+#: c-family/c.opt:1882
 #, fuzzy, no-c-format
 msgid "Enable OpenMP's SIMD directives."
 msgstr "Unclassifiable OpenMP 指令於 %C"
 
-#: c-family/c.opt:1899
+#: c-family/c.opt:1886
 #, fuzzy, no-c-format
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "識別 C++關鍵字如同「compl」和「xor」"
 
-#: c-family/c.opt:1910
+#: c-family/c.opt:1897
 #, fuzzy, no-c-format
 #| msgid "Look for and use PCH files even when preprocessing"
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "即使在預先處理時也搜尋並使用 PCH 檔案"
 
-#: c-family/c.opt:1914
+#: c-family/c.opt:1901
 #, fuzzy, no-c-format
 #| msgid "Downgrade conformance errors to warnings"
 msgid "Downgrade conformance errors to warnings."
 msgstr "將相容性錯誤降格為警告"
 
-#: c-family/c.opt:1918
+#: c-family/c.opt:1905
 #, fuzzy, no-c-format
 msgid "Enable Plan 9 language extensions."
 msgstr "啟用 Plan 9 語言延伸"
 
-#: c-family/c.opt:1922
+#: c-family/c.opt:1909
 #, fuzzy, no-c-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "Treat the input file as already preprocessed."
 msgstr "將輸入檔案當作已經預先處理過的"
 
-#: c-family/c.opt:1930
+#: c-family/c.opt:1917
 #, fuzzy, no-c-format
 msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
 msgstr "-ftrack-macro-expansion=<0|1|2> 軌段位置的字組來自巨集展開和顯示它們在中錯誤訊息"
 
-#: c-family/c.opt:1934
+#: c-family/c.opt:1921
 #, fuzzy, no-c-format
 msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
 msgstr "-fno-pretty-templates 不優質列印模板特殊化做為模板簽名在之後引數"
 
-#: c-family/c.opt:1938
+#: c-family/c.opt:1925
 #, no-c-format
 msgid "Treat known sprintf return values as constants."
 msgstr ""
 
-#: c-family/c.opt:1942
+#: c-family/c.opt:1929
 #, fuzzy, no-c-format
 #| msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime"
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
 msgstr "指定物件檔案可能在執行時被換入以允許「修復並繼續」除錯模式"
 
-#: c-family/c.opt:1946
+#: c-family/c.opt:1933
 #, fuzzy, no-c-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "已過時。此開關不起作用。"
 
-#: c-family/c.opt:1950
+#: c-family/c.opt:1937
 #, fuzzy, no-c-format
 #| msgid "Generate run time type descriptor information"
 msgid "Generate run time type descriptor information."
 msgstr "產生執行時類型描述資訊"
 
-#: c-family/c.opt:1954 ada/gcc-interface/lang.opt:81
+#: c-family/c.opt:1941 ada/gcc-interface/lang.opt:81
 #, fuzzy, no-c-format
 #| msgid "Use the narrowest integer type possible for enumeration types"
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "為列舉類型使用盡可能窄的整數類型"
 
-#: c-family/c.opt:1958
+#: c-family/c.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\""
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "強制指定「wchar_t」的內在類型為「unsigned short」"
 
-#: c-family/c.opt:1962
+#: c-family/c.opt:1949
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "沒有給定「signed」或「unsigned」時將位元段視作有號的"
 
-#: c-family/c.opt:1966 ada/gcc-interface/lang.opt:85
+#: c-family/c.opt:1953 ada/gcc-interface/lang.opt:85
 #, fuzzy, no-c-format
 #| msgid "Make \"char\" signed by default"
 msgid "Make \"char\" signed by default."
 msgstr "使「char」類型預設為有號"
 
-#: c-family/c.opt:1970
+#: c-family/c.opt:1957
 #, fuzzy, no-c-format
 msgid "Enable C++14 sized deallocation support."
 msgstr "啟用十進位浮點數硬體支援"
 
-#: c-family/c.opt:1977
+#: c-family/c.opt:1964
 #, no-c-format
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
 msgstr ""
 
-#: c-family/c.opt:1993
+#: c-family/c.opt:1980
 #, fuzzy, no-c-format
 #| msgid "Display statistics accumulated during compilation"
 msgid "Display statistics accumulated during compilation."
 msgstr "顯示編譯程序中累計的統計數字"
 
-#: c-family/c.opt:1997
+#: c-family/c.opt:1984
 #, fuzzy, no-c-format
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "假設該值的列舉類型型態是一律在之內最小範圍的該型態"
 
-#: c-family/c.opt:2004 c-family/c.opt:2009
+#: c-family/c.opt:1991 c-family/c.opt:1996
 #, no-c-format
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
 msgstr ""
 
-#: c-family/c.opt:2026
+#: c-family/c.opt:2013
 #, fuzzy, no-c-format
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "單一循環最大的剝離數"
 
-#: c-family/c.opt:2033
+#: c-family/c.opt:2020
 #, fuzzy, no-c-format
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
 msgstr "-ftemplate-depth=<number>\t指定最大值模板具現化深度"
 
-#: c-family/c.opt:2040
+#: c-family/c.opt:2027
 #, fuzzy, no-c-format
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
 msgstr "-fno-threadsafe-statics\t不產生 thread-safe 編碼用於初始化本地靜態"
 
-#: c-family/c.opt:2044
+#: c-family/c.opt:2031
 #, fuzzy, no-c-format
 #| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "未指定「signed」或「unsigned」時預設位元段為無號的"
 
-#: c-family/c.opt:2048 ada/gcc-interface/lang.opt:89
+#: c-family/c.opt:2035 ada/gcc-interface/lang.opt:89
 #, fuzzy, no-c-format
 #| msgid "Make \"char\" unsigned by default"
 msgid "Make \"char\" unsigned by default."
 msgstr "使「char」類型預設為無號"
 
-#: c-family/c.opt:2052
+#: c-family/c.opt:2039
 #, fuzzy, no-c-format
 #| msgid "Use __cxa_atexit to register destructors"
 msgid "Use __cxa_atexit to register destructors."
 msgstr "將 __cxa_atexit 而非 atexit 登記為解構函式"
 
-#: c-family/c.opt:2056
+#: c-family/c.opt:2043
 #, fuzzy, no-c-format
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "使用 __cxa_get_exception_ptr 在中異常處理"
 
-#: c-family/c.opt:2060
+#: c-family/c.opt:2047
 #, fuzzy, no-c-format
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "標記所有內聯的函式和方法做為已隱藏可視性"
 
-#: c-family/c.opt:2064
+#: c-family/c.opt:2051
 #, fuzzy, no-c-format
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "變更可視性到匹配 Microsoft 視覺的工作室按照預設"
 
-#: c-family/c.opt:2076 d/lang.opt:326
+#: c-family/c.opt:2063
 #, fuzzy, no-c-format
 #| msgid "Emit common-like symbols as weak symbols"
 msgid "Emit common-like symbols as weak symbols."
 msgstr "將公共符號視作弱符號"
 
-#: c-family/c.opt:2080
+#: c-family/c.opt:2067
 #, fuzzy, no-c-format
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-fwide-exec-charset=<cset>\t轉換所有 wide 字串和字元常數到字元集<cset>"
 
-#: c-family/c.opt:2084
+#: c-family/c.opt:2071
 #, fuzzy, no-c-format
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "產生 # 列指令點於目前的工作目錄"
 
-#: c-family/c.opt:2092
+#: c-family/c.opt:2079
 #, fuzzy, no-c-format
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
 msgstr "產生 lazy 類別查找 (透過 objcgetClass()) 用於使用在中 Zero-Link 模式(_G)"
 
-#: c-family/c.opt:2096
+#: c-family/c.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Dump declarations to a .decl file"
 msgid "Dump declarations to a .decl file."
 msgstr "將宣告傾印到一個 .decl 檔案中"
 
-#: c-family/c.opt:2100
+#: c-family/c.opt:2087
 #, fuzzy, no-c-format
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "-femit-struct-debug-baseonly\t強烈縮小的除錯資訊用於結構"
 
-#: c-family/c.opt:2104
+#: c-family/c.opt:2091
 #, fuzzy, no-c-format
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "-femit-struct-debug-reduced\tConservative 縮小的除錯資訊用於結構"
 
-#: c-family/c.opt:2108
+#: c-family/c.opt:2095
 #, fuzzy, no-c-format
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "-femit-struct-debug-detailed=<spec-list>\t詳細的縮小的除錯資訊用於結構"
 
-#: c-family/c.opt:2112
+#: c-family/c.opt:2099
 #, no-c-format
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
 msgstr ""
 
-#: c-family/c.opt:2117
+#: c-family/c.opt:2104
 #, fuzzy, no-c-format
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <dir>\t加入<dir>到結束的系統包含路徑"
 
-#: c-family/c.opt:2121
+#: c-family/c.opt:2108
 #, fuzzy, no-c-format
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "-imacros <file>\t接受定義的巨集在中<檔案>"
 
-#: c-family/c.opt:2125
+#: c-family/c.opt:2112
 #, fuzzy, no-c-format
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-imultilib <dir>\t設定<dir>為 multilib 包含子目錄"
 
-#: c-family/c.opt:2129
+#: c-family/c.opt:2116
 #, fuzzy, no-c-format
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "-include <file>\t包含內容的<檔案>之前其他檔案"
 
-#: c-family/c.opt:2133
+#: c-family/c.opt:2120
 #, fuzzy, no-c-format
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
 msgstr "-iprefix <path>\t指定<路徑>做為前綴用於下一個兩選項"
 
-#: c-family/c.opt:2137
+#: c-family/c.opt:2124
 #, fuzzy, no-c-format
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <dir>\t設定<dir>為系統根目錄"
 
-#: c-family/c.opt:2141
+#: c-family/c.opt:2128
 #, fuzzy, no-c-format
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <dir>\t加入<dir>到開始的系統包含路徑"
 
-#: c-family/c.opt:2145
+#: c-family/c.opt:2132
 #, fuzzy, no-c-format
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-iquote <dir>\t加入<dir>到結束的引言包含路徑"
 
-#: c-family/c.opt:2149
+#: c-family/c.opt:2136
 #, fuzzy, no-c-format
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <dir>\t加入<dir>到結束的系統包含路徑"
 
-#: c-family/c.opt:2153
+#: c-family/c.opt:2140
 #, fuzzy, no-c-format
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <dir>\t加入<dir>到結束的主要包含路徑"
 
-#: c-family/c.opt:2163
+#: c-family/c.opt:2150
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories (those specified with -isystem will still be used)"
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "不搜尋標準系統標頭檔案目錄(但仍將使用由 -isystem 指定的目錄)"
 
-#: c-family/c.opt:2167
+#: c-family/c.opt:2154
 #, fuzzy, no-c-format
 #| msgid "Do not search standard system include directories for C++"
 msgid "Do not search standard system include directories for C++."
 msgstr "不搜尋 C++ 標準系統標頭檔案目錄"
 
-#: c-family/c.opt:2179
+#: c-family/c.opt:2166
 #, fuzzy, no-c-format
 #| msgid "Generate C header of platform-specific features"
 msgid "Generate C header of platform-specific features."
 msgstr "產生有平臺相關特性的 C 標頭檔案"
 
-#: c-family/c.opt:2183
+#: c-family/c.opt:2170
 #, fuzzy, no-c-format
 msgid "Remap file names when including files."
 msgstr "重新映射檔案名稱時包含檔"
 
-#: c-family/c.opt:2187 c-family/c.opt:2191
+#: c-family/c.opt:2174 c-family/c.opt:2178
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
 msgstr "符合到 ISO 1998 C++標準修訂由 2003 技術 corrigendum"
 
-#: c-family/c.opt:2195
+#: c-family/c.opt:2182
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "遵循 ISO 1998 C++ 標準"
 
-#: c-family/c.opt:2199
+#: c-family/c.opt:2186
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++11."
 msgstr "不宜用支持 -std=c++11"
 
-#: c-family/c.opt:2203
+#: c-family/c.opt:2190
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++14."
 msgstr "不宜用支持 -std=c++11"
 
-#: c-family/c.opt:2207
+#: c-family/c.opt:2194
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "遵循 ISO 1998 C++ 標準"
 
-#: c-family/c.opt:2211
+#: c-family/c.opt:2198
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c++17."
 msgstr "不宜用支持 -std=c++11"
 
-#: c-family/c.opt:2215
+#: c-family/c.opt:2202
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "遵循 ISO 1998 C++ 標準"
 
-#: c-family/c.opt:2219 c-family/c.opt:2223
+#: c-family/c.opt:2206 c-family/c.opt:2210
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
 msgstr "符合到 ISO 2011 C++標準 (實驗性質和不完整支援)"
 
-#: c-family/c.opt:2227 c-family/c.opt:2231
+#: c-family/c.opt:2214 c-family/c.opt:2218
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
 msgstr "符合到 ISO 2011 C++標準 (實驗性質和不完整支援)"
 
-#: c-family/c.opt:2235 c-family/c.opt:2373
+#: c-family/c.opt:2222 c-family/c.opt:2360
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 2011 C standard."
 msgstr "遵循 ISO 1990 C 標準"
 
-#: c-family/c.opt:2239
+#: c-family/c.opt:2226
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=c11."
 msgstr "不宜用支持 -std=c11"
 
-#: c-family/c.opt:2243 c-family/c.opt:2247 c-family/c.opt:2377
-#: c-family/c.opt:2381
+#: c-family/c.opt:2230 c-family/c.opt:2234 c-family/c.opt:2364
+#: c-family/c.opt:2368
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "遵循 ISO 1990 C 標準於 1994 年修訂的版本"
 
-#: c-family/c.opt:2251
+#: c-family/c.opt:2238
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "符合到 ISO 2011 C 標準 (實驗性質和不完整支援)"
 
-#: c-family/c.opt:2255 c-family/c.opt:2259 c-family/c.opt:2357
+#: c-family/c.opt:2242 c-family/c.opt:2246 c-family/c.opt:2344
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 1990 C standard."
 msgstr "遵循 ISO 1990 C 標準"
 
-#: c-family/c.opt:2263 c-family/c.opt:2365
+#: c-family/c.opt:2250 c-family/c.opt:2352
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard"
 msgid "Conform to the ISO 1999 C standard."
 msgstr "遵循 ISO 1999 C 標準"
 
-#: c-family/c.opt:2267
+#: c-family/c.opt:2254
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c99."
 msgstr "已過時，請使用 -std=c99"
 
-#: c-family/c.opt:2271 c-family/c.opt:2276
+#: c-family/c.opt:2258 c-family/c.opt:2263
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
 msgstr "符合到 ISO 1998 C++標準修訂由 2003 技術 corrigendum"
 
-#: c-family/c.opt:2281
+#: c-family/c.opt:2268
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 標準，也支援 GNU 擴充"
 
-#: c-family/c.opt:2285
+#: c-family/c.opt:2272
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "不宜用支持 -std=gnu++11"
 
-#: c-family/c.opt:2289
+#: c-family/c.opt:2276
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "不宜用支持 -std=gnu++11"
 
-#: c-family/c.opt:2293
+#: c-family/c.opt:2280
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 標準，也支援 GNU 擴充"
 
-#: c-family/c.opt:2297
+#: c-family/c.opt:2284
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "不宜用支持 -std=gnu++11"
 
-#: c-family/c.opt:2301
+#: c-family/c.opt:2288
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 標準，也支援 GNU 擴充"
 
-#: c-family/c.opt:2305 c-family/c.opt:2309
+#: c-family/c.opt:2292 c-family/c.opt:2296
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
 msgstr "符合到 ISO 2011 C++標準與 GNU 延伸 (實驗性質和不完整支援)"
 
-#: c-family/c.opt:2313 c-family/c.opt:2317
+#: c-family/c.opt:2300 c-family/c.opt:2304
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "符合到 ISO 2011 C++標準與 GNU 延伸 (實驗性質和不完整支援)"
 
-#: c-family/c.opt:2321
+#: c-family/c.opt:2308
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 標準，也支援 GNU 擴充"
 
-#: c-family/c.opt:2325
+#: c-family/c.opt:2312
 #, fuzzy, no-c-format
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "不宜用支持 -std=gnu11"
 
-#: c-family/c.opt:2329 c-family/c.opt:2333
+#: c-family/c.opt:2316 c-family/c.opt:2320
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "遵循 ISO 1990 C 標準，也支援 GNU 擴充"
 
-#: c-family/c.opt:2337
+#: c-family/c.opt:2324
 #, fuzzy, no-c-format
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "符合到 ISO 2011 C 標準與 GNU 延伸 (實驗性質和不完整支援)"
 
-#: c-family/c.opt:2341 c-family/c.opt:2345
+#: c-family/c.opt:2328 c-family/c.opt:2332
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "遵循 ISO 1990 C 標準，也支援 GNU 擴充"
 
-#: c-family/c.opt:2349
+#: c-family/c.opt:2336
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1999 C standard with GNU extensions"
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "遵循 ISO 1999 C 標準，也支援 GNU 擴充"
 
-#: c-family/c.opt:2353
+#: c-family/c.opt:2340
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "已過時，請使用 -std=gnu99"
 
-#: c-family/c.opt:2361
+#: c-family/c.opt:2348
 #, fuzzy, no-c-format
 #| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "遵循 ISO 1990 C 標準於 1994 年修訂的版本"
 
-#: c-family/c.opt:2369
+#: c-family/c.opt:2356
 #, fuzzy, no-c-format
 #| msgid "Deprecated in favor of -std=iso9899:1999"
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "已過時，為 -std=iso9899:1999 所取代"
 
-#: c-family/c.opt:2385
+#: c-family/c.opt:2372
 #, no-c-format
 msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
 msgstr ""
 
-#: c-family/c.opt:2402
+#: c-family/c.opt:2389
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable traditional preprocessing."
 msgstr "啟用傳統預先處理"
 
-#: c-family/c.opt:2406
+#: c-family/c.opt:2393
 #, fuzzy, no-c-format
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\t支援 ISO C 三併詞"
 
-#: c-family/c.opt:2410
+#: c-family/c.opt:2397
 #, fuzzy, no-c-format
 #| msgid "Do not predefine system-specific and GCC-specific macros"
 msgid "Do not predefine system-specific and GCC-specific macros."
@@ -8484,6 +8479,12 @@ msgstr "以 32 位元整數模式編譯"
 msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified by <ident>."
 msgstr ""
 
+#: d/lang.opt:326
+#, fuzzy, no-c-format
+#| msgid "Emit implicit instantiations of templates"
+msgid "Emit template instantiations as weak symbols."
+msgstr "允許範本隱含實體化"
+
 #: d/lang.opt:346
 #, fuzzy, no-c-format
 #| msgid "Do not assume that standard C libraries and \"main\" exist"
@@ -9809,148 +9810,162 @@ msgstr "支援超過 8192 得到條目於 ColdFire"
 msgid "Support TLS segment larger than 64K."
 msgstr "支援 TLS 資料段大於 64K"
 
-#: config/riscv/riscv.opt:26
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:68
+#: config/arm/arm.opt:90 config/microblaze/microblaze.opt:60
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as big endian"
+msgid "Assume target CPU is configured as big endian."
+msgstr "假定目的 CPU 被配置為高位位元組在前"
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:88
+#: config/arm/arm.opt:155 config/microblaze/microblaze.opt:64
+#, fuzzy, no-c-format
+#| msgid "Assume target CPU is configured as little endian"
+msgid "Assume target CPU is configured as little endian."
+msgstr "假定目的 CPU 被配置為低位位元組在前"
+
+#: config/riscv/riscv.opt:34
 #, fuzzy, no-c-format
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "-mbranch-cost=成本\t設定成本的分支到大致上成本指令"
 
-#: config/riscv/riscv.opt:30
+#: config/riscv/riscv.opt:38
 #, fuzzy, no-c-format
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
 msgstr "時產生 -mabicalls 編碼，允許可執行檔案以使用 PLTs 和複製重定址"
 
-#: config/riscv/riscv.opt:34
+#: config/riscv/riscv.opt:42
 #, fuzzy, no-c-format
 msgid "Specify integer and floating-point calling convention."
 msgstr "指定 __fp16 浮點格式"
 
-#: config/riscv/riscv.opt:38 config/i386/i386.opt:421
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:421
 #, fuzzy, no-c-format
 #| msgid "Attempt to keep stack aligned to this power of 2"
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "試圖讓堆疊保持對齊到 2 的此次方上"
 
-#: config/riscv/riscv.opt:42
+#: config/riscv/riscv.opt:50
 #, fuzzy, no-c-format
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "已知 ABIs (用於使用與 -mabi=選項)："
 
-#: config/riscv/riscv.opt:67
+#: config/riscv/riscv.opt:75
 #, fuzzy, no-c-format
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "使用硬體浮點數平方根指令"
 
-#: config/riscv/riscv.opt:71
+#: config/riscv/riscv.opt:79
 #, fuzzy, no-c-format
 #| msgid "Use trap instructions to check for integer divide by zero"
 msgid "Use hardware instructions for integer division."
 msgstr "使用陷阱指令偵測整數零除"
 
-#: config/riscv/riscv.opt:75
+#: config/riscv/riscv.opt:83
 #, no-c-format
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
 msgstr ""
 
-#: config/riscv/riscv.opt:80 config/mips/mips.opt:405
+#: config/riscv/riscv.opt:88 config/mips/mips.opt:405
 #, fuzzy, no-c-format
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=處理器\t最佳化輸出用於處理器"
 
-#: config/riscv/riscv.opt:84
+#: config/riscv/riscv.opt:92
 #, fuzzy, no-c-format
 msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
 msgstr "-mtune=處理器\t最佳化輸出用於處理器"
 
-#: config/riscv/riscv.opt:88
+#: config/riscv/riscv.opt:96
 #, fuzzy, no-c-format
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
 msgstr "-G<number>\t置放全域和靜態資料小於<數字>位元組進入特殊區段 (於某些目標)"
 
-#: config/riscv/riscv.opt:92
+#: config/riscv/riscv.opt:100
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "使用子程式完成函式前言/尾聲"
 
-#: config/riscv/riscv.opt:96
+#: config/riscv/riscv.opt:104
 #, no-c-format
 msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
 msgstr ""
 
-#: config/riscv/riscv.opt:102 config/aarch64/aarch64.opt:92
+#: config/riscv/riscv.opt:110 config/aarch64/aarch64.opt:92
 #, fuzzy, no-c-format
 msgid "Specify the code model."
 msgstr "選取編碼式樣"
 
-#: config/riscv/riscv.opt:106
+#: config/riscv/riscv.opt:114
 #, fuzzy, no-c-format
 #| msgid "Do not use unaligned memory references"
 msgid "Do not generate unaligned memory accesses."
 msgstr "不使用未對齊的記憶體參照"
 
-#: config/riscv/riscv.opt:110 config/i386/i386.opt:293
+#: config/riscv/riscv.opt:118 config/i386/i386.opt:293
 #: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
 #: config/tilegx/tilegx.opt:57
 #, fuzzy, no-c-format
 msgid "Known code models (for use with the -mcmodel= option):"
 msgstr "已知編碼式樣 (用於使用與 -mcmodel=選項)："
 
-#: config/riscv/riscv.opt:120
+#: config/riscv/riscv.opt:128
 #, no-c-format
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:124
+#: config/riscv/riscv.opt:132
 #, no-c-format
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
 msgstr ""
 
-#: config/riscv/riscv.opt:143
+#: config/riscv/riscv.opt:151
 #, no-c-format
 msgid "Emit RISC-V ELF attribute."
 msgstr ""
 
-#: config/riscv/riscv.opt:147 config/i386/i386.opt:246
+#: config/riscv/riscv.opt:155 config/i386/i386.opt:246
 #, fuzzy, no-c-format
 #| msgid "Do not tune writable data alignment"
 msgid "Use the given data alignment."
 msgstr "不調整可寫資料對齊"
 
-#: config/riscv/riscv.opt:151 config/i386/i386.opt:250
+#: config/riscv/riscv.opt:159 config/i386/i386.opt:250
 #, fuzzy, no-c-format
 msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgstr "已知 TLS 方言 (用於使用與 -mtls-dialect=選項)："
 
-#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:235
+#: config/riscv/riscv.opt:169 config/aarch64/aarch64.opt:235
 #: config/i386/i386.opt:995 config/rs6000/rs6000.opt:570
 #, no-c-format
 msgid "Use given stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:165 config/aarch64/aarch64.opt:239
+#: config/riscv/riscv.opt:173 config/aarch64/aarch64.opt:239
 #: config/rs6000/rs6000.opt:574
 #, fuzzy, no-c-format
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "有效引數到 -mfloat-gprs=："
 
-#: config/riscv/riscv.opt:175 config/i386/i386.opt:1009
+#: config/riscv/riscv.opt:183 config/i386/i386.opt:1009
 #: config/rs6000/rs6000.opt:584
 #, no-c-format
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:182 config/i386/i386.opt:1016
+#: config/riscv/riscv.opt:190 config/i386/i386.opt:1016
 #: config/rs6000/rs6000.opt:591
 #, no-c-format
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
-#: config/riscv/riscv.opt:192
+#: config/riscv/riscv.opt:200
 #, fuzzy, no-c-format
 msgid "Supported ISA specs (for use with the -misa-spec= option):"
 msgstr "已知 ABIs (用於使用與 -mabi=選項)："
 
-#: config/riscv/riscv.opt:205
+#: config/riscv/riscv.opt:213
 #, fuzzy, no-c-format
 #| msgid "Specify the name of the target CPU"
 msgid "Set the version of RISC-V ISA spec."
@@ -10086,13 +10101,6 @@ msgstr ""
 msgid "The code model option names for -mcmodel:"
 msgstr ""
 
-#: config/aarch64/aarch64.opt:68 config/arm/arm.opt:90
-#: config/microblaze/microblaze.opt:60
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as big endian"
-msgid "Assume target CPU is configured as big endian."
-msgstr "假定目的 CPU 被配置為高位位元組在前"
-
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1030
 #, fuzzy, no-c-format
 msgid "Generate code which uses only the general registers."
@@ -10113,13 +10121,6 @@ msgstr ""
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr ""
 
-#: config/aarch64/aarch64.opt:88 config/arm/arm.opt:155
-#: config/microblaze/microblaze.opt:64
-#, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as little endian"
-msgid "Assume target CPU is configured as little endian."
-msgstr "假定目的 CPU 被配置為低位位元組在前"
-
 #: config/aarch64/aarch64.opt:96
 #, no-c-format
 msgid "Don't assume that unaligned accesses are handled by the system."
@@ -17867,2316 +17868,2316 @@ msgstr ""
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <dir>\t設定目錄名稱為用於傾印"
 
-#: common.opt:970
+#: common.opt:974
 #, no-c-format
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:974
+#: common.opt:978
 #, no-c-format
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy, no-c-format
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "對齊函式入口"
 
-#: common.opt:988
+#: common.opt:992
 #, fuzzy, no-c-format
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "對齊只能為跳轉所到達的標籤"
 
-#: common.opt:995
+#: common.opt:999
 #, fuzzy, no-c-format
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "對齊所有的標籤"
 
-#: common.opt:1002
+#: common.opt:1006
 #, fuzzy, no-c-format
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "對齊循環入口"
 
-#: common.opt:1009
+#: common.opt:1013
 #, no-c-format
 msgid "Allow the compiler to introduce new data races on stores."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 #, fuzzy, no-c-format
 #| msgid "Enable traditional preprocessing"
 msgid "Enable static analysis pass."
 msgstr "啟用傳統預先處理"
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy, no-c-format
 msgid "Select what to sanitize."
 msgstr "選取執行階段"
 
-#: common.opt:1037
+#: common.opt:1041
 #, no-c-format
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 #, no-c-format
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1045
+#: common.opt:1049
 #, no-c-format
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1050
+#: common.opt:1054
 #, no-c-format
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1054
+#: common.opt:1058
 #, fuzzy, no-c-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "此開關已過時；請改用 -Wextra"
 
-#: common.opt:1061
+#: common.opt:1065
 #, no-c-format
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1065
+#: common.opt:1069
 #, fuzzy, no-c-format
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "產生精確到每條指令邊界的堆疊展開表"
 
-#: common.opt:1069
+#: common.opt:1073
 #, fuzzy, no-c-format
 msgid "Generate auto-inc/dec instructions."
 msgstr "產生 auto-inc/十二月指令"
 
-#: common.opt:1073
+#: common.opt:1077
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1078
+#: common.opt:1082
 #, no-c-format
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1087
+#: common.opt:1091
 #, fuzzy, no-c-format
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "產生檢查陣列存取是否越界的程式碼"
 
-#: common.opt:1091
+#: common.opt:1095
 #, fuzzy, no-c-format
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "將加/減法、比較、跳轉指令序列替換為根據計數暫存器跳轉指令"
 
-#: common.opt:1095
+#: common.opt:1099
 #, fuzzy, no-c-format
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "為分支概率使用取樣資訊"
 
-#: common.opt:1111
+#: common.opt:1115
 #, fuzzy, no-c-format
 msgid "Output callgraph information on a per-file basis."
 msgstr "輸出堆疊用法資訊於 per-function 基礎"
 
-#: common.opt:1115
+#: common.opt:1119
 #, fuzzy, no-c-format
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "輸出堆疊用法資訊於 per-function 基礎"
 
-#: common.opt:1119
+#: common.opt:1123
 #, fuzzy, no-c-format
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<register>\t標記<暫存器>做為被保留跨越函式"
 
-#: common.opt:1123
+#: common.opt:1127
 #, fuzzy, no-c-format
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<register>\t標記<暫存器>做為被已損壞由函式呼叫"
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "函式呼叫前後儲存/恢復暫存器值"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy, no-c-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "此開關已過時；請改用 -Wextra"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy, no-c-format
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "檢查 new 的回傳值"
 
-#: common.opt:1142 common.opt:1146
+#: common.opt:1146 common.opt:1150
 #, fuzzy, no-c-format
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "內部一致性錯誤"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "啟用函式取樣"
 
-#: common.opt:1154
+#: common.opt:1158
 #, fuzzy, no-c-format
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "找尋機會到縮小堆疊調整和堆疊參考。"
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy, no-c-format
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Put uninitialized globals in the common section."
 msgstr "不將未初始化的全域資料放在公共區段中"
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy, no-c-format
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug [=<opts>]\t編譯與和而無需例如： -gtoggle，而比較 final-insns 傾印"
 
-#: common.opt:1170
+#: common.opt:1174
 #, fuzzy, no-c-format
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "運行只有第二編譯的 -fcompare-debug"
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy, no-c-format
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "施行比較 elimination 之後暫存器配額已完成"
 
-#: common.opt:1178
+#: common.opt:1182
 #, fuzzy, no-c-format
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "不施行最佳化增加 noticeably 堆疊用法"
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy, no-c-format
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "進行一趟暫存器副本傳遞最佳化"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy, no-c-format
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "進行跨跳轉最佳化"
 
-#: common.opt:1190
+#: common.opt:1194
 #, fuzzy, no-c-format
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "進行 CSE 時，跟隨跳轉至目的"
 
-#: common.opt:1198
+#: common.opt:1202
 #, fuzzy, no-c-format
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "當進行複數除法時省略縮減範圍的步驟"
 
-#: common.opt:1202
+#: common.opt:1206
 #, fuzzy, no-c-format
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "複雜乘法和除法追隨 Fortran 規則"
 
-#: common.opt:1206
+#: common.opt:1210
 #, fuzzy, no-c-format
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "將每個資料項分別放在它們各自的區段中"
 
-#: common.opt:1210
+#: common.opt:1214
 #, fuzzy, no-c-format
 msgid "List all available debugging counters with their limits and counts."
 msgstr "列出所有可用偵錯計數器與它們的限度和計數。"
 
-#: common.opt:1214
+#: common.opt:1218
 #, fuzzy, no-c-format
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<counter>:<限制>[,<計數器>:<限制>,...]\t設定除錯計數器限制。  "
 
-#: common.opt:1218
+#: common.opt:1222
 #, fuzzy, no-c-format
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr "映射一個目錄名稱到另外的在中除錯資訊"
 
-#: common.opt:1222
+#: common.opt:1226
 #, fuzzy, no-c-format
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr "映射一個目錄名稱到另外的在中除錯資訊"
 
-#: common.opt:1226
+#: common.opt:1230
 #, fuzzy, no-c-format
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "輸出.debugtypes 區段時使用 DWARF v4 debuginfo(_T)。"
 
-#: common.opt:1232
+#: common.opt:1236
 #, fuzzy, no-c-format
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "延遲將函式引數彈堆疊"
 
-#: common.opt:1236
+#: common.opt:1240
 #, fuzzy, no-c-format
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "試圖利用延遲轉移指令後"
 
-#: common.opt:1240
+#: common.opt:1244
 #, no-c-format
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1244
+#: common.opt:1248
 #, fuzzy, no-c-format
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "刪除無用的空指標檢查"
 
-#: common.opt:1248
+#: common.opt:1252
 #, no-c-format
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1252
+#: common.opt:1256
 #, fuzzy, no-c-format
 msgid "Perform speculative devirtualization."
 msgstr "施行超區塊格式透過尾端複印法"
 
-#: common.opt:1256
+#: common.opt:1260
 #, fuzzy, no-c-format
 msgid "Try to convert virtual calls to direct ones."
 msgstr "試著轉換虛擬呼叫到直接的一個。"
 
-#: common.opt:1260
+#: common.opt:1264
 #, fuzzy, no-c-format
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[一旦|every-line]\t多久會到 emit 來源位置於起始部分的 line-wrapped 診斷"
 
-#: common.opt:1277
+#: common.opt:1281
 #, no-c-format
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 #, no-c-format
 msgid "Show labels annotating ranges of source code when showing source."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, no-c-format
 msgid "Show line numbers in the left margin when showing source."
 msgstr ""
 
-#: common.opt:1293
+#: common.opt:1297
 #, no-c-format
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, no-c-format
 msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
 msgstr ""
 
-#: common.opt:1333
+#: common.opt:1337
 #, no-c-format
 msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 #, no-c-format
 msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, no-c-format
 msgid "-fdiagnostics-format=[text|json]\tSelect output format."
 msgstr ""
 
-#: common.opt:1367
+#: common.opt:1371
 #, no-c-format
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1371
+#: common.opt:1375
 #, no-c-format
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1375
+#: common.opt:1379
 #, fuzzy, no-c-format
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "修正適當診斷訊息與命令列選項該控制項它們"
 
-#: common.opt:1379
+#: common.opt:1383
 #, no-c-format
 msgid "Print CWE identifiers for diagnostic messages, where available."
 msgstr ""
 
-#: common.opt:1383
+#: common.opt:1387
 #, no-c-format
 msgid "Specify how to print any control-flow path associated with a diagnostic."
 msgstr ""
 
-#: common.opt:1387
+#: common.opt:1391
 #, no-c-format
 msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
 msgstr ""
 
-#: common.opt:1391
+#: common.opt:1395
 #, fuzzy, no-c-format
 msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
 msgstr "-ftabstop=<number>\t間距    定位停駐點用於欄報告"
 
-#: common.opt:1407
+#: common.opt:1411
 #, no-c-format
 msgid "Show stack depths of events in paths."
 msgstr ""
 
-#: common.opt:1411
+#: common.opt:1415
 #, no-c-format
 msgid "Set minimum width of left margin of source code when showing source."
 msgstr ""
 
-#: common.opt:1415
+#: common.opt:1419
 #, fuzzy, no-c-format
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
 msgstr "-fdisable-[ 樹|rtl|ipa ]-<pass>=range1+range2 停用最佳化回合"
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, no-c-format
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
 msgstr "-fenable-[ 樹|rtl|ipa ]-<pass>=range1+range2 啟用最佳化回合"
 
-#: common.opt:1423
+#: common.opt:1427
 #, fuzzy, no-c-format
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\t傾印各種編譯器內部到檔案"
 
-#: common.opt:1430
+#: common.opt:1434
 #, fuzzy, no-c-format
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=檔名\t傾印到檔名 insns 於結束的翻譯"
 
-#: common.opt:1434
+#: common.opt:1438
 #, fuzzy, no-c-format
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=檔名\t寫入所有宣告到檔案做為前往編碼"
 
-#: common.opt:1438
+#: common.opt:1442
 #, fuzzy, no-c-format
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "不列印輸出的位址在中偵錯傾印"
 
-#: common.opt:1442
+#: common.opt:1446
 #, no-c-format
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1447
+#: common.opt:1451
 #, no-c-format
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1451
+#: common.opt:1455
 #, fuzzy, no-c-format
 msgid "Dump optimization passes."
 msgstr "傾印最佳化次數"
 
-#: common.opt:1455
+#: common.opt:1459
 #, fuzzy, no-c-format
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "不列印輸出的指令數量，列號記事和位址在中偵錯傾印"
 
-#: common.opt:1459
+#: common.opt:1463
 #, fuzzy, no-c-format
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "不列印輸出的前一個和下一個 insn 數量在中偵錯傾印"
 
-#: common.opt:1463
+#: common.opt:1467
 #, fuzzy, no-c-format
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "啟用 CFI 表格透過氣體組譯器指令。"
 
-#: common.opt:1467
+#: common.opt:1471
 #, fuzzy, no-c-format
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "進行早內聯"
 
-#: common.opt:1475
+#: common.opt:1479
 #, fuzzy, no-c-format
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "施行 interprocedural 消除的彙總"
 
-#: common.opt:1479
+#: common.opt:1483
 #, fuzzy, no-c-format
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "在除錯資訊中進行無用類型消除"
 
-#: common.opt:1483
+#: common.opt:1487
 #, fuzzy, no-c-format
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "在除錯資訊中進行無用類型消除"
 
-#: common.opt:1487
+#: common.opt:1491
 #, fuzzy, no-c-format
 msgid "Do not suppress C++ class debug information."
 msgstr "不抑制 C++類別除錯資訊。"
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "啟用異常處理"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy, no-c-format
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "進行一些細微的、代價高昂的最佳化"
 
-#: common.opt:1499
+#: common.opt:1503
 #, fuzzy, no-c-format
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[快速|標準]\t指定處理的過剩浮點精確度"
 
-#: common.opt:1514
+#: common.opt:1518
 #, no-c-format
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1530
+#: common.opt:1534
 #, fuzzy, no-c-format
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "輸出 lto 物件包含兩者中介語言和二進位輸出。"
 
-#: common.opt:1534
+#: common.opt:1538
 #, fuzzy, no-c-format
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "假定結果不會是 NaN 或無限大浮點數"
 
-#: common.opt:1538
+#: common.opt:1542
 #, no-c-format
 msgid "Assume that loops with an exit will terminate and not loop indefinitely."
 msgstr ""
 
-#: common.opt:1542
+#: common.opt:1546
 #, fuzzy, no-c-format
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<register>\t標記<暫存器>做為是不得使用到編譯器"
 
-#: common.opt:1546
+#: common.opt:1550
 #, fuzzy, no-c-format
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "不將單精度和雙精度浮點數指派到擴充精度的暫存器中"
 
-#: common.opt:1554
+#: common.opt:1558
 #, fuzzy, no-c-format
 msgid "Perform a forward propagation pass on RTL."
 msgstr "施行轉寄傳播傳送 RTL"
 
-#: common.opt:1558
+#: common.opt:1562
 #, fuzzy, no-c-format
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[關閉|於|快速] 施行浮點運算式合約。"
 
-#: common.opt:1575
+#: common.opt:1579
 #, no-c-format
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1582
+#: common.opt:1586
 #, fuzzy, no-c-format
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "允許將函式位址儲存在暫存器中"
 
-#: common.opt:1586
+#: common.opt:1590
 #, fuzzy, no-c-format
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "將每個函式分別放在它們各自的區段中"
 
-#: common.opt:1590
+#: common.opt:1594
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "進行全域公因式消去"
 
-#: common.opt:1594
+#: common.opt:1598
 #, fuzzy, no-c-format
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "在全域公因式消去中進行增強的讀轉移最佳化"
 
-#: common.opt:1598
+#: common.opt:1602
 #, fuzzy, no-c-format
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "在全域公因式消去後進行存儲轉移"
 
-#: common.opt:1602
+#: common.opt:1606
 #, fuzzy, no-c-format
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "在全域公因式消去中進行冗餘的寫後讀消除"
 
-#: common.opt:1607
+#: common.opt:1611
 #, fuzzy, no-c-format
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "在指派暫存器後進行全域公因式消去"
 
-#: common.opt:1624
+#: common.opt:1628
 #, no-c-format
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 #, fuzzy, no-c-format
 msgid "Enable in and out of Graphite representation."
 msgstr "啟用在中和超出石墨表示"
 
-#: common.opt:1633
+#: common.opt:1637
 #, fuzzy, no-c-format
 msgid "Enable Graphite Identity transformation."
 msgstr "啟用石墨身分變換"
 
-#: common.opt:1637
+#: common.opt:1641
 #, fuzzy, no-c-format
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "啟用 hoisting 載入從條件指標。"
 
-#: common.opt:1646
+#: common.opt:1650
 #, no-c-format
 msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
 msgstr ""
 
-#: common.opt:1651
+#: common.opt:1655
 #, fuzzy, no-c-format
 msgid "Mark all loops as parallel."
 msgstr "標記所有迴圈做為平行"
 
-#: common.opt:1655 common.opt:1663 common.opt:2827
+#: common.opt:1659 common.opt:1667 common.opt:2831
 #, fuzzy, no-c-format
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "啟用迴圈交換變換。 如同 -floop-interchange"
 
-#: common.opt:1659
+#: common.opt:1663
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "啟用樹上的循環不變量轉移"
 
-#: common.opt:1667
+#: common.opt:1671
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "展開所有循環"
 
-#: common.opt:1671
+#: common.opt:1675
 #, fuzzy, no-c-format
 msgid "Enable support for GNU transactional memory."
 msgstr "啟用支援用於 GNU transactional 記憶體"
 
-#: common.opt:1675
+#: common.opt:1679
 #, no-c-format
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1683
+#: common.opt:1687
 #, fuzzy, no-c-format
 #| msgid "Run the loop optimizer twice"
 msgid "Enable the loop nest optimizer."
 msgstr "執行循環最佳化引擎兩次"
 
-#: common.opt:1687
+#: common.opt:1691
 #, fuzzy, no-c-format
 msgid "Force bitfield accesses to match their type width."
 msgstr "強制 bitfield 存取到匹配它們的型態寬度"
 
-#: common.opt:1691
+#: common.opt:1695
 #, no-c-format
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1695
+#: common.opt:1699
 #, fuzzy, no-c-format
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "啟用分支概率猜測"
 
-#: common.opt:1703
+#: common.opt:1707
 #, fuzzy, no-c-format
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "處理 #ident 指令"
 
-#: common.opt:1707
+#: common.opt:1711
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "將條件跳轉替換為沒有跳轉的等值表示"
 
-#: common.opt:1711
+#: common.opt:1715
 #, fuzzy, no-c-format
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "將條件跳轉替換為條件執行"
 
-#: common.opt:1715
+#: common.opt:1719
 #, no-c-format
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1731
+#: common.opt:1735
 #, fuzzy, no-c-format
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "轉換條件式跳位在中 innermost 迴圈到 branchless equivalents"
 
-#: common.opt:1743
+#: common.opt:1747
 #, fuzzy, no-c-format
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "不產生 .size 指令"
 
-#: common.opt:1747
+#: common.opt:1751
 #, fuzzy, no-c-format
 msgid "Perform indirect inlining."
 msgstr "施行間接內聯"
 
-#: common.opt:1753
+#: common.opt:1757
 #, fuzzy, no-c-format
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "啟用內聯的函式宣告「內聯」，停用全部停用內聯"
 
-#: common.opt:1757
+#: common.opt:1761
 #, fuzzy, no-c-format
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "整合函式進入它們的呼叫者時編碼大小是已知無法到 grow"
 
-#: common.opt:1761
+#: common.opt:1765
 #, fuzzy, no-c-format
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "整合函式無法宣告「內聯」進入它們的呼叫者時 profitable"
 
-#: common.opt:1765
+#: common.opt:1769
 #, fuzzy, no-c-format
 msgid "Integrate functions only required by their single caller."
 msgstr "整合函式只有必要項由它們的單一呼叫者"
 
-#: common.opt:1772
+#: common.opt:1776
 #, fuzzy, no-c-format
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<number>\t限制大小的內聯的函式到<數字>"
 
-#: common.opt:1776
+#: common.opt:1780
 #, fuzzy, no-c-format
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "內聯 __atomic 計算時鎖定自由指令序列是可用。"
 
-#: common.opt:1783
+#: common.opt:1787
 #, no-c-format
 msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1806
+#: common.opt:1810
 #, fuzzy, no-c-format
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "器具函式條目然後離開與側寫檔呼叫"
 
-#: common.opt:1810
+#: common.opt:1814
 #, fuzzy, no-c-format
 msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=名稱 ,... 不器具清單的函式"
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, no-c-format
 msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=檔名 ,... 不器具函式清單的在中檔案"
 
-#: common.opt:1818
+#: common.opt:1822
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "進行處理序間的複寫傳遞"
 
-#: common.opt:1822
+#: common.opt:1826
 #, fuzzy, no-c-format
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "施行仿本要讓 Interprocedural 常數傳用 stronger"
 
-#: common.opt:1830
+#: common.opt:1834
 #, fuzzy, no-c-format
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "進行處理序間的複寫傳遞"
 
-#: common.opt:1834
+#: common.opt:1838
 #, fuzzy, no-c-format
 msgid "Perform interprocedural modref analysis."
 msgstr "施行 interprocedural points-to 分析"
 
-#: common.opt:1838
+#: common.opt:1842
 #, fuzzy, no-c-format
 msgid "Perform interprocedural profile propagation."
 msgstr "施行 interprocedural 側寫檔傳播"
 
-#: common.opt:1842
+#: common.opt:1846
 #, fuzzy, no-c-format
 msgid "Perform interprocedural points-to analysis."
 msgstr "施行 interprocedural points-to 分析"
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy, no-c-format
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "發現純函式和常函式"
 
-#: common.opt:1850
+#: common.opt:1854
 #, no-c-format
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, no-c-format
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 #, no-c-format
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only and non addressable static variables."
 msgstr "發現唯讀和不可定址靜態變數"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy, no-c-format
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "發現唯讀和不可定址靜態變數"
 
-#: common.opt:1870
+#: common.opt:1874
 #, no-c-format
 msgid "Reduce stack alignment on call sites if possible."
 msgstr ""
 
-#: common.opt:1882
+#: common.opt:1886
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "進行樹上的值欄位傳遞"
 
-#: common.opt:1886
+#: common.opt:1890
 #, fuzzy, no-c-format
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|優先權] 設定使用的 IRA 演算法"
 
-#: common.opt:1899
+#: common.opt:1903
 #, fuzzy, no-c-format
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[一個|所有|混合] 設定區域用於 IRA"
 
-#: common.opt:1915
+#: common.opt:1919
 #, fuzzy, no-c-format
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "使用 IRA 基底的暫存器壓力 calculation"
 
-#: common.opt:1920
+#: common.opt:1924
 #, fuzzy, no-c-format
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "使用 IRA 基底的暫存器壓力 calculation"
 
-#: common.opt:1925
+#: common.opt:1929
 #, fuzzy, no-c-format
 msgid "Share slots for saving different hard registers."
 msgstr "共享插槽用於儲存不同的硬暫存器。"
 
-#: common.opt:1929
+#: common.opt:1933
 #, fuzzy, no-c-format
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "共享堆疊插槽用於 spilled pseudo-registers。"
 
-#: common.opt:1933
+#: common.opt:1937
 #, fuzzy, no-c-format
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<number>\t控制 IRA's 等級的診斷訊息。"
 
-#: common.opt:1937
+#: common.opt:1941
 #, fuzzy, no-c-format
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "在樹上最佳化歸納變數"
 
-#: common.opt:1941
+#: common.opt:1945
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "為足夠大的 switch 敘述使用跳轉表"
 
-#: common.opt:1945
+#: common.opt:1949
 #, fuzzy, no-c-format
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use bit tests for sufficiently large switch statements."
 msgstr "為足夠大的 switch 敘述使用跳轉表"
 
-#: common.opt:1949
+#: common.opt:1953
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "為完全內聯的函式產生程式碼"
 
-#: common.opt:1953
+#: common.opt:1957
 #, fuzzy, no-c-format
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "為完全內聯的函式產生程式碼"
 
-#: common.opt:1957
+#: common.opt:1961
 #, fuzzy, no-c-format
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "保留未用到的靜態常數"
 
-#: common.opt:1961
+#: common.opt:1965
 #, fuzzy, no-c-format
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "給外部符號加入起始的底線"
 
-#: common.opt:1969
+#: common.opt:1973
 #, no-c-format
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1973
+#: common.opt:1977
 #, fuzzy, no-c-format
 msgid "Enable link-time optimization."
 msgstr "啟用 link-time 最佳化。"
 
-#: common.opt:1977
+#: common.opt:1981
 #, fuzzy, no-c-format
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Link-time 最佳化與平行工作編號的或 jobserver。"
 
-#: common.opt:1999
+#: common.opt:2003
 #, no-c-format
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:2004
+#: common.opt:2008
 #, fuzzy, no-c-format
 msgid "-flto-compression-level=<number>\tUse zlib/zstd compression level <number> for IL."
 msgstr "-flto-compression-level=<number>\t使用 zlib 壓縮等級<數字>用於 IL"
 
-#: common.opt:2012
+#: common.opt:2016
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics."
 msgstr "報告各種 link-time 最佳化統計"
 
-#: common.opt:2016
+#: common.opt:2020
 #, fuzzy, no-c-format
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "報告各種 link-time 最佳化統計"
 
-#: common.opt:2020
+#: common.opt:2024
 #, fuzzy, no-c-format
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "執行內建數學函式後設定 errno"
 
-#: common.opt:2024
+#: common.opt:2028
 #, fuzzy, no-c-format
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<number>\t最大值錯誤代號的到報告"
 
-#: common.opt:2028
+#: common.opt:2032
 #, fuzzy, no-c-format
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "報告永久性記憶體指派"
 
-#: common.opt:2032
+#: common.opt:2036
 #, fuzzy, no-c-format
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "報告永久性記憶體指派"
 
-#: common.opt:2039
+#: common.opt:2043
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "試圖合併相同的常數和常變數"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy, no-c-format
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "試圖合併不同編譯單元中的相同常數"
 
-#: common.opt:2047
+#: common.opt:2051
 #, fuzzy, no-c-format
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "試圖到合併相等的除錯字串跨越編譯單元"
 
-#: common.opt:2051
+#: common.opt:2055
 #, fuzzy, no-c-format
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<number>\t限制診斷到<數字>字元各列。 0 抑制換列"
 
-#: common.opt:2055
+#: common.opt:2059
 #, fuzzy, no-c-format
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "在首趟調度前進行基於 SMS 的模調度"
 
-#: common.opt:2059
+#: common.opt:2063
 #, fuzzy, no-c-format
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "施行 SMS 基底的 modulo 排程與暫存器移動允許"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy, no-c-format
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "將每次循環中不變的計算外提"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy, no-c-format
 msgid "Use the RTL dead code elimination pass."
 msgstr "使用 RTL 無作用程式碼 elimination 回合"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy, no-c-format
 msgid "Use the RTL dead store elimination pass."
 msgstr "使用 RTL 無作用儲存體 elimination 回合"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy, no-c-format
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "啟用/停用已經透過模調度的循環中的傳統調度"
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy, no-c-format
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "支援同步非呼叫異常"
 
-#: common.opt:2083
+#: common.opt:2087
 #, no-c-format
 msgid "-foffload=<targets>=<options>\tSpecify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 #, no-c-format
 msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:2100
+#: common.opt:2104
 #, fuzzy, no-c-format
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "盡可能不產生堆疊框架"
 
-#: common.opt:2104
+#: common.opt:2108
 #, fuzzy, no-c-format
 msgid "Enable all optimization info dumps on stderr."
 msgstr "在樹層級進行循環最佳化"
 
-#: common.opt:2108
+#: common.opt:2112
 #, no-c-format
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, no-c-format
 msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 #, fuzzy, no-c-format
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "最佳化同級遞迴和尾遞迴"
 
-#: common.opt:2124
+#: common.opt:2128
 #, fuzzy, no-c-format
 msgid "Perform partial inlining."
 msgstr "施行部分內聯"
 
-#: common.opt:2128 common.opt:2132
+#: common.opt:2132 common.opt:2136
 #, fuzzy, no-c-format
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "報告於記憶體配置之前 interprocedural 最佳化"
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy, no-c-format
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "將結構成員不帶間隔地緊實存放"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy, no-c-format
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<number>\t設定初始最大值結構成員對齊"
 
-#: common.opt:2144
+#: common.opt:2148
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "在記憶體而不是暫存器中回傳小聚合"
 
-#: common.opt:2148
+#: common.opt:2152
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "進行循環剝離"
 
-#: common.opt:2152
+#: common.opt:2156
 #, fuzzy, no-c-format
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "啟用機器相關的窺孔最佳化"
 
-#: common.opt:2156
+#: common.opt:2160
 #, fuzzy, no-c-format
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "在 sched2 前進行一趟 RTL 窺孔最佳化"
 
-#: common.opt:2160
+#: common.opt:2164
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "盡可能產生與位置無關的程式碼(大模式)"
 
-#: common.opt:2164
+#: common.opt:2168
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "為可執行檔案盡可能產生與位置無關的程式碼(大模式)"
 
-#: common.opt:2168
+#: common.opt:2172
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "盡可能產生與位置無關的程式碼(小模式)"
 
-#: common.opt:2172
+#: common.opt:2176
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "為可執行檔案盡可能產生與位置無關的程式碼(小模式)"
 
-#: common.opt:2176
+#: common.opt:2180
 #, no-c-format
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2180
+#: common.opt:2184
 #, fuzzy, no-c-format
 msgid "Specify a plugin to load."
 msgstr "指定外掛程式到載入"
 
-#: common.opt:2184
+#: common.opt:2188
 #, fuzzy, no-c-format
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<name>-< 鍵>[=<值>]\t指定引數<鍵>=<值>用於外掛程式<名稱>"
 
-#: common.opt:2188
+#: common.opt:2192
 #, fuzzy, no-c-format
 msgid "Run predictive commoning optimization."
 msgstr "運行 predictive 共同最佳化。"
 
-#: common.opt:2192
+#: common.opt:2196
 #, fuzzy, no-c-format
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "如果可用，為循環中的陣列產生預取指令"
 
-#: common.opt:2196
+#: common.opt:2200
 #, fuzzy, no-c-format
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "啟用基本程式取樣程式碼"
 
-#: common.opt:2200
+#: common.opt:2204
 #, no-c-format
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2204
+#: common.opt:2208
 #, fuzzy, no-c-format
 msgid "Insert arc-based program profiling code."
 msgstr "插入 arc-based 程式側寫檔編碼"
 
-#: common.opt:2208
+#: common.opt:2212
 #, fuzzy, no-c-format
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "設定最上層目錄用於存入側寫檔資料。"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy, no-c-format
 msgid "Select the name for storing the profile note file."
 msgstr "設定最上層目錄用於存入側寫檔資料。"
 
-#: common.opt:2217
+#: common.opt:2221
 #, fuzzy, no-c-format
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "啟用校正的流程不一致側寫檔資料輸入"
 
-#: common.opt:2221
+#: common.opt:2225
 #, no-c-format
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2225
+#: common.opt:2229
 #, no-c-format
 msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2229
+#: common.opt:2233
 #, no-c-format
 msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
 msgstr ""
 
-#: common.opt:2245
+#: common.opt:2249
 #, no-c-format
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr ""
 
-#: common.opt:2261
+#: common.opt:2265
 #, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
-#: common.opt:2265
+#: common.opt:2269
 #, fuzzy, no-c-format
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "啟用一些公共選項來產生樣本檔案，以便進行基於取樣的最佳化"
 
-#: common.opt:2269
+#: common.opt:2273
 #, fuzzy, no-c-format
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "啟用共同選項用於產生側寫檔資訊用於側寫檔反饋導最佳化，而設定 -fprofile-dir="
 
-#: common.opt:2273
+#: common.opt:2277
 #, no-c-format
 msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2277
+#: common.opt:2281
 #, no-c-format
 msgid "Register the profile information in the specified section instead of using a constructor/destructor."
 msgstr ""
 
-#: common.opt:2281
+#: common.opt:2285
 #, no-c-format
 msgid "Do not assume that functions never executed during the train run are cold."
 msgstr ""
 
-#: common.opt:2285
+#: common.opt:2289
 #, fuzzy, no-c-format
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "啟用一些公共選項以進行基於取樣的最佳化"
 
-#: common.opt:2289
+#: common.opt:2293
 #, fuzzy, no-c-format
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "啟用共同選項用於履行側寫檔反饋導最佳化，而設定 -fprofile-dir="
 
-#: common.opt:2293
+#: common.opt:2297
 #, fuzzy, no-c-format
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "為取樣運算式的值插入相關程式碼"
 
-#: common.opt:2297
+#: common.opt:2301
 #, fuzzy, no-c-format
 msgid "Report on consistency of profile."
 msgstr "內部一致性錯誤"
 
-#: common.opt:2301
+#: common.opt:2305
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "函式重新排序以改善程式碼版面設置"
 
-#: common.opt:2305
+#: common.opt:2309
 #, fuzzy, no-c-format
 msgid "Insert NOP instructions at each function entry."
 msgstr "產生 cld 指令在中函式 prologue。"
 
-#: common.opt:2312
+#: common.opt:2316
 #, fuzzy, no-c-format
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<string>\t製作編譯可再生使用<字串>"
 
-#: common.opt:2322
+#: common.opt:2326
 #, fuzzy, no-c-format
 msgid "Record gcc command line switches in the object file."
 msgstr "記錄 gcc 命令列切換在中目的檔案。"
 
-#: common.opt:2326
+#: common.opt:2330
 #, fuzzy, no-c-format
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "在暫存器中回傳小聚合"
 
-#: common.opt:2334
+#: common.opt:2338
 #, no-c-format
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2345
+#: common.opt:2349
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
 msgstr ""
 
-#: common.opt:2360
+#: common.opt:2364
 #, no-c-format
 msgid "Tell DCE to remove unused C++ allocations."
 msgstr ""
 
-#: common.opt:2364
+#: common.opt:2368
 #, fuzzy, no-c-format
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "啟用暫存器壓力敏感的 insn 排程"
 
-#: common.opt:2368
+#: common.opt:2372
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "進行暫存器重新命名最佳化"
 
-#: common.opt:2372
+#: common.opt:2376
 #, fuzzy, no-c-format
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "進行暫存器重新命名最佳化"
 
-#: common.opt:2376
+#: common.opt:2380
 #, fuzzy, no-c-format
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "基本區塊重新排序以改善程式碼版面設置"
 
-#: common.opt:2380
+#: common.opt:2384
 #, no-c-format
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2393
+#: common.opt:2397
 #, fuzzy, no-c-format
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "重新排序基本區塊和分割進入熱門和 cold 區段"
 
-#: common.opt:2397
+#: common.opt:2401
 #, fuzzy, no-c-format
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "函式重新排序以改善程式碼版面設置"
 
-#: common.opt:2401
+#: common.opt:2405
 #, fuzzy, no-c-format
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "在循環最佳化結束後增加一趟公因式消去"
 
-#: common.opt:2409
+#: common.opt:2413
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "停用假定預設浮點捨入行為的最佳化"
 
-#: common.opt:2413
+#: common.opt:2417
 #, fuzzy, no-c-format
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "啟用基本區塊間的調度"
 
-#: common.opt:2417
+#: common.opt:2421
 #, fuzzy, no-c-format
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "啟用暫存器壓力敏感的 insn 排程"
 
-#: common.opt:2421
+#: common.opt:2425
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "允許非載入的預測移動"
 
-#: common.opt:2425
+#: common.opt:2429
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "允許一些載入的預測移動"
 
-#: common.opt:2429
+#: common.opt:2433
 #, fuzzy, no-c-format
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "允許更多載入的預測移動"
 
-#: common.opt:2433
+#: common.opt:2437
 #, fuzzy, no-c-format
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<number>\t設定詳細度等級的排程程式"
 
-#: common.opt:2437
+#: common.opt:2441
 #, fuzzy, no-c-format
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "如果排程貼文重新載入，做超區塊排程"
 
-#: common.opt:2445
+#: common.opt:2449
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "指派暫存器前重新調度指令"
 
-#: common.opt:2449
+#: common.opt:2453
 #, fuzzy, no-c-format
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "指派暫存器後重新調度指令"
 
-#: common.opt:2456
+#: common.opt:2460
 #, fuzzy, no-c-format
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "排程指令使用選擇性排程演算法"
 
-#: common.opt:2460
+#: common.opt:2464
 #, fuzzy, no-c-format
 msgid "Run selective scheduling after reload."
 msgstr "運行選擇性排程之後重新載入"
 
-#: common.opt:2464
+#: common.opt:2468
 #, no-c-format
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2468
+#: common.opt:2472
 #, fuzzy, no-c-format
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "施行軟體管線操作的內迴圈在的期間選擇性排程"
 
-#: common.opt:2472
+#: common.opt:2476
 #, fuzzy, no-c-format
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "施行軟體管線操作的外迴圈在的期間選擇性排程"
 
-#: common.opt:2476
+#: common.opt:2480
 #, fuzzy, no-c-format
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "重新排程管線的區域而無需管線操作"
 
-#: common.opt:2480
+#: common.opt:2484
 #, no-c-format
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy, no-c-format
 msgid "Allow premature scheduling of queued insns."
 msgstr "允許過早排程的已佇列 insns"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy, no-c-format
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<number>\t設定已佇列 insns 數量該可以是過早已排程"
 
-#: common.opt:2498
+#: common.opt:2502
 #, fuzzy, no-c-format
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "設定 dependence 距離簽入過早排程的已佇列 insns"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy, no-c-format
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<number>\t設定 dependence 距離簽入過早排程的已佇列 insns"
 
-#: common.opt:2506
+#: common.opt:2510
 #, fuzzy, no-c-format
 msgid "Enable the group heuristic in the scheduler."
 msgstr "啟用群組試探在中排程程式"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy, no-c-format
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "啟用關鍵路徑試探在中排程程式"
 
-#: common.opt:2514
+#: common.opt:2518
 #, fuzzy, no-c-format
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "啟用 speculative 指令試探在中排程程式"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy, no-c-format
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "啟用分級試探在中排程程式"
 
-#: common.opt:2522
+#: common.opt:2526
 #, fuzzy, no-c-format
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "啟用最後一筆指令試探在中排程程式"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy, no-c-format
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "啟用附屬計數試探在中排程程式"
 
-#: common.opt:2530
+#: common.opt:2534
 #, fuzzy, no-c-format
 msgid "Access data in the same section from shared anchor points."
 msgstr "存取資料在中相同區段從共享的錨點"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy, no-c-format
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "打開冗餘延伸 Elimination 回合。"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy, no-c-format
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "顯示欄數量在中診斷，若是可用。 預設開"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy, no-c-format
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Emit 函式 prologues 只有之前零件的函式該需要它，"
 
-#: common.opt:2555
+#: common.opt:2559
 #, no-c-format
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2559
+#: common.opt:2563
 #, fuzzy, no-c-format
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "停用為 IEEE 訊息 NaN 可見的最佳化"
 
-#: common.opt:2563
+#: common.opt:2567
 #, fuzzy, no-c-format
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "停用浮點數最佳化該忽略我 signedness 的零"
 
-#: common.opt:2567
+#: common.opt:2571
 #, fuzzy, no-c-format
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "將浮點常數轉換為單精度常數"
 
-#: common.opt:2571
+#: common.opt:2575
 #, fuzzy, no-c-format
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "展開循環時分離歸納變數的生存期"
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy, no-c-format
 msgid "Generate discontiguous stack frames."
 msgstr "產生 discontiguous 堆疊框架"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy, no-c-format
 msgid "Split wide types into independent registers."
 msgstr "分割 wide 類型進入獨立暫存器"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy, no-c-format
 msgid "Split wide types into independent registers earlier."
 msgstr "分割 wide 類型進入獨立暫存器"
 
-#: common.opt:2587
+#: common.opt:2591
 #, fuzzy, no-c-format
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "啟用轉寄傳播於樹"
 
-#: common.opt:2591
+#: common.opt:2595
 #, no-c-format
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, no-c-format
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy, no-c-format
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "展開循環時也展開變數"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy, no-c-format
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[沒有|通用|特定的]\t插入堆疊檢查編碼進入程式"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy, no-c-format
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "插入堆疊檢查編碼進入程式。 如同 -fstack-check=特定的"
 
-#: common.opt:2611
+#: common.opt:2615
 #, no-c-format
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy, no-c-format
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\t陷阱如果堆疊前往過去<暫存器>"
 
-#: common.opt:2623
+#: common.opt:2627
 #, fuzzy, no-c-format
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<name>\t陷阱如果堆疊前往過去符號<名稱>"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy, no-c-format
 msgid "Use propolice as a stack protection method."
 msgstr "使用 propolice 做為堆疊保護方法"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy, no-c-format
 msgid "Use a stack protection method for every function."
 msgstr "使用堆疊保護方法用於每函式"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy, no-c-format
 msgid "Use a smart stack protection method for certain functions."
 msgstr "使用堆疊保護方法用於每函式"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy, no-c-format
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "使用堆疊保護方法用於每函式"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy, no-c-format
 msgid "Output stack usage information on a per-function basis."
 msgstr "輸出堆疊用法資訊於 per-function 基礎"
 
-#: common.opt:2655
+#: common.opt:2659
 #, fuzzy, no-c-format
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "假定套用強重疊規則"
 
-#: common.opt:2659
+#: common.opt:2663
 #, fuzzy, no-c-format
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "對待帶正負號溢位做為未定義"
 
-#: common.opt:2663
+#: common.opt:2667
 #, no-c-format
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2667
+#: common.opt:2671
 #, fuzzy, no-c-format
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "檢查語法錯誤，然後停止"
 
-#: common.opt:2671
+#: common.opt:2675
 #, fuzzy, no-c-format
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "產生「gcov」需要的資料檔案"
 
-#: common.opt:2675
+#: common.opt:2679
 #, fuzzy, no-c-format
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "進行跳轉執行緒最佳化"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy, no-c-format
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "報告每趟組譯的耗時"
 
-#: common.opt:2683
+#: common.opt:2687
 #, no-c-format
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2687
+#: common.opt:2691
 #, fuzzy, no-c-format
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\t設定預設 thread-local 貯藏體編碼產生式樣"
 
-#: common.opt:2706
+#: common.opt:2710
 #, fuzzy, no-c-format
 msgid "Reorder top level functions, variables, and asms."
 msgstr "重新排序頂層函式、變數，而asms"
 
-#: common.opt:2710
+#: common.opt:2714
 #, fuzzy, no-c-format
 msgid "Perform superblock formation via tail duplication."
 msgstr "施行超區塊格式透過尾端複印法"
 
-#: common.opt:2714
+#: common.opt:2718
 #, no-c-format
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2722
+#: common.opt:2726
 #, fuzzy, no-c-format
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "假定浮點運算可能引發陷阱"
 
-#: common.opt:2726
+#: common.opt:2730
 #, fuzzy, no-c-format
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "陷阱用於帶正負號溢位另外、減去和乘法"
 
-#: common.opt:2730
+#: common.opt:2734
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "啟用樹上的 SSA-CCP 最佳化"
 
-#: common.opt:2734
+#: common.opt:2738
 #, fuzzy, no-c-format
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "啟用 SSA-BIT-CCP 最佳化於樹"
 
-#: common.opt:2742
+#: common.opt:2746
 #, fuzzy, no-c-format
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "啟用樹上的循環不變量轉移"
 
-#: common.opt:2750
+#: common.opt:2754
 #, fuzzy, no-c-format
 msgid "Enable SSA coalescing of user variables."
 msgstr "施行變數追蹤並且標籤變數所 uninitialized"
 
-#: common.opt:2758
+#: common.opt:2762
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "在樹層級進行複寫傳遞"
 
-#: common.opt:2766
+#: common.opt:2770
 #, fuzzy, no-c-format
 msgid "Transform condition stores into unconditional ones."
 msgstr "變換條件儲存進入 unconditional 一個"
 
-#: common.opt:2770
+#: common.opt:2774
 #, fuzzy, no-c-format
 msgid "Perform conversions of switch initializations."
 msgstr "施行轉換的切換初始化。"
 
-#: common.opt:2774
+#: common.opt:2778
 #, fuzzy, no-c-format
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "啟用樹上的 SSA 死程式碼消除最佳化"
 
-#: common.opt:2778
+#: common.opt:2782
 #, fuzzy, no-c-format
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "啟用主導最佳化"
 
-#: common.opt:2782
+#: common.opt:2786
 #, fuzzy, no-c-format
 msgid "Enable tail merging on trees."
 msgstr "啟用尾端合併於樹"
 
-#: common.opt:2786
+#: common.opt:2790
 #, fuzzy, no-c-format
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "刪除死存儲"
 
-#: common.opt:2790
+#: common.opt:2794
 #, fuzzy, no-c-format
 msgid "Enable forward propagation on trees."
 msgstr "啟用轉寄傳播於樹"
 
-#: common.opt:2794
+#: common.opt:2798
 #, fuzzy, no-c-format
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "啟用樹上的完全冗餘消除(FRE)"
 
-#: common.opt:2798
+#: common.opt:2802
 #, fuzzy, no-c-format
 msgid "Enable string length optimizations on trees."
 msgstr "啟用字串長度最佳化於樹"
 
-#: common.opt:2802
+#: common.opt:2806
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2808
+#: common.opt:2812
 #, no-c-format
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2815
+#: common.opt:2819
 #, fuzzy, no-c-format
 msgid "Enable loop distribution on trees."
 msgstr "啟用迴圈發布於樹"
 
-#: common.opt:2819
+#: common.opt:2823
 #, fuzzy, no-c-format
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "啟用迴圈發布用於胚騰變換的進入函式庫呼叫"
 
-#: common.opt:2823
+#: common.opt:2827
 #, fuzzy, no-c-format
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "啟用樹上的循環不變量轉移"
 
-#: common.opt:2831
+#: common.opt:2835
 #, fuzzy, no-c-format
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "在循環中產生正規的歸納變數"
 
-#: common.opt:2835
+#: common.opt:2839
 #, fuzzy, no-c-format
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "在樹層級進行循環最佳化"
 
-#: common.opt:2839
+#: common.opt:2843
 #, fuzzy, no-c-format
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "啟用自動 parallelization 的迴圈"
 
-#: common.opt:2843
+#: common.opt:2847
 #, fuzzy, no-c-format
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "啟用 hoisting 載入從條件指標。"
 
-#: common.opt:2847
+#: common.opt:2851
 #, fuzzy, no-c-format
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "啟用樹上的 SSA-PRE 最佳化"
 
-#: common.opt:2851
+#: common.opt:2855
 #, no-c-format
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2855
+#: common.opt:2859
 #, fuzzy, no-c-format
 msgid "Perform function-local points-to analysis on trees."
 msgstr "施行 function-local points-to 分析於樹。"
 
-#: common.opt:2859
+#: common.opt:2863
 #, fuzzy, no-c-format
 msgid "Enable reassociation on tree level."
 msgstr "啟用 reassociation 於樹等級"
 
-#: common.opt:2867
+#: common.opt:2871
 #, fuzzy, no-c-format
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "啟用樹上的 SSA 程式碼下沉最佳化"
 
-#: common.opt:2871
+#: common.opt:2875
 #, fuzzy, no-c-format
 msgid "Perform straight-line strength reduction."
 msgstr "進行強度削減最佳化"
 
-#: common.opt:2875
+#: common.opt:2879
 #, fuzzy, no-c-format
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "為聚合類型進行標量替換"
 
-#: common.opt:2879
+#: common.opt:2883
 #, fuzzy, no-c-format
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "置換暫時的運算式在中 SSA-> 一般回合"
 
-#: common.opt:2883
+#: common.opt:2887
 #, fuzzy, no-c-format
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "施行即時範圍分裂在的期間 SSA-> 一般回合"
 
-#: common.opt:2887
+#: common.opt:2891
 #, fuzzy, no-c-format
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "進行樹上的值欄位傳遞"
 
-#: common.opt:2891
+#: common.opt:2895
 #, no-c-format
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2895
+#: common.opt:2899
 #, no-c-format
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "一次編譯一整個編譯單元"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "展開所有迭代次數已知的循環"
 
-#: common.opt:2908
+#: common.opt:2912
 #, fuzzy, no-c-format
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "展開所有循環"
 
-#: common.opt:2923
+#: common.opt:2927
 #, fuzzy, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "允許最佳化用於浮點算術該項也許會變更"
 
-#: common.opt:2928
+#: common.opt:2932
 #, fuzzy, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "如同 -fassociative-math 用於運算式該項包含除法。"
 
-#: common.opt:2936
+#: common.opt:2940
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "允許可能違反 IEEE 或 ISO 標準的最佳化"
 
-#: common.opt:2940
+#: common.opt:2944
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "外提循環內的測試敘述"
 
-#: common.opt:2944
+#: common.opt:2948
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "進行循環剝離"
 
-#: common.opt:2948
+#: common.opt:2952
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2952
+#: common.opt:2956
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "僅為異常處理產生堆疊展開表"
 
-#: common.opt:2956
+#: common.opt:2960
 #, fuzzy, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2960
+#: common.opt:2964
 #, fuzzy, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2964
+#: common.opt:2968
 #, fuzzy, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2976
+#: common.opt:2980
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "進行變數追蹤"
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "施行變數追蹤由 notating 指派"
 
-#: common.opt:2990
+#: common.opt:2994
 #, fuzzy, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "切換 -fvar-tracking-assignments"
 
-#: common.opt:2998
+#: common.opt:3002
 #, fuzzy, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "施行變數追蹤並且標籤變數所 uninitialized"
 
-#: common.opt:3003
+#: common.opt:3007
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "在樹上進行循環向量化"
 
-#: common.opt:3011
+#: common.opt:3015
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "在樹上進行循環向量化"
 
-#: common.opt:3015
+#: common.opt:3019
 #, fuzzy, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "啟用基本區塊 vectorization (SLP) 於樹"
 
-#: common.opt:3019
+#: common.opt:3023
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:3042
+#: common.opt:3046
 #, fuzzy, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "沒做任何事。 保留的用於回溯相容性。"
 
-#: common.opt:3050
+#: common.opt:3054
 #, fuzzy, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "啟用複製傳用的 scalar-evolution 資訊。"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "為組譯輸出加入額外註釋"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[預設|內部|隱藏|保護的]\t設定預設符號可視性"
 
-#: common.opt:3083
+#: common.opt:3087
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3099
+#: common.opt:3103
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3103
+#: common.opt:3107
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3107
+#: common.opt:3111
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "在最佳化中使用運算式值樣本提供的資訊"
 
-#: common.opt:3111
+#: common.opt:3115
 #, fuzzy, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "建構網頁和分割 unrelated 使用的單一變數"
 
-#: common.opt:3115
+#: common.opt:3119
 #, fuzzy, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "啟用條件無作用程式碼 elimination 用於內建呼叫"
 
-#: common.opt:3119
+#: common.opt:3123
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "進行全程式最佳化"
 
-#: common.opt:3123
+#: common.opt:3127
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "假定有號運算溢出時回繞"
 
-#: common.opt:3127
+#: common.opt:3131
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "假定有號運算溢出時回繞"
 
-#: common.opt:3131
+#: common.opt:3135
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "將初始化為零的資料存放在 bss 區段中"
 
-#: common.opt:3135
+#: common.opt:3139
 #, fuzzy, no-c-format
 #| msgid "Save registers around function calls"
 msgid "Clear call-used registers upon function return."
 msgstr "函式呼叫前後儲存/恢復暫存器值"
 
-#: common.opt:3139
+#: common.opt:3143
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:3143
+#: common.opt:3147
 #, fuzzy, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> 需求組譯器支援用於 CFI 指令"
 
-#: common.opt:3147
+#: common.opt:3151
 #, fuzzy, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> 需求組譯器支援用於 CFI 指令"
 
-#: common.opt:3167
+#: common.opt:3171
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3171
+#: common.opt:3175
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:3175
+#: common.opt:3179
 #, fuzzy, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "產生除錯資訊在中 DWARF v2 (或稍後) 格式"
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Use 32-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Use 64-bit DWARF format when emitting DWARF debug information."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "產生預設擴充格式的除錯資訊"
 
-#: common.opt:3191
+#: common.opt:3195
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "為每個函式產生單一的離開點"
 
-#: common.opt:3195
+#: common.opt:3199
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3203
+#: common.opt:3207
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3207
+#: common.opt:3211
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3215
+#: common.opt:3219
 #, fuzzy, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "記錄 gcc 命令列切換在中 DWARF DW_AT_producer。"
 
-#: common.opt:3219
+#: common.opt:3223
 #, fuzzy, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:3223
+#: common.opt:3227
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "產生 STABS 格式的除錯資訊"
 
-#: common.opt:3227
+#: common.opt:3231
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "產生擴充 STABS 格式的除錯資訊"
 
-#: common.opt:3231
+#: common.opt:3235
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3235
+#: common.opt:3239
 #, fuzzy, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "不 emit DWARF 增加位於之後已選版本"
 
-#: common.opt:3239
+#: common.opt:3243
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3243
+#: common.opt:3247
 #, fuzzy, no-c-format
 msgid "Toggle debug information generation."
 msgstr "切換除錯資訊產生"
 
-#: common.opt:3247
+#: common.opt:3251
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3254
+#: common.opt:3258
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "產生 VMS 格式的除錯資訊"
 
-#: common.opt:3258
+#: common.opt:3262
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "產生 XCOFF 格式的除錯資訊"
 
-#: common.opt:3262
+#: common.opt:3266
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "產生 XCOFF 擴充格式的除錯資訊"
 
-#: common.opt:3280
+#: common.opt:3284
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "產生 isel 指令"
 
-#: common.opt:3284
+#: common.opt:3288
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3291
+#: common.opt:3295
 #, fuzzy, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\t設定<dir>為預設外掛程式目錄"
 
-#: common.opt:3295
+#: common.opt:3299
 #, fuzzy, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <dir>\t設定<dir>為 multilib 包含子目錄"
 
-#: common.opt:3320
+#: common.opt:3324
 #, fuzzy, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <file>\t置放輸出進入<檔案>"
 
-#: common.opt:3324
+#: common.opt:3328
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "啟用函式取樣"
 
-#: common.opt:3334
+#: common.opt:3338
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "與 -pedantic 類似，但將它們視作錯誤"
 
-#: common.opt:3374
+#: common.opt:3378
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "不顯示編譯的函式或逝去的時間"
 
-#: common.opt:3406
+#: common.opt:3410
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "啟用詳細輸出"
 
-#: common.opt:3410
+#: common.opt:3414
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "顯示編譯器版本"
 
-#: common.opt:3414
+#: common.opt:3418
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "不顯示警告"
 
-#: common.opt:3424
+#: common.opt:3428
 #, fuzzy, no-c-format
 msgid "Create a shared library."
 msgstr "建立共用函式庫"
 
-#: common.opt:3472
+#: common.opt:3476
 #, fuzzy, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:3476
+#: common.opt:3480
 #, fuzzy, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:3480
+#: common.opt:3484
 #, fuzzy, no-c-format
 msgid "Create a static position independent executable."
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:3487
+#: common.opt:3491
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -20320,1164 +20321,1174 @@ msgstr ""
 
 #: params.opt:162
 #, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:167
+#, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
 msgstr ""
 
-#: params.opt:166
+#: params.opt:171
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
 msgstr ""
 
-#: params.opt:170
+#: params.opt:175
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
 msgstr ""
 
-#: params.opt:174
+#: params.opt:179
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload"
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
 msgstr "重新載入後允許進行冗餘消除的關鍵邊執行次數的比例閾值"
 
-#: params.opt:178
+#: params.opt:183
 #, fuzzy, no-c-format
 #| msgid "The threshold ratio for performing partial redundancy elimination after reload"
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
 msgstr "重新載入後進行部分冗餘消除的比例閾值"
 
-#: params.opt:182
+#: params.opt:187
 #, fuzzy, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
 msgstr "縮放比例因子在中 calculation 的最大值距離運算式可以被移動由 GCSE 最佳化"
 
-#: params.opt:186
+#: params.opt:191
 #, fuzzy, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
 msgstr "成本於該項 GCSE 最佳化將無法條件約束距離運算式可以旅遊"
 
-#: params.opt:190
+#: params.opt:195
 #, fuzzy, no-c-format
 #| msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap"
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
 msgstr "引發無用收集的堆展開的最小值，以占堆總大小的百分比給出"
 
-#: params.opt:194
+#: params.opt:199
 #, fuzzy, no-c-format
 #| msgid "Minimum heap size before we start collecting garbage, in kilobytes"
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
 msgstr "開始無用回收時最小的堆大小，以千位元組表示"
 
-#: params.opt:198
+#: params.opt:203
 #, no-c-format
 msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
 msgstr ""
 
-#: params.opt:202
+#: params.opt:207
 #, no-c-format
 msgid "Whether codegen errors should be ICEs when -fchecking."
 msgstr ""
 
-#: params.opt:206
+#: params.opt:211
 #, fuzzy, no-c-format
 msgid "Maximum number of arrays per SCoP."
 msgstr "最大值參數數量在中 SCoP"
 
-#: params.opt:210
+#: params.opt:215
 #, fuzzy, no-c-format
 msgid "Maximum number of parameters in a SCoP."
 msgstr "最大值參數數量在中 SCoP"
 
-#: params.opt:214
+#: params.opt:219
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
 msgstr ""
 
-#: params.opt:218
+#: params.opt:223
 #, fuzzy, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
 msgstr "選取分數的最大計數的重複的基本區塊在中程式給定的基本區塊需要必須被認為熱門"
 
-#: params.opt:222
+#: params.opt:227
 #, no-c-format
 msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
 msgstr ""
 
-#: params.opt:226
+#: params.opt:231
 #, fuzzy, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
 msgstr "選取分數的最大頻率的執行的基本區塊在中函式給定的基本區塊需要必須被認為熱門"
 
-#: params.opt:230
+#: params.opt:235
 #, no-c-format
 msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
 msgstr ""
 
-#: params.opt:234
+#: params.opt:239
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
 msgstr ""
 
-#: params.opt:238
+#: params.opt:243
 #, fuzzy, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
 msgstr "如何太多可以給定的編譯單元 grow 因為內聯 (在中百分比)"
 
-#: params.opt:242
+#: params.opt:247
 #, fuzzy, no-c-format
 #| msgid "The upper bound for sharing integer constants"
 msgid "The upper bound for sharing integer constants."
 msgstr "共享整型常數的上界"
 
-#: params.opt:246
+#: params.opt:251
 #, fuzzy, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
 msgstr "臨界值 ipa-cp 機會求值該仍然是認為的 beneficial 到仿本。"
 
-#: params.opt:250
+#: params.opt:255
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
 msgstr ""
 
-#: params.opt:254
+#: params.opt:259
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "內聯函式中巢狀內聯的最大深度"
 
-#: params.opt:258
+#: params.opt:263
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
 msgstr "僅當被執行的呼叫的概率超過此參數時方進行遞迴地內聯"
 
-#: params.opt:262
+#: params.opt:267
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:266
+#: params.opt:271
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
 msgstr ""
 
-#: params.opt:270
+#: params.opt:275
 #, fuzzy, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
 msgstr "如何太多可以給定的編譯單元 grow 因為 interprocedural 常數傳用 (在中百分比)"
 
-#: params.opt:274
+#: params.opt:279
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit that IPA-CP pass considers large."
 msgstr "超過這個大小的翻譯單元被認為是大的"
 
-#: params.opt:278
+#: params.opt:283
 #, fuzzy, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
 msgstr "最大容量的值清單的關聯的與每個參數用於 interprocedural 常數傳用"
 
-#: params.opt:282
+#: params.opt:287
 #, no-c-format
 msgid "Maximum number of statements visited during jump function offset discovery."
 msgstr ""
 
-#: params.opt:286
+#: params.opt:291
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
 msgstr ""
 
-#: params.opt:290
+#: params.opt:295
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
 msgstr ""
 
-#: params.opt:294
+#: params.opt:299
 #, fuzzy, no-c-format
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "最大值條件儲存對數量該可以是 sunk"
 
-#: params.opt:298
+#: params.opt:303
 #, no-c-format
 msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
 msgstr ""
 
-#: params.opt:302
+#: params.opt:307
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
 msgstr ""
 
-#: params.opt:306
+#: params.opt:311
 #, no-c-format
 msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
 msgstr ""
 
-#: params.opt:310
+#: params.opt:315
 #, fuzzy, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
 msgstr "最大值允許的增長的大小的新參數 ipa-sra 置換指標到彙總與"
 
-#: params.opt:314
+#: params.opt:319
 #, fuzzy, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
 msgstr "暫存器數量在中每個類別 kept 未使用的由迴圈 invariant 移動"
 
-#: params.opt:318
+#: params.opt:323
 #, fuzzy, no-c-format
 msgid "Max size of conflict table in MB."
 msgstr "最大尺寸的衝突表格在中 MB"
 
-#: params.opt:322
+#: params.opt:327
 #, fuzzy, no-c-format
 msgid "Max loops number for regional RA."
 msgstr "最大迴圈數字用於 regional RA"
 
-#: params.opt:326
+#: params.opt:331
 #, fuzzy, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
 msgstr "如果 candidates 數量在中設定是較小，我們一律試著移除未使用的 ivs 在的期間它的最佳化"
 
-#: params.opt:330
+#: params.opt:335
 #, fuzzy, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
 msgstr "約束於 candidates 數量下列的該所有 candidates 被認為在中 iv 最佳化"
 
-#: params.opt:334
+#: params.opt:339
 #, fuzzy, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "約束於 iv 使用數量循環最佳化的在中 iv 最佳化"
 
-#: params.opt:338
+#: params.opt:343
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
 msgstr ""
 
-#: params.opt:342
+#: params.opt:347
 #, no-c-format
 msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
 msgstr ""
 
-#: params.opt:346
+#: params.opt:351
 #, fuzzy, no-c-format
 msgid "The size of L1 cache line."
 msgstr "大小的 L1 快取列"
 
-#: params.opt:350
+#: params.opt:355
 #, fuzzy, no-c-format
 msgid "The size of L1 cache."
 msgstr "大小的 L1 快取"
 
-#: params.opt:354
+#: params.opt:359
 #, fuzzy, no-c-format
 msgid "The size of L2 cache."
 msgstr "大小的 L2 快取"
 
-#: params.opt:358
+#: params.opt:363
 #, fuzzy, no-c-format
 #| msgid "Maximal growth due to inlining of large function (in percent)"
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "內聯大函式造成的程式碼膨脹的上限(以百分數的形式給出)"
 
-#: params.opt:362
+#: params.opt:367
 #, fuzzy, no-c-format
 #| msgid "The size of function body to be considered large"
 msgid "The size of function body to be considered large."
 msgstr "超過這個大小的函式體被認為是大的"
 
-#: params.opt:366
+#: params.opt:371
 #, fuzzy, no-c-format
 msgid "The size of stack frame to be considered large."
 msgstr "大小的堆疊框架為認為的大"
 
-#: params.opt:370
+#: params.opt:375
 #, fuzzy, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "最大堆疊框架增長由於內聯 (在中百分比)"
 
-#: params.opt:374
+#: params.opt:379
 #, fuzzy, no-c-format
 #| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit to be considered large."
 msgstr "超過這個大小的翻譯單元被認為是大的"
 
-#: params.opt:378
+#: params.opt:383
 #, no-c-format
 msgid "Maximum number of concurrently open C++ module files when lazy loading."
 msgstr ""
 
-#: params.opt:382
+#: params.opt:387
 #, fuzzy, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
 msgstr "最小成本的 expensive 運算式在中迴圈 invariant 移動"
 
-#: params.opt:386
+#: params.opt:391
 #, no-c-format
 msgid "True if a non-short-circuit operation is optimal."
 msgstr ""
 
-#: params.opt:390
+#: params.opt:395
 #, fuzzy, no-c-format
 msgid "Size of tiles for loop blocking."
 msgstr "大小的並排用於迴圈阻塞"
 
-#: params.opt:394
+#: params.opt:399
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "單一循環中考慮展開的平均最大指令數"
 
-#: params.opt:398
+#: params.opt:403
 #, no-c-format
 msgid "The minimum stride ratio for loop interchange to be profitable."
 msgstr ""
 
-#: params.opt:402
+#: params.opt:407
 #, fuzzy, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
 msgstr "最大基本區塊數字循環用於迴圈 invariant 移動"
 
-#: params.opt:406
+#: params.opt:411
 #, fuzzy, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
 msgstr "最大值 datarefs 數量循環用於建立迴圈資料依存性"
 
-#: params.opt:410
+#: params.opt:415
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "最大值指令數量在中基本區塊為認為的用於 SLP vectorization"
 
-#: params.opt:414
+#: params.opt:419
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "單一循環中考慮展開的最大指令數"
 
-#: params.opt:418
+#: params.opt:423
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
 msgstr ""
 
-#: params.opt:422
+#: params.opt:427
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
 msgstr ""
 
-#: params.opt:426
+#: params.opt:431
 #, fuzzy, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
 msgstr "最少大小的分割用於 LTO (在中估計的指令)"
 
-#: params.opt:430
+#: params.opt:435
 #, no-c-format
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr ""
 
-#: params.opt:434
+#: params.opt:439
 #, fuzzy, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
 msgstr "最少大小的分割用於 LTO (在中估計的指令)"
 
-#: params.opt:438
+#: params.opt:443
 #, fuzzy, no-c-format
 msgid "Number of partitions the program should be split to."
 msgstr "分割區數量程式應該是分割到"
 
-#: params.opt:442
+#: params.opt:447
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "單一循環中考慮展開的平均最大指令數"
 
-#: params.opt:446
+#: params.opt:451
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of insns combine tries to combine."
 msgstr "考慮進行交叉跳轉的最大入邊數量"
 
-#: params.opt:450
+#: params.opt:455
 #, fuzzy, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
 msgstr "最大值深度的迴圈巢狀我們完全 peel"
 
-#: params.opt:454
+#: params.opt:459
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop that is peeled completely"
 msgid "The maximum number of peelings of a single loop that is peeled completely."
 msgstr "一個完全剝離的單一循環最大的剝離數"
 
-#: params.opt:458
+#: params.opt:463
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a completely peeled loop"
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "一個完全剝離的循環所能有的最大指令數"
 
-#: params.opt:462
+#: params.opt:467
 #, fuzzy, no-c-format
 #| msgid "The maximum number of incoming edges to consider for crossjumping"
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "考慮進行交叉跳轉的最大入邊數量"
 
-#: params.opt:466
+#: params.opt:471
 #, fuzzy, no-c-format
 msgid "The maximum instructions CSE process before flushing."
 msgstr "最大值指令 CSE 處理之前清理"
 
-#: params.opt:470
+#: params.opt:475
 #, fuzzy, no-c-format
 #| msgid "The maximum length of path considered in cse"
 msgid "The maximum length of path considered in cse."
 msgstr "公因式消去時考慮的最大路徑長度"
 
-#: params.opt:474
+#: params.opt:479
 #, fuzzy, no-c-format
 #| msgid "The maximum memory locations recorded by cselib"
 msgid "The maximum memory locations recorded by cselib."
 msgstr "cselib 可指派的最大記憶體量"
 
-#: params.opt:478
+#: params.opt:483
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
 msgstr ""
 
-#: params.opt:482
+#: params.opt:487
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to fill a delay slot"
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "考慮填充入延遲槽中的最大指令數"
 
-#: params.opt:486
+#: params.opt:491
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to find accurate live register information"
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "用以發現準確的作用中暫存器資訊的最大指令數量"
 
-#: params.opt:490
+#: params.opt:495
 #, fuzzy, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
 msgstr "最大值現用本地儲存數量在中 RTL 無作用儲存體 elimination"
 
-#: params.opt:494
+#: params.opt:499
 #, fuzzy, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "最大值數量巢狀的間接內聯施行的由早期 inliner"
 
-#: params.opt:498
+#: params.opt:503
 #, fuzzy, no-c-format
 #| msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable"
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
 msgstr "在指標分析之前的結構變數中欄位的最大數目，將該結構視為單一變數"
 
-#: params.opt:502
+#: params.opt:507
 #, fuzzy, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
 msgstr "最大值基本區塊數量各函式為分析的由石墨"
 
-#: params.opt:506
+#: params.opt:511
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
 msgstr ""
 
-#: params.opt:510
+#: params.opt:515
 #, fuzzy, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "最大值 nops 數量到插入用於提示 (預設 2)"
 
-#: params.opt:514
+#: params.opt:519
 #, fuzzy, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
 msgstr "最大值比率的插入到刪除的運算式在中 GCSE"
 
-#: params.opt:518
+#: params.opt:523
 #, fuzzy, no-c-format
 #| msgid "The maximum amount of memory to be allocated by GCSE"
 msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
 msgstr "GCSE 可指派的最大記憶體量"
 
-#: params.opt:522
+#: params.opt:527
 #, fuzzy, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "最大值 insns 數量到重製時 unfactoring 計算的前往"
 
-#: params.opt:526
+#: params.opt:531
 #, fuzzy, no-c-format
 #| msgid "The maximum expansion factor when copying basic blocks"
 msgid "The maximum expansion factor when copying basic blocks."
 msgstr "複製基本區塊時最大的展開因子"
 
-#: params.opt:530
+#: params.opt:535
 #, fuzzy, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
 msgstr "最大值深度的搜尋在中 dominator 樹用於運算式到 hoist"
 
-#: params.opt:534
+#: params.opt:539
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "自動內聯時指令的最大數量"
 
-#: params.opt:538
+#: params.opt:543
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "由於巢狀內聯造成的內聯函式程式碼膨脹的上限值(指令數)"
 
-#: params.opt:542
+#: params.opt:547
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions non-inline function can grow to via recursive inlining"
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "由於巢狀內聯造成的非內聯函式程式碼膨脹的上限值(指令數)"
 
-#: params.opt:546
+#: params.opt:551
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "單一可內聯的函式體最多能包含的指令數"
 
-#: params.opt:550
+#: params.opt:555
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when inlining for size."
 msgstr "自動內聯時指令的最大數量"
 
-#: params.opt:554
+#: params.opt:559
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "自動內聯時指令的最大數量"
 
-#: params.opt:558
+#: params.opt:563
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "內聯函式中巢狀內聯的最大深度"
 
-#: params.opt:562
+#: params.opt:567
 #, fuzzy, no-c-format
 #| msgid "The maximum depth of recursive inlining for non-inline functions"
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "非內聯函式中巢狀內聯的最大深度"
 
-#: params.opt:566
+#: params.opt:571
 #, fuzzy, no-c-format
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "最大值次數量該 insn 可能被已排程"
 
-#: params.opt:570
+#: params.opt:575
 #, fuzzy, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
 msgstr "約束在之上成本的運算式到計算反覆運算數量"
 
-#: params.opt:574
+#: params.opt:579
 #, fuzzy, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
 msgstr "約束在之上反覆運算數量 brute 強制 # 的反覆運算分析演算法評估"
 
-#: params.opt:578
+#: params.opt:583
 #, fuzzy, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
 msgstr "最大值敘述數量允許的在中區塊該需要被重製時執行緒跳躍"
 
-#: params.opt:582
+#: params.opt:587
 #, fuzzy, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
 msgstr "最大值 RTL 節點數量該可以被記錄做為 combiner's 最後一筆值"
 
-#: params.opt:586
+#: params.opt:591
 #, fuzzy, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
 msgstr "最大值 insns 數量到重製時 unfactoring 計算的前往"
 
-#: params.opt:590
+#: params.opt:595
 #, fuzzy, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
 msgstr "最大值回溯試圖數量排程程式應該製作時 modulo 排程迴圈"
 
-#: params.opt:594
+#: params.opt:599
 #, fuzzy, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
 msgstr "最大值長度的部分 antic 設定時履行樹 pre 最佳化"
 
-#: params.opt:598
+#: params.opt:603
 #, fuzzy, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
 msgstr "最大值反覆運算數量透過 CFG 到延伸區域"
 
-#: params.opt:602
+#: params.opt:607
 #, fuzzy, no-c-format
 #| msgid "The maximum number of peelings of a single loop"
 msgid "The maximum number of peelings of a single loop."
 msgstr "單一循環最大的剝離數"
 
-#: params.opt:606
+#: params.opt:611
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of a peeled loop"
 msgid "The maximum number of insns of a peeled loop."
 msgstr "剝離後的循環所能有的最大指令數"
 
-#: params.opt:610
+#: params.opt:615
 #, fuzzy, no-c-format
 #| msgid "The maximum length of scheduling's pending operations list"
 msgid "The maximum length of scheduling's pending operations list."
 msgstr "調度候選作業清單的最大長度"
 
-#: params.opt:614 params.opt:658
+#: params.opt:619 params.opt:663
 #, fuzzy, no-c-format
 #| msgid "The maximum number of blocks in a region to be considered for interblock scheduling"
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "一個區域中考慮進行塊間調度的最大塊數"
 
-#: params.opt:618 params.opt:662
+#: params.opt:623 params.opt:667
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "一個區域中考慮進行塊間調度的最大指令數"
 
-#: params.opt:622
+#: params.opt:627
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
 msgstr ""
 
-#: params.opt:626
+#: params.opt:631
 #, fuzzy, no-c-format
 #| msgid "The maximum number of loop iterations we predict statically"
 msgid "The maximum number of loop iterations we predict statically."
 msgstr "靜態預測時的最多循環次數"
 
-#: params.opt:630
+#: params.opt:635
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to search backward when looking for equivalent reload"
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "後向搜尋以尋找等價多載入時要搜尋的最大指令數量"
 
-#: params.opt:634
+#: params.opt:639
 #, fuzzy, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "最大值指令數量在中基本區塊為認為的用於 SLP vectorization"
 
-#: params.opt:638
+#: params.opt:643
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
 msgstr ""
 
-#: params.opt:642
+#: params.opt:647
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
 msgstr ""
 
-#: params.opt:646
+#: params.opt:651
 #, fuzzy, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
 msgstr "最大值反覆運算數量透過 CFG 到延伸區域"
 
-#: params.opt:650
+#: params.opt:655
 #, fuzzy, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
 msgstr "最大值衝突延遲用於 insn 為認為的用於 speculative 移動"
 
-#: params.opt:654
+#: params.opt:659
 #, fuzzy, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
 msgstr "最大值指令數量準備好發放為認為的由排程程式在的期間第一個排程回合"
 
-#: params.opt:666
+#: params.opt:671
 #, fuzzy, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
 msgstr "進行強度削減最佳化"
 
-#: params.opt:670
+#: params.opt:675
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively."
 msgstr ""
 
-#: params.opt:674
+#: params.opt:679
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
 msgstr ""
 
-#: params.opt:678
+#: params.opt:683
 #, fuzzy, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
 msgstr "最大值現用本地儲存數量在中 RTL 無作用儲存體 elimination"
 
-#: params.opt:682
+#: params.opt:687
 #, fuzzy, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
 msgstr "最大值條件儲存對數量該可以是 sunk"
 
-#: params.opt:686 params.opt:690
+#: params.opt:691 params.opt:695
 #, fuzzy, no-c-format
 msgid "Maximum number of store chains to track at the same time in the store merging pass."
 msgstr "最大值現用本地儲存數量在中 RTL 無作用儲存體 elimination"
 
-#: params.opt:694
+#: params.opt:699
 #, fuzzy, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
 msgstr "最大值數目的類似的 bbs 到比較 bb 與"
 
-#: params.opt:698
+#: params.opt:703
 #, fuzzy, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
 msgstr "最大值數目的反覆運算的回合之上函式"
 
-#: params.opt:702
+#: params.opt:707
 #, fuzzy, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
 msgstr "最大值字串數量用於該項 strlen 最佳化回合將軌段字串長度"
 
-#: params.opt:706
+#: params.opt:711
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
 msgstr ""
 
-#: params.opt:710
+#: params.opt:715
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unrollings of a single loop"
 msgid "The maximum number of unrollings of a single loop."
 msgstr "單一循環最多可以被展開的次數"
 
-#: params.opt:714
+#: params.opt:719
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "單一循環中考慮展開的最大指令數"
 
-#: params.opt:718
+#: params.opt:723
 #, fuzzy, no-c-format
 #| msgid "The maximum number of insns of an unswitched loop"
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "去開關後的循環所能有的最大指令數"
 
-#: params.opt:722
+#: params.opt:727
 #, fuzzy, no-c-format
 #| msgid "The maximum number of unswitchings in a single loop"
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "單一循環中考慮去開關的最大指令數"
 
-#: params.opt:726
+#: params.opt:731
 #, fuzzy, no-c-format
 #| msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling"
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
 msgstr "如果使用了 -fvariable-expansion-in-unroller，即指單一變數在循環展開時可以同時被展開的次數"
 
-#: params.opt:730
+#: params.opt:735
 #, fuzzy, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
 msgstr "最大遞迴深度用於展開 var 追蹤運算式"
 
-#: params.opt:734
+#: params.opt:739
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
 msgstr ""
 
-#: params.opt:738
+#: params.opt:743
 #, fuzzy, no-c-format
 msgid "Max. size of var tracking hash tables."
 msgstr "最大大小的 var 追蹤雜湊表"
 
-#: params.opt:742
+#: params.opt:747
 #, no-c-format
 msgid "Maximum number of VALUEs handled during a single find_base_term call."
 msgstr ""
 
-#: params.opt:746
+#: params.opt:751
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP."
 msgstr ""
 
-#: params.opt:750
+#: params.opt:755
 #, fuzzy, no-c-format
 #| msgid "The minimum number of matching instructions to consider for crossjumping"
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "考慮進行交叉跳轉的最小匹配指令數量"
 
-#: params.opt:754
+#: params.opt:759
 #, fuzzy, no-c-format
 #| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
 msgstr "僅當被執行的呼叫的概率超過此參數時方進行遞迴地內聯"
 
-#: params.opt:758
+#: params.opt:763
 #, fuzzy, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
 msgstr "最小。比率的 insns 到 prefetches 以啟用 prefetching 用於迴圈與不明旅程計數"
 
-#: params.opt:762
+#: params.opt:767
 #, no-c-format
 msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
 msgstr ""
 
-#: params.opt:766
+#: params.opt:771
 #, fuzzy, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
 msgstr "最小 UID 為用於 nondebug insn"
 
-#: params.opt:770
+#: params.opt:775
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
 msgstr ""
 
-#: params.opt:774
+#: params.opt:779
 #, fuzzy, no-c-format
 #| msgid "The minimum probability of reaching a source block for interblock speculative scheduling"
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
 msgstr "區塊間預測調度時到達一個來源塊的最小概率"
 
-#: params.opt:778
+#: params.opt:783
 #, fuzzy, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
 msgstr "如果 -ftree-vectorize 被使用，最少迴圈約束的迴圈為認為的用於 vectorization"
 
-#: params.opt:782
+#: params.opt:787
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:800
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:786
+#: params.opt:804
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop"
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
 msgstr "單一循環中考慮展開的最大指令數"
 
-#: params.opt:790
+#: params.opt:808
 #, no-c-format
 msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
 msgstr ""
 
-#: params.opt:812
+#: params.opt:830
 #, fuzzy, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
 msgstr "最大值可能性的條目 BB 的分割區域 (在中百分比相對於條目 BB 的函式) 要讓部分內聯發生"
 
-#: params.opt:816
+#: params.opt:834
 #, fuzzy, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
 msgstr "最大估計的 outcome 的分支認為的可預測"
 
-#: params.opt:820
+#: params.opt:838
 #, no-c-format
 msgid "Whether software prefetch hints should be issued for non-constant strides."
 msgstr ""
 
-#: params.opt:824
+#: params.opt:842
 #, fuzzy, no-c-format
 msgid "The number of insns executed before prefetch is completed."
 msgstr "insns 數量執行的之前 prefetch 被已完成"
 
-#: params.opt:828
+#: params.opt:846
 #, fuzzy, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
 msgstr "最小。比率的 insns 到 mem ops 以啟用 prefetching 在中迴圈"
 
-#: params.opt:832
+#: params.opt:850
 #, no-c-format
 msgid "The minimum constant stride beyond which we should use prefetch hints for."
 msgstr ""
 
-#: params.opt:836
+#: params.opt:854
 #, no-c-format
 msgid "Use internal function id in profile lookup."
 msgstr ""
 
-#: params.opt:840
+#: params.opt:858
 #, fuzzy, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
 msgstr "最大值深度的迴圈巢狀我們完全 peel"
 
-#: params.opt:844
+#: params.opt:862
 #, fuzzy, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
 msgstr "最大值條件儲存對數量該可以是 sunk"
 
-#: params.opt:848
+#: params.opt:866
 #, fuzzy, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
 msgstr "約束在之上 complexity 的運算式在中純量演化分析器"
 
-#: params.opt:852
+#: params.opt:870
 #, fuzzy, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
 msgstr "約束於大小的運算式已用於純量演化分析器"
 
-#: params.opt:856
+#: params.opt:874
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
 msgstr ""
 
-#: params.opt:860
+#: params.opt:878
 #, fuzzy, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
 msgstr "最少間距    可能會衝突儲存和載入"
 
-#: params.opt:864
+#: params.opt:882
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
 msgstr ""
 
-#: params.opt:868
+#: params.opt:886
 #, fuzzy, no-c-format
 msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
 msgstr "最少可能性的 speculation 成功 (在中百分比)，因而該 speculative insn 將被已排程。"
 
-#: params.opt:872
+#: params.opt:890
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
 msgstr ""
 
-#: params.opt:876
+#: params.opt:894
 #, fuzzy, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "最大值指令數量在中就緒清單所認為的合格用於重新命名"
 
-#: params.opt:880
+#: params.opt:898
 #, fuzzy, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
 msgstr "最大容量的期望視窗的選擇性排程"
 
-#: params.opt:884
+#: params.opt:902
 #, fuzzy, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
 msgstr "最大值次數量該 insn 可能被已排程"
 
-#: params.opt:888
+#: params.opt:906
 #, fuzzy, no-c-format
 msgid "The number of prefetches that can run at the same time."
 msgstr "prefetches 數量該可以運行同時"
 
-#: params.opt:892
+#: params.opt:910
 #, fuzzy, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
 msgstr "目標區塊相對的執行頻率 (做為百分比) 必要項到槽敘述"
 
-#: params.opt:896
+#: params.opt:914
 #, fuzzy, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
 msgstr "週期數量 Swing 類別 modulo 排程程式認為時檢查衝突使用 DFA"
 
-#: params.opt:900
+#: params.opt:918
 #, fuzzy, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
 msgstr "臨界值在之上平均值迴圈計數認為的由 Swing 類別 modulo 排程程式"
 
-#: params.opt:904
+#: params.opt:922
 #, fuzzy, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
 msgstr "因子用於調校上限該 Swing 類別 modulo 排程程式用於排程迴圈"
 
-#: params.opt:908
+#: params.opt:926
 #, fuzzy, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
 msgstr "最小值的階段計數該 Swing 類別 modulo 排程程式將產生。"
 
-#: params.opt:912
+#: params.opt:930
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
 msgstr ""
 
-#: params.opt:916
+#: params.opt:934
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
 msgstr ""
 
-#: params.opt:920
+#: params.opt:938
 #, no-c-format
 msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
 msgstr ""
 
-#: params.opt:924
+#: params.opt:942
 #, fuzzy, no-c-format
 #| msgid "The maximum number of instructions to consider to unroll in a loop on average"
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "單一循環中考慮展開的平均最大指令數"
 
-#: params.opt:928
+#: params.opt:946
 #, fuzzy, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
 msgstr "下限用於緩衝區為認為的用於堆疊 smashing 保護"
 
-#: params.opt:932
+#: params.opt:950
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:936
+#: params.opt:954
 #, no-c-format
 msgid "Interval in which to probe the stack expressed as a power of two in bytes."
 msgstr ""
 
-#: params.opt:940
+#: params.opt:958
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
 msgstr ""
 
-#: params.opt:944
+#: params.opt:962
 #, no-c-format
 msgid "Maximum size of a single store merging region in bytes."
 msgstr ""
 
-#: params.opt:948
+#: params.opt:966
 #, fuzzy, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
 msgstr "最大值比率介於陣列大小和切換分支用於切換轉換到發生"
 
-#: params.opt:952
+#: params.opt:970
 #, fuzzy, no-c-format
 msgid "Maximum number of bases stored in each modref tree."
 msgstr "最大值參數數量在中 SCoP"
 
-#: params.opt:956
+#: params.opt:974
 #, fuzzy, no-c-format
 msgid "Maximum number of references stored in each modref base."
 msgstr "最大值參數數量在中 SCoP"
 
-#: params.opt:960
+#: params.opt:978
 #, fuzzy, no-c-format
 msgid "Maximum number of accesses stored in each modref reference."
 msgstr "最大值現用本地儲存數量在中 RTL 無作用儲存體 elimination"
 
-#: params.opt:964
+#: params.opt:982
 #, fuzzy, no-c-format
 msgid "Maximum number of tests performed by modref query."
 msgstr "最大值條件儲存對數量該可以是 sunk"
 
-#: params.opt:968
+#: params.opt:986
 #, no-c-format
 msgid "Maximum depth of DFS walk used by modref escape analysis."
 msgstr ""
 
-#: params.opt:972
+#: params.opt:990
 #, fuzzy, no-c-format
 msgid "Maximum number of escape points tracked by modref per SSA-name."
 msgstr "最大值次數量該 insn 可能被已排程"
 
-#: params.opt:976
+#: params.opt:994
 #, fuzzy, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
 msgstr "大小在中位元組之後該項 thread-local 彙總應該被器具與記錄檔函式以代替儲存/還原對"
 
-#: params.opt:980
+#: params.opt:998
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
 msgstr "必須被蹤跡形成所覆寫的函式百分比，以執行頻率加權。當取樣反饋無法使用時使用"
 
-#: params.opt:984
+#: params.opt:1002
 #, fuzzy, no-c-format
 #| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available"
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
 msgstr "必須被蹤跡形成所覆寫的函式百分比，以執行頻率加權。當取樣反饋可用時使用"
 
-#: params.opt:988
+#: params.opt:1006
 #, fuzzy, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "最大編碼增長造成的由尾端複印法 (在中百分比)"
 
-#: params.opt:992
+#: params.opt:1010
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
 msgstr "當最優邊的概率小於此限值(以百分數表示)時，停止前向增長。當取樣反饋無法使用時使用。"
 
-#: params.opt:996
+#: params.opt:1014
 #, fuzzy, no-c-format
 #| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available"
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
 msgstr "當最優邊的概率小於此限值(以百分數表示)時，停止前向增長。當取樣反饋可用時使用。"
 
-#: params.opt:1000
+#: params.opt:1018
 #, fuzzy, no-c-format
 #| msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)"
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
 msgstr "當最優邊的反向概率小於此閾值(以百分數表示)時停止反向增長"
 
-#: params.opt:1004
+#: params.opt:1022
 #, fuzzy, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
 msgstr "設定最大值指令數量執行的在中平行在中 reassociated 樹。如果 0, 使用目標附屬試探。"
 
-#: params.opt:1008
+#: params.opt:1026
 #, fuzzy, no-c-format
 #| msgid "Emit implicit instantiations of templates"
 msgid "Emit special instrumentation for accesses to volatiles."
 msgstr "允許範本隱含實體化"
 
-#: params.opt:1012
+#: params.opt:1030
 #, no-c-format
 msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
 msgstr ""
 
-#: params.opt:1016
+#: params.opt:1034
 #, fuzzy, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
 msgstr "最大值命名空間數量到搜尋替代方案時名稱查找失敗"
 
-#: params.opt:1020
+#: params.opt:1038
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "使用子程式完成函式前言/尾聲"
 
-#: params.opt:1024
+#: params.opt:1042
 #, fuzzy, no-c-format
 #| msgid "Use subroutines for function prologues and epilogues"
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "使用子程式完成函式前言/尾聲"
 
-#: params.opt:1028
+#: params.opt:1046
 #, no-c-format
 msgid "Instruction accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1032
+#: params.opt:1050
 #, no-c-format
 msgid "Time accounted for function thunk overhead."
 msgstr ""
 
-#: params.opt:1036
+#: params.opt:1054
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
 msgstr ""
 
-#: params.opt:1040
+#: params.opt:1058
 #, no-c-format
 msgid "Maximum unroll factor for the unroll-and-jam transformation."
 msgstr ""
 
-#: params.opt:1044
+#: params.opt:1062
 #, no-c-format
 msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
 msgstr ""
 
-#: params.opt:1048
+#: params.opt:1066
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
 msgstr ""
 
-#: params.opt:1052
+#: params.opt:1070
 #, fuzzy, no-c-format
 msgid "Whether to use canonical types."
 msgstr "是否要使用權威的類型"
 
-#: params.opt:1056
+#: params.opt:1074
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop epilogue vectorization using smaller vector size."
 msgstr "在樹上進行循環向量化"
 
-#: params.opt:1060
+#: params.opt:1078
 #, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
 msgstr ""
 
-#: params.opt:1064
+#: params.opt:1082
 #, fuzzy, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
 msgstr "約束於執行時檢查數量插入的由 vectorizer's 迴圈定版用於別名檢查"
 
-#: params.opt:1068
+#: params.opt:1086
 #, fuzzy, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "約束於執行時檢查數量插入的由 vectorizer's 迴圈定版用於對齊檢查"
 
-#: params.opt:1072
+#: params.opt:1090
 #, no-c-format
 msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
 msgstr ""
@@ -21513,7 +21524,7 @@ msgid "expected boolean type"
 msgstr "預期的布林值型態"
 
 #: go/gofrontend/expressions.cc:5155 c/c-parser.c:15375 c/c-parser.c:15382
-#: cp/parser.c:37455 cp/parser.c:37462
+#: cp/parser.c:37508 cp/parser.c:37515
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -21591,7 +21602,7 @@ msgstr "不足引數"
 #: go/gofrontend/expressions.cc:10181 go/gofrontend/expressions.cc:10262
 #: go/gofrontend/expressions.cc:10335 go/gofrontend/expressions.cc:11146
 #: go/gofrontend/expressions.cc:12226 go/gofrontend/expressions.cc:12240
-#: go/gofrontend/expressions.cc:12261 cp/pt.c:9041
+#: go/gofrontend/expressions.cc:12261 cp/pt.c:9065
 #, fuzzy, gcc-internal-format
 msgid "too many arguments"
 msgstr "太多引數"
@@ -22015,7 +22026,7 @@ msgstr "%qE 屬性衝突與屬性 %s"
 
 #: attribs.c:455 c-family/c-attribs.c:886 c-family/c-attribs.c:2340
 #: c-family/c-attribs.c:2805 c-family/c-attribs.c:4513
-#: c-family/c-attribs.c:4606 cp/decl.c:15180 cp/friend.c:303 cp/tree.c:4932
+#: c-family/c-attribs.c:4606 cp/decl.c:15198 cp/friend.c:303 cp/tree.c:4993
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
@@ -22070,7 +22081,7 @@ msgstr "型態屬性忽略的之後型態已經定義"
 #. is a constraint violation if it is not one of the known
 #. standard attributes.  Diagnose it here with a pedwarn and
 #. then discard it to prevent a duplicate warning later.
-#: attribs.c:729 attribs.c:1637 attribs.c:1647 attribs.c:1657
+#: attribs.c:729 attribs.c:1714 attribs.c:1724 attribs.c:1734
 #: c-family/c-attribs.c:914 c-family/c-attribs.c:976 c-family/c-attribs.c:995
 #: c-family/c-attribs.c:1013 c-family/c-attribs.c:1043
 #: c-family/c-attribs.c:1064 c-family/c-attribs.c:1085
@@ -22099,20 +22110,20 @@ msgstr "型態屬性忽略的之後型態已經定義"
 #: c-family/c-attribs.c:5171 c-family/c-attribs.c:5253
 #: c-family/c-attribs.c:5309 c-family/c-attribs.c:5325
 #: c-family/c-attribs.c:5479 c-family/c-common.c:5809 c-family/c-common.c:5812
-#: config/darwin.c:2131 config/arm/arm.c:7253 config/arm/arm.c:7281
-#: config/arm/arm.c:7298 config/avr/avr.c:9675 config/csky/csky.c:6108
+#: config/darwin.c:2126 config/arm/arm.c:7262 config/arm/arm.c:7290
+#: config/arm/arm.c:7307 config/avr/avr.c:9675 config/csky/csky.c:6108
 #: config/csky/csky.c:6130 config/h8300/h8300.c:4918 config/h8300/h8300.c:4942
-#: config/i386/i386-options.c:3474 config/i386/i386-options.c:3632
-#: config/i386/i386-options.c:3864 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:20292 ada/gcc-interface/utils.c:6576
+#: config/i386/i386-options.c:3487 config/i386/i386-options.c:3645
+#: config/i386/i386-options.c:3877 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:20409 ada/gcc-interface/utils.c:6576
 #: ada/gcc-interface/utils.c:6592 ada/gcc-interface/utils.c:6621
 #: ada/gcc-interface/utils.c:6638 ada/gcc-interface/utils.c:6655
 #: ada/gcc-interface/utils.c:6670 ada/gcc-interface/utils.c:6686
 #: ada/gcc-interface/utils.c:6712 ada/gcc-interface/utils.c:6781
 #: ada/gcc-interface/utils.c:6808 ada/gcc-interface/utils.c:6829
 #: ada/gcc-interface/utils.c:6850 ada/gcc-interface/utils.c:6866
-#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4624
-#: c/c-decl.c:4627 c/c-decl.c:4642 c/c-parser.c:4961 jit/dummy-frontend.c:185
+#: ada/gcc-interface/utils.c:6921 brig/brig-lang.c:484 c/c-decl.c:4623
+#: c/c-decl.c:4626 c/c-decl.c:4641 c/c-parser.c:4961 jit/dummy-frontend.c:185
 #: lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute ignored"
@@ -22123,8 +22134,8 @@ msgstr "%qE 屬性被忽略"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2106 cp/decl.c:2152 cp/decl.c:2169
-#: cp/decl.c:2782 cp/decl.c:3237
+#: attribs.c:1007 cp/decl.c:1200 cp/decl.c:2104 cp/decl.c:2150 cp/decl.c:2167
+#: cp/decl.c:2777 cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -22135,59 +22146,59 @@ msgstr "%q+D 的前一個宣告"
 msgid "ignoring attributes applied to %qT after definition"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: attribs.c:1568
+#: attribs.c:1645
 #, gcc-internal-format
 msgid "%q+D already declared with dllexport attribute: dllimport ignored"
 msgstr "%q+D 已被宣告為具有 dllexport 屬性：忽略 dllimport"
 
-#: attribs.c:1580
+#: attribs.c:1657
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
 msgstr "%q+D 重宣告時沒有 dllimport 屬性，但已被做為 dllimport 連結參照過"
 
-#: attribs.c:1594
+#: attribs.c:1671
 #, gcc-internal-format
 msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
 msgstr "%q+D 重宣告時沒有 dllimport 屬性：忽略先前的 dllimport"
 
-#: attribs.c:1675
+#: attribs.c:1752
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared as  dllimport: attribute ignored"
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "內聯函式 %q+D 宣告為 dllimport：忽略此屬性"
 
-#: attribs.c:1683
+#: attribs.c:1760
 #, gcc-internal-format
 msgid "function %q+D definition is marked dllimport"
 msgstr "函式 %q+D 的定義被標記為 dllimport"
 
-#: attribs.c:1691
+#: attribs.c:1768
 #, gcc-internal-format
 msgid "variable %q+D definition is marked dllimport"
 msgstr "變數 %q+D 的定義被標記為 dllimport"
 
-#: attribs.c:1722
+#: attribs.c:1799
 #, fuzzy, gcc-internal-format
 msgid "external linkage required for symbol %q+D because of %qE attribute"
 msgstr "外部連結必要項用於符號 %q+D 因為 %qE 屬性"
 
-#: attribs.c:1736
+#: attribs.c:1813
 #, fuzzy, gcc-internal-format
 msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
 msgstr "%qE 意味著預設可視性，但是 %qD 已宣告的與不同的可視性"
 
-#: attribs.c:1999
+#: attribs.c:2076
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 
-#: attribs.c:2005 attribs.c:2025
+#: attribs.c:2082 attribs.c:2102
 #, fuzzy, gcc-internal-format
 msgid "%qD target declared here"
 msgstr "%qD 被宣告在此"
 
-#: attribs.c:2019
+#: attribs.c:2096
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
@@ -22289,7 +22300,7 @@ msgstr "參考 %qs 無法宣告 %<mutable%>"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "偏移量超過字串常數界"
 
-#: builtins.c:1454 cp/name-lookup.c:6424
+#: builtins.c:1454 cp/name-lookup.c:6441
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qD 宣告的在此"
@@ -22314,724 +22325,724 @@ msgstr "%<__builtin_prefetch%> 的第三個引數必須是一個常數"
 msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
 msgstr "%<__builtin_prefetch%> 的第三個引數無效；使用 0"
 
-#: builtins.c:3954
+#: builtins.c:3958
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:3956 calls.c:1730
+#: builtins.c:3960 calls.c:1730
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3961
+#: builtins.c:3965
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E may exceed maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:3963
+#: builtins.c:3967
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E exceeds maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:3970
+#: builtins.c:3974
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:3972 calls.c:1735
+#: builtins.c:3976 calls.c:1735
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3978
+#: builtins.c:3982
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:3980
+#: builtins.c:3984
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:3990
+#: builtins.c:3994
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed source size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:3992
+#: builtins.c:3996
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds source size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:3997
+#: builtins.c:4001
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E may exceed source size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:3999
+#: builtins.c:4003
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E exceeds source size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4006
+#: builtins.c:4010
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed source size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4008
+#: builtins.c:4012
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds source size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4013
+#: builtins.c:4017
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] may exceed source size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4015
+#: builtins.c:4019
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds source size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4024
+#: builtins.c:4028
 #, fuzzy, gcc-internal-format
 msgid "source object declared here"
 msgstr "%qD 宣告的在此"
 
-#: builtins.c:4027
+#: builtins.c:4031
 #, fuzzy, gcc-internal-format
 msgid "source object allocated here"
 msgstr "宣告的在此"
 
-#: builtins.c:4042
+#: builtins.c:4046
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified size %E may exceed maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4044
+#: builtins.c:4048
 #, gcc-internal-format
 msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4049
+#: builtins.c:4053
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size %E may exceed maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4051
+#: builtins.c:4055
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size %E exceeds maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4058
+#: builtins.c:4062
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified size between %E and %E may exceed maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4060
+#: builtins.c:4064
 #, gcc-internal-format
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:4066
+#: builtins.c:4070
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size between %E and %E may exceed maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4068
+#: builtins.c:4072
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified size between %E and %E exceeds maximum object size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4078
+#: builtins.c:4082
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed destination size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4080
+#: builtins.c:4084
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4085
+#: builtins.c:4089
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound %E may exceed destination size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4087
+#: builtins.c:4091
 #, gcc-internal-format
 msgid "%Kspecified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:4094
+#: builtins.c:4098
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] may exceed destination size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4096
+#: builtins.c:4100
 #, fuzzy, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds destination size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4101 builtins.c:4103
+#: builtins.c:4105 builtins.c:4107
 #, fuzzy, gcc-internal-format
 msgid "%Kspecified bound [%E, %E] exceeds destination size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4113
+#: builtins.c:4117
 #, fuzzy, gcc-internal-format
 msgid "destination object declared here"
 msgstr "%qD 被宣告在此"
 
-#: builtins.c:4116
+#: builtins.c:4120
 #, fuzzy, gcc-internal-format
 msgid "destination object allocated here"
 msgstr "function-definition 未被允許在此"
 
-#: builtins.c:4143
+#: builtins.c:4147
 #, gcc-internal-format
 msgid "%K%qD may access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4145
+#: builtins.c:4149
 #, gcc-internal-format
 msgid "%K%qD accessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4148
+#: builtins.c:4152
 #, gcc-internal-format
 msgid "%K%qD may access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4150
+#: builtins.c:4154
 #, gcc-internal-format
 msgid "%K%qD accessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4155
+#: builtins.c:4159
 #, gcc-internal-format
 msgid "%Kmay access %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4157
+#: builtins.c:4161
 #, gcc-internal-format
 msgid "%Kaccessing %E byte in a region of size %E"
 msgstr ""
 
-#: builtins.c:4160
+#: builtins.c:4164
 #, gcc-internal-format
 msgid "%Kmay access %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4162
+#: builtins.c:4166
 #, gcc-internal-format
 msgid "%Kaccessing %E bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4171
+#: builtins.c:4175
 #, gcc-internal-format
 msgid "%K%qD may access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4173
+#: builtins.c:4177
 #, gcc-internal-format
 msgid "%K%qD accessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4178
+#: builtins.c:4182
 #, gcc-internal-format
 msgid "%Kmay access %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4180
+#: builtins.c:4184
 #, gcc-internal-format
 msgid "%Kaccessing %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4188
+#: builtins.c:4192
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may access between %E and %E bytes in a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4190
+#: builtins.c:4194
 #, fuzzy, gcc-internal-format
 msgid "%K%qD accessing between %E and %E bytes in a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4196
+#: builtins.c:4200
 #, fuzzy, gcc-internal-format
 msgid "%Kmay access between %E and %E bytes in a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4198
+#: builtins.c:4202
 #, fuzzy, gcc-internal-format
 msgid "%Kaccessing between %E and %E bytes in a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4211
+#: builtins.c:4215
 #, gcc-internal-format
 msgid "%K%qD may write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4213
+#: builtins.c:4217
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4216
+#: builtins.c:4220
 #, gcc-internal-format
 msgid "%K%qD may write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4218
+#: builtins.c:4222
 #, gcc-internal-format
 msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4223
+#: builtins.c:4227
 #, gcc-internal-format
 msgid "%Kmay write %E byte into a region of size %E"
 msgstr ""
 
-#: builtins.c:4225
+#: builtins.c:4229
 #, gcc-internal-format
 msgid "%Kwriting %E byte into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4228
+#: builtins.c:4232
 #, gcc-internal-format
 msgid "%Kmay write %E bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4230
+#: builtins.c:4234
 #, gcc-internal-format
 msgid "%Kwriting %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4239
+#: builtins.c:4243
 #, gcc-internal-format
 msgid "%K%qD may write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4241 builtins.c:4779
+#: builtins.c:4245 builtins.c:4783
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4247
+#: builtins.c:4251
 #, gcc-internal-format
 msgid "%Kmay write %E or more bytes into a region of size %E"
 msgstr ""
 
-#: builtins.c:4249 builtins.c:4784
+#: builtins.c:4253 builtins.c:4788
 #, gcc-internal-format
 msgid "%Kwriting %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4258
+#: builtins.c:4262
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may write between %E and %E bytes into a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4260
+#: builtins.c:4264
 #, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4267
+#: builtins.c:4271
 #, fuzzy, gcc-internal-format
 msgid "%Kmay write between %E and %E bytes into a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4269
+#: builtins.c:4273
 #, gcc-internal-format
 msgid "%Kwriting between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:4284
+#: builtins.c:4288
 #, gcc-internal-format
 msgid "%K%qD may read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4286
+#: builtins.c:4290
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4289
+#: builtins.c:4293
 #, gcc-internal-format
 msgid "%K%qD may read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4291
+#: builtins.c:4295
 #, gcc-internal-format
 msgid "%K%qD reading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4297
+#: builtins.c:4301
 #, gcc-internal-format
 msgid "%Kmay read %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4299
+#: builtins.c:4303
 #, gcc-internal-format
 msgid "%Kreading %E byte from a region of size %E"
 msgstr ""
 
-#: builtins.c:4302
+#: builtins.c:4306
 #, gcc-internal-format
 msgid "%Kmay read %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4304
+#: builtins.c:4308
 #, gcc-internal-format
 msgid "%Kreading %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4313
+#: builtins.c:4317
 #, gcc-internal-format
 msgid "%K%qD may read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4315
+#: builtins.c:4319
 #, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4320
+#: builtins.c:4324
 #, gcc-internal-format
 msgid "%Kmay read %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4322
+#: builtins.c:4326
 #, gcc-internal-format
 msgid "%Kreading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4330
+#: builtins.c:4334
 #, fuzzy, gcc-internal-format
 msgid "%K%qD may read between %E and %E bytes from a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4332
+#: builtins.c:4336
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4337
+#: builtins.c:4341
 #, fuzzy, gcc-internal-format
 msgid "%Kmay read between %E and %E bytes from a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4339
+#: builtins.c:4343
 #, gcc-internal-format
 msgid "%Kreading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:4354
+#: builtins.c:4358
 #, gcc-internal-format
 msgid "%K%qD expecting %E byte in a region of size %E"
 msgid_plural "%K%qD expecting %E bytes in a region of size %E"
 msgstr[0] ""
 
-#: builtins.c:4359
+#: builtins.c:4363
 #, gcc-internal-format
 msgid "%Kexpecting %E byte in a region of size %E"
 msgid_plural "%Kexpecting %E bytes in a region of size %E"
 msgstr[0] ""
 
-#: builtins.c:4367
+#: builtins.c:4371
 #, gcc-internal-format
 msgid "%K%qD expecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4371
+#: builtins.c:4375
 #, gcc-internal-format
 msgid "%Kexpecting %E or more bytes in a region of size %E"
 msgstr ""
 
-#: builtins.c:4378
+#: builtins.c:4382
 #, fuzzy, gcc-internal-format
 msgid "%K%qD expecting between %E and %E bytes in a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4382
+#: builtins.c:4386
 #, fuzzy, gcc-internal-format
 msgid "%Kexpecting between %E and %E bytes in a region of size %E"
 msgstr "大小的陣列 %qE 是負"
 
-#: builtins.c:4545
+#: builtins.c:4549
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into destination object %qE of size %s"
 msgstr "%qD 被宣告在此"
 
-#: builtins.c:4548
+#: builtins.c:4552
 #, gcc-internal-format
 msgid "destination object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4554
+#: builtins.c:4558
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into destination object of size %s allocated by %qE"
 msgstr "%qD 被宣告在此"
 
-#: builtins.c:4557
+#: builtins.c:4561
 #, gcc-internal-format
 msgid "destination object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:4565
+#: builtins.c:4569
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into source object %qE of size %s"
 msgstr "內聯函式 %q+D 宣告的 weak"
 
-#: builtins.c:4568
+#: builtins.c:4572
 #, gcc-internal-format
 msgid "source object %qE of size %s"
 msgstr ""
 
-#: builtins.c:4575
+#: builtins.c:4579
 #, fuzzy, gcc-internal-format
 msgid "at offset %s into source object of size %s allocated by %qE"
 msgstr "%qD 被宣告在此"
 
-#: builtins.c:4578
+#: builtins.c:4582
 #, gcc-internal-format
 msgid "source object of size %s allocated by %qE"
 msgstr ""
 
-#: builtins.c:6425 builtins.c:6498
+#: builtins.c:6429 builtins.c:6502
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:7390 gimplify.c:3383
+#: builtins.c:7394 gimplify.c:3383
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "給函式 %<va_start%> 的參數太少"
 
-#: builtins.c:7490
+#: builtins.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid argument to %qD"
 msgstr "錯誤地使用了 %qD"
 
-#: builtins.c:7503
+#: builtins.c:7507
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "不受支援的引數類型到內建函式"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:7511
+#: builtins.c:7515
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:7841 builtins.c:7881
+#: builtins.c:7845 builtins.c:7885
 #, fuzzy, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "兩者引數到 %<__builtin___clear_cache%>必須是指標"
 
-#: builtins.c:7971
+#: builtins.c:7975
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "trampoline 產生的用於巢狀的函式 %qD"
 
-#: builtins.c:8366 builtins.c:8379
+#: builtins.c:8370 builtins.c:8383
 #, fuzzy, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD 變更的語意在中 GCC 4.4"
 
-#: builtins.c:8485
+#: builtins.c:8489
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:8493
+#: builtins.c:8497
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "無效的記憶體式樣引數到內建"
 
-#: builtins.c:8554 builtins.c:8681
+#: builtins.c:8558 builtins.c:8685
 #, fuzzy, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "失敗記憶體式樣無法 stronger 比成功記憶體式樣用於 %<__atomic_compare_exchange%>"
 
-#: builtins.c:8562 builtins.c:8689
+#: builtins.c:8566 builtins.c:8693
 #, fuzzy, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "無效的失敗記憶體式樣用於 %<__atomic_compare_exchange%>"
 
-#: builtins.c:8747
+#: builtins.c:8751
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "無效的記憶體式樣用於 %<__atomic_load%>"
 
-#: builtins.c:8779 builtins.c:8972
+#: builtins.c:8783 builtins.c:8976
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "無效的記憶體式樣用於 %<__atomic_store%>"
 
-#: builtins.c:9093
+#: builtins.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 1 to %qs"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: builtins.c:9135
+#: builtins.c:9139
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-integer argument 1 to %qs"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: builtins.c:9199
+#: builtins.c:9203
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
 
-#: builtins.c:9219
+#: builtins.c:9223
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
 
-#: builtins.c:9278
+#: builtins.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s not supported: ignored"
 msgid "%qs only supported in OpenACC code"
 msgstr "-f%s 不受支援：已忽略"
 
-#: builtins.c:9285
+#: builtins.c:9289
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 0 to %qs"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: builtins.c:9297
+#: builtins.c:9301
 #, fuzzy, gcc-internal-format
 msgid "illegal argument 0 to %qs"
 msgstr "缺少引數到 %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:9755 expr.c:11247
+#: builtins.c:9759 expr.c:11247
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kinvalid 使用的 %<__builtin_va_arg_pack()%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:9761
+#: builtins.c:9765
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kinvalid 使用的 %<__builtin_va_arg_pack_len()%>"
 
-#: builtins.c:10093
+#: builtins.c:10097
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> 的第二個引數必須是 1"
 
-#: builtins.c:10986
+#: builtins.c:10990
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "目的格式不支援無限大浮點數"
 
-#: builtins.c:12607
+#: builtins.c:12611
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "在定參數的函式中使用了 %<va_start%>"
 
-#: builtins.c:12615
+#: builtins.c:12619
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "錯誤的引數數量到函式 %<va_start%>"
 
-#: builtins.c:12630
+#: builtins.c:12634
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "呼叫 %<__builtin_next_arg%> 時沒有給定引數"
 
-#: builtins.c:12635
+#: builtins.c:12639
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "錯誤的引數數量到函式 %<__builtin_next_arg%>"
 
-#: builtins.c:12668
+#: builtins.c:12672
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%> 的第二個參數不是最後一個具名參數"
 
-#: builtins.c:12681
+#: builtins.c:12685
 #, fuzzy, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "未定義的行為時秒參數的 %<va_start%> 被宣告與 %<register%>貯藏體"
 
-#: builtins.c:12710
+#: builtins.c:12714
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kfirst 引數的 %D 必須是指標，秒整數常數"
 
-#: builtins.c:12723
+#: builtins.c:12727
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Klast 引數的 %D 不是整數常數介於 0 和 3"
 
-#: builtins.c:13526
+#: builtins.c:13530
 #, gcc-internal-format
 msgid "%K%qD called on pointer %qE with nonzero offset%s"
 msgstr ""
 
-#: builtins.c:13531 builtins.c:13595 gimple-ssa-isolate-paths.c:412
-#: tree.c:13239 tree.c:13276 c/c-typeck.c:2939 c/c-typeck.c:3026
-#: c/c-typeck.c:5541 c/c-typeck.c:10767 c/c-typeck.c:10784
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7278 cp/call.c:9295
-#: cp/constexpr.c:843 cp/constexpr.c:3583 cp/cvt.c:1077 cp/cvt.c:1115
-#: cp/decl.c:8251 cp/decl.c:15330 cp/decl.c:15709 cp/decl2.c:5623
-#: cp/decl2.c:5674 cp/parser.c:20758 cp/pt.c:8849 cp/semantics.c:2093
-#: cp/semantics.c:3337 cp/semantics.c:4424 cp/typeck.c:1803 cp/typeck.c:2020
-#: cp/typeck.c:4091 cp/typeck.c:9787
+#: builtins.c:13535 builtins.c:13599 gimple-ssa-isolate-paths.c:412
+#: tree.c:13239 tree.c:13276 c/c-typeck.c:2989 c/c-typeck.c:3076
+#: c/c-typeck.c:5601 c/c-typeck.c:10827 c/c-typeck.c:10844
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7282 cp/call.c:9315
+#: cp/constexpr.c:844 cp/constexpr.c:3638 cp/cvt.c:1077 cp/cvt.c:1115
+#: cp/decl.c:8257 cp/decl.c:15348 cp/decl.c:15727 cp/decl2.c:5624
+#: cp/decl2.c:5675 cp/parser.c:20795 cp/pt.c:8873 cp/semantics.c:2112
+#: cp/semantics.c:3355 cp/semantics.c:4452 cp/typeck.c:1814 cp/typeck.c:2031
+#: cp/typeck.c:4102 cp/typeck.c:9794
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "宣告的在此"
 
-#: builtins.c:13541 builtins.c:13666
+#: builtins.c:13545 builtins.c:13670
 #, fuzzy, gcc-internal-format
 msgid "returned from %qD"
 msgstr "必要項從 %q#D\n"
 
-#: builtins.c:13544
+#: builtins.c:13548
 #, fuzzy, gcc-internal-format
 msgid "returned from %qT"
 msgstr "必要項從 %q#D\n"
 
-#: builtins.c:13546
+#: builtins.c:13550
 #, fuzzy, gcc-internal-format
 msgid "obtained here"
 msgstr "聯合定義的在此"
 
-#: builtins.c:13589
+#: builtins.c:13593
 #, gcc-internal-format
 msgid "%K%qD called on unallocated object %qD"
 msgstr ""
 
-#: builtins.c:13609
+#: builtins.c:13613
 #, gcc-internal-format
 msgid "%K%qD called on a pointer to an unallocated object %qE"
 msgstr ""
 
-#: builtins.c:13618
+#: builtins.c:13622
 #, fuzzy, gcc-internal-format
 msgid "assigned here"
 msgstr "聯合定義的在此"
 
-#: builtins.c:13647
+#: builtins.c:13651
 #, gcc-internal-format
 msgid "%K%qD called on pointer returned from a mismatched allocation function"
 msgstr ""
 
-#: builtins.c:13656
+#: builtins.c:13660
 #, gcc-internal-format
 msgid "%K%qD called on pointer to an unallocated object"
 msgstr ""
@@ -23809,306 +23820,306 @@ msgstr "基本區塊無法 laid 向下順序的"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "bb 記事數量在中 insn 鏈接 (%d) !=n_basic_blocks (%d)"
 
-#: cgraph.c:3139
+#: cgraph.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "呼叫邊計數為負"
 
-#: cgraph.c:3235
+#: cgraph.c:3246
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3240
+#: cgraph.c:3251
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3270
+#: cgraph.c:3281
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3276
+#: cgraph.c:3287
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3282 cgraph.c:3312
+#: cgraph.c:3293 cgraph.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3300
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3300
+#: cgraph.c:3311
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3319
+#: cgraph.c:3330
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3332
+#: cgraph.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "缺少形狀參數用於呼叫到 %s 於 %L"
 
-#: cgraph.c:3337
+#: cgraph.c:3348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "在區塊 %i 之後缺少邊界"
 
-#: cgraph.c:3346
+#: cgraph.c:3357
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3386
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "為邊 %s->%s 設定 AUX 欄位"
 
-#: cgraph.c:3382
+#: cgraph.c:3393
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3387
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: cgraph.c:3392
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "內聯仿本被所需的"
 
-#: cgraph.c:3399
+#: cgraph.c:3410
 #, fuzzy, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: cgraph.c:3404
+#: cgraph.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "假定符號可能無效"
 
-#: cgraph.c:3409
+#: cgraph.c:3420
 #, fuzzy, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "外部可見的內聯仿本"
 
-#: cgraph.c:3414
+#: cgraph.c:3425
 #, fuzzy, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "內聯仿本與位址佔用"
 
-#: cgraph.c:3419
+#: cgraph.c:3430
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "內聯仿本被所需的"
 
-#: cgraph.c:3426
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3431
+#: cgraph.c:3442
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3438
+#: cgraph.c:3449
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "回傳與值在中函式不具任何傳回類型"
 
-#: cgraph.c:3446
+#: cgraph.c:3457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux 欄位設定用於間接邊緣從 %s"
 
-#: cgraph.c:3452 cgraph.c:3512
+#: cgraph.c:3463 cgraph.c:3523
 #, fuzzy, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: cgraph.c:3460
+#: cgraph.c:3471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "間接邊緣從 %s 未被標記為間接或已關聯的 indirectinfo(_I)，相應敘述是："
 
-#: cgraph.c:3468 cgraph.c:3539
+#: cgraph.c:3479 cgraph.c:3550
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3480
+#: cgraph.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3490
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to pointer 錯誤"
 
-#: cgraph.c:3495
+#: cgraph.c:3506
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "多個內聯呼叫者"
 
-#: cgraph.c:3502
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "為非內聯的呼叫者設定了 inlined_to pointer"
 
-#: cgraph.c:3529
+#: cgraph.c:3540
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "呼叫者邊緣頻率 %i 不匹配 BB 頻率 %i"
 
-#: cgraph.c:3560
+#: cgraph.c:3571
 #, fuzzy, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "收到的郵件邊緣計數不匹配 PHI 引數數量"
 
-#: cgraph.c:3577
+#: cgraph.c:3588
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3588
+#: cgraph.c:3599
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlinedto 指標是設定並不是找到任何 predecessors(_T)"
 
-#: cgraph.c:3593
+#: cgraph.c:3604
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to pointer 參照自身"
 
-#: cgraph.c:3604
+#: cgraph.c:3615
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "節點有錯誤的 cloneof(_O)"
 
-#: cgraph.c:3617
+#: cgraph.c:3628
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "節點有錯誤的仿本清單"
 
-#: cgraph.c:3623
+#: cgraph.c:3634
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: cgraph.c:3628
+#: cgraph.c:3639
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "節點有錯誤的 prevclone 指標(_C)"
 
-#: cgraph.c:3633
+#: cgraph.c:3644
 #, fuzzy, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "雙倍鏈結的仿本清單的已損壞"
 
-#: cgraph.c:3645
+#: cgraph.c:3656
 #, fuzzy, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "別名有呼叫邊緣"
 
-#: cgraph.c:3651
+#: cgraph.c:3662
 #, fuzzy, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "別名有 non-alias 參考"
 
-#: cgraph.c:3656
+#: cgraph.c:3667
 #, fuzzy, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "別名有超過一個別名參考"
 
-#: cgraph.c:3663
+#: cgraph.c:3674
 #, fuzzy, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "分析的別名沒有任何參考"
 
-#: cgraph.c:3672
+#: cgraph.c:3683
 #, fuzzy, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "沒有邊緣超出 thunk 節點"
 
-#: cgraph.c:3677
+#: cgraph.c:3688
 #, fuzzy, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "超過一個邊緣超出 thunk 節點"
 
-#: cgraph.c:3682
+#: cgraph.c:3693
 #, fuzzy, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Thunk 未被猜想到有內文"
 
-#: cgraph.c:3716
+#: cgraph.c:3727
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "共享的 call_stmt："
 
-#: cgraph.c:3724
+#: cgraph.c:3735
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "邊緣指到不對的宣告："
 
-#: cgraph.c:3733
+#: cgraph.c:3744
 #, fuzzy, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "間接邊緣與不明被呼叫端相應到 callstmt 與已知宣告(_S)："
 
-#: cgraph.c:3743
+#: cgraph.c:3754
 #, fuzzy, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "缺少callgraph 邊緣用於呼叫 stmt："
 
-#: cgraph.c:3753
+#: cgraph.c:3764
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "需要敘述"
 
-#: cgraph.c:3766
+#: cgraph.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "邊緣 %s->%s 沒有任何相應 callstmt(_S)"
 
-#: cgraph.c:3778
+#: cgraph.c:3789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "間接邊緣從 %s 沒有任何相應 callstmt(_S)"
 
-#: cgraph.c:3797 cgraph.c:3810
+#: cgraph.c:3808 cgraph.c:3821
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3802
+#: cgraph.c:3813
 #, fuzzy, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "轉換的暫存器到不同的大小"
 
-#: cgraph.c:3818
+#: cgraph.c:3829
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node 失敗"
 
-#: cgraph.c:3940 varpool.c:304
+#: cgraph.c:3951 varpool.c:304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s：區段 %s 缺少"
@@ -24194,12 +24205,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%<weakref%> 屬性忽略的因為變數被初始化的"
 
 #. include_self=
-#: cgraphunit.c:1082 c/c-decl.c:12107
+#: cgraphunit.c:1082 c/c-decl.c:12106
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F 使用過但從未定義"
 
-#: cgraphunit.c:1084 c/c-decl.c:12117
+#: cgraphunit.c:1084 c/c-decl.c:12116
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
@@ -24274,7 +24285,7 @@ msgstr "%q+D 回傳值的大小為 %u 位元組"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "%q+D 回傳值的大小為 %wd 位元組"
 
-#: cgraphunit.c:2394
+#: cgraphunit.c:2390
 #, fuzzy, gcc-internal-format
 msgid "nodes with unreleased memory found"
 msgstr "節點與 unreleased 記憶體找到"
@@ -24686,12 +24697,12 @@ msgstr ""
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
 msgstr "多重 EH 身分被支援只有與組譯器支援.cfipersonality 指令(_P)"
 
-#: dwarf2out.c:11050
+#: dwarf2out.c:11059
 #, gcc-internal-format
 msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14644
+#: dwarf2out.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) 找到在中變數位置"
@@ -24711,7 +24722,7 @@ msgstr "共享的 rtx"
 msgid "internal consistency failure"
 msgstr "內部一致性錯誤"
 
-#: emit-rtl.c:4038
+#: emit-rtl.c:4039
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE：需要 emit_jump_insn 時使用了 emit_insn used where：\n"
@@ -24842,42 +24853,42 @@ msgstr "無法關閉最後的 insn 傾印檔案 %qs：%m"
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "大定點常數隱含地截短至定點型態"
 
-#: fold-const.c:4617 fold-const.c:4627
+#: fold-const.c:4618 fold-const.c:4628
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由於位元段寬度所限，比較結果永遠為 %d"
 
-#: fold-const.c:5981 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
+#: fold-const.c:5982 tree-ssa-reassoc.c:2736 tree-ssa-reassoc.c:3752
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "假設帶正負號溢位不發生時簡化範圍測試"
 
-#: fold-const.c:6441 fold-const.c:6455
+#: fold-const.c:6442 fold-const.c:6456
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比較結果始終為 %d"
 
-#: fold-const.c:6599
+#: fold-const.c:6600
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "對兩個不匹配的不等比較取 %<or%> 的結果總為 1"
 
-#: fold-const.c:6604
+#: fold-const.c:6605
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "對兩個互斥的相等比較取 %<and%> 的結果永遠是 0"
 
-#: fold-const.c:9811
+#: fold-const.c:9812
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "假設帶正負號溢位不發生時縮小常數在中比較"
 
-#: fold-const.c:10211
+#: fold-const.c:10212
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "假設帶正負號溢位不發生時合併常數周圍比較"
 
-#: fold-const.c:13468
+#: fold-const.c:13469
 #, fuzzy, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折疊檢查：原來的樹變更的由折疊"
@@ -24892,7 +24903,7 @@ msgstr "總計大小的區域物件太大"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "總計大小的區域物件太大"
 
-#: function.c:1786 gimplify.c:6328 gimplify.c:6488
+#: function.c:1786 gimplify.c:6329 gimplify.c:6489
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> 中不可能的約束"
@@ -25523,7 +25534,7 @@ msgstr "空指標"
 msgid "function may return address of local variable"
 msgstr "函式回傳局部變數的位址"
 
-#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10861
+#: gimple-ssa-isolate-paths.c:409 c/c-typeck.c:10921
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "函式回傳局部變數的位址"
@@ -25880,62 +25891,62 @@ msgstr ""
 msgid "%Gnull format string"
 msgstr "%s 在中格式字串於 %L"
 
-#: gimple-ssa-warn-alloca.c:288
+#: gimple-ssa-warn-alloca.c:287
 #, fuzzy
 msgid "%Guse of %<alloca%>"
 msgstr "無效的使用的 %<auto%>"
 
-#: gimple-ssa-warn-alloca.c:324
+#: gimple-ssa-warn-alloca.c:323
 #, fuzzy
 msgid "%Gargument to variable-length array may be too large"
 msgstr "警告如果變數長度陣列被使用"
 
-#: gimple-ssa-warn-alloca.c:326
+#: gimple-ssa-warn-alloca.c:325
 #, fuzzy
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "字串長度於 %L 太大"
 
-#: gimple-ssa-warn-alloca.c:332
+#: gimple-ssa-warn-alloca.c:331
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument may be as large as %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:344
+#: gimple-ssa-warn-alloca.c:343
 #, fuzzy
 msgid "%Gargument to variable-length array is too large"
 msgstr "警告如果變數長度陣列被使用"
 
-#: gimple-ssa-warn-alloca.c:346
+#: gimple-ssa-warn-alloca.c:345
 #, fuzzy
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "字串長度於 %L 太大"
 
-#: gimple-ssa-warn-alloca.c:351
+#: gimple-ssa-warn-alloca.c:350
 #, gcc-internal-format
 msgid "limit is %wu bytes, but argument is %s"
 msgstr ""
 
-#: gimple-ssa-warn-alloca.c:360
+#: gimple-ssa-warn-alloca.c:359
 #, fuzzy
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C90 禁止變數長度陣列"
 
-#: gimple-ssa-warn-alloca.c:361
+#: gimple-ssa-warn-alloca.c:360
 #, fuzzy
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "無效的使用的 %<auto%>"
 
-#: gimple-ssa-warn-alloca.c:367
+#: gimple-ssa-warn-alloca.c:366
 #, fuzzy
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "無效的使用的 %<auto%>"
 
-#: gimple-ssa-warn-alloca.c:372
+#: gimple-ssa-warn-alloca.c:371
 #, fuzzy
 msgid "%Gargument to variable-length array is zero"
 msgstr "警告如果變數長度陣列被使用"
 
-#: gimple-ssa-warn-alloca.c:374
+#: gimple-ssa-warn-alloca.c:373
 #, fuzzy
 #| msgid "Second argument of MOD at %L is zero"
 msgid "%Gargument to %<alloca%> is zero"
@@ -26040,7 +26051,7 @@ msgstr ""
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3734
+#: gimple-ssa-warn-restrict.c:1773 c-family/c-warn.c:3735
 #, fuzzy, gcc-internal-format
 msgid "array %qD declared here"
 msgstr "%qD 宣告的在此"
@@ -26066,11 +26077,11 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1818 tree-ssa-uninit.c:586 tree-ssa-uninit.c:664
-#: c/c-decl.c:3873 c/c-decl.c:4146 c/c-typeck.c:8868 cp/class.c:1437
-#: cp/class.c:3253 cp/constexpr.c:956 cp/decl.c:4209 cp/decl.c:11926
-#: cp/decl.c:12405 cp/decl.c:12414 cp/friend.c:386 cp/friend.c:396
-#: cp/init.c:2665 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
-#: cp/parser.c:6768 cp/parser.c:23234
+#: c/c-decl.c:3872 c/c-decl.c:4145 c/c-typeck.c:8928 cp/class.c:1444
+#: cp/class.c:3260 cp/constexpr.c:957 cp/decl.c:4197 cp/decl.c:11944
+#: cp/decl.c:12423 cp/decl.c:12432 cp/friend.c:386 cp/friend.c:396
+#: cp/init.c:2672 cp/parser.c:3434 cp/parser.c:3580 cp/parser.c:3631
+#: cp/parser.c:6768 cp/parser.c:23271
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD 宣告的在此"
@@ -26150,313 +26161,313 @@ msgstr ""
 msgid "using result of function returning %<void%>"
 msgstr "使用結果的函式回傳 %<void%>"
 
-#: gimplify.c:6329
+#: gimplify.c:6330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-memory output %d must stay in memory"
 msgstr "non-memory 輸入 %d 必須保持在中記憶體"
 
-#: gimplify.c:6342
+#: gimplify.c:6343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "組譯輸出 %d 中左值無效"
 
-#: gimplify.c:6489
+#: gimplify.c:6490
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "non-memory 輸入 %d 必須保持在中記憶體"
 
-#: gimplify.c:6529 gimplify.c:6538
+#: gimplify.c:6530 gimplify.c:6539
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "記憶體輸入 %d 不可直接定址"
 
-#: gimplify.c:7152
+#: gimplify.c:7153
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "threadprivate 變數 %qE 已用於 untied 任務"
 
-#: gimplify.c:7154
+#: gimplify.c:7155
 #, fuzzy, gcc-internal-format
 msgid "enclosing region"
 msgstr "封閉任務"
 
-#: gimplify.c:7158
+#: gimplify.c:7159
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "threadprivate 變數 %qE 已用於 untied 任務"
 
-#: gimplify.c:7160
+#: gimplify.c:7161
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "封閉任務"
 
-#: gimplify.c:7173
+#: gimplify.c:7174
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "threadprivate 變數 %qE 已用於 untied 任務"
 
-#: gimplify.c:7175
+#: gimplify.c:7176
 #, fuzzy, gcc-internal-format
 msgid "enclosing task"
 msgstr "封閉任務"
 
-#: gimplify.c:7260
+#: gimplify.c:7261
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:7262
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "封閉任務"
 
-#: gimplify.c:7405
+#: gimplify.c:7406
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:7407
+#: gimplify.c:7408
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7468
+#: gimplify.c:7469
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7476
+#: gimplify.c:7477
 #, fuzzy, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE undeclared (先使用在中這個函式)"
 
-#: gimplify.c:7541
+#: gimplify.c:7542
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %<target%>"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:7543
+#: gimplify.c:7544
 #, fuzzy, gcc-internal-format
 msgid "enclosing %<target%>"
 msgstr "封閉任務"
 
-#: gimplify.c:7573 gimplify.c:9014
+#: gimplify.c:7574 gimplify.c:9015
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "變數 %q+D 宣告為 %<inline%>"
 
-#: gimplify.c:7594
+#: gimplify.c:7595
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7725
+#: gimplify.c:7726
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:7728
+#: gimplify.c:7729
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "迭代變數 %qE 應該是私人的"
 
-#: gimplify.c:7742
+#: gimplify.c:7743
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "迭代變數 %qE 不應為 firstprivate"
 
-#: gimplify.c:7745
+#: gimplify.c:7746
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:7748
+#: gimplify.c:7749
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:8615 gimplify.c:8621
+#: gimplify.c:8616 gimplify.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "conditional %<lastprivate%> clause on %qs construct"
 msgstr "尚未支援程式碼模式 %<large%>"
 
-#: gimplify.c:8638
+#: gimplify.c:8639
 #, fuzzy, gcc-internal-format
 msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
 msgstr "%qD 並非變數在中子句 %<lastprivate%>"
 
-#: gimplify.c:8727
+#: gimplify.c:8728
 #, gcc-internal-format
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8735 gimplify.c:12857
+#: gimplify.c:8736 gimplify.c:12858
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
 msgstr ""
 
-#: gimplify.c:8746 gimplify.c:8752 gimplify.c:8758 gimplify.c:8764
-#: gimplify.c:12850
+#: gimplify.c:8747 gimplify.c:8753 gimplify.c:8759 gimplify.c:8765
+#: gimplify.c:12851
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "尚未支援程式碼模式 %<large%>"
 
-#: gimplify.c:8858
+#: gimplify.c:8859
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:9184
+#: gimplify.c:9185
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9366
+#: gimplify.c:9367
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: gimplify.c:9728
+#: gimplify.c:9729
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:9785
+#: gimplify.c:9786
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:9817
+#: gimplify.c:9818
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:10017
+#: gimplify.c:10018
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:10227
+#: gimplify.c:10228
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:10281
+#: gimplify.c:10282
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10530
+#: gimplify.c:10531
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10591
+#: gimplify.c:10592
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10682
+#: gimplify.c:10683
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10829
+#: gimplify.c:10830
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10848
+#: gimplify.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD 範本宣告無效"
 
-#: gimplify.c:10985
+#: gimplify.c:10986
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:11319
+#: gimplify.c:11320
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11578 gimplify.c:11582 gimplify.c:11591
+#: gimplify.c:11579 gimplify.c:11583 gimplify.c:11592
 #, gcc-internal-format
 msgid "%qs clause may not appear on non-rectangular %qs"
 msgstr ""
 
-#: gimplify.c:11823 gimplify.c:12082
+#: gimplify.c:11824 gimplify.c:12083
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12788
+#: gimplify.c:12789
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12812
+#: gimplify.c:12813
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12832
+#: gimplify.c:12833
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12885
+#: gimplify.c:12886
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13748 omp-low.c:3472
+#: gimplify.c:13749 omp-low.c:3472
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "已排序的區域必須是接近巢狀的內部迴圈區域與已排序的子句"
 
-#: gimplify.c:13766
+#: gimplify.c:13767
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13779
+#: gimplify.c:13780
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13792
+#: gimplify.c:13793
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13803
+#: gimplify.c:13804
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:15080
+#: gimplify.c:15082
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失敗"
 
-#: gimplify.c:15613
+#: gimplify.c:15615
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "透過 %<...%> 傳遞時 %qT 被提升為 %qT"
 
-#: gimplify.c:15618
+#: gimplify.c:15620
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您應該向 %<va_arg%> 傳遞 %qT 而不是 %qT)"
 
-#: gimplify.c:15625
+#: gimplify.c:15627
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果執行到這段程式碼，程式將中止"
@@ -26907,24 +26918,24 @@ msgstr ""
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
 
-#: ira.c:2317 ira.c:2339
+#: ira.c:2318 ira.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%s cannot be used in %<asm%> here"
 msgstr "%s 不能在這裡用於 asm"
 
-#: ira.c:5920
+#: ira.c:5921
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
 msgstr ""
 
-#: ira.c:5921
+#: ira.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "as %qD"
 msgid "for %qD"
 msgstr "做為 %qD"
 
-#: ira.c:5937
+#: ira.c:5938
 #, gcc-internal-format
 msgid "frame size too large for reliable stack checking"
 msgstr "對可靠的堆疊檢查來說框架太大了"
@@ -26945,12 +26956,12 @@ msgstr "%<asm%> 運算元有不可能的條件約束"
 msgid "unable to find a register to spill"
 msgstr "在類別 %qs 中找不到可捨出的暫存器"
 
-#: lra-constraints.c:4135 reload.c:3863 reload.c:4118
+#: lra-constraints.c:4140 reload.c:3869 reload.c:4124
 #, gcc-internal-format
 msgid "inconsistent operand constraints in an %<asm%>"
 msgstr "一句 %<asm%> 中運算元約束不一致"
 
-#: lra-constraints.c:5091
+#: lra-constraints.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "最大值條件儲存對數量該可以是 sunk"
@@ -27672,12 +27683,12 @@ msgstr "-malign-functions=%d 未被介於 0 和 %d"
 msgid "unrecognized argument in option %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: opts-common.c:1366 config/i386/i386-options.c:1551
+#: opts-common.c:1366 config/i386/i386-options.c:1554
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: opts-common.c:1369 config/i386/i386-options.c:1554
+#: opts-common.c:1369 config/i386/i386-options.c:1557
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "有效引數到 %qs 是：%s"
@@ -27803,7 +27814,7 @@ msgstr "transactional 記憶體未被支援與 non-call 異常"
 msgid "section anchors must be disabled when toplevel reorder is disabled"
 msgstr "區段錨點必須已停用時最上層重新排序已停用"
 
-#: opts.c:1002 config/darwin.c:3317
+#: opts.c:1002 config/darwin.c:3312
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition 不適用於異常於這個架構"
@@ -28326,22 +28337,22 @@ msgstr "隱含地流行的 regs 必須被群組於頂的堆疊"
 msgid "output operand %d must use %<&%> constraint"
 msgstr "輸出運算元 %d 必須使用 %<&%> 約束"
 
-#: regcprop.c:1229
+#: regcprop.c:1230
 #, fuzzy, gcc-internal-format
 msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
 msgstr "validate_value_data：[%u] 不當的 next_regno 用於清空鏈接 (%u)"
 
-#: regcprop.c:1241
+#: regcprop.c:1242
 #, fuzzy, gcc-internal-format
 msgid "%qs: loop in %<next_regno%> chain (%u)"
 msgstr "validate_value_data：迴圈在中 regno 鏈接 (%u)"
 
-#: regcprop.c:1244
+#: regcprop.c:1245
 #, fuzzy, gcc-internal-format
 msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
 msgstr "validate_value_data：[%u] 不當的 oldest_regno (%u)"
 
-#: regcprop.c:1256
+#: regcprop.c:1257
 #, fuzzy, gcc-internal-format
 msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
 msgstr "validate_value_data：[%u] 非空 reg 在中鏈接 (%s %u %i)"
@@ -28403,12 +28414,12 @@ msgstr "不能在 %<asm%> 中重新載入整數常數運算元"
 msgid "impossible register constraint in %<asm%>"
 msgstr "%<asm%> 中不可能的暫存器約束"
 
-#: reload.c:2687
+#: reload.c:2692
 #, fuzzy, gcc-internal-format
 msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
 msgstr "這個目標不支援 %qs"
 
-#: reload.c:3720
+#: reload.c:3726
 #, gcc-internal-format
 msgid "%<&%> constraint used with no register class"
 msgstr "%<&%> 約束未與暫存器類型一起使用"
@@ -28438,53 +28449,53 @@ msgstr "%<asm%> 運算元的約束與運算元大小不相容"
 msgid "output operand is constant in %<asm%>"
 msgstr "%<asm%> 的輸出運算元是常數"
 
-#: rtl.c:850
+#: rtl.c:860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
 msgstr "RTL 檢查：存取的 elt %d 的『%s』與最後一筆 elt %d 在中 %s，於 %s:%d"
 
-#: rtl.c:860
+#: rtl.c:870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL 檢查：預期的 elt %d 型態『%c』，有『%c』(rtx %s) 在中 %s，於 %s:%d"
 
-#: rtl.c:870
+#: rtl.c:880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
 msgstr "RTL 檢查：預期的 elt %d 型態『%c』或『%c』，有『%c』(rtx %s) 在中 %s，於 %s:%d"
 
-#: rtl.c:879
+#: rtl.c:889
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL 檢查：需要程式碼「%s」，卻得到「%s」在 %s，於 %s:%d"
 
-#: rtl.c:889
+#: rtl.c:899
 #, gcc-internal-format, gfc-internal-format
 msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL 檢查：需要程式碼「%s」或「%s」，卻得到「%s」在 %s，於 %s:%d"
 
-#: rtl.c:900
+#: rtl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
 msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
 msgstr "RTL 檢查：需要程式碼「%s」或「%s」，卻得到「%s」在 %s，於 %s:%d"
 
-#: rtl.c:927
+#: rtl.c:937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
 msgstr "RTL 檢查：試圖到對待 non-block 符號做為區塊符號在中 %s，於 %s:%d"
 
-#: rtl.c:937
+#: rtl.c:947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL 檢查：存取的 elt %d 的向量與最後一筆 elt %d 在中 %s，於 %s:%d"
 
-#: rtl.c:947
+#: rtl.c:957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL 檢查：存取的 elt %d 的向量與最後一筆 elt %d 在中 %s，於 %s:%d"
 
-#: rtl.c:958
+#: rtl.c:968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
 msgstr "RTL 旗標檢查：%s 使用的與未預期的 rtx 編碼『%s』在中 %s，於 %s:%d"
@@ -28529,23 +28540,23 @@ msgstr "匹配的約束參照了無效的運算元號"
 msgid "invalid punctuation %qc in constraint"
 msgstr "約束中出現無效的標點 %qc"
 
-#: stmt.c:430
+#: stmt.c:431
 #, gcc-internal-format
 msgid "matching constraint does not allow a register"
 msgstr "匹配的約束不允許使用暫存器"
 
-#: stmt.c:524
+#: stmt.c:525
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate asm operand name %qs"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "重複的組譯運算元名 %qs"
 
-#: stmt.c:621
+#: stmt.c:622
 #, gcc-internal-format
 msgid "missing close brace for named operand"
 msgstr "具名運算元後缺少右大括號"
 
-#: stmt.c:650
+#: stmt.c:651
 #, gcc-internal-format
 msgid "undefined named operand %qs"
 msgstr "未定義的具名運算元 %qs"
@@ -29243,9 +29254,9 @@ msgstr "%%R 的運算元無效"
 #: tree-cfg.c:3186 tree-cfg.c:3195 tree-cfg.c:3212 tree-cfg.c:3849
 #: tree-cfg.c:3878 tree-cfg.c:3895 tree-cfg.c:3916 tree-cfg.c:3964
 #: tree-cfg.c:3985 tree-cfg.c:4039 tree-cfg.c:4063 tree-cfg.c:4099
-#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4260
-#: tree-cfg.c:4272 tree-cfg.c:4331 tree-cfg.c:4356 tree-cfg.c:4429
-#: tree-cfg.c:4507
+#: tree-cfg.c:4120 tree-cfg.c:4152 tree-cfg.c:4228 tree-cfg.c:4262
+#: tree-cfg.c:4274 tree-cfg.c:4333 tree-cfg.c:4358 tree-cfg.c:4431
+#: tree-cfg.c:4509
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "型態不匹配在中 nontype 參數包裝"
@@ -29281,7 +29292,7 @@ msgstr "無效的偏移運算元在中 MEM_REF"
 msgid "invalid clique in %qs"
 msgstr "錯誤地使用了 %qD"
 
-#: tree-cfg.c:3305 tree-cfg.c:4519
+#: tree-cfg.c:3305 tree-cfg.c:4521
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
@@ -29490,369 +29501,369 @@ msgstr "無效的運算元在中三進作業"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4284 tree-cfg.c:4343
+#: tree-cfg.c:4286 tree-cfg.c:4345
 #, fuzzy, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "向量類型預期的在中向量 permute 運算式"
 
-#: tree-cfg.c:4299
+#: tree-cfg.c:4301
 #, fuzzy, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "向量與不同的元件號碼找到在中向量 permute 運算式"
 
-#: tree-cfg.c:4315
+#: tree-cfg.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid mask type in %qs"
 msgstr "無效的循環移位指令"
 
-#: tree-cfg.c:4375
+#: tree-cfg.c:4377
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "不支援的組合：%s"
 
-#: tree-cfg.c:4384
+#: tree-cfg.c:4386
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "無效的位置或大小運算元到 BIT_FIELD_REF"
 
-#: tree-cfg.c:4390
+#: tree-cfg.c:4392
 #, fuzzy, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "Shift 的 non-integer 運算元"
 
-#: tree-cfg.c:4400
+#: tree-cfg.c:4402
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: tree-cfg.c:4410
+#: tree-cfg.c:4412
 #, fuzzy, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qD 並非型態"
 
-#: tree-cfg.c:4465
+#: tree-cfg.c:4467
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "non-trivial 轉換於指派"
 
-#: tree-cfg.c:4474
+#: tree-cfg.c:4476
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "在中敘述"
 
-#: tree-cfg.c:4493
+#: tree-cfg.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "%%R 的運算元無效"
 
-#: tree-cfg.c:4534 tree-cfg.c:4560
+#: tree-cfg.c:4536 tree-cfg.c:4562
 #, fuzzy, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "無效的 rhs 用於 gimple 記憶體儲存"
 
-#: tree-cfg.c:4594 tree-cfg.c:4612
+#: tree-cfg.c:4596 tree-cfg.c:4614
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "incorrect type of vector %qs elements"
 msgstr "左移次數大於或等於類型寬度"
 
-#: tree-cfg.c:4603 tree-cfg.c:4620
+#: tree-cfg.c:4605 tree-cfg.c:4622
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "不正確引數數量到函式 %qE"
 
-#: tree-cfg.c:4628
+#: tree-cfg.c:4630
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4637
+#: tree-cfg.c:4639
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4644
+#: tree-cfg.c:4646
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4653
+#: tree-cfg.c:4655
 #, fuzzy, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "比較向量與不同的元件類型"
 
-#: tree-cfg.c:4664
+#: tree-cfg.c:4666
 #, fuzzy, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR 與 always-false 條件"
 
-#: tree-cfg.c:4723
+#: tree-cfg.c:4725
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "無效的運算元在中回傳敘述"
 
-#: tree-cfg.c:4738 c/gimple-parser.c:2422
+#: tree-cfg.c:4740 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "無效的轉換在中回傳敘述"
 
-#: tree-cfg.c:4762
+#: tree-cfg.c:4764
 #, fuzzy, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "前往目的是 neither 標貼 nor 指標"
 
-#: tree-cfg.c:4781
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "無效的運算元到開關敘述"
 
-#: tree-cfg.c:4789
+#: tree-cfg.c:4791
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "無效的運算元到開關敘述"
 
-#: tree-cfg.c:4799
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "%<default%> 標籤未出現在 switch 敘述內"
 
-#: tree-cfg.c:4811
+#: tree-cfg.c:4813
 #, fuzzy, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "無效的 CASE_CHAIN"
 
-#: tree-cfg.c:4817
+#: tree-cfg.c:4819
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: tree-cfg.c:4824
+#: tree-cfg.c:4826
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "無效的運算元到開關敘述"
 
-#: tree-cfg.c:4834
+#: tree-cfg.c:4836
 #, fuzzy, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: tree-cfg.c:4841
+#: tree-cfg.c:4843
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4852
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "函式宣告中出現參數名卻未指定類型"
 
-#: tree-cfg.c:4902
+#: tree-cfg.c:4904
 #, fuzzy, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "不正確條目在中 label_to_block_map"
 
-#: tree-cfg.c:4912
+#: tree-cfg.c:4914
 #, fuzzy, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "不正確集合降落填充數字"
 
-#: tree-cfg.c:4928
+#: tree-cfg.c:4930
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "無效的比較編碼在中 gimple cond"
 
-#: tree-cfg.c:4936
+#: tree-cfg.c:4938
 #, fuzzy, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "無效的標貼在中 gimple cond"
 
-#: tree-cfg.c:5019 tree-cfg.c:5028
+#: tree-cfg.c:5021 tree-cfg.c:5030
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "無效的 PHI 結果"
 
-#: tree-cfg.c:5038
+#: tree-cfg.c:5040
 #, fuzzy, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "缺少PHI def"
 
-#: tree-cfg.c:5052
+#: tree-cfg.c:5054
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "無效的 PHI 引數"
 
-#: tree-cfg.c:5059
+#: tree-cfg.c:5061
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "不相容的類型在中 PHI 引數 %u"
 
-#: tree-cfg.c:5157
+#: tree-cfg.c:5159
 #, fuzzy, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "verifygimple 失敗(_G)"
 
-#: tree-cfg.c:5214
+#: tree-cfg.c:5216
 #, fuzzy, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "dead STMT 在中 EH 表格"
 
-#: tree-cfg.c:5230
+#: tree-cfg.c:5232
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5279
+#: tree-cfg.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "local declaration from a different function"
 msgstr "隱含宣告函式 %qE"
 
-#: tree-cfg.c:5382
+#: tree-cfg.c:5384
 #, fuzzy, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimplebb (phi) 是設定為錯誤的基本區塊(_B)"
 
-#: tree-cfg.c:5391
+#: tree-cfg.c:5393
 #, fuzzy, gcc-internal-format
 msgid "PHI node with location"
 msgstr "從這個地方"
 
-#: tree-cfg.c:5402 tree-cfg.c:5449
+#: tree-cfg.c:5404 tree-cfg.c:5451
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "對樹結區段的共享不正確"
 
-#: tree-cfg.c:5410
+#: tree-cfg.c:5412
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5437
+#: tree-cfg.c:5439
 #, fuzzy, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimplebb (stmt) 是設定為錯誤的基本區塊(_B)"
 
-#: tree-cfg.c:5477
+#: tree-cfg.c:5479
 #, fuzzy, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "敘述標記的用於丟擲，但是 doesn%'t"
 
-#: tree-cfg.c:5483
+#: tree-cfg.c:5485
 #, fuzzy, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "敘述標記的用於丟擲在中中間的區塊"
 
-#: tree-cfg.c:5505
+#: tree-cfg.c:5507
 #, fuzzy, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verifygimple 失敗(_G)"
 
-#: tree-cfg.c:5527
+#: tree-cfg.c:5529
 #, fuzzy, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK 有 IL 關聯的與它"
 
-#: tree-cfg.c:5534
+#: tree-cfg.c:5536
 #, fuzzy, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK 有 IL 關聯的與它"
 
-#: tree-cfg.c:5541
+#: tree-cfg.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fallthru 到離開從 bb %d"
 
-#: tree-cfg.c:5565
+#: tree-cfg.c:5567
 #, fuzzy, gcc-internal-format
 msgid "nonlocal label "
 msgstr "nonlocal 標貼 "
 
-#: tree-cfg.c:5574
+#: tree-cfg.c:5576
 #, fuzzy, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH 降落填充標貼 "
 
-#: tree-cfg.c:5583 tree-cfg.c:5592 tree-cfg.c:5617
+#: tree-cfg.c:5585 tree-cfg.c:5594 tree-cfg.c:5619
 #, fuzzy, gcc-internal-format
 msgid "label "
 msgstr "標貼 "
 
-#: tree-cfg.c:5607
+#: tree-cfg.c:5609
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "基本區塊 %d 中出現流程控制"
 
-#: tree-cfg.c:5640
+#: tree-cfg.c:5642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "fallthru 邊緣之後控制敘述在中 bb %d"
 
-#: tree-cfg.c:5653
+#: tree-cfg.c:5655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "真/假邊緣之後 non-GIMPLE_COND 在中 bb %d"
 
-#: tree-cfg.c:5676 tree-cfg.c:5698 tree-cfg.c:5715 tree-cfg.c:5784
+#: tree-cfg.c:5678 tree-cfg.c:5700 tree-cfg.c:5717 tree-cfg.c:5786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "錯誤的外送的郵件邊緣旗標於結束的 bb %d"
 
-#: tree-cfg.c:5686
+#: tree-cfg.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "基本區塊 %d 末尾明確的 goto"
 
-#: tree-cfg.c:5720
+#: tree-cfg.c:5722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "回傳邊緣不點到離開在中 bb %d"
 
-#: tree-cfg.c:5750
+#: tree-cfg.c:5752
 #, fuzzy, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "找到預設大小寫無法於開始的大小寫向量"
 
-#: tree-cfg.c:5758
+#: tree-cfg.c:5760
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "大小寫標貼無法排序："
 
-#: tree-cfg.c:5775
+#: tree-cfg.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "多餘的出邊 %d->%d"
 
-#: tree-cfg.c:5798
+#: tree-cfg.c:5800
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "缺少邊 %i->%i"
 
-#: tree-cfg.c:9473
+#: tree-cfg.c:9475
 #, fuzzy, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> 函式做回傳"
 
-#: tree-cfg.c:9494 tree-cfg.c:9526
+#: tree-cfg.c:9496 tree-cfg.c:9528
 #, fuzzy, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "控制達到結束的 non-void 函式"
 
-#: tree-cfg.c:9592
+#: tree-cfg.c:9594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: tree-cfg.c:9597 cp/cvt.c:1119
+#: tree-cfg.c:9599 cp/cvt.c:1119
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "忽略傳回值的函式宣告的與屬性 warn_unused_result"
@@ -30947,7 +30958,7 @@ msgstr "執行緒區域性的 COMMON 資料沒有實作"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%q+D 需要的對齊邊界大於實作的對齊邊界 %wu"
 
-#: varasm.c:2284 c/c-decl.c:5451 c/c-parser.c:1660
+#: varasm.c:2284 c/c-decl.c:5450 c/c-parser.c:1660
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D 的存儲大小不明"
@@ -31113,7 +31124,7 @@ msgstr "位元碼串流：預期的標籤 %s 以代替 %s"
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "位元碼串流：標籤 %s 不是在中預期的範圍 [%s，%s]"
 
-#: c-family/c-ada-spec.c:2840
+#: c-family/c-ada-spec.c:2843
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported record layout"
@@ -31746,7 +31757,7 @@ msgstr "%qE 屬性追隨 %qE"
 msgid "type was previously declared %qE"
 msgstr "型態是在之前宣告 %qE"
 
-#: c-family/c-attribs.c:3948 cp/class.c:4749
+#: c-family/c-attribs.c:3948 cp/class.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -31768,7 +31779,7 @@ msgstr "%qD 不是相容與 %qD"
 msgid "%qE argument is not a function"
 msgstr "cleanup 引數不是一個函式"
 
-#: c-family/c-attribs.c:4068 cp/name-lookup.c:6060
+#: c-family/c-attribs.c:4068 cp/name-lookup.c:6077
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "不宜用訊息並非字串"
@@ -32208,12 +32219,12 @@ msgstr "enum 常數定義的在此"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "位址的 %qD 將一律評估做為 %<true%>"
 
-#: c-family/c-common.c:3500 cp/semantics.c:823 cp/typeck.c:9569
+#: c-family/c-common.c:3500 cp/semantics.c:842 cp/typeck.c:9576
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建議在做為真值的賦值敘述前後加上括號"
 
-#: c-family/c-common.c:3587 c/c-decl.c:4688 c/c-decl.c:7081 c/c-typeck.c:15429
+#: c-family/c-common.c:3587 c/c-decl.c:4687 c/c-decl.c:7080 c/c-typeck.c:15489
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "錯誤地使用了 %<restrict%>"
@@ -32375,13 +32386,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "預設引數指定的用於 lambda 參數"
 
 #: c-family/c-common.c:5974 c-family/c-common.c:6804 c-family/c-common.c:6851
-#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3671
+#: c-family/c-common.c:6926 c-family/c-common.c:6999 c/c-typeck.c:3721
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "提供給函式 %qE 的引數太少"
 
 #: c-family/c-common.c:5979 c-family/c-common.c:6857 c-family/c-common.c:7025
-#: c/c-typeck.c:3535
+#: c/c-typeck.c:3585
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "提供給函式 %qE 的引數太多"
@@ -33351,7 +33362,7 @@ msgstr "不受支援的 non-standard 串接的字串實字"
 msgid "traditional C rejects string constant concatenation"
 msgstr "傳統 C 不接受字串常數粘貼"
 
-#: c-family/c-omp.c:116 cp/pt.c:18845
+#: c-family/c-omp.c:116 cp/pt.c:18928
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -33401,7 +33412,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:736 cp/semantics.c:9430
+#: c-family/c-omp.c:736 cp/semantics.c:9458
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "無效的型態用於迭代變數 %qE"
@@ -33416,17 +33427,17 @@ msgstr "無效的型態用於迭代變數 %qE"
 msgid "%qE is not initialized"
 msgstr "%qE 未被初始化的"
 
-#: c-family/c-omp.c:778 cp/semantics.c:9319
+#: c-family/c-omp.c:778 cp/semantics.c:9347
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制述詞"
 
-#: c-family/c-omp.c:884 cp/semantics.c:8938
+#: c-family/c-omp.c:884 cp/semantics.c:8966
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "無效的控制述詞"
 
-#: c-family/c-omp.c:891 cp/semantics.c:9325
+#: c-family/c-omp.c:891 cp/semantics.c:9353
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少遞增運算式"
@@ -33436,7 +33447,7 @@ msgstr "缺少遞增運算式"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1022 cp/semantics.c:9053
+#: c-family/c-omp.c:1022 cp/semantics.c:9081
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無效的遞增運算式"
@@ -33502,7 +33513,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.c:2382 c/c-typeck.c:15242 cp/semantics.c:8581
+#: c-family/c-omp.c:2382 c/c-typeck.c:15302 cp/semantics.c:8609
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -34097,8 +34108,8 @@ msgstr "<return-value>"
 msgid "wrong type argument to %s"
 msgstr "錯誤的型態引數到 %s"
 
-#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:2949
-#: cp/constexpr.c:6003
+#: c-family/c-warn.c:58 c-family/c-warn.c:71 cp/constexpr.c:3004
+#: cp/constexpr.c:6066
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常數運算式溢出"
@@ -34599,17 +34610,17 @@ msgstr "遞減的函式 %qD"
 msgid "function %qD used as %<asm%> output"
 msgstr "函式 %qD 使用的做為 %<asm%> 輸出"
 
-#: c-family/c-warn.c:1858 c/c-typeck.c:4924
+#: c-family/c-warn.c:1858 c/c-typeck.c:4984
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "指派的唯讀位置 %qE"
 
-#: c-family/c-warn.c:1859 c/c-typeck.c:4927
+#: c-family/c-warn.c:1859 c/c-typeck.c:4987
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "遞增的唯讀位置 %qE"
 
-#: c-family/c-warn.c:1860 c/c-typeck.c:4930
+#: c-family/c-warn.c:1860 c/c-typeck.c:4990
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "遞減的唯讀位置 %qE"
@@ -34789,8 +34800,8 @@ msgstr ""
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:2251 c/c-typeck.c:12061 c/c-typeck.c:12229
-#: cp/typeck.c:5433
+#: c-family/c-warn.c:2251 c/c-typeck.c:12121 c/c-typeck.c:12289
+#: cp/typeck.c:5444
 #, fuzzy, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "比較介於類型 %qT 和 %qT"
@@ -34874,155 +34885,155 @@ msgid "passing argument %i to %qs-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to %qs-qualified parameter aliases with arguments %Z"
 msgstr[0] "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: c-family/c-warn.c:2790 c/c-typeck.c:5495 cp/call.c:5803
+#: c-family/c-warn.c:2791 c/c-typeck.c:5555 cp/call.c:5807
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2897
+#: c-family/c-warn.c:2898
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2898
+#: c-family/c-warn.c:2899
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
 
-#: c-family/c-warn.c:2991
+#: c-family/c-warn.c:2992
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2998 c-family/c-warn.c:3001 cp/init.c:635
+#: c-family/c-warn.c:2999 c-family/c-warn.c:3002 cp/init.c:642
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "聯合定義的在此"
 
-#: c-family/c-warn.c:3088
+#: c-family/c-warn.c:3089
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:3315
+#: c-family/c-warn.c:3316
 #, fuzzy
 msgid "mismatch in bound %Z of argument %u declared as %s"
 msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
 msgstr[0] "大小不匹配在中引數 %d 的 %qE"
 
-#: c-family/c-warn.c:3318 c-family/c-warn.c:3688
+#: c-family/c-warn.c:3319 c-family/c-warn.c:3689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s"
 msgstr "在之前宣告的在此"
 
-#: c-family/c-warn.c:3452
+#: c-family/c-warn.c:3453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a variable length array"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: c-family/c-warn.c:3457
+#: c-family/c-warn.c:3458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a pointer %s"
 msgstr "在之前宣告的在此"
 
-#: c-family/c-warn.c:3458
+#: c-family/c-warn.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an ordinary array %s"
 msgstr "在之前宣告的在此"
 
-#: c-family/c-warn.c:3471 c-family/c-warn.c:3485
+#: c-family/c-warn.c:3472 c-family/c-warn.c:3486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as a pointer"
 msgstr "引數 %d 的 %qE 必須是指標類型"
 
-#: c-family/c-warn.c:3475 c-family/c-warn.c:3501
+#: c-family/c-warn.c:3476 c-family/c-warn.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as a variable length array %s"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: c-family/c-warn.c:3488
+#: c-family/c-warn.c:3489
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "previously declared as an array %s"
 msgstr "在之前宣告的在此"
 
-#: c-family/c-warn.c:3497
+#: c-family/c-warn.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared as an ordinary array"
 msgstr ""
 
-#: c-family/c-warn.c:3525
+#: c-family/c-warn.c:3526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u variable bound"
 msgid_plural "argument %u of type %s declared with %u variable bounds"
 msgstr[0] "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: c-family/c-warn.c:3532
+#: c-family/c-warn.c:3533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %q+D with attribute noinline"
 msgid "previously declared as %s with %u variable bound"
 msgid_plural "previously declared as %s with %u variable bounds"
 msgstr[0] "先前 %q+D 的宣告帶有 noinline 屬性"
 
-#: c-family/c-warn.c:3556
+#: c-family/c-warn.c:3557
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s declared with %u unspecified variable bound"
 msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3564
+#: c-family/c-warn.c:3565
 #, gcc-internal-format, gfc-internal-format
 msgid "previously declared as %s with %u unspecified variable bound"
 msgid_plural "previously declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3571
+#: c-family/c-warn.c:3572
 #, gcc-internal-format, gfc-internal-format
 msgid "subsequently declared as %s with %u unspecified variable bound"
 msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
 msgstr[0] ""
 
-#: c-family/c-warn.c:3624
+#: c-family/c-warn.c:3625
 #, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound argument %E"
 msgstr ""
 
-#: c-family/c-warn.c:3631 c-family/c-warn.c:3664
+#: c-family/c-warn.c:3632 c-family/c-warn.c:3665
 #, fuzzy, gcc-internal-format
 msgid "argument %u of type %s declared with mismatched bound %<%s%>"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: c-family/c-warn.c:3643
+#: c-family/c-warn.c:3644
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound argument %E"
 msgstr "在之前宣告的在此"
 
-#: c-family/c-warn.c:3648
+#: c-family/c-warn.c:3649
 #, fuzzy, gcc-internal-format
 msgid "previously declared as %s with bound %<%s%>"
 msgstr "前一個宣告的 %<%c%s%>"
 
-#: c-family/c-warn.c:3667
+#: c-family/c-warn.c:3668
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previously declared as %s with bound %qs"
 msgstr "先前的宣告 %q+D"
 
-#: c-family/c-warn.c:3686
+#: c-family/c-warn.c:3687
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u of type %s with mismatched bound"
 msgstr ""
 
-#: c-family/c-warn.c:3717
+#: c-family/c-warn.c:3718
 #, gcc-internal-format
 msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
 msgstr ""
 
-#: c-family/c-warn.c:3727
+#: c-family/c-warn.c:3728
 #, gcc-internal-format
 msgid "add parentheses around %qE to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:3731
+#: c-family/c-warn.c:3732
 #, gcc-internal-format
 msgid "add parentheses around the second %<sizeof%> to silence this warning"
 msgstr ""
@@ -35037,7 +35048,7 @@ msgstr "%qs 並非有效選項到前置處理器"
 msgid "too many input files"
 msgstr "輸入檔案太多"
 
-#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:14814
+#: common/config/aarch64/aarch64-common.c:519 config/aarch64/aarch64.c:16448
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "-mcpu 開關的值 %qs 錯誤"
@@ -35070,14 +35081,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:368 common/config/arm/arm-common.c:432
-#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:14746
-#: config/aarch64/aarch64.c:14784
+#: common/config/arm/arm-common.c:479 config/aarch64/aarch64.c:16380
+#: config/aarch64/aarch64.c:16418
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:435
-#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:14749
+#: common/config/arm/arm-common.c:482 config/aarch64/aarch64.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "有效引數到 %qs 是：%s"
@@ -35240,62 +35251,62 @@ msgstr "-mregparm=%d 不在 0 和 %d 之間"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:290
+#: common/config/riscv/riscv-common.c:295
 #, gcc-internal-format
 msgid "%<-march=%s%>: Extension `%s' appear more than one time."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:535
+#: common/config/riscv/riscv-common.c:540
 #, gcc-internal-format
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:605
+#: common/config/riscv/riscv-common.c:610
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:617
+#: common/config/riscv/riscv-common.c:622
 #, gcc-internal-format
 msgid "version of `g` will be omitted, please specify version for individual extension."
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:636
+#: common/config/riscv/riscv-common.c:641
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:663
+#: common/config/riscv/riscv-common.c:668
 #, gcc-internal-format
 msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:667
+#: common/config/riscv/riscv-common.c:672
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:773
+#: common/config/riscv/riscv-common.c:778
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: common/config/riscv/riscv-common.c:785
+#: common/config/riscv/riscv-common.c:790
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: common/config/riscv/riscv-common.c:814
+#: common/config/riscv/riscv-common.c:819
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:851
+#: common/config/riscv/riscv-common.c:856
 #, gcc-internal-format
 msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
 msgstr ""
 
-#: common/config/riscv/riscv-common.c:979
+#: common/config/riscv/riscv-common.c:984
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qE is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
@@ -35462,90 +35473,90 @@ msgstr "-mcpu=%s 衝突與 -march=%s"
 msgid "%s conflicts with ppc64 (arch flags ignored)"
 msgstr ""
 
-#: config/darwin.c:2011
+#: config/darwin.c:2006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s for LTO output"
 msgstr "開啟暫存檔 %s 用於 LTO 輸出時失敗"
 
-#: config/darwin.c:2104
+#: config/darwin.c:2099
 #, fuzzy, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
 msgstr "%qE 2.95 vtable-compatibility 屬性套用只有時編譯 kext"
 
-#: config/darwin.c:2111
+#: config/darwin.c:2106
 #, fuzzy, gcc-internal-format
 msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
 msgstr "%qE 2.95 vtable-compatibility 屬性套用只有到 C++類別"
 
-#: config/darwin.c:2848
+#: config/darwin.c:2843
 #, fuzzy, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "可見性屬性在此配置下不受支援；已忽略"
 
-#: config/darwin.c:3063
+#: config/darwin.c:3058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to open temporary file %s with LTO output"
 msgstr "開啟暫存檔 %s 與 LTO 輸出時失敗"
 
-#: config/darwin.c:3267
+#: config/darwin.c:3262
 #, fuzzy, gcc-internal-format
 msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%>>=2 必須被用於 %<-m64%> 目標與 %<-fnext-runtime%>"
 
-#: config/darwin.c:3272
+#: config/darwin.c:3267
 #, fuzzy, gcc-internal-format
 msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
 msgstr "%<-fobjc-abi-version%>>=2 未被支援於 %<-m32%> 目標與 %<-fnext-runtime%>"
 
-#: config/darwin.c:3287
+#: config/darwin.c:3282
 #, fuzzy, gcc-internal-format
 #| msgid "-pg not supported on this platform"
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "-pg 在此平臺上不受支援"
 
-#: config/darwin.c:3365
+#: config/darwin.c:3360
 #, fuzzy, gcc-internal-format
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "%<-mdynamic-no-pic%> 強制變更 %<-fpic%>，%<-fPIC%>，%<-fpie%> 或 %<-fPIE%>"
 
-#: config/darwin.c:3408
+#: config/darwin.c:3403
 #, gcc-internal-format
 msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
 msgstr ""
 
-#: config/darwin.c:3588
+#: config/darwin.c:3583
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgstr "內建函式 %qD 需求 %<-mconstant-cfstrings%> 旗標"
 
-#: config/darwin.c:3595
+#: config/darwin.c:3590
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD takes one argument only"
 msgstr "內建函式 %qD 需一個引數只有"
 
-#: config/darwin.c:3683
+#: config/darwin.c:3678
 #, fuzzy, gcc-internal-format
 msgid "CFString literal is missing"
 msgstr "CFString 實字缺少"
 
-#: config/darwin.c:3694
+#: config/darwin.c:3689
 #, fuzzy, gcc-internal-format
 msgid "CFString literal expression is not a string constant"
 msgstr "CFString 實字運算式並非字串常數"
 
-#: config/darwin.c:3718
+#: config/darwin.c:3713
 #, fuzzy, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
 msgstr "%s 在中 CFString 實字"
 
-#: config/darwin.c:3719
+#: config/darwin.c:3714
 #, fuzzy, gcc-internal-format
 msgid "embedded NUL in CFString literal"
 msgstr "%s 在中 CFString 實字"
 
 #: config/host-darwin.c:65
 #, fuzzy, gcc-internal-format
-msgid "could not unmap %<pch_address_space%> %m"
+msgid "could not unmap %<pch_address_space%>: %m"
 msgstr "couldn%'t unmap pch_address_space：%m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
@@ -35683,371 +35694,371 @@ msgstr "%<# pragma GCC optimize%>並非字串或數字"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "不明 # pragma GCC 輔助處理器 %E"
 
-#: config/aarch64/aarch64.c:1636
+#: config/aarch64/aarch64.c:1973
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new 不能用於函式類型"
 
-#: config/aarch64/aarch64.c:1711 config/aarch64/aarch64.c:1725
+#: config/aarch64/aarch64.c:2048 config/aarch64/aarch64.c:2062
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "預期 %<,%>或 %<)%>"
 
-#: config/aarch64/aarch64.c:2178
+#: config/aarch64/aarch64.c:2515
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "複雜引數必須有浮點型態"
 
-#: config/aarch64/aarch64.c:2181
+#: config/aarch64/aarch64.c:2518
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs 是不相容的與 %qs"
 
-#: config/aarch64/aarch64.c:2185
+#: config/aarch64/aarch64.c:2522
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2188
+#: config/aarch64/aarch64.c:2525
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:2204
+#: config/aarch64/aarch64.c:2541
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "不使用 SPE ABI 延伸"
 
-#: config/aarch64/aarch64.c:2205
+#: config/aarch64/aarch64.c:2542
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5704
+#: config/aarch64/aarch64.c:6103
 #, fuzzy, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "引數到 decltype 必須是運算式"
 
-#: config/aarch64/aarch64.c:6025
+#: config/aarch64/aarch64.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/aarch64/aarch64.c:6147 config/aarch64/aarch64.c:6210
-#: config/aarch64/aarch64.c:6329 config/aarch64/aarch64.c:16667
-#: config/arm/arm.c:7075 config/arm/arm.c:7105 config/arm/arm.c:28839
+#: config/aarch64/aarch64.c:6546 config/aarch64/aarch64.c:6609
+#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:18309
+#: config/arm/arm.c:7084 config/arm/arm.c:7114 config/arm/arm.c:28855
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6278
+#: config/aarch64/aarch64.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "使用 SPE ABI 延伸"
 
-#: config/aarch64/aarch64.c:6281
+#: config/aarch64/aarch64.c:6680
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/aarch64/aarch64.c:6453
+#: config/aarch64/aarch64.c:6857
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14270
+#: config/aarch64/aarch64.c:15904
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14314
+#: config/aarch64/aarch64.c:15948
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14370
+#: config/aarch64/aarch64.c:16004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "運算元的約束無效"
 
-#: config/aarch64/aarch64.c:14382
+#: config/aarch64/aarch64.c:16016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "無效 %%h 值"
 
-#: config/aarch64/aarch64.c:14402
+#: config/aarch64/aarch64.c:16036
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "無效的範圍 %s 在中選項 %s"
 
-#: config/aarch64/aarch64.c:14420
+#: config/aarch64/aarch64.c:16054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "不明 spec 函式 %qs"
 
-#: config/aarch64/aarch64.c:14588 config/riscv/riscv.c:4816
+#: config/aarch64/aarch64.c:16222 config/riscv/riscv.c:4825
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14597 config/riscv/riscv.c:4825
+#: config/aarch64/aarch64.c:16231 config/riscv/riscv.c:4834
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14605
+#: config/aarch64/aarch64.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "指定指派暫存器的順序"
 
-#: config/aarch64/aarch64.c:14615 config/riscv/riscv.c:4854
-#: config/rs6000/rs6000.c:4583
+#: config/aarch64/aarch64.c:16249 config/riscv/riscv.c:4863
+#: config/rs6000/rs6000.c:4587
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: config/aarch64/aarch64.c:14686
+#: config/aarch64/aarch64.c:16320
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14702
+#: config/aarch64/aarch64.c:16336
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14787
+#: config/aarch64/aarch64.c:16421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/aarch64/aarch64.c:14811
+#: config/aarch64/aarch64.c:16445
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.c:14818
+#: config/aarch64/aarch64.c:16452
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "不明 TLS 式樣 %qs"
 
-#: config/aarch64/aarch64.c:14877
+#: config/aarch64/aarch64.c:16511
 #, fuzzy, gcc-internal-format
 msgid "invalid argument given to %<-mharden-sls=%>"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/aarch64/aarch64.c:14888
+#: config/aarch64/aarch64.c:16522
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d/-mpaired-single must be used with -mfp64 -mhard-float"
 msgid "%<%s%> must be by itself for %<-mharden-sls=%>"
 msgstr "-mips3d/-mpaired-single 必須與 -mfp64 -mhard-float 一起使用"
 
-#: config/aarch64/aarch64.c:14893
+#: config/aarch64/aarch64.c:16527
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
 msgstr "無效的引數到內建函式"
 
-#: config/aarch64/aarch64.c:14999
+#: config/aarch64/aarch64.c:16633
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "無效的引數到內建函式"
 
-#: config/aarch64/aarch64.c:15001
+#: config/aarch64/aarch64.c:16635
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "無效的引數到內建函式"
 
-#: config/aarch64/aarch64.c:15025
+#: config/aarch64/aarch64.c:16659
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.c:15028
+#: config/aarch64/aarch64.c:16662
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "不明值 %qs 的 -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:15032
+#: config/aarch64/aarch64.c:16666
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "%qs 後缺少檔案名稱"
 
-#: config/aarch64/aarch64.c:15060
+#: config/aarch64/aarch64.c:16694
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.c:15063
+#: config/aarch64/aarch64.c:16697
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/aarch64/aarch64.c:15197 config/arm/arm.c:3244
+#: config/aarch64/aarch64.c:16831
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "切換 -mcpu=%s 衝突與 -march=%s 切換"
 
-#: config/aarch64/aarch64.c:15253
+#: config/aarch64/aarch64.c:16887
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s 不支援 %s"
 
-#: config/aarch64/aarch64.c:15260
+#: config/aarch64/aarch64.c:16894
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15342
+#: config/aarch64/aarch64.c:16976
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15345
+#: config/aarch64/aarch64.c:16979
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/aarch64/aarch64.c:15520
+#: config/aarch64/aarch64.c:17158
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15523
+#: config/aarch64/aarch64.c:17161
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15527 config/aarch64/aarch64.c:15569
-#: config/aarch64/aarch64.c:15676
+#: config/aarch64/aarch64.c:17165 config/aarch64/aarch64.c:17207
+#: config/aarch64/aarch64.c:17314
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15562
+#: config/aarch64/aarch64.c:17200
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15565
+#: config/aarch64/aarch64.c:17203
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15592
+#: config/aarch64/aarch64.c:17230
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15596
+#: config/aarch64/aarch64.c:17234
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15631
+#: config/aarch64/aarch64.c:17269
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15672
+#: config/aarch64/aarch64.c:17310
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.c:15730 config/aarch64/aarch64.c:15903
+#: config/aarch64/aarch64.c:17368 config/aarch64/aarch64.c:17541
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> 格式錯誤"
 
-#: config/aarch64/aarch64.c:15774
+#: config/aarch64/aarch64.c:17412
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15782 config/i386/i386-options.c:1201
+#: config/aarch64/aarch64.c:17420 config/i386/i386-options.c:1204
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15836
+#: config/aarch64/aarch64.c:17474
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/aarch64/aarch64.c:15893 config/arm/arm.c:32851
-#: config/rs6000/rs6000.c:24138 config/s390/s390.c:15744
+#: config/aarch64/aarch64.c:17531 config/arm/arm.c:32867
+#: config/rs6000/rs6000.c:24255 config/s390/s390.c:15767
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "屬性 %qE 引數不是字串"
 
-#: config/aarch64/aarch64.c:15920
+#: config/aarch64/aarch64.c:17558
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/aarch64/aarch64.c:15929
+#: config/aarch64/aarch64.c:17567
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17355 config/arm/arm.c:6427
-#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12128
-#: config/s390/s390.c:12205
+#: config/aarch64/aarch64.c:18997 config/arm/arm.c:6436
+#: config/rs6000/rs6000-call.c:6329 config/s390/s390.c:12151
+#: config/s390/s390.c:12228
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17360 config/arm/arm.c:6432
-#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12123
-#: config/s390/s390.c:12200
+#: config/aarch64/aarch64.c:19002 config/arm/arm.c:6441
+#: config/rs6000/rs6000-call.c:6324 config/s390/s390.c:12146
+#: config/s390/s390.c:12223
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:18493
+#: config/aarch64/aarch64.c:20135
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "運算元號超出範圍"
 
-#: config/aarch64/aarch64.c:18495
+#: config/aarch64/aarch64.c:20137
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "運算元號超出範圍"
 
-#: config/aarch64/aarch64.c:23410 config/i386/i386.c:22491
+#: config/aarch64/aarch64.c:25053 config/i386/i386.c:22491
 #: config/i386/i386.c:22619
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
 msgstr "不支援的組合：%s"
 
-#: config/aarch64/aarch64.c:23420 config/aarch64/aarch64.c:23447
+#: config/aarch64/aarch64.c:25063 config/aarch64/aarch64.c:25090
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23424
+#: config/aarch64/aarch64.c:25067
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:23428
+#: config/aarch64/aarch64.c:25071
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/aarch64/aarch64.c:23451
+#: config/aarch64/aarch64.c:25094
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/aarch64/aarch64.c:23476
+#: config/aarch64/aarch64.c:25119
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %wd for type %qT"
@@ -36115,7 +36126,7 @@ msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "-mmemory-latency 開關的值 %qs 錯誤"
 
 #: config/alpha/alpha.c:6651 config/alpha/alpha.c:6654 config/arc/arc.c:7073
-#: config/arc/arc.c:7347 config/s390/s390.c:856 config/tilegx/tilegx.c:3536
+#: config/arc/arc.c:7347 config/s390/s390.c:879 config/tilegx/tilegx.c:3536
 #: config/tilepro/tilepro.c:3100
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -36240,18 +36251,18 @@ msgstr "%qs 屬性的引數不是「ilink1」或「ilink2」"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qs 屬性的引數不是「ilink1」或「ilink2」"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7216 config/arm/arm.c:7234
-#: config/arm/arm.c:7415 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7225 config/arm/arm.c:7243
+#: config/arm/arm.c:7424 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/bpf/bpf.c:80 config/csky/csky.c:6068 config/csky/csky.c:6096
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:318
-#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3429
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3662
-#: config/i386/i386-options.c:3713 config/i386/i386-options.c:3750
+#: config/h8300/h8300.c:4894 config/i386/i386-options.c:3442
+#: config/i386/i386-options.c:3619 config/i386/i386-options.c:3675
+#: config/i386/i386-options.c:3726 config/i386/i386-options.c:3763
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5164
-#: config/riscv/riscv.c:3039 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:20188 config/rx/rx.c:2727 config/rx/rx.c:2753
-#: config/s390/s390.c:1071 config/s390/s390.c:1158 config/sh/sh.c:8428
+#: config/riscv/riscv.c:3048 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:20305 config/rx/rx.c:2727 config/rx/rx.c:2753
+#: config/s390/s390.c:1094 config/s390/s390.c:1181 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
 #: config/visium/visium.c:724
@@ -36690,232 +36701,238 @@ msgstr "目的 CPU 不支援 THUMB 指令"
 msgid "target CPU does not support unaligned accesses"
 msgstr "目標 CPU 不支援 unaligned 存取"
 
-#: config/arm/arm.c:3489
+#: config/arm/arm.c:3244
+#, fuzzy, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr "切換 -mcpu=%s 衝突與 -march=%s 切換"
+
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check 和 -mno-apcs-frame 互不相容"
 
-#: config/arm/arm.c:3498
+#: config/arm/arm.c:3503
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic 和 -mapcs-reent 互不相容"
 
-#: config/arm/arm.c:3501
+#: config/arm/arm.c:3506
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "不支援 APCS 重入程式碼。已忽略"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3529
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3532
+#: config/arm/arm.c:3537
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "結構大小邊界只能是設定為 8, 32 或 64"
 
-#: config/arm/arm.c:3534
+#: config/arm/arm.c:3539
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "結構大小邊界只能是設定為 8 或 32"
 
-#: config/arm/arm.c:3559
+#: config/arm/arm.c:3564
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC 是不相容的與 -msingle-pic-base"
 
-#: config/arm/arm.c:3571 config/arm/arm.c:32865
+#: config/arm/arm.c:3576 config/arm/arm.c:32881
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/arm/arm.c:3579
+#: config/arm/arm.c:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= 不與 -fpic 並用時不起作用"
 
-#: config/arm/arm.c:3588
+#: config/arm/arm.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "「%s」不能做為 PIC 暫存器"
 
-#: config/arm/arm.c:3610 config/pru/pru.c:612
+#: config/arm/arm.c:3615 config/pru/pru.c:612
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition 不支援於這個架構"
 
-#: config/arm/arm.c:3755
+#: config/arm/arm.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable 與 -msdata=%s 互不相容"
 
-#: config/arm/arm.c:3807
+#: config/arm/arm.c:3812
 #, fuzzy, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt 需求 AAPCS 相容 ABI 用於適當作業"
 
-#: config/arm/arm.c:3810
+#: config/arm/arm.c:3815
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi 需要相應 CPU 的支援"
 
-#: config/arm/arm.c:3818
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "目的 CPU 不支援交互工作"
 
-#: config/arm/arm.c:3831
+#: config/arm/arm.c:3836
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS 不支援 -mcaller-super-interworking"
 
-#: config/arm/arm.c:3834
+#: config/arm/arm.c:3839
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS 不支援 -mcallee-super-interworking"
 
-#: config/arm/arm.c:3839
+#: config/arm/arm.c:3844
 #, fuzzy, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 以及沒有 ldrh"
 
-#: config/arm/arm.c:3842
+#: config/arm/arm.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "目的 CPU 不支援 THUMB 指令"
 
-#: config/arm/arm.c:3847
+#: config/arm/arm.c:3852
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3859
-#, gcc-internal-format
-msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
-msgstr ""
+#: config/arm/arm.c:3864
+#, fuzzy, gcc-internal-format
+#| msgid "-mfloat-abi=hard and VFP"
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
+msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:3867
+#: config/arm/arm.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:6101
+#: config/arm/arm.c:6110
 #, fuzzy, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "non-AAPCS 衍生的 PCS 變體"
 
-#: config/arm/arm.c:6103
+#: config/arm/arm.c:6112
 #, fuzzy, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "variadic 函式必須使用基底 AAPCS 變體"
 
-#: config/arm/arm.c:6123
+#: config/arm/arm.c:6132
 #, fuzzy, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS 變體"
 
-#: config/arm/arm.c:6375
+#: config/arm/arm.c:6384
 #, fuzzy, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 hard-float VFP ABI"
 
-#: config/arm/arm.c:6464
+#: config/arm/arm.c:6473
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6848 config/arm/arm.c:7069 config/arm/arm.c:7102
-#: config/arm/arm.c:28832
+#: config/arm/arm.c:6857 config/arm/arm.c:7078 config/arm/arm.c:7111
+#: config/arm/arm.c:28848
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7240
+#: config/arm/arm.c:7249
 #, gcc-internal-format
 msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
 msgstr ""
 
-#: config/arm/arm.c:7364
+#: config/arm/arm.c:7373
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE 屬性只有套用到函式，無法 %s"
 
-#: config/arm/arm.c:7376
+#: config/arm/arm.c:7385
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: config/arm/arm.c:7385
+#: config/arm/arm.c:7394
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE 屬性只有套用到函式，無法 %s"
 
-#: config/arm/arm.c:7407 config/arm/arm.c:7459
+#: config/arm/arm.c:7416 config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: config/arm/arm.c:7426
+#: config/arm/arm.c:7435
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE 屬性沒有任何效果於單位本地函式"
 
-#: config/arm/arm.c:7475
+#: config/arm/arm.c:7484
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE 屬性只有套用到函數型式"
 
-#: config/arm/arm.c:9439
+#: config/arm/arm.c:9448
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13198
+#: config/arm/arm.c:13217
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13201
+#: config/arm/arm.c:13220
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25478
+#: config/arm/arm.c:25497
 #, fuzzy, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "無法計算真實位置的重疊參數"
 
-#: config/arm/arm.c:26140
+#: config/arm/arm.c:26159
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "非預期的模組結束"
 
-#: config/arm/arm.c:26399
+#: config/arm/arm.c:26418
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高暫存器彈堆疊時沒有可用的低暫存器"
 
-#: config/arm/arm.c:26651
+#: config/arm/arm.c:26670
 #, fuzzy, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/arm/arm.c:26897
+#: config/arm/arm.c:26916
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32880
+#: config/arm/arm.c:32896
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "無效的向量型態用於屬性 %qs"
@@ -36923,22 +36940,22 @@ msgstr "無效的向量型態用於屬性 %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32888
+#: config/arm/arm.c:32904
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32901
+#: config/arm/arm.c:32917
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "無效的向量型態用於屬性 %qs"
 
-#: config/arm/arm.c:32915
+#: config/arm/arm.c:32931
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "目標屬性或 pragma 變更 SPE ABI"
 
-#: config/arm/arm.c:33927
+#: config/arm/arm.c:33943
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
@@ -37018,17 +37035,17 @@ msgstr "-fpic 未被支援"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIC 未被支援"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5111
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:5122
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "函式屬性 %qs，%qs 和 %qs 彼此互斥"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:5123
+#: config/avr/avr.c:1066 config/riscv/riscv.c:5134
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs 函式無法有引數"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:5120
+#: config/avr/avr.c:1069 config/riscv/riscv.c:5131
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs 函式無法回傳值"
@@ -37789,136 +37806,136 @@ msgstr "%qs 的引數必須是一個 2 位無號原文"
 msgid "parameter to builtin not valid: %s"
 msgstr "-ffpe-trap 的參數無效：%s"
 
-#: config/i386/i386-expand.c:8043
+#: config/i386/i386-expand.c:8049
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/i386/i386-expand.c:8453 config/i386/i386-expand.c:9905
+#: config/i386/i386-expand.c:8459 config/i386/i386-expand.c:9911
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後一筆引數必須是 2-bit 即時"
 
-#: config/i386/i386-expand.c:8841
+#: config/i386/i386-expand.c:8847
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fifth 引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:8936
+#: config/i386/i386-expand.c:8942
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:9836
+#: config/i386/i386-expand.c:9842
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386-expand.c:9851
+#: config/i386/i386-expand.c:9857
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386-expand.c:9884
+#: config/i386/i386-expand.c:9890
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386-expand.c:9924
+#: config/i386/i386-expand.c:9930
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386-expand.c:9937
+#: config/i386/i386-expand.c:9943
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386-expand.c:9947
+#: config/i386/i386-expand.c:9953
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "下一個到最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:9952
+#: config/i386/i386-expand.c:9958
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:10089
+#: config/i386/i386-expand.c:10095
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "引數必須是常數"
 
-#: config/i386/i386-expand.c:10094
+#: config/i386/i386-expand.c:10100
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "錯誤指令："
 
-#: config/i386/i386-expand.c:10100 config/i386/i386-expand.c:10420
+#: config/i386/i386-expand.c:10106 config/i386/i386-expand.c:10426
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "對樹結區段的共享不正確"
 
-#: config/i386/i386-expand.c:10402
+#: config/i386/i386-expand.c:10408
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386-expand.c:10408
+#: config/i386/i386-expand.c:10414
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386-expand.c:10411
+#: config/i386/i386-expand.c:10417
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:10906 config/rs6000/rs6000-call.c:10919
+#: config/i386/i386-expand.c:10912 config/rs6000/rs6000-call.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: config/i386/i386-expand.c:11119
+#: config/i386/i386-expand.c:11125
 #, fuzzy, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE 需要不明 isa 選項"
 
-#: config/i386/i386-expand.c:11123
+#: config/i386/i386-expand.c:11129
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE 需要 isa 選項 %s"
 
-#: config/i386/i386-expand.c:12044
+#: config/i386/i386-expand.c:12050
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386-expand.c:12077
+#: config/i386/i386-expand.c:12083
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後一筆引數必須是即時"
 
-#: config/i386/i386-expand.c:12838 config/i386/i386-expand.c:13050
+#: config/i386/i386-expand.c:12844 config/i386/i386-expand.c:13056
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386-expand.c:13103
+#: config/i386/i386-expand.c:13109
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386-expand.c:13109
+#: config/i386/i386-expand.c:13115
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "錯誤指令："
 
-#: config/i386/i386-expand.c:13128
+#: config/i386/i386-expand.c:13134
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "下一個到最後一筆引數必須是 8-bit 即時"
@@ -37938,525 +37955,525 @@ msgstr "不支援堆疊限制運算式"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/i386/i386-options.c:849 config/i386/i386-options.c:2000
-#: config/i386/i386-options.c:2009
+#: config/i386/i386-options.c:852 config/i386/i386-options.c:2010
+#: config/i386/i386-options.c:2019
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "編碼式樣 %s 不支援 PIC 模式"
 
-#: config/i386/i386-options.c:1106
+#: config/i386/i386-options.c:1109
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument is not a string"
 msgstr "屬性 %qE 引數不是字串"
 
-#: config/i386/i386-options.c:1170
+#: config/i386/i386-options.c:1173
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs argument %qs is unknown"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/i386/i386-options.c:1233
+#: config/i386/i386-options.c:1236
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "序列屬性於 %C 已經指定的在中型態敘述"
 
-#: config/i386/i386-options.c:1271
+#: config/i386/i386-options.c:1274
 #, fuzzy, gcc-internal-format
 msgid "attribute value %qs is unknown in %qs attribute"
 msgstr "%s 屬性的『%s』衝突與 %s 屬性於 %L"
 
-#: config/i386/i386-options.c:1522
+#: config/i386/i386-options.c:1525
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: config/i386/i386-options.c:1528
+#: config/i386/i386-options.c:1531
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386-options.c:1538
+#: config/i386/i386-options.c:1541
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%q+D 的暫存器名無效"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1564
+#: config/i386/i386-options.c:1567
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386-options.c:1577
+#: config/i386/i386-options.c:1580
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "對齊指定的用於函式 %qE"
 
-#: config/i386/i386-options.c:1587
+#: config/i386/i386-options.c:1590
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386-options.c:1594
+#: config/i386/i386-options.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs 沒有指定類別名"
 
-#: config/i386/i386-options.c:1647
+#: config/i386/i386-options.c:1650
 #, gcc-internal-format
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.c:1832
+#: config/i386/i386-options.c:1835
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/i386/i386-options.c:1879
+#: config/i386/i386-options.c:1889
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
-#: config/i386/i386-options.c:1881
+#: config/i386/i386-options.c:1891
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.c:1909
+#: config/i386/i386-options.c:1919
 #, fuzzy, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386-options.c:1914
+#: config/i386/i386-options.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386-options.c:1929
+#: config/i386/i386-options.c:1939
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386-options.c:1940
+#: config/i386/i386-options.c:1950
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-f%s 不受支援：已忽略"
 
-#: config/i386/i386-options.c:1946
+#: config/i386/i386-options.c:1956
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "transactional 記憶體未被支援與 non-call 異常"
 
-#: config/i386/i386-options.c:1949
+#: config/i386/i386-options.c:1959
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "transactional 記憶體未被支援與 non-call 異常"
 
-#: config/i386/i386-options.c:1953
+#: config/i386/i386-options.c:1963
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fdirectives-only 是不相容的與 -traditional"
 
-#: config/i386/i386-options.c:1970 config/i386/i386-options.c:1979
-#: config/i386/i386-options.c:1991 config/i386/i386-options.c:2002
-#: config/i386/i386-options.c:2013
+#: config/i386/i386-options.c:1980 config/i386/i386-options.c:1989
+#: config/i386/i386-options.c:2001 config/i386/i386-options.c:2012
+#: config/i386/i386-options.c:2023
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386-options.c:1982 config/i386/i386-options.c:1994
+#: config/i386/i386-options.c:1992 config/i386/i386-options.c:2004
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/i386/i386-options.c:2037
+#: config/i386/i386-options.c:2047
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel 不支援在中這個組態"
 
-#: config/i386/i386-options.c:2042
+#: config/i386/i386-options.c:2052
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未編譯入對 %i 位模式的支援"
 
-#: config/i386/i386-options.c:2051
+#: config/i386/i386-options.c:2064
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.c:2053
+#: config/i386/i386-options.c:2066
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.c:2060
+#: config/i386/i386-options.c:2073
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.c:2062
+#: config/i386/i386-options.c:2075
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.c:2070 config/i386/i386-options.c:2444
+#: config/i386/i386-options.c:2083 config/i386/i386-options.c:2457
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您選擇的 CPU 不支援 x86-64 指令集"
 
-#: config/i386/i386-options.c:2383
+#: config/i386/i386-options.c:2396
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-march= 所帶參數(%s)不正確"
 
-#: config/i386/i386-options.c:2384
+#: config/i386/i386-options.c:2397
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %sarch=%s %s"
 
-#: config/i386/i386-options.c:2406
+#: config/i386/i386-options.c:2419
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.c:2408
+#: config/i386/i386-options.c:2421
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2413
+#: config/i386/i386-options.c:2426
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.c:2414
+#: config/i386/i386-options.c:2427
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.c:2463
+#: config/i386/i386-options.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune= 所帶參數(%s)不正確"
 
-#: config/i386/i386-options.c:2464
+#: config/i386/i386-options.c:2477
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %stune=%s %s"
 
-#: config/i386/i386-options.c:2485
+#: config/i386/i386-options.c:2498
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.c:2487
+#: config/i386/i386-options.c:2500
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.c:2492
+#: config/i386/i386-options.c:2505
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.c:2493
+#: config/i386/i386-options.c:2506
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.c:2517
+#: config/i386/i386-options.c:2530
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386-options.c:2519
+#: config/i386/i386-options.c:2532
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386-options.c:2522
+#: config/i386/i386-options.c:2535
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之間"
 
-#: config/i386/i386-options.c:2550
+#: config/i386/i386-options.c:2563
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386-options.c:2551
+#: config/i386/i386-options.c:2564
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386-options.c:2630
+#: config/i386/i386-options.c:2643
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-mpreferred-stack-boundary 未被支援用於這個目標"
 
-#: config/i386/i386-options.c:2633
+#: config/i386/i386-options.c:2646
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/i386/i386-options.c:2656
+#: config/i386/i386-options.c:2669
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 未被介於 %d 和 12"
 
-#: config/i386/i386-options.c:2669
+#: config/i386/i386-options.c:2682
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: config/i386/i386-options.c:2672
+#: config/i386/i386-options.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: config/i386/i386-options.c:2678
+#: config/i386/i386-options.c:2691
 #, fuzzy, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386-options.c:2679
+#: config/i386/i386-options.c:2692
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386-options.c:2689
+#: config/i386/i386-options.c:2702
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已停用，使用 387 指令"
 
-#: config/i386/i386-options.c:2696
+#: config/i386/i386-options.c:2709
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已停用，使用 SSE 指令"
 
-#: config/i386/i386-options.c:2746
+#: config/i386/i386-options.c:2759
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.c:2748
+#: config/i386/i386-options.c:2761
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.c:2762
+#: config/i386/i386-options.c:2775
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.c:2764
+#: config/i386/i386-options.c:2777
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.c:2818
+#: config/i386/i386-options.c:2831
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry isn%'t 支援的用於 32-bit 在中組合與 -fpic"
 
-#: config/i386/i386-options.c:2821
+#: config/i386/i386-options.c:2834
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386-options.c:2825
+#: config/i386/i386-options.c:2838
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.c:2890
+#: config/i386/i386-options.c:2903
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/i386/i386-options.c:2949
+#: config/i386/i386-options.c:2962
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2954
+#: config/i386/i386-options.c:2967
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:2982
+#: config/i386/i386-options.c:2995
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.c:3030
+#: config/i386/i386-options.c:3043
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: config/i386/i386-options.c:3157
+#: config/i386/i386-options.c:3170
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.c:3172
+#: config/i386/i386-options.c:3185
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3221
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386-options.c:3231
+#: config/i386/i386-options.c:3244
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3266
+#: config/i386/i386-options.c:3279
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386-options.c:3276
+#: config/i386/i386-options.c:3289
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3389
+#: config/i386/i386-options.c:3402
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3391
+#: config/i386/i386-options.c:3404
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 位元組 cop 指令未被允許在中 64-bit VLIW 模式"
 
-#: config/i386/i386-options.c:3395
+#: config/i386/i386-options.c:3408
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3442 config/i386/i386-options.c:3493
+#: config/i386/i386-options.c:3455 config/i386/i386-options.c:3506
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 屬性互不相容"
 
-#: config/i386/i386-options.c:3447
+#: config/i386/i386-options.c:3460
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.c:3454 config/i386/i386-options.c:3682
+#: config/i386/i386-options.c:3467 config/i386/i386-options.c:3695
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 屬性需求整數常數引數"
 
-#: config/i386/i386-options.c:3460
+#: config/i386/i386-options.c:3473
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/i386/i386-options.c:3485 config/i386/i386-options.c:3528
+#: config/i386/i386-options.c:3498 config/i386/i386-options.c:3541
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.c:3489
+#: config/i386/i386-options.c:3502
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 屬性互不相容"
 
-#: config/i386/i386-options.c:3497 config/i386/i386-options.c:3546
+#: config/i386/i386-options.c:3510 config/i386/i386-options.c:3559
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.c:3507 config/i386/i386-options.c:3524
+#: config/i386/i386-options.c:3520 config/i386/i386-options.c:3537
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.c:3511
+#: config/i386/i386-options.c:3524
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 屬性互不相容"
 
-#: config/i386/i386-options.c:3515 config/i386/i386-options.c:3542
+#: config/i386/i386-options.c:3528 config/i386/i386-options.c:3555
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.c:3532 config/i386/i386-options.c:3550
+#: config/i386/i386-options.c:3545 config/i386/i386-options.c:3563
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.c:3538
+#: config/i386/i386-options.c:3551
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 屬性被用於無 class-method"
 
-#: config/i386/i386-options.c:3642 config/rs6000/rs6000.c:20301
+#: config/i386/i386-options.c:3655 config/rs6000/rs6000.c:20418
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/i386/i386-options.c:3669
+#: config/i386/i386-options.c:3682
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/i386/i386-options.c:3690
+#: config/i386/i386-options.c:3703
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/i386/i386-options.c:3724 config/i386/i386-options.c:3734
+#: config/i386/i386-options.c:3737 config/i386/i386-options.c:3747
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 屬性不是相容"
 
-#: config/i386/i386-options.c:3761 config/i386/i386-options.c:3783
-#: config/ia64/ia64.c:812 config/s390/s390.c:1168
+#: config/i386/i386-options.c:3774 config/i386/i386-options.c:3796
+#: config/ia64/ia64.c:812 config/s390/s390.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 屬性需要字串常數引數"
 
-#: config/i386/i386-options.c:3771 config/i386/i386-options.c:3793
-#: config/s390/s390.c:1197
+#: config/i386/i386-options.c:3784 config/i386/i386-options.c:3806
+#: config/s390/s390.c:1220
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: config/i386/i386-options.c:3825
+#: config/i386/i386-options.c:3838
 #, fuzzy, gcc-internal-format
 #| msgid "dereferenced pointers should have a name or a type tag"
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "提領的指標應具有一個名稱或類型標記"
 
-#: config/i386/i386-options.c:3832
+#: config/i386/i386-options.c:3845
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "插斷函式必須沒有任何引數"
 
-#: config/i386/i386-options.c:3843
+#: config/i386/i386-options.c:3856
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3846
+#: config/i386/i386-options.c:3859
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
@@ -38921,7 +38938,7 @@ msgstr "%qE 無法同時有 %<mips16%> 和 %<nomips16%>屬性"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE redeclared 與衝突 %qs 屬性"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3067
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:3076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE 屬性需要字串常數引數"
@@ -40008,57 +40025,57 @@ msgstr ""
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/riscv/riscv.c:2687 config/riscv/riscv.c:2729
+#: config/riscv/riscv.c:2696 config/riscv/riscv.c:2738
 #, fuzzy, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/riscv/riscv.c:3078
+#: config/riscv/riscv.c:3087
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/riscv/riscv.c:4735
+#: config/riscv/riscv.c:4744
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4778
+#: config/riscv/riscv.c:4787
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4782
+#: config/riscv/riscv.c:4791
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4786
+#: config/riscv/riscv.c:4795
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4796
+#: config/riscv/riscv.c:4805
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/riscv/riscv.c:4809
+#: config/riscv/riscv.c:4818
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4836 config/rs6000/rs6000.c:4595
+#: config/riscv/riscv.c:4845 config/rs6000/rs6000.c:4599
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs 並非有效類別名稱"
 
-#: config/riscv/riscv.c:4850 config/rs6000/rs6000.c:4578
+#: config/riscv/riscv.c:4859 config/rs6000/rs6000.c:4582
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: config/riscv/riscv.c:5149
+#: config/riscv/riscv.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs 函式無法有引數"
@@ -40592,245 +40609,245 @@ msgstr "使用暫存器 r2 和 r5"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3238 config/rs6000/rs6000.c:3241
-#: config/rs6000/rs6000.c:3244
+#: config/rs6000/rs6000.c:3242 config/rs6000/rs6000.c:3245
+#: config/rs6000/rs6000.c:3248
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: config/rs6000/rs6000.c:3345
+#: config/rs6000/rs6000.c:3349
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 需要 PowerPC64 架構，正在啟用"
 
-#: config/rs6000/rs6000.c:3491
+#: config/rs6000/rs6000.c:3495
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mas100-syntax 是不相容的與 -gdwarf"
 
-#: config/rs6000/rs6000.c:3511 config/rs6000/rtems.h:114
+#: config/rs6000/rs6000.c:3515 config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires a PowerPC64 cpu"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 需要 PowerPC64 CPU"
 
-#: config/rs6000/rs6000.c:3519
+#: config/rs6000/rs6000.c:3523
 #, fuzzy, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "-mcmodel 不相容的與其他光碟內容表選項"
 
-#: config/rs6000/rs6000.c:3540
+#: config/rs6000/rs6000.c:3544
 #, fuzzy, gcc-internal-format
 msgid "%qs unsupported for this ABI"
 msgstr "FPA 被不受支援的在中 AAPCS"
 
-#: config/rs6000/rs6000.c:3673
+#: config/rs6000/rs6000.c:3677
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 在 64 位元 Darwin 下不受支援；它與已安裝的 C 和 C++ 函式庫不相容"
 
-#: config/rs6000/rs6000.c:3812
+#: config/rs6000/rs6000.c:3816
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec 不支援在中這個目標"
 
-#: config/rs6000/rs6000.c:3829
+#: config/rs6000/rs6000.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring 在低位位元組在前的系統上不受支援"
 
-#: config/rs6000/rs6000.c:3915
+#: config/rs6000/rs6000.c:3919
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3923
+#: config/rs6000/rs6000.c:3927
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-mcmodel 不相容的與其他光碟內容表選項"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3948 config/rs6000/rs6000.c:3956
-#: config/rs6000/rs6000.c:3963 config/rs6000/rs6000.c:3970
-#: config/rs6000/rs6000.c:3978 config/rs6000/rs6000.c:3997
-#: config/rs6000/rs6000.c:4059 config/rs6000/rs6000.c:4086
-#: config/rs6000/rs6000.c:4113 config/rs6000/rs6000.c:4128
-#: config/rs6000/rs6000.c:4136 config/rs6000/rs6000.c:4181
-#: config/rs6000/rs6000.c:4183 config/rs6000/rs6000.c:4275
-#: config/rs6000/rs6000.c:4288 config/rs6000/rs6000.c:4297
-#: config/rs6000/rs6000.c:4447 config/rs6000/rs6000.c:4470
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3960
+#: config/rs6000/rs6000.c:3967 config/rs6000/rs6000.c:3974
+#: config/rs6000/rs6000.c:3982 config/rs6000/rs6000.c:4001
+#: config/rs6000/rs6000.c:4063 config/rs6000/rs6000.c:4090
+#: config/rs6000/rs6000.c:4117 config/rs6000/rs6000.c:4132
+#: config/rs6000/rs6000.c:4140 config/rs6000/rs6000.c:4185
+#: config/rs6000/rs6000.c:4187 config/rs6000/rs6000.c:4279
+#: config/rs6000/rs6000.c:4292 config/rs6000/rs6000.c:4301
+#: config/rs6000/rs6000.c:4451 config/rs6000/rs6000.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: config/rs6000/rs6000.c:4172
+#: config/rs6000/rs6000.c:4176
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "目標屬性或 pragma 變更長兩倍大小"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4202
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4213
+#: config/rs6000/rs6000.c:4217
 #, fuzzy, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "使用我進階精確度長雙倍"
 
-#: config/rs6000/rs6000.c:4216
+#: config/rs6000/rs6000.c:4220
 #, fuzzy, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr "使用 IBM 進階精確度長雙倍"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s 不支援 %s"
 
-#: config/rs6000/rs6000.c:4244
+#: config/rs6000/rs6000.c:4248
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4267
+#: config/rs6000/rs6000.c:4271
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4354
+#: config/rs6000/rs6000.c:4358
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "不明 vectorization 函式庫 ABI 型態 (%s) 用於 -mveclibabi=切換"
 
-#: config/rs6000/rs6000.c:4379 config/rs6000/rs6000.c:4394
+#: config/rs6000/rs6000.c:4383 config/rs6000/rs6000.c:4398
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "目標屬性或 pragma 變更 AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4407
+#: config/rs6000/rs6000.c:4411
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "目標屬性或 pragma 變更 darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4603
+#: config/rs6000/rs6000.c:4607
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "需要 call-clobbered 目標暫存器"
 
-#: config/rs6000/rs6000.c:4900
+#: config/rs6000/rs6000.c:4904
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/rs6000/rs6000.c:4937
+#: config/rs6000/rs6000.c:4941
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7847
+#: config/rs6000/rs6000.c:7901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/rs6000/rs6000.c:10582
+#: config/rs6000/rs6000.c:10675
 #, gcc-internal-format
-msgid "%qs is an opaque type, and you can't set it to other values."
+msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.c:17677
+#: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支援取樣 64 位元程式碼"
 
-#: config/rs6000/rs6000.c:19967
+#: config/rs6000/rs6000.c:20084
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/rs6000/rs6000.c:20049
+#: config/rs6000/rs6000.c:20166
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<long double%> 無效"
 
-#: config/rs6000/rs6000.c:20051
+#: config/rs6000/rs6000.c:20168
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用布林類型無效"
 
-#: config/rs6000/rs6000.c:20053
+#: config/rs6000/rs6000.c:20170
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<complex%> 無效"
 
-#: config/rs6000/rs6000.c:20055
+#: config/rs6000/rs6000.c:20172
 #, fuzzy, gcc-internal-format
-msgid "use of decimal floating point types in AltiVec types is invalid"
+msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "使用的十進位浮點數類型在中 AltiVec 類型無效"
 
-#: config/rs6000/rs6000.c:20061
+#: config/rs6000/rs6000.c:20178
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:20064
+#: config/rs6000/rs6000.c:20181
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "在 AltiVec 類型中使用 %<long%> 已過時；請改用 %<int%>"
 
-#: config/rs6000/rs6000.c:20069
+#: config/rs6000/rs6000.c:20186
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<long long%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:20072
+#: config/rs6000/rs6000.c:20189
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<double%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:24110
+#: config/rs6000/rs6000.c:24227
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "無效的 cpu「%s」用於 %s「%s」%s"
 
-#: config/rs6000/rs6000.c:24113
+#: config/rs6000/rs6000.c:24230
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: config/rs6000/rs6000.c:24115
+#: config/rs6000/rs6000.c:24232
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s「%s」%s 無效"
 
-#: config/rs6000/rs6000.c:24660
+#: config/rs6000/rs6000.c:24777
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24819
+#: config/rs6000/rs6000.c:24936
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24851
+#: config/rs6000/rs6000.c:24968
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/rs6000/rs6000.c:25107
+#: config/rs6000/rs6000.c:25224
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
 
-#: config/rs6000/rs6000.c:27708
+#: config/rs6000/rs6000.c:27827
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
@@ -41020,7 +41037,7 @@ msgstr "RX FPU 指令不支援 NaNs 和 infinities"
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:712 config/s390/s390.c:896
+#: config/s390/s390-c.c:712 config/s390/s390.c:919
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -41092,205 +41109,211 @@ msgstr "%qE 被不宜用"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.c:743
+#: config/s390/s390.c:762
+#, fuzzy, gcc-internal-format
+#| msgid "constant argument out of range for %qs"
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr "常數引數超過 %qs 的範圍"
+
+#: config/s390/s390.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.c:759
+#: config/s390/s390.c:782
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.c:808
+#: config/s390/s390.c:831
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:814
+#: config/s390/s390.c:837
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)."
 msgstr ""
 
-#: config/s390/s390.c:821
+#: config/s390/s390.c:844
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:827
+#: config/s390/s390.c:850
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher."
 msgstr ""
 
-#: config/s390/s390.c:833
+#: config/s390/s390.c:856
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires arch14 or higher."
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: config/s390/s390.c:852
+#: config/s390/s390.c:875
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "<unresolved overloaded function type>"
 
-#: config/s390/s390.c:859 config/tilegx/tilegx.c:3539
+#: config/s390/s390.c:882 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "不當的內建 icode"
 
-#: config/s390/s390.c:993
+#: config/s390/s390.c:1016
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "無效的引數到內建函式"
 
-#: config/s390/s390.c:1094
+#: config/s390/s390.c:1117
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:1184
+#: config/s390/s390.c:1207
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/s390/s390.c:10001
+#: config/s390/s390.c:10024
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部變數大小總和超過架構極值。"
 
-#: config/s390/s390.c:11366
+#: config/s390/s390.c:11389
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "影格大小的函式 %qs 是 %wd 位元組超出使用者提供的堆疊限制的 %d 位元組。 unconditional 陷阱被已加入。"
 
-#: config/s390/s390.c:11382
+#: config/s390/s390.c:11405
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "影格大小的函式 %qs 是 %wd 位元組該項是超過半堆疊大小。動態檢查會無法是 reliable。沒有檢查發出用於這個函式。"
 
-#: config/s390/s390.c:11410
+#: config/s390/s390.c:11433
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "影格大小的 %qs 是 %wd 位元組"
 
-#: config/s390/s390.c:11414
+#: config/s390/s390.c:11437
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs 使用動態堆疊指派"
 
-#: config/s390/s390.c:13124
+#: config/s390/s390.c:13147
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "巢狀函式 %qs 被宣告為 %<extern%>"
 
-#: config/s390/s390.c:15390
+#: config/s390/s390.c:15413
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/s390/s390.c:15397
+#: config/s390/s390.c:15420
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15432
+#: config/s390/s390.c:15455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.c:15435
+#: config/s390/s390.c:15458
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15464
+#: config/s390/s390.c:15487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.c:15468
+#: config/s390/s390.c:15491
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "硬體十進位浮點數指令無法使用在中 ESA/390 模式"
 
-#: config/s390/s390.c:15480
+#: config/s390/s390.c:15503
 #, fuzzy, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp can%'t 被已用於接合與 -msoft-float"
 
-#: config/s390/s390.c:15489
+#: config/s390/s390.c:15512
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支援"
 
-#: config/s390/s390.c:15495
+#: config/s390/s390.c:15518
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "堆疊大小必須大於堆疊防護值"
 
-#: config/s390/s390.c:15497
+#: config/s390/s390.c:15520
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "堆疊大小不能大於 64K"
 
-#: config/s390/s390.c:15500
+#: config/s390/s390.c:15523
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard 意味著使用 -mstack-size"
 
-#: config/s390/s390.c:15513
+#: config/s390/s390.c:15536
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15516
+#: config/s390/s390.c:15539
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15519
+#: config/s390/s390.c:15542
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15545
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15575
+#: config/s390/s390.c:15598
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE 屬性被支援只有用於 SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15611
+#: config/s390/s390.c:15634
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "引數到 %qs 應該是 non-negative 整數"
 
-#: config/s390/s390.c:15618
+#: config/s390/s390.c:15641
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/s390/s390.c:15649
+#: config/s390/s390.c:15672
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15810 config/s390/s390.c:15860 config/s390/s390.c:15877
+#: config/s390/s390.c:15833 config/s390/s390.c:15883 config/s390/s390.c:15900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15816
+#: config/s390/s390.c:15839
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "%<__int128%>未被支援由這個目標"
@@ -41639,18 +41662,23 @@ msgstr "-fexcess-precision=標準用於 Ada"
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1637
+#: ada/gcc-interface/trans.c:332
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr "insn 含有無效的位址！"
+
+#: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
 msgid "subprogram %q+F not marked %<Inline_Always%>"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:1639 ada/gcc-interface/trans.c:1645
+#: ada/gcc-interface/trans.c:1644 ada/gcc-interface/trans.c:1650
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "parent subprogram cannot be inlined"
 msgstr "範本參數不能是夥伴"
 
-#: ada/gcc-interface/trans.c:1643
+#: ada/gcc-interface/trans.c:1648
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "subprogram %q+F not marked %<Inline%>"
@@ -41722,8 +41750,8 @@ msgstr "屬性 %qs 套用到陣列類型只有"
 msgid "could not read the BRIG file"
 msgstr "無法寫入回應檔案 %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2210 c/c-typeck.c:12707 cp/typeck.c:2146
-#: cp/typeck.c:8603 cp/typeck.c:9394
+#: c/c-convert.c:101 c/c-typeck.c:2260 c/c-typeck.c:12767 cp/typeck.c:2157
+#: cp/typeck.c:8610 cp/typeck.c:9401
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如預期地被忽略"
@@ -41783,7 +41811,7 @@ msgstr "變數 %qD 設定並不是使用"
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "陣列 %q+D 類型與隱含初始化不相容"
 
-#: c/c-decl.c:1596 c/c-decl.c:7353 c/c-decl.c:8261 c/c-decl.c:9068
+#: c/c-decl.c:1596 c/c-decl.c:7352 c/c-decl.c:8260 c/c-decl.c:9067
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "原本地定義的在此"
@@ -42015,7 +42043,7 @@ msgstr "%q+D 的宣告隱藏了先前的一個非變數宣告"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: c/c-decl.c:3041 cp/name-lookup.c:3339
+#: c/c-decl.c:3041 cp/name-lookup.c:3340
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD 的宣告隱藏了一個全域宣告"
@@ -42025,7 +42053,7 @@ msgstr "%qD 的宣告隱藏了一個全域宣告"
 msgid "declaration of %qD shadows a previous local"
 msgstr "%qD 的宣告隱藏了先前的一個局部變數"
 
-#: c/c-decl.c:3073 cp/name-lookup.c:3112
+#: c/c-decl.c:3073 cp/name-lookup.c:3113
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "帶陰影宣告是在此"
@@ -42035,217 +42063,217 @@ msgstr "帶陰影宣告是在此"
 msgid "nested extern declaration of %qD"
 msgstr "對 %qD 的巢狀的外部宣告"
 
-#: c/c-decl.c:3367 c/c-decl.c:3381
+#: c/c-decl.c:3366 c/c-decl.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "隱含宣告函式 %qE"
 
-#: c/c-decl.c:3373 c/c-decl.c:3386
+#: c/c-decl.c:3372 c/c-decl.c:3385
 #, gcc-internal-format
 msgid "implicit declaration of function %qE"
 msgstr "隱含宣告函式 %qE"
 
-#: c/c-decl.c:3405
+#: c/c-decl.c:3404
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qE"
 msgstr "對 %q+#D 無效的重宣告"
 
-#: c/c-decl.c:3675
+#: c/c-decl.c:3674
 #, gcc-internal-format
 msgid "incompatible implicit declaration of built-in function %qD"
 msgstr "隱含宣告與內建函式 %qD 不相容"
 
-#: c/c-decl.c:3685
+#: c/c-decl.c:3684
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "include %qs or provide a declaration of %qD"
 msgstr "對 %q+#D 無效的重宣告"
 
-#: c/c-decl.c:3696
+#: c/c-decl.c:3695
 #, gcc-internal-format
 msgid "incompatible implicit declaration of function %qD"
 msgstr "隱含宣告與函式 %qD 不相容"
 
-#: c/c-decl.c:3757
+#: c/c-decl.c:3756
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE undeclared 在此 (無法在中函式)"
 
-#: c/c-decl.c:3762
+#: c/c-decl.c:3761
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared here (not in a function)"
 msgstr "%qE undeclared 在此 (無法在中函式)"
 
-#: c/c-decl.c:3775
+#: c/c-decl.c:3774
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE undeclared (先使用在中這個函式)"
 
-#: c/c-decl.c:3780
+#: c/c-decl.c:3779
 #, fuzzy, gcc-internal-format
 msgid "%qE undeclared (first use in this function)"
 msgstr "%qE undeclared (先使用在中這個函式)"
 
-#: c/c-decl.c:3784
+#: c/c-decl.c:3783
 #, fuzzy, gcc-internal-format
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每個 undeclared 識別碼被報告只一次用於每個函式看來在中"
 
-#: c/c-decl.c:3832 cp/decl.c:3281
+#: c/c-decl.c:3831 cp/decl.c:3263
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "標籤 %qE 在所有函式外被參照"
 
-#: c/c-decl.c:3868
+#: c/c-decl.c:3867
 #, gcc-internal-format
 msgid "jump into scope of identifier with variably modified type"
 msgstr "跳至具有可變類型的識別碼的作用欄位中"
 
-#: c/c-decl.c:3871
+#: c/c-decl.c:3870
 #, fuzzy, gcc-internal-format
 msgid "jump skips variable initialization"
 msgstr "跳躍跳過變數初始化"
 
-#: c/c-decl.c:3872 c/c-decl.c:3927 c/c-decl.c:4017
+#: c/c-decl.c:3871 c/c-decl.c:3926 c/c-decl.c:4016
 #, fuzzy, gcc-internal-format
 msgid "label %qD defined here"
 msgstr "標貼 %qD 定義的在此"
 
-#: c/c-decl.c:3926 c/c-decl.c:4016
+#: c/c-decl.c:3925 c/c-decl.c:4015
 #, gcc-internal-format
 msgid "jump into statement expression"
 msgstr "跳轉至敘述運算式中"
 
-#: c/c-decl.c:3949
+#: c/c-decl.c:3948
 #, gcc-internal-format
 msgid "duplicate label declaration %qE"
 msgstr "重複的標籤定義 %qE"
 
-#: c/c-decl.c:4048 cp/decl.c:3687
+#: c/c-decl.c:4047 cp/decl.c:3669
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複的標籤 %qD"
 
-#: c/c-decl.c:4079
+#: c/c-decl.c:4078
 #, fuzzy, gcc-internal-format
 msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
 msgstr "傳統 C lacks 分隔命名空間用於標貼，識別碼 %qE 衝突"
 
-#: c/c-decl.c:4144
+#: c/c-decl.c:4143
 #, fuzzy, gcc-internal-format
 msgid "switch jumps over variable initialization"
 msgstr "切換跳躍之上變數初始化"
 
-#: c/c-decl.c:4145 c/c-decl.c:4156
+#: c/c-decl.c:4144 c/c-decl.c:4155
 #, fuzzy, gcc-internal-format
 msgid "switch starts here"
 msgstr "切換開始在此"
 
-#: c/c-decl.c:4155
+#: c/c-decl.c:4154
 #, fuzzy, gcc-internal-format
 msgid "switch jumps into statement expression"
 msgstr "切換跳躍進入敘述運算式"
 
-#: c/c-decl.c:4238
+#: c/c-decl.c:4237
 #, fuzzy, gcc-internal-format
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE 定義為錯誤的 kind 的標籤"
 
-#: c/c-decl.c:4424 cp/tree.c:4728
+#: c/c-decl.c:4423 cp/tree.c:4789
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: c/c-decl.c:4433
+#: c/c-decl.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: c/c-decl.c:4698
+#: c/c-decl.c:4697
 #, gcc-internal-format
 msgid "unnamed struct/union that defines no instances"
 msgstr "未定義任何實體的無名結構/聯合"
 
-#: c/c-decl.c:4709
+#: c/c-decl.c:4708
 #, gcc-internal-format
 msgid "empty declaration with storage class specifier does not redeclare tag"
 msgstr "帶有存儲類別的空宣告沒有重宣告標記"
 
-#: c/c-decl.c:4725
+#: c/c-decl.c:4724
 #, gcc-internal-format
 msgid "empty declaration with type qualifier does not redeclare tag"
 msgstr "帶有類型限定的空宣告沒有重宣告標記"
 
-#: c/c-decl.c:4737
+#: c/c-decl.c:4736
 #, fuzzy, gcc-internal-format
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "清空宣告與 %<Alignas%(_A)>不 redeclare 標籤"
 
-#: c/c-decl.c:4759 c/c-decl.c:4767
+#: c/c-decl.c:4758 c/c-decl.c:4766
 #, gcc-internal-format
 msgid "useless type name in empty declaration"
 msgstr "空宣告中類型名無用"
 
-#: c/c-decl.c:4775
+#: c/c-decl.c:4774
 #, gcc-internal-format
 msgid "%<inline%> in empty declaration"
 msgstr "%<inline%> 用於空宣告中"
 
-#: c/c-decl.c:4781
+#: c/c-decl.c:4780
 #, fuzzy, gcc-internal-format
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "%<Noreturn%(_N)>在中清空宣告"
 
-#: c/c-decl.c:4787
+#: c/c-decl.c:4786
 #, gcc-internal-format
 msgid "%<auto%> in file-scope empty declaration"
 msgstr "檔案作用欄位中出現 %<auto%> 空宣告"
 
-#: c/c-decl.c:4793
+#: c/c-decl.c:4792
 #, gcc-internal-format
 msgid "%<register%> in file-scope empty declaration"
 msgstr "檔案作用欄位中出現 %<register%> 空宣告"
 
-#: c/c-decl.c:4800
+#: c/c-decl.c:4799
 #, gcc-internal-format
 msgid "useless storage class specifier in empty declaration"
 msgstr "空宣告中指定存儲類別無用"
 
-#: c/c-decl.c:4806
+#: c/c-decl.c:4805
 #, fuzzy, gcc-internal-format
 msgid "useless %qs in empty declaration"
 msgstr "無用的 %<Alignas%(_A)>在中清空宣告"
 
-#: c/c-decl.c:4819
+#: c/c-decl.c:4818
 #, gcc-internal-format
 msgid "useless type qualifier in empty declaration"
 msgstr "空宣告中類型限定無用"
 
-#: c/c-decl.c:4826
+#: c/c-decl.c:4825
 #, fuzzy, gcc-internal-format
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "無用的 %<Alignas%(_A)>在中清空宣告"
 
-#: c/c-decl.c:4844
+#: c/c-decl.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of attributes in empty declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: c/c-decl.c:4858 c/c-parser.c:2033
+#: c/c-decl.c:4857 c/c-parser.c:2033
 #, gcc-internal-format
 msgid "empty declaration"
 msgstr "空宣告"
 
-#: c/c-decl.c:4929
+#: c/c-decl.c:4928
 #, gcc-internal-format
 msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
 msgstr "ISO C90 不支援在參數陣列宣告中使用 %<static%> 或類型限定符"
 
-#: c/c-decl.c:4933
+#: c/c-decl.c:4932
 #, gcc-internal-format
 msgid "ISO C90 does not support %<[*]%> array declarators"
 msgstr "ISO C90 不支援 %<[*]%> 陣列宣告"
@@ -42253,29 +42281,29 @@ msgstr "ISO C90 不支援 %<[*]%> 陣列宣告"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4939 c/c-decl.c:7820 c/c-decl.c:9738
+#: c/c-decl.c:4938 c/c-decl.c:7819 c/c-decl.c:9737
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不允許在中不同於函式原型範圍"
 
-#: c/c-decl.c:5104
+#: c/c-decl.c:5103
 #, gcc-internal-format
 msgid "%q+D is usually a function"
 msgstr "%q+D 一般是一個函式"
 
-#: c/c-decl.c:5113
+#: c/c-decl.c:5112
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD 被初始化(改用 __typeof__)"
 
-#: c/c-decl.c:5118
+#: c/c-decl.c:5117
 #, gcc-internal-format
 msgid "function %qD is initialized like a variable"
 msgstr "函式 %qD 像變數一樣被初始化"
 
 #. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
-#: c/c-decl.c:5124
+#: c/c-decl.c:5123
 #, gcc-internal-format
 msgid "parameter %qD is initialized"
 msgstr "參數 %qD 已初始化"
@@ -42284,272 +42312,272 @@ msgstr "參數 %qD 已初始化"
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:5143 c/c-decl.c:5158 c/c-typeck.c:8153
+#: c/c-decl.c:5142 c/c-decl.c:5157 c/c-typeck.c:8213
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "可變大小的物件不能被初始化"
 
-#: c/c-decl.c:5149
+#: c/c-decl.c:5148
 #, gcc-internal-format
 msgid "variable %qD has initializer but incomplete type"
 msgstr "變數 %qD 有初始值設定但類型不完全"
 
-#: c/c-decl.c:5238
+#: c/c-decl.c:5237
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %q+D given attribute %qs"
 msgstr "為內聯函式 %q+D 給定了 noinline 屬性"
 
-#: c/c-decl.c:5288
+#: c/c-decl.c:5287
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %qT is invalid in C++"
 msgstr "uninitialized 常數成員在中 %qT 無效在中 C++"
 
-#: c/c-decl.c:5290
+#: c/c-decl.c:5289
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized"
 msgstr "%qD 應該被初始化的"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5370
 #, gcc-internal-format
 msgid "initializer fails to determine size of %q+D"
 msgstr "初始值設定無法決定 %q+D 的大小"
 
-#: c/c-decl.c:5376
+#: c/c-decl.c:5375
 #, gcc-internal-format
 msgid "array size missing in %q+D"
 msgstr "在 %q+D 中缺少陣列大小"
 
-#: c/c-decl.c:5380
+#: c/c-decl.c:5379
 #, gcc-internal-format
 msgid "zero or negative size array %q+D"
 msgstr "陣列 %q+D 大小為 0 或負"
 
-#: c/c-decl.c:5469
+#: c/c-decl.c:5468
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t constant"
 msgstr "%q+D 的存儲大小不是常數"
 
-#: c/c-decl.c:5519
+#: c/c-decl.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "為非靜態局部變數 %q+D 忽略了 asm 限定符"
 
-#: c/c-decl.c:5557
+#: c/c-decl.c:5556
 #, gcc-internal-format
 msgid "cannot put object with volatile field into register"
 msgstr "不能將帶有 volatile 欄位的物件放入暫存器"
 
-#: c/c-decl.c:5643
+#: c/c-decl.c:5642
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "uninitialized 常數 %qD 無效在中 C++"
 
-#: c/c-decl.c:5658 cp/decl.c:8192
+#: c/c-decl.c:5657 cp/decl.c:8198
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
 
-#: c/c-decl.c:5915
+#: c/c-decl.c:5914
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C 不允許前向參數宣告"
 
-#: c/c-decl.c:6026
+#: c/c-decl.c:6025
 #, fuzzy, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "定義輸入複合實字無效在中 C++"
 
-#: c/c-decl.c:6047 c/c-decl.c:6062
+#: c/c-decl.c:6046 c/c-decl.c:6061
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "位元段 %qs 的寬度不是一個整數常數"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bit-field %qs 寬度不是整數常數運算式"
 
-#: c/c-decl.c:6068
+#: c/c-decl.c:6067
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "位元段 %qs 寬度為負"
 
-#: c/c-decl.c:6073
+#: c/c-decl.c:6072
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "位元段 %qs 寬度為 0"
 
-#: c/c-decl.c:6083
+#: c/c-decl.c:6082
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "位元段 %qs 類型無效"
 
-#: c/c-decl.c:6089
+#: c/c-decl.c:6088
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "不能將位元段 %qD 宣告為函式類型"
 
-#: c/c-decl.c:6100
+#: c/c-decl.c:6099
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "位元段類型 %qs 是一個 GCC 擴充"
 
-#: c/c-decl.c:6106
+#: c/c-decl.c:6105
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs 的寬度超過它自身的類型"
 
-#: c/c-decl.c:6119
+#: c/c-decl.c:6118
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs 比其類型的值要窄"
 
-#: c/c-decl.c:6134
+#: c/c-decl.c:6133
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 禁止陣列 %qE 其大小 can%'t 被評估"
 
-#: c/c-decl.c:6137
+#: c/c-decl.c:6136
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 禁止陣列其大小 can%'t 被評估"
 
-#: c/c-decl.c:6144
+#: c/c-decl.c:6143
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: c/c-decl.c:6146
+#: c/c-decl.c:6145
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 禁止變數長度陣列"
 
-#: c/c-decl.c:6357 c/c-decl.c:6753 c/c-decl.c:6763
+#: c/c-decl.c:6356 c/c-decl.c:6752 c/c-decl.c:6762
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "variably 已修改 %qE 於檔案範圍"
 
-#: c/c-decl.c:6359
+#: c/c-decl.c:6358
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "variably 已修改欄位於檔案範圍"
 
-#: c/c-decl.c:6379
+#: c/c-decl.c:6378
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "型態預設值到 %<int%> 在中宣告的 %qE"
 
-#: c/c-decl.c:6383
+#: c/c-decl.c:6382
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "型態預設值到 %<int%> 在中型態名稱"
 
-#: c/c-decl.c:6415
+#: c/c-decl.c:6414
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "重複的 %<const%>"
 
-#: c/c-decl.c:6417
+#: c/c-decl.c:6416
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "重複的 %<restrict%>"
 
-#: c/c-decl.c:6419
+#: c/c-decl.c:6418
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "重複的 %<volatile%>"
 
-#: c/c-decl.c:6421
+#: c/c-decl.c:6420
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "重複的 %<restrict%>"
 
-#: c/c-decl.c:6424
+#: c/c-decl.c:6423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "衝突具名的位址空間 (%s vs %s)"
 
-#: c/c-decl.c:6447 c/c-parser.c:3048
+#: c/c-decl.c:6446 c/c-parser.c:3048
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:6461
+#: c/c-decl.c:6460
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "函式宣告定義為 %<auto%>"
 
-#: c/c-decl.c:6463
+#: c/c-decl.c:6462
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "函式宣告定義為 %<register%>"
 
-#: c/c-decl.c:6465
+#: c/c-decl.c:6464
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "函式宣告定義為 %<typedef%>"
 
-#: c/c-decl.c:6467
+#: c/c-decl.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "函式宣告定義為 %<auto%>"
 
-#: c/c-decl.c:6485
+#: c/c-decl.c:6484
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "貯藏類別指定的用於結構欄位 %qE"
 
-#: c/c-decl.c:6488
+#: c/c-decl.c:6487
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "貯藏類別指定的用於結構欄位"
 
-#: c/c-decl.c:6492
+#: c/c-decl.c:6491
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "貯藏類別指定的用於參數 %qE"
 
-#: c/c-decl.c:6495
+#: c/c-decl.c:6494
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "貯藏類別指定的用於未命名參數"
 
-#: c/c-decl.c:6498 cp/decl.c:12158
+#: c/c-decl.c:6497 cp/decl.c:12176
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "為類型名指定了存儲類別"
 
-#: c/c-decl.c:6515
+#: c/c-decl.c:6514
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE 初始化的和宣告 %<extern%>"
 
-#: c/c-decl.c:6519
+#: c/c-decl.c:6518
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE 同時有 %<extern%> 和初始設定式"
 
-#: c/c-decl.c:6524
+#: c/c-decl.c:6523
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "file-scope 宣告的 %qE 指定 %<auto%>"
 
-#: c/c-decl.c:6528
+#: c/c-decl.c:6527
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "file-scope 宣告的 %qE 指定 %<register%>"
 
-#: c/c-decl.c:6533
+#: c/c-decl.c:6532
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "巢狀的函式 %qE 宣告 %<extern%>"
 
-#: c/c-decl.c:6536
+#: c/c-decl.c:6535
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "function-scope %qE 隱含地自動和宣告 %<__thread%>"
@@ -42557,719 +42585,719 @@ msgstr "function-scope %qE 隱含地自動和宣告 %<__thread%>"
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:6583 c/c-decl.c:6977
+#: c/c-decl.c:6582 c/c-decl.c:6976
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static 或類型限定符出現在非參數陣列宣告中"
 
-#: c/c-decl.c:6644
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "宣告的 %qE 做為陣列的虛值"
 
-#: c/c-decl.c:6646
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "宣告的型態名稱做為陣列的虛值"
 
-#: c/c-decl.c:6653
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "宣告的 %qE 做為陣列的函式"
 
-#: c/c-decl.c:6656
+#: c/c-decl.c:6655
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "宣告的型態名稱做為陣列的函式"
 
-#: c/c-decl.c:6664 c/c-decl.c:8792
+#: c/c-decl.c:6663 c/c-decl.c:8791
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "對包含彈性陣列成員的結構的無效使用"
 
-#: c/c-decl.c:6696
+#: c/c-decl.c:6695
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "大小的陣列 %qE 有 non-integer 型態"
 
-#: c/c-decl.c:6700
+#: c/c-decl.c:6699
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "大小的未命名陣列有 non-integer 型態"
 
-#: c/c-decl.c:6708
+#: c/c-decl.c:6707
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "大小的陣列 %qE 有 non-integer 型態"
 
-#: c/c-decl.c:6711
+#: c/c-decl.c:6710
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "大小的未命名陣列有 non-integer 型態"
 
-#: c/c-decl.c:6723
+#: c/c-decl.c:6722
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C 禁止 zero-size 陣列 %qE"
 
-#: c/c-decl.c:6726
+#: c/c-decl.c:6725
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C 禁止 zero-size 陣列"
 
-#: c/c-decl.c:6735
+#: c/c-decl.c:6734
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "大小的陣列 %qE 是負"
 
-#: c/c-decl.c:6737
+#: c/c-decl.c:6736
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "大小的未命名陣列是負"
 
-#: c/c-decl.c:6823
+#: c/c-decl.c:6822
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "大小的陣列 %qE 太大"
 
-#: c/c-decl.c:6826
+#: c/c-decl.c:6825
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "大小的未命名陣列太大"
 
-#: c/c-decl.c:6865 c/c-decl.c:7523
+#: c/c-decl.c:6864 c/c-decl.c:7522
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 不允許彈性陣列成員"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6887
+#: c/c-decl.c:6886
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: c/c-decl.c:6900
+#: c/c-decl.c:6899
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "陣列元素的類型不完全"
 
-#: c/c-decl.c:6906
+#: c/c-decl.c:6905
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: c/c-decl.c:6910
+#: c/c-decl.c:6909
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE 宣告的做為函式回傳函式"
 
-#: c/c-decl.c:7016
+#: c/c-decl.c:7015
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "型態名稱宣告的做為函式回傳函式"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7022
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE 宣告的做為函式回傳陣列"
 
-#: c/c-decl.c:7026
+#: c/c-decl.c:7025
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "型態名稱宣告的做為函式回傳陣列"
 
-#: c/c-decl.c:7067
+#: c/c-decl.c:7066
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "函式定義有限定的 void 回傳類型"
 
-#: c/c-decl.c:7071 cp/decl.c:12458
+#: c/c-decl.c:7070 cp/decl.c:12476
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: c/c-decl.c:7109 c/c-decl.c:7319 c/c-decl.c:7373 c/c-decl.c:7457
-#: c/c-decl.c:7582 c/c-parser.c:3050
+#: c/c-decl.c:7108 c/c-decl.c:7318 c/c-decl.c:7372 c/c-decl.c:7456
+#: c/c-decl.c:7581 c/c-parser.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 
-#: c/c-decl.c:7115 c/c-decl.c:7325 c/c-decl.c:7462 c/c-decl.c:7587
+#: c/c-decl.c:7114 c/c-decl.c:7324 c/c-decl.c:7461 c/c-decl.c:7586
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 
-#: c/c-decl.c:7210
+#: c/c-decl.c:7209
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs 合併的與 %<auto%> 限定元用於 %qE"
 
-#: c/c-decl.c:7214
+#: c/c-decl.c:7213
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs 合併的與 %<register%> 限定元用於 %qE"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7219
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs 指定的用於自動變數 %qE"
 
-#: c/c-decl.c:7236
+#: c/c-decl.c:7235
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs 指定的用於參數 %qE"
 
-#: c/c-decl.c:7239
+#: c/c-decl.c:7238
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs 指定的用於未命名參數"
 
-#: c/c-decl.c:7245
+#: c/c-decl.c:7244
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs 指定的用於結構欄位 %qE"
 
-#: c/c-decl.c:7248
+#: c/c-decl.c:7247
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs 指定的用於結構欄位"
 
-#: c/c-decl.c:7263
+#: c/c-decl.c:7262
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "位元段 %qs 類型無效"
 
-#: c/c-decl.c:7265
+#: c/c-decl.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "位元段 %qs 類型無效"
 
-#: c/c-decl.c:7274
+#: c/c-decl.c:7273
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "對齊指定的用於 typedef %qE"
 
-#: c/c-decl.c:7276
+#: c/c-decl.c:7275
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "對齊指定的用於 %<register%> 物件 %qE"
 
-#: c/c-decl.c:7281
+#: c/c-decl.c:7280
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "對齊指定的用於參數 %qE"
 
-#: c/c-decl.c:7283
+#: c/c-decl.c:7282
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "對齊指定的用於未命名參數"
 
-#: c/c-decl.c:7288
+#: c/c-decl.c:7287
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "對齊指定的用於 bit-field %qE"
 
-#: c/c-decl.c:7290
+#: c/c-decl.c:7289
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "對齊指定的用於未命名 bit-field"
 
-#: c/c-decl.c:7293
+#: c/c-decl.c:7292
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "對齊指定的用於函式 %qE"
 
-#: c/c-decl.c:7300
+#: c/c-decl.c:7299
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<Alignas%(_A)>說明符無法縮小對齊的 %qE"
 
-#: c/c-decl.c:7303
+#: c/c-decl.c:7302
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<Alignas%(_A)>說明符無法縮小對齊的未命名欄位"
 
-#: c/c-decl.c:7334
+#: c/c-decl.c:7333
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D 宣告為 %<inline%>"
 
-#: c/c-decl.c:7336
+#: c/c-decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:7379
+#: c/c-decl.c:7378
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:7390
+#: c/c-decl.c:7389
 #, fuzzy, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "成員的結構或聯合無法有 variably 已修改型態"
 
-#: c/c-decl.c:7407 cp/decl.c:11090
+#: c/c-decl.c:7406 cp/decl.c:11108
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "變數或欄位 %qE 宣告為 void"
 
-#: c/c-decl.c:7447
+#: c/c-decl.c:7446
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "出現在參數陣列宣告中的屬性被忽略"
 
-#: c/c-decl.c:7489
+#: c/c-decl.c:7488
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "參數 %q+D 宣告為 %<inline%>"
 
-#: c/c-decl.c:7491
+#: c/c-decl.c:7490
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "參數 %q+D 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:7504
+#: c/c-decl.c:7503
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "欄位 %qE 宣告的做為函式"
 
-#: c/c-decl.c:7511
+#: c/c-decl.c:7510
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "欄位 %qE 有不完整型態"
 
-#: c/c-decl.c:7513
+#: c/c-decl.c:7512
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "未命名欄位有不完整型態"
 
-#: c/c-decl.c:7553 c/c-decl.c:7564 c/c-decl.c:7567
+#: c/c-decl.c:7552 c/c-decl.c:7563 c/c-decl.c:7566
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "無效的貯藏類別用於函式 %qE"
 
-#: c/c-decl.c:7624
+#: c/c-decl.c:7623
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "不能內聯 %<main%> 函式"
 
-#: c/c-decl.c:7626
+#: c/c-decl.c:7625
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:7637
+#: c/c-decl.c:7636
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 不支援 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:7640
+#: c/c-decl.c:7639
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 不支援 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:7669
+#: c/c-decl.c:7668
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "先前被宣告為 %<static%> 的變數重宣告為 %<extern%>"
 
-#: c/c-decl.c:7679
+#: c/c-decl.c:7678
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "變數 %q+D 宣告為 %<inline%>"
 
-#: c/c-decl.c:7681
+#: c/c-decl.c:7680
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "變數 %q+D 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:7716
+#: c/c-decl.c:7715
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "non-nested 函式與 variably 已修改型態"
 
-#: c/c-decl.c:7718
+#: c/c-decl.c:7717
 #, fuzzy, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "物件與 variably 已修改型態必須沒有任何鏈結"
 
-#: c/c-decl.c:7826 c/c-decl.c:9546
+#: c/c-decl.c:7825 c/c-decl.c:9545
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "函式宣告不是一個原型"
 
-#: c/c-decl.c:7836
+#: c/c-decl.c:7835
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "函式宣告中出現參數名卻未指定類型"
 
-#: c/c-decl.c:7881
+#: c/c-decl.c:7880
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "參數 %u (%q+D) 的類型不完全"
 
-#: c/c-decl.c:7885
+#: c/c-decl.c:7884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "參數 %u 有不完整型態"
 
-#: c/c-decl.c:7896
+#: c/c-decl.c:7895
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "參數 %u (%q+D)類型為 void"
 
-#: c/c-decl.c:7900
+#: c/c-decl.c:7899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "參數 %u 有虛值型態"
 
-#: c/c-decl.c:7974
+#: c/c-decl.c:7973
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> 做為僅有的參數時不能被限定"
 
-#: c/c-decl.c:7978 c/c-decl.c:8014
+#: c/c-decl.c:7977 c/c-decl.c:8013
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> 必須是僅有的參數"
 
-#: c/c-decl.c:8008
+#: c/c-decl.c:8007
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "參數 %q+D 有一個前向宣告"
 
-#: c/c-decl.c:8054
+#: c/c-decl.c:8053
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8060
+#: c/c-decl.c:8059
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:8168
+#: c/c-decl.c:8167
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "enum 型態定義的在此"
 
-#: c/c-decl.c:8174
+#: c/c-decl.c:8173
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "結構定義的在此"
 
-#: c/c-decl.c:8180
+#: c/c-decl.c:8179
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "聯合定義的在此"
 
-#: c/c-decl.c:8257
+#: c/c-decl.c:8256
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> 重定義"
 
-#: c/c-decl.c:8259
+#: c/c-decl.c:8258
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> 重定義"
 
-#: c/c-decl.c:8268
+#: c/c-decl.c:8267
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "巢狀的 %<union %E%> 重定義"
 
-#: c/c-decl.c:8270
+#: c/c-decl.c:8269
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "巢狀的 %<struct %E%> 重定義"
 
-#: c/c-decl.c:8300 c/c-decl.c:9087
+#: c/c-decl.c:8299 c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "定義輸入 %qs 運算式無效在中 C++"
 
-#: c/c-decl.c:8367 cp/decl.c:5143
+#: c/c-decl.c:8366 cp/decl.c:5139
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "沒有宣告任何東西"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8371
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 doesn%'t 支援未命名結構/聯合"
 
-#: c/c-decl.c:8375
+#: c/c-decl.c:8374
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 doesn%'t 支援未命名結構/聯合"
 
-#: c/c-decl.c:8468 c/c-decl.c:8486 c/c-decl.c:8547
+#: c/c-decl.c:8467 c/c-decl.c:8485 c/c-decl.c:8546
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "重複的成員 %q+D"
 
-#: c/c-decl.c:8573
+#: c/c-decl.c:8572
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8576
+#: c/c-decl.c:8575
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:8701
+#: c/c-decl.c:8700
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "聯合包含無名成員"
 
-#: c/c-decl.c:8703
+#: c/c-decl.c:8702
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "聯合體沒有成員"
 
-#: c/c-decl.c:8708
+#: c/c-decl.c:8707
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "結構不包含任何具名成員"
 
-#: c/c-decl.c:8710
+#: c/c-decl.c:8709
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "結構體沒有成員"
 
-#: c/c-decl.c:8771 cp/decl.c:13430
+#: c/c-decl.c:8770 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexible 陣列成員在中聯合"
 
-#: c/c-decl.c:8777
+#: c/c-decl.c:8776
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: c/c-decl.c:8783
+#: c/c-decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "flexible 陣列成員在中聯合"
 
-#: c/c-decl.c:8814
+#: c/c-decl.c:8813
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "值傳遞在中 %qs 太大"
 
-#: c/c-decl.c:8919
+#: c/c-decl.c:8918
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "聯合不能成為透明的"
 
-#: c/c-decl.c:9059
+#: c/c-decl.c:9058
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "巢狀的 %<enum %E%> 重定義"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:9066
+#: c/c-decl.c:9065
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> 重宣告"
 
-#: c/c-decl.c:9145 cp/decl.c:15903
+#: c/c-decl.c:9144 cp/decl.c:15921
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "指定的模式對列舉值來說太小"
 
-#: c/c-decl.c:9160
+#: c/c-decl.c:9159
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "列舉值超過了最大整數類型可表示的範圍"
 
-#: c/c-decl.c:9280 c/c-decl.c:9296
+#: c/c-decl.c:9279 c/c-decl.c:9295
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE 的列舉值不是一個整數常數"
 
-#: c/c-decl.c:9291
+#: c/c-decl.c:9290
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "列舉值值用於 %qE 不是整數常數運算式"
 
-#: c/c-decl.c:9315
+#: c/c-decl.c:9314
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "列舉值溢出"
 
-#: c/c-decl.c:9323
+#: c/c-decl.c:9322
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 將列舉值限制在 %<int%> 範圍內"
 
-#: c/c-decl.c:9440 cp/decl.c:5454 cp/decl.c:16454
+#: c/c-decl.c:9439 cp/decl.c:5450 cp/decl.c:16472
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "內聯函式 %qD 給定的屬性 noinline"
 
-#: c/c-decl.c:9458
+#: c/c-decl.c:9457
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "回傳不完全的類型"
 
-#: c/c-decl.c:9469
+#: c/c-decl.c:9468
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "回傳類型預設為 %<int%>"
 
-#: c/c-decl.c:9497
+#: c/c-decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "全域函式沒有原型時給出警告"
 
-#: c/c-decl.c:9555
+#: c/c-decl.c:9554
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "沒有前一個原型用於 %qD"
 
-#: c/c-decl.c:9564
+#: c/c-decl.c:9563
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD 被使用不具任何原型之前它的定義"
 
-#: c/c-decl.c:9572 cp/decl.c:16589
+#: c/c-decl.c:9571 cp/decl.c:16607
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "沒有前一個宣告用於 %qD"
 
-#: c/c-decl.c:9582
+#: c/c-decl.c:9581
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD 被使用不具任何宣告之前它的定義"
 
-#: c/c-decl.c:9601
+#: c/c-decl.c:9600
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "傳回類型的 %qD 不是 %<int%>"
 
-#: c/c-decl.c:9603
+#: c/c-decl.c:9602
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:9610
+#: c/c-decl.c:9609
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD 是正常非靜態函式"
 
-#: c/c-decl.c:9658
+#: c/c-decl.c:9657
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "舊式參數宣告在中原型的函式定義"
 
-#: c/c-decl.c:9673
+#: c/c-decl.c:9672
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "傳統 C 拒絕 ISO C 樣式函式定義"
 
-#: c/c-decl.c:9690
+#: c/c-decl.c:9689
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgstr "ISO C 不支援十進位浮點數"
 
-#: c/c-decl.c:9730 c/c-decl.c:9734
+#: c/c-decl.c:9729 c/c-decl.c:9733
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "舊式函式定義"
 
-#: c/c-decl.c:9747
+#: c/c-decl.c:9746
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "參數名稱缺少的從參數清單"
 
-#: c/c-decl.c:9763
+#: c/c-decl.c:9762
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: c/c-decl.c:9771
+#: c/c-decl.c:9770
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "多重參數具名的 %qD"
 
-#: c/c-decl.c:9780
+#: c/c-decl.c:9779
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "參數 %qD 宣告的與虛值型態"
 
-#: c/c-decl.c:9809 c/c-decl.c:9814
+#: c/c-decl.c:9808 c/c-decl.c:9813
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
 
-#: c/c-decl.c:9834
+#: c/c-decl.c:9833
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "參數 %qD 有不完整型態"
 
-#: c/c-decl.c:9841
+#: c/c-decl.c:9840
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "宣告用於參數 %qD 但是沒有此類參數"
 
-#: c/c-decl.c:9894
+#: c/c-decl.c:9893
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "引數個數與內建原型不符"
 
-#: c/c-decl.c:9905
+#: c/c-decl.c:9904
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "引數數目與原型不符"
 
-#: c/c-decl.c:9908 c/c-decl.c:9955 c/c-decl.c:9969
+#: c/c-decl.c:9907 c/c-decl.c:9954 c/c-decl.c:9968
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "原型宣告"
 
-#: c/c-decl.c:9947
+#: c/c-decl.c:9946
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "提升後的引數 %qD 與內建原型不符"
 
-#: c/c-decl.c:9952
+#: c/c-decl.c:9951
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "提升後的引數 %qD 與原型不符"
 
-#: c/c-decl.c:9962
+#: c/c-decl.c:9961
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "引數 %qD 與內建原型不符"
 
-#: c/c-decl.c:9967
+#: c/c-decl.c:9966
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引數 %qD 與原型不符"
 
-#: c/c-decl.c:10225 cp/decl.c:17414
+#: c/c-decl.c:10224 cp/decl.c:17432
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: c/c-decl.c:10244 cp/decl.c:17498
+#: c/c-decl.c:10243 cp/decl.c:17516
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "參數 %qD 設定並不是使用"
@@ -43277,265 +43305,265 @@ msgstr "參數 %qD 設定並不是使用"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10340
+#: c/c-decl.c:10339
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> 迴圈初始宣告是只有允許的在中 C99 模式"
 
-#: c/c-decl.c:10345
+#: c/c-decl.c:10344
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "使用選項 -std=c99 或 -std=gnu99 到編譯您的編碼"
 
-#: c/c-decl.c:10352
+#: c/c-decl.c:10351
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 不支援 %<[*]%> 陣列宣告"
 
-#: c/c-decl.c:10384
+#: c/c-decl.c:10383
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的靜態變數 %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.c:10388
+#: c/c-decl.c:10387
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-decl.c:10395
+#: c/c-decl.c:10394
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:10400
+#: c/c-decl.c:10399
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:10404
+#: c/c-decl.c:10403
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:10408
+#: c/c-decl.c:10407
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 non-variable %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.c:10700
+#: c/c-decl.c:10699
 #, fuzzy, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不相容的位址空間限定元 %qs 和 %qs"
 
-#: c/c-decl.c:10759 c/c-decl.c:10766
+#: c/c-decl.c:10758 c/c-decl.c:10765
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "需要指定宣告"
 
-#: c/c-decl.c:10794 c/c-decl.c:11178 c/c-decl.c:11573
+#: c/c-decl.c:10793 c/c-decl.c:11177 c/c-decl.c:11572
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣告指定了兩個以上的資料類型"
 
-#: c/c-decl.c:10806 cp/parser.c:31446
+#: c/c-decl.c:10805 cp/parser.c:31500
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> 對 GCC 來說太長了"
 
-#: c/c-decl.c:10819
+#: c/c-decl.c:10818
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支援 %<long long%>"
 
-#: c/c-decl.c:11048 c/c-parser.c:9956
+#: c/c-decl.c:11047 c/c-parser.c:9956
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.c:11094
+#: c/c-decl.c:11093
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支援飽和類型"
 
-#: c/c-decl.c:11165 c/c-decl.c:11731
+#: c/c-decl.c:11164 c/c-decl.c:11730
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重複的 %qE"
 
-#: c/c-decl.c:11225
+#: c/c-decl.c:11224
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C 不支援 %<__int128%>型態"
 
-#: c/c-decl.c:11247
+#: c/c-decl.c:11246
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
 
-#: c/c-decl.c:11290
+#: c/c-decl.c:11289
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.c:11409
+#: c/c-decl.c:11408
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C 不支援 %<__int128%>型態"
 
-#: c/c-decl.c:11459
+#: c/c-decl.c:11458
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
 
-#: c/c-decl.c:11530
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C 不支援十進位浮點數"
 
-#: c/c-decl.c:11554 c/c-decl.c:11827 c/c-parser.c:8967
+#: c/c-decl.c:11553 c/c-decl.c:11826 c/c-parser.c:8967
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定點類型不支援用於這個目標"
 
-#: c/c-decl.c:11556
+#: c/c-decl.c:11555
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支援定點類型"
 
-#: c/c-decl.c:11591
+#: c/c-decl.c:11590
 #, fuzzy, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++查找的 %qD 會回傳欄位，不是型態"
 
-#: c/c-decl.c:11604
+#: c/c-decl.c:11603
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE 不是一個 typedef 類型，也不是一個內建類型"
 
-#: c/c-decl.c:11653
+#: c/c-decl.c:11652
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE 沒有出現在宣告的開頭"
 
-#: c/c-decl.c:11674
+#: c/c-decl.c:11673
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> 與 %<auto%> 一起使用"
 
-#: c/c-decl.c:11676
+#: c/c-decl.c:11675
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> 與 %<register%> 一起使用"
 
-#: c/c-decl.c:11678
+#: c/c-decl.c:11677
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: c/c-decl.c:11692 c/c-parser.c:8325
+#: c/c-decl.c:11691 c/c-parser.c:8325
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 不支援 %qE"
 
-#: c/c-decl.c:11695 c/c-parser.c:8328
+#: c/c-decl.c:11694 c/c-parser.c:8328
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支援 %qE"
 
-#: c/c-decl.c:11707
+#: c/c-decl.c:11706
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> 出現在 %<extern%> 之前"
 
-#: c/c-decl.c:11716
+#: c/c-decl.c:11715
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> 出現在 %<static%> 之前"
 
-#: c/c-decl.c:11729
+#: c/c-decl.c:11728
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11737
+#: c/c-decl.c:11736
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣告指定了多個存儲類別"
 
-#: c/c-decl.c:11745
+#: c/c-decl.c:11744
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-decl.c:11824
+#: c/c-decl.c:11823
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>被使用而無需 %<_Fract%>或 %<_Accum%>"
 
-#: c/c-decl.c:11839
+#: c/c-decl.c:11838
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: c/c-decl.c:11866
+#: c/c-decl.c:11865
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11892 c/c-decl.c:11908 c/c-decl.c:11934
+#: c/c-decl.c:11891 c/c-decl.c:11907 c/c-decl.c:11933
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支援複整數"
 
-#: c/c-decl.c:12361 cp/semantics.c:5793
+#: c/c-decl.c:12360 cp/semantics.c:5821
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12365 cp/semantics.c:5797
+#: c/c-decl.c:12364 cp/semantics.c:5825
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:387 c/c-typeck.c:11988 cp/typeck.c:5073
+#: c/c-fold.c:387 c/c-typeck.c:12048 cp/typeck.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次數為負"
 
-#: c/c-fold.c:397 c/c-typeck.c:11997 cp/typeck.c:5081
+#: c/c-fold.c:397 c/c-typeck.c:12057 cp/typeck.c:5092
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次數為負"
 
-#: c/c-fold.c:398 c/c-typeck.c:11926 cp/typeck.c:5021
+#: c/c-fold.c:398 c/c-typeck.c:11986 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次數為負"
 
-#: c/c-fold.c:406 c/c-typeck.c:12016 cp/typeck.c:5089
+#: c/c-fold.c:406 c/c-typeck.c:12076 cp/typeck.c:5100
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次數大於或等於類型寬度"
 
-#: c/c-fold.c:407 c/c-typeck.c:11950 cp/typeck.c:5032
+#: c/c-fold.c:407 c/c-typeck.c:12010 cp/typeck.c:5043
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次數大於或等於類型寬度"
 
-#: c/c-fold.c:414 c/c-typeck.c:12008
+#: c/c-fold.c:414 c/c-typeck.c:12068
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "左移次數大於或等於類型寬度"
 
-#: c/c-fold.c:415 c/c-typeck.c:11937
+#: c/c-fold.c:415 c/c-typeck.c:11997
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -43556,7 +43584,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: c/c-parser.c:1325 cp/parser.c:31680
+#: c/c-parser.c:1325 cp/parser.c:31734
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "預期的列尾"
@@ -43566,7 +43594,7 @@ msgstr "預期的列尾"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C 禁止清空轉譯單位"
 
-#: c/c-parser.c:1665 cp/semantics.c:3201
+#: c/c-parser.c:1665 cp/semantics.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
@@ -43602,7 +43630,7 @@ msgid "unknown type name %qE"
 msgstr "不明型態名稱 %qE"
 
 #: c/c-parser.c:2001 c/c-parser.c:12508 c/c-parser.c:18876 c/c-parser.c:19393
-#: c/c-parser.c:19910 cp/parser.c:41330 cp/parser.c:45195
+#: c/c-parser.c:19910 cp/parser.c:41383 cp/parser.c:45248
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定宣告"
@@ -43623,7 +43651,7 @@ msgstr "%q+D 不能有 section 屬性"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "預期 %<;%>，識別碼或 %<(%>"
 
-#: c/c-parser.c:2066 cp/parser.c:33879 cp/parser.c:33951
+#: c/c-parser.c:2066 cp/parser.c:33933 cp/parser.c:34005
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "前綴屬性被忽略用於方法"
@@ -43638,7 +43666,7 @@ msgstr "前綴屬性被忽略用於實作"
 msgid "unexpected attribute"
 msgstr "未預期的屬性"
 
-#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11832 cp/parser.c:12039
+#: c/c-parser.c:2132 c/c-parser.c:6220 cp/parser.c:11853 cp/parser.c:12060
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -43680,7 +43708,7 @@ msgstr "檔案作用欄位中出現 %<auto%> 空宣告"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: c/c-parser.c:2415 cp/parser.c:14539
+#: c/c-parser.c:2415 cp/parser.c:14563
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要 %<,%> 或 %<;%>"
@@ -43738,7 +43766,7 @@ msgstr "運算式在中靜態假設不是常數"
 msgid "static assertion failed: %E"
 msgstr "靜態假設失敗：%E"
 
-#: c/c-parser.c:2683 cp/semantics.c:10131
+#: c/c-parser.c:2683 cp/semantics.c:10159
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "靜態假設失敗：%E"
@@ -43785,14 +43813,14 @@ msgstr "範本參數 %d 無效"
 #: c/c-parser.c:12166 c/c-parser.c:12212 c/c-parser.c:12998 c/c-parser.c:13031
 #: c/c-parser.c:15343 c/c-parser.c:15453 c/c-parser.c:15726 c/c-parser.c:15989
 #: c/c-parser.c:17946 c/c-parser.c:20428 c/c-parser.c:20619
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8961
-#: cp/parser.c:31683 cp/parser.c:34856 cp/parser.c:37421 cp/parser.c:37589
-#: cp/parser.c:42903 cp/parser.c:44510
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8968
+#: cp/parser.c:31737 cp/parser.c:34910 cp/parser.c:37474 cp/parser.c:37642
+#: cp/parser.c:42956 cp/parser.c:44563
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要識別碼"
 
-#: c/c-parser.c:3238 cp/parser.c:20165
+#: c/c-parser.c:3238 cp/parser.c:20202
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列舉表以逗號結尾"
@@ -43877,7 +43905,7 @@ msgstr "需要指定宣告或 %<...%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4932 cp/parser.c:27867
+#: c/c-parser.c:4932 cp/parser.c:27902
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "%qE 屬性沒有任何效果"
@@ -43938,7 +43966,7 @@ msgstr "ISO C90 禁止混合的宣告和編碼"
 msgid "expected %<}%> before %<else%>"
 msgstr "預期 %<}%>之前 %<else%>expected %<}%> before %<else%>預期 %<}%>之前 %<else%>"
 
-#: c/c-parser.c:5776 cp/parser.c:12162
+#: c/c-parser.c:5776 cp/parser.c:12184
 #, fuzzy, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> 而無需前一個 %<if%>"
@@ -43953,7 +43981,7 @@ msgstr "標籤位於複合敘述末尾"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5815 c/c-parser.c:5828 c/c-parser.c:6241
-#: c/gimple-parser.c:2276 cp/parser.c:11782
+#: c/gimple-parser.c:2276 cp/parser.c:11803
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "需要敘述"
@@ -43978,17 +44006,17 @@ msgstr "需要識別碼或 %<*%>"
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: c/c-parser.c:6348 cp/parser.c:13616
+#: c/c-parser.c:6348 cp/parser.c:13640
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建議大括號周圍清空內文在中 %<if%> 敘述"
 
-#: c/c-parser.c:6390 cp/parser.c:13619
+#: c/c-parser.c:6390 cp/parser.c:13643
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建議大括號周圍清空內文在中 %<else%> 敘述"
 
-#: c/c-parser.c:6521 cp/parser.c:12433
+#: c/c-parser.c:6521 cp/parser.c:12455
 #, fuzzy, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "建議明確的大括號到避免模稜兩可的 %<else%>"
@@ -44008,12 +44036,12 @@ msgstr "多重迭代變數在中快速列舉類型"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "無效的迭代變數在中快速列舉類型"
 
-#: c/c-parser.c:6872 cp/parser.c:12702
+#: c/c-parser.c:6872 cp/parser.c:12724
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6878 cp/parser.c:12708
+#: c/c-parser.c:6878 cp/parser.c:12730
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -44029,8 +44057,8 @@ msgstr "缺少收集在中快速列舉類型"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "重複的 cv 限定"
 
-#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21018
-#: cp/parser.c:21035 cp/parser.c:21049
+#: c/c-parser.c:7037 c/c-parser.c:7048 c/c-parser.c:7059 cp/parser.c:21055
+#: cp/parser.c:21072 cp/parser.c:21086
 #, fuzzy, gcc-internal-format
 #| msgid "%J  first type here"
 msgid "first seen here"
@@ -44059,12 +44087,12 @@ msgstr "ISO C 不允許省略 ?: 運算式中的第二項"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7819 cp/typeck.c:4849
+#: c/c-parser.c:7819 cp/typeck.c:4860
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7825 cp/typeck.c:4854
+#: c/c-parser.c:7825 cp/typeck.c:4865
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "型態的欄位宣告的在此"
@@ -44467,12 +44495,12 @@ msgstr "objective-c 方法宣告被預期"
 msgid "no type or storage class may be specified here,"
 msgstr "沒有型態或貯藏類別也許會被指定的在此，"
 
-#: c/c-parser.c:11951 cp/parser.c:34713
+#: c/c-parser.c:11951 cp/parser.c:34767
 #, fuzzy, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "不明內容屬性"
 
-#: c/c-parser.c:11965 cp/parser.c:34726
+#: c/c-parser.c:11965 cp/parser.c:34780
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -44483,51 +44511,51 @@ msgstr "缺少 Code 屬性"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "不明內容屬性"
 
-#: c/c-parser.c:12007 cp/parser.c:34763
+#: c/c-parser.c:12007 cp/parser.c:34817
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明內容屬性"
 
-#: c/c-parser.c:12016 cp/parser.c:34772
+#: c/c-parser.c:12016 cp/parser.c:34826
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "重複 %<@%>之前 Objective-C 字串"
 
-#: c/c-parser.c:12027 cp/parser.c:34786
+#: c/c-parser.c:12027 cp/parser.c:34840
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "預期 selection-statement"
 
-#: c/c-parser.c:12043 cp/parser.c:34805
+#: c/c-parser.c:12043 cp/parser.c:34859
 #, fuzzy, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "setter 名稱必須終止與 %<:%>"
 
-#: c/c-parser.c:12257 cp/parser.c:44841
+#: c/c-parser.c:12257 cp/parser.c:44894
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12301 c/c-parser.c:19390 c/c-parser.c:19685 c/c-parser.c:19744
-#: c/c-parser.c:19830 cp/parser.c:41327 cp/parser.c:41661 cp/parser.c:41751
-#: cp/parser.c:41824 cp/parser.c:44888 cp/parser.c:44903 cp/parser.c:44918
-#: cp/parser.c:44934 cp/parser.c:44950 cp/parser.c:44966 cp/parser.c:44993
-#: cp/parser.c:45006 cp/parser.c:45029 cp/parser.c:45042
+#: c/c-parser.c:19830 cp/parser.c:41380 cp/parser.c:41714 cp/parser.c:41804
+#: cp/parser.c:41877 cp/parser.c:44941 cp/parser.c:44956 cp/parser.c:44971
+#: cp/parser.c:44987 cp/parser.c:45003 cp/parser.c:45019 cp/parser.c:45046
+#: cp/parser.c:45059 cp/parser.c:45082 cp/parser.c:45095
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<# pragma omp flush%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:12324 cp/parser.c:45019
+#: c/c-parser.c:12324 cp/parser.c:45072
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.c:12411 cp/parser.c:45114
+#: c/c-parser.c:12411 cp/parser.c:45167
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
 
-#: c/c-parser.c:12418 cp/parser.c:45120
+#: c/c-parser.c:12418 cp/parser.c:45173
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
@@ -44537,18 +44565,18 @@ msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp secti
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45149 cp/parser.c:45182
+#: c/c-parser.c:12453 c/c-parser.c:12477 cp/parser.c:45202 cp/parser.c:45235
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:12490 cp/parser.c:44878
+#: c/c-parser.c:12490 cp/parser.c:44931
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
 #: c/c-parser.c:12829 c/c-parser.c:15837 c/c-parser.c:21433 c/c-parser.c:21441
-#: cp/parser.c:35224 cp/parser.c:37940 cp/parser.c:43961 cp/parser.c:43969
+#: cp/parser.c:35278 cp/parser.c:37993 cp/parser.c:44014 cp/parser.c:44022
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多 %qs 子句"
@@ -44568,53 +44596,53 @@ msgstr "預期 %<,%>或 %<)%>"
 msgid "%qD is not a variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:13267 cp/semantics.c:7767
+#: c/c-parser.c:13267 cp/semantics.c:7795
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:13309 cp/parser.c:35911
+#: c/c-parser.c:13309 cp/parser.c:35964
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:13386 cp/parser.c:35975
+#: c/c-parser.c:13386 cp/parser.c:36028
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:13388 cp/parser.c:35977
+#: c/c-parser.c:13388 cp/parser.c:36030
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:13508 cp/parser.c:36088
+#: c/c-parser.c:13508 cp/parser.c:36141
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36106
-#: cp/parser.c:41653 cp/parser.c:41743
+#: c/c-parser.c:13528 c/c-parser.c:19737 c/c-parser.c:19823 cp/parser.c:36159
+#: cp/parser.c:41706 cp/parser.c:41796
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "預期 %<catch%>"
 
-#: c/c-parser.c:13581 cp/parser.c:36161
+#: c/c-parser.c:13581 cp/parser.c:36214
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13588 cp/parser.c:36168
+#: c/c-parser.c:13588 cp/parser.c:36221
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:13590 cp/parser.c:36170
+#: c/c-parser.c:13590 cp/parser.c:36223
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:13596 cp/parser.c:36176
+#: c/c-parser.c:13596 cp/parser.c:36229
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -44636,108 +44664,108 @@ msgstr "%<num_threads%> 值必須是正值"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13804 cp/semantics.c:7972
+#: c/c-parser.c:13804 cp/semantics.c:8000
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13851 cp/semantics.c:8002
+#: c/c-parser.c:13851 cp/semantics.c:8030
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: c/c-parser.c:13885 cp/parser.c:36368
+#: c/c-parser.c:13885 cp/parser.c:36421
 #, fuzzy, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "預期的整數運算式"
 
-#: c/c-parser.c:13925 cp/parser.c:36410
+#: c/c-parser.c:13925 cp/parser.c:36463
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:13986 cp/parser.c:36475
+#: c/c-parser.c:13986 cp/parser.c:36528
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.c:14052 cp/parser.c:36544
+#: c/c-parser.c:14052 cp/parser.c:36597
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14055 cp/parser.c:36547
+#: c/c-parser.c:14055 cp/parser.c:36600
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.c:14129 cp/semantics.c:7009
+#: c/c-parser.c:14129 cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7041
+#: c/c-parser.c:14141 c/c-parser.c:14264 cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:14203 cp/parser.c:35683
+#: c/c-parser.c:14203 cp/parser.c:35736
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多引數"
 
-#: c/c-parser.c:14237 cp/parser.c:35716
+#: c/c-parser.c:14237 cp/parser.c:35769
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "未預期的屬性"
 
-#: c/c-parser.c:14404 cp/semantics.c:8137
+#: c/c-parser.c:14404 cp/semantics.c:8165
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 屬性引數不是整數常數"
 
-#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36579 cp/parser.c:36589
+#: c/c-parser.c:14462 c/c-parser.c:14468 cp/parser.c:36632 cp/parser.c:36642
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36627
+#: c/c-parser.c:14502 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.c:14555 cp/parser.c:36695
+#: c/c-parser.c:14555 cp/parser.c:36748
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43612
+#: c/c-parser.c:14680 c/c-parser.c:20999 cp/parser.c:43665
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:14800 cp/parser.c:36953
+#: c/c-parser.c:14800 cp/parser.c:37006
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "宣告中同時使用了 %<long%> 和 %<void%>"
 
-#: c/c-parser.c:14854 cp/parser.c:36969
+#: c/c-parser.c:14854 cp/parser.c:37022
 #, fuzzy, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<runtime%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:14858 cp/parser.c:36972
+#: c/c-parser.c:14858 cp/parser.c:37025
 #, fuzzy, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<auto%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:14870 cp/semantics.c:7076
+#: c/c-parser.c:14870 cp/semantics.c:7104
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:14893 cp/parser.c:36992
+#: c/c-parser.c:14893 cp/parser.c:37045
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "無效的排程 kind"
@@ -44747,17 +44775,17 @@ msgstr "無效的排程 kind"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:15059 cp/semantics.c:7172
+#: c/c-parser.c:15059 cp/semantics.c:7200
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:15104 cp/semantics.c:7291
+#: c/c-parser.c:15104 cp/semantics.c:7319
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:15149 cp/semantics.c:7389
+#: c/c-parser.c:15149 cp/semantics.c:7417
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
@@ -44777,23 +44805,23 @@ msgstr "崩潰引數需要正面的常數整數運算式"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:15580 cp/parser.c:37721
+#: c/c-parser.c:15580 cp/parser.c:37774
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%qs 是不相容的與 %qs"
 
-#: c/c-parser.c:15627 cp/parser.c:37769 cp/parser.c:37998 cp/parser.c:38048
+#: c/c-parser.c:15627 cp/parser.c:37822 cp/parser.c:38051 cp/parser.c:38101
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:15714 cp/parser.c:37844
+#: c/c-parser.c:15714 cp/parser.c:37897
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無效遮罩"
 
-#: c/c-parser.c:15812 cp/parser.c:37945
+#: c/c-parser.c:15812 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "無效的排程 kind"
@@ -44808,84 +44836,84 @@ msgstr "無效的排程 kind"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:16009 cp/semantics.c:7547
+#: c/c-parser.c:16009 cp/semantics.c:7575
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:16206 cp/parser.c:38282
+#: c/c-parser.c:16206 cp/parser.c:38335
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38293 cp/parser.c:38664
+#: c/c-parser.c:16217 c/c-parser.c:16549 cp/parser.c:38346 cp/parser.c:38717
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: c/c-parser.c:16261 cp/parser.c:38340
+#: c/c-parser.c:16261 cp/parser.c:38393
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:38518
+#: c/c-parser.c:16406 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-parser.c:16538 cp/parser.c:38653
+#: c/c-parser.c:16538 cp/parser.c:38706
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:16671 cp/parser.c:42180
+#: c/c-parser.c:16671 cp/parser.c:42233
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16681 cp/parser.c:42190
+#: c/c-parser.c:16681 cp/parser.c:42243
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-parser.c:16701 cp/parser.c:42210
+#: c/c-parser.c:16701 cp/parser.c:42263
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16712 cp/parser.c:42221
+#: c/c-parser.c:16712 cp/parser.c:42274
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "無效的輸入宣告"
 
-#: c/c-parser.c:16719 cp/parser.c:42228
+#: c/c-parser.c:16719 cp/parser.c:42281
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-parser.c:16727 cp/parser.c:42236
+#: c/c-parser.c:16727 cp/parser.c:42289
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "對於 bool 變數 %qD 使用 %<--%> 無效"
 
-#: c/c-parser.c:16738 cp/parser.c:42258
+#: c/c-parser.c:16738 cp/parser.c:42311
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "對於 bool 變數 %qD 使用 %<--%> 無效"
 
-#: c/c-parser.c:16748 cp/parser.c:42268
+#: c/c-parser.c:16748 cp/parser.c:42321
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16841 cp/parser.c:42365
+#: c/c-parser.c:16841 cp/parser.c:42418
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "預期的字串之後 %<# pragma message%>"
 
-#: c/c-parser.c:16857 cp/parser.c:42382
+#: c/c-parser.c:16857 cp/parser.c:42435
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -44900,7 +44928,7 @@ msgstr "%qE 未被宣告"
 msgid "expected function name"
 msgstr "預期的函式"
 
-#: c/c-parser.c:17128 cp/parser.c:44205
+#: c/c-parser.c:17128 cp/parser.c:44258
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -44911,27 +44939,27 @@ msgstr "%qD 不是一個成員範本函式"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17191 cp/parser.c:44256 cp/parser.c:44301
+#: c/c-parser.c:17191 cp/parser.c:44309 cp/parser.c:44354
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17222 cp/parser.c:44330
+#: c/c-parser.c:17222 cp/parser.c:44383
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17223 cp/parser.c:44332
+#: c/c-parser.c:17223 cp/parser.c:44385
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:17267 cp/parser.c:42583
+#: c/c-parser.c:17267 cp/parser.c:42636
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17322 cp/parser.c:38743
+#: c/c-parser.c:17322 cp/parser.c:38796
 #, fuzzy, gcc-internal-format
 msgid "expected %<allocator%>"
 msgstr "預期 %<operator%>"
@@ -44941,84 +44969,84 @@ msgstr "預期 %<operator%>"
 msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.c:17353 cp/parser.c:38758
+#: c/c-parser.c:17353 cp/parser.c:38811
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable 不再受支援"
 
-#: c/c-parser.c:17452 cp/parser.c:38851
+#: c/c-parser.c:17452 cp/parser.c:38904
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:17474 cp/parser.c:38873
+#: c/c-parser.c:17474 cp/parser.c:38926
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:17488 cp/parser.c:38887
+#: c/c-parser.c:17488 cp/parser.c:38940
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:17495 cp/parser.c:38894
+#: c/c-parser.c:17495 cp/parser.c:38947
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:17552 cp/parser.c:38951
+#: c/c-parser.c:17552 cp/parser.c:39004
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17561 cp/parser.c:38960
+#: c/c-parser.c:17561 cp/parser.c:39013
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17571 cp/parser.c:38969
+#: c/c-parser.c:17571 cp/parser.c:39022
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17837 cp/parser.c:39174 cp/parser.c:39200
+#: c/c-parser.c:17837 cp/parser.c:39227 cp/parser.c:39253
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "無效的表單的 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:17841 cp/parser.c:39231 cp/parser.c:39247
+#: c/c-parser.c:17841 cp/parser.c:39284 cp/parser.c:39300
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "無效的運算子用於 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:17890 cp/semantics.c:9721 cp/semantics.c:9731
+#: c/c-parser.c:17890 cp/semantics.c:9749 cp/semantics.c:9759
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
 
-#: c/c-parser.c:17990 cp/semantics.c:9796
+#: c/c-parser.c:17990 cp/semantics.c:9824
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: c/c-parser.c:18047 cp/parser.c:39431
+#: c/c-parser.c:18047 cp/parser.c:39484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "需要 %<:%>，%<,%>，%<;%>，%<}%> 或 %<__attribute__%>"
 
-#: c/c-parser.c:18059 cp/parser.c:39447
+#: c/c-parser.c:18059 cp/parser.c:39500
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:18095 cp/parser.c:39480
+#: c/c-parser.c:18095 cp/parser.c:39533
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.c:18102 cp/parser.c:39487
+#: c/c-parser.c:18102 cp/parser.c:39540
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -45028,32 +45056,32 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "預期 %<(%>或列尾"
 
-#: c/c-parser.c:18161 cp/parser.c:40092
+#: c/c-parser.c:18161 cp/parser.c:40145
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:18166 cp/parser.c:40098
+#: c/c-parser.c:18166 cp/parser.c:40151
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:18222 cp/parser.c:40149
+#: c/c-parser.c:18222 cp/parser.c:40202
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18233 cp/parser.c:40160
+#: c/c-parser.c:18233 cp/parser.c:40213
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18251 cp/parser.c:40188
+#: c/c-parser.c:18251 cp/parser.c:40241
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:18330 cp/semantics.c:9306 cp/semantics.c:9397
+#: c/c-parser.c:18330 cp/semantics.c:9334 cp/semantics.c:9425
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "預期的迭代宣告或初始化"
@@ -45063,73 +45091,73 @@ msgstr "預期的迭代宣告或初始化"
 msgid "not enough perfectly nested loops"
 msgstr "不足 perfectly 巢狀的迴圈"
 
-#: c/c-parser.c:18464 cp/parser.c:40502
+#: c/c-parser.c:18464 cp/parser.c:40555
 #, fuzzy, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "崩潰的迴圈無法 perfectly 巢狀"
 
-#: c/c-parser.c:18547 cp/parser.c:40298 cp/parser.c:40340 cp/pt.c:17886
+#: c/c-parser.c:18547 cp/parser.c:40351 cp/parser.c:40393 cp/pt.c:17969
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代變數 %qD 不應為 firstprivate"
 
-#: c/c-parser.c:18681 cp/parser.c:40621
+#: c/c-parser.c:18681 cp/parser.c:40674
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> 做為僅有的參數時不能被限定"
 
-#: c/c-parser.c:18895 cp/parser.c:40839
+#: c/c-parser.c:18895 cp/parser.c:40892
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<# pragma omp barrier%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:19105 cp/parser.c:41040
+#: c/c-parser.c:19105 cp/parser.c:41093
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "預期 %<operator%>"
 
-#: c/c-parser.c:19381 cp/parser.c:41318
+#: c/c-parser.c:19381 cp/parser.c:41371
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.c:19634 cp/parser.c:41591
+#: c/c-parser.c:19634 cp/parser.c:41644
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19650 cp/parser.c:41607
+#: c/c-parser.c:19650 cp/parser.c:41660
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19698 cp/parser.c:41837
+#: c/c-parser.c:19698 cp/parser.c:41890
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19772 cp/parser.c:41690
+#: c/c-parser.c:19772 cp/parser.c:41743
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19784 cp/parser.c:41702
+#: c/c-parser.c:19784 cp/parser.c:41755
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19859 cp/parser.c:41781
+#: c/c-parser.c:19859 cp/parser.c:41834
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19872 cp/parser.c:41794
+#: c/c-parser.c:19872 cp/parser.c:41847
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:20095 cp/parser.c:42055
+#: c/c-parser.c:20095 cp/parser.c:42108
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -45144,58 +45172,58 @@ msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:20270 cp/parser.c:42731
+#: c/c-parser.c:20270 cp/parser.c:42784
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "預期 selection-statement"
 
-#: c/c-parser.c:20323 cp/parser.c:42783
+#: c/c-parser.c:20323 cp/parser.c:42836
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20348 cp/parser.c:42807
+#: c/c-parser.c:20348 cp/parser.c:42860
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s 只有接受 2 引數"
 
-#: c/c-parser.c:20375 cp/parser.c:42846 cp/pt.c:11516
+#: c/c-parser.c:20375 cp/parser.c:42899 cp/pt.c:11539
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:20378 cp/parser.c:42849 cp/pt.c:11533
+#: c/c-parser.c:20378 cp/parser.c:42902 cp/pt.c:11556
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: c/c-parser.c:20402 cp/parser.c:42877 cp/pt.c:11519
+#: c/c-parser.c:20402 cp/parser.c:42930 cp/pt.c:11542
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: c/c-parser.c:20447 cp/parser.c:42921
+#: c/c-parser.c:20447 cp/parser.c:42974
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "需要字面字串"
 
-#: c/c-parser.c:20469 cp/parser.c:42943 cp/pt.c:11523
+#: c/c-parser.c:20469 cp/parser.c:42996 cp/pt.c:11546
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "預期的整數運算式"
 
-#: c/c-parser.c:20480 cp/parser.c:42954
+#: c/c-parser.c:20480 cp/parser.c:43007
 #, fuzzy, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "內容 %qs 已經指定的在中 %<@synthesize%>"
 
-#: c/c-parser.c:20567 cp/parser.c:43040
+#: c/c-parser.c:20567 cp/parser.c:43093
 #, fuzzy, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:20642 cp/parser.c:43148
+#: c/c-parser.c:20642 cp/parser.c:43201
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "預期 %<catch%>"
@@ -45205,13 +45233,13 @@ msgstr "預期 %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "『%s』於 %L 並非函式"
 
-#: c/c-parser.c:20668 cp/decl.c:7567
+#: c/c-parser.c:20668 cp/decl.c:7563
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s 和 -msdata=%s 互不相容"
 
-#: c/c-parser.c:20680 cp/decl.c:7576
+#: c/c-parser.c:20680 cp/decl.c:7572
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -45221,32 +45249,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:20731 cp/parser.c:43193
+#: c/c-parser.c:20731 cp/parser.c:43246
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:20840 cp/parser.c:43298
+#: c/c-parser.c:20840 cp/parser.c:43351
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20889 cp/parser.c:43347
+#: c/c-parser.c:20889 cp/parser.c:43400
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20908 cp/parser.c:43372
+#: c/c-parser.c:20908 cp/parser.c:43425
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "預期 %<try%>"
 
-#: c/c-parser.c:20915 cp/parser.c:43379
+#: c/c-parser.c:20915 cp/parser.c:43432
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "預期 %<decltype%>"
 
-#: c/c-parser.c:20921 cp/parser.c:43386
+#: c/c-parser.c:20921 cp/parser.c:43439
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
@@ -45301,43 +45329,43 @@ msgstr "預期的函式"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21331 cp/parser.c:43854
+#: c/c-parser.c:21331 cp/parser.c:43907
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:21395 cp/parser.c:43917
+#: c/c-parser.c:21395 cp/parser.c:43970
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.c:21415 cp/parser.c:43943
+#: c/c-parser.c:21415 cp/parser.c:43996
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21424 cp/parser.c:43952
+#: c/c-parser.c:21424 cp/parser.c:44005
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "尚未支援程式碼模式 %<large%>"
 
-#: c/c-parser.c:21436 cp/parser.c:43964
+#: c/c-parser.c:21436 cp/parser.c:44017
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21448 cp/parser.c:43976
+#: c/c-parser.c:21448 cp/parser.c:44029
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21457 cp/parser.c:43985
+#: c/c-parser.c:21457 cp/parser.c:44038
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21471 cp/parser.c:43999
+#: c/c-parser.c:21471 cp/parser.c:44052
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -45352,27 +45380,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: c/c-parser.c:21736 cp/semantics.c:8745
+#: c/c-parser.c:21736 cp/semantics.c:8773
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE 宣告 %<threadprivate%> 之後先使用"
 
-#: c/c-parser.c:21738 cp/semantics.c:8747
+#: c/c-parser.c:21738 cp/semantics.c:8775
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: c/c-parser.c:21742 cp/semantics.c:8749
+#: c/c-parser.c:21742 cp/semantics.c:8777
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE 有不完整型態"
 
-#: c/c-parser.c:21921 cp/parser.c:44732
+#: c/c-parser.c:21921 cp/parser.c:44785
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而無需 transactional 記憶體支援已啟用"
 
-#: c/c-parser.c:21927 cp/parser.c:44738
+#: c/c-parser.c:21927 cp/parser.c:44791
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之內 %<__transaction_relaxed%>"
@@ -45382,7 +45410,7 @@ msgstr "%<__transaction_cancel%>在之內 %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> 函式呼叫無法在之內外異動作業或 %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21944 cp/parser.c:44756
+#: c/c-parser.c:21944 cp/parser.c:44809
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>無法在之內 %<__transaction_atomic%>"
@@ -45398,7 +45426,7 @@ msgstr "封閉平行"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD 類型不完全"
 
-#: c/c-typeck.c:241 c/c-typeck.c:10615 c/c-typeck.c:10657 cp/call.c:4552
+#: c/c-typeck.c:241 c/c-typeck.c:10675 c/c-typeck.c:10717 cp/call.c:4555
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "對 void 運算式的無效使用"
@@ -45441,128 +45469,128 @@ msgstr "%qD 必須不有可變個數引數數量"
 msgid "function types not truly compatible in ISO C"
 msgstr "函式類型與 ISO C 不完全相容"
 
-#: c/c-typeck.c:770
+#: c/c-typeck.c:776
 #, fuzzy, gcc-internal-format
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "can%'t 混合運算元的十進位浮點數和向量類型"
 
-#: c/c-typeck.c:775
+#: c/c-typeck.c:781
 #, fuzzy, gcc-internal-format
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "can%'t 混合運算元的十進位浮點數和複雜類型"
 
-#: c/c-typeck.c:780
+#: c/c-typeck.c:786
 #, fuzzy, gcc-internal-format
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "can%'t 混合運算元的十進位浮點數和其他浮點數類型"
 
-#: c/c-typeck.c:1325
+#: c/c-typeck.c:1331
 #, fuzzy, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "指標目標類型不相容的在中 C++"
 
-#: c/c-typeck.c:1329
+#: c/c-typeck.c:1335
 #, gcc-internal-format
 msgid "types are not quite compatible"
 msgstr "類型不完全相容"
 
-#: c/c-typeck.c:1333
+#: c/c-typeck.c:1339
 #, fuzzy, gcc-internal-format
 msgid "pointer target types incompatible in C++"
 msgstr "指標目標類型不相容的在中 C++"
 
-#: c/c-typeck.c:1666
+#: c/c-typeck.c:1672
 #, gcc-internal-format
 msgid "function return types not compatible due to %<volatile%>"
 msgstr "由於 %<volatile%>，函式回傳類型不相容"
 
-#: c/c-typeck.c:1924
+#: c/c-typeck.c:1930
 #, fuzzy, gcc-internal-format
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "轉換陣列複合實字到指標被不當形式的在中 C++"
 
-#: c/c-typeck.c:2457 c/c-typeck.c:9170
+#: c/c-typeck.c:2507 c/c-typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: c/c-typeck.c:2461 c/c-typeck.c:9174
+#: c/c-typeck.c:2511 c/c-typeck.c:9234
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: c/c-typeck.c:2470
+#: c/c-typeck.c:2520
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
 msgstr ""
 
-#: c/c-typeck.c:2473
+#: c/c-typeck.c:2523
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
 msgstr ""
 
-#: c/c-typeck.c:2533
+#: c/c-typeck.c:2583
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
 msgstr ""
 
-#: c/c-typeck.c:2539
+#: c/c-typeck.c:2589
 #, gcc-internal-format
 msgid "request for member %qE in something not a structure or union"
 msgstr "在非結構或聯合中請求成員 %qE"
 
-#: c/c-typeck.c:2587
+#: c/c-typeck.c:2637
 #, gcc-internal-format
 msgid "dereferencing %<void *%> pointer"
 msgstr "提領 %<void *%> 指標"
 
-#: c/c-typeck.c:2642
+#: c/c-typeck.c:2692
 #, fuzzy, gcc-internal-format
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "註標的值是 neither 陣列 nor 指標 nor 向量"
 
-#: c/c-typeck.c:2652 cp/typeck.c:3588 cp/typeck.c:3681
+#: c/c-typeck.c:2702 cp/typeck.c:3599 cp/typeck.c:3692
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "陣列下標不是一個整數"
 
-#: c/c-typeck.c:2658
+#: c/c-typeck.c:2708
 #, gcc-internal-format
 msgid "subscripted value is pointer to function"
 msgstr "下標運算的左運算元是函式指標"
 
-#: c/c-typeck.c:2712
+#: c/c-typeck.c:2762
 #, gcc-internal-format
 msgid "ISO C forbids subscripting %<register%> array"
 msgstr "ISO C 不允許按下標存取 %<register%> 陣列"
 
-#: c/c-typeck.c:2715
+#: c/c-typeck.c:2765
 #, gcc-internal-format
 msgid "ISO C90 forbids subscripting non-lvalue array"
 msgstr "ISO C90 不允許非左值的陣列做為下標運算的左運算元"
 
-#: c/c-typeck.c:2829
+#: c/c-typeck.c:2879
 #, fuzzy, gcc-internal-format
 msgid "enum constant defined here"
 msgstr "enum 常數定義的在此"
 
-#: c/c-typeck.c:2936 cp/typeck.c:1801
+#: c/c-typeck.c:2986 cp/typeck.c:1812
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
 
-#: c/c-typeck.c:3089
+#: c/c-typeck.c:3139
 #, fuzzy, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
 msgstr "被呼叫的物件 %qE 不是一個函式"
 
-#: c/c-typeck.c:3094
+#: c/c-typeck.c:3144
 #, fuzzy, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
 msgstr "被呼叫的物件 %qE 不是一個函式"
 
-#: c/c-typeck.c:3100
+#: c/c-typeck.c:3150
 #, fuzzy, gcc-internal-format
 msgid "called object is not a function or function pointer"
 msgstr "被呼叫的物件 %qE 不是一個函式"
@@ -45570,1648 +45598,1648 @@ msgstr "被呼叫的物件 %qE 不是一個函式"
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
 #. executions of the program must execute the code.
-#: c/c-typeck.c:3130
+#: c/c-typeck.c:3180
 #, gcc-internal-format
 msgid "function called through a non-compatible type"
 msgstr "函式經由不相容的類型呼叫"
 
-#: c/c-typeck.c:3135 c/c-typeck.c:3187
+#: c/c-typeck.c:3185 c/c-typeck.c:3237
 #, fuzzy, gcc-internal-format
 msgid "function with qualified void return type called"
 msgstr "函式與經資格修飾虛值傳回類型 called"
 
-#: c/c-typeck.c:3242
+#: c/c-typeck.c:3292
 #, gcc-internal-format, gfc-internal-format
 msgid "type of formal parameter %d is incomplete"
 msgstr "引數 %d 的類型不完全"
 
-#: c/c-typeck.c:3256
+#: c/c-typeck.c:3306
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than floating due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將做為整數而不是浮點數傳遞"
 
-#: c/c-typeck.c:3262
+#: c/c-typeck.c:3312
 #, gcc-internal-format
 msgid "passing argument %d of %qE as integer rather than complex due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將做為整數而不是複數傳遞"
 
-#: c/c-typeck.c:3268
+#: c/c-typeck.c:3318
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than floating due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將做為複數而不是浮點數傳遞"
 
-#: c/c-typeck.c:3274
+#: c/c-typeck.c:3324
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than integer due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將做為浮點數而不是整數傳遞"
 
-#: c/c-typeck.c:3280
+#: c/c-typeck.c:3330
 #, gcc-internal-format
 msgid "passing argument %d of %qE as complex rather than integer due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將做為複數而不是整數傳遞"
 
-#: c/c-typeck.c:3286
+#: c/c-typeck.c:3336
 #, gcc-internal-format
 msgid "passing argument %d of %qE as floating rather than complex due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將做為浮點數而不是複數傳遞"
 
-#: c/c-typeck.c:3300
+#: c/c-typeck.c:3350
 #, gcc-internal-format
 msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將做為 %<float%> 而不是 %<double%> 傳遞"
 
-#: c/c-typeck.c:3326
+#: c/c-typeck.c:3376
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
 msgstr "傳遞引數 %d 的 %qE 做為 %qT 而非 %qT 由於原型"
 
-#: c/c-typeck.c:3351
+#: c/c-typeck.c:3401
 #, gcc-internal-format
 msgid "passing argument %d of %qE with different width due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將以不同的寬度傳遞"
 
-#: c/c-typeck.c:3375
+#: c/c-typeck.c:3425
 #, gcc-internal-format
 msgid "passing argument %d of %qE as unsigned due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將作用無號數傳遞"
 
-#: c/c-typeck.c:3380
+#: c/c-typeck.c:3430
 #, gcc-internal-format
 msgid "passing argument %d of %qE as signed due to prototype"
 msgstr "根據原型，引數 %d (%qE) 將做為有號數傳遞"
 
-#: c/c-typeck.c:3533
+#: c/c-typeck.c:3583
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %qE"
 msgstr "太多引數到方法 %qE"
 
-#: c/c-typeck.c:3543
+#: c/c-typeck.c:3593
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "提供給函式 %qE 的引數太多"
 
-#: c/c-typeck.c:3615
+#: c/c-typeck.c:3665
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
 
-#: c/c-typeck.c:3683
+#: c/c-typeck.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "提供給函式 %qE 的引數太少"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3886 cp/typeck.c:5119 cp/typeck.c:5388
+#: c/c-typeck.c:3908 c/c-typeck.c:3936 cp/typeck.c:5130 cp/typeck.c:5399
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "比較與字串實字結果於未規定行為"
 
-#: c/c-typeck.c:3866 c/c-typeck.c:3877 cp/typeck.c:5146 cp/typeck.c:5170
+#: c/c-typeck.c:3916 c/c-typeck.c:3927 cp/typeck.c:5157 cp/typeck.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "比較指標和整數"
 
-#: c/c-typeck.c:3869 c/c-typeck.c:3880 cp/typeck.c:5149 cp/typeck.c:5173
+#: c/c-typeck.c:3919 c/c-typeck.c:3930 cp/typeck.c:5160 cp/typeck.c:5184
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
 msgstr "從 %qT 轉換到 %qT 並未提領指標"
 
-#: c/c-typeck.c:3900
+#: c/c-typeck.c:3950
 #, fuzzy, gcc-internal-format
 msgid "comparison between %qT and %qT"
 msgstr "比較介於 %qT 和 %qT"
 
-#: c/c-typeck.c:3951
+#: c/c-typeck.c:4001
 #, gcc-internal-format
 msgid "pointer of type %<void *%> used in subtraction"
 msgstr "在減法中使用類型為 %<void *%> 的指標"
 
-#: c/c-typeck.c:3954
+#: c/c-typeck.c:4004
 #, gcc-internal-format
 msgid "pointer to a function used in subtraction"
 msgstr "函式指標不能相減"
 
-#: c/c-typeck.c:3988
+#: c/c-typeck.c:4038
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在參照不完全類型的指標上執行算術運算"
 
-#: c/c-typeck.c:3997 cp/typeck.c:6086
+#: c/c-typeck.c:4047 cp/typeck.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "在參照不完全類型的指標上執行算術運算"
 
-#: c/c-typeck.c:4430
+#: c/c-typeck.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "預期的布林表示式"
 
-#: c/c-typeck.c:4434
+#: c/c-typeck.c:4494
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4444
+#: c/c-typeck.c:4504
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C 不支援用 ~ 求共軛複數"
 
-#: c/c-typeck.c:4468
+#: c/c-typeck.c:4528
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "不能對該類型的引數求絕對值"
 
-#: c/c-typeck.c:4493
+#: c/c-typeck.c:4553
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "單位元 ! 的引數類型無效"
 
-#: c/c-typeck.c:4551
+#: c/c-typeck.c:4611
 #, fuzzy, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "遞增的列舉類型值無效在中 C++"
 
-#: c/c-typeck.c:4554
+#: c/c-typeck.c:4614
 #, fuzzy, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "遞減的列舉類型值無效在中 C++"
 
-#: c/c-typeck.c:4561
+#: c/c-typeck.c:4621
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "預期的布林表示式"
 
-#: c/c-typeck.c:4564
+#: c/c-typeck.c:4624
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "預期的布林表示式"
 
-#: c/c-typeck.c:4580
+#: c/c-typeck.c:4640
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C 不支援對複數類型進行 %<++%> 或 %<--%> 作業"
 
-#: c/c-typeck.c:4606 c/c-typeck.c:4640
+#: c/c-typeck.c:4666 c/c-typeck.c:4700
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "該類型的引數不能自增"
 
-#: c/c-typeck.c:4608 c/c-typeck.c:4643
+#: c/c-typeck.c:4668 c/c-typeck.c:4703
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "該類型的引數不能自減"
 
-#: c/c-typeck.c:4628
+#: c/c-typeck.c:4688
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "無法遞增指標到不完整型態 %qT"
 
-#: c/c-typeck.c:4632
+#: c/c-typeck.c:4692
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "無法遞減指標到不完整型態 %qT"
 
-#: c/c-typeck.c:4739
+#: c/c-typeck.c:4799
 #, fuzzy, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "需位址的運算式的型態 %<void%>"
 
-#: c/c-typeck.c:4798
+#: c/c-typeck.c:4858
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "無法取得位元段 %qD 的位址"
 
-#: c/c-typeck.c:4811
+#: c/c-typeck.c:4871
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "無法取右值運算式 %<this%> 的位址"
 
-#: c/c-typeck.c:4819
+#: c/c-typeck.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "要求暫存器變數 %qD 的位址。"
 
-#: c/c-typeck.c:5004
+#: c/c-typeck.c:5064
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "巢狀函式中使用了全域暫存器變數 %qD"
 
-#: c/c-typeck.c:5007
+#: c/c-typeck.c:5067
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "巢狀函式中使用了暫存器變數 %qD"
 
-#: c/c-typeck.c:5012
+#: c/c-typeck.c:5072
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "要求全域暫存器變數 %qD 的位址"
 
-#: c/c-typeck.c:5014
+#: c/c-typeck.c:5074
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "要求暫存器變數 %qD 的位址。"
 
-#: c/c-typeck.c:5153
+#: c/c-typeck.c:5213
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "非左值陣列出現在條件運算式中"
 
-#: c/c-typeck.c:5235
+#: c/c-typeck.c:5295
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他結果的條件"
 
-#: c/c-typeck.c:5294 c/c-typeck.c:5300
+#: c/c-typeck.c:5354 c/c-typeck.c:5360
 #, gcc-internal-format
 msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5317
+#: c/c-typeck.c:5377
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C 不允許條件運算式僅有一邊為空"
 
-#: c/c-typeck.c:5334
+#: c/c-typeck.c:5394
 #, fuzzy, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "指標到 disjoint 位址空間已用於條件運算式"
 
-#: c/c-typeck.c:5345 c/c-typeck.c:5362
+#: c/c-typeck.c:5405 c/c-typeck.c:5422
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "條件運算式指標類型不匹配"
 
-#: c/c-typeck.c:5350 c/c-typeck.c:5367
+#: c/c-typeck.c:5410 c/c-typeck.c:5427
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C 不允許在條件運算式中同時使用 %<void *%> 和函式指標"
 
-#: c/c-typeck.c:5380
+#: c/c-typeck.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "條件運算式指標類型不匹配"
 
-#: c/c-typeck.c:5385
+#: c/c-typeck.c:5445
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "條件運算式指標類型不匹配"
 
-#: c/c-typeck.c:5394 c/c-typeck.c:5405
+#: c/c-typeck.c:5454 c/c-typeck.c:5465
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "條件運算式中指標/整數類型不匹配"
 
-#: c/c-typeck.c:5419
+#: c/c-typeck.c:5479
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "條件運算式中類型不匹配"
 
-#: c/c-typeck.c:5534
+#: c/c-typeck.c:5594
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: c/c-typeck.c:5538
+#: c/c-typeck.c:5598
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: c/c-typeck.c:5556
+#: c/c-typeck.c:5616
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: c/c-typeck.c:5561
+#: c/c-typeck.c:5621
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: c/c-typeck.c:5570 cp/cvt.c:1098
+#: c/c-typeck.c:5630 cp/cvt.c:1098
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "in call to %qD, declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: c/c-typeck.c:5619
+#: c/c-typeck.c:5679
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "逗號運算式的左運算元不起作用"
 
-#: c/c-typeck.c:5637 c/c-typeck.c:11178
+#: c/c-typeck.c:5697 c/c-typeck.c:11238
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "逗號運算式的左運算元不起作用"
 
-#: c/c-typeck.c:5708
+#: c/c-typeck.c:5768
 #, fuzzy
 msgid "cast adds %q#v qualifier to function type"
 msgstr "演員陣容加入 %q#v 限定元到函數型式"
 
-#: c/c-typeck.c:5714
+#: c/c-typeck.c:5774
 #, fuzzy
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "演員陣容捨棄 %q#v 限定元從指標目標類型"
 
-#: c/c-typeck.c:5749
+#: c/c-typeck.c:5809
 #, fuzzy, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "要是安全所有中介指標在中演員陣容從 %qT 到 %qT 必須是 %<const%> 經資格修飾"
 
-#: c/c-typeck.c:5843
+#: c/c-typeck.c:5903
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "類型轉換指定了陣列類型"
 
-#: c/c-typeck.c:5849
+#: c/c-typeck.c:5909
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "類型轉換指定了函式類型"
 
-#: c/c-typeck.c:5864
+#: c/c-typeck.c:5924
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C 不允許將非標量轉換為其自身類型"
 
-#: c/c-typeck.c:5884
+#: c/c-typeck.c:5944
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C 不允許轉換為聯合類型"
 
-#: c/c-typeck.c:5894
+#: c/c-typeck.c:5954
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "類型轉換的來源類型未出現在聯合中"
 
-#: c/c-typeck.c:5929
+#: c/c-typeck.c:5989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "演員陣容到 %s 位址空間指標從 disjoint 通用位址空間指標"
 
-#: c/c-typeck.c:5934
+#: c/c-typeck.c:5994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "演員陣容到通用位址空間指標從 disjoint %s 位址空間指標"
 
-#: c/c-typeck.c:5939
+#: c/c-typeck.c:5999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "演員陣容到 %s 位址空間指標從 disjoint %s 位址空間指標"
 
-#: c/c-typeck.c:5959
+#: c/c-typeck.c:6019
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "類型轉換增大了目的類型的對齊需求"
 
-#: c/c-typeck.c:5970
+#: c/c-typeck.c:6030
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "當將一個指標轉換為大小不同的整數時給出警告"
 
-#: c/c-typeck.c:5975
+#: c/c-typeck.c:6035
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "從類型為 %qT 的函式呼叫轉換到不匹配的類型 %qT"
 
-#: c/c-typeck.c:5984 cp/typeck.c:8438
+#: c/c-typeck.c:6044 cp/typeck.c:8445
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "當將一個指標轉換為大小不同的整數時給出警告"
 
-#: c/c-typeck.c:5998
+#: c/c-typeck.c:6058
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C 不允許將一個函式指標轉換為一個物件指標"
 
-#: c/c-typeck.c:6007
+#: c/c-typeck.c:6067
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C 不允許將一個物件指標轉換為一個函式指標"
 
-#: c/c-typeck.c:6017
+#: c/c-typeck.c:6077
 #, fuzzy, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "can%'t 轉換從不完整型態 %qT 到 %qT"
 
-#: c/c-typeck.c:6112
+#: c/c-typeck.c:6172
 #, fuzzy, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "定義輸入演員陣容無效在中 C++"
 
-#: c/c-typeck.c:6153
+#: c/c-typeck.c:6213
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "取消賦值"
 
-#: c/c-typeck.c:6279
+#: c/c-typeck.c:6339
 #, fuzzy, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "enum 轉換在中指派無效在中 C++"
 
-#: c/c-typeck.c:6481 c/c-typeck.c:6503 c/c-typeck.c:6529
+#: c/c-typeck.c:6541 c/c-typeck.c:6563 c/c-typeck.c:6589
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(在 %qs 的初始化附近)"
 
-#: c/c-typeck.c:6544
+#: c/c-typeck.c:6604
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "用括號中的字串常數初始化陣列"
 
-#: c/c-typeck.c:6587 c/c-typeck.c:6833
+#: c/c-typeck.c:6647 c/c-typeck.c:6893
 #, fuzzy, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "預期 %qT 但是引數是的型態 %qT"
 
-#: c/c-typeck.c:6621
+#: c/c-typeck.c:6681
 #, gcc-internal-format
 msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6624
+#: c/c-typeck.c:6684
 #, gcc-internal-format
 msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
 msgstr ""
 
-#: c/c-typeck.c:6629
+#: c/c-typeck.c:6689
 #, fuzzy, gcc-internal-format
 msgid "built-in %qD declared here"
 msgstr "%qD 宣告的在此"
 
-#: c/c-typeck.c:6828
+#: c/c-typeck.c:6888
 #, fuzzy, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "enum 轉換時傳遞引數 %d 的 %qE 無效在中 C++"
 
-#: c/c-typeck.c:6837
+#: c/c-typeck.c:6897
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "enum 轉換在中指派無效在中 C++"
 
-#: c/c-typeck.c:6841
+#: c/c-typeck.c:6901
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "enum 轉換在中初始化無效在中 C++"
 
-#: c/c-typeck.c:6846
+#: c/c-typeck.c:6906
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "enum 轉換在中回傳無效在中 C++"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %q#T to %q#T"
 msgid "implicit conversion from %qT to %qT"
 msgstr "從 %q#T 到 %q#T 的轉換"
 
-#: c/c-typeck.c:7042 c/c-typeck.c:7397
+#: c/c-typeck.c:7102 c/c-typeck.c:7457
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "傳遞引數 %d 的 %qE 製作 %q#v 經資格修飾函式指標從資格不符的"
 
-#: c/c-typeck.c:7045 c/c-typeck.c:7400
+#: c/c-typeck.c:7105 c/c-typeck.c:7460
 #, fuzzy
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "指派製作 %q#v 經資格修飾函式指標從資格不符的"
 
-#: c/c-typeck.c:7048 c/c-typeck.c:7402
+#: c/c-typeck.c:7108 c/c-typeck.c:7462
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "初始化製作 %q#v 經資格修飾函式指標從資格不符的"
 
-#: c/c-typeck.c:7051 c/c-typeck.c:7404
+#: c/c-typeck.c:7111 c/c-typeck.c:7464
 #, fuzzy
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "回傳製作 %q#v 經資格修飾函式指標從資格不符的"
 
-#: c/c-typeck.c:7059 c/c-typeck.c:7292 c/c-typeck.c:7335
+#: c/c-typeck.c:7119 c/c-typeck.c:7352 c/c-typeck.c:7395
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: c/c-typeck.c:7061 c/c-typeck.c:7294 c/c-typeck.c:7337
+#: c/c-typeck.c:7121 c/c-typeck.c:7354 c/c-typeck.c:7397
 #, fuzzy
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "指派捨棄 %qv 限定元從指標目標類型"
 
-#: c/c-typeck.c:7063 c/c-typeck.c:7296 c/c-typeck.c:7339
+#: c/c-typeck.c:7123 c/c-typeck.c:7356 c/c-typeck.c:7399
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "初始化捨棄 %qv 限定元從指標目標類型"
 
-#: c/c-typeck.c:7065 c/c-typeck.c:7298 c/c-typeck.c:7341
+#: c/c-typeck.c:7125 c/c-typeck.c:7358 c/c-typeck.c:7401
 #, fuzzy
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "回傳捨棄 %qv 限定元從指標目標類型"
 
-#: c/c-typeck.c:7074
+#: c/c-typeck.c:7134
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C 不允許將引數轉換為聯合"
 
-#: c/c-typeck.c:7142
+#: c/c-typeck.c:7202
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "C++ 中不允許從 %qT 到 %qT 的隱含轉換"
 
-#: c/c-typeck.c:7155
+#: c/c-typeck.c:7215
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "傳遞引數 %d 的 %qE 從指標到 non-enclosed 位址空間"
 
-#: c/c-typeck.c:7165
+#: c/c-typeck.c:7225
 #, fuzzy, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "指派從指標到 non-enclosed 位址空間"
 
-#: c/c-typeck.c:7175
+#: c/c-typeck.c:7235
 #, fuzzy, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "初始化從指標到 non-enclosed 位址空間"
 
-#: c/c-typeck.c:7185
+#: c/c-typeck.c:7245
 #, fuzzy, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "回傳從指標到 non-enclosed 位址空間"
 
-#: c/c-typeck.c:7208
+#: c/c-typeck.c:7268
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "引數 %d(屬於 %qE)可能是 format 屬性的備選"
 
-#: c/c-typeck.c:7214
+#: c/c-typeck.c:7274
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "賦值的左手邊可能是 format 屬性的備選時"
 
-#: c/c-typeck.c:7219
+#: c/c-typeck.c:7279
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手邊可能是 format 屬性的備選時"
 
-#: c/c-typeck.c:7224 cp/typeck.c:9547
+#: c/c-typeck.c:7284 cp/typeck.c:9554
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "回傳類型可能是 format 屬性的備選"
 
-#: c/c-typeck.c:7245
+#: c/c-typeck.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from incompatible scalar storage order"
 msgstr "傳遞參數 %d (屬於 %qE)時在不相容的指標類型間轉換"
 
-#: c/c-typeck.c:7250
+#: c/c-typeck.c:7310
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "無法遞增指標到不完整型態 %qT"
 
-#: c/c-typeck.c:7255
+#: c/c-typeck.c:7315
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
 msgstr "永遠不相容的指標類型初始化"
 
-#: c/c-typeck.c:7260
+#: c/c-typeck.c:7320
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
 msgstr "回傳與值在中函式不具任何傳回類型"
 
-#: c/c-typeck.c:7309
+#: c/c-typeck.c:7369
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C 不允許將引數 %d(屬於 %qE)在函式指標和 %<void *%> 間傳遞"
 
-#: c/c-typeck.c:7312
+#: c/c-typeck.c:7372
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C 不允許在函式指標和 %<void *%> 間賦值"
 
-#: c/c-typeck.c:7314
+#: c/c-typeck.c:7374
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C 不允許在函式指標和 %<void *%> 間初始化"
 
-#: c/c-typeck.c:7316
+#: c/c-typeck.c:7376
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C 不允許在函式指標和 %<void *%> 間回傳"
 
-#: c/c-typeck.c:7360
+#: c/c-typeck.c:7420
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "傳遞參數 %d (屬於 %qE) 給指標時目的與指標有/無號不一致"
 
-#: c/c-typeck.c:7368
+#: c/c-typeck.c:7428
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "對指標賦值時目的與指標有/無號不一致"
 
-#: c/c-typeck.c:7373
+#: c/c-typeck.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "初始化指標時目的與指標有/無號不一致"
 
-#: c/c-typeck.c:7378
+#: c/c-typeck.c:7438
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "傳遞參數 %d (屬於 %qE) 給指標時目的與指標有/無號不一致"
 
-#: c/c-typeck.c:7420
+#: c/c-typeck.c:7480
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "傳遞參數 %d (屬於 %qE)時在不相容的指標類型間轉換"
 
-#: c/c-typeck.c:7428
+#: c/c-typeck.c:7488
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "無法遞增指標到不完整型態 %qT"
 
-#: c/c-typeck.c:7433
+#: c/c-typeck.c:7493
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "永遠不相容的指標類型賦值"
 
-#: c/c-typeck.c:7439
+#: c/c-typeck.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "永遠不相容的指標類型初始化"
 
-#: c/c-typeck.c:7444
+#: c/c-typeck.c:7504
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "永遠不相容的指標類型初始化"
 
-#: c/c-typeck.c:7451
+#: c/c-typeck.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "成員指標類型 %qT 與物件類型 %qT 不相容"
 
-#: c/c-typeck.c:7456
+#: c/c-typeck.c:7516
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "回傳與值在中函式不具任何傳回類型"
 
-#: c/c-typeck.c:7495
+#: c/c-typeck.c:7555
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "傳遞參數 %d (屬於 %qE)時將整數賦給指標，未作類型轉換"
 
-#: c/c-typeck.c:7502
+#: c/c-typeck.c:7562
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "賦值時將整數賦給指標，未作類型轉換"
 
-#: c/c-typeck.c:7507
+#: c/c-typeck.c:7567
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "初始化時將整數賦給指標，未作類型轉換"
 
-#: c/c-typeck.c:7511
+#: c/c-typeck.c:7571
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "傳遞參數 %d (屬於 %qE)時將整數賦給指標，未作類型轉換"
 
-#: c/c-typeck.c:7531
+#: c/c-typeck.c:7591
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "傳遞參數 %d (屬於 %qE)時將指標賦給整數，未作類型轉換"
 
-#: c/c-typeck.c:7538
+#: c/c-typeck.c:7598
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "賦值時將指標賦給整數，未作類型轉換"
 
-#: c/c-typeck.c:7543
+#: c/c-typeck.c:7603
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "初始化將指標賦給整數，未作類型轉換"
 
-#: c/c-typeck.c:7547
+#: c/c-typeck.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "傳遞參數 %d (屬於 %qE)時將指標賦給整數，未作類型轉換"
 
-#: c/c-typeck.c:7574
+#: c/c-typeck.c:7634
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "引數 %d(屬於 %qE)類型不相容"
 
-#: c/c-typeck.c:7585
+#: c/c-typeck.c:7645
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "不相容的類型時指派輸入 %qT 從型態 %qT"
 
-#: c/c-typeck.c:7595
+#: c/c-typeck.c:7655
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "不相容的類型時初始化型態 %qT 使用型態 %qT"
 
-#: c/c-typeck.c:7605
+#: c/c-typeck.c:7665
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "不相容的類型時傳回類型 %qT 但是 %qT 被預期"
 
-#: c/c-typeck.c:7673
+#: c/c-typeck.c:7733
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "傳統 C 不接受自動的聚合初始化"
 
-#: c/c-typeck.c:7913 c/c-typeck.c:8807 cp/typeck2.c:1082
+#: c/c-typeck.c:7973 c/c-typeck.c:8867 cp/typeck2.c:1082
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "對彈性陣列成員的初始化"
 
-#: c/c-typeck.c:7929 cp/typeck2.c:1099
+#: c/c-typeck.c:7989 cp/typeck2.c:1099
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
 
-#: c/c-typeck.c:7969
+#: c/c-typeck.c:8029
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "用字串常數初始化的陣列類型不合適"
 
-#: c/c-typeck.c:8037 cp/typeck.c:2182
+#: c/c-typeck.c:8097 cp/typeck.c:2193
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "對非左值陣列的無效使用"
 
-#: c/c-typeck.c:8056 c/c-typeck.c:8080 c/c-typeck.c:8083 c/c-typeck.c:8091
-#: c/c-typeck.c:8131 c/c-typeck.c:9660 c/c-typeck.c:9710
+#: c/c-typeck.c:8116 c/c-typeck.c:8140 c/c-typeck.c:8143 c/c-typeck.c:8151
+#: c/c-typeck.c:8191 c/c-typeck.c:9720 c/c-typeck.c:9770
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "初始值設定元素不是常數"
 
-#: c/c-typeck.c:8065
+#: c/c-typeck.c:8125
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "用非常數的陣列運算式初始化陣列"
 
-#: c/c-typeck.c:8096 c/c-typeck.c:8144 c/c-typeck.c:9720
+#: c/c-typeck.c:8156 c/c-typeck.c:8204 c/c-typeck.c:9780
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: c/c-typeck.c:8138 c/c-typeck.c:9715
+#: c/c-typeck.c:8198 c/c-typeck.c:9775
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "初始值設定中的元素在載入時無法被計算出"
 
-#: c/c-typeck.c:8157
+#: c/c-typeck.c:8217
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "無效的初始值設定"
 
-#: c/c-typeck.c:8435 cp/decl.c:6976
+#: c/c-typeck.c:8495 cp/decl.c:6972
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量類型不能被初始化"
 
-#: c/c-typeck.c:8655
+#: c/c-typeck.c:8715
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "初始值設定項末尾有多餘的大括號組"
 
-#: c/c-typeck.c:8738
+#: c/c-typeck.c:8798
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "標量初始化帶大括號"
 
-#: c/c-typeck.c:8804 c/c-typeck.c:10243 cp/typeck2.c:1109 cp/typeck2.c:1367
+#: c/c-typeck.c:8864 c/c-typeck.c:10303 cp/typeck2.c:1109 cp/typeck2.c:1364
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在巢狀的上下文中初始化彈性陣列成員"
 
-#: c/c-typeck.c:8841
+#: c/c-typeck.c:8901
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "初始值設定周圍缺少大括號"
 
-#: c/c-typeck.c:8864
+#: c/c-typeck.c:8924
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: c/c-typeck.c:8888
+#: c/c-typeck.c:8948
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "空的標量初始值設定項"
 
-#: c/c-typeck.c:8893
+#: c/c-typeck.c:8953
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "標量初始化設定中有多餘元素"
 
-#: c/c-typeck.c:9012 c/c-typeck.c:9094
+#: c/c-typeck.c:9072 c/c-typeck.c:9154
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "在非陣列初始值設定項中出現陣列索引"
 
-#: c/c-typeck.c:9017 c/c-typeck.c:9156
+#: c/c-typeck.c:9077 c/c-typeck.c:9216
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "欄位名不在記錄或聯合初始化設定中"
 
-#: c/c-typeck.c:9067
+#: c/c-typeck.c:9127
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "初始值設定中陣列索引不是整型"
 
-#: c/c-typeck.c:9076 c/c-typeck.c:9085
+#: c/c-typeck.c:9136 c/c-typeck.c:9145
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "陣列索引在中初始設定式不是整數常數運算式"
 
-#: c/c-typeck.c:9090 c/c-typeck.c:9092
+#: c/c-typeck.c:9150 c/c-typeck.c:9152
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "初始值設定中陣列索引不是常數"
 
-#: c/c-typeck.c:9096 c/c-typeck.c:9099
+#: c/c-typeck.c:9156 c/c-typeck.c:9159
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "初始化時陣列索引越界"
 
-#: c/c-typeck.c:9118
+#: c/c-typeck.c:9178
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "初始值設定項中索引範圍為空"
 
-#: c/c-typeck.c:9127
+#: c/c-typeck.c:9187
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "初始值設定中資料索引範圍超出陣列邊界"
 
-#: c/c-typeck.c:9229 c/c-typeck.c:9259 c/c-typeck.c:9803
+#: c/c-typeck.c:9289 c/c-typeck.c:9319 c/c-typeck.c:9863
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "帶副作用的欄位初始化設定被覆寫"
 
-#: c/c-typeck.c:9233 c/c-typeck.c:9263 c/c-typeck.c:9806
+#: c/c-typeck.c:9293 c/c-typeck.c:9323 c/c-typeck.c:9866
 #, fuzzy, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "初始化的欄位覆寫"
 
-#: c/c-typeck.c:9737
+#: c/c-typeck.c:9797
 #, fuzzy, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "enum 轉換在中初始化無效在中 C++"
 
-#: c/c-typeck.c:10118
+#: c/c-typeck.c:10178
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "字元陣列初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:10125 c/c-typeck.c:10202
+#: c/c-typeck.c:10185 c/c-typeck.c:10262
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "結構初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:10146
+#: c/c-typeck.c:10206
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:10217 cp/typeck2.c:1086
+#: c/c-typeck.c:10277 cp/typeck2.c:1086
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "對彈性陣列成員非靜態地初始化"
 
-#: c/c-typeck.c:10312
+#: c/c-typeck.c:10372
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "聯合初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:10334
+#: c/c-typeck.c:10394
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "傳統 C 不接受對聯合的初始化"
 
-#: c/c-typeck.c:10396
+#: c/c-typeck.c:10456
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "陣列初始值設定項中有多餘的元素"
 
-#: c/c-typeck.c:10430
+#: c/c-typeck.c:10490
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "向量初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:10462
+#: c/c-typeck.c:10522
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "標量初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:10704
+#: c/c-typeck.c:10764
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允許 %<goto *expr;%>"
 
-#: c/c-typeck.c:10731 c/gimple-parser.c:2404 cp/typeck.c:10039
+#: c/c-typeck.c:10791 c/gimple-parser.c:2404 cp/typeck.c:10046
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被宣告為 %<noreturn%> 的函式卻有 %<return%> 敘述"
 
-#: c/c-typeck.c:10759 c/c-typeck.c:10763
+#: c/c-typeck.c:10819 c/c-typeck.c:10823
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "在有回傳值的的函式中，%<return%> 不帶回傳值"
 
-#: c/c-typeck.c:10777 c/gimple-parser.c:2414
+#: c/c-typeck.c:10837 c/gimple-parser.c:2414
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "在無回傳值的函式中，%<return%> 帶回傳值"
 
-#: c/c-typeck.c:10780
+#: c/c-typeck.c:10840
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C 禁止 %<return%> 與運算式，在中函式回傳虛值"
 
-#: c/c-typeck.c:10857
+#: c/c-typeck.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "函式回傳局部變數的位址"
 
-#: c/c-typeck.c:10947 cp/semantics.c:1420
+#: c/c-typeck.c:11007 cp/semantics.c:1439
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch 敘述中的值不是一個整數"
 
-#: c/c-typeck.c:10972
+#: c/c-typeck.c:11032
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "在 ISO C 中，%<long%> 開關運算式不被轉換為 %<int%>"
 
-#: c/c-typeck.c:11010 c/c-typeck.c:11018
+#: c/c-typeck.c:11070 c/c-typeck.c:11078
 #, fuzzy, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "大小寫標貼不是整數常數運算式"
 
-#: c/c-typeck.c:11024 cp/parser.c:11953
+#: c/c-typeck.c:11084 cp/parser.c:11974
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: c/c-typeck.c:11026
+#: c/c-typeck.c:11086
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> 標籤未出現在 switch 敘述內"
 
-#: c/c-typeck.c:11102 cp/parser.c:13452
+#: c/c-typeck.c:11162 cp/parser.c:13476
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 敘述不在循環或開關敘述內"
 
-#: c/c-typeck.c:11105 c/c-typeck.c:11125 cp/decl.c:3661 cp/parser.c:13462
-#: cp/parser.c:13483
+#: c/c-typeck.c:11165 c/c-typeck.c:11185 cp/decl.c:3643 cp/parser.c:13486
+#: cp/parser.c:13507
 #, fuzzy, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "無效的離開從 OpenMP 結構化訊息塊"
 
-#: c/c-typeck.c:11108 cp/parser.c:13465
+#: c/c-typeck.c:11168 cp/parser.c:13489
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "中斷敘述使用的與 OpenMP 用於迴圈"
 
-#: c/c-typeck.c:11122 cp/parser.c:13475
+#: c/c-typeck.c:11182 cp/parser.c:13499
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 敘述出現在循環以外"
 
-#: c/c-typeck.c:11160 cp/cp-gimplify.c:218
+#: c/c-typeck.c:11220 cp/cp-gimplify.c:218
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "敘述不起作用"
 
-#: c/c-typeck.c:11204
+#: c/c-typeck.c:11264
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "運算式敘述類型不完全"
 
-#: c/c-typeck.c:12038 c/c-typeck.c:12206 cp/typeck.c:5402
+#: c/c-typeck.c:12098 c/c-typeck.c:12266 cp/typeck.c:5413
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "比較向量與不同的元件類型"
 
-#: c/c-typeck.c:12046 c/c-typeck.c:12214 cp/typeck.c:5415
+#: c/c-typeck.c:12106 c/c-typeck.c:12274 cp/typeck.c:5426
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "比較向量與不同的元件號碼的"
 
-#: c/c-typeck.c:12071 c/c-typeck.c:12239 cp/typeck.c:5450
+#: c/c-typeck.c:12131 c/c-typeck.c:12299 cp/typeck.c:5461
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到介面用於類別 %qE"
 
-#: c/c-typeck.c:12085 cp/typeck.c:5108
+#: c/c-typeck.c:12145 cp/typeck.c:5119
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "使用 == 或 != 比較浮點數是不安全的"
 
-#: c/c-typeck.c:12103 c/c-typeck.c:12124
+#: c/c-typeck.c:12163 c/c-typeck.c:12184
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "比較將一律評估做為 %<false%> 用於位址的 %qD 將永不是空值"
 
-#: c/c-typeck.c:12109 c/c-typeck.c:12130
+#: c/c-typeck.c:12169 c/c-typeck.c:12190
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "比較將一律評估做為 %<true%> 用於位址的 %qD 將永不是空值"
 
-#: c/c-typeck.c:12151 c/c-typeck.c:12280
+#: c/c-typeck.c:12211 c/c-typeck.c:12340
 #, fuzzy, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "比較的指標到 disjoint 位址空間"
 
-#: c/c-typeck.c:12158 c/c-typeck.c:12164
+#: c/c-typeck.c:12218 c/c-typeck.c:12224
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C 不允許在 %<void *%> 和函式指標間比較"
 
-#: c/c-typeck.c:12171 c/c-typeck.c:12290
+#: c/c-typeck.c:12231 c/c-typeck.c:12350
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "比較不相關的指標時缺少類型轉換"
 
-#: c/c-typeck.c:12183 c/c-typeck.c:12188 c/c-typeck.c:12316 c/c-typeck.c:12321
+#: c/c-typeck.c:12243 c/c-typeck.c:12248 c/c-typeck.c:12376 c/c-typeck.c:12381
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "比較指標和整數"
 
-#: c/c-typeck.c:12268
+#: c/c-typeck.c:12328
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "在完全和不完全指標間比較"
 
-#: c/c-typeck.c:12270
+#: c/c-typeck.c:12330
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C 不允許函式指標間比較大小"
 
-#: c/c-typeck.c:12275
+#: c/c-typeck.c:12335
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "已排序的比較的指標與空指標"
 
-#: c/c-typeck.c:12298 c/c-typeck.c:12301 c/c-typeck.c:12308 c/c-typeck.c:12311
+#: c/c-typeck.c:12358 c/c-typeck.c:12361 c/c-typeck.c:12368 c/c-typeck.c:12371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指標與整數 0 比較大小"
 
-#: c/c-typeck.c:12380
+#: c/c-typeck.c:12440
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
 
-#: c/c-typeck.c:12695
+#: c/c-typeck.c:12755
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "需要標量時使用了不能被轉換為指標的陣列"
 
-#: c/c-typeck.c:12699
+#: c/c-typeck.c:12759
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "需要標量時使用了結構類型"
 
-#: c/c-typeck.c:12703
+#: c/c-typeck.c:12763
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "需要標量時使用了聯合類型"
 
-#: c/c-typeck.c:12719
+#: c/c-typeck.c:12779
 #, fuzzy, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "使用的向量型態位置純量被必要項"
 
-#: c/c-typeck.c:12909 cp/semantics.c:9869
+#: c/c-typeck.c:12969 cp/semantics.c:9897
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12920 c/c-typeck.c:12930 cp/semantics.c:9880
-#: cp/semantics.c:9890
+#: c/c-typeck.c:12980 c/c-typeck.c:12990 cp/semantics.c:9908
+#: cp/semantics.c:9918
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "預期 %<;%>之後類別定義"
 
-#: c/c-typeck.c:12965 cp/semantics.c:9925
+#: c/c-typeck.c:13025 cp/semantics.c:9953
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13009 c/c-typeck.c:14596 c/c-typeck.c:14683 c/c-typeck.c:14756
+#: c/c-typeck.c:13069 c/c-typeck.c:14656 c/c-typeck.c:14743 c/c-typeck.c:14816
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.c:13021 c/c-typeck.c:14528 c/c-typeck.c:14669
-#: cp/semantics.c:4930 cp/semantics.c:7473 cp/semantics.c:7667
+#: c/c-typeck.c:13081 c/c-typeck.c:14588 c/c-typeck.c:14729
+#: cp/semantics.c:4958 cp/semantics.c:7501 cp/semantics.c:7695
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13030 c/c-typeck.c:14693 cp/semantics.c:4940
-#: cp/semantics.c:7686
+#: c/c-typeck.c:13090 c/c-typeck.c:14753 cp/semantics.c:4968
+#: cp/semantics.c:7714
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD 不是一個成員範本函式"
 
-#: c/c-typeck.c:13038 c/c-typeck.c:14702
+#: c/c-typeck.c:13098 c/c-typeck.c:14762
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: c/c-typeck.c:13049 cp/semantics.c:4956 cp/semantics.c:7715
+#: c/c-typeck.c:13109 cp/semantics.c:4984 cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13053 c/c-typeck.c:14721 cp/semantics.c:4960
-#: cp/semantics.c:7719
+#: c/c-typeck.c:13113 c/c-typeck.c:14781 cp/semantics.c:4988
+#: cp/semantics.c:7747
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13060
+#: c/c-typeck.c:13120
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.c:13069 c/c-typeck.c:14728 c/c-typeck.c:14846
-#: cp/semantics.c:4978 cp/semantics.c:7726 cp/semantics.c:7907
+#: c/c-typeck.c:13129 c/c-typeck.c:14788 c/c-typeck.c:14906
+#: cp/semantics.c:5006 cp/semantics.c:7754 cp/semantics.c:7935
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13105 cp/semantics.c:5012
+#: c/c-typeck.c:13165 cp/semantics.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.c:13112 cp/semantics.c:5019
+#: c/c-typeck.c:13172 cp/semantics.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.c:13135 cp/semantics.c:5052
+#: c/c-typeck.c:13195 cp/semantics.c:5080
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "Cray 指標『%s』在中 %s 子句於 %L"
 
-#: c/c-typeck.c:13152 c/c-typeck.c:13218 c/c-typeck.c:13495
-#: cp/semantics.c:5069 cp/semantics.c:5135
+#: c/c-typeck.c:13212 c/c-typeck.c:13278 c/c-typeck.c:13555
+#: cp/semantics.c:5097 cp/semantics.c:5163
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:13171 cp/semantics.c:5088
+#: c/c-typeck.c:13231 cp/semantics.c:5116
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:13179 cp/semantics.c:5096
+#: c/c-typeck.c:13239 cp/semantics.c:5124
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13188 c/c-typeck.c:13309 cp/semantics.c:5105
-#: cp/semantics.c:5226
+#: c/c-typeck.c:13248 c/c-typeck.c:13369 cp/semantics.c:5133
+#: cp/semantics.c:5254
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:13205 cp/semantics.c:5122
+#: c/c-typeck.c:13265 cp/semantics.c:5150
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13246 cp/semantics.c:5163
+#: c/c-typeck.c:13306 cp/semantics.c:5191
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13261 cp/semantics.c:5178
+#: c/c-typeck.c:13321 cp/semantics.c:5206
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13297 cp/semantics.c:5214
+#: c/c-typeck.c:13357 cp/semantics.c:5242
 #, fuzzy, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: c/c-typeck.c:13301 cp/semantics.c:5218
+#: c/c-typeck.c:13361 cp/semantics.c:5246
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: c/c-typeck.c:13319 c/c-typeck.c:13434 cp/semantics.c:5236
-#: cp/semantics.c:5365
+#: c/c-typeck.c:13379 c/c-typeck.c:13494 cp/semantics.c:5264
+#: cp/semantics.c:5393
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "複製陣列區段進入 contiguous 區塊於程序條目"
 
-#: c/c-typeck.c:13327 cp/semantics.c:5244
+#: c/c-typeck.c:13387 cp/semantics.c:5272
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: c/c-typeck.c:13713 cp/semantics.c:6318
+#: c/c-typeck.c:13773 cp/semantics.c:6346
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "拋出 NULL，它的類型是整數而不是指標"
 
-#: c/c-typeck.c:13720
+#: c/c-typeck.c:13780
 #, gcc-internal-format
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.c:13726 cp/semantics.c:6325
+#: c/c-typeck.c:13786 cp/semantics.c:6353
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "參數 %qD 有不完整型態"
 
-#: c/c-typeck.c:13739 cp/semantics.c:6341
+#: c/c-typeck.c:13799 cp/semantics.c:6369
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "bit-field %qD 與 non-integral 型態"
 
-#: c/c-typeck.c:13759 cp/semantics.c:6377
+#: c/c-typeck.c:13819 cp/semantics.c:6405
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
 
-#: c/c-typeck.c:13786
+#: c/c-typeck.c:13846
 #, gcc-internal-format
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13793 cp/semantics.c:6411
+#: c/c-typeck.c:13853 cp/semantics.c:6439
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:6417
+#: c/c-typeck.c:13859 cp/semantics.c:6445
 #, fuzzy, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "無效的運算式用於輸出修飾鍵『%c』"
 
-#: c/c-typeck.c:13805 cp/semantics.c:6423
+#: c/c-typeck.c:13865 cp/semantics.c:6451
 #, fuzzy, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "%L 處運算式參照類型錯誤"
 
-#: c/c-typeck.c:13842 cp/semantics.c:6471
+#: c/c-typeck.c:13902 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "預期的指標"
 
-#: c/c-typeck.c:13924 cp/semantics.c:6546
+#: c/c-typeck.c:13984 cp/semantics.c:6574
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "尚未支援程式碼模式 %<large%>"
 
-#: c/c-typeck.c:13946 cp/semantics.c:6566
+#: c/c-typeck.c:14006 cp/semantics.c:6594
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "尚未支援程式碼模式 %<large%>"
 
-#: c/c-typeck.c:13972 c/c-typeck.c:13982
+#: c/c-typeck.c:14032 c/c-typeck.c:14042
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:14002
+#: c/c-typeck.c:14062
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14014
+#: c/c-typeck.c:14074
 #, fuzzy, gcc-internal-format
 msgid "zero sized type %qT in %qs clause"
 msgstr "假設的大小陣列『%s』在中 %s 子句於 %L"
 
-#: c/c-typeck.c:14022
+#: c/c-typeck.c:14082
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %qs clause"
 msgstr "變數長度陣列 %qE 被使用"
 
-#: c/c-typeck.c:14072
+#: c/c-typeck.c:14132
 #, fuzzy, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE 有無效的型態用於 %<reduction(%s)%>"
 
-#: c/c-typeck.c:14081 cp/semantics.c:6210
+#: c/c-typeck.c:14141 cp/semantics.c:6238
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:14169
+#: c/c-typeck.c:14229
 #, fuzzy, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:14187 c/c-typeck.c:14920 cp/semantics.c:8362
+#: c/c-typeck.c:14247 c/c-typeck.c:14980 cp/semantics.c:8390
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14199 cp/semantics.c:8430
+#: c/c-typeck.c:14259 cp/semantics.c:8458
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE 必須是 %<threadprivate%> 用於 %<copyin%>"
 
-#: c/c-typeck.c:14213 cp/semantics.c:6607
+#: c/c-typeck.c:14273 cp/semantics.c:6635
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:14221
+#: c/c-typeck.c:14281
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14229
+#: c/c-typeck.c:14289
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14248 cp/semantics.c:6681
+#: c/c-typeck.c:14308 cp/semantics.c:6709
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14278 c/c-typeck.c:14839 c/c-typeck.c:15063
-#: cp/semantics.c:6768 cp/semantics.c:7900 cp/semantics.c:8198
+#: c/c-typeck.c:14338 c/c-typeck.c:14899 c/c-typeck.c:15123
+#: cp/semantics.c:6796 cp/semantics.c:7928 cp/semantics.c:8226
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14293 cp/semantics.c:6783
+#: c/c-typeck.c:14353 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14306 c/c-typeck.c:14338 c/c-typeck.c:14369
+#: c/c-typeck.c:14366 c/c-typeck.c:14398 c/c-typeck.c:14429
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14314 c/c-typeck.c:14345 c/c-typeck.c:14617 c/c-typeck.c:14767
-#: c/c-typeck.c:14774 c/c-typeck.c:14792 c/c-typeck.c:14802 c/c-typeck.c:14809
-#: cp/semantics.c:6796 cp/semantics.c:6804 cp/semantics.c:6861
-#: cp/semantics.c:6868 cp/semantics.c:6912 cp/semantics.c:7600
-#: cp/semantics.c:7777 cp/semantics.c:7784 cp/semantics.c:7801
-#: cp/semantics.c:7811 cp/semantics.c:7818
+#: c/c-typeck.c:14374 c/c-typeck.c:14405 c/c-typeck.c:14677 c/c-typeck.c:14827
+#: c/c-typeck.c:14834 c/c-typeck.c:14852 c/c-typeck.c:14862 c/c-typeck.c:14869
+#: cp/semantics.c:6824 cp/semantics.c:6832 cp/semantics.c:6889
+#: cp/semantics.c:6896 cp/semantics.c:6940 cp/semantics.c:7628
+#: cp/semantics.c:7805 cp/semantics.c:7812 cp/semantics.c:7829
+#: cp/semantics.c:7839 cp/semantics.c:7846
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14317 c/c-typeck.c:14348 c/c-typeck.c:14777 c/c-typeck.c:14812
-#: cp/semantics.c:6807 cp/semantics.c:6871 cp/semantics.c:7787
-#: cp/semantics.c:7821
+#: c/c-typeck.c:14377 c/c-typeck.c:14408 c/c-typeck.c:14837 c/c-typeck.c:14872
+#: cp/semantics.c:6835 cp/semantics.c:6899 cp/semantics.c:7815
+#: cp/semantics.c:7849
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14331 cp/semantics.c:6853
+#: c/c-typeck.c:14391 cp/semantics.c:6881
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE 並非變數在中子句 %<firstprivate%>"
 
-#: c/c-typeck.c:14362 cp/semantics.c:6904
+#: c/c-typeck.c:14422 cp/semantics.c:6932
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE 並非變數在中子句 %<lastprivate%>"
 
-#: c/c-typeck.c:14381 cp/semantics.c:7243
+#: c/c-typeck.c:14441 cp/semantics.c:7271
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14388
+#: c/c-typeck.c:14448
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: c/c-typeck.c:14395
+#: c/c-typeck.c:14455
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14402
+#: c/c-typeck.c:14462
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14415 cp/semantics.c:7314
+#: c/c-typeck.c:14475 cp/semantics.c:7342
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14421
+#: c/c-typeck.c:14481
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14434 cp/semantics.c:7353
+#: c/c-typeck.c:14494 cp/semantics.c:7381
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14440
+#: c/c-typeck.c:14500
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14509 cp/semantics.c:7439
+#: c/c-typeck.c:14569 cp/semantics.c:7467
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.c:14520 cp/semantics.c:7464
+#: c/c-typeck.c:14580 cp/semantics.c:7492
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14536 cp/semantics.c:7483
+#: c/c-typeck.c:14596 cp/semantics.c:7511
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.c:14545 cp/semantics.c:7494
+#: c/c-typeck.c:14605 cp/semantics.c:7522
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.c:14588 cp/semantics.c:7575
+#: c/c-typeck.c:14648 cp/semantics.c:7603
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:14613 c/c-typeck.c:14789 cp/semantics.c:7596
-#: cp/semantics.c:7798
+#: c/c-typeck.c:14673 c/c-typeck.c:14849 cp/semantics.c:7624
+#: cp/semantics.c:7826
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14621 c/c-typeck.c:14795 cp/semantics.c:7604
-#: cp/semantics.c:7804
+#: c/c-typeck.c:14681 c/c-typeck.c:14855 cp/semantics.c:7632
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14676 cp/semantics.c:7674
+#: c/c-typeck.c:14736 cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14747 c/c-typeck.c:14853 cp/semantics.c:7756
-#: cp/semantics.c:7914
+#: c/c-typeck.c:14807 c/c-typeck.c:14913 cp/semantics.c:7784
+#: cp/semantics.c:7942
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14834 cp/semantics.c:7894
+#: c/c-typeck.c:14894 cp/semantics.c:7922
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14862 cp/semantics.c:7924
+#: c/c-typeck.c:14922 cp/semantics.c:7952
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14876 cp/semantics.c:7940
+#: c/c-typeck.c:14936 cp/semantics.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14879 cp/semantics.c:7943
+#: c/c-typeck.c:14939 cp/semantics.c:7971
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14896
+#: c/c-typeck.c:14956
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "來源並非指標"
 
-#: c/c-typeck.c:14903
+#: c/c-typeck.c:14963
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: c/c-typeck.c:14933 c/c-typeck.c:15024 cp/semantics.c:8340
+#: c/c-typeck.c:14993 c/c-typeck.c:15084 cp/semantics.c:8368
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "-frepo 必須與 -c 一起使用"
 
-#: c/c-typeck.c:14953 cp/semantics.c:7526
+#: c/c-typeck.c:15013 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.c:15046 cp/semantics.c:8166
+#: c/c-typeck.c:15106 cp/semantics.c:8194
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:15113 cp/semantics.c:8501
+#: c/c-typeck.c:15173 cp/semantics.c:8529
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: c/c-typeck.c:15123
+#: c/c-typeck.c:15183
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:15142 cp/semantics.c:8292
+#: c/c-typeck.c:15202 cp/semantics.c:8320
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15154 cp/semantics.c:8305
+#: c/c-typeck.c:15214 cp/semantics.c:8333
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15165 c/c-typeck.c:15173 cp/semantics.c:8314
-#: cp/semantics.c:8332
+#: c/c-typeck.c:15225 c/c-typeck.c:15233 cp/semantics.c:8342
+#: cp/semantics.c:8360
 #, fuzzy, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: c/c-typeck.c:15218 cp/semantics.c:8272
+#: c/c-typeck.c:15278 cp/semantics.c:8300
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15255 cp/semantics.c:8322
+#: c/c-typeck.c:15315 cp/semantics.c:8350
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15265 cp/semantics.c:8351
+#: c/c-typeck.c:15325 cp/semantics.c:8379
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "-frepo 必須與 -c 一起使用"
 
-#: c/c-typeck.c:15283 cp/semantics.c:8526
+#: c/c-typeck.c:15343 cp/semantics.c:8554
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
 
-#: c/c-typeck.c:15457
+#: c/c-typeck.c:15517
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15462
+#: c/c-typeck.c:15522
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "給 %<va_arg%> 的第一個參數的類型不是 %<va_list%>"
 
-#: c/c-typeck.c:15468
+#: c/c-typeck.c:15528
 #, fuzzy, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++需求升級的型態，無法 enum 型態，在中 %<va_arg%>"
@@ -47436,7 +47464,7 @@ msgstr "  當從 %qT 轉換為 %qT 時"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  沒有已知轉換用於引數 %d 從 %qT 到 %qT"
 
-#: cp/call.c:3729 cp/pt.c:6885
+#: cp/call.c:3729 cp/pt.c:6906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -47549,698 +47577,703 @@ msgstr ""
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
 
-#: cp/call.c:4641
+#: cp/call.c:4644
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:4644
+#: cp/call.c:4647
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "呼叫多載的 %<%D(%A)%> 有歧義"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4869
+#: cp/call.c:4872
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "沒有物件不能呼叫成員函式指標 %E，考慮使用 .* 或 ->*"
 
-#: cp/call.c:4941
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "對 %<(%T) (%A)%> 的呼叫沒有匹配"
 
-#: cp/call.c:4955
+#: cp/call.c:4958
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "對 %<(%T) (%A)%> 的呼叫有歧義"
 
-#: cp/call.c:5007
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "模稜兩可的過載用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5011
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:5011
+#: cp/call.c:5014
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "無效的運算元到二進位 %s (有 %qT 和 %qT)"
 
-#: cp/call.c:5013
+#: cp/call.c:5016
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "無效的運算元到二進位 %s (有 %qT 和 %qT)"
 
-#: cp/call.c:5015
+#: cp/call.c:5018
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:5032
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:5036
+#: cp/call.c:5039
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "沒有匹配用於三進 %<operator?:%> 在中 %<%E？%E：%E%>"
 
-#: cp/call.c:5045 cp/call.c:5089 cp/call.c:5099
+#: cp/call.c:5048 cp/call.c:5092 cp/call.c:5102
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:5048
+#: cp/call.c:5051
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%E%s%>"
 
-#: cp/call.c:5055
+#: cp/call.c:5058
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:5058
+#: cp/call.c:5061
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "沒有匹配用於 %<operator[]%> 在中 %<%E[%E]%>"
 
-#: cp/call.c:5066
+#: cp/call.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:5069
+#: cp/call.c:5072
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:5075
+#: cp/call.c:5078
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:5078
+#: cp/call.c:5081
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%s%E%>"
 
-#: cp/call.c:5093
+#: cp/call.c:5096
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%E %s %E%>"
 
-#: cp/call.c:5102
+#: cp/call.c:5105
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%s%E%>"
 
-#: cp/call.c:5212
+#: cp/call.c:5215
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C 不允許省略 ?: 運算式中的第二項"
 
-#: cp/call.c:5279
+#: cp/call.c:5282
 #, fuzzy, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "找不到介面用於類別 %qE"
 
-#: cp/call.c:5296 cp/call.c:5303
+#: cp/call.c:5299 cp/call.c:5306
 #, fuzzy
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "轉換的純量到向量牽連出截斷"
 
-#: cp/call.c:5359
+#: cp/call.c:5362
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "條件運算式中列舉不匹配：%qT 對 %qT"
 
-#: cp/call.c:5439
+#: cp/call.c:5442
 #, fuzzy, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "秒運算元到條件式運算子是的型態 %<void%>，但是第三運算元是 neither throw-expression nor 的型態 %<void%>"
 
-#: cp/call.c:5444
+#: cp/call.c:5447
 #, fuzzy, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "第三運算元到條件式運算子是的型態 %<void%>，但是第二運算元是 neither throw-expression nor 的型態 %<void%>"
 
-#: cp/call.c:5493 cp/call.c:5608 cp/call.c:5779
+#: cp/call.c:5496 cp/call.c:5611 cp/call.c:5782
 #, fuzzy, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "運算元到 ?:有不同的類型 %qT 和 %qT"
 
-#: cp/call.c:5497
+#: cp/call.c:5500
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5684
+#: cp/call.c:5687
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他結果的條件"
 
-#: cp/call.c:5700
+#: cp/call.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "條件運算式中列舉不匹配：%qT 對 %qT"
 
-#: cp/call.c:5713
+#: cp/call.c:5716
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "條件運算式介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/call.c:5718
+#: cp/call.c:5721
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "條件運算式介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/call.c:5734
+#: cp/call.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "列舉和非列舉類型一起出現在條件運算式中"
 
-#: cp/call.c:6415
+#: cp/call.c:6419
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> 沒有出現在字尾 %qs 中，嘗試使用字首運算子"
 
-#: cp/call.c:6417
+#: cp/call.c:6421
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "沒有 %<%D(整數)%>宣告的用於後綴 %qs"
 
-#: cp/call.c:6497
+#: cp/call.c:6501
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6548
+#: cp/call.c:6552
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "傳回類型的 %qD 不是 %<int%>"
 
-#: cp/call.c:6550
+#: cp/call.c:6554
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6621
+#: cp/call.c:6625
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在 %q#T 和 %q#T 間比較"
 
-#: cp/call.c:7005
+#: cp/call.c:7009
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:7008
+#: cp/call.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "non-placement deallocation 函式 %q+D"
 
-#: cp/call.c:7047
+#: cp/call.c:7051
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "non-placement deallocation 函式 %q+D"
 
-#: cp/call.c:7221
+#: cp/call.c:7225
 #, fuzzy, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "沒有相應 deallocation 函式用於 %qD"
 
-#: cp/call.c:7227
+#: cp/call.c:7231
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "沒有合適的 %<operator %s%> 給 %qT"
 
-#: cp/call.c:7263
+#: cp/call.c:7267
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:7264 cp/decl.c:8260
+#: cp/call.c:7268 cp/decl.c:8266
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "宣告的在此"
 
-#: cp/call.c:7269
+#: cp/call.c:7273
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:7270 cp/decl.c:8261
+#: cp/call.c:7274 cp/decl.c:8267
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "宣告的在此"
 
-#: cp/call.c:7277
+#: cp/call.c:7281
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D 無法存取"
 
-#: cp/call.c:7358
+#: cp/call.c:7362
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "將 NULL 做為非指標引數 %P 傳遞給 %qD"
 
-#: cp/call.c:7361 cp/call.c:7380 cp/decl.c:9950 cp/typeck.c:4188
+#: cp/call.c:7365 cp/call.c:7384 cp/decl.c:9962 cp/typeck.c:4199
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "宣告的在此"
 
-#: cp/call.c:7365
+#: cp/call.c:7369
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "將 NULL 轉換到非指標類型 %qT"
 
-#: cp/call.c:7377
+#: cp/call.c:7381
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "轉換 %<false%> 到指標類型用於引數 %P 的 %qD"
 
-#: cp/call.c:7384
+#: cp/call.c:7388
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "轉換 %<false%> 到指標類型 %qT"
 
-#: cp/call.c:7451
+#: cp/call.c:7455
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化引數 %P，屬於 %qD"
 
-#: cp/call.c:7471
+#: cp/call.c:7475
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/call.c:7521
+#: cp/call.c:7525
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "太多大括號周圍初始設定式用於 %qT"
 
-#: cp/call.c:7532
+#: cp/call.c:7536
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/call.c:7541
+#: cp/call.c:7545
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "無效的使用者定義的轉換從 %qT 到 %qT"
 
-#: cp/call.c:7578 cp/cvt.c:227
+#: cp/call.c:7582 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/call.c:7620 cp/call.c:7627
+#: cp/call.c:7624 cp/call.c:7631
 #, fuzzy, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "轉換到 %qT 從初始設定式清單會使用明確的建構子 %qD"
 
-#: cp/call.c:7623
+#: cp/call.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/call.c:7893
+#: cp/call.c:7897
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "轉換到易變的參考類型 %q#T 從 rvalue 的型態 %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7906
+#, fuzzy
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
+
+#: cp/call.c:7911
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.c:7908
+#: cp/call.c:7923
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "轉換到易變的參考類型 %q#T 從 rvalue 的型態 %qT"
 
-#: cp/call.c:7911
+#: cp/call.c:7926
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: cp/call.c:7950
+#: cp/call.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "無法將位元段 %qE 繫結到 %qT"
 
-#: cp/call.c:7953 cp/call.c:7971
+#: cp/call.c:7968 cp/call.c:7986
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能將緊實的欄位 %qE 繫結到 %qT"
 
-#: cp/call.c:7956
+#: cp/call.c:7971
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "無法將右值 %qE 繫結到 %qT"
 
-#: cp/call.c:8151
+#: cp/call.c:8166
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
 
-#: cp/call.c:8175 cp/cvt.c:1978
+#: cp/call.c:8190 cp/cvt.c:1978
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:8219
+#: cp/call.c:8234
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "無法回合物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>"
 
-#: cp/call.c:8255
+#: cp/call.c:8270
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.c:8265
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.c:8333
+#: cp/call.c:8348
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "遞迴求值的預設引數用於 %q#D"
 
-#: cp/call.c:8342
+#: cp/call.c:8357
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "呼叫到 %qD 使用預設引數用於參數 %P, 該項不是未定義"
 
-#: cp/call.c:8442
+#: cp/call.c:8457
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函式的引數可能是 format 屬性的備選"
 
-#: cp/call.c:8504
+#: cp/call.c:8519
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "缺席函式 %q+D 與預設引數"
 
-#: cp/call.c:9083
+#: cp/call.c:9103
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "將 %qT 做為 %q#D 的 %<this%> 引數時丟棄了類型限定"
 
-#: cp/call.c:9086 cp/call.c:11715
+#: cp/call.c:9106 cp/call.c:11736
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  在呼叫 %qD 時"
 
-#: cp/call.c:9111
+#: cp/call.c:9131
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT 是 %qT 的一個不可存取的基礎類別"
 
-#: cp/call.c:9293
+#: cp/call.c:9313
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/call.c:9425
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9825
+#: cp/call.c:9845
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9828
+#: cp/call.c:9848
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD 無法 thread-local 因為它有 non-trivial 型態 %qT"
 
-#: cp/call.c:9833
+#: cp/call.c:9853
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9838
+#: cp/call.c:9858
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9853
+#: cp/call.c:9873
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/call.c:9855
+#: cp/call.c:9875
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:9857
+#: cp/call.c:9877
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/call.c:9860
+#: cp/call.c:9880
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9863
+#: cp/call.c:9883
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD 無法 thread-local 因為它有 non-trivial 型態 %qT"
 
-#: cp/call.c:9865
+#: cp/call.c:9885
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9886
+#: cp/call.c:9906
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/call.c:9888
+#: cp/call.c:9908
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:9890
+#: cp/call.c:9910
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "擴充：%C 處舊式的初始化"
 
-#: cp/call.c:9893
+#: cp/call.c:9913
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9896
+#: cp/call.c:9916
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "轉換到虛值將無法存取物件的 non-trivially-copyable 型態 %qT"
 
-#: cp/call.c:9899
+#: cp/call.c:9919
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9910
+#: cp/call.c:9930
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9922
+#: cp/call.c:9942
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9939
+#: cp/call.c:9959
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9942
+#: cp/call.c:9962
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9952
+#: cp/call.c:9972
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "無法回合物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>"
 
-#: cp/call.c:9955
+#: cp/call.c:9975
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9958
+#: cp/call.c:9978
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9967
+#: cp/call.c:9987
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9989
+#: cp/call.c:10009
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qD 宣告的在此"
 
-#: cp/call.c:10089
+#: cp/call.c:10109
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "常數參考它自己"
 
-#: cp/call.c:10363 cp/typeck.c:9482
+#: cp/call.c:10383 cp/typeck.c:9489
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "無法轉換 %qT 到 %qT"
 
-#: cp/call.c:10385
+#: cp/call.c:10405
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "沒有匹配函式用於呼叫到 %<%T::運算子 %T(%A)%#V%>"
 
-#: cp/call.c:10417
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "對 %<%T::%s(%A)%#V%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:10464
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/call.c:10502 cp/pt.c:16264 cp/typeck.c:3162
+#: cp/call.c:10522 cp/pt.c:16347 cp/typeck.c:3173
 #, fuzzy, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "無法呼叫建構子 %<%T::%D%>直接"
 
-#: cp/call.c:10504
+#: cp/call.c:10524
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  用於 function-style 演員陣容，移除冗餘 %<::%D%>"
 
-#: cp/call.c:10696
+#: cp/call.c:10716
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:10699
+#: cp/call.c:10719
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "對多載的 %<%s(%A)%> 的呼叫有歧義"
 
-#: cp/call.c:10722
+#: cp/call.c:10742
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/call.c:10727
+#: cp/call.c:10747
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "建構式回傳值"
 
-#: cp/call.c:10728
+#: cp/call.c:10748
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "解構函式回傳值"
 
-#: cp/call.c:10751
+#: cp/call.c:10771
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "沒有物件無法呼叫成員函式 %qD"
 
-#: cp/call.c:11713
+#: cp/call.c:11734
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "傳遞 %qT 時選擇 %qT 而不是 %qT"
 
-#: cp/call.c:11782
+#: cp/call.c:11803
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "選擇 %qD 而不是 %qD"
 
-#: cp/call.c:11783
+#: cp/call.c:11804
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  當從 %qT 轉換為 %qT 時"
 
-#: cp/call.c:11786
+#: cp/call.c:11807
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  因為前者的引數類型轉換序列更好"
 
-#: cp/call.c:12036
+#: cp/call.c:12057
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "預設引數不匹配在中過載解析度"
 
-#: cp/call.c:12040
+#: cp/call.c:12061
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidate 1:%q+#F"
 
-#: cp/call.c:12042
+#: cp/call.c:12063
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidate 2:%q+#F"
 
-#: cp/call.c:12088
+#: cp/call.c:12109
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 認為有歧義，盡管第一個備選的最差類型轉換要好於第二個備選的最差類型轉換"
 
-#: cp/call.c:12475
+#: cp/call.c:12496
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暫時的約束到 %qD 只有持續直到建構子離開"
 
-#: cp/call.c:12630
+#: cp/call.c:12651
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.c:12634
+#: cp/call.c:12655
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -48270,1175 +48303,1175 @@ msgstr "無法從基礎類別 %qT 轉換到衍生類別 %qT，透過虛基礎類
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
 msgstr "無法從基礎類別 %qT 轉換到衍生類別 %qT，透過虛基礎類別 %qT"
 
-#: cp/class.c:371
+#: cp/class.c:378
 #, fuzzy, gcc-internal-format
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "無法轉換 %qT 到 %qT 在中指派"
 
-#: cp/class.c:1184
+#: cp/class.c:1191
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "衝突與前一個宣告在此"
 
-#: cp/class.c:1187
+#: cp/class.c:1194
 #, fuzzy, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "衝突與前一個宣告在此"
 
-#: cp/class.c:1205
+#: cp/class.c:1212
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D 無法被多載"
 
-#: cp/class.c:1207 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
-#: cp/name-lookup.c:2735 cp/name-lookup.c:3061
+#: cp/class.c:1214 cp/decl.c:1744 cp/decl.c:1756 cp/decl.c:1781 cp/decl.c:1804
+#: cp/name-lookup.c:2736 cp/name-lookup.c:3062
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "前一個宣告 %q+#D"
 
-#: cp/class.c:1249
+#: cp/class.c:1256
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "方法 %q+D 的權限設定衝突，已忽略"
 
-#: cp/class.c:1252
+#: cp/class.c:1259
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "欄位 %qE 的權限設定衝突，已忽略"
 
-#: cp/class.c:1321
+#: cp/class.c:1328
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr " 因為局部方法 %q+#D 與之同名"
 
-#: cp/class.c:1325
+#: cp/class.c:1332
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local method %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:1331
+#: cp/class.c:1338
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr " 因為局部成員 %q+#D 與之同名"
 
-#: cp/class.c:1335
+#: cp/class.c:1342
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:1410
+#: cp/class.c:1417
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1413 cp/class.c:1420 cp/class.c:1427 cp/class.c:1439
+#: cp/class.c:1420 cp/class.c:1427 cp/class.c:1434 cp/class.c:1446
 #: cp/cvt.c:1100
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qD 宣告的在此"
 
-#: cp/class.c:1418
+#: cp/class.c:1425
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1425
+#: cp/class.c:1432
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1433
+#: cp/class.c:1440
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1744
+#: cp/class.c:1751
 #, fuzzy, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "無法衍生從 %<final%> 基底 %qT 在中衍生類型 %qT"
 
-#: cp/class.c:2218
+#: cp/class.c:2225
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "類別 %qT 中所有成員函式都是私有的"
 
-#: cp/class.c:2230
+#: cp/class.c:2237
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T 僅定義了一個私有解構函式且沒有夥伴"
 
-#: cp/class.c:2271
+#: cp/class.c:2278
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T 僅定義了一個私有建構式且沒有夥伴"
 
-#: cp/class.c:2275
+#: cp/class.c:2282
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2567
+#: cp/class.c:2574
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD 的最終多載在 %qT 中不唯一"
 
-#: cp/class.c:2929
+#: cp/class.c:2936
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D 無法被多載"
 
-#: cp/class.c:2932
+#: cp/class.c:2939
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D 標記的強制變更，但是不強制變更"
 
-#: cp/class.c:2947
+#: cp/class.c:2954
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D 標記的最後的，但是不是虛擬"
 
-#: cp/class.c:3010
+#: cp/class.c:3017
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D 被隱藏"
 
-#: cp/class.c:3011
+#: cp/class.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  為 %q+D"
 
-#: cp/class.c:3046
+#: cp/class.c:3053
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D 無效；匿名聯合只能有非靜態的資料成員"
 
-#: cp/class.c:3056 cp/parser.c:21822
+#: cp/class.c:3063 cp/parser.c:21859
 #, fuzzy, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "%<mwords-little-endian%> 被不宜用而將被  移除的在中未來釋出"
 
-#: cp/class.c:3252
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3444
+#: cp/class.c:3451
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "位元段 %q+#D 有非整數的類型"
 
-#: cp/class.c:3460
+#: cp/class.c:3467
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "位元段 %q+D 的寬度不是一個整數常數"
 
-#: cp/class.c:3465
+#: cp/class.c:3472
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "位元段 %q+D 寬度為負"
 
-#: cp/class.c:3470
+#: cp/class.c:3477
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "位元段 %q+D 寬度為 0"
 
-#: cp/class.c:3480
+#: cp/class.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D 的寬度超過了它的類型"
 
-#: cp/class.c:3486
+#: cp/class.c:3493
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D 太小而不能存放 %q#T 的所有可能值"
 
-#: cp/class.c:3547
+#: cp/class.c:3554
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "有建構式的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3550
+#: cp/class.c:3557
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "有解構函式的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3552
+#: cp/class.c:3559
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3556
+#: cp/class.c:3563
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/class.c:3672
+#: cp/class.c:3679
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D 不能是靜態的，因為它是聯合的成員"
 
-#: cp/class.c:3685
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:3698
+#: cp/class.c:3705
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "欄位 %q+D 無效地宣告為函式類型"
 
-#: cp/class.c:3704
+#: cp/class.c:3711
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/class.c:3775
+#: cp/class.c:3782
 #, fuzzy, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "忽略包裝的屬性因為解裝 non-POD 欄位 %q+#D"
 
-#: cp/class.c:3827
+#: cp/class.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/class.c:3830
+#: cp/class.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/class.c:3861
+#: cp/class.c:3868
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "初始化了聯合 %qT 中的多個欄位"
 
-#: cp/class.c:3863
+#: cp/class.c:3870
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:3906
+#: cp/class.c:3913
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "欄位 %q+#D 與類別同名"
 
-#: cp/class.c:3934
+#: cp/class.c:3941
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T 有指標資料成員"
 
-#: cp/class.c:3939
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  但沒有多載 %<%T(const %T&)%>"
 
-#: cp/class.c:3941
+#: cp/class.c:3948
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  或 %<operator=(const %T&)%>"
 
-#: cp/class.c:3945
+#: cp/class.c:3952
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  也沒有多載 %<operator=(const %T&)%>"
 
-#: cp/class.c:3947
+#: cp/class.c:3954
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:4404
+#: cp/class.c:4411
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4407
+#: cp/class.c:4414
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4735
+#: cp/class.c:4742
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "為非虛方法 %q+D 指定了初始值設定項"
 
-#: cp/class.c:4768
+#: cp/class.c:4775
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/class.c:5224
+#: cp/class.c:5231
 #, fuzzy, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "方法強制變更兩者 %<transaction_pure%> 和 %qE 方法"
 
-#: cp/class.c:5245
+#: cp/class.c:5252
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "方法宣告 %qE 強迫 %qE 方法"
 
-#: cp/class.c:5901 cp/constexpr.c:245
+#: cp/class.c:5908 cp/constexpr.c:246
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "封入類別的 constexpr 非靜態成員函式 %q+#D 並非實字型態"
 
-#: cp/class.c:5927
+#: cp/class.c:5934
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T 不是實字因為："
 
-#: cp/class.c:5930
+#: cp/class.c:5937
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5933
+#: cp/class.c:5940
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/class.c:5936
+#: cp/class.c:5943
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "運算式 %qE 不指定 constexpr 函式"
 
-#: cp/class.c:5944
+#: cp/class.c:5951
 #, fuzzy, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T 不是彙總，沒有 trivial 預設建構函式，而沒有任何 constexpr 建構子該並非複製或移動建構子"
 
-#: cp/class.c:5977
+#: cp/class.c:5984
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  基礎類別 %qT 的 %q+T 是 non-literal"
 
-#: cp/class.c:5992
+#: cp/class.c:5999
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:5999
+#: cp/class.c:6006
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:6120
+#: cp/class.c:6127
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基礎類別 %q#T 有一個非虛解構函式"
 
-#: cp/class.c:6149
+#: cp/class.c:6156
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "類別中有非靜態參照 %q+#D，卻沒有提供建構式"
 
-#: cp/class.c:6155
+#: cp/class.c:6162
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "類別中有非靜態常數成員 %q+#D 卻沒有建構式"
 
-#: cp/class.c:6474
+#: cp/class.c:6481
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，直接基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:6486
+#: cp/class.c:6493
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，虛基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:6736
+#: cp/class.c:6743
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D 的偏移量與 ABI 不相容，並且在 GCC 的未來版本中可能會有變化"
 
-#: cp/class.c:6915
+#: cp/class.c:6922
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "大小的陣列 %qE 太大"
 
-#: cp/class.c:7201
+#: cp/class.c:7208
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "無效的使用的 %<...%>與 non-slice"
 
-#: cp/class.c:7203
+#: cp/class.c:7210
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "對包含彈性陣列成員的結構的無效使用"
 
-#: cp/class.c:7208
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:7236
+#: cp/class.c:7243
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: cp/class.c:7238
+#: cp/class.c:7245
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "flexible 陣列成員在中否則清空結構"
 
-#: cp/class.c:7247 cp/class.c:7278
+#: cp/class.c:7254 cp/class.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T 重定義"
 
-#: cp/class.c:7255
+#: cp/class.c:7262
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: cp/class.c:7257
+#: cp/class.c:7264
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexible 陣列成員在中否則清空結構"
 
-#: cp/class.c:7276
+#: cp/class.c:7283
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:7390 cp/parser.c:25610
+#: cp/class.c:7397 cp/parser.c:25645
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T 重定義"
 
-#: cp/class.c:7527
+#: cp/class.c:7534
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T 有虛擬函式和可存取 non-virtual 解構式"
 
-#: cp/class.c:7555
+#: cp/class.c:7562
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "型態透明類別 %qT 沒有任何欄位"
 
-#: cp/class.c:7561
+#: cp/class.c:7568
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "型態透明類別 %qT 有基礎類別"
 
-#: cp/class.c:7565
+#: cp/class.c:7572
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "型態透明類別 %qT 有虛擬函式"
 
-#: cp/class.c:7571
+#: cp/class.c:7578
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7728
+#: cp/class.c:7735
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "定義的 %q#D 被標記 %<dllimport%>"
 
-#: cp/class.c:7739
+#: cp/class.c:7746
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "試圖完成結構，但為先前的解析錯誤所插斷"
 
-#: cp/class.c:8246
+#: cp/class.c:8253
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "語言字串 %<\"%E\"%> 不可識別"
 
-#: cp/class.c:8336
+#: cp/class.c:8343
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "無法解析多載函式 %qD，基於向類型 %qT 的轉換"
 
-#: cp/class.c:8494
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "沒有可將函式 %qD 轉換到類型 %q#T 的匹配項"
 
-#: cp/class.c:8521
+#: cp/class.c:8528
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "將多載函式 %qD 轉換為類型 %q#T 有歧義"
 
-#: cp/class.c:8548
+#: cp/class.c:8555
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成員指標 %qD"
 
-#: cp/class.c:8551
+#: cp/class.c:8558
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成員指標只能用 %<&%E%> 構成)"
 
-#: cp/class.c:8627 cp/class.c:8669
+#: cp/class.c:8634 cp/class.c:8676
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "類型資訊不充分"
 
-#: cp/class.c:8647
+#: cp/class.c:8654
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "無法將 %qE 從類型 %qT 轉換到類型 %qT"
 
-#: cp/class.c:8921
+#: cp/class.c:8928
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/class.c:8924
+#: cp/class.c:8931
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
 msgstr "在這裡又被宣告為 %q#D"
 
-#: cp/constexpr.c:106
+#: cp/constexpr.c:107
 #, fuzzy, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
 msgstr "型態 %qT 的 constexpr 變數 %qD 不是實字"
 
-#: cp/constexpr.c:117
+#: cp/constexpr.c:118
 #, fuzzy, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:129
+#: cp/constexpr.c:130
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type %qT"
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
 msgstr "參數不能具有可變類型 %qT"
 
-#: cp/constexpr.c:193
+#: cp/constexpr.c:194
 #, fuzzy, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/constexpr.c:206
+#: cp/constexpr.c:207
 #, fuzzy, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
 msgstr "無效的型態用於參數 %d 的 constexpr 函式 %q+#D"
 
-#: cp/constexpr.c:218
+#: cp/constexpr.c:219
 #, gcc-internal-format
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.c:229
+#: cp/constexpr.c:230
 #, fuzzy, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
 msgstr "無效的傳回類型 %qT 的 constexpr 函式 %q+D"
 
-#: cp/constexpr.c:256
+#: cp/constexpr.c:257
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T 有虛擬基礎類別"
 
-#: cp/constexpr.c:517
+#: cp/constexpr.c:518
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
 msgstr "constexpr 建構子沒有清空內文"
 
-#: cp/constexpr.c:780
+#: cp/constexpr.c:781
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%> 建構子用於聯合 %qT 必須初始化精確的一個非靜態資料成員"
 
-#: cp/constexpr.c:841
+#: cp/constexpr.c:842
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/constexpr.c:883
+#: cp/constexpr.c:884
 #, fuzzy, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
 msgstr "內文的 constexpr 函式 %qD 不是 return-statement"
 
-#: cp/constexpr.c:972
+#: cp/constexpr.c:973
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D 不是可用做為 constexpr 函式因為："
 
-#: cp/constexpr.c:1445 cp/constexpr.c:2747
+#: cp/constexpr.c:1446 cp/constexpr.c:2783
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "%<constexpr%> 無法用於類型宣告"
 
-#: cp/constexpr.c:1450 cp/constexpr.c:1460 cp/constexpr.c:2942
+#: cp/constexpr.c:1451 cp/constexpr.c:1461 cp/constexpr.c:2997
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E並非常數運算式"
 
-#: cp/constexpr.c:1735 cp/constexpr.c:7953
+#: cp/constexpr.c:1771 cp/constexpr.c:8016
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1826
 #, fuzzy, gcc-internal-format
 msgid "modifying a const object %qE is not allowed in a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:1792
+#: cp/constexpr.c:1828
 #, fuzzy, gcc-internal-format
 msgid "originally declared %<const%> here"
 msgstr "原本地定義的在此"
 
-#: cp/constexpr.c:2010 cp/constexpr.c:2065 cp/constexpr.c:2097
-#: cp/constexpr.c:2118
+#: cp/constexpr.c:2046 cp/constexpr.c:2101 cp/constexpr.c:2133
+#: cp/constexpr.c:2154
 #, gcc-internal-format
 msgid "reference %<dynamic_cast%> failed"
 msgstr ""
 
-#: cp/constexpr.c:2011
+#: cp/constexpr.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a base type for type %qT"
 msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "類型 %qT 不是類型 %qT 的基礎類別"
 
-#: cp/constexpr.c:2035
+#: cp/constexpr.c:2071
 #, fuzzy, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
 msgstr "變數 %D 的型態 %<io%> 必須被 uninitialized"
 
-#: cp/constexpr.c:2066 cp/constexpr.c:2098
+#: cp/constexpr.c:2102 cp/constexpr.c:2134
 #, gcc-internal-format
 msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2120
+#: cp/constexpr.c:2156
 #, fuzzy, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
 msgstr "  %qT 是模稜兩可的基礎類別的 %qT"
 
-#: cp/constexpr.c:2123
+#: cp/constexpr.c:2159
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.c:2198 cp/constexpr.c:2467 cp/constexpr.c:7985
+#: cp/constexpr.c:2234 cp/constexpr.c:2503 cp/constexpr.c:8048
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "呼叫到 non-constexpr 函式 %qD"
 
-#: cp/constexpr.c:2315
+#: cp/constexpr.c:2351
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "運算式 %qE 不指定 constexpr 函式"
 
-#: cp/constexpr.c:2388
+#: cp/constexpr.c:2424
 #, gcc-internal-format
 msgid "array deallocation of object allocated with non-array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2392 cp/constexpr.c:2414
+#: cp/constexpr.c:2428 cp/constexpr.c:2450
 #, fuzzy, gcc-internal-format
 msgid "allocation performed here"
 msgstr "宣告的在此"
 
-#: cp/constexpr.c:2410
+#: cp/constexpr.c:2446
 #, gcc-internal-format
 msgid "non-array deallocation of object allocated with array allocation"
 msgstr ""
 
-#: cp/constexpr.c:2427
+#: cp/constexpr.c:2463
 #, fuzzy, gcc-internal-format
 msgid "deallocation of already deallocated storage"
 msgstr "試圖配置已經配置的變數"
 
-#: cp/constexpr.c:2434
+#: cp/constexpr.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a previous local"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "%qD 的宣告隱藏了先前的一個局部變數"
 
-#: cp/constexpr.c:2541
+#: cp/constexpr.c:2577
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD called 在中常數運算式"
 
-#: cp/constexpr.c:2548
+#: cp/constexpr.c:2584
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD called 在中常數運算式"
 
-#: cp/constexpr.c:2552
+#: cp/constexpr.c:2588
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD 使用的之前它的定義"
 
-#: cp/constexpr.c:2643
+#: cp/constexpr.c:2679
 #, fuzzy, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "呼叫有環狀依存性"
 
-#: cp/constexpr.c:2654
+#: cp/constexpr.c:2690
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:2982
+#: cp/constexpr.c:3037
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "右移次數為負"
 
-#: cp/constexpr.c:2989
+#: cp/constexpr.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "右移次數為負"
 
-#: cp/constexpr.c:3012
+#: cp/constexpr.c:3067
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "逗號運算式的左運算元不起作用"
 
-#: cp/constexpr.c:3031
+#: cp/constexpr.c:3086
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/constexpr.c:3189
+#: cp/constexpr.c:3244
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3578
+#: cp/constexpr.c:3633
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:3581
+#: cp/constexpr.c:3636
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:3586
+#: cp/constexpr.c:3641
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3644
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:3772
+#: cp/constexpr.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:3820
+#: cp/constexpr.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提領 %<void *%> 指標"
 
-#: cp/constexpr.c:3837 cp/constexpr.c:3936 cp/constexpr.c:6051
-#: cp/constexpr.c:6148 cp/constexpr.c:7905
+#: cp/constexpr.c:3892 cp/constexpr.c:3991 cp/constexpr.c:6114
+#: cp/constexpr.c:6211 cp/constexpr.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:3843
+#: cp/constexpr.c:3898
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "可變的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:3874 cp/constexpr.c:3896
+#: cp/constexpr.c:3929 cp/constexpr.c:3951
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:3876
+#: cp/constexpr.c:3931
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "存取 %qD 成員以代替初始化的 %qD 成員在中常數運算式"
 
-#: cp/constexpr.c:4007
+#: cp/constexpr.c:4062
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4010
+#: cp/constexpr.c:4065
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4021
+#: cp/constexpr.c:4076
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4024
+#: cp/constexpr.c:4079
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4035
+#: cp/constexpr.c:4090
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4038
+#: cp/constexpr.c:4093
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4049
+#: cp/constexpr.c:4104
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4053
+#: cp/constexpr.c:4108
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4064
+#: cp/constexpr.c:4119
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:4067
+#: cp/constexpr.c:4122
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:4108
+#: cp/constexpr.c:4163
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "巢狀的函式不支援於這個目標"
 
-#: cp/constexpr.c:4117 cp/constexpr.c:4127
+#: cp/constexpr.c:4172 cp/constexpr.c:4182
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.c:4147
+#: cp/constexpr.c:4202
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:4171
+#: cp/constexpr.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:4183
+#: cp/constexpr.c:4238
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:4906 cp/constexpr.c:6718
+#: cp/constexpr.c:4961 cp/constexpr.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "提領 %<void *%> 指標"
 
-#: cp/constexpr.c:4926
+#: cp/constexpr.c:4981
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "存取值的 %qE 透過 %qT glvalue 在中常數運算式"
 
-#: cp/constexpr.c:4971
+#: cp/constexpr.c:5026
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:4973 cp/constexpr.c:4980
+#: cp/constexpr.c:5028 cp/constexpr.c:5035
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "宣告的在此"
 
-#: cp/constexpr.c:4978
+#: cp/constexpr.c:5033
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "使用的值的物件被建構在中常數運算式"
 
-#: cp/constexpr.c:4983
+#: cp/constexpr.c:5038
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:4990
+#: cp/constexpr.c:5045
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD 已用於它的本身初始設定式"
 
-#: cp/constexpr.c:4995
+#: cp/constexpr.c:5050
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D 不是常數"
 
-#: cp/constexpr.c:4998
+#: cp/constexpr.c:5053
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D 是易變的"
 
-#: cp/constexpr.c:5003 cp/constexpr.c:5010
+#: cp/constexpr.c:5058 cp/constexpr.c:5065
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD 未被初始化的與常數運算式"
 
-#: cp/constexpr.c:5016
+#: cp/constexpr.c:5071
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD 未被宣告 %<constexpr%>"
 
-#: cp/constexpr.c:5019
+#: cp/constexpr.c:5074
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/constexpr.c:5265
+#: cp/constexpr.c:5320
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:5334
+#: cp/constexpr.c:5389
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:5347
+#: cp/constexpr.c:5402
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/constexpr.c:5739 cp/constexpr.c:6976
+#: cp/constexpr.c:5802 cp/constexpr.c:7039
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:5845
+#: cp/constexpr.c:5908
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:5947
+#: cp/constexpr.c:6010
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:5948
+#: cp/constexpr.c:6011
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.c:6013
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:6026
+#: cp/constexpr.c:6089
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:6208 cp/constexpr.c:8583
+#: cp/constexpr.c:6271 cp/constexpr.c:8646
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:6636 cp/constexpr.c:8110
+#: cp/constexpr.c:6699 cp/constexpr.c:8173
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:6664
+#: cp/constexpr.c:6727
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "轉換從指標類型 %qT 到算術型式 %qT 在中 constant-expression"
 
-#: cp/constexpr.c:6693
+#: cp/constexpr.c:6756
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: cp/constexpr.c:6729
+#: cp/constexpr.c:6792
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:6834 cp/constexpr.c:8409 cp/constexpr.c:8787
+#: cp/constexpr.c:6897 cp/constexpr.c:8472 cp/constexpr.c:8850
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:6929
+#: cp/constexpr.c:6992
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "預期 template-id"
 
-#: cp/constexpr.c:6935
+#: cp/constexpr.c:6998
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "內建函式 %qD 需一個引數只有"
 
-#: cp/constexpr.c:6960
+#: cp/constexpr.c:7023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/constexpr.c:6979
+#: cp/constexpr.c:7042
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "未預期的運算式 %qE 的 kind %s"
 
-#: cp/constexpr.c:7209
+#: cp/constexpr.c:7272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:7217
+#: cp/constexpr.c:7280
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:7232
+#: cp/constexpr.c:7295
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:7243
+#: cp/constexpr.c:7306
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:7265
+#: cp/constexpr.c:7328
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:7845
+#: cp/constexpr.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "從具有類型 %qT 的右值運算式到類型 %qT 中的轉換無效"
 
-#: cp/constexpr.c:8075
+#: cp/constexpr.c:8138
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:8078
+#: cp/constexpr.c:8141
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:8130
+#: cp/constexpr.c:8193
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/constexpr.c:8163
+#: cp/constexpr.c:8226
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 物件 %qE 與執行緒本地或自動貯藏體並非常數運算式"
 
-#: cp/constexpr.c:8202
+#: cp/constexpr.c:8265
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:8356
+#: cp/constexpr.c:8419
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:8423
+#: cp/constexpr.c:8486
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "虛函式不能是夥伴"
 
-#: cp/constexpr.c:8438
+#: cp/constexpr.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:8502
+#: cp/constexpr.c:8565
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:8552
+#: cp/constexpr.c:8615
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.c:8559
+#: cp/constexpr.c:8622
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.c:8632
+#: cp/constexpr.c:8695
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "除法由零並非 constant-expression"
 
-#: cp/constexpr.c:8728
+#: cp/constexpr.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:8795
+#: cp/constexpr.c:8858
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "non-constant 陣列初始化"
 
-#: cp/constexpr.c:8825
+#: cp/constexpr.c:8888
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:8834
+#: cp/constexpr.c:8897
 #, fuzzy, gcc-internal-format
 msgid "label definition is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:8853
+#: cp/constexpr.c:8916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "未預期的 AST 的 kind %s"
@@ -49448,52 +49481,52 @@ msgstr "未預期的 AST 的 kind %s"
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1325
+#: cp/cp-gimplify.c:1333
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "位址的 %qD 將一律評估做為 %<true%>"
 
-#: cp/cp-gimplify.c:1328
+#: cp/cp-gimplify.c:1336
 #, fuzzy, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/cp-gimplify.c:1340
+#: cp/cp-gimplify.c:1348
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2793
+#: cp/cp-gimplify.c:2773
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/cp-gimplify.c:2815 cp/cp-gimplify.c:2827 cp/decl.c:4066 cp/method.c:978
+#: cp/cp-gimplify.c:2795 cp/cp-gimplify.c:2807 cp/decl.c:4048 cp/method.c:978
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD 並非型態"
 
-#: cp/cp-gimplify.c:2833
+#: cp/cp-gimplify.c:2813
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qT 並非類別型態"
 
-#: cp/cp-gimplify.c:2850
+#: cp/cp-gimplify.c:2830
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/cp-gimplify.c:2861
+#: cp/cp-gimplify.c:2841
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/cp-gimplify.c:2873
+#: cp/cp-gimplify.c:2853
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2977
+#: cp/cp-gimplify.c:2957
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -49542,7 +49575,7 @@ msgstr "轉換到 non-const 參考類型 %q#T 從 rvalue 的型態 %qT"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: cp/cvt.c:498 cp/typeck.c:7969
+#: cp/cvt.c:498 cp/typeck.c:7976
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "從 %qT 轉換到 %qT 並未提領指標"
@@ -49934,7 +49967,7 @@ msgstr "從先前的宣告 %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/decl.c:1303 cp/decl.c:15319
+#: cp/decl.c:1303 cp/decl.c:15337
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -50080,8 +50113,8 @@ msgstr "先前對於 %q+#D 的非函式宣告"
 msgid "%q#D previously defined here"
 msgstr "%q+#D 已在此定義過"
 
-#: cp/decl.c:1901 cp/name-lookup.c:3187 cp/name-lookup.c:3216
-#: cp/name-lookup.c:3240
+#: cp/decl.c:1901 cp/name-lookup.c:3188 cp/name-lookup.c:3217
+#: cp/name-lookup.c:3241
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
@@ -50121,59 +50154,59 @@ msgstr "為參數 %d (屬於 %q#D)指定了預設引數"
 msgid "previous specification in %q#D here"
 msgstr "但先前在 %q+#D 中已有指定"
 
-#: cp/decl.c:2047
+#: cp/decl.c:2045
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration %qD conflicts with builtin"
 msgstr "與內建宣告 %q#D 衝突"
 
-#: cp/decl.c:2055
+#: cp/decl.c:2053
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of namespace %qD conflicts with"
 msgid "declaration %qD conflicts with import"
 msgstr "命名空間 %qD 的宣告存在衝突，與"
 
-#: cp/decl.c:2056
+#: cp/decl.c:2054
 #, fuzzy, gcc-internal-format
 msgid "import declared %q#D here"
 msgstr "%qD 宣告的在此"
 
-#: cp/decl.c:2064
+#: cp/decl.c:2062
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting declaration %qD"
 msgstr "相互衝突的宣告 %q#D"
 
-#: cp/decl.c:2065
+#: cp/decl.c:2063
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %q#D here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
 
-#: cp/decl.c:2090
+#: cp/decl.c:2088
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "%q+D 的上一個定義在此"
 
-#: cp/decl.c:2091
+#: cp/decl.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "%q+D 的上一個宣告在此"
 
-#: cp/decl.c:2104
+#: cp/decl.c:2102
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.c:2149
+#: cp/decl.c:2147
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "同一作用欄位中 %qD 冗餘的重宣告"
 
-#: cp/decl.c:2166
+#: cp/decl.c:2164
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "刪除的定義的 %qD"
@@ -50186,48 +50219,48 @@ msgstr "刪除的定義的 %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2640
+#: cp/decl.c:2635
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "在初次使用後明確特例化 %qD"
 
-#: cp/decl.c:2779
+#: cp/decl.c:2774
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "『setter』屬性的內容 %qD 衝突與前一個宣告"
 
 #. Reject two definitions.
-#: cp/decl.c:3052 cp/decl.c:3081 cp/decl.c:3123 cp/decl.c:3140 cp/decl.c:3243
+#: cp/decl.c:3034 cp/decl.c:3063 cp/decl.c:3105 cp/decl.c:3122 cp/decl.c:3225
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "重複定義的 %q#D"
 
-#: cp/decl.c:3068
+#: cp/decl.c:3050
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD 衝突與使用的函式"
 
-#: cp/decl.c:3078
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D 無法宣告的在中類別"
 
-#: cp/decl.c:3092 cp/decl.c:3150
+#: cp/decl.c:3074 cp/decl.c:3132
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D redeclared 內聯與 %<gnu_inline%> 屬性"
 
-#: cp/decl.c:3095 cp/decl.c:3153
+#: cp/decl.c:3077 cp/decl.c:3135
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D redeclared 內聯而無需 %<gnu_inline%> 屬性"
 
-#: cp/decl.c:3102 cp/decl.c:3160
+#: cp/decl.c:3084 cp/decl.c:3142
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %q+D redeclared"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.c:3109
+#: cp/decl.c:3091
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -50235,2393 +50268,2409 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3174
+#: cp/decl.c:3156
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "重新宣告的朋友 %q#D 可能無法有預設模板引數"
 
-#: cp/decl.c:3189
+#: cp/decl.c:3171
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "thread-local 宣告的 %q#D 追隨 non-thread-local 宣告"
 
-#: cp/decl.c:3192
+#: cp/decl.c:3174
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "non-thread-local 宣告的 %q#D 追隨 thread-local 宣告"
 
-#: cp/decl.c:3207 cp/decl.c:3251 cp/name-lookup.c:2730 cp/name-lookup.c:3214
-#: cp/name-lookup.c:3238
+#: cp/decl.c:3189 cp/decl.c:3233 cp/name-lookup.c:2731 cp/name-lookup.c:3215
+#: cp/name-lookup.c:3239
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "重新宣告的 %q#D"
 
-#: cp/decl.c:3234
+#: cp/decl.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "同一作用欄位中 %qD 冗餘的重宣告"
 
-#: cp/decl.c:3300
+#: cp/decl.c:3282
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3301
+#: cp/decl.c:3283
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "前一個宣告"
 
-#: cp/decl.c:3395
+#: cp/decl.c:3377
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  從這裡"
 
-#: cp/decl.c:3418 cp/decl.c:3646
+#: cp/decl.c:3400 cp/decl.c:3628
 #, fuzzy, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  離開 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3446
+#: cp/decl.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  略過 %q+#D 的初始化"
 
-#: cp/decl.c:3449
+#: cp/decl.c:3431
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  輸入範圍的 %q+#D 該項有 non-trivial 解構式"
 
-#: cp/decl.c:3463 cp/decl.c:3617
+#: cp/decl.c:3445 cp/decl.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  進入 try 區塊"
 
-#: cp/decl.c:3469 cp/decl.c:3599 cp/decl.c:3619
+#: cp/decl.c:3451 cp/decl.c:3581 cp/decl.c:3601
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  進入 catch 區塊"
 
-#: cp/decl.c:3475 cp/decl.c:3629
+#: cp/decl.c:3457 cp/decl.c:3611
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  輸入 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3481 cp/decl.c:3621
+#: cp/decl.c:3463 cp/decl.c:3603
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3488 cp/decl.c:3623
+#: cp/decl.c:3470 cp/decl.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "需要敘述"
 
-#: cp/decl.c:3606
+#: cp/decl.c:3588
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  略過 %q+#D 的初始化"
 
-#: cp/decl.c:3609
+#: cp/decl.c:3591
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  輸入範圍的 %q+#D 該項有 non-trivial 解構式"
 
-#: cp/decl.c:4073 cp/parser.c:6807
+#: cp/decl.c:4055 cp/parser.c:6807
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD 使用時未帶範本參數"
 
-#: cp/decl.c:4084
+#: cp/decl.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is not a function template"
+msgid "%qD is a function, not a type"
+msgstr "%qD 不是一個函式範本"
+
+#: cp/decl.c:4072
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T 並非類別"
 
-#: cp/decl.c:4112 cp/decl.c:4198
+#: cp/decl.c:4100 cp/decl.c:4186
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類別範本，在%q#T 中 "
 
-#: cp/decl.c:4113
+#: cp/decl.c:4101
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/decl.c:4126
+#: cp/decl.c:4114
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "查找的 %qT 在中 %qT 是模稜兩可的"
 
-#: cp/decl.c:4135
+#: cp/decl.c:4123
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非類別模板"
 
-#: cp/decl.c:4142
+#: cp/decl.c:4130
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非型態"
 
-#: cp/decl.c:4207
+#: cp/decl.c:4195
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "範本參數與範本不符"
 
-#: cp/decl.c:4543
+#: cp/decl.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "要求的對齊邊界不是 2 的某次方"
 
-#: cp/decl.c:5042
+#: cp/decl.c:5038
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有建構式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.c:5045
+#: cp/decl.c:5041
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有構構函式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5044
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/decl.c:5067
+#: cp/decl.c:5063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:5070
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "屬性用於 %q#T 必須追隨 %qs 關鍵字"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5108
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一個宣告指定了多個類型"
 
-#: cp/decl.c:5117
+#: cp/decl.c:5113
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "對 C++ 內建類型 %qT 的重宣告"
 
-#: cp/decl.c:5134
+#: cp/decl.c:5130
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: cp/decl.c:5167
+#: cp/decl.c:5163
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 宣告中缺少類型名"
 
-#: cp/decl.c:5175
+#: cp/decl.c:5171
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允許匿名結構"
 
-#: cp/decl.c:5182
+#: cp/decl.c:5178
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.c:5185
+#: cp/decl.c:5181
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.c:5190
+#: cp/decl.c:5186
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> 只能在類別中指定"
 
-#: cp/decl.c:5193
+#: cp/decl.c:5189
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能為建構式指定 %<explicit%>"
 
-#: cp/decl.c:5196
+#: cp/decl.c:5192
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.c:5200
+#: cp/decl.c:5196
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:5204
+#: cp/decl.c:5200
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:5208
+#: cp/decl.c:5204
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:5212
+#: cp/decl.c:5208
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.c:5216
+#: cp/decl.c:5212
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> 被忽略在中這個宣告"
 
-#: cp/decl.c:5219 cp/decl.c:5222 cp/decl.c:5225
+#: cp/decl.c:5215 cp/decl.c:5218 cp/decl.c:5221
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> 無法用於類型宣告"
 
-#: cp/decl.c:5247
+#: cp/decl.c:5243
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/decl.c:5250
+#: cp/decl.c:5246
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/decl.c:5322
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略屬性套用到類別型態 %qT 外側的定義"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5326
+#: cp/decl.c:5322
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略屬性套用到附屬型態 %qT 而無需關聯的宣告"
 
-#: cp/decl.c:5390 cp/decl2.c:859
+#: cp/decl.c:5386 cp/decl2.c:859
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD 被初始化的 (使用 decltype 做為替代)"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5399
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D 宣告有 %<extern%> 並被初始化"
 
-#: cp/decl.c:5441
+#: cp/decl.c:5437
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "定義的 %q#D 被標記 %<dllimport%>"
 
-#: cp/decl.c:5465
+#: cp/decl.c:5461
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/decl.c:5473
+#: cp/decl.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D 宣告為範本"
 
-#: cp/decl.c:5474
+#: cp/decl.c:5470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "無效的成員範本宣告 %qD"
 
-#: cp/decl.c:5486
+#: cp/decl.c:5482
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允許將 %<%T::%D%> 定義為 %<%T::%D%>"
 
-#: cp/decl.c:5498
+#: cp/decl.c:5494
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允許成員 %qD 的初始化"
 
-#: cp/decl.c:5546
+#: cp/decl.c:5542
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出現在類別外的 %q#D 的宣告不是定義"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5559
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgstr ""
 
-#: cp/decl.c:5598
+#: cp/decl.c:5594
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:5603
+#: cp/decl.c:5599
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
 
-#: cp/decl.c:5675
+#: cp/decl.c:5671
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "變數 %q#D 有初始值設定，但是類型不完全"
 
-#: cp/decl.c:5681 cp/decl.c:6834
+#: cp/decl.c:5677 cp/decl.c:6830
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "陣列 %q#D 的元素類型不完全"
 
-#: cp/decl.c:5691
+#: cp/decl.c:5687
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合 %q#D 類型不完全，無法被定義"
 
-#: cp/decl.c:5758
+#: cp/decl.c:5754
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD 宣告為參照卻未被初始化"
 
-#: cp/decl.c:5841
+#: cp/decl.c:5837
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名稱已用於 GNU-style 指定的初始設定式用於陣列"
 
-#: cp/decl.c:5847
+#: cp/decl.c:5843
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名稱 %qD 用在 GNU 風格的陣列指定元素初始值設定中"
 
-#: cp/decl.c:5866
+#: cp/decl.c:5862
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值設定不受支援"
 
-#: cp/decl.c:5870
+#: cp/decl.c:5866
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.c:5926
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值設定無法決定 %qD 的大小"
 
-#: cp/decl.c:5933
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD 缺少陣列大小"
 
-#: cp/decl.c:5945
+#: cp/decl.c:5941
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小為 0 的陣列 %qD"
 
-#: cp/decl.c:5985
+#: cp/decl.c:5981
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "貯藏大小的 %qD isn%'t 已知"
 
-#: cp/decl.c:6010
+#: cp/decl.c:6006
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "貯藏大小的 %qD isn%'t 常數"
 
-#: cp/decl.c:6061
+#: cp/decl.c:6057
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.c:6065
+#: cp/decl.c:6061
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.c:6071
+#: cp/decl.c:6067
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  您可以解決方法這個由移除初始設定式"
 
-#: cp/decl.c:6113
+#: cp/decl.c:6109
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "未初始化的常數 %qD"
 
-#: cp/decl.c:6120
+#: cp/decl.c:6116
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.c:6129
+#: cp/decl.c:6125
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.c:6137
+#: cp/decl.c:6133
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T 沒有任何 user-provided 預設建構函式"
 
-#: cp/decl.c:6141
+#: cp/decl.c:6137
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建構子未被 user-provided 因為它是明確的缺席在中類別本體"
 
-#: cp/decl.c:6144
+#: cp/decl.c:6140
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建構子不初始化 %q+#D"
 
-#: cp/decl.c:6312
+#: cp/decl.c:6308
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無效類型 %qT 做為類型為 %qT 的向量的初始化設定"
 
-#: cp/decl.c:6369
+#: cp/decl.c:6365
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT 的初始化設定必須在大括號內"
 
-#: cp/decl.c:6407
+#: cp/decl.c:6403
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E]=%>已用於 GNU-style 指定的初始設定式用於類別 %qT"
 
-#: cp/decl.c:6415
+#: cp/decl.c:6411
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/decl.c:6443
+#: cp/decl.c:6439
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/decl.c:6494
+#: cp/decl.c:6490
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示項 %qE 外側彙總初始設定式"
 
-#: cp/decl.c:6533 cp/decl.c:6793 cp/typeck2.c:1380 cp/typeck2.c:1694
-#: cp/typeck2.c:1742 cp/typeck2.c:1789
+#: cp/decl.c:6529 cp/decl.c:6789 cp/typeck2.c:1377 cp/typeck2.c:1691
+#: cp/typeck2.c:1739 cp/typeck2.c:1786
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT 的初始值設定項太多"
 
-#: cp/decl.c:6574
+#: cp/decl.c:6570
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.c:6584
+#: cp/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.c:6702
+#: cp/decl.c:6698
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT 的初始值設定周圍缺少大括號"
 
-#: cp/decl.c:6822
+#: cp/decl.c:6818
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "來源是指標到不完整型態"
 
-#: cp/decl.c:6836
+#: cp/decl.c:6832
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "元件的陣列 %q#T 有不完整型態"
 
-#: cp/decl.c:6849
+#: cp/decl.c:6845
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "variable-sized 複合實字"
 
-#: cp/decl.c:6904
+#: cp/decl.c:6900
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D 有不完整型態"
 
-#: cp/decl.c:6925
+#: cp/decl.c:6921
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "純量物件 %qD 需求一個元件在中初始設定式"
 
-#: cp/decl.c:6970
+#: cp/decl.c:6966
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在中 C++98 %qD 必須被初始化的由建構子，無法由 %<{...}%>"
 
-#: cp/decl.c:7102
+#: cp/decl.c:7098
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "陣列 %qD 被有括號的字面字串 %qE 所初始化"
 
-#: cp/decl.c:7137
+#: cp/decl.c:7133
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "建構式中對靜態成員的初始化無效"
 
-#: cp/decl.c:7139
+#: cp/decl.c:7135
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.c:7142
+#: cp/decl.c:7138
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.c:7147
+#: cp/decl.c:7143
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一個類別外的初始化)"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7328
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/decl.c:7590
+#: cp/decl.c:7586
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: cp/decl.c:7614
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "太少引數到建構子 %q#D"
 
-#: cp/decl.c:7619
+#: cp/decl.c:7615
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7620
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7629
+#: cp/decl.c:7625
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7634
+#: cp/decl.c:7630
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7684
+#: cp/decl.c:7680
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/decl.c:7702 cp/decl.c:14061
+#: cp/decl.c:7698 cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/decl.c:7706 cp/decl.c:14065
+#: cp/decl.c:7702 cp/decl.c:14083
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.c:7759
+#: cp/decl.c:7758
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "無效的使用的成員函式 (did 您忘記%<()%>?)"
 
-#: cp/decl.c:7867
+#: cp/decl.c:7866
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可變大小的物件不能被初始化"
 
-#: cp/decl.c:7926
+#: cp/decl.c:7925
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隱藏了早先的類型宣告 %q#D"
 
-#: cp/decl.c:7969
+#: cp/decl.c:7968
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE 屬性只有套用到變數和函式"
 
-#: cp/decl.c:8140
+#: cp/decl.c:8146
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函式 %q#D 像變數一樣被初始化"
 
-#: cp/decl.c:8246
+#: cp/decl.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  不能在 %q+D 使用過時的繫結，因為它有解構函式"
 
-#: cp/decl.c:8249
+#: cp/decl.c:8255
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:8256
+#: cp/decl.c:8262
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT 是 %qT 不可存取的基礎類別"
 
-#: cp/decl.c:8282
+#: cp/decl.c:8288
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8291
+#: cp/decl.c:8297
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8507
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "來源是指標到不完整型態"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8523
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: cp/decl.c:8526 cp/decl.c:8611
+#: cp/decl.c:8532 cp/decl.c:8617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs 指定的用於結構欄位"
 
-#: cp/decl.c:8530
+#: cp/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:8533
+#: cp/decl.c:8539
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:8578
+#: cp/decl.c:8584
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.c:8604
+#: cp/decl.c:8610
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.c:8613
+#: cp/decl.c:8619
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8634
+#: cp/decl.c:8640
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.c:8646
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.c:8663
+#: cp/decl.c:8675
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:8668
+#: cp/decl.c:8680
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/decl.c:8673
+#: cp/decl.c:8685
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "無法分解位址"
 
-#: cp/decl.c:8679
+#: cp/decl.c:8691
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "來源是的不完整類別型態"
 
-#: cp/decl.c:8688
+#: cp/decl.c:8700
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "無法套用 %<offsetof%> 到靜態資料成員 %qD"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9167
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:9158
+#: cp/decl.c:9170
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/decl.c:9163
+#: cp/decl.c:9175
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9400
+#: cp/decl.c:9412
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始設定式失敗到決定大小的 %qT"
 
-#: cp/decl.c:9404
+#: cp/decl.c:9416
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "陣列大小缺少的在中 %qT"
 
-#: cp/decl.c:9407
+#: cp/decl.c:9419
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "zero-size 陣列 %qT"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9435
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的解構函式不能做為成員"
 
-#: cp/decl.c:9425
+#: cp/decl.c:9437
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的建構式不能做為成員"
 
-#: cp/decl.c:9451
+#: cp/decl.c:9463
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD 宣告的做為 %<virtual%> 變數"
 
-#: cp/decl.c:9453
+#: cp/decl.c:9465
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中變數宣告"
 
-#: cp/decl.c:9459
+#: cp/decl.c:9471
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD 宣告的做為 %<virtual%> 參數"
 
-#: cp/decl.c:9462
+#: cp/decl.c:9474
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD 宣告的做為 %<inline%> 參數"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9476
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中參數宣告"
 
-#: cp/decl.c:9470
+#: cp/decl.c:9482
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD 宣告的做為 %<virtual%> 型態"
 
-#: cp/decl.c:9473
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD 宣告的做為 %<inline%> 型態"
 
-#: cp/decl.c:9475
+#: cp/decl.c:9487
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中類型宣告"
 
-#: cp/decl.c:9481
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD 宣告的做為 %<virtual%> 欄位"
 
-#: cp/decl.c:9484
+#: cp/decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD 宣告的做為 %<inline%> 欄位"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中欄位宣告"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9505
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:9500
+#: cp/decl.c:9512
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D 宣告時有異常指定"
 
-#: cp/decl.c:9532
+#: cp/decl.c:9544
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD 的定義不在包含 %qT 的命名空間中"
 
-#: cp/decl.c:9572
+#: cp/decl.c:9584
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "靜態成員函式 %q#D 的宣告帶有類型限定符"
 
-#: cp/decl.c:9583
+#: cp/decl.c:9595
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: cp/decl.c:9590
+#: cp/decl.c:9602
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "使舊的宣告 %q+#D 出現歧義"
 
-#: cp/decl.c:9593
+#: cp/decl.c:9605
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法 %qD 回傳非 Java 類型 %qT"
 
-#: cp/decl.c:9669
+#: cp/decl.c:9681
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/decl.c:9691
+#: cp/decl.c:9703
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:9701
+#: cp/decl.c:9713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD 不是一個範本函式"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9758
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在夥伴宣告中定義明確特例化 %qD"
 
-#: cp/decl.c:9757
+#: cp/decl.c:9769
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本範本的宣告中對範本識別碼 %qD 的使用無效"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9788
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "夥伴範本特例化 %qD 中不允許出現預設參數"
 
-#: cp/decl.c:9785
+#: cp/decl.c:9797
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> 不允許用於夥伴範本特例化 %qD 的宣告"
 
-#: cp/decl.c:9802
+#: cp/decl.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "出現在類別外的 %q#D 的宣告不是定義"
 
-#: cp/decl.c:9847
+#: cp/decl.c:9859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9862
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能將 %<::main%> 宣告為 inline"
 
-#: cp/decl.c:9853 cp/decl.c:9856
+#: cp/decl.c:9865 cp/decl.c:9868
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "不能將 %<::main%> 宣告為 static"
 
-#: cp/decl.c:9858
+#: cp/decl.c:9870
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能將 %<::main%> 宣告為 static"
 
-#: cp/decl.c:9920
+#: cp/decl.c:9932
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:9921
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:9929
+#: cp/decl.c:9941
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:9930
+#: cp/decl.c:9942
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9952
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9960
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.c:9968
+#: cp/decl.c:9980
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "實字運算子與 C 鏈結"
 
-#: cp/decl.c:9978
+#: cp/decl.c:9990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 有無效的引數清單"
 
-#: cp/decl.c:9986
+#: cp/decl.c:9998
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10004
 #, fuzzy, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "浮點數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.c:9999
+#: cp/decl.c:10011
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "實字運算子字尾無法前繼的由 %<_%>被保留的用於未來標準化"
 
-#: cp/decl.c:10004
+#: cp/decl.c:10016
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD 必須是 non-member 函式"
 
-#: cp/decl.c:10087
+#: cp/decl.c:10099
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> 必須回傳 %<int%>"
 
-#: cp/decl.c:10127
+#: cp/decl.c:10139
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隱含宣告的 %qD 的定義"
 
-#: cp/decl.c:10132
+#: cp/decl.c:10144
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "定義的 explicitly-defaulted %q+D"
 
-#: cp/decl.c:10134
+#: cp/decl.c:10146
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D 明確的缺席在此"
 
-#: cp/decl.c:10151
+#: cp/decl.c:10163
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成員函式 %q#D 未在類別 %qT 中宣告"
 
-#: cp/decl.c:10344
+#: cp/decl.c:10356
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.c:10353
+#: cp/decl.c:10365
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: cp/decl.c:10360
+#: cp/decl.c:10371
+#, fuzzy, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr "特殊化的 %qD 必須出現於命名空間範圍"
+
+#: cp/decl.c:10378
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:10363
+#: cp/decl.c:10381
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "可變大小的物件不能被初始化"
 
-#: cp/decl.c:10487
+#: cp/decl.c:10505
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的不完整型態"
 
-#: cp/decl.c:10491
+#: cp/decl.c:10509
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> 所需自 in-class 初始化的靜態資料成員 %q#D 的 non-integral 型態"
 
-#: cp/decl.c:10495
+#: cp/decl.c:10513
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的 non-literal 型態"
 
-#: cp/decl.c:10506
+#: cp/decl.c:10524
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "類別中對具有非整數類型 %qT 的靜態資料成員的初始化無效"
 
-#: cp/decl.c:10511
+#: cp/decl.c:10529
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允許在類別內初始化非常數靜態成員 %qD"
 
-#: cp/decl.c:10516
+#: cp/decl.c:10534
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允許初始化成員常數 %qD，因為它有非整數的類型 %qT"
 
-#: cp/decl.c:10627
+#: cp/decl.c:10645
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "陣列 %qD 的大小具有非整數類型 %qT"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/decl.c:10661 cp/decl.c:10733
+#: cp/decl.c:10679 cp/decl.c:10751
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.c:10665 cp/decl.c:10736
+#: cp/decl.c:10683 cp/decl.c:10754
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.c:10716
+#: cp/decl.c:10734
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.c:10719
+#: cp/decl.c:10737
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允許大小為 0 的陣列"
 
-#: cp/decl.c:10743
+#: cp/decl.c:10761
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++禁止變數長度陣列 %qD"
 
-#: cp/decl.c:10746
+#: cp/decl.c:10764
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++禁止變數長度陣列"
 
-#: cp/decl.c:10752
+#: cp/decl.c:10770
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "變數長度陣列 %qD 被使用"
 
-#: cp/decl.c:10755
+#: cp/decl.c:10773
 #, fuzzy, gcc-internal-format
 msgid "variable length array is used"
 msgstr "變數長度陣列被使用"
 
-#: cp/decl.c:10807
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "陣列維數溢出"
 
-#: cp/decl.c:10867
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:10869 cp/pt.c:15991
+#: cp/decl.c:10887 cp/pt.c:16074
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "產生 %qT 的陣列"
 
-#: cp/decl.c:10879
+#: cp/decl.c:10897
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "宣告的 %qD 做為陣列的虛值"
 
-#: cp/decl.c:10881
+#: cp/decl.c:10899
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "建立陣列的虛值"
 
-#: cp/decl.c:10886
+#: cp/decl.c:10904
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "宣告的 %qD 做為陣列的函式"
 
-#: cp/decl.c:10888
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "建立陣列的函式"
 
-#: cp/decl.c:10893
+#: cp/decl.c:10911
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "宣告的 %qD 做為陣列的參考"
 
-#: cp/decl.c:10895
+#: cp/decl.c:10913
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "建立陣列的參考"
 
-#: cp/decl.c:10900
+#: cp/decl.c:10918
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "宣告的 %qD 做為陣列的函式成員"
 
-#: cp/decl.c:10903
+#: cp/decl.c:10921
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "建立陣列的函式成員"
 
-#: cp/decl.c:10921
+#: cp/decl.c:10939
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.c:10925
+#: cp/decl.c:10943
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "宣告多維陣列必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.c:11007
+#: cp/decl.c:11025
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "為建構式指定回傳值無效"
 
-#: cp/decl.c:11010
+#: cp/decl.c:11028
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:11021
+#: cp/decl.c:11039
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.c:11024
+#: cp/decl.c:11042
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:11037
+#: cp/decl.c:11055
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "為 %<operator %T%> 指定了回傳值"
 
-#: cp/decl.c:11040
+#: cp/decl.c:11058
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11067
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.c:11052
+#: cp/decl.c:11070
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:11056
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD 宣告時範本參數表太多"
 
-#: cp/decl.c:11065
+#: cp/decl.c:11083
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "衝突說明符在中宣告的 %qs"
 
-#: cp/decl.c:11086
+#: cp/decl.c:11104
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名變數或欄位宣告為 void"
 
-#: cp/decl.c:11094
+#: cp/decl.c:11112
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "變數或欄位宣告為 void"
 
-#: cp/decl.c:11109
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.c:11114
+#: cp/decl.c:11132
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:11361
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "無效的使用的限定名稱 %<::%D%>"
 
-#: cp/decl.c:11364 cp/decl.c:11386
+#: cp/decl.c:11382 cp/decl.c:11404
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "無效的使用的限定名稱 %<%T::%D%>"
 
-#: cp/decl.c:11367
+#: cp/decl.c:11385
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "無效的使用的限定名稱 %<%D::%D%>"
 
-#: cp/decl.c:11377
+#: cp/decl.c:11395
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11419
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.c:11408
+#: cp/decl.c:11426
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "%qD 未宣告為成員"
 
-#: cp/decl.c:11436
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少宣告識別碼：使用了保留字 %qD"
 
-#: cp/decl.c:11487
+#: cp/decl.c:11505
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函式定義不宣告參數"
 
-#: cp/decl.c:11495 cp/decl.c:11504 cp/decl.c:13312
+#: cp/decl.c:11513 cp/decl.c:11522 cp/decl.c:13330
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.c:11512
+#: cp/decl.c:11530
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "宣告的 %qD 做為 %<typedef%>"
 
-#: cp/decl.c:11517
+#: cp/decl.c:11535
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "宣告的 %qD 做為參數"
 
-#: cp/decl.c:11552
+#: cp/decl.c:11570
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "未指定類別"
 
-#: cp/decl.c:11559 cp/decl.c:11566 cp/decl.c:11573 cp/decl.c:11580
+#: cp/decl.c:11577 cp/decl.c:11584 cp/decl.c:11591 cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%> 無法出現在中 typedef 宣告"
 
-#: cp/decl.c:11591
+#: cp/decl.c:11609
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.c:11601
+#: cp/decl.c:11619
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs 的宣告指定了兩個以上的資料類型"
 
-#: cp/decl.c:11609
+#: cp/decl.c:11627
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "衝突說明符在中宣告的 %qs"
 
-#: cp/decl.c:11656
+#: cp/decl.c:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.c:11705 cp/decl.c:11709 cp/decl.c:11712
+#: cp/decl.c:11723 cp/decl.c:11727 cp/decl.c:11730
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允許宣告無類型的 %qs"
 
-#: cp/decl.c:11729
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int128%>未被支援由這個目標"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11755
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++不支援 %<__int128%>用於 %qs"
 
-#: cp/decl.c:11791
+#: cp/decl.c:11809
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> 和 %<unsigned%>指定的一起用於 %qs"
 
-#: cp/decl.c:11797
+#: cp/decl.c:11815
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> 和 %<short%>指定的一起用於 %qs"
 
-#: cp/decl.c:11805 cp/decl.c:11811
+#: cp/decl.c:11823 cp/decl.c:11829
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qT"
 msgstr "%qs 沒有指定類別名"
 
-#: cp/decl.c:11816
+#: cp/decl.c:11834
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/decl.c:11818
+#: cp/decl.c:11836
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: cp/decl.c:11885
+#: cp/decl.c:11903
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "對 %qs 而言無效的複數"
 
-#: cp/decl.c:11924
+#: cp/decl.c:11942
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:11945
+#: cp/decl.c:11963
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.c:11954
+#: cp/decl.c:11972
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.c:11967
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "參數宣告中出現的 typedef 宣告無效"
 
-#: cp/decl.c:11974
+#: cp/decl.c:11992
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "貯藏類別指定的用於模板參數 %qs"
 
-#: cp/decl.c:11984 cp/decl.c:12156
+#: cp/decl.c:12002 cp/decl.c:12174
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "為參數 %qs 指定了存儲類別"
 
-#: cp/decl.c:11992 cp/decl.c:12001 cp/decl.c:12007 cp/decl.c:12013
+#: cp/decl.c:12010 cp/decl.c:12019 cp/decl.c:12025 cp/decl.c:12031
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.c:12023
+#: cp/decl.c:12041
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.c:12033 cp/decl.c:12036 cp/decl.c:12038 cp/decl.c:12041
-#: cp/decl.c:12051 cp/decl.c:12061 cp/decl.c:12071 cp/decl.c:12075
+#: cp/decl.c:12051 cp/decl.c:12054 cp/decl.c:12056 cp/decl.c:12059
+#: cp/decl.c:12069 cp/decl.c:12079 cp/decl.c:12089 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:12045 cp/decl.c:12067
+#: cp/decl.c:12063 cp/decl.c:12085
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12073
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "無效的輸入宣告"
 
-#: cp/decl.c:12079
+#: cp/decl.c:12097
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12090
+#: cp/decl.c:12108
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:12093
+#: cp/decl.c:12111
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12128
+#: cp/decl.c:12146
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.c:12154
+#: cp/decl.c:12172
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.c:12168
+#: cp/decl.c:12186
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "巢狀函式 %qs 被宣告為 %<extern%>"
 
-#: cp/decl.c:12173
+#: cp/decl.c:12191
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在頂層將 %qs 宣告為 %<auto%>"
 
-#: cp/decl.c:12181
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函式作用欄位的 %qs 隱含為 auto，卻被宣告為 %<__thread%>"
 
-#: cp/decl.c:12195
+#: cp/decl.c:12213
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "為夥伴函式宣告指定了無效的存儲類別"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12244
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "%qE 屬性被忽略"
 
-#: cp/decl.c:12227
+#: cp/decl.c:12245
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:12285
+#: cp/decl.c:12303
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12309
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "需要左圓括號"
 
-#: cp/decl.c:12340
+#: cp/decl.c:12358
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12360
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs 函式使用 %<auto%> 型態說明符而無需尾隨傳回類型"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12382
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:12369
+#: cp/decl.c:12387
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:12376
+#: cp/decl.c:12394
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.c:12385
+#: cp/decl.c:12403
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.c:12390
+#: cp/decl.c:12408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "無效的使用的 %<auto%>"
 
-#: cp/decl.c:12401
+#: cp/decl.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/decl.c:12410
+#: cp/decl.c:12428
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12441
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12437
+#: cp/decl.c:12455
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:12440
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs 函式與尾隨傳回類型無法宣告的與 %<auto%> 型態說明符"
 
-#: cp/decl.c:12464
+#: cp/decl.c:12482
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12476
+#: cp/decl.c:12494
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs 宣告為回傳一個函式的函式"
 
-#: cp/decl.c:12482
+#: cp/decl.c:12500
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs 宣告為回傳一個陣列的函式"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12507
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> 函式回傳了一個非 void 的回傳值"
 
-#: cp/decl.c:12500 cp/pt.c:29580
+#: cp/decl.c:12518 cp/pt.c:29643
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12506 cp/pt.c:29586
+#: cp/decl.c:12524 cp/pt.c:29649
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:12538
+#: cp/decl.c:12556
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "解構函式不能是靜態成員函式"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12558
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.c:12545
+#: cp/decl.c:12563
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.c:12554
+#: cp/decl.c:12572
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:12555
+#: cp/decl.c:12573
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.c:12573
+#: cp/decl.c:12591
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "建構式不能被宣告為虛函式"
 
-#: cp/decl.c:12590
+#: cp/decl.c:12608
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:12595
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "夥伴宣告不在類別定義內"
 
-#: cp/decl.c:12599
+#: cp/decl.c:12617
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "can%'t 定義朋友函式 %qs 在中區域類別定義"
 
-#: cp/decl.c:12609
+#: cp/decl.c:12627
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12613
+#: cp/decl.c:12631
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12626
+#: cp/decl.c:12644
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs 函式無法有引數"
 
-#: cp/decl.c:12653
+#: cp/decl.c:12671
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "解構函式不能有參數"
 
-#: cp/decl.c:12693
+#: cp/decl.c:12711
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.c:12706 cp/decl.c:12713
+#: cp/decl.c:12724 cp/decl.c:12731
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/decl.c:12715
+#: cp/decl.c:12733
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "無法宣告參照 %q#T 成員的指標"
 
-#: cp/decl.c:12744
+#: cp/decl.c:12762
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:12745
+#: cp/decl.c:12763
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:12818
+#: cp/decl.c:12836
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "無法宣告參考到 %q#T, 該項並非 typedef 或模板型態引數"
 
-#: cp/decl.c:12889
+#: cp/decl.c:12907
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "範本識別碼 %qD 做為宣告"
 
-#: cp/decl.c:12915
+#: cp/decl.c:12933
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成員函式隱含地成為所屬類別的夥伴"
 
-#: cp/decl.c:12920
+#: cp/decl.c:12938
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多餘的限定 %<%T::%> 於成員 %qs 上"
 
-#: cp/decl.c:12950
+#: cp/decl.c:12968
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "無法定義成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:12952
+#: cp/decl.c:12970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "無法宣告成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:12960
+#: cp/decl.c:12978
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "無法宣告成員 %<%T::%s%> 於 %qT 之內"
 
-#: cp/decl.c:13000
+#: cp/decl.c:13018
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "non-parameter %qs 無法參數包裝"
 
-#: cp/decl.c:13009
+#: cp/decl.c:13027
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "資料成員不能具有可變類型 %qT"
 
-#: cp/decl.c:13012
+#: cp/decl.c:13030
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "參數不能具有可變類型 %qT"
 
-#: cp/decl.c:13023
+#: cp/decl.c:13041
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.c:13026
+#: cp/decl.c:13044
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> 用於空宣告中"
 
-#: cp/decl.c:13029
+#: cp/decl.c:13047
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/decl.c:13039
+#: cp/decl.c:13057
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:13046
+#: cp/decl.c:13064
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非物件成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:13052
+#: cp/decl.c:13070
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函式 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:13058
+#: cp/decl.c:13076
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "靜態 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:13064
+#: cp/decl.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "常數 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:13070
+#: cp/decl.c:13088
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "參考 %qs 無法宣告 %<mutable%>"
 
-#: cp/decl.c:13086
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/decl.c:13089
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/decl.c:13115
+#: cp/decl.c:13133
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: cp/decl.c:13118
+#: cp/decl.c:13136
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef 宣告 %<auto%>"
 
-#: cp/decl.c:13123
+#: cp/decl.c:13141
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:13127
+#: cp/decl.c:13145
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名稱可能無法是 nested-name-specifier"
 
-#: cp/decl.c:13153
+#: cp/decl.c:13171
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允許嵌類別的類型 %qD 與其所屬的類別同名"
 
-#: cp/decl.c:13242
+#: cp/decl.c:13260
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "夥伴函式宣告中出現了 %<inline%>"
 
-#: cp/decl.c:13250
+#: cp/decl.c:13268
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "範本參數不能是夥伴"
 
-#: cp/decl.c:13252
+#: cp/decl.c:13270
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "夥伴宣告需要 class，即 %<friend class %T::%D%>"
 
-#: cp/decl.c:13256
+#: cp/decl.c:13274
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "夥伴宣告需要 class，即 %<friend %#T%>"
 
-#: cp/decl.c:13269
+#: cp/decl.c:13287
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "試圖讓 %qT 成為全域欄位的夥伴"
 
-#: cp/decl.c:13289
+#: cp/decl.c:13307
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成員函式類型上的限定符無效"
 
-#: cp/decl.c:13293
+#: cp/decl.c:13311
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:13303
+#: cp/decl.c:13321
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象宣告 %qT 做為宣告"
 
-#: cp/decl.c:13318
+#: cp/decl.c:13336
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.c:13337
+#: cp/decl.c:13355
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在參數宣告中使用 %<::%>"
 
-#: cp/decl.c:13346 cp/parser.c:19160
+#: cp/decl.c:13364 cp/parser.c:19197
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "不能將參數 %q+D 宣告為具有抽象類型 %qT"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13369
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "class template placeholder %qE not permitted in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/decl.c:13354
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "use %<auto%> for an abbreviated function template"
 msgstr "%qD 不是一個函式範本"
 
-#: cp/decl.c:13359
+#: cp/decl.c:13377
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13380
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "參數宣告 %<auto%>"
 
-#: cp/decl.c:13413 cp/parser.c:3429
+#: cp/decl.c:13431 cp/parser.c:3429
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用範本名 %qE 時不帶引數表無效"
 
-#: cp/decl.c:13417
+#: cp/decl.c:13435
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非靜態資料成員宣告 %<auto%>"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13456
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.c:13441
+#: cp/decl.c:13459
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 不允許彈性陣列成員"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13457
+#: cp/decl.c:13475
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "錯誤地使用了 %<::%>"
 
-#: cp/decl.c:13478
+#: cp/decl.c:13496
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "宣告的函式 %qD 在中無效的語境"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD 不能宣告為虛函式，因為它總是靜態的"
 
-#: cp/decl.c:13512
+#: cp/decl.c:13530
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在解構函式 %qD 中的夥伴宣告需要限定名"
 
-#: cp/decl.c:13519
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/decl.c:13526 cp/decl.c:13539
+#: cp/decl.c:13544 cp/decl.c:13557
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:13532
+#: cp/decl.c:13550
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13563
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "預期的限定名稱在中朋友宣告用於建構子 %qD"
 
-#: cp/decl.c:13554
+#: cp/decl.c:13572
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:13560
+#: cp/decl.c:13578
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.c:13568 cp/decl.c:13898
+#: cp/decl.c:13586 cp/decl.c:13916
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "無法開啟 %s"
 
-#: cp/decl.c:13577
+#: cp/decl.c:13595
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/decl.c:13580
+#: cp/decl.c:13598
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "原來的型態宣告的在此"
 
-#: cp/decl.c:13642
+#: cp/decl.c:13660
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "欄位 %qD 類型不完全"
 
-#: cp/decl.c:13647
+#: cp/decl.c:13665
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名稱 %qT 類型不完全"
 
-#: cp/decl.c:13667
+#: cp/decl.c:13685
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.c:13670
+#: cp/decl.c:13688
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.c:13723 cp/decl.c:13734
+#: cp/decl.c:13741 cp/decl.c:13752
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:13728
+#: cp/decl.c:13746
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "constexpr 靜態資料成員 %qD 必須有初始設定式"
 
-#: cp/decl.c:13762 cp/decl.c:13770 cp/decl.c:13777 cp/decl.c:13784
+#: cp/decl.c:13780 cp/decl.c:13788 cp/decl.c:13795 cp/decl.c:13802
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:13839
+#: cp/decl.c:13857
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<auto%> 無效"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13860
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<register%> 無效"
 
-#: cp/decl.c:13848
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:13852
+#: cp/decl.c:13870
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:13857
+#: cp/decl.c:13875
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specifiers 在中 %qs 不允許外側類別定義"
 
-#: cp/decl.c:13869
+#: cp/decl.c:13887
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<static%> 無效"
 
-#: cp/decl.c:13873
+#: cp/decl.c:13891
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.c:13881
+#: cp/decl.c:13899
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虛函式 %qs 不是類別成員"
 
-#: cp/decl.c:13888
+#: cp/decl.c:13906
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs 定義的在中 non-class 範圍"
 
-#: cp/decl.c:13889
+#: cp/decl.c:13907
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs 宣告的在中 non-class 範圍"
 
-#: cp/decl.c:13932
+#: cp/decl.c:13950
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能將成員函式 %qD 宣告為有靜態連結"
 
-#: cp/decl.c:13941
+#: cp/decl.c:13959
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一個函式中宣告一個靜態函式"
 
-#: cp/decl.c:13980
+#: cp/decl.c:13998
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "與宣告不同，定義靜態資料成員時不能使用 %<static%>"
 
-#: cp/decl.c:13987
+#: cp/decl.c:14005
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "靜態成員 %qD 宣告為 %<register%>"
 
-#: cp/decl.c:13993
+#: cp/decl.c:14011
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能明確地將成員 %q#D 宣告為有外部連結"
 
-#: cp/decl.c:14001
+#: cp/decl.c:14019
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "宣告的 constexpr 變數 %qD 並非定義"
 
-#: cp/decl.c:14008
+#: cp/decl.c:14026
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.c:14028
+#: cp/decl.c:14046
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "宣告的 %q#D 沒有任何初始設定式"
 
-#: cp/decl.c:14040
+#: cp/decl.c:14058
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs 已初始化，卻又被宣告為 %<extern%>"
 
-#: cp/decl.c:14045
+#: cp/decl.c:14063
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs 既有 %<extern%> 又有初始值設定"
 
-#: cp/decl.c:14217
+#: cp/decl.c:14235
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "預設引數 %qE 使用 %qD"
 
-#: cp/decl.c:14220
+#: cp/decl.c:14238
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "預設引數 %qE 使用了局部變數 %qD"
 
-#: cp/decl.c:14310
+#: cp/decl.c:14328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:14314
+#: cp/decl.c:14332
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:14336
+#: cp/decl.c:14354
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "無效的參數類型 %qT"
 
-#: cp/decl.c:14344
+#: cp/decl.c:14362
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/decl.c:14369
+#: cp/decl.c:14387
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "參數 %qD 包含指標到陣列的不明約束 %qT"
 
-#: cp/decl.c:14371
+#: cp/decl.c:14389
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "參數 %qD 包含參考到陣列的不明約束 %qT"
 
-#: cp/decl.c:14630
+#: cp/decl.c:14648
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "無效的建構式：您要的可能是 %<%T (const %T&)%>"
 
-#: cp/decl.c:14709
+#: cp/decl.c:14727
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/decl.c:14716
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD 不能被宣告為靜態的"
 
-#: cp/decl.c:14746
+#: cp/decl.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD 必須是一個非靜態的成員函式"
 
-#: cp/decl.c:14752
+#: cp/decl.c:14770
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD 必須是一個非靜態成員函式或非成員函式"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14780
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD 的引數必須有類別或列舉類型"
 
 #. 13.4.0.3
-#: cp/decl.c:14788
+#: cp/decl.c:14806
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ 不允許多載 ?: 運算子"
 
 #. Variadic.
-#: cp/decl.c:14799
+#: cp/decl.c:14817
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: cp/decl.c:14825
+#: cp/decl.c:14843
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD 必須帶 0 或 1 個引數"
 
-#: cp/decl.c:14826
+#: cp/decl.c:14844
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD 必須帶 1 或 2 個引數"
 
-#: cp/decl.c:14838
+#: cp/decl.c:14856
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的參數"
 
-#: cp/decl.c:14839
+#: cp/decl.c:14857
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的第二個參數"
 
-#: cp/decl.c:14850
+#: cp/decl.c:14868
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.c:14851 cp/decl.c:14861
+#: cp/decl.c:14869 cp/decl.c:14879
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD 帶且僅帶 1 個引數"
 
-#: cp/decl.c:14862
+#: cp/decl.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.c:14876
+#: cp/decl.c:14894
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD 不能有預設參數"
 
-#: cp/decl.c:14900
+#: cp/decl.c:14918
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "轉換到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.c:14907
+#: cp/decl.c:14925
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "轉換到參考到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:14909
+#: cp/decl.c:14927
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "轉換到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:14918
+#: cp/decl.c:14936
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "轉換到參考到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.c:14920
+#: cp/decl.c:14938
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "轉換到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.c:14936
+#: cp/decl.c:14954
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: cp/decl.c:14955
+#: cp/decl.c:14973
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "字首 %qD 應當回傳 %qT"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14980
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "字尾 %qD 應當回傳 %qT"
 
-#: cp/decl.c:14974
+#: cp/decl.c:14992
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD 應當回傳值而非參照"
 
-#: cp/decl.c:15029
+#: cp/decl.c:15047
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用範本類型參數 %qT，在 %qs 後"
 
-#: cp/decl.c:15052
+#: cp/decl.c:15070
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用別名模板特殊化 %qT 之後 %qs"
 
-#: cp/decl.c:15055
+#: cp/decl.c:15073
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名 %qD，在 %qs 後"
 
-#: cp/decl.c:15057
+#: cp/decl.c:15075
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD 有前一個宣告在此"
 
-#: cp/decl.c:15065
+#: cp/decl.c:15083
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: cp/decl.c:15066 cp/decl.c:15073
+#: cp/decl.c:15084 cp/decl.c:15091
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T 先前在此處有過宣告"
 
-#: cp/decl.c:15072
+#: cp/decl.c:15090
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT 做為列舉被參照"
@@ -52633,108 +52682,108 @@ msgstr "%qT 做為列舉被參照"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:15087
+#: cp/decl.c:15105
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> 需要範本參數"
 
-#: cp/decl.c:15130 cp/name-lookup.c:5736 cp/name-lookup.c:5871
-#: cp/parser.c:6817 cp/parser.c:29391
+#: cp/decl.c:15148 cp/name-lookup.c:5753 cp/name-lookup.c:5888
+#: cp/parser.c:6817 cp/parser.c:29445
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/decl.c:15151 cp/name-lookup.c:5434
+#: cp/decl.c:15169 cp/name-lookup.c:5451
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD 與其宣告所在的類別同名"
 
-#: cp/decl.c:15179 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
-#: cp/pt.c:9740
+#: cp/decl.c:15197 cp/friend.c:302 cp/parser.c:3254 cp/parser.c:6526
+#: cp/pt.c:9764
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT 不是一個範本"
 
-#: cp/decl.c:15184
+#: cp/decl.c:15202
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:15287
+#: cp/decl.c:15305
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用列舉 %q#D 前沒有給出宣告"
 
-#: cp/decl.c:15318
+#: cp/decl.c:15336
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT 重宣告為非範本"
 
-#: cp/decl.c:15329 cp/semantics.c:3336
+#: cp/decl.c:15347 cp/semantics.c:3354
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %qD to be a bit-field type"
 msgid "cannot declare %qD in a different module"
 msgstr "不能將 %qD 宣告為位元段類型"
 
-#: cp/decl.c:15457
+#: cp/decl.c:15475
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "衍生聯合 %qT 無效"
 
-#: cp/decl.c:15464
+#: cp/decl.c:15482
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15475
+#: cp/decl.c:15493
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/decl.c:15500
+#: cp/decl.c:15518
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基礎類別型 %qT 不是結構或類別"
 
-#: cp/decl.c:15530
+#: cp/decl.c:15548
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "遞迴的類型 %qT 未定義"
 
-#: cp/decl.c:15532
+#: cp/decl.c:15550
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複的基礎類別型 %qT 無效"
 
-#: cp/decl.c:15677
+#: cp/decl.c:15695
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "範圍/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:15680 cp/decl.c:15688 cp/decl.c:15698 cp/decl.c:16300
-#: cp/parser.c:20064
+#: cp/decl.c:15698 cp/decl.c:15706 cp/decl.c:15716 cp/decl.c:16318
+#: cp/parser.c:20101
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "前一個定義在此"
 
-#: cp/decl.c:15685
+#: cp/decl.c:15703
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "下層的型態不匹配在中 enum %q#T"
 
-#: cp/decl.c:15695
+#: cp/decl.c:15713
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下層的輸入 enum %q#T"
 
-#: cp/decl.c:15706
+#: cp/decl.c:15724
 #, fuzzy, gcc-internal-format
 #| msgid "created and used with different endianness"
 msgid "cannot define %qD in different module"
 msgstr "建立和使用時使用了不同的高/低位位元組在前設定"
 
-#: cp/decl.c:15780
+#: cp/decl.c:15798
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
@@ -52743,78 +52792,78 @@ msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15927
+#: cp/decl.c:15945
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "沒有一個整數類型可以表示 %qT 的所有列舉值"
 
-#: cp/decl.c:16102
+#: cp/decl.c:16120
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.c:16112
+#: cp/decl.c:16130
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.c:16161
+#: cp/decl.c:16179
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.c:16162
+#: cp/decl.c:16180
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.c:16173
+#: cp/decl.c:16191
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD 處列舉值溢出"
 
-#: cp/decl.c:16193
+#: cp/decl.c:16211
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 
-#: cp/decl.c:16298 cp/parser.c:20062
+#: cp/decl.c:16316 cp/parser.c:20099
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T 多次定義"
 
-#: cp/decl.c:16338
+#: cp/decl.c:16356
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.c:16498 cp/typeck.c:10213
+#: cp/decl.c:16516 cp/typeck.c:10220
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> 應當回傳一個對 %<*this%> 的參照"
 
-#: cp/decl.c:17347
+#: cp/decl.c:17365
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.c:17349 cp/typeck.c:10093
+#: cp/decl.c:17367 cp/typeck.c:10100
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由於 %<volatile%>，函式回傳類型不相容"
 
-#: cp/decl.c:17411
+#: cp/decl.c:17429
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.c:17593
+#: cp/decl.c:17611
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD 已在類別 %qT 中定義過"
 
-#: cp/decl.c:17984
+#: cp/decl.c:18002
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
@@ -52854,7 +52903,7 @@ msgstr "不能 delete 一個函式。只有參照物件的指標才是 %<delete%
 msgid "deleting %qT is undefined"
 msgstr "刪除 %qT 未定義"
 
-#: cp/decl2.c:580 cp/pt.c:5824
+#: cp/decl2.c:580 cp/pt.c:5841
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D 宣告為範本"
@@ -52864,7 +52913,7 @@ msgstr "%q#D 宣告為範本"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "模板參數清單提供 don%'t 匹配模板參數的 %qD"
 
-#: cp/decl2.c:635 cp/pt.c:5781
+#: cp/decl2.c:635 cp/pt.c:5798
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "解構函式 %qD 被宣告為一個成員範本"
@@ -53202,22 +53251,22 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5618
+#: cp/decl2.c:5619
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "轉換 lambda 該項使用 %<...%>到函式指標"
 
-#: cp/decl2.c:5621
+#: cp/decl2.c:5622
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用的刪除的函式 %qD"
 
-#: cp/decl2.c:5671
+#: cp/decl2.c:5672
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/decl2.c:5703
+#: cp/decl2.c:5704
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -53325,7 +53374,7 @@ msgstr "對 %<%T::%D%> 的參照有歧義"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD 不是類型 %qT 的成員"
 
-#: cp/error.c:4550 cp/typeck.c:2550
+#: cp/error.c:4550 cp/typeck.c:2561
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD 不是 %qT 的成員"
@@ -53336,7 +53385,7 @@ msgstr "%qD 不是 %qT 的成員"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD 不是類型 %qT 的成員"
 
-#: cp/error.c:4576 cp/typeck.c:3146
+#: cp/error.c:4576 cp/typeck.c:3157
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD 不是 %qD 的成員"
@@ -53524,417 +53573,417 @@ msgstr "value-initialization 的參考類型 %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "遞迴求值的預設引數用於 %q#D"
 
-#: cp/init.c:633
+#: cp/init.c:640
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:704
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/init.c:755
+#: cp/init.c:762
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:781
+#: cp/init.c:788
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD 應該被初始化的在中成員初始值清單"
 
-#: cp/init.c:802
+#: cp/init.c:809
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/init.c:918
+#: cp/init.c:925
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/init.c:933 cp/init.c:959 cp/init.c:2504 cp/method.c:2261
+#: cp/init.c:940 cp/init.c:966 cp/init.c:2511 cp/method.c:2261
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "uninitialized 常數成員在中 %q#T"
 
-#: cp/init.c:935 cp/init.c:953 cp/init.c:961 cp/init.c:2489 cp/init.c:2517
+#: cp/init.c:942 cp/init.c:960 cp/init.c:968 cp/init.c:2496 cp/init.c:2524
 #: cp/method.c:2264 cp/method.c:2275
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%qD 應該被初始化的"
 
-#: cp/init.c:951 cp/init.c:2476 cp/method.c:2272
+#: cp/init.c:958 cp/init.c:2483 cp/method.c:2272
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "uninitialized 參考成員在中 %q#T"
 
-#: cp/init.c:1128
+#: cp/init.c:1135
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D 將隨後被初始化"
 
-#: cp/init.c:1131
+#: cp/init.c:1138
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "基礎類別 %qT 將在"
 
-#: cp/init.c:1135
+#: cp/init.c:1142
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1137
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  基礎類別 %qT"
 
-#: cp/init.c:1139
+#: cp/init.c:1146
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  時初始化的在此"
 
-#: cp/init.c:1156
+#: cp/init.c:1163
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "多重初始化施用於 %qD"
 
-#: cp/init.c:1160
+#: cp/init.c:1167
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "多重初始化施用於基底 %qT"
 
-#: cp/init.c:1247
+#: cp/init.c:1254
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "初始化用於多重成員的 %qT"
 
-#: cp/init.c:1344
+#: cp/init.c:1351
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "基礎類別 %q#T 應該是明確的初始化的在中複製建構函式"
 
-#: cp/init.c:1575 cp/init.c:1594
+#: cp/init.c:1582 cp/init.c:1601
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "類別 %qT 沒具名為 %qD 的欄位"
 
-#: cp/init.c:1581
+#: cp/init.c:1588
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D 是一個靜態資料成員；它只能在定義時被初始化"
 
-#: cp/init.c:1588
+#: cp/init.c:1595
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/init.c:1627
+#: cp/init.c:1634
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "對沒有基礎類別的 %qT 的無名初始化"
 
-#: cp/init.c:1635
+#: cp/init.c:1642
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "對使用了多繼承的 %qT 的無名初始化"
 
-#: cp/init.c:1682
+#: cp/init.c:1689
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD 既是一個直接基礎類別又是一個間接虛基礎類別"
 
-#: cp/init.c:1690
+#: cp/init.c:1697
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/init.c:1693
+#: cp/init.c:1700
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接基礎類別"
 
-#: cp/init.c:1805 cp/init.c:4511 cp/typeck2.c:1238
+#: cp/init.c:1812 cp/init.c:4518 cp/typeck2.c:1238
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "陣列必須被初始化的與 brace-enclosed 初始設定式"
 
-#: cp/init.c:2115 cp/semantics.c:3604
+#: cp/init.c:2122 cp/semantics.c:3622
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT 並非類別型態"
 
-#: cp/init.c:2159
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "不完全類型 %qT 沒有成員 %qD"
 
-#: cp/init.c:2173
+#: cp/init.c:2180
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "參照位元段 %qD 指標無效"
 
-#: cp/init.c:2259 cp/typeck.c:2018
+#: cp/init.c:2266 cp/typeck.c:2029
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/init.c:2266 cp/semantics.c:2092
+#: cp/init.c:2273 cp/semantics.c:2111
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "對非靜態資料成員 %qD 的無效使用"
 
-#: cp/init.c:2473
+#: cp/init.c:2480
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 參考成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2481
+#: cp/init.c:2488
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 參考成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2485
+#: cp/init.c:2492
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "uninitialized 參考成員在中 %q#T"
 
-#: cp/init.c:2501
+#: cp/init.c:2508
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 常數成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2509
+#: cp/init.c:2516
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 常數成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2513
+#: cp/init.c:2520
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "uninitialized 常數成員在中 %q#T"
 
-#: cp/init.c:2623
+#: cp/init.c:2630
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2626
+#: cp/init.c:2633
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2636
+#: cp/init.c:2643
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2639
+#: cp/init.c:2646
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2648
+#: cp/init.c:2655
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2651
+#: cp/init.c:2658
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
 msgstr ""
 
-#: cp/init.c:2668
+#: cp/init.c:2675
 #, fuzzy, gcc-internal-format
 msgid "at offset %wi from %qD declared here"
 msgstr "內聯函式 %q+D 宣告的 weak"
 
-#: cp/init.c:2672
+#: cp/init.c:2679
 #, fuzzy, gcc-internal-format
 msgid "at offset [%wi, %wi] from %qD declared here"
 msgstr "內聯函式 %q+D 宣告的 weak"
 
-#: cp/init.c:2887
+#: cp/init.c:2894
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "整數溢出"
 
-#: cp/init.c:2897
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "變數「%s」在 %L 處上下文中必須是常數"
 
-#: cp/init.c:2915
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "variably 已修改欄位於檔案範圍"
 
-#: cp/init.c:2931
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/init.c:2933
+#: cp/init.c:2940
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/init.c:2943
+#: cp/init.c:2950
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "對 new 而言類型 %<void%> 無效"
 
-#: cp/init.c:2949
+#: cp/init.c:2956
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:2991
+#: cp/init.c:2998
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%<new%> %q#T 時常數未初始化"
 
-#: cp/init.c:3135
+#: cp/init.c:3142
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "找不到合適的 %qD，在類別 %qT 中"
 
-#: cp/init.c:3142 cp/search.c:1058
+#: cp/init.c:3149 cp/search.c:1058
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "對成員 %qD 的請求有歧義"
 
-#: cp/init.c:3216
+#: cp/init.c:3223
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3219
+#: cp/init.c:3226
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "類別 %qT 沒具名為 %qD 的欄位"
 
-#: cp/init.c:3222
+#: cp/init.c:3229
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3419
+#: cp/init.c:3426
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "parenthesized 初始設定式在中陣列新"
 
-#: cp/init.c:3712
+#: cp/init.c:3719
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: cp/init.c:3741
+#: cp/init.c:3748
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new 不能用於參照類型"
 
-#: cp/init.c:3750
+#: cp/init.c:3757
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new 不能用於函式類型"
 
-#: cp/init.c:3869
+#: cp/init.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "偵測到呼叫 delete 運算子時可能出現的問題："
 
-#: cp/init.c:3873
+#: cp/init.c:3880
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:4420
+#: cp/init.c:4427
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值設定在完成之前結束"
 
-#: cp/init.c:4726
+#: cp/init.c:4733
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 時陣列大小不明"
 
-#: cp/init.c:4760
+#: cp/init.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "偵測到呼叫 delete 運算子時可能出現的問題："
 
-#: cp/init.c:4765
+#: cp/init.c:4772
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:4780
+#: cp/init.c:4787
 #, fuzzy, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "刪除物件的抽象類別型態 %qT 該項有 non-virtual 解構式將造成未定義的行為"
 
-#: cp/init.c:4785
+#: cp/init.c:4792
 #, fuzzy, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "刪除物件的 polymorphic 類別型態 %qT 該項有 non-virtual 解構式也許造成未定義的行為"
 
-#: cp/init.c:5089
+#: cp/init.c:5096
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: cp/lambda.c:528
+#: cp/lambda.c:529
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.c:543
+#: cp/lambda.c:544
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.c:547
+#: cp/lambda.c:548
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "複合字面值有可變的大小"
 
-#: cp/lambda.c:571
+#: cp/lambda.c:572
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "無法擷取 %qE 由參考"
 
-#: cp/lambda.c:581
+#: cp/lambda.c:582
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "無效的使用的不完整型態 %q#T"
 
-#: cp/lambda.c:633
+#: cp/lambda.c:637
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.c:709
+#: cp/lambda.c:713
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.c:711
+#: cp/lambda.c:715
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.c:825
+#: cp/lambda.c:829
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> 未被擷取用於這個 lambda 函式"
@@ -53993,62 +54042,62 @@ msgstr "%qD 的引數不依賴範本參數，所以 %qD 的宣告必須可用"
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(如果您使用 %<-fpermissive%>，G++ 會接受您的程式碼，但是允許使用未定義的名稱是過時的風格)"
 
-#: cp/mangle.c:2357
+#: cp/mangle.c:2350
 #, fuzzy, gcc-internal-format
 msgid "mangling %<typeof%>, use %<decltype%> instead"
 msgstr "mangling typeof，使用 decltype 做為替代"
 
-#: cp/mangle.c:2361
+#: cp/mangle.c:2354
 #, fuzzy, gcc-internal-format
 msgid "mangling %<__underlying_type%>"
 msgstr "mangling __underlying_type"
 
-#: cp/mangle.c:2668
+#: cp/mangle.c:2661
 #, fuzzy, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "mangling 不明定點型態"
 
-#: cp/mangle.c:3428
+#: cp/mangle.c:3439
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3433
+#: cp/mangle.c:3444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "mangling %C"
 
-#: cp/mangle.c:3509
+#: cp/mangle.c:3520
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "省略的 %<?:%> 中運算元不能被修飾"
 
-#: cp/mangle.c:4074
+#: cp/mangle.c:4085
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:4120
+#: cp/mangle.c:4131
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4126
+#: cp/mangle.c:4137
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4398
+#: cp/mangle.c:4409
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4403
+#: cp/mangle.c:4414
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/mangle.c:4408
+#: cp/mangle.c:4419
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
@@ -54235,317 +54284,317 @@ msgstr "%q+#D 是隱含地刪除的因為預設定義會被不當形式的："
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:3136
+#: cp/method.c:3153
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "不匹配預期的簽名 %qD"
 
-#: cp/method.c:3139
+#: cp/method.c:3156
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "不匹配預期的簽名 %qD"
 
-#: cp/method.c:3171
+#: cp/method.c:3188
 #, fuzzy, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "明確的缺席函式 %q+D 無法宣告的做為 constexpr 因為蘊含宣告不是 constexpr："
 
-#: cp/method.c:3191
+#: cp/method.c:3208
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "模板無法缺席"
 
-#: cp/method.c:3226
+#: cp/method.c:3243
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD 無法缺席"
 
-#: cp/method.c:3235
+#: cp/method.c:3252
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "缺席函式 %q+D 與預設引數"
 
-#: cp/name-lookup.c:2727
+#: cp/name-lookup.c:2728
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/name-lookup.c:2733
+#: cp/name-lookup.c:2734
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D 衝突與前一個宣告"
 
-#: cp/name-lookup.c:2910
+#: cp/name-lookup.c:2911
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D 隱藏了 %q#T 的建構式"
 
-#: cp/name-lookup.c:3059
+#: cp/name-lookup.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "相互衝突的宣告 %q#D"
 
-#: cp/name-lookup.c:3064
+#: cp/name-lookup.c:3065
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "由於不同的異常規格"
 
-#: cp/name-lookup.c:3162
+#: cp/name-lookup.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/name-lookup.c:3185
+#: cp/name-lookup.c:3186
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D 的宣告隱藏了一個參數"
 
-#: cp/name-lookup.c:3319
+#: cp/name-lookup.c:3320
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/name-lookup.c:3746
+#: cp/name-lookup.c:3763
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "朋友宣告 %qD 在中區域類別而無需事前宣告"
 
-#: cp/name-lookup.c:4226
+#: cp/name-lookup.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:4229
+#: cp/name-lookup.c:4246
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4844
+#: cp/name-lookup.c:4861
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not have external linkage"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/name-lookup.c:4846 cp/parser.c:11133 cp/parser.c:11143
-#: cp/semantics.c:3788 cp/semantics.c:3800
+#: cp/name-lookup.c:4863 cp/parser.c:11154 cp/parser.c:11164
+#: cp/semantics.c:3806 cp/semantics.c:3818
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+#D 宣告的在此"
 
-#: cp/name-lookup.c:5588
+#: cp/name-lookup.c:5605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> 指定了解構函式"
 
-#: cp/name-lookup.c:5604
+#: cp/name-lookup.c:5621
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "在類別作用欄位使用非成員的 using 宣告"
 
-#: cp/name-lookup.c:5612
+#: cp/name-lookup.c:5629
 #, fuzzy, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/name-lookup.c:5628 cp/pt.c:18214
+#: cp/name-lookup.c:5645 cp/pt.c:18297
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE 並非類別、命名空間，或列舉類型"
 
-#: cp/name-lookup.c:5638
+#: cp/name-lookup.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "%q#D 宣告為範本"
 
-#: cp/name-lookup.c:5649 cp/name-lookup.c:5707
+#: cp/name-lookup.c:5666 cp/name-lookup.c:5724
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "在類別作用欄位使用非成員的 using 宣告"
 
-#: cp/name-lookup.c:5672
+#: cp/name-lookup.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接基礎類別"
 
-#: cp/name-lookup.c:5717
+#: cp/name-lookup.c:5734
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5729
+#: cp/name-lookup.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD 未被宣告在中 %qD"
 
-#: cp/name-lookup.c:5743
+#: cp/name-lookup.c:5760
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD not in a namespace surrounding %qD"
 msgid "using-declaration may not name namespace %qD"
 msgstr "%qD 的宣告不在包含 %qD 的命名空間中"
 
-#: cp/name-lookup.c:5754
+#: cp/name-lookup.c:5771
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> 在 %qT 內指定了建構式"
 
-#: cp/name-lookup.c:5850
+#: cp/name-lookup.c:5867
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD 的宣告不在包含 %qD 的命名空間中"
 
-#: cp/name-lookup.c:5891
+#: cp/name-lookup.c:5908
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD 的宣告中有明確的限定"
 
-#: cp/name-lookup.c:5901
+#: cp/name-lookup.c:5918
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD 應當已在 %qD 內部宣告過"
 
-#: cp/name-lookup.c:5954
+#: cp/name-lookup.c:5971
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD 未被宣告在中 %qD"
 
-#: cp/name-lookup.c:5956
+#: cp/name-lookup.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/name-lookup.c:6010
+#: cp/name-lookup.c:6027
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/name-lookup.c:6017
+#: cp/name-lookup.c:6034
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD 屬性是無意義的自從成員的匿名命名空間提取本機符號"
 
-#: cp/name-lookup.c:6027 cp/name-lookup.c:6054
+#: cp/name-lookup.c:6044 cp/name-lookup.c:6071
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.c:6033
+#: cp/name-lookup.c:6050
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.c:6070 cp/name-lookup.c:8581
+#: cp/name-lookup.c:6087 cp/name-lookup.c:8598
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定 %qD 屬性被忽略"
 
-#: cp/name-lookup.c:6398
+#: cp/name-lookup.c:6415
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空間搜尋的用於 %qE"
 
-#: cp/name-lookup.c:6450
+#: cp/name-lookup.c:6467
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建議的替代方案："
 
-#: cp/name-lookup.c:6456
+#: cp/name-lookup.c:6473
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:6985
+#: cp/name-lookup.c:7002
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:6991
+#: cp/name-lookup.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "靜態成員函式中不能使用 %<this%>"
 
-#: cp/name-lookup.c:7427
+#: cp/name-lookup.c:7444
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "weak %q+D 無法定義 %qE"
 
-#: cp/name-lookup.c:7430
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "結構定義的在此"
 
-#: cp/name-lookup.c:8213
+#: cp/name-lookup.c:8230
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:8575
+#: cp/name-lookup.c:8592
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "開關 %qs 不再被支援"
 
-#: cp/name-lookup.c:8578
+#: cp/name-lookup.c:8595
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:8669
+#: cp/name-lookup.c:8686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/name-lookup.c:8766
+#: cp/name-lookup.c:8783
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "『%s』於 %L 是模稜兩可的"
 
-#: cp/name-lookup.c:8782
+#: cp/name-lookup.c:8799
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "這裡不允許命名空間別名 %qD，假定為 %qD"
 
-#: cp/name-lookup.c:8862
+#: cp/name-lookup.c:8879
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法屬性必須被指定的於結束只有"
 
-#: cp/name-lookup.c:8863
+#: cp/name-lookup.c:8880
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "標貼 %qD 定義的在此"
 
-#: cp/name-lookup.c:8915
+#: cp/name-lookup.c:8932
 #, fuzzy, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD 衝突與使用的函式"
 
-#: cp/name-lookup.c:8917
+#: cp/name-lookup.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "前一個定義在此"
 
-#: cp/name-lookup.c:8997
+#: cp/name-lookup.c:9014
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX 進入 pop_everything ()\n"
 
-#: cp/name-lookup.c:9006
+#: cp/name-lookup.c:9023
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -54571,7 +54620,7 @@ msgstr "識別碼 %qE 是關鍵字在中 C++11"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1415 cp/parser.c:42693
+#: cp/parser.c:1415 cp/parser.c:42746
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
@@ -54596,7 +54645,7 @@ msgstr "%<::%E%>未被宣告"
 msgid "request for member %qE in non-class type %qT"
 msgstr "要求用於成員 %qE 在中 non-class 型態 %qT"
 
-#: cp/parser.c:3106 cp/parser.c:20001
+#: cp/parser.c:3106 cp/parser.c:20038
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>未被宣告"
@@ -54676,7 +54725,7 @@ msgstr "無效的範本 ID"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮點實字無法出現在中 constant-expression"
 
-#: cp/parser.c:3301 cp/pt.c:19710
+#: cp/parser.c:3301 cp/pt.c:19792
 #, fuzzy, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "演員陣容到型態不同於積分或列舉類型型態無法出現在中 constant-expression"
@@ -54814,7 +54863,7 @@ msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:3496 cp/parser.c:28706
+#: cp/parser.c:3496 cp/parser.c:28760
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "使用者定義的實字只有可用與 -std=c++11 或 -std=gnu++11"
@@ -54942,7 +54991,7 @@ msgstr "無法找到字串實字運算子 %qD 與 %qT，%qT 引數"
 msgid "global module fragment contents must be from preprocessor inclusion"
 msgstr ""
 
-#: cp/parser.c:4935 cp/parser.c:14325
+#: cp/parser.c:4935 cp/parser.c:14349
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "預期的宣告"
@@ -54993,7 +55042,7 @@ msgstr "statement-expressions 未被允許外側函式 nor 在中 template-argum
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3942
+#: cp/parser.c:5638 cp/parser.c:5817 cp/parser.c:5995 cp/semantics.c:3960
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "預期 primary-expression"
@@ -55024,7 +55073,7 @@ msgstr "範圍 %qT 之前 %<~%>並非 class-name"
 msgid "%<template%> keyword not permitted in destructor name"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/parser.c:6329 cp/parser.c:8350
+#: cp/parser.c:6329 cp/parser.c:8357
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
@@ -55045,12 +55094,12 @@ msgstr "%<~%T%> 宣告為 %qT 的一個成員"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名 %qD 用於解構函式宣告"
 
-#: cp/parser.c:6500 cp/parser.c:22400
+#: cp/parser.c:6500 cp/parser.c:22437
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "預期 unqualified-id"
 
-#: cp/parser.c:6527 cp/typeck.c:2843 cp/typeck.c:2846 cp/typeck.c:2863
+#: cp/parser.c:6527 cp/typeck.c:2854 cp/typeck.c:2857 cp/typeck.c:2874
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD 不是一個範本"
@@ -55087,7 +55136,7 @@ msgstr "預期 nested-name-specifier"
 msgid "expected nested-name-specifier"
 msgstr "預期 nested-name-specifier"
 
-#: cp/parser.c:7143 cp/parser.c:9595
+#: cp/parser.c:7143 cp/parser.c:9602
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "類型可能無法被定義在中演員陣容"
@@ -55102,7 +55151,7 @@ msgstr "類型可能無法被定義在中 %<typeid%> 運算式"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
 
-#: cp/parser.c:7336 cp/pt.c:20360
+#: cp/parser.c:7336 cp/pt.c:20442
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "錯誤的引數數量到 %<__builtin_complex%>"
@@ -55117,1136 +55166,1141 @@ msgstr "ISO C++ 不允許複合字面值"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:8088 cp/typeck.c:2731
+#: cp/parser.c:8095 cp/typeck.c:2742
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "錯誤地使用了 %qD"
 
-#: cp/parser.c:8097
+#: cp/parser.c:8104
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%>並非類別成員"
 
-#: cp/parser.c:8402
+#: cp/parser.c:8409
 #, fuzzy, gcc-internal-format
 msgid "non-scalar type"
 msgstr "non-scalar 型態"
 
-#: cp/parser.c:8512
+#: cp/parser.c:8519
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++不允許 %<alignof%> 與 non-type"
 
-#: cp/parser.c:8607
+#: cp/parser.c:8614
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "類型可能無法被定義在中 %<noexcept%> 運算式"
 
-#: cp/parser.c:8881 cp/parser.c:31202
+#: cp/parser.c:8888 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "類型可能無法被定義在中 new-expression"
 
-#: cp/parser.c:8946
+#: cp/parser.c:8953
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
 
-#: cp/parser.c:9032
+#: cp/parser.c:9039
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "類型可能無法被定義在中 new-expression"
 
-#: cp/parser.c:9048
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "括起的類型識別碼後面不能出現陣列邊界"
 
-#: cp/parser.c:9050
+#: cp/parser.c:9057
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/parser.c:9082
+#: cp/parser.c:9089
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:9127
+#: cp/parser.c:9134
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "需要運算式類型"
 
-#: cp/parser.c:9156
+#: cp/parser.c:9163
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "類型可能無法被定義在中 new-type-id"
 
-#: cp/parser.c:9291
+#: cp/parser.c:9298
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new 宣告中的運算式必須具有整數或列舉類型"
 
-#: cp/parser.c:9700
+#: cp/parser.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "使用舊式的類型轉換"
 
-#: cp/parser.c:9849
+#: cp/parser.c:9856
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%<>>%>運算子被視為兩正確角度中括號在中 C++11"
 
-#: cp/parser.c:9852
+#: cp/parser.c:9859
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "建議 parentheses 周圍 %<>>%>運算式"
 
-#: cp/parser.c:10060
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++不允許 ?:與省略的中間運算元"
 
-#: cp/parser.c:10349
+#: cp/parser.c:10356
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10506
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/parser.c:10798
+#: cp/parser.c:10809
+#, fuzzy, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr "lambda-expression 在中 unevaluated 語境"
+
+#: cp/parser.c:10819
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10829
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10960
+#: cp/parser.c:10981
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10982
+#: cp/parser.c:11003
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "預期的結束的 capture-list"
 
-#: cp/parser.c:10997
+#: cp/parser.c:11018
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "明確的 by-copy 擷取的 %<this%> 冗餘與 by-copy 擷取預設"
 
-#: cp/parser.c:11002 cp/parser.c:11023 cp/parser.c:11215
+#: cp/parser.c:11023 cp/parser.c:11044 cp/parser.c:11236
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "已經擷取 %qD 在中 lambda 運算式"
 
-#: cp/parser.c:11017
+#: cp/parser.c:11038
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11037
+#: cp/parser.c:11058
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "無法擷取 %qE 由參考"
 
-#: cp/parser.c:11056
+#: cp/parser.c:11077
 #, fuzzy, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11067
+#: cp/parser.c:11088
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:11098
+#: cp/parser.c:11119
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11126
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:11129
+#: cp/parser.c:11150
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "擷取的 non-variable %qD "
 
-#: cp/parser.c:11139
+#: cp/parser.c:11160
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "擷取的變數 %qD 與 non-automatic 貯藏體持續時間"
 
-#: cp/parser.c:11177
+#: cp/parser.c:11198
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:11188
+#: cp/parser.c:11209
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "明確的 by-copy 擷取的 %qD 冗餘與 by-copy 擷取預設"
 
-#: cp/parser.c:11193
+#: cp/parser.c:11214
 #, fuzzy, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "明確的 by-reference 擷取的 %qD 冗餘與 by-reference 擷取預設"
 
-#: cp/parser.c:11272
+#: cp/parser.c:11293
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11276
+#: cp/parser.c:11297
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11344
+#: cp/parser.c:11365
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "預設引數指定的用於 lambda 參數"
 
-#: cp/parser.c:11364
+#: cp/parser.c:11385
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11376
+#: cp/parser.c:11397
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重複的 %<volatile%>"
 
-#: cp/parser.c:11383
+#: cp/parser.c:11404
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11396
+#: cp/parser.c:11417
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11414
+#: cp/parser.c:11435
 #, fuzzy, gcc-internal-format
 msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11456
+#: cp/parser.c:11477
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11845 cp/parser.c:12046
+#: cp/parser.c:11866 cp/parser.c:12067
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:11885
+#: cp/parser.c:11906
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "預期 labeled-statement"
 
-#: cp/parser.c:11934
+#: cp/parser.c:11955
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case 標籤 %qE 未出現在 switch 敘述中"
 
-#: cp/parser.c:12053
+#: cp/parser.c:12074
 #, fuzzy, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "需要 %<typename%> 之前 %qE 因為 %qT 是附屬範圍"
 
-#: cp/parser.c:12062
+#: cp/parser.c:12083
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%>名稱建構子，不是型態"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12131
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:12275
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:12302
+#: cp/parser.c:12324
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:12470 cp/parser.c:31686
+#: cp/parser.c:12492 cp/parser.c:31740
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "預期 selection-statement"
 
-#: cp/parser.c:12511
+#: cp/parser.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "函式回傳了一個陣列"
 
-#: cp/parser.c:12513
+#: cp/parser.c:12535
 #, fuzzy, gcc-internal-format
 msgid "condition declares a function"
 msgstr "欄位 %qE 宣告的做為函式"
 
-#: cp/parser.c:12553
+#: cp/parser.c:12575
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "類型可能無法被定義在中條件"
 
 #. Anything else is an error.
-#: cp/parser.c:12634 cp/parser.c:21692 cp/parser.c:24161
+#: cp/parser.c:12656 cp/parser.c:21729 cp/parser.c:24198
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "預期的初始設定式"
 
-#: cp/parser.c:12918
+#: cp/parser.c:12942
 #, gcc-internal-format
 msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
 msgstr ""
 
 #. rval
-#: cp/parser.c:12925
+#: cp/parser.c:12949
 #, gcc-internal-format
 msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
 msgstr ""
 
-#: cp/parser.c:12950
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "non-local variable %q#D uses local type %qT"
 msgid "loop variable %qD creates a copy from type %qT"
 msgstr "非局部變數 %q#D 使用了局部類型 %qT"
 
-#: cp/parser.c:12955
+#: cp/parser.c:12979
 #, gcc-internal-format
 msgid "use reference type to prevent copying"
 msgstr ""
 
-#: cp/parser.c:13098
+#: cp/parser.c:13122
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "range-based %<for%> 運算式的型態 %qT 有不完整型態"
 
-#: cp/parser.c:13182
+#: cp/parser.c:13206
 #, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "不一致開始/結束類型在中 range-based %<for%> 敘述：%qT 和 %qT"
 
-#: cp/parser.c:13325 cp/parser.c:31689
+#: cp/parser.c:13349 cp/parser.c:31743
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "預期 iteration-statement"
 
-#: cp/parser.c:13371
+#: cp/parser.c:13395
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:13395
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:13526
+#: cp/parser.c:13550
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13534
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允許執行時可知的 goto 目的"
 
-#: cp/parser.c:13547 cp/parser.c:31692
+#: cp/parser.c:13571 cp/parser.c:31746
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "預期 jump-statement"
 
-#: cp/parser.c:13724
+#: cp/parser.c:13748
 #, fuzzy, gcc-internal-format
 msgid "expected module-name"
 msgstr "預期 template-name"
 
-#: cp/parser.c:13759
+#: cp/parser.c:13783
 #, fuzzy, gcc-internal-format
 #| msgid "method declaration not in @interface context"
 msgid "module-declaration not permitted in header-unit"
 msgstr "方法宣告不在@interface 上下文中"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13808
 #, gcc-internal-format
 msgid "private module fragment only permitted in purview of module interface or partition"
 msgstr ""
 
-#: cp/parser.c:13789
+#: cp/parser.c:13813
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "private module fragment"
 msgstr "沒有參數"
 
 #. Neither the first declaration, nor in a GMF.
-#: cp/parser.c:13795
+#: cp/parser.c:13819
 #, gcc-internal-format
 msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
 msgstr ""
 
-#: cp/parser.c:13832
+#: cp/parser.c:13856
 #, gcc-internal-format
 msgid "post-module-declaration imports must be contiguous"
 msgstr ""
 
-#: cp/parser.c:13835
+#: cp/parser.c:13859
 #, gcc-internal-format
 msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
 msgstr ""
 
-#: cp/parser.c:13843
+#: cp/parser.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "import-declaration must be at global scope"
 msgstr "在類別作用欄位使用非成員的 using 宣告"
 
-#: cp/parser.c:13856
+#: cp/parser.c:13880
 #, fuzzy, gcc-internal-format
 msgid "import cannot appear directly in a linkage-specification"
 msgstr "無效的連繫規格"
 
-#: cp/parser.c:13864
+#: cp/parser.c:13888
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be include-translated"
 msgstr ""
 
-#: cp/parser.c:13869
+#: cp/parser.c:13893
 #, gcc-internal-format
 msgid "post-module-declaration imports must not be from header inclusion"
 msgstr ""
 
-#: cp/parser.c:13889
+#: cp/parser.c:13913
 #, gcc-internal-format
 msgid "%qE may only occur after a module interface declaration"
 msgstr ""
 
-#: cp/parser.c:13897
+#: cp/parser.c:13921
 #, fuzzy, gcc-internal-format
 msgid "%qE may only occur once in an export declaration"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:13918
+#: cp/parser.c:13942
 #, gcc-internal-format
 msgid "%<export%> not part of following module-directive"
 msgstr ""
 
-#: cp/parser.c:14020
+#: cp/parser.c:14044
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "attributes are not permitted in this position"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/parser.c:14024
+#: cp/parser.c:14048
 #, fuzzy, gcc-internal-format
 msgid "attributes may be inserted here"
 msgstr "%qE 屬性被忽略"
 
-#: cp/parser.c:14155 cp/parser.c:25964
+#: cp/parser.c:14179 cp/parser.c:25999
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多餘的 %<;%>"
 
-#: cp/parser.c:14248
+#: cp/parser.c:14272
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>無法於起始部分的區塊"
 
-#: cp/parser.c:14463
+#: cp/parser.c:14487
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:14483
+#: cp/parser.c:14507
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/parser.c:14504
+#: cp/parser.c:14528
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合宣告和函式定義"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14607
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14586
+#: cp/parser.c:14610
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:14637
+#: cp/parser.c:14661
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:14689
+#: cp/parser.c:14713
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "預期的宣告"
 
-#: cp/parser.c:14707
+#: cp/parser.c:14731
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "無效的初始設定式用於成員函式 %qD"
 
-#: cp/parser.c:14876
+#: cp/parser.c:14900
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> 使用的外側的類別"
 
-#: cp/parser.c:14915
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: cp/parser.c:14918
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14985
+#: cp/parser.c:15009
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> 變更平均在中 C++11; 請移除它"
 
-#: cp/parser.c:15021
+#: cp/parser.c:15045
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "decl-specifier 無效的在中條件"
 
-#: cp/parser.c:15028
+#: cp/parser.c:15052
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D 無效，在 %q#T 中"
 
-#: cp/parser.c:15109
+#: cp/parser.c:15133
 #, fuzzy, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "decl-specifier 無效的在中條件"
 
-#: cp/parser.c:15128
+#: cp/parser.c:15152
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "類別定義不能被宣告為夥伴"
 
-#: cp/parser.c:15201 cp/parser.c:26479
+#: cp/parser.c:15225 cp/parser.c:26514
 #, fuzzy, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.c:15220
+#: cp/parser.c:15244
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "類型可能無法被定義在中 exception-specification"
 
-#: cp/parser.c:15224
+#: cp/parser.c:15248
 #, fuzzy, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:15288
+#: cp/parser.c:15312
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無效的連繫規格"
 
-#: cp/parser.c:15392
+#: cp/parser.c:15416
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:15594
+#: cp/parser.c:15618
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:15607
+#: cp/parser.c:15631
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "類型可能無法被定義在中 %<decltype%> 運算式"
 
-#: cp/parser.c:15770
+#: cp/parser.c:15794
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "類型可能無法被定義在中 new-type-id"
 
-#: cp/parser.c:15799
+#: cp/parser.c:15823
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:15803
+#: cp/parser.c:15827
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:15887
+#: cp/parser.c:15911
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有建構子需成員初始設定式"
 
-#: cp/parser.c:15914
+#: cp/parser.c:15938
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "無法展開初始設定式用於成員 %<%D%>"
 
-#: cp/parser.c:15926 cp/pt.c:26408
+#: cp/parser.c:15950 cp/pt.c:26446
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer 用於 %qD 追隨建構子 delegation"
 
-#: cp/parser.c:15938 cp/pt.c:26420
+#: cp/parser.c:15962 cp/pt.c:26458
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建構子 delegation 追隨 mem-initializer 用於 %qD"
 
-#: cp/parser.c:15990
+#: cp/parser.c:16014
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代錯誤的舊式基礎類別初始值設定"
 
-#: cp/parser.c:16075
+#: cp/parser.c:16099
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(限定的初始值設定隱含地是一個類型)"
 
-#: cp/parser.c:16476
+#: cp/parser.c:16500
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介於 %<「」%>和字尾識別碼"
 
-#: cp/parser.c:16482
+#: cp/parser.c:16506
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "預期的字尾識別碼"
 
-#: cp/parser.c:16491
+#: cp/parser.c:16515
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "預期的清空字串之後 %<operator%> 關鍵字"
 
-#: cp/parser.c:16497
+#: cp/parser.c:16521
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "無效的運算元在中三進作業"
 
-#: cp/parser.c:16531
+#: cp/parser.c:16555
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "預期的運算子"
 
-#: cp/parser.c:16578
+#: cp/parser.c:16602
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "關鍵字 %<export%> 未實作，將被忽略"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16604
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<export%> not implemented, and will be ignored"
 msgid "keyword %<export%> is deprecated, and is ignored"
 msgstr "關鍵字 %<export%> 未實作，將被忽略"
 
-#: cp/parser.c:16582
+#: cp/parser.c:16606
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
 msgstr "-ms2600 未與 -ms 一起使用"
 
-#: cp/parser.c:16761
+#: cp/parser.c:16785
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:16769
+#: cp/parser.c:16793
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:16912
+#: cp/parser.c:16940
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無效的使用的模板模板參數 %qT"
 
-#: cp/parser.c:17148 cp/parser.c:17234 cp/parser.c:23932
+#: cp/parser.c:17176 cp/parser.c:17262 cp/parser.c:23969
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:17152 cp/parser.c:17238
+#: cp/parser.c:17180 cp/parser.c:17266
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:17305
+#: cp/parser.c:17333
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "預期 template-id"
 
-#: cp/parser.c:17367
+#: cp/parser.c:17395
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以 %<<::%> 開始一個範本引數清單"
 
-#: cp/parser.c:17371
+#: cp/parser.c:17399
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> 是 %<[%> 的另一種拼法。請在 %<<%> 和 %<::%> 間加上空格"
 
-#: cp/parser.c:17375
+#: cp/parser.c:17403
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用 %<-fpermissive%> G++將接受您的編碼)"
 
-#: cp/parser.c:17405
+#: cp/parser.c:17433
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:17406
+#: cp/parser.c:17434
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:17413
+#: cp/parser.c:17441
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "預期 template-argument"
 
-#: cp/parser.c:17517
+#: cp/parser.c:17545
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "範本引數表語法錯誤"
 
 #. The name does not name a template.
-#: cp/parser.c:17602 cp/parser.c:17768 cp/parser.c:17973
+#: cp/parser.c:17630 cp/parser.c:17796 cp/parser.c:18001
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "預期 template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:17648
+#: cp/parser.c:17676
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/parser.c:17650
+#: cp/parser.c:17678
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用 %<%T::template %D%> 來表示這是一個範本"
 
-#: cp/parser.c:17829
+#: cp/parser.c:17857
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:17938 cp/parser.c:17956 cp/parser.c:18127
+#: cp/parser.c:17966 cp/parser.c:17984 cp/parser.c:18155
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "預期 template-argument"
 
-#: cp/parser.c:18094
+#: cp/parser.c:18122
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18257
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "明確的實體化不應該使用 %<inline%> 說明符"
 
-#: cp/parser.c:18233
+#: cp/parser.c:18261
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "明確的實體化不應該使用 %<constexpr%> 說明符"
 
-#: cp/parser.c:18237
+#: cp/parser.c:18265
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "明確的實體化不應該使用 %<constexpr%> 說明符"
 
-#: cp/parser.c:18297
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化範本有 C 連結"
 
-#: cp/parser.c:18517
+#: cp/parser.c:18554
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "預期的型態說明符"
 
-#: cp/parser.c:18710
+#: cp/parser.c:18747
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18716
+#: cp/parser.c:18753
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18721
+#: cp/parser.c:18758
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18878
+#: cp/parser.c:18915
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "預期 template-id 用於型態"
 
-#: cp/parser.c:19008
+#: cp/parser.c:19045
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "預期 type-name"
 
-#: cp/parser.c:19118
+#: cp/parser.c:19155
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE 沒有命名一個類型"
 
-#: cp/parser.c:19119
+#: cp/parser.c:19156
 #, fuzzy, gcc-internal-format
 msgid "concept defined here"
 msgstr "聯合定義的在此"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19178
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:19148
+#: cp/parser.c:19185
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:19391
+#: cp/parser.c:19428
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "elaborated-type-specifier 用於範圍的 enum 必須不使用 %<%D%>關鍵字"
 
-#: cp/parser.c:19467
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "typedef 名稱可能無法是 nested-name-specifier"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19666
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣告 %qD 不宣告任何事"
 
-#: cp/parser.c:19717
+#: cp/parser.c:19754
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "屬性忽略的於 uninstantiated 型態"
 
-#: cp/parser.c:19723
+#: cp/parser.c:19760
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/parser.c:19728
+#: cp/parser.c:19765
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "屬性忽略的於 elaborated-type-specifier 該並非前置宣告"
 
-#: cp/parser.c:19868
+#: cp/parser.c:19905
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD 是列舉類型模板"
 
-#: cp/parser.c:19879
+#: cp/parser.c:19916
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/parser.c:19894
+#: cp/parser.c:19931
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:19951
+#: cp/parser.c:19988
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "預期 %<;%>或 %<{%>"
 
-#: cp/parser.c:19995
+#: cp/parser.c:20032
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "無法加入列舉值清單到模板具現化"
 
-#: cp/parser.c:20009
+#: cp/parser.c:20046
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:20021 cp/parser.c:25439
+#: cp/parser.c:20058 cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "宣告的 %qD 在中命名空間 %qD 該項不封閉 %qD"
 
-#: cp/parser.c:20026 cp/parser.c:25444
+#: cp/parser.c:20063 cp/parser.c:25479
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD 宣告出現在 %qD 中，而後者並不包含 %qD"
 
-#: cp/parser.c:20038 cp/parser.c:25457
+#: cp/parser.c:20075 cp/parser.c:25492
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "額外合格不允許"
 
-#: cp/parser.c:20075
+#: cp/parser.c:20112
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/parser.c:20100
+#: cp/parser.c:20137
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而無需名稱"
 
-#: cp/parser.c:20103
+#: cp/parser.c:20140
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必須使用簡單的識別碼"
 
-#: cp/parser.c:20290
+#: cp/parser.c:20327
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD 不是一個命名空間"
 
-#: cp/parser.c:20294
+#: cp/parser.c:20331
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD 不是一個命名空間"
 
-#: cp/parser.c:20298
+#: cp/parser.c:20335
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:20359
+#: cp/parser.c:20396
 #, fuzzy, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:20370
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:20389
+#: cp/parser.c:20426
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:20399
+#: cp/parser.c:20436
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:20404
+#: cp/parser.c:20441
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20445
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "列舉量不能有屬性 %C"
 
-#: cp/parser.c:20411
+#: cp/parser.c:20448
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "當內聯函式無法被內聯時給出警告"
 
-#: cp/parser.c:20418
+#: cp/parser.c:20455
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空間 %qD 做為運算式"
 
-#: cp/parser.c:20473
+#: cp/parser.c:20510
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:20648
+#: cp/parser.c:20685
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "明確的轉換運算子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:20663
+#: cp/parser.c:20700
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "範本識別碼不允許出現在 using 宣告中"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20718
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:20691
+#: cp/parser.c:20728
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "存取宣告被不宜用在中 favour 的 using-declarations；建議：加入 %<using%> 關鍵字"
 
-#: cp/parser.c:20756
+#: cp/parser.c:20793
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-declaration here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
 
-#: cp/parser.c:20826
+#: cp/parser.c:20863
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "類型可能無法被定義在中別名模板宣告"
 
-#: cp/parser.c:20997
+#: cp/parser.c:21034
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:21016 cp/parser.c:21033 cp/parser.c:21047
+#: cp/parser.c:21053 cp/parser.c:21070 cp/parser.c:21084
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:21023
+#: cp/parser.c:21060
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "使用的參數 %qD 外側函式內文"
 
-#: cp/parser.c:21060
+#: cp/parser.c:21097
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT 不是一個命名空間"
 
-#: cp/parser.c:21076
+#: cp/parser.c:21113
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "使用的參數 %qD 外側函式內文"
 
-#: cp/parser.c:21304
+#: cp/parser.c:21341
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "empty parentheses were disambiguated as a function declaration"
 msgstr "函式宣告中出現參數名卻未指定類型"
 
-#: cp/parser.c:21315
+#: cp/parser.c:21352
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses to default-initialize a variable"
 msgstr "parenthesized 初始設定式在中陣列新"
 
-#: cp/parser.c:21320
+#: cp/parser.c:21357
 #, gcc-internal-format
 msgid "or replace parentheses with braces to aggregate-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21323
+#: cp/parser.c:21360
 #, gcc-internal-format
 msgid "or replace parentheses with braces to value-initialize a variable"
 msgstr ""
 
-#: cp/parser.c:21340 cp/parser.c:21365
+#: cp/parser.c:21377 cp/parser.c:21402
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "parentheses were disambiguated as a function declaration"
 msgstr "函式宣告中出現參數名卻未指定類型"
 
-#: cp/parser.c:21352 cp/parser.c:21373
+#: cp/parser.c:21389 cp/parser.c:21410
 #, gcc-internal-format
 msgid "replace parentheses with braces to declare a variable"
 msgstr ""
 
-#: cp/parser.c:21359
+#: cp/parser.c:21396
 #, fuzzy, gcc-internal-format
 msgid "add parentheses to declare a variable"
 msgstr "函式 %qD redeclared 做為變數"
 
-#: cp/parser.c:21587
+#: cp/parser.c:21624
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition 未被允許在此"
 
-#: cp/parser.c:21598
+#: cp/parser.c:21635
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "函式定義中不允許出現 asm 指定"
 
-#: cp/parser.c:21602
+#: cp/parser.c:21639
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函式定義中不允許有屬性"
 
-#: cp/parser.c:21653
+#: cp/parser.c:21690
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "預期的建構子、解構式，或類型轉換"
 
-#: cp/parser.c:21773
+#: cp/parser.c:21810
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "初始設定式提供的用於函式"
 
-#: cp/parser.c:21815
+#: cp/parser.c:21852
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:21829
+#: cp/parser.c:21866
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "函式 %q+D 重宣告為內聯的"
 
-#: cp/parser.c:22320
+#: cp/parser.c:22357
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "陣列邊界不是一個整數常數"
 
-#: cp/parser.c:22446
+#: cp/parser.c:22483
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "無法定義成員的附屬 typedef %qT"
 
-#: cp/parser.c:22450
+#: cp/parser.c:22487
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>並非型態"
@@ -56255,437 +56309,437 @@ msgstr "%<%T::%E%>並非型態"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:22479
+#: cp/parser.c:22516
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無效的宣告子"
 
-#: cp/parser.c:22487
+#: cp/parser.c:22524
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "將建構式做為範本用法無效"
 
-#: cp/parser.c:22489
+#: cp/parser.c:22526
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用 %<%T::%D%> 而不是 %<%T::%D%> 來以限定名指定建構式"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:22604
+#: cp/parser.c:22641
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "%q+D 在宣告前使用"
 
-#: cp/parser.c:22629
+#: cp/parser.c:22666
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "預期的宣告子"
 
-#: cp/parser.c:22750
+#: cp/parser.c:22787
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD 是一個命名空間"
 
-#: cp/parser.c:22752
+#: cp/parser.c:22789
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "無法表單成員指標的 non-class %q#T"
 
-#: cp/parser.c:22773
+#: cp/parser.c:22810
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "預期 ptr-operator"
 
-#: cp/parser.c:22834
+#: cp/parser.c:22871
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:22888
+#: cp/parser.c:22925
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:22925
+#: cp/parser.c:22962
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22983
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "重製 virt-specifier"
 
-#: cp/parser.c:23232
+#: cp/parser.c:23269
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/parser.c:23238
+#: cp/parser.c:23275
 #, fuzzy, gcc-internal-format
 msgid "%qT not permitted in template argument"
 msgstr "不匹配的引數"
 
-#: cp/parser.c:23241 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2200
+#: cp/parser.c:23278 cp/typeck2.c:353 cp/typeck2.c:400 cp/typeck2.c:2197
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "無效的使用的 %qT"
 
-#: cp/parser.c:23267
+#: cp/parser.c:23304
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "類型可能無法被定義在中模板引數"
 
-#: cp/parser.c:23272
+#: cp/parser.c:23309
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:23378
+#: cp/parser.c:23415
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "預期 type-specifier"
 
-#: cp/parser.c:23659
+#: cp/parser.c:23696
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "預期 %<,%>或 %<...%>"
 
-#: cp/parser.c:23737
+#: cp/parser.c:23774
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "類型可能無法被定義在中參數類型"
 
-#: cp/parser.c:23916
+#: cp/parser.c:23953
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "預設參數只允許出現在函式參數中"
 
-#: cp/parser.c:23934
+#: cp/parser.c:23971
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:23940
+#: cp/parser.c:23977
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:23942
+#: cp/parser.c:23979
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "參數包裝無法有預設引數"
 
-#: cp/parser.c:24068
+#: cp/parser.c:24105
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:24072
+#: cp/parser.c:24109
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:24396
+#: cp/parser.c:24433
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:24416
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:24454
+#: cp/parser.c:24491
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++不允許 C99 指定的初始設定式"
 
-#: cp/parser.c:24468
+#: cp/parser.c:24505
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:24493
+#: cp/parser.c:24530
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:24544
+#: cp/parser.c:24581
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:24600 cp/parser.c:24739
+#: cp/parser.c:24637 cp/parser.c:24774
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "預期 class-name"
 
-#: cp/parser.c:24978
+#: cp/parser.c:25013
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:24981
+#: cp/parser.c:25016
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "預期 %<;%>之後結構定義"
 
-#: cp/parser.c:24984
+#: cp/parser.c:25019
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/parser.c:25381
+#: cp/parser.c:25416
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "預期 %<{%>或 %<:%>"
 
-#: cp/parser.c:25392
+#: cp/parser.c:25427
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "無法指定 %<override%> 用於類別"
 
-#: cp/parser.c:25400
+#: cp/parser.c:25435
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "全域合格的類別名稱無效"
 
-#: cp/parser.c:25407
+#: cp/parser.c:25442
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "限定名稱不名稱類別"
 
-#: cp/parser.c:25419
+#: cp/parser.c:25454
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:25425
+#: cp/parser.c:25460
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD 的宣告中類別名無效"
 
-#: cp/parser.c:25479
+#: cp/parser.c:25514
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "明確特例化前必須有 %<template <>%>"
 
-#: cp/parser.c:25511
+#: cp/parser.c:25546
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函式模板 %qD redeclared 做為類別模板"
 
-#: cp/parser.c:25547
+#: cp/parser.c:25582
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "無法解析 typename 型態"
 
-#: cp/parser.c:25612
+#: cp/parser.c:25647
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T 的上一個定義"
 
-#: cp/parser.c:25712 cp/parser.c:31695
+#: cp/parser.c:25747 cp/parser.c:31749
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "預期 class-key"
 
-#: cp/parser.c:25736
+#: cp/parser.c:25771
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:25740
+#: cp/parser.c:25775
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:25983
+#: cp/parser.c:26018
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "在中 C++03 class-key 必須被使用時宣告朋友"
 
-#: cp/parser.c:26001
+#: cp/parser.c:26036
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:26019
+#: cp/parser.c:26054
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:26117
+#: cp/parser.c:26152
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:26124
+#: cp/parser.c:26159
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "對齊指定的用於未命名 bit-field"
 
-#: cp/parser.c:26137
+#: cp/parser.c:26172
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:26290
+#: cp/parser.c:26325
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bit-field %qD 與 non-integral 型態"
 
-#: cp/parser.c:26318
+#: cp/parser.c:26353
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函式定義上有 pure 指定"
 
-#: cp/parser.c:26338
+#: cp/parser.c:26373
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:26385
+#: cp/parser.c:26420
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:26399
+#: cp/parser.c:26434
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:26473
+#: cp/parser.c:26508
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "無效的 pure 說明符 (只有 %<=0%>被允許)"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26543
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "brace-enclosed 初始設定式未被允許在此"
 
-#: cp/parser.c:26638
+#: cp/parser.c:26673
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> 指定的一次以上在中 base-specified"
 
-#: cp/parser.c:26658
+#: cp/parser.c:26693
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "超過一個存取說明符在中 base-specified"
 
-#: cp/parser.c:26682
+#: cp/parser.c:26717
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:26685
+#: cp/parser.c:26720
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(基礎類別隱含地是一個類型)"
 
-#: cp/parser.c:26885 cp/parser.c:26979
+#: cp/parser.c:26920 cp/parser.c:27014
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "類型可能無法被定義在中 exception-specification"
 
-#: cp/parser.c:26987
+#: cp/parser.c:27022
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "由於不同的異常規格"
 
-#: cp/parser.c:26993
+#: cp/parser.c:27028
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "動態異常規格被不宜用在中 C++0x; 使用 %<noexcept%> 做為替代"
 
-#: cp/parser.c:27037
+#: cp/parser.c:27072
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:27078
+#: cp/parser.c:27113
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:27190
+#: cp/parser.c:27225
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:27797
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: cp/parser.c:27811
+#: cp/parser.c:27846
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要識別碼或 %<(%>"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:27900
+#: cp/parser.c:27935
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:27935
+#: cp/parser.c:27970
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs specified multiple times"
 msgstr "%qE 屬性未被支援用於 R8C 目標"
 
-#: cp/parser.c:27977
+#: cp/parser.c:28012
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:28037
+#: cp/parser.c:28072
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:28377 cp/parser.c:28386
+#: cp/parser.c:28415 cp/parser.c:28424
 #, fuzzy, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.c:28723
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:29073
+#: cp/parser.c:29127
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "要求的位置不是一個整數常數"
 
-#: cp/parser.c:29081
+#: cp/parser.c:29135
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求的對齊不是整數常數"
 
-#: cp/parser.c:29563
+#: cp/parser.c:29617
 #, fuzzy, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "專用化成員 %<%T::%E%>需求 %<模板<>%>語法specializing member %<%T::%E%> requires %<template<>%> syntax專用化成員 %<%T::%E%>需求 %<模板<>%>語法"
 
-#: cp/parser.c:29568
+#: cp/parser.c:29622
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無效的宣告的 %<%T::%E%>"
 
-#: cp/parser.c:29572
+#: cp/parser.c:29626
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "範本參數表太少"
@@ -56694,623 +56748,623 @@ msgstr "範本參數表太少"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:29579
+#: cp/parser.c:29633
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "範本參數表太多"
 
-#: cp/parser.c:29978
+#: cp/parser.c:30032
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "具名回傳值不再被支援"
 
-#: cp/parser.c:30149
+#: cp/parser.c:30203
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:30158
+#: cp/parser.c:30212
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:30164
+#: cp/parser.c:30218
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:30264
+#: cp/parser.c:30318
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.c:30274
+#: cp/parser.c:30328
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/parser.c:30297
+#: cp/parser.c:30351
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "無效的宣告的成員模板在中區域類別"
 
-#: cp/parser.c:30306
+#: cp/parser.c:30360
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C 連結的範本"
 
-#: cp/parser.c:30326
+#: cp/parser.c:30380
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "無效的明確的特殊化"
 
-#: cp/parser.c:30431
+#: cp/parser.c:30485
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "模板宣告的 %<typedef%>"
 
-#: cp/parser.c:30482
+#: cp/parser.c:30536
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "沒有宣告任何東西"
 
-#: cp/parser.c:30529
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "明確的模板特殊化無法有貯藏類別"
 
-#: cp/parser.c:30829
+#: cp/parser.c:30883
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%>應該是 %<>>%>在之內巢狀的模板引數清單"
 
-#: cp/parser.c:30842
+#: cp/parser.c:30896
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的 %<>>%>，使用 %<>%> 來結束範本引數清單"
 
-#: cp/parser.c:31150
+#: cp/parser.c:31204
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:31302
+#: cp/parser.c:31356
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "無效的使用的 %qD 在中連繫規格"
 
-#: cp/parser.c:31317
+#: cp/parser.c:31371
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>之前 %qD"
 
-#: cp/parser.c:31452
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++1998 不支援 %<long long%>"
 
-#: cp/parser.c:31463
+#: cp/parser.c:31517
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "宣告中同時使用了 %<short%> 和 %<char%>"
 
-#: cp/parser.c:31468
+#: cp/parser.c:31522
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重複的 %qE"
 
-#: cp/parser.c:31494
+#: cp/parser.c:31548
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重複的 %qs"
 
-#: cp/parser.c:31546
+#: cp/parser.c:31600
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "預期 %<new%>"
 
-#: cp/parser.c:31549
+#: cp/parser.c:31603
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "預期 %<delete%>"
 
-#: cp/parser.c:31552
+#: cp/parser.c:31606
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "預期 %<return%>"
 
-#: cp/parser.c:31558
+#: cp/parser.c:31612
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "預期 %<extern%>"
 
-#: cp/parser.c:31561
+#: cp/parser.c:31615
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "預期 %<static_assert%>"
 
-#: cp/parser.c:31564
+#: cp/parser.c:31618
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/parser.c:31567
+#: cp/parser.c:31621
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "預期 %<operator%>"
 
-#: cp/parser.c:31570
+#: cp/parser.c:31624
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "預期 %<class%>"
 
-#: cp/parser.c:31573
+#: cp/parser.c:31627
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "預期 %<template%>"
 
-#: cp/parser.c:31576
+#: cp/parser.c:31630
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "預期 %<namespace%>"
 
-#: cp/parser.c:31579
+#: cp/parser.c:31633
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "預期 %<using%>"
 
-#: cp/parser.c:31582
+#: cp/parser.c:31636
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "預期 %<asm%>"
 
-#: cp/parser.c:31585
+#: cp/parser.c:31639
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "預期 %<try%>"
 
-#: cp/parser.c:31588
+#: cp/parser.c:31642
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.c:31591
+#: cp/parser.c:31645
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "預期 %<throw%>"
 
-#: cp/parser.c:31594
+#: cp/parser.c:31648
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.c:31597
+#: cp/parser.c:31651
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "預期 %<__label__%>"
 
-#: cp/parser.c:31600
+#: cp/parser.c:31654
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "預期 %<@try%>"
 
-#: cp/parser.c:31603
+#: cp/parser.c:31657
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "預期 %<@synchronized%>"
 
-#: cp/parser.c:31606
+#: cp/parser.c:31660
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "預期 %<@throw%>"
 
-#: cp/parser.c:31609
+#: cp/parser.c:31663
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "預期 %<__transaction_atomic%>"
 
-#: cp/parser.c:31612
+#: cp/parser.c:31666
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "預期 %<__transaction_relaxed%>"
 
-#: cp/parser.c:31615
+#: cp/parser.c:31669
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "預期 %<@end%>"
 
-#: cp/parser.c:31647
+#: cp/parser.c:31701
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "預期 %<::%>"
 
-#: cp/parser.c:31659
+#: cp/parser.c:31713
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "預期 %<...%>"
 
-#: cp/parser.c:31662
+#: cp/parser.c:31716
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "預期 %<*%>"
 
-#: cp/parser.c:31665
+#: cp/parser.c:31719
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "預期 %<~%>"
 
-#: cp/parser.c:31671
+#: cp/parser.c:31725
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "預期 %<:%>或 %<::%>"
 
-#: cp/parser.c:31698
+#: cp/parser.c:31752
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:32000
+#: cp/parser.c:32054
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:32151
+#: cp/parser.c:32205
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了 %qs 標記，在命名 %q#T 時"
 
-#: cp/parser.c:32156
+#: cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T 是在之前宣告的在此"
 
-#: cp/parser.c:32276
+#: cp/parser.c:32330
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/parser.c:32416 cp/parser.c:32450
+#: cp/parser.c:32470 cp/parser.c:32504
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT 宣告的與更大可視性比它的基底 %qT"
 
-#: cp/parser.c:32423 cp/parser.c:32456
+#: cp/parser.c:32477 cp/parser.c:32510
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:32424 cp/parser.c:32457
+#: cp/parser.c:32478 cp/parser.c:32511
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "預期 class-key"
 
-#: cp/parser.c:32431
+#: cp/parser.c:32485
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "標貼 %qD 定義的在此"
 
-#: cp/parser.c:32432
+#: cp/parser.c:32486
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qD 宣告的在此"
 
-#: cp/parser.c:32514
+#: cp/parser.c:32568
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD 重宣告時有不同的可存取性"
 
-#: cp/parser.c:32535
+#: cp/parser.c:32589
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "做為消歧義的 %<template%> 只能用於範本內"
 
-#: cp/parser.c:32783
+#: cp/parser.c:32837
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "檔案在預設參數處結束"
 
-#: cp/parser.c:33024 cp/parser.c:34332 cp/parser.c:34521
+#: cp/parser.c:33078 cp/parser.c:34386 cp/parser.c:34575
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置錯誤的 %<@%D%> Objective-C++ 建構"
 
-#: cp/parser.c:33095
+#: cp/parser.c:33149
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:33165
+#: cp/parser.c:33219
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:33196
+#: cp/parser.c:33250
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> 必須指定一個類型做為引數"
 
-#: cp/parser.c:33600
+#: cp/parser.c:33654
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "無效的 Objective-C++ 選擇子名"
 
-#: cp/parser.c:33675 cp/parser.c:33693
+#: cp/parser.c:33729 cp/parser.c:33747
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "objective-c++ 方法宣告被預期"
 
-#: cp/parser.c:33687 cp/parser.c:33753
+#: cp/parser.c:33741 cp/parser.c:33807
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "方法屬性必須被指定的於結束"
 
-#: cp/parser.c:33796
+#: cp/parser.c:33850
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介於 Objective-C++ 方法"
 
-#: cp/parser.c:33993 cp/parser.c:34000 cp/parser.c:34007
+#: cp/parser.c:34047 cp/parser.c:34054 cp/parser.c:34061
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "無效的型態舉例來說變數"
 
-#: cp/parser.c:34124
+#: cp/parser.c:34178
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> 需要識別碼"
 
-#: cp/parser.c:34297
+#: cp/parser.c:34351
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "屬性可能無法被指定的之前 %<@%D%>Objective-C++ 關鍵字"
 
-#: cp/parser.c:34304
+#: cp/parser.c:34358
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "前綴屬性被忽略之前 %<@%D%>"
 
-#: cp/parser.c:34584 cp/parser.c:34591 cp/parser.c:34598
+#: cp/parser.c:34638 cp/parser.c:34645 cp/parser.c:34652
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "無效的型態用於內容"
 
-#: cp/parser.c:34760
+#: cp/parser.c:34814
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "不明內容屬性"
 
-#: cp/parser.c:35826
+#: cp/parser.c:35879
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "預期的整數運算式"
 
-#: cp/parser.c:35843
+#: cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.c:36826
+#: cp/parser.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:37579
+#: cp/parser.c:37632
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "類型可能無法被定義在中參數類型"
 
-#: cp/parser.c:39708
+#: cp/parser.c:39761
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
 
-#: cp/parser.c:40259
+#: cp/parser.c:40312
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:40346 cp/pt.c:17893
+#: cp/parser.c:40399 cp/pt.c:17976
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代變數 %qD 不應為消除"
 
-#: cp/parser.c:40439
+#: cp/parser.c:40492
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不足做迴圈用於崩潰 !$OMP 做於 %L"
 
-#: cp/parser.c:42655
+#: cp/parser.c:42708
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
 
-#: cp/parser.c:43486
+#: cp/parser.c:43539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:43516
+#: cp/parser.c:43569
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "預期 id-expression"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43581
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:43631
+#: cp/parser.c:43684
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在回傳類型中定義新類型"
 
-#: cp/parser.c:43651 cp/semantics.c:5850
+#: cp/parser.c:43704 cp/semantics.c:5878
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43655 cp/semantics.c:5858
+#: cp/parser.c:43708 cp/semantics.c:5886
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43658 cp/pt.c:14005 cp/semantics.c:5864
+#: cp/parser.c:43711 cp/pt.c:14072 cp/semantics.c:5892
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:43661 cp/semantics.c:5870
+#: cp/parser.c:43714 cp/semantics.c:5898
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:44188
+#: cp/parser.c:44241
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:44198
+#: cp/parser.c:44251
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD 不是一個成員範本函式"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:44552
+#: cp/parser.c:44605
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:44599 cp/semantics.c:9954
+#: cp/parser.c:44652 cp/semantics.c:9982
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:44601 cp/semantics.c:9956
+#: cp/parser.c:44654 cp/semantics.c:9984
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:44747
+#: cp/parser.c:44800
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>無法在之內外 %<__transaction_atomic%>"
 
-#: cp/parser.c:44750
+#: cp/parser.c:44803
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函式"
 
-#: cp/parser.c:44801
+#: cp/parser.c:44854
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "異常的 # pragma GCC 輔助處理器"
 
-#: cp/parser.c:45086
+#: cp/parser.c:45139
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<# pragma omp taskyield%>也許會只有被已用於複合陳述"
 
-#: cp/parser.c:45129
+#: cp/parser.c:45182
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:45161
+#: cp/parser.c:45214
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "# pragma GCC 選項未被允許內部函式"
 
-#: cp/parser.c:45241
+#: cp/parser.c:45294
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: cp/parser.c:45280
+#: cp/parser.c:45333
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "此上下文中不允許標準轉換"
 
-#: cp/parser.c:45481
+#: cp/parser.c:45534
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.c:45537
+#: cp/parser.c:45590
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:299
+#: cp/pt.c:297
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "資料成員 %qD 不能是成員範本"
 
-#: cp/pt.c:312
+#: cp/pt.c:310
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "無效的成員範本宣告 %qD"
 
-#: cp/pt.c:736
+#: cp/pt.c:734
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "明確特例化出現在非命名空間作用欄位 %qD 中"
 
-#: cp/pt.c:750
+#: cp/pt.c:748
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "所包含的類別範本並未被明確特例化"
 
-#: cp/pt.c:834
+#: cp/pt.c:832
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/pt.c:845 cp/pt.c:1078
+#: cp/pt.c:843 cp/pt.c:1080
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "在不同命名空間內對 %qD 的特例化"
 
-#: cp/pt.c:847
+#: cp/pt.c:845
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  從 %q+#D 的定義"
 
-#: cp/pt.c:864
+#: cp/pt.c:862
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qD 的明確實體化出現在命名空間 %qD 中，而後者並不包含命名空間 %qD"
 
-#: cp/pt.c:990
+#: cp/pt.c:992
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "名稱的類別陰影模板模板參數 %qD"
 
-#: cp/pt.c:1002
+#: cp/pt.c:1004
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/pt.c:1005 cp/pt.c:1144
+#: cp/pt.c:1007 cp/pt.c:1146
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.c:1037
+#: cp/pt.c:1039
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "%qT 的實體化在特例化之後"
 
-#: cp/pt.c:1081
+#: cp/pt.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -57318,150 +57372,150 @@ msgstr "  從 %q+#D 的定義"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1122
+#: cp/pt.c:1124
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "%qT 的實體化在 %qT 的特例化之後"
 
-#: cp/pt.c:1140
+#: cp/pt.c:1142
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "模板特殊化的 %qD 不允許由 ISO C++"
 
-#: cp/pt.c:1605
+#: cp/pt.c:1607
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "%qD 的特例化在實體化之後"
 
-#: cp/pt.c:2047 cp/semantics.c:5719
+#: cp/pt.c:2049 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2183
+#: cp/pt.c:2185
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD 不是一個函式範本"
 
-#: cp/pt.c:2188
+#: cp/pt.c:2190
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD 並非變數"
 
-#: cp/pt.c:2480
+#: cp/pt.c:2486
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "範本識別碼 %qD(屬於 %q+D)不匹配任何範本宣告"
 
-#: cp/pt.c:2484
+#: cp/pt.c:2490
 #, fuzzy, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "發現 %d %<template<>%>，需要 %d 用於專用化成員函式模板"
 
-#: cp/pt.c:2495
+#: cp/pt.c:2500
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "有歧義的範本特例化 %qD (為 %q+D)"
 
-#: cp/pt.c:2702
+#: cp/pt.c:2707
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:2712
+#: cp/pt.c:2717
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:2718
+#: cp/pt.c:2723
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2742
+#: cp/pt.c:2747
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "在初次使用後明確特例化 %qD"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2747
+#: cp/pt.c:2752
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%qD 的明確實體化出現在命名空間 %qD 中，而後者並不包含命名空間 %qD"
 
-#: cp/pt.c:2783
+#: cp/pt.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "在初次使用後明確特例化 %qD"
 
-#: cp/pt.c:2787
+#: cp/pt.c:2792
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:2788
+#: cp/pt.c:2793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:2878 cp/pt.c:2938
+#: cp/pt.c:2883 cp/pt.c:2943
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "範本識別碼 %qD 出現在基本範本的宣告中"
 
-#: cp/pt.c:2891
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "明確初始化中出現了範本參數清單"
 
-#: cp/pt.c:2897
+#: cp/pt.c:2902
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "為明確實體化提供的定義"
 
-#: cp/pt.c:2905
+#: cp/pt.c:2910
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD 宣告時範本參數表太多"
 
-#: cp/pt.c:2908
+#: cp/pt.c:2913
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD 宣告時範本參數表太少"
 
-#: cp/pt.c:2910
+#: cp/pt.c:2915
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD 的明確特例化必須由 %<template <>%> 引入"
 
-#: cp/pt.c:2916
+#: cp/pt.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.c:2949
+#: cp/pt.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "函式範本部分特例化 %qD 是不允許的"
 
-#: cp/pt.c:2953
+#: cp/pt.c:2958
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "函式範本部分特例化 %qD 是不允許的"
 
-#: cp/pt.c:2985
+#: cp/pt.c:2990
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "明確特例化時指定了預設參數"
 
-#: cp/pt.c:3028
+#: cp/pt.c:3033
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD 不是一個範本函式"
@@ -57474,168 +57528,168 @@ msgstr "%qD 不是一個範本函式"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3090
+#: cp/pt.c:3095
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "特例化了隱含宣告的特殊成員函式"
 
-#: cp/pt.c:3106
+#: cp/pt.c:3111
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "成員函式 %qD 未在 %qT 中宣告"
 
-#: cp/pt.c:3137
+#: cp/pt.c:3142
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "朋友宣告 %qD 在中區域類別而無需事前宣告"
 
-#: cp/pt.c:3140
+#: cp/pt.c:3145
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
 
-#: cp/pt.c:3249
+#: cp/pt.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.c:3830
+#: cp/pt.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "%L 處 ACOS 的參數必須在 -1 和 1 之間"
 
-#: cp/pt.c:4133
+#: cp/pt.c:4158
 #, fuzzy, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "基底初始設定式擴展 %<%T%>不含任何參數包裝"
 
-#: cp/pt.c:4201
+#: cp/pt.c:4226
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "擴展胚騰 %<%T%>不含任何引數包裝"
 
-#: cp/pt.c:4203
+#: cp/pt.c:4228
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "擴展胚騰 %<%E%>不含任何引數包裝"
 
-#: cp/pt.c:4262
+#: cp/pt.c:4287
 #, fuzzy, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "參數包裝無法展開的與 %<...%>："
 
-#: cp/pt.c:4279 cp/pt.c:5092
+#: cp/pt.c:4304 cp/pt.c:5109
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4281
+#: cp/pt.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.c:4407
+#: cp/pt.c:4432
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/pt.c:4410
+#: cp/pt.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/pt.c:4412
+#: cp/pt.c:4437
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "範本參數類型 %qT 宣告為 %<friend%>"
 
-#: cp/pt.c:5028
+#: cp/pt.c:5045
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/pt.c:5087
+#: cp/pt.c:5104
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到範本參數："
 
-#: cp/pt.c:5110
+#: cp/pt.c:5127
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.c:5114
+#: cp/pt.c:5131
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5118 cp/pt.c:5129 cp/pt.c:5137
+#: cp/pt.c:5135 cp/pt.c:5146 cp/pt.c:5154
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:5126
+#: cp/pt.c:5143
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5136
+#: cp/pt.c:5153
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "提供給函式 %qE 的引數太多"
 
-#: cp/pt.c:5150
+#: cp/pt.c:5167
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.c:5152
+#: cp/pt.c:5169
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:5198
+#: cp/pt.c:5215
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "參數包裝引數 %qE 必須是於結束的模板引數清單"
 
-#: cp/pt.c:5201
+#: cp/pt.c:5218
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "參數包裝引數 %qT 必須是於結束的模板引數清單"
 
-#: cp/pt.c:5224
+#: cp/pt.c:5241
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/pt.c:5270
+#: cp/pt.c:5287
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "型態 %qT 的模板引數 %qE 依存於模板參數"
 
-#: cp/pt.c:5330
+#: cp/pt.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:5334
+#: cp/pt.c:5351
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "局部特化的 %qT 之後實體化的 %qT"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5534
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 沒有預設參數"
@@ -57644,48 +57698,48 @@ msgstr "%qD 沒有預設參數"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5540
+#: cp/pt.c:5557
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "參數包裝 %qE 必須是於結束的模板參數清單"
 
-#: cp/pt.c:5576
+#: cp/pt.c:5593
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "預設模板引數可能無法被已用於函式模板朋友重新宣告"
 
-#: cp/pt.c:5579
+#: cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "預設模板引數可能無法被已用於函式模板朋友宣告"
 
-#: cp/pt.c:5582
+#: cp/pt.c:5599
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "預設模板引數可能無法被已用於函式模板而無需 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:5585
+#: cp/pt.c:5602
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "預設模板引數可能無法被已用於局部特化"
 
-#: cp/pt.c:5588 cp/pt.c:5646
+#: cp/pt.c:5605 cp/pt.c:5663
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:5757
+#: cp/pt.c:5774
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "參數 %qD 被宣告為 void"
 
-#: cp/pt.c:5765
+#: cp/pt.c:5782
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "範本類別沒具名字"
 
-#: cp/pt.c:5773
+#: cp/pt.c:5790
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
@@ -57695,500 +57749,500 @@ msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5796
+#: cp/pt.c:5813
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD 範本宣告無效"
 
-#: cp/pt.c:5952
+#: cp/pt.c:5969
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "對非範本 %q#D 的範本定義"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6008
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 級的 %q#D 範本參數，卻給出了 %d 級"
 
-#: cp/pt.c:6005
+#: cp/pt.c:6022
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 個範本參數，為 %q#D"
 
-#: cp/pt.c:6008
+#: cp/pt.c:6025
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "得到 %d 個範本參數，為 %q#T"
 
-#: cp/pt.c:6010
+#: cp/pt.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  但實際需要 %d 個"
 
-#: cp/pt.c:6031
+#: cp/pt.c:6048
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "模板引數到 %qD 不匹配原來的模板 %qD"
 
-#: cp/pt.c:6034
+#: cp/pt.c:6051
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用模板<>用於明確的特殊化"
 
-#: cp/pt.c:6179
+#: cp/pt.c:6196
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT 不是一個範本類型"
 
-#: cp/pt.c:6192
+#: cp/pt.c:6209
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD 的宣告中沒有 template 限定"
 
-#: cp/pt.c:6203
+#: cp/pt.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redeclared 與 %d 模板參數"
 
-#: cp/pt.c:6207
+#: cp/pt.c:6224
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "前一個宣告 %q+D 使用 %d 模板參數"
 
-#: cp/pt.c:6245
+#: cp/pt.c:6262
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "範本參數 %q+#D"
 
-#: cp/pt.c:6246
+#: cp/pt.c:6263
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在這裡又被宣告為 %q#D"
 
-#: cp/pt.c:6257
+#: cp/pt.c:6274
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/pt.c:6260 cp/pt.c:6309
+#: cp/pt.c:6277 cp/pt.c:6326
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6288
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定義 %q#D 的預設參數"
 
-#: cp/pt.c:6273
+#: cp/pt.c:6290
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.c:6306
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/pt.c:6637 cp/pt.c:6706
+#: cp/pt.c:6658 cp/pt.c:6727
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE 並非有效模板引數用於型態 %qT"
 
-#: cp/pt.c:6640
+#: cp/pt.c:6661
 #, fuzzy, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:6643
+#: cp/pt.c:6664
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:6656
+#: cp/pt.c:6677
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:6660
+#: cp/pt.c:6681
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6709
+#: cp/pt.c:6730
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必須是成員指標的形式 %<&X::Y%>"
 
-#: cp/pt.c:6711
+#: cp/pt.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD 不是 %qT 的成員"
 
-#: cp/pt.c:6773
+#: cp/pt.c:6794
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  無法 deduce 模板參數 %qD"
 
-#: cp/pt.c:6782
+#: cp/pt.c:6803
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  類型 %qT 和 %qT 有不相容的 cv-qualifiers"
 
-#: cp/pt.c:6791
+#: cp/pt.c:6812
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  不匹配的類型 %qT 和 %qT"
 
-#: cp/pt.c:6800
+#: cp/pt.c:6821
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  模板參數 %qD 並非參數包裝，但是引數 %qD 是"
 
-#: cp/pt.c:6811
+#: cp/pt.c:6832
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  模板引數 %qE 不匹配成員指標常數 %qE"
 
-#: cp/pt.c:6821
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE 不是 equivalent 到 %qE"
 
-#: cp/pt.c:6830
+#: cp/pt.c:6851
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  不一致參數包裝推導與 %qT 和 %qT"
 
-#: cp/pt.c:6842
+#: cp/pt.c:6863
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  deduced 衝突類型用於參數 %qT (%qT 和 %qT)"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6867
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 衝突值用於 non-type 參數 %qE (%qE 和 %qE)"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6868
+#: cp/pt.c:6889
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  成員函數型式 %qT 並非有效模板引數"
 
-#: cp/pt.c:6880
+#: cp/pt.c:6901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  candidate 預期 %d 引數，%d 提供"
 
-#: cp/pt.c:6911
+#: cp/pt.c:6932
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  無法轉換 %qE (型態 %qT) 輸入 %qT"
 
-#: cp/pt.c:6924
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT 是模稜兩可的基礎類別的 %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6949
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT 未被衍生自 %qT"
 
-#: cp/pt.c:6939
+#: cp/pt.c:6960
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板參數的模板模板引數是不一致與其他 deduced 模板引數"
 
-#: cp/pt.c:6949
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  無法 deduce 模板用於 %qT 從 non-template 型態 %qT"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6980
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  模板引數 %qE 不匹配 %qD"
 
-#: cp/pt.c:7021
+#: cp/pt.c:7042
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qE 並非變數"
 
-#: cp/pt.c:7029
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:7039
+#: cp/pt.c:7060
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:7054
+#: cp/pt.c:7075
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:7064
+#: cp/pt.c:7085
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:7071
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:7089
+#: cp/pt.c:7110
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:7097
+#: cp/pt.c:7118
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:7206
+#: cp/pt.c:7230
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為字面字串不能用在此上下文中"
 
-#: cp/pt.c:7365
+#: cp/pt.c:7389
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.c:7379
+#: cp/pt.c:7403
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.c:7465
+#: cp/pt.c:7489
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為 cv 限定衝突"
 
-#: cp/pt.c:7473
+#: cp/pt.c:7497
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是 lvalue"
 
-#: cp/pt.c:7491
+#: cp/pt.c:7515
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D 並非有效模板引數用於型態 %qT 因為參考變數沒有常數位址"
 
-#: cp/pt.c:7550
+#: cp/pt.c:7574
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它是一個指標"
 
-#: cp/pt.c:7552
+#: cp/pt.c:7576
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: cp/pt.c:7606
+#: cp/pt.c:7630
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它的類型是 %qT"
 
-#: cp/pt.c:8155
+#: cp/pt.c:8179
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:8171
+#: cp/pt.c:8195
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:8305
+#: cp/pt.c:8329
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD 使用的做為模板模板引數"
 
-#: cp/pt.c:8334
+#: cp/pt.c:8358
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "無效的使用的解構式 %qE 做為型態"
 
-#: cp/pt.c:8339
+#: cp/pt.c:8363
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某個範本參數的類型成員時，請使用 %<typename %E%>"
 
-#: cp/pt.c:8355 cp/pt.c:8389 cp/pt.c:8443
+#: cp/pt.c:8379 cp/pt.c:8413 cp/pt.c:8467
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:8363
+#: cp/pt.c:8387
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  需要一個 %qT 類型的常數，卻給出了 %qT"
 
-#: cp/pt.c:8371
+#: cp/pt.c:8395
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:8377
+#: cp/pt.c:8401
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  需要一個類別範本，卻給出了 %qE"
 
-#: cp/pt.c:8380
+#: cp/pt.c:8404
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:8394
+#: cp/pt.c:8418
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  需要一個類型，卻給出了 %qT"
 
-#: cp/pt.c:8397
+#: cp/pt.c:8421
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  需要一個類別範本，卻給出了 %qT"
 
-#: cp/pt.c:8447
+#: cp/pt.c:8471
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  預期的模板的型態 %qD，得到 %qT"
 
-#: cp/pt.c:8461
+#: cp/pt.c:8485
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:8464
+#: cp/pt.c:8488
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:8528
+#: cp/pt.c:8552
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能將範本參數從 %qE 轉換到 %qT"
 
-#: cp/pt.c:8666 cp/pt.c:8979
+#: cp/pt.c:8690 cp/pt.c:9003
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "範本參數 %d 無效"
 
-#: cp/pt.c:8681 cp/pt.c:8813
+#: cp/pt.c:8705 cp/pt.c:8837
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:8809
+#: cp/pt.c:8833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:8818
+#: cp/pt.c:8842
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供給 %q+D"
 
-#: cp/pt.c:8843
+#: cp/pt.c:8867
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:8847
+#: cp/pt.c:8871
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "為參數 %d (屬於 %q#D)指定了預設引數"
 
-#: cp/pt.c:8945
+#: cp/pt.c:8969
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9589
+#: cp/pt.c:9613
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D 並非函式模板"
 
-#: cp/pt.c:9752
+#: cp/pt.c:9776
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非範本類型 %qT 做為範本"
 
-#: cp/pt.c:9754
+#: cp/pt.c:9778
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "對於範本宣告 %q+D"
 
-#: cp/pt.c:9883 cp/pt.c:21201
+#: cp/pt.c:9907 cp/pt.c:21283
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "內部一致性錯誤"
 
-#: cp/pt.c:10280
+#: cp/pt.c:10287
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:10924
+#: cp/pt.c:10947
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d (使用 -ftemplate-depth=到增加最大值) 替代 %qS"
 
-#: cp/pt.c:12083
+#: cp/pt.c:12106
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexible 陣列成員在中聯合"
 
-#: cp/pt.c:12580
+#: cp/pt.c:12603
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12977
+#: cp/pt.c:13033
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE 沒有出現在宣告的開頭"
 
-#: cp/pt.c:13065
+#: cp/pt.c:13121
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "不匹配的引數包裝長度當展開 %<%T%>"
 
-#: cp/pt.c:13068
+#: cp/pt.c:13124
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "不匹配的引數包裝長度當展開 %<%E%>"
 
-#: cp/pt.c:13658
+#: cp/pt.c:13725
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定義 %q#D 的預設參數"
 
-#: cp/pt.c:13757
+#: cp/pt.c:13824
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員函式指標"
@@ -58206,298 +58260,298 @@ msgstr "產生非類別類型 %qT 的成員函式指標"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14830
+#: cp/pt.c:14913
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "變數 %qD 有函數型式"
 
-#: cp/pt.c:15030
+#: cp/pt.c:15113
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "無效的參數類型 %qT"
 
-#: cp/pt.c:15032
+#: cp/pt.c:15115
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在宣告 %q+D 中"
 
-#: cp/pt.c:15147
+#: cp/pt.c:15230
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函式回傳了一個陣列"
 
-#: cp/pt.c:15149
+#: cp/pt.c:15232
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函式回傳了一個函式"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15928
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成對 void 的參照"
 
-#: cp/pt.c:15847
+#: cp/pt.c:15930
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "表單指標到參考類型 %qT"
 
-#: cp/pt.c:15849
+#: cp/pt.c:15932
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "表單參考到參考類型 %qT"
 
-#: cp/pt.c:15862
+#: cp/pt.c:15945
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:15865
+#: cp/pt.c:15948
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:15913
+#: cp/pt.c:15996
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/pt.c:15919
+#: cp/pt.c:16002
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/pt.c:15925
+#: cp/pt.c:16008
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "建立參照 void 類型的成員指標"
 
-#: cp/pt.c:16026
+#: cp/pt.c:16109
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:16046
+#: cp/pt.c:16129
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT 不是類別、結構或聯合類型"
 
-#: cp/pt.c:16078
+#: cp/pt.c:16161
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT 被解析到非列舉類型 %qT"
 
-#: cp/pt.c:16086
+#: cp/pt.c:16169
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT 被解析到非類別類型 %qT"
 
-#: cp/pt.c:16200
+#: cp/pt.c:16283
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:16388
+#: cp/pt.c:16471
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定型態 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/pt.c:16403
+#: cp/pt.c:16486
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依賴名 %qE 被解析為非類型，但實體化卻產生了一個類型"
 
-#: cp/pt.c:16405
+#: cp/pt.c:16488
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定類型，請使用 %<typename %E%>"
 
-#: cp/pt.c:16498
+#: cp/pt.c:16581
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/pt.c:16649
+#: cp/pt.c:16732
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用無效欄位 %qD"
 
-#: cp/pt.c:17213 cp/pt.c:19086
+#: cp/pt.c:17296 cp/pt.c:19169
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "無效的使用的包裝擴展運算式"
 
-#: cp/pt.c:17217 cp/pt.c:19090
+#: cp/pt.c:17300 cp/pt.c:19173
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用 %<...%>到展開引數包裝"
 
-#: cp/pt.c:19230
+#: cp/pt.c:19313
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "ISO C++不允許初始設定式在中 lambda 運算式擷取清單"
 
-#: cp/pt.c:20286
+#: cp/pt.c:20368
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被宣告在中這個範圍，而找不到任何宣告是由 argument-dependent 查找於點的實體化"
 
-#: cp/pt.c:20313
+#: cp/pt.c:20395
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "宣告在中附屬基底 %qT 找不到由資格不符的查找"
 
-#: cp/pt.c:20318
+#: cp/pt.c:20400
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用 %<this->%D%>做為替代"
 
-#: cp/pt.c:20321
+#: cp/pt.c:20403
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用 %<%T::%D%>做為替代"
 
-#: cp/pt.c:20326
+#: cp/pt.c:20408
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: cp/pt.c:20374
+#: cp/pt.c:20456
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "錯誤的引數數量到 %<__builtin_choose_expr%>"
 
-#: cp/pt.c:20594
+#: cp/pt.c:20676
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/pt.c:20597
+#: cp/pt.c:20679
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD 既不是類別也不是命名空間"
 
-#: cp/pt.c:20919
+#: cp/pt.c:21001
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT 是/使用了匿名類型"
 
-#: cp/pt.c:20921
+#: cp/pt.c:21003
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "模板引數用於 %qD 使用本地型態 %qT"
 
-#: cp/pt.c:20931
+#: cp/pt.c:21013
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT 是一個可變類型"
 
-#: cp/pt.c:20946
+#: cp/pt.c:21028
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/pt.c:20964
+#: cp/pt.c:21046
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  試圖實體化 %qD"
 
-#: cp/pt.c:25055
+#: cp/pt.c:25142
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:25057
+#: cp/pt.c:25144
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:25063
+#: cp/pt.c:25150
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:25087 cp/pt.c:25182
+#: cp/pt.c:25174 cp/pt.c:25269
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:25093
+#: cp/pt.c:25180
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:25095
+#: cp/pt.c:25182
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:25114
+#: cp/pt.c:25201
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/pt.c:25120 cp/pt.c:25177
+#: cp/pt.c:25207 cp/pt.c:25264
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/pt.c:25125
+#: cp/pt.c:25212
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "型態 %qT 用於明確的實體化 %qD 不匹配宣告的型態 %qT"
 
-#: cp/pt.c:25133
+#: cp/pt.c:25220
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "對 %q#D 的明確實體化"
 
-#: cp/pt.c:25169
+#: cp/pt.c:25256
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "對 %q#D 重複的明確實體化"
 
-#: cp/pt.c:25192 cp/pt.c:25259
+#: cp/pt.c:25279 cp/pt.c:25346
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++1998 禁止使用的 %<extern%> 於明確的實體化"
 
-#: cp/pt.c:25197 cp/pt.c:25274
+#: cp/pt.c:25284 cp/pt.c:25361
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "為範本實體化化套用了存儲類型 %qD"
 
-#: cp/pt.c:25231
+#: cp/pt.c:25318
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "明確的實體化的 non-class 模板 %qD"
 
-#: cp/pt.c:25234
+#: cp/pt.c:25321
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "明確實體化非範本類型 %qT"
 
-#: cp/pt.c:25243
+#: cp/pt.c:25330
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T 的明確實體化出現在範本定義之前"
 
-#: cp/pt.c:25264
+#: cp/pt.c:25351
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允許在明確實體化時使用 %qE"
 
-#: cp/pt.c:25304
+#: cp/pt.c:25391
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "對 %q#T 重複的明確實體化"
 
-#: cp/pt.c:25647
+#: cp/pt.c:25685
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -58510,161 +58564,161 @@ msgstr "在初次使用後明確特例化 %qD"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:26148
+#: cp/pt.c:26186
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "明確實體化 %qD 時沒有可用的定義"
 
-#: cp/pt.c:26196
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d 舉例說明 %q+D, 可能會從虛擬表格產生 (使用 -ftemplate-depth=到增加最大值)"
 
-#: cp/pt.c:26562
+#: cp/pt.c:26600
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:26592
+#: cp/pt.c:26630
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.c:26601
+#: cp/pt.c:26639
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:26609
+#: cp/pt.c:26647
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/pt.c:26611
+#: cp/pt.c:26649
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.c:27965
+#: cp/pt.c:28003
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/pt.c:28246
+#: cp/pt.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/pt.c:28255
+#: cp/pt.c:28298
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT 不是一個命名空間"
 
-#: cp/pt.c:28282
+#: cp/pt.c:28325
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/pt.c:29286
+#: cp/pt.c:29348
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/pt.c:29293
+#: cp/pt.c:29354
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:29395
+#: cp/pt.c:29457
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:29402
+#: cp/pt.c:29464
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:29418
+#: cp/pt.c:29480
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.c:29426
+#: cp/pt.c:29488
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考慮內聯函式"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.c:29441
+#: cp/pt.c:29503
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.c:29445
+#: cp/pt.c:29507
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "間接函式 %q+D 無法宣告的 weakref"
 
-#: cp/pt.c:29461
+#: cp/pt.c:29523
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.c:29463
+#: cp/pt.c:29525
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.c:29529
+#: cp/pt.c:29589
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:29532
+#: cp/pt.c:29592
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29627
+#: cp/pt.c:29690
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:29629
+#: cp/pt.c:29692
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:29686
+#: cp/pt.c:29752
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29690
+#: cp/pt.c:29756
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:29694
+#: cp/pt.c:29760
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:29698
+#: cp/pt.c:29764
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:29834
+#: cp/pt.c:29900
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "無效的 non-type 模板引數"
@@ -58808,541 +58862,541 @@ msgstr "無法宣告 %q+#D"
 msgid "  since %q+#D declared in base class"
 msgstr "  因為 %q+#D 已在基礎類別中宣告過"
 
-#: cp/semantics.c:937
+#: cp/semantics.c:956
 #, fuzzy, gcc-internal-format
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "%qD 未被宣告 %<constexpr%>"
 
-#: cp/semantics.c:1085
+#: cp/semantics.c:1104
 #, fuzzy, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "建議明確的大括號周圍清空內文在中 %<do%> 敘述"
 
-#: cp/semantics.c:1603
+#: cp/semantics.c:1622
 #, gcc-internal-format
 msgid "catching polymorphic type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1608
+#: cp/semantics.c:1627
 #, gcc-internal-format
 msgid "catching type %q#T by value"
 msgstr ""
 
-#: cp/semantics.c:1613
+#: cp/semantics.c:1632
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "catching non-reference type %q#T"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/semantics.c:1823
+#: cp/semantics.c:1842
 #, fuzzy, gcc-internal-format
 #| msgid "type of asm operand %qE could not be determined"
 msgid "type of %<asm%> operand %qE could not be determined"
 msgstr "無法確定 asm 運算元 %qE 的類型"
 
-#: cp/semantics.c:1905
+#: cp/semantics.c:1924
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "__label__ 宣告是只有允許的在中函式範圍"
 
-#: cp/semantics.c:2090
+#: cp/semantics.c:2109
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "在靜態成員函式中使用成員 %q+D 無效"
 
-#: cp/semantics.c:2337
+#: cp/semantics.c:2356
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "不匹配的引數"
 
-#: cp/semantics.c:2397
+#: cp/semantics.c:2416
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2749
+#: cp/semantics.c:2768
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/semantics.c:2817
+#: cp/semantics.c:2836
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "解構函式不能有參數"
 
-#: cp/semantics.c:2899
+#: cp/semantics.c:2918
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "靜態成員函式中不能使用 %<this%>"
 
-#: cp/semantics.c:2901
+#: cp/semantics.c:2920
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "在非成員函式中使用 %<this%> 無效"
 
-#: cp/semantics.c:2903
+#: cp/semantics.c:2922
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "在頂層使用 %<this%> 無效"
 
-#: cp/semantics.c:2925
+#: cp/semantics.c:2944
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "偽解構函式名的限定作用欄位無效"
 
-#: cp/semantics.c:2933 cp/typeck.c:2763
+#: cp/semantics.c:2952 cp/typeck.c:2774
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的類型 %qT 不匹配解構函式名 ~%qT"
 
-#: cp/semantics.c:2955
+#: cp/semantics.c:2974
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE 的類型不是 %qT"
 
-#: cp/semantics.c:3035
+#: cp/semantics.c:3054
 #, fuzzy, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "複合實字的 non-object 型態 %qT"
 
-#: cp/semantics.c:3215
+#: cp/semantics.c:3233
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "範本參數必須使用 %<class%> 或 %<typename%> 關鍵字"
 
-#: cp/semantics.c:3265
+#: cp/semantics.c:3283
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "將類型 %qT 做為範本的範本參數的預設值無效"
 
-#: cp/semantics.c:3268
+#: cp/semantics.c:3286
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "範本的範本參數的預設引數無效"
 
-#: cp/semantics.c:3285
+#: cp/semantics.c:3303
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "在範本參數清單中定義了 %q#T"
 
-#: cp/semantics.c:3316
+#: cp/semantics.c:3334
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "對限定類型 %qT 的定義無效"
 
-#: cp/semantics.c:3599
+#: cp/semantics.c:3617
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "無效的基礎類別"
 
-#: cp/semantics.c:3762
+#: cp/semantics.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/semantics.c:3779 cp/semantics.c:10726
+#: cp/semantics.c:3797 cp/semantics.c:10754
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD 未被擷取"
 
-#: cp/semantics.c:3783
+#: cp/semantics.c:3801
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3785
+#: cp/semantics.c:3803
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3797
+#: cp/semantics.c:3815
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函式中使用 %<auto%> 變數"
 
-#: cp/semantics.c:3799
+#: cp/semantics.c:3817
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "在包含函式中使用參數"
 
-#: cp/semantics.c:3926
+#: cp/semantics.c:3944
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "使用的參數 %qD 外側函式內文"
 
-#: cp/semantics.c:3936
+#: cp/semantics.c:3954
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "不匹配的引數"
 
-#: cp/semantics.c:3972
+#: cp/semantics.c:3990
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "範本參數 %qD(類型為 %qT)不允許出現在整數運算式中，因為它的類型不是整數或列舉"
 
-#: cp/semantics.c:4003
+#: cp/semantics.c:4021
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "將類別範本 %qT 做為運算式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:4010
+#: cp/semantics.c:4028
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多繼承網格中對 %qD 的存取有歧義"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4056
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD 不能出現在常數運算式中"
 
-#: cp/semantics.c:4215
+#: cp/semantics.c:4243
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE 的類型不明"
 
-#: cp/semantics.c:4244
+#: cp/semantics.c:4272
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT 不是列舉類型型態"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4378
+#: cp/semantics.c:4406
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "參數包裝 __bases 只有有效在中模板宣告"
 
-#: cp/semantics.c:4410
+#: cp/semantics.c:4438
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "無法套用 %<offsetof%> 到解構式 %<~%T%>"
 
-#: cp/semantics.c:4423
+#: cp/semantics.c:4451
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:4427
+#: cp/semantics.c:4455
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:4432
+#: cp/semantics.c:4460
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:4443
+#: cp/semantics.c:4471
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4970 cp/semantics.c:6752 cp/semantics.c:6836
-#: cp/semantics.c:6887 cp/semantics.c:7229 cp/semantics.c:7450
-#: cp/semantics.c:7733 cp/semantics.c:8181
+#: cp/semantics.c:4998 cp/semantics.c:6780 cp/semantics.c:6864
+#: cp/semantics.c:6915 cp/semantics.c:7257 cp/semantics.c:7478
+#: cp/semantics.c:7761 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5716
+#: cp/semantics.c:5744
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/semantics.c:5990
+#: cp/semantics.c:6018
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:6040
+#: cp/semantics.c:6068
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: cp/semantics.c:6159
+#: cp/semantics.c:6187
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:6620
+#: cp/semantics.c:6648
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6635
+#: cp/semantics.c:6663
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:6659
+#: cp/semantics.c:6687
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6764 cp/semantics.c:8194
+#: cp/semantics.c:6792 cp/semantics.c:8222
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6849
+#: cp/semantics.c:6877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD 並非變數在中子句 %<firstprivate%>"
 
-#: cp/semantics.c:6900
+#: cp/semantics.c:6928
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD 並非變數在中子句 %<lastprivate%>"
 
-#: cp/semantics.c:6950
+#: cp/semantics.c:6978
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6964
+#: cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6998
+#: cp/semantics.c:7026
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7001
+#: cp/semantics.c:7029
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7005
+#: cp/semantics.c:7033
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7027
+#: cp/semantics.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:7031
+#: cp/semantics.c:7059
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:7036
+#: cp/semantics.c:7064
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:7063
+#: cp/semantics.c:7091
 #, fuzzy, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:7096
+#: cp/semantics.c:7124
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7110
+#: cp/semantics.c:7138
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: cp/semantics.c:7130
+#: cp/semantics.c:7158
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7159
+#: cp/semantics.c:7187
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7189
+#: cp/semantics.c:7217
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "切片結束必須是整數"
 
-#: cp/semantics.c:7211
+#: cp/semantics.c:7239
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:7240
+#: cp/semantics.c:7268
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:7255
+#: cp/semantics.c:7283
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7262
+#: cp/semantics.c:7290
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.c:7277
+#: cp/semantics.c:7305
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:7310
+#: cp/semantics.c:7338
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:7321
+#: cp/semantics.c:7349
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.c:7338
+#: cp/semantics.c:7366
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: cp/semantics.c:7350
+#: cp/semantics.c:7378
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:7359
+#: cp/semantics.c:7387
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.c:7460
+#: cp/semantics.c:7488
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7886
+#: cp/semantics.c:7914
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "太多 %qs 子句"
 
-#: cp/semantics.c:7890
+#: cp/semantics.c:7918
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7959
+#: cp/semantics.c:7987
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7989
+#: cp/semantics.c:8017
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:8019
+#: cp/semantics.c:8047
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:8032
+#: cp/semantics.c:8060
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/semantics.c:8055
+#: cp/semantics.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: cp/semantics.c:8065
+#: cp/semantics.c:8093
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:8122
+#: cp/semantics.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> 未被定義為一個指標類型"
 
-#: cp/semantics.c:8511
+#: cp/semantics.c:8539
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8738
+#: cp/semantics.c:8766
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD 不是檔案，命名空間或區塊範圍變數"
 
-#: cp/semantics.c:8752
+#: cp/semantics.c:8780
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE 指令無法在中 %qT 定義"
 
-#: cp/semantics.c:8949
+#: cp/semantics.c:8977
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "差異介於 %qE 和 %qD 沒有整數類型"
 
-#: cp/semantics.c:9415
+#: cp/semantics.c:9443
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:9718 cp/semantics.c:9728
+#: cp/semantics.c:9746 cp/semantics.c:9756
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:10133
+#: cp/semantics.c:10161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "靜態假設失敗：%s"
 
-#: cp/semantics.c:10136
+#: cp/semantics.c:10164
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "%qE evaluates to false"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: cp/semantics.c:10148
+#: cp/semantics.c:10176
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "non-constant 條件用於靜態假設"
 
-#: cp/semantics.c:10177
+#: cp/semantics.c:10205
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "引數到 decltype 必須是運算式"
 
-#: cp/semantics.c:10214
+#: cp/semantics.c:10242
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "decltype 無法解析位址的多載化函式"
 
-#: cp/semantics.c:10765
+#: cp/semantics.c:10793
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/semantics.c:10818
+#: cp/semantics.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/semantics.c:10820
+#: cp/semantics.c:10848
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10838
+#: cp/semantics.c:10866
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -59351,22 +59405,22 @@ msgstr "%<__builtin_return_address%> 的引數不受支援"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.c:10887
+#: cp/semantics.c:10915
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.c:10893
+#: cp/semantics.c:10921
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10920
+#: cp/semantics.c:10948
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.c:10928
+#: cp/semantics.c:10956
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
@@ -59376,1098 +59430,1099 @@ msgstr ""
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV 限定符不能套用到 %qT 上"
 
-#: cp/tree.c:1934
+#: cp/tree.c:1943
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/tree.c:4249
+#: cp/tree.c:4300
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4253
+#: cp/tree.c:4304
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.c:4256
+#: cp/tree.c:4307
 #, fuzzy, gcc-internal-format
 msgid " declared here"
 msgstr "宣告的在此"
 
-#: cp/tree.c:4261
+#: cp/tree.c:4312
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.c:4263
+#: cp/tree.c:4314
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4745
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "基礎類別 %qT 有 cv 限定"
 
-#: cp/tree.c:4687
+#: cp/tree.c:4748
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qD 未被擷取"
 
-#: cp/tree.c:4694
+#: cp/tree.c:4755
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD 並非變數"
 
-#: cp/tree.c:4702
+#: cp/tree.c:4763
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD 並非型態"
 
-#: cp/tree.c:4720
+#: cp/tree.c:4781
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qE 屬性引數不是字串常數"
 
-#: cp/tree.c:4735
+#: cp/tree.c:4796
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.c:4753
+#: cp/tree.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.c:4759
+#: cp/tree.c:4820
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.c:4779
+#: cp/tree.c:4840
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "%qE 屬性沒有任何效果"
 
-#: cp/tree.c:4783
+#: cp/tree.c:4844
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qE 屬性不套用輸入"
 
-#: cp/tree.c:4846
+#: cp/tree.c:4907
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "請求的 init_priority 不是一個整數常數"
 
-#: cp/tree.c:4868
+#: cp/tree.c:4929
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能將 %qE 屬性用於某個類別的物件的檔案作用欄位定義"
 
-#: cp/tree.c:4876
+#: cp/tree.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "請求的 init_priority 越界"
 
-#: cp/tree.c:4887
+#: cp/tree.c:4948
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "請求的 init_priority 保留為內部使用"
 
-#: cp/tree.c:4899
+#: cp/tree.c:4960
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE 屬性在此平臺上不受支援"
 
-#: cp/tree.c:4926
+#: cp/tree.c:4987
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/tree.c:4946
+#: cp/tree.c:5007
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/tree.c:4957
+#: cp/tree.c:5018
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.c:4970 cp/tree.c:4983
+#: cp/tree.c:5031 cp/tree.c:5044
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.c:4972
+#: cp/tree.c:5033
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.c:4985
+#: cp/tree.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.c:5009
+#: cp/tree.c:5070
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: cp/tree.c:5015
+#: cp/tree.c:5076
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:5022
+#: cp/tree.c:5083
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:5029
+#: cp/tree.c:5090
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:5051
+#: cp/tree.c:5112
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.c:5057
+#: cp/tree.c:5118
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.c:5937
+#: cp/tree.c:5998
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "零做為空指標常數"
 
-#: cp/tree.c:5959
+#: cp/tree.c:6020
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失敗，於 %s:%d"
 
-#: cp/typeck.c:467
+#: cp/typeck.c:478
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "比較介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:473
+#: cp/typeck.c:484
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "轉換介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:479
+#: cp/typeck.c:490
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "條件運算式介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:627
+#: cp/typeck.c:638
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++禁止比較介於指標的型態 %<void *%> 和 pointer-to-function"
 
-#: cp/typeck.c:632
+#: cp/typeck.c:643
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++禁止轉換介於指標的型態 %<void *%> 和 pointer-to-function"
 
-#: cp/typeck.c:637
+#: cp/typeck.c:648
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++禁止條件運算式介於指標的型態 %<void *%> 和 pointer-to-function"
 
-#: cp/typeck.c:716
+#: cp/typeck.c:727
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "比較介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:721
+#: cp/typeck.c:732
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "轉換介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:726
+#: cp/typeck.c:737
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "條件運算式介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:1547
+#: cp/typeck.c:1558
 #, fuzzy, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "權威的類型不同用於相等的類型 %T 和 %T"
 
-#: cp/typeck.c:1554
+#: cp/typeck.c:1565
 #, fuzzy, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "相同權威的型態節點用於不同的類型 %T 和 %T"
 
-#: cp/typeck.c:1714
+#: cp/typeck.c:1725
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%qs 用於成員函式無效"
 
-#: cp/typeck.c:1812
+#: cp/typeck.c:1823
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "無效的應用程式的 %<sizeof%> 到 bit-field"
 
-#: cp/typeck.c:1820
+#: cp/typeck.c:1831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++禁止套用 %<sizeof%> 到運算式的函數型式"
 
-#: cp/typeck.c:1885
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "無效的應用程式的 %<__alignof%>到 bit-field"
 
-#: cp/typeck.c:1896
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++禁止套用 %<__alignof%>到運算式的函數型式"
 
-#: cp/typeck.c:1978
+#: cp/typeck.c:1989
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/typeck.c:2023
+#: cp/typeck.c:2034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/typeck.c:2191
+#: cp/typeck.c:2202
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "需位址的暫時的陣列"
 
-#: cp/typeck.c:2373
+#: cp/typeck.c:2384
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "不宜用轉換從字串常數到 %qT"
 
-#: cp/typeck.c:2377
+#: cp/typeck.c:2388
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "不宜用轉換從字串常數到 %qT"
 
-#: cp/typeck.c:2513 cp/typeck.c:3078
+#: cp/typeck.c:2524 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "要求用於成員 %qD 在中 %qE，該項是的指標類型 %qT (也許您 meant 以使用 %<->%> ?)"
 
-#: cp/typeck.c:2517 cp/typeck.c:3082
+#: cp/typeck.c:2528 cp/typeck.c:3093
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "對成員 %qD 的請求出現在 %qE 中，而後者具有非類別類型 %qT"
 
-#: cp/typeck.c:2548
+#: cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "對非靜態資料成員 %qE 的使用無效"
 
-#: cp/typeck.c:2628
+#: cp/typeck.c:2639
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "無效的存取到非靜態資料成員 %qD  的空值物件"
 
-#: cp/typeck.c:2778
+#: cp/typeck.c:2789
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "物件類型 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/typeck.c:2787
+#: cp/typeck.c:2798
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "被解構的類型是 %qT，但解構函式卻使用了 %qT"
 
-#: cp/typeck.c:2929
+#: cp/typeck.c:2940
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2948
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: cp/typeck.c:2971
+#: cp/typeck.c:2982
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2982
+#: cp/typeck.c:2993
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2997
+#: cp/typeck.c:3008
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: cp/typeck.c:3112 cp/typeck.c:3138
+#: cp/typeck.c:3123 cp/typeck.c:3149
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> 不是 %qT 的成員"
 
-#: cp/typeck.c:3177
+#: cp/typeck.c:3188
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT 不是 %qT 的基礎類別"
 
-#: cp/typeck.c:3230
+#: cp/typeck.c:3241
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD 不是一個成員範本函式"
 
-#: cp/typeck.c:3433
+#: cp/typeck.c:3444
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT 不是一個參照物件的類型"
 
-#: cp/typeck.c:3465
+#: cp/typeck.c:3476
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "無效的使用的陣列索引於成員指標"
 
-#: cp/typeck.c:3468
+#: cp/typeck.c:3479
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "無效的使用的一元 %<*%>於成員指標"
 
-#: cp/typeck.c:3471
+#: cp/typeck.c:3482
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "無效的使用的隱含轉換於成員指標"
 
-#: cp/typeck.c:3475
+#: cp/typeck.c:3486
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3540
+#: cp/typeck.c:3551
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "陣列參照缺少下標"
 
-#: cp/typeck.c:3637
+#: cp/typeck.c:3648
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下標存取宣告為 %<register%> 的陣列"
 
-#: cp/typeck.c:3675
+#: cp/typeck.c:3686
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下標運算的左運算元既非陣列也非指標"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3758
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用 %qE 時缺少物件"
 
-#: cp/typeck.c:3972
+#: cp/typeck.c:3983
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允許在程式裡呼叫 %<::main%>"
 
-#: cp/typeck.c:3993
+#: cp/typeck.c:4004
 #, fuzzy, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必須使用 %<.*%>或 %<->*%> 到呼叫成員指標函式在中 %<%E (...)%>，例如： %<(...->* %E) (...)%>"
 
-#: cp/typeck.c:4010
+#: cp/typeck.c:4021
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:4013
+#: cp/typeck.c:4024
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:4016
+#: cp/typeck.c:4027
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:4074
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/typeck.c:4075
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "太少引數到建構子 %q#D"
 
-#: cp/typeck.c:4080
+#: cp/typeck.c:4091
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "太多引數到成員函式 %q#D"
 
-#: cp/typeck.c:4081
+#: cp/typeck.c:4092
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "太少引數到成員函式 %q#D"
 
-#: cp/typeck.c:4087
+#: cp/typeck.c:4098
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "太多引數到函式 %q#D"
 
-#: cp/typeck.c:4088
+#: cp/typeck.c:4099
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "太少引數到函式 %q#D"
 
-#: cp/typeck.c:4098
+#: cp/typeck.c:4109
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "太多引數到方法 %q#D"
 
-#: cp/typeck.c:4099
+#: cp/typeck.c:4110
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "太少引數到方法 %q#D"
 
-#: cp/typeck.c:4102
+#: cp/typeck.c:4113
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "給予函式的引數太多"
 
-#: cp/typeck.c:4103
+#: cp/typeck.c:4114
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "給予函式的引數太少"
 
-#: cp/typeck.c:4185
+#: cp/typeck.c:4196
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "參數 %P (屬於 %qD)的類型 %qT 不完全"
 
-#: cp/typeck.c:4191
+#: cp/typeck.c:4202
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "參數 %P 的類型 %qT 不完全"
 
-#: cp/typeck.c:4440
+#: cp/typeck.c:4451
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "位址的 %qD 將永不是空值"
 
-#: cp/typeck.c:4451
+#: cp/typeck.c:4462
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "比較將一律評估做為 %<true%> 用於位址的 %qD 將永不是空值"
 
-#: cp/typeck.c:4497
+#: cp/typeck.c:4508
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "轉換介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:4502
+#: cp/typeck.c:4513
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "比較介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:4532
+#: cp/typeck.c:4543
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4536
+#: cp/typeck.c:4547
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "轉換從指標類型 %qT 到算術型式 %qT 在中 constant-expression"
 
-#: cp/typeck.c:4545
+#: cp/typeck.c:4556
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4549
+#: cp/typeck.c:4560
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.c:4675 cp/typeck.c:4687
+#: cp/typeck.c:4686 cp/typeck.c:4698
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定從多載函式轉換到類型 %qT"
 
-#: cp/typeck.c:4733
+#: cp/typeck.c:4744
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算術運算式中使用了 NULL"
 
-#: cp/typeck.c:5189 cp/typeck.c:5198 cp/typeck.c:5491 cp/typeck.c:5500
+#: cp/typeck.c:5200 cp/typeck.c:5209 cp/typeck.c:5502 cp/typeck.c:5511
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允許比較指標和整數的值"
 
-#: cp/typeck.c:5404 cp/typeck.c:5417
+#: cp/typeck.c:5415 cp/typeck.c:5428
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/typeck.c:5440
+#: cp/typeck.c:5451
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5472 cp/typeck.c:5480
+#: cp/typeck.c:5483 cp/typeck.c:5491
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "指標與整數 0 比較大小"
 
-#: cp/typeck.c:5530
+#: cp/typeck.c:5541
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮點引數間的無效比較"
 
-#: cp/typeck.c:5576
+#: cp/typeck.c:5587
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
 
-#: cp/typeck.c:5656
+#: cp/typeck.c:5667
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "運算元類型 %qT 和 %qT 對二進位 %qO 而言無效"
 
-#: cp/typeck.c:6008
+#: cp/typeck.c:6019
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允許在減法中使用類型為 %<void *%> 的指標"
 
-#: cp/typeck.c:6016
+#: cp/typeck.c:6027
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允許在減法中使用函式指標"
 
-#: cp/typeck.c:6024
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允許在減法中使用參照方法的指標"
 
-#: cp/typeck.c:6077
+#: cp/typeck.c:6088
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指標算術中使用參照不完全類型的指標無效"
 
-#: cp/typeck.c:6156
+#: cp/typeck.c:6167
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "需位址的建構子 %qE"
 
-#: cp/typeck.c:6157
+#: cp/typeck.c:6168
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/typeck.c:6173
+#: cp/typeck.c:6184
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用 %qE 形成成員函式指標的用法無效。"
 
-#: cp/typeck.c:6176
+#: cp/typeck.c:6187
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  需要一個限定的識別碼"
 
-#: cp/typeck.c:6183
+#: cp/typeck.c:6194
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parentheses 周圍 %qE 無法用來表單成員函式指標"
 
-#: cp/typeck.c:6369
+#: cp/typeck.c:6380
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過提取一個未限定的或帶括號的非靜態成員函式的位址來形成一個成員函式指標。請使用 %<&%T::%D%>"
 
-#: cp/typeck.c:6375
+#: cp/typeck.c:6386
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過取已繫結的成員函式的位址來建構成員函式指標。請改用 %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6410
+#: cp/typeck.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "取臨時變數的位址"
 
-#: cp/typeck.c:6427
+#: cp/typeck.c:6438
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允許取函式 %<::main%> 的位址"
 
-#: cp/typeck.c:6485
+#: cp/typeck.c:6496
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能建立參照參照成員 %qD 的指標"
 
-#: cp/typeck.c:6505
+#: cp/typeck.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "無法取得位元段 %qD 的位址"
 
-#: cp/typeck.c:6521
+#: cp/typeck.c:6532
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/typeck.c:6668
+#: cp/typeck.c:6679
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "需位址的運算式的型態 %<void%>"
 
-#: cp/typeck.c:6669
+#: cp/typeck.c:6680
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6792
+#: cp/typeck.c:6803
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/typeck.c:6793
+#: cp/typeck.c:6804
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++禁止遞減 enum"
 
-#: cp/typeck.c:6809
+#: cp/typeck.c:6820
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "無法遞增指標到不完整型態 %qT"
 
-#: cp/typeck.c:6811
+#: cp/typeck.c:6822
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "無法遞減指標到不完整型態 %qT"
 
-#: cp/typeck.c:6823
+#: cp/typeck.c:6834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞增指標的型態 %qT"
 
-#: cp/typeck.c:6825
+#: cp/typeck.c:6836
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞減指標的型態 %qT"
 
-#: cp/typeck.c:6864
+#: cp/typeck.c:6875
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6877
+#: cp/typeck.c:6888
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6887
+#: cp/typeck.c:6898
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6895
+#: cp/typeck.c:6906
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:7075
+#: cp/typeck.c:7086
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "無法取右值運算式 %<this%> 的位址"
 
-#: cp/typeck.c:7097
+#: cp/typeck.c:7108
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求明確暫存器變數 %qD 的位址。"
 
-#: cp/typeck.c:7102
+#: cp/typeck.c:7113
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "請求宣告為 %<register%> 的 %qD 的位址"
 
-#: cp/typeck.c:7177
+#: cp/typeck.c:7188
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "list-initializer 用於 non-class 型態必須不被 parenthesized"
 
-#: cp/typeck.c:7189
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "運算式清單視為複合式表示式在中初始設定式"
 
-#: cp/typeck.c:7193
+#: cp/typeck.c:7204
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "運算式清單視為複合式表示式在中 mem-initializer"
 
-#: cp/typeck.c:7197
+#: cp/typeck.c:7208
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "運算式清單視為複合式表示式在中 functional 演員陣容"
 
-#: cp/typeck.c:7234
+#: cp/typeck.c:7245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 運算式清單被看作複合運算式"
 
-#: cp/typeck.c:7321
+#: cp/typeck.c:7332
 #, fuzzy, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "沒有語境到解析型態的 %qE"
 
-#: cp/typeck.c:7355
+#: cp/typeck.c:7366
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "演員陣容從型態 %qT 輸入 %qT 演員陣容暫離限定元"
 
-#: cp/typeck.c:7361
+#: cp/typeck.c:7372
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "staticcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.c:7368
+#: cp/typeck.c:7379
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.c:7392
+#: cp/typeck.c:7403
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "%qT 使用了局部類型 %qT"
 
-#: cp/typeck.c:7406
+#: cp/typeck.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/typeck.c:7843
+#: cp/typeck.c:7854
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 static_cast 無效"
 
-#: cp/typeck.c:7849 cp/typeck.c:7855 cp/typeck.c:9510
+#: cp/typeck.c:7860 cp/typeck.c:7866 cp/typeck.c:9517
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/typeck.c:7881
+#: cp/typeck.c:7892
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "從 %qT 轉換到 %qT"
 
-#: cp/typeck.c:7956
-#, gcc-internal-format
-msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#: cp/typeck.c:7963
+#, fuzzy, gcc-internal-format
+#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "從具有類型 %qT 的右值運算式到類型 %qT 中的轉換無效"
 
-#: cp/typeck.c:8026
+#: cp/typeck.c:8033
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "從 %qT 到 %qT 的轉換損失精度"
 
-#: cp/typeck.c:8051
+#: cp/typeck.c:8058
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8062
+#: cp/typeck.c:8069
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "比較介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:8083 cp/typeck.c:8273
+#: cp/typeck.c:8090 cp/typeck.c:8280
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "從 %qT 到 %qT 的轉換增大了目的類型的對齊需求"
 
-#: cp/typeck.c:8100
+#: cp/typeck.c:8107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允許在函式指標和物件指標間進行轉換"
 
-#: cp/typeck.c:8114
+#: cp/typeck.c:8121
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/typeck.c:8187
+#: cp/typeck.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它既不是指標，也不是參照，也不是資料成員指標"
 
-#: cp/typeck.c:8196
+#: cp/typeck.c:8203
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它是一個指標函式類型的指標或參照"
 
-#: cp/typeck.c:8238
+#: cp/typeck.c:8245
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.c:8308
+#: cp/typeck.c:8315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.c:8409 cp/typeck.c:8418
+#: cp/typeck.c:8416 cp/typeck.c:8425
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允許轉換為陣列類型 %qT"
 
-#: cp/typeck.c:8427
+#: cp/typeck.c:8434
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函式類型 %qT 的轉換無效"
 
-#: cp/typeck.c:8737
+#: cp/typeck.c:8744
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8757
+#: cp/typeck.c:8764
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  在求 %<%Q(%#T, %#T)%> 值時"
 
-#: cp/typeck.c:8817
+#: cp/typeck.c:8824
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "指派到陣列從初始設定式清單"
 
-#: cp/typeck.c:8844
+#: cp/typeck.c:8851
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "將 %qT 賦值給 %qT 時類型不相容"
 
-#: cp/typeck.c:8858
+#: cp/typeck.c:8865
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "陣列使用的做為初始設定式"
 
-#: cp/typeck.c:8860
+#: cp/typeck.c:8867
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "無效的陣列指派"
 
-#: cp/typeck.c:8997
+#: cp/typeck.c:9004
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "  在成員函式指標轉換中"
 
-#: cp/typeck.c:9011
+#: cp/typeck.c:9018
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成員指標轉換經由虛基礎類別 %qT"
 
-#: cp/typeck.c:9058 cp/typeck.c:9077
+#: cp/typeck.c:9065 cp/typeck.c:9084
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "  在成員指標轉換中"
 
-#: cp/typeck.c:9158
+#: cp/typeck.c:9165
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到類型 %qT 的轉換無效，從類型 %qT"
 
-#: cp/typeck.c:9473
+#: cp/typeck.c:9480
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "無法轉換 %qT 到 %qT 在中預設引數"
 
-#: cp/typeck.c:9478
+#: cp/typeck.c:9485
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "無法轉換 %qT 到 %qT 在中引數傳遞"
 
-#: cp/typeck.c:9487
+#: cp/typeck.c:9494
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/typeck.c:9491
+#: cp/typeck.c:9498
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "無法轉換 %qT 到 %qT 在中回傳"
 
-#: cp/typeck.c:9496
+#: cp/typeck.c:9503
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "無法轉換 %qT 到 %qT 在中指派"
 
-#: cp/typeck.c:9528
+#: cp/typeck.c:9535
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "參數 %qP 的 %qD 也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9539
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "參數也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9537
+#: cp/typeck.c:9544
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "目標的轉換也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9542
+#: cp/typeck.c:9549
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "目標的初始化也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9552
+#: cp/typeck.c:9559
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "left-hand 側邊的指派也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9648
+#: cp/typeck.c:9655
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在傳遞引數 %P (屬於 %q+D)"
 
-#: cp/typeck.c:9730
+#: cp/typeck.c:9737
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "回傳臨時變數的參照"
 
-#: cp/typeck.c:9733
+#: cp/typeck.c:9740
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9769
+#: cp/typeck.c:9776
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "回傳了對局部變數的 %q+D 的參照"
 
-#: cp/typeck.c:9773
+#: cp/typeck.c:9780
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9779
+#: cp/typeck.c:9786
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:9783
+#: cp/typeck.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:9982
+#: cp/typeck.c:9989
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9984 cp/typeck.c:10007
+#: cp/typeck.c:9991 cp/typeck.c:10014
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:10006
+#: cp/typeck.c:10013
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "太多值在中回傳敘述"
 
-#: cp/typeck.c:10045
+#: cp/typeck.c:10052
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "解構函式回傳值"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:10053
+#: cp/typeck.c:10060
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能從建構式的異常處理中回傳"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:10056
+#: cp/typeck.c:10063
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "建構式回傳值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:10091 cp/typeck.c:10137
+#: cp/typeck.c:10098 cp/typeck.c:10144
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.c:10099
+#: cp/typeck.c:10106
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<brace-enclosed initializer list>"
 
-#: cp/typeck.c:10118
+#: cp/typeck.c:10125
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "不一致類型 %qT 和 %qT deduced 用於 lambda 傳回類型"
 
-#: cp/typeck.c:10121
+#: cp/typeck.c:10128
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/typeck.c:10156
+#: cp/typeck.c:10163
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.c:10185
+#: cp/typeck.c:10192
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> 不能回傳 NULL，除非它被宣告為 %<throw()%> (或 -fcheck-new 起作用)"
 
-#: cp/typeck.c:10828
+#: cp/typeck.c:10838
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "使用暫時的做為 lvalue"
@@ -60743,111 +60798,106 @@ msgstr "標量初始化帶大括號"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "不可使用複合原文初始化類型為 %qT 的聚集"
 
-#: cp/typeck2.c:1586 cp/typeck2.c:1616
+#: cp/typeck2.c:1583 cp/typeck2.c:1613
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/typeck2.c:1593
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1600
+#: cp/typeck2.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1691
+#: cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "型態的 %qD 不匹配原來的宣告"
 
-#: cp/typeck2.c:1764
+#: cp/typeck2.c:1761
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的聯合中找不到欄位 %qD"
 
-#: cp/typeck2.c:1775
+#: cp/typeck2.c:1772
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在聯合初始值設定中出現了索引值而不是欄位名"
 
-#: cp/typeck2.c:1969
+#: cp/typeck2.c:1966
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "偵測到循環指標代理"
 
-#: cp/typeck2.c:1983
+#: cp/typeck2.c:1980
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> 的基運算元具有非指標類型 %qT"
 
-#: cp/typeck2.c:2013
+#: cp/typeck2.c:2010
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> 的結果給出了非指標的結果"
 
-#: cp/typeck2.c:2015
+#: cp/typeck2.c:2012
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> 的左運算元不是一個指標"
 
-#: cp/typeck2.c:2042
+#: cp/typeck2.c:2039
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE 不能做為成員指標，因為它的類型為 %qT"
 
-#: cp/typeck2.c:2051
+#: cp/typeck2.c:2048
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "無法套用成員指標 %qE 到 %qE，該項是的 non-class 型態 %qT"
 
-#: cp/typeck2.c:2073
+#: cp/typeck2.c:2070
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成員指標類型 %qT 與物件類型 %qT 不相容"
 
-#: cp/typeck2.c:2131
+#: cp/typeck2.c:2128
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:2142
+#: cp/typeck2.c:2139
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:2150
+#: cp/typeck2.c:2147
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:2191
+#: cp/typeck2.c:2188
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "functional 演員陣容到陣列類型 %qT"
 
-#: cp/typeck2.c:2213
-#, fuzzy, gcc-internal-format
-msgid "cannot deduce template arguments for %qT from %<()%>"
-msgstr "在中模板引數用於型態 %qT "
-
-#: cp/typeck2.c:2233
+#: cp/typeck2.c:2219
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: cp/typeck2.c:2474
+#: cp/typeck2.c:2460
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "呼叫的函式 %qD 會拋出不完全的類型 %q#T"
 
-#: cp/typeck2.c:2477
+#: cp/typeck2.c:2463
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "呼叫的函式會拋出不完全的類型 %q#T"
@@ -60867,289 +60917,295 @@ msgstr ""
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:134
+#: d/dmd/dsymbolsem.c:136
 #, gcc-internal-format
 msgid "missing or corrupt object.d"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:182
+#: d/dmd/dsymbolsem.c:184
 #, gcc-internal-format
 msgid "%p has no semantic routine"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:304
+#: d/dmd/dsymbolsem.c:306
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "extern symbols cannot have initializers"
 msgstr "外部「%s」在 %L 處不能有初始值設定"
 
-#: d/dmd/dsymbolsem.c:385
+#: d/dmd/dsymbolsem.c:387
 #, fuzzy, gcc-internal-format
 msgid "__gshared not allowed in safe functions; use shared"
 msgstr "asm 不允許在中 %<transaction_safe%> 函式"
 
-#: d/dmd/dsymbolsem.c:397
+#: d/dmd/dsymbolsem.c:399
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is inferred from initializer %s, and variables cannot be of type void"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:401
+#: d/dmd/dsymbolsem.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variables cannot be of type void"
 msgstr "可變大小的物件不能被初始化"
 
-#: d/dmd/dsymbolsem.c:407
+#: d/dmd/dsymbolsem.c:409
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "cannot be declared to be a function"
 msgstr "new 不能用於函式類型"
 
-#: d/dmd/dsymbolsem.c:416
+#: d/dmd/dsymbolsem.c:418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redefinition of %<struct %E%>"
-msgid "no definition of struct %s"
+msgid "no definition of struct `%s`"
 msgstr "%<struct %E%> 重定義"
 
-#: d/dmd/dsymbolsem.c:420
+#: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if type is not inferred, did you mean `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:605
+#: d/dmd/dsymbolsem.c:619
 #, gcc-internal-format
 msgid "cannot be final, perhaps you meant const?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:610
+#: d/dmd/dsymbolsem.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be %s"
 msgstr "無法開啟 %s"
 
-#: d/dmd/dsymbolsem.c:622
+#: d/dmd/dsymbolsem.c:636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "cannot be `scope` and `%s`"
 msgstr "無法開啟 %s"
 
-#: d/dmd/dsymbolsem.c:626
+#: d/dmd/dsymbolsem.c:640
 #, fuzzy, gcc-internal-format
 msgid "field cannot be `scope`"
 msgstr "weak %q+D 無法定義 %qE"
 
-#: d/dmd/dsymbolsem.c:659
+#: d/dmd/dsymbolsem.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "Use the Cygwin interface"
 msgid "field not allowed in interface"
 msgstr "使用 Cygwin 介面"
 
-#: d/dmd/dsymbolsem.c:663
+#: d/dmd/dsymbolsem.c:677
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot be further field because it will change the determined %s size"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:684
+#: d/dmd/dsymbolsem.c:698
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot use template to add field to aggregate `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:691
+#: d/dmd/dsymbolsem.c:705
 #, gcc-internal-format
 msgid "only parameters or foreach declarations can be ref"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:700
+#: d/dmd/dsymbolsem.c:714
 #, gcc-internal-format
 msgid "only parameters or stack based variables can be inout"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:718
+#: d/dmd/dsymbolsem.c:732
 #, fuzzy, gcc-internal-format
 #| msgid "variable-size type declared outside of any function"
 msgid "inout variables can only be declared inside inout functions"
 msgstr "變長類型的宣告出現在所有函式之外"
 
-#: d/dmd/dsymbolsem.c:737
+#: d/dmd/dsymbolsem.c:751
 #, gcc-internal-format, gfc-internal-format
 msgid "default construction is disabled for type %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:746
+#: d/dmd/dsymbolsem.c:760
 #, gcc-internal-format
 msgid "globals, statics, fields, manifest constants, ref and out parameters cannot be scope"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:752
+#: d/dmd/dsymbolsem.c:766
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to scope class must be scope"
 msgstr "需要敘述"
 
-#: d/dmd/dsymbolsem.c:762 d/dmd/dsymbolsem.c:769
+#: d/dmd/dsymbolsem.c:776 d/dmd/dsymbolsem.c:783
 #, fuzzy, gcc-internal-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "void initializers for pointers not allowed in safe functions"
 msgstr "將初始化為零的資料存放在 bss 區段中"
 
-#: d/dmd/dsymbolsem.c:782
+#: d/dmd/dsymbolsem.c:796
 #, fuzzy, gcc-internal-format
 msgid "manifest constants must have initializers"
 msgstr "只有建構子需成員初始設定式"
 
-#: d/dmd/dsymbolsem.c:794
+#: d/dmd/dsymbolsem.c:808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "size of type %s is invalid"
 msgstr "braced spec 內文 %qs 無效"
 
-#: d/dmd/dsymbolsem.c:829
+#: d/dmd/dsymbolsem.c:843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%s does not have a default initializer"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: d/dmd/dsymbolsem.c:873
+#: d/dmd/dsymbolsem.c:887
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "is not a static and cannot have static initializer"
 msgstr "外部「%s」在 %L 處不能有初始值設定"
 
-#: d/dmd/dsymbolsem.c:993
+#: d/dmd/dsymbolsem.c:1007
 #, gcc-internal-format, gfc-internal-format
 msgid "of type struct %s uses this(this), which is not allowed in static initialization"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1028
+#: d/dmd/dsymbolsem.c:1042
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "static storage variables cannot have destructors"
 msgstr "Java 類別 %qT 不能有解構函式"
 
-#: d/dmd/dsymbolsem.c:1339
+#: d/dmd/dsymbolsem.c:1340
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "string expected for library name"
 msgstr "需要類別名"
 
-#: d/dmd/dsymbolsem.c:1371
+#: d/dmd/dsymbolsem.c:1372
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "function name expected for start address"
 msgstr "位址中有非預期的副作用"
 
-#: d/dmd/dsymbolsem.c:1386
+#: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format
 msgid "function name expected for start address, not `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1400
+#: d/dmd/dsymbolsem.c:1401
 #, fuzzy, gcc-internal-format
 msgid "string expected for mangled name"
 msgstr "預期的函式"
 
-#: d/dmd/dsymbolsem.c:1413
+#: d/dmd/dsymbolsem.c:1414
 #, gcc-internal-format
 msgid "zero-length string not allowed for mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1418
+#: d/dmd/dsymbolsem.c:1419
 #, gcc-internal-format
 msgid "mangled name characters can only be of type char"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1443
+#: d/dmd/dsymbolsem.c:1444
 msgid "char 0x%02x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1456
+#: d/dmd/dsymbolsem.c:1457
 msgid "char 0x%04x not allowed in mangled name"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1519
+#: d/dmd/dsymbolsem.c:1465
+#, fuzzy, gcc-internal-format
+#| msgid "no arguments"
+msgid "takes no argument"
+msgstr "沒有參數"
+
+#: d/dmd/dsymbolsem.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration %q+D"
 msgid "can only apply to a single declaration"
 msgstr "對於範本宣告 %q+D"
 
-#: d/dmd/dsymbolsem.c:1532
+#: d/dmd/dsymbolsem.c:1539
 #, gcc-internal-format
 msgid "pragma is missing closing `;`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:1565
+#: d/dmd/dsymbolsem.c:1573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "incomplete mixin declaration (%s)"
 msgstr "相互衝突的宣告 %q#D"
 
-#: d/dmd/dsymbolsem.c:1747
+#: d/dmd/dsymbolsem.c:1758
 #, fuzzy, gcc-internal-format
 msgid "base type must not be void"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: d/dmd/dsymbolsem.c:1773
+#: d/dmd/dsymbolsem.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "enum %s must have at least one member"
 msgstr "程序『%s』與回合於 %L 必須至少有一個引數"
 
-#: d/dmd/dsymbolsem.c:1859
+#: d/dmd/dsymbolsem.c:1870
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "circular reference to enum member"
 msgstr "回傳臨時變數的參照"
 
-#: d/dmd/dsymbolsem.c:2037
+#: d/dmd/dsymbolsem.c:2048
 #, gcc-internal-format, gfc-internal-format
 msgid "initialization with (%s.%s + 1) causes overflow for type `%s`"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2066
+#: d/dmd/dsymbolsem.c:2077
 #, gcc-internal-format
 msgid "has inexact value, due to loss of precision"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2144
+#: d/dmd/dsymbolsem.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgid "template tuple parameter must be last one"
 msgstr "範本參數必須使用 %<class%> 或 %<typename%> 關鍵字"
 
-#: d/dmd/dsymbolsem.c:2320
+#: d/dmd/dsymbolsem.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive mixin instantiation"
 msgstr "遞迴內聯"
 
 #. ensure error message gets printed
-#: d/dmd/dsymbolsem.c:2374 d/dmd/dsymbolsem.c:5234
+#: d/dmd/dsymbolsem.c:2385 d/dmd/dsymbolsem.c:5364
 #, fuzzy, gcc-internal-format
 #| msgid "recursive inlining"
 msgid "recursive expansion"
 msgstr "遞迴內聯"
 
-#: d/dmd/dsymbolsem.c:2414
+#: d/dmd/dsymbolsem.c:2425
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "error instantiating"
 msgstr "寫入 %qs 時錯誤"
 
-#: d/dmd/dsymbolsem.c:2537 d/dmd/dsymbolsem.c:2706
+#: d/dmd/dsymbolsem.c:2565 d/dmd/dsymbolsem.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s must be a function instead of %s"
 msgstr "%qs 必須被使用與 %qs"
 
-#: d/dmd/dsymbolsem.c:2634
+#: d/dmd/dsymbolsem.c:2662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "without `this` cannot be %s"
 msgstr "虛函式不能是夥伴"
 
-#: d/dmd/dsymbolsem.c:2734
+#: d/dmd/dsymbolsem.c:2762
 #, gcc-internal-format
 msgid "storage class `auto` has no effect if return type is not inferred"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2739
+#: d/dmd/dsymbolsem.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "functions cannot be scope"
@@ -61158,45 +61214,55 @@ msgstr "虛函式不能是夥伴"
 #. Non-static nested functions have a hidden 'this' pointer to which
 #. * the 'return' applies
 #.
-#: d/dmd/dsymbolsem.c:2747
+#: d/dmd/dsymbolsem.c:2775
 #, gcc-internal-format
 msgid "static member has no `this` to which `return` can apply"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2759
+#: d/dmd/dsymbolsem.c:2787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s method can't be abstract"
 msgid "%s functions cannot be abstract"
 msgstr "%s 方法不能被抽象的"
 
-#: d/dmd/dsymbolsem.c:2766
+#: d/dmd/dsymbolsem.c:2794
 #, gcc-internal-format, gfc-internal-format
 msgid "%s method is not virtual and cannot override"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2768
+#: d/dmd/dsymbolsem.c:2796
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot override a non-virtual function"
 msgstr "多載虛函式名時給出警告"
 
-#: d/dmd/dsymbolsem.c:2772
+#: d/dmd/dsymbolsem.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify both -C and -o"
 msgid "cannot be both final and abstract"
 msgstr "不能同時指定 -C 和 -o"
 
-#: d/dmd/dsymbolsem.c:2784
+#: d/dmd/dsymbolsem.c:2829
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2835
+#, gcc-internal-format, gfc-internal-format
+msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
+msgstr ""
+
+#: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
 msgid "constructors, destructors, postblits, invariants, new and delete functions are not allowed in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2786
+#: d/dmd/dsymbolsem.c:2853
 #, gcc-internal-format, gfc-internal-format
 msgid "function body only allowed in final functions in interface %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2794
+#: d/dmd/dsymbolsem.c:2861
 #, gcc-internal-format, gfc-internal-format
 msgid "destructors, postblits and invariants are not allowed in union %s"
 msgstr ""
@@ -61204,180 +61270,180 @@ msgstr ""
 #. If same name function exists in base class but 'this' is auto return,
 #. * cannot find index of base class's vtbl[] to override.
 #.
-#: d/dmd/dsymbolsem.c:2850
+#: d/dmd/dsymbolsem.c:2917
 #, gcc-internal-format
 msgid "return type inference is not supported if may override base class function"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:2880 d/dmd/dsymbolsem.c:2975
+#: d/dmd/dsymbolsem.c:2947 d/dmd/dsymbolsem.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s"
 msgstr "強迫最後的函式 %q+D"
 
-#: d/dmd/dsymbolsem.c:3008
+#: d/dmd/dsymbolsem.c:3075
 #, fuzzy, gcc-internal-format
 msgid "multiple overrides of same function"
 msgstr "太少引數到函式 %q#D"
 
-#: d/dmd/dsymbolsem.c:3103
+#: d/dmd/dsymbolsem.c:3170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "incompatible covariant types %s and %s"
 msgstr "%qE 不相容的屬性忽略"
 
-#: d/dmd/dsymbolsem.c:3125
+#: d/dmd/dsymbolsem.c:3192
 #, gcc-internal-format, gfc-internal-format
 msgid "does not override any function, did you mean to override `%s%s`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3128
+#: d/dmd/dsymbolsem.c:3195
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "does not override any function"
 msgstr "%qD 不是一個成員範本函式"
 
-#: d/dmd/dsymbolsem.c:3149
+#: d/dmd/dsymbolsem.c:3216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot override final function %s.%s"
 msgstr "強迫最後的函式 %q+D"
 
-#: d/dmd/dsymbolsem.c:3164
+#: d/dmd/dsymbolsem.c:3231
 #, fuzzy, gcc-internal-format
 msgid "override only applies to class member functions"
 msgstr "%qE 屬性只有套用到函式"
 
-#: d/dmd/dsymbolsem.c:3173
+#: d/dmd/dsymbolsem.c:3240
 #, gcc-internal-format
 msgid "in and out contracts can only appear without a body when they are virtual interface functions or abstract"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3196
+#: d/dmd/dsymbolsem.c:3263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn about overloaded virtual function names"
 msgid "cannot use template to add virtual function to class `%s`"
 msgstr "多載虛函式名時給出警告"
 
-#: d/dmd/dsymbolsem.c:3304
+#: d/dmd/dsymbolsem.c:3371
 #, gcc-internal-format
 msgid "default constructor for structs only allowed with @disable, no body, and no parameters"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3648
+#: d/dmd/dsymbolsem.c:3715
 #, gcc-internal-format
 msgid "at least one argument of type size_t expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3654
+#: d/dmd/dsymbolsem.c:3721
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "first argument must be type size_t, not %s"
 msgstr "第一個引數必須是 [] 位元組"
 
-#: d/dmd/dsymbolsem.c:3690
+#: d/dmd/dsymbolsem.c:3757
 #, gcc-internal-format
 msgid "one argument of type void* expected"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3696
+#: d/dmd/dsymbolsem.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "one argument of type void* expected, not %s"
 msgstr "向量類型預期的在中向量 permute 運算式"
 
-#: d/dmd/dsymbolsem.c:3754
+#: d/dmd/dsymbolsem.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "%s method can't be abstract"
 msgid "structs, unions cannot be abstract"
 msgstr "%s 方法不能被抽象的"
 
-#: d/dmd/dsymbolsem.c:3894 d/dmd/dsymbolsem.c:4446
+#: d/dmd/dsymbolsem.c:3961 d/dmd/dsymbolsem.c:4513
 #, gcc-internal-format, gfc-internal-format
 msgid "already exists at %s. Perhaps in another function with the same name?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:3976
+#: d/dmd/dsymbolsem.c:4043
 #, gcc-internal-format
 msgid "storage class `auto` is invalid when declaring a class, did you mean to use `scope`?"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4039
+#: d/dmd/dsymbolsem.c:4106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be class or interface, not %s"
 msgstr "Cray 指標於 %C 必須是整數"
 
-#: d/dmd/dsymbolsem.c:4062
+#: d/dmd/dsymbolsem.c:4129
 #, fuzzy, gcc-internal-format
 #| msgid "circular pointer delegation detected"
 msgid "circular inheritance"
 msgstr "偵測到循環指標代理"
 
-#: d/dmd/dsymbolsem.c:4098 d/dmd/dsymbolsem.c:4588
+#: d/dmd/dsymbolsem.c:4165 d/dmd/dsymbolsem.c:4655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "base type must be interface, not %s"
 msgstr "Cray 指標於 %C 必須是整數"
 
-#: d/dmd/dsymbolsem.c:4109 d/dmd/dsymbolsem.c:4599
+#: d/dmd/dsymbolsem.c:4176 d/dmd/dsymbolsem.c:4666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "inherits from duplicate interface %s"
 msgstr "忽略重複的目錄「%s」\n"
 
-#: d/dmd/dsymbolsem.c:4173
+#: d/dmd/dsymbolsem.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot inherit from final class %s"
 msgstr "無法為類別 %s 找到檔案"
 
-#: d/dmd/dsymbolsem.c:4273
+#: d/dmd/dsymbolsem.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C++ base class %s needs at least one virtual function"
 msgstr "型態透明類別 %qT 有虛擬函式"
 
-#: d/dmd/dsymbolsem.c:4297
+#: d/dmd/dsymbolsem.c:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "static class cannot inherit from nested class %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4305
+#: d/dmd/dsymbolsem.c:4372
 #, gcc-internal-format, gfc-internal-format
 msgid "is nested within %s, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4312
+#: d/dmd/dsymbolsem.c:4379
 #, gcc-internal-format, gfc-internal-format
 msgid "is not nested, but super class %s is nested within %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4420
+#: d/dmd/dsymbolsem.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot implicitly generate a default ctor when base class %s is missing a default ctor"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4467
+#: d/dmd/dsymbolsem.c:4534
 #, gcc-internal-format, gfc-internal-format
 msgid "Field members of a synchronized class cannot be %s"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4607
+#: d/dmd/dsymbolsem.c:4674
 #, gcc-internal-format
 msgid "circular inheritance of interface"
 msgstr ""
 
-#: d/dmd/dsymbolsem.c:4841
+#: d/dmd/dsymbolsem.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "mixin templates are not regular templates"
 msgstr "範本參數與範本不符"
 
-#: d/dmd/dsymbolsem.c:5028
+#: d/dmd/dsymbolsem.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "template instantiation %s forward references template declaration %s"
 msgstr "範本識別碼 %qD(屬於 %q+D)不匹配任何範本宣告"
 
-#: d/dmd/dsymbolsem.c:5409
+#: d/dmd/dsymbolsem.c:5540
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve"
 msgstr "無法讀取 %s"
 
-#: d/dmd/dsymbolsem.c:5436
+#: d/dmd/dsymbolsem.c:5567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot alias an expression %s"
 msgstr "無法需位址的 %qs"
@@ -61392,22 +61458,22 @@ msgstr ""
 msgid "(%s) is false"
 msgstr "開啟 %s 失敗：%s"
 
-#: d/dmd/semantic2.c:210
+#: d/dmd/semantic2.c:219
 #, gcc-internal-format
 msgid ": Unable to initialize enum with class or pointer to struct. Use static const variable instead."
 msgstr ""
 
-#: d/dmd/semantic2.c:219
+#: d/dmd/semantic2.c:228
 #, gcc-internal-format, gfc-internal-format
 msgid "is mutable. Only const or immutable class thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:226
+#: d/dmd/semantic2.c:235
 #, gcc-internal-format, gfc-internal-format
 msgid "is a pointer to mutable struct. Only pointers to const, immutable or shared struct thread local variable are allowed, not %s"
 msgstr ""
 
-#: d/dmd/semantic2.c:384
+#: d/dmd/semantic2.c:404
 #, fuzzy, gcc-internal-format
 msgid "has forward references"
 msgstr "別名有 non-alias 參考"
@@ -61471,23 +61537,22 @@ msgstr "建構式中對靜態成員的初始化無效"
 msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr ""
 
-#: d/dmd/semantic3.c:860
+#: d/dmd/semantic3.c:862
 #, gcc-internal-format, gfc-internal-format
-msgid "has no return statement, but is expected to return a value of type %s"
+msgid "has no `return` statement, but is expected to return a value of type `%s`"
 msgstr ""
 
-#: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "function return type cannot be function"
-msgid "no return exp; or assert(0); at end of function"
-msgstr "函式不能回傳函式"
+#: d/dmd/semantic3.c:864
+#, gcc-internal-format
+msgid "no `return exp;` or `assert(0);` at end of function"
+msgstr ""
 
-#: d/dmd/semantic3.c:1193
+#: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
 msgid "synchronized function %s must be a member of a class"
 msgstr ""
 
-#: d/dmd/semantic3.c:1212
+#: d/dmd/semantic3.c:1190
 #, fuzzy, gcc-internal-format
 msgid "naked assembly functions with contracts are not supported"
 msgstr "%<__int128%>未被支援由這個目標"
@@ -62040,7 +62105,7 @@ msgstr "non-parameter %qs 無法參數包裝"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "『我』於 %L 和『J』於 %L 無法兩者是 BOZ 實字常數"
 
-#: fortran/check.c:123 fortran/resolve.c:10921
+#: fortran/check.c:123 fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "無效的 exponent-letter『q』在中 real-literal-constant 於 %C"
@@ -63181,12 +63246,12 @@ msgstr ""
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "初始化字串開始於 %L 被截短至符合變數 (%d/%d)"
 
-#: fortran/data.c:188 fortran/resolve.c:5099
+#: fortran/data.c:188 fortran/resolve.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L 處的子字串起始索引小於 1"
 
-#: fortran/data.c:194 fortran/resolve.c:5129
+#: fortran/data.c:194 fortran/resolve.c:5137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "子字串結束索引於 %L 超出字串長度"
@@ -63375,7 +63440,7 @@ msgstr "%C 處錯誤地指定 INTENT"
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003:已推遲型態參數於 %C"
 
-#: fortran/decl.c:1155 fortran/resolve.c:12452
+#: fortran/decl.c:1155 fortran/resolve.c:12461
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -65919,7 +65984,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1356
-#: fortran/trans-array.c:6713 fortran/trans-array.c:8208
+#: fortran/trans-array.c:6680 fortran/trans-array.c:8175
 #: fortran/trans-intrinsic.c:8549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -66001,7 +66066,7 @@ msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1794
+#: fortran/frontend-passes.c:3458 fortran/trans-expr.c:1831
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -66140,12 +66205,12 @@ msgstr "第一個引數的定義的指派於 %L 必須是含義 (出) 或含義
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L 處定義賦值的第二個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17201
+#: fortran/interface.c:987 fortran/resolve.c:17210
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第一個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17219
+#: fortran/interface.c:994 fortran/resolve.c:17228
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第二個參數必須是 INTENT(IN)"
@@ -66258,551 +66323,551 @@ msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和純量)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和 rank-%d)"
 
-#: fortran/interface.c:2355
+#: fortran/interface.c:2356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "無效的程序引數於 %L"
 
-#: fortran/interface.c:2363 fortran/interface.c:2390
+#: fortran/interface.c:2364 fortran/interface.c:2391
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "介面不匹配在中虛設程序『%s』於 %L:%s"
 
-#: fortran/interface.c:2401
+#: fortran/interface.c:2402
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "實際引數到 contiguous 指標虛設『%s』於 %L 必須是僅需 contigous"
 
-#: fortran/interface.c:2424
+#: fortran/interface.c:2425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "含義 (%s) 實際引數於 %L 也許 interfere 與實際引數於 %L。"
 
-#: fortran/interface.c:2434
+#: fortran/interface.c:2435
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "型態不匹配在中引數『%s』於 %L; 傳遞 %s 到 %s"
 
-#: fortran/interface.c:2444
+#: fortran/interface.c:2445
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/interface.c:2460
+#: fortran/interface.c:2461
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/interface.c:2470
+#: fortran/interface.c:2471
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "實際引數到『%s』於 %L 必須有相同宣告的型態"
 
-#: fortran/interface.c:2485
+#: fortran/interface.c:2486
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2496
+#: fortran/interface.c:2502
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/interface.c:2515
+#: fortran/interface.c:2521
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Corank 不匹配在中引數『%s』於 %L (%d 和 %d)"
 
-#: fortran/interface.c:2533
+#: fortran/interface.c:2539
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "實際引數到『%s』於 %L 必須是僅需 contiguous"
 
-#: fortran/interface.c:2548
+#: fortran/interface.c:2554
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "實際引數到 non-INTENT (INOUT) 虛設『%s』於 %L, 該項是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.c:2563
+#: fortran/interface.c:2569
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "實際引數到 non-INTENT (INOUT) 虛設『%s』於 %L, 該項是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.c:2582
+#: fortran/interface.c:2588
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "虛引數『%s』必須是指標或 assumed-shape 陣列而無需 CONTIGUOUS 屬性 - 做為實際引數於 %L 不是僅需 contiguous 和兩者是非同步或易變的"
 
-#: fortran/interface.c:2595
+#: fortran/interface.c:2601
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "傳遞 coarray 於 %L 到 allocatable、noncoarray，含義 (出) 虛引數『%s』"
 
-#: fortran/interface.c:2602
+#: fortran/interface.c:2608
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "傳遞 coarray 於 %L 到 allocatable，noncoarray 虛引數『%s』，該項無效如果配額狀態被已修改"
 
-#: fortran/interface.c:2676
+#: fortran/interface.c:2682
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorphic 純量傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2687
+#: fortran/interface.c:2693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "元件的 assumed-shaped 或指標陣列傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2692
+#: fortran/interface.c:2698
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "元件的 assumed-shaped 或指標陣列傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2705
+#: fortran/interface.c:2711
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "延伸：純量 non-default-kind，non-C_CHAR-kind 字元實際引數與陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2713
+#: fortran/interface.c:2719
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003:純量字元實際引數與陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:3064
+#: fortran/interface.c:3070
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.c:3087
+#: fortran/interface.c:3093
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.c:3091
+#: fortran/interface.c:3097
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.c:3100
+#: fortran/interface.c:3106
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "關鍵字引數『%s』於 %L 已經關聯的與另外的實際引數"
 
-#: fortran/interface.c:3110
+#: fortran/interface.c:3116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "更多實際的比形式引數在中程序呼叫於 %L"
 
-#: fortran/interface.c:3124
+#: fortran/interface.c:3130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "缺少交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.c:3136
+#: fortran/interface.c:3142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "未預期的交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.c:3165
+#: fortran/interface.c:3171
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/interface.c:3168
+#: fortran/interface.c:3174
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008:空指標於 %L 到 non-pointer 虛設『%s』"
 
-#: fortran/interface.c:3192
+#: fortran/interface.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3214
+#: fortran/interface.c:3220
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "字元長度不匹配 (%ld/%ld) 介於實際引數和指標或 allocatable 虛引數『%s』於 %L"
 
-#: fortran/interface.c:3221
+#: fortran/interface.c:3227
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "字元長度不匹配 (%ld/%ld) 介於實際引數和 assumed-shape 虛引數『%s』於 %L"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3241
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "實際引數於 %L 到 allocatable 或指標虛引數『%s』必須有已推遲長度型態參數如果和只有如果虛設有一個"
 
-#: fortran/interface.c:3252
+#: fortran/interface.c:3258
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "字元長度的實際引數短於的虛引數『%s』(%lu/%lu) 於 %L"
 
-#: fortran/interface.c:3260 fortran/interface.c:3265
+#: fortran/interface.c:3266 fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "實際引數含有太少元件用於虛引數『%s』(%lu/%lu) 於 %L"
 
-#: fortran/interface.c:3285
+#: fortran/interface.c:3291
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "預期的程序指標用於引數『%s』於 %L"
 
-#: fortran/interface.c:3301
+#: fortran/interface.c:3307
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "預期的程序用於引數『%s』於 %L"
 
-#: fortran/interface.c:3318
+#: fortran/interface.c:3324
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "實際引數用於『%s』無法 assumed-size 陣列於 %L"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3333
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "「%s」的引數在 %L 處必須是一個指標"
 
-#: fortran/interface.c:3337
+#: fortran/interface.c:3343
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008:Non-pointer 實際引數於 %L 到指標虛設『%s』"
 
-#: fortran/interface.c:3347
+#: fortran/interface.c:3353
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Coindexed 實際引數於 %L 到指標虛設『%s』"
 
-#: fortran/interface.c:3360
+#: fortran/interface.c:3366
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Coindexed 實際引數於 %L 到 allocatable 虛設『%s』需求含義 (在中)"
 
-#: fortran/interface.c:3374
+#: fortran/interface.c:3380
 #, fuzzy, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Coindexed 非同步或易變的實際引數於 %L 需求該虛設『%s』有 neither 非同步 nor 易變的"
 
-#: fortran/interface.c:3388
+#: fortran/interface.c:3394
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Coindexed 實際引數於 %L 與 allocatable ultimate 成分到虛設『%s』需求還是值或含義 (在中)"
 
-#: fortran/interface.c:3400
+#: fortran/interface.c:3406
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "實際的類別陣列引數用於『%s』必須是全部陣列於 %L"
 
-#: fortran/interface.c:3410
+#: fortran/interface.c:3416
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "實際引數用於『%s』必須是 ALLOCATABLE 於 %L"
 
-#: fortran/interface.c:3440
+#: fortran/interface.c:3446
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Array-section 實際引數與向量註標於 %L 是不相容的與含義 (出)，含義 (INOUT)，易變的或非同步屬性的虛引數『%s』"
 
-#: fortran/interface.c:3459
+#: fortran/interface.c:3465
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Assumed-shape 實際引數於 %L 是不相容的與 non-assumed-shape 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3482
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Array-section 實際引數於 %L 是不相容的與 non-assumed-shape 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.c:3496
+#: fortran/interface.c:3502
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Pointer-array 實際引數於 %L 需求 assumed-shape 或 pointer-array 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.c:3519
+#: fortran/interface.c:3525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "缺少交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.c:3527
+#: fortran/interface.c:3533
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "參數「%s」在 %L 處缺少引數"
 
-#: fortran/interface.c:3657
+#: fortran/interface.c:3663
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3686
+#: fortran/interface.c:3692
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3712
+#: fortran/interface.c:3718
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3722
+#: fortran/interface.c:3728
 #, fuzzy, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "相同實際引數關聯的與含義 (%s) 引數『%s』和含義 (%s) 引數『%s』於 %L"
 
-#: fortran/interface.c:3752
+#: fortran/interface.c:3758
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3772
+#: fortran/interface.c:3778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "程序引數於 %L 是本地到 PURE 程序和有指標屬性"
 
-#: fortran/interface.c:3784
+#: fortran/interface.c:3790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Coindexed 實際引數於 %L 在中 PURE 程序被傳遞到含義 (%s) 引數"
 
-#: fortran/interface.c:3794
+#: fortran/interface.c:3800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Coindexed 實際引數於 %L 在中 PURE 程序被傳遞到指標虛引數"
 
-#: fortran/interface.c:3805
+#: fortran/interface.c:3811
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Coindexed polymorphic 實際引數於 %L 被傳遞 polymorphic 虛引數『%s』"
 
-#: fortran/interface.c:3847
+#: fortran/interface.c:3853
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "程序『%s』called 於 %L 不是明確的宣告"
 
-#: fortran/interface.c:3851 fortran/interface.c:3861
+#: fortran/interface.c:3857 fortran/interface.c:3867
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "程序『%s』called 於 %L 不是明確的宣告"
 
-#: fortran/interface.c:3857
+#: fortran/interface.c:3863
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "呼叫程序「%s」帶隱含介面，位於 %L"
 
-#: fortran/interface.c:3870
+#: fortran/interface.c:3876
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "指標物件『%s』於 %L 必須有明確的函式介面或被宣告做為陣列"
 
-#: fortran/interface.c:3878
+#: fortran/interface.c:3884
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "allocatable 物件『%s』於 %L 必須有明確的函式介面或被宣告做為陣列"
 
-#: fortran/interface.c:3886
+#: fortran/interface.c:3892
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Allocatable 函式『%s』於 %L 必須有明確的函式介面"
 
-#: fortran/interface.c:3903
+#: fortran/interface.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/interface.c:3912
+#: fortran/interface.c:3918
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "關鍵字引數需求明確的介面用於程序『%s』於 %L"
 
-#: fortran/interface.c:3921
+#: fortran/interface.c:3927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "符號「%s」在 %L 處已經有了明確介面"
 
-#: fortran/interface.c:3936
+#: fortran/interface.c:3942
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "實際引數的 LOCK_TYPE 或與 LOCK_TYPE 成分於 %L 需求明確的介面用於程序『%s』"
 
-#: fortran/interface.c:3951
+#: fortran/interface.c:3957
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "實際引數的 LOCK_TYPE 或與 LOCK_TYPE 成分於 %L 需求明確的介面用於程序『%s』"
 
-#: fortran/interface.c:3961
+#: fortran/interface.c:3967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "鑄型引數到空值必要項於 %L"
 
-#: fortran/interface.c:3971
+#: fortran/interface.c:3977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "關鍵字引數需求明確的介面用於程序『%s』於 %L"
 
-#: fortran/interface.c:4013
+#: fortran/interface.c:4019
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "程序指標成分『%s』called 與隱含的介面於 %L"
 
-#: fortran/interface.c:4024
+#: fortran/interface.c:4030
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/interface.c:4109
+#: fortran/interface.c:4115
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "鑄型=必要項在中空值() 引數於 %L:模稜兩可介於特定的函式 %s 和 %s"
 
-#: fortran/interface.c:4179
+#: fortran/interface.c:4185
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "%q+D 別名到未定義的符號 %qE"
 
-#: fortran/interface.c:4552
+#: fortran/interface.c:4558
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "實體『%s』於 %C 已經呈現在中介面"
 
-#: fortran/interface.c:4669
+#: fortran/interface.c:4675
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4763
+#: fortran/interface.c:4769
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "無法覆寫通用『%s』於 %L"
 
-#: fortran/interface.c:4775
+#: fortran/interface.c:4781
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "『%s』於 %L 強制變更程序繫結宣告 NON_OVERRIDABLE"
 
-#: fortran/interface.c:4783
+#: fortran/interface.c:4789
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "『%s』於 %L 必須不是已推遲做為它強制變更 non-DEFERRED 繫結"
 
-#: fortran/interface.c:4791
+#: fortran/interface.c:4797
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "『%s』於 %L 強制變更 PURE 程序且須也是 PURE"
 
-#: fortran/interface.c:4800
+#: fortran/interface.c:4806
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "『%s』於 %L 強制變更 ELEMENTAL 程序且須也是 ELEMENTAL"
 
-#: fortran/interface.c:4806
+#: fortran/interface.c:4812
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "『%s』於 %L 強制變更 non-ELEMENTAL 程序且須無法是 ELEMENTAL，還是"
 
-#: fortran/interface.c:4815
+#: fortran/interface.c:4821
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "『%s』於 %L 強制變更副常式且須也是副常式"
 
-#: fortran/interface.c:4826
+#: fortran/interface.c:4832
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "『%s』於 %L 強制變更函式且須也是函式"
 
-#: fortran/interface.c:4834
+#: fortran/interface.c:4840
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "引數不匹配用於強迫程序『%s』於 %L:%s"
 
-#: fortran/interface.c:4845
+#: fortran/interface.c:4851
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "『%s』於 %L 強制變更公用的程序且須無法是私人的"
 
-#: fortran/interface.c:4875
+#: fortran/interface.c:4881
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "虛引數『%s』的『%s』於 %L 應該被具名的『%s』做為到匹配相應引數的 overridden 程序"
 
-#: fortran/interface.c:4886
+#: fortran/interface.c:4892
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "引數不匹配用於強迫程序『%s』於 %L:%s"
 
-#: fortran/interface.c:4895
+#: fortran/interface.c:4901
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "『%s』於 %L 必須有相同形式引數數量做為 overridden 程序"
 
-#: fortran/interface.c:4904
+#: fortran/interface.c:4910
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "『%s』於 %L 強制變更 NOPASS 繫結且須也是 NOPASS"
 
-#: fortran/interface.c:4915
+#: fortran/interface.c:4921
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "『%s』於 %L 強制變更繫結與回合且須也是回合"
 
-#: fortran/interface.c:4922
+#: fortran/interface.c:4928
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是於相同位置做為 passed-object 虛引數的 overridden 程序"
 
-#: fortran/interface.c:4943
+#: fortran/interface.c:4949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s 標記在 %L 處必須具有類型 %s"
 
-#: fortran/interface.c:4950
+#: fortran/interface.c:4956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "%L 處引數維數必須具有 INTEGER 類型"
 
-#: fortran/interface.c:4957
+#: fortran/interface.c:4963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "%L 引數維數必須是標量"
 
-#: fortran/interface.c:4961
+#: fortran/interface.c:4967
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4965
+#: fortran/interface.c:4971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Character-valued %s『%s』於 %L 必須不被假設長度"
 
-#: fortran/interface.c:4969
+#: fortran/interface.c:4975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "「%s」啞元引數在 %L 處不能是 INTENT(OUT)"
 
-#: fortran/interface.c:5027 fortran/interface.c:5073
+#: fortran/interface.c:5033 fortran/interface.c:5079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "DATA 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/interface.c:5039
+#: fortran/interface.c:5045
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "ELEMENTAL 程序『%s』於 %L 必須有明確的介面"
 
-#: fortran/interface.c:5051
+#: fortran/interface.c:5057
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "對「%s」的呼叫給出的參數太多，於 %L 處"
 
-#: fortran/interface.c:5058
+#: fortran/interface.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -66955,34 +67020,34 @@ msgstr "transformational intrinsic『%s』於 %L 未被允許在中初始化運
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fortran 2003:Elemental 函式做為初始化運算式與 non-integer/non-character 引數於 %L"
 
-#: fortran/intrinsic.c:5149
+#: fortran/intrinsic.c:5154
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "副常式呼叫到『%s』在中做共時區塊於 %L 不是 PURE"
 
-#: fortran/intrinsic.c:5156
+#: fortran/intrinsic.c:5161
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "副常式呼叫到 intrinsic『%s』於 %L 不是 PURE"
 
-#: fortran/intrinsic.c:5258
+#: fortran/intrinsic.c:5263
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "擴充：從 %s 到 %s，位於 %L"
 
-#: fortran/intrinsic.c:5279
+#: fortran/intrinsic.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "從 %s 轉換到 %s，位於 %L"
 
-#: fortran/intrinsic.c:5296 fortran/intrinsic.c:5313
+#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "可能的變更的值在中轉換從 %s 到 %s 於 %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5301 fortran/intrinsic.c:5321
+#: fortran/intrinsic.c:5306 fortran/intrinsic.c:5326
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "從 %s 轉換到 %s，位於 %L"
@@ -66990,24 +67055,24 @@ msgstr "從 %s 轉換到 %s，位於 %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5387 fortran/resolve.c:10896
+#: fortran/intrinsic.c:5392 fortran/resolve.c:10904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "不能將 %s 轉換為 %s，於 %L"
 
-#: fortran/intrinsic.c:5392
+#: fortran/intrinsic.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "不能將 %s 轉換為 %s，於 %L"
 
-#: fortran/intrinsic.c:5483
+#: fortran/intrinsic.c:5488
 #, fuzzy, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "『%s』宣告的於 %L 也許會陰影 intrinsic 的同名。 以便呼叫 intrinsic，明確的 INTRINSIC 宣告也許會被必要項。"
 
-#: fortran/intrinsic.c:5489
+#: fortran/intrinsic.c:5494
 #, fuzzy, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "『%s』宣告的於 %L 也是名稱的 intrinsic。 它只能被 called 透過明確的介面或如果宣告的外部。"
@@ -67551,7 +67616,7 @@ msgstr "名稱表列『%s』在中讀取敘述於 %L 含有符號『%s』該項
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 是 polymorphic 和需要定義的輸入/輸出程序"
 
-#: fortran/io.c:3431 fortran/resolve.c:15073
+#: fortran/io.c:3431 fortran/resolve.c:15082
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Fortran 2003:名稱表列物件『%s』在中名稱表列『%s』於 %L 與 ALLOCATABLE 或指標成分"
@@ -68750,12 +68815,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:205
+#: fortran/misc.c:207
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:309
+#: fortran/misc.c:311
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -68916,150 +68981,150 @@ msgstr "Intrinsic 運算子『%s』引用於 %L 找不到在中模組『%s』"
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:6223
+#: fortran/module.c:6234
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6413
+#: fortran/module.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Cannot open module file %qs for writing at %C: %s"
 msgstr "無法開啟模組檔案「%s」寫入，在 %C 處：%s"
 
-#: fortran/module.c:6434
+#: fortran/module.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "寫入模組檔案「%s」時發生錯誤：%s"
 
-#: fortran/module.c:6445
+#: fortran/module.c:6456
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete module file %qs: %s"
 msgstr "無法刪除模組檔案『%s』：%s"
 
-#: fortran/module.c:6448
+#: fortran/module.c:6459
 #, fuzzy, gcc-internal-format
 msgid "Cannot rename module file %qs to %qs: %s"
 msgstr "無法重新命名模組檔案『%s』到『%s』：%s"
 
-#: fortran/module.c:6454
+#: fortran/module.c:6465
 #, fuzzy, gcc-internal-format
 msgid "Cannot delete temporary module file %qs: %s"
 msgstr "無法刪除暫時的模組檔案『%s』：%s"
 
-#: fortran/module.c:6511
+#: fortran/module.c:6522
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "符號『%s』已經宣告"
 
-#: fortran/module.c:6582
+#: fortran/module.c:6593
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6690 fortran/module.c:7034
+#: fortran/module.c:6701 fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "符號『%s』，引用於 %L, 不是在中已選標準"
 
-#: fortran/module.c:6818
+#: fortran/module.c:6829
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "符號『%s』引用於 %L 找不到在中 intrinsic 模組 ISO_C_BINDING"
 
-#: fortran/module.c:6839 fortran/module.c:6872 fortran/module.c:6914
+#: fortran/module.c:6850 fortran/module.c:6883 fortran/module.c:6925
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "符號『%s』已經宣告"
 
-#: fortran/module.c:7019
+#: fortran/module.c:7030
 #, fuzzy, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "使用的 intrinsic 模組『%s』於 %C 衝突與非內建模組名稱使用的在之前"
 
-#: fortran/module.c:7041
+#: fortran/module.c:7052
 #, fuzzy, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "使用的 NUMERIC_STORAGE_SIZE 具名的常數從 intrinsic 模組 ISO_FORTRAN_ENV 於 %L 是不相容的與選項 %s"
 
-#: fortran/module.c:7109
+#: fortran/module.c:7120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "使用的 NUMERIC_STORAGE_SIZE 具名的常數從 intrinsic 模組 ISO_FORTRAN_ENV 於 %C 是不相容的與選項 %s"
 
-#: fortran/module.c:7163
+#: fortran/module.c:7174
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "符號『%s』引用於 %L 找不到在中 intrinsic 模組 ISO_FORTRAN_ENV"
 
-#: fortran/module.c:7189
+#: fortran/module.c:7200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/module.c:7218
+#: fortran/module.c:7229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003:ISO_FORTRAN_ENV intrinsic 模組於 %C"
 
-#: fortran/module.c:7230
+#: fortran/module.c:7241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:7243
+#: fortran/module.c:7254
 #, fuzzy, gcc-internal-format
 msgid "Cannot find an intrinsic module named %qs at %C"
 msgstr "找不到 intrinsic 模組具名的『%s』於 %C"
 
-#: fortran/module.c:7249
+#: fortran/module.c:7260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "Fortran 2003:「使用::模組」於 %C"
 
-#: fortran/module.c:7255
+#: fortran/module.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:7261
+#: fortran/module.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:7271
+#: fortran/module.c:7282
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Cannot open module file %qs for reading at %C: %s"
 msgstr "無法開啟模組檔案「%s」讀取，在 %C 處：%s"
 
-#: fortran/module.c:7274
+#: fortran/module.c:7285
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7285
+#: fortran/module.c:7296
 #, fuzzy, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "使用的非內建模組『%s』於 %C 衝突與 intrinsic 模組名稱使用的在之前"
 
-#: fortran/module.c:7308
+#: fortran/module.c:7319
 #, fuzzy, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "檔案『%s』開啟的於 %C 並非 GFORTRAN 模組檔案"
 
-#: fortran/module.c:7316
+#: fortran/module.c:7327
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7333
+#: fortran/module.c:7344
 #, gcc-internal-format
 msgid "Cannot USE a submodule that is currently built"
 msgstr ""
 
-#: fortran/module.c:7335
+#: fortran/module.c:7346
 #, gcc-internal-format
 msgid "Cannot USE a module that is currently built"
 msgstr ""
@@ -69603,8 +69668,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10721
-#: fortran/resolve.c:12026
+#: fortran/openmp.c:4722 fortran/openmp.c:4733 fortran/resolve.c:10729
+#: fortran/resolve.c:12035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "如果子句於 %L 需要純量邏輯的運算式"
@@ -71649,7 +71714,7 @@ msgstr "intrinsic『%s』宣告的 INTRINSIC 於 %L 不是可用在中目前的
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "非遞迴程序『%s』於 %L 是可能會呼叫它自己遞迴。 宣告它遞迴或使用 -frecursive"
 
-#: fortran/resolve.c:1926 fortran/resolve.c:10250 fortran/resolve.c:11954
+#: fortran/resolve.c:1926 fortran/resolve.c:10258 fortran/resolve.c:11962
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "標籤 %d(參照自 %L)從未被定義"
@@ -71769,7 +71834,7 @@ msgstr "無法解析特定的函式『%s』於 %L"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "函式「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:2961 fortran/resolve.c:17133
+#: fortran/resolve.c:2961 fortran/resolve.c:17142
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -71927,216 +71992,216 @@ msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 msgid "Impure function at %L might not be evaluated"
 msgstr "alwaysinline 函式也許無法是 inlinable(_I)"
 
-#: fortran/resolve.c:4020
+#: fortran/resolve.c:4021
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "By-value 引數於 %L 無法陣列或陣列區段"
 
-#: fortran/resolve.c:4041
+#: fortran/resolve.c:4042
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4212 fortran/resolve.c:4227
+#: fortran/resolve.c:4216 fortran/resolve.c:4231
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
 msgstr "By-value 引數於 %L 無法陣列或陣列區段"
 
-#: fortran/resolve.c:4266
+#: fortran/resolve.c:4270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Equality comparison for %s at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Inequality comparison for %s at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.c:4324
+#: fortran/resolve.c:4332
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4494 fortran/resolve.c:4517
+#: fortran/resolve.c:4502 fortran/resolve.c:4525
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4612
+#: fortran/resolve.c:4620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4617
+#: fortran/resolve.c:4625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中 codimension %d"
 
-#: fortran/resolve.c:4627
+#: fortran/resolve.c:4635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中 codimension %d"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4660
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零間隔無效"
 
-#: fortran/resolve.c:4669
+#: fortran/resolve.c:4677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4677
+#: fortran/resolve.c:4685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4693
+#: fortran/resolve.c:4701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4702
+#: fortran/resolve.c:4710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4718
+#: fortran/resolve.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "陣列參照缺少下標"
 
-#: fortran/resolve.c:4741
+#: fortran/resolve.c:4749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rightmost 上限的假設的大小陣列區段尚未指定於 %L"
 
-#: fortran/resolve.c:4751
+#: fortran/resolve.c:4759
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L 處陣列參照中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4759
+#: fortran/resolve.c:4767
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Coindex 分級不匹配在中陣列參照於 %L (%d/%d)"
 
-#: fortran/resolve.c:4775
+#: fortran/resolve.c:4783
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Coindex 的 codimension %d 必須是純量於 %L"
 
-#: fortran/resolve.c:4803
+#: fortran/resolve.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L 處陣列索引必須是標量"
 
-#: fortran/resolve.c:4809
+#: fortran/resolve.c:4817
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "陣列索引於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/resolve.c:4815
+#: fortran/resolve.c:4823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "擴充：%L 處的 REAL 陣列索引"
 
-#: fortran/resolve.c:4854
+#: fortran/resolve.c:4862
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 引數維數必須是標量"
 
-#: fortran/resolve.c:4861
+#: fortran/resolve.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L 處引數維數必須具有 INTEGER 類型"
 
-#: fortran/resolve.c:4919
+#: fortran/resolve.c:4927
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4930
+#: fortran/resolve.c:4938
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4942
+#: fortran/resolve.c:4950
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4985
+#: fortran/resolve.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L 處陣列索引是一個秩為 %d 的陣列"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5091
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L 處的子字串起始索引類型必須為 INTEGER"
 
-#: fortran/resolve.c:5090
+#: fortran/resolve.c:5098
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L 處的子字串起始索引必須是標量"
 
-#: fortran/resolve.c:5112
+#: fortran/resolve.c:5120
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L 處的子字串終止索引類型必須為 INTEGER"
 
-#: fortran/resolve.c:5119
+#: fortran/resolve.c:5127
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L 處的子字串終止索引必須是標量"
 
-#: fortran/resolve.c:5139
+#: fortran/resolve.c:5147
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "子字串結束索引於 %L 太大"
 
-#: fortran/resolve.c:5329
+#: fortran/resolve.c:5337
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L 處陣列參照錯誤"
 
-#: fortran/resolve.c:5343
+#: fortran/resolve.c:5351
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有指標屬性於 %L"
 
-#: fortran/resolve.c:5353
+#: fortran/resolve.c:5361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有 ALLOCATABLE 屬性於 %L"
 
-#: fortran/resolve.c:5399
+#: fortran/resolve.c:5407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "兩個以上部分參考與非零值分級必須不被指定的於 %L"
 
-#: fortran/resolve.c:5491
+#: fortran/resolve.c:5499
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5573
+#: fortran/resolve.c:5581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:5583
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -72145,12 +72210,12 @@ msgstr "假定外形的陣列在 %L 處必須是啞引數"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5593
+#: fortran/resolve.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5612
+#: fortran/resolve.c:5620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -72159,294 +72224,294 @@ msgstr "假定外形的陣列在 %L 處必須是啞引數"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5622
+#: fortran/resolve.c:5630
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5633
+#: fortran/resolve.c:5641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5642
+#: fortran/resolve.c:5650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5658
+#: fortran/resolve.c:5666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5838
+#: fortran/resolve.c:5846
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』，已用於規格運算式，被引用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.c:5843
+#: fortran/resolve.c:5851
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』被使用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.c:5913
+#: fortran/resolve.c:5921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphic 子物件的 coindexed 物件於 %L"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 物件與 polymorphic allocatable subcomponent 於 %L"
 
-#: fortran/resolve.c:5942
+#: fortran/resolve.c:5950
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qE 被不宜用"
 
-#: fortran/resolve.c:6030
+#: fortran/resolve.c:6038
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.c:6184 fortran/resolve.c:6336
+#: fortran/resolve.c:6192 fortran/resolve.c:6344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "在中 type-spec 於 %L 時發生錯誤"
 
-#: fortran/resolve.c:6300
+#: fortran/resolve.c:6308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Passed-object 於 %L 必須是純量"
 
-#: fortran/resolve.c:6307
+#: fortran/resolve.c:6315
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 procedure-pointer 成分呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:6346
+#: fortran/resolve.c:6354
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 type-bound 程序呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:6355
+#: fortran/resolve.c:6363
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "基底物件用於 NOPASS type-bound 程序呼叫於 %L 必須是純量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6543
+#: fortran/resolve.c:6551
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "找到沒有匹配特定的繫結用於呼叫到通用『%s』於 %L"
 
-#: fortran/resolve.c:6577
+#: fortran/resolve.c:6585
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "『%s』於 %L 應該是副常式"
 
-#: fortran/resolve.c:6629
+#: fortran/resolve.c:6637
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "『%s』於 %L 應該是函式"
 
-#: fortran/resolve.c:7164
+#: fortran/resolve.c:7172
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要運算式類型"
 
-#: fortran/resolve.c:7197
+#: fortran/resolve.c:7205
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L 處)必須是一個標量"
 
-#: fortran/resolve.c:7207
+#: fortran/resolve.c:7215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: fortran/resolve.c:7211 fortran/resolve.c:7218
+#: fortran/resolve.c:7219 fortran/resolve.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L 處)必須是 INTEGER"
 
-#: fortran/resolve.c:7273
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "步進敘述於 %L 處的 DO 迴圈中不可為零"
 
-#: fortran/resolve.c:7296
+#: fortran/resolve.c:7304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "做迴圈於 %L 將被執行零次"
 
-#: fortran/resolve.c:7313
+#: fortran/resolve.c:7321
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7319
+#: fortran/resolve.c:7327
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7380
+#: fortran/resolve.c:7388
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7385
+#: fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 啟始敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7392
+#: fortran/resolve.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 結束敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7400
+#: fortran/resolve.c:7408
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L 處的 FORALL 步幅敘述必須是 %s 標量"
 
-#: fortran/resolve.c:7405
+#: fortran/resolve.c:7413
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L 處的 FORALL 步幅敘述不能為零"
 
-#: fortran/resolve.c:7418
+#: fortran/resolve.c:7426
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引『%s』可能無法出現在中 triplet 規格於 %L"
 
-#: fortran/resolve.c:7522 fortran/resolve.c:7819
+#: fortran/resolve.c:7530 fortran/resolve.c:7827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object 於 %L 必須是 ALLOCATABLE 或指標"
 
-#: fortran/resolve.c:7530 fortran/resolve.c:7783
+#: fortran/resolve.c:7538 fortran/resolve.c:7791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.c:7640
+#: fortran/resolve.c:7648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr 於 %L 必須是純量或有同級做為 allocate-object 於 %L"
 
-#: fortran/resolve.c:7671
+#: fortran/resolve.c:7679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr 於 %L 和 allocate-object 於 %L 必須有相同形狀"
 
-#: fortran/resolve.c:7830
+#: fortran/resolve.c:7838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "型態的實體於 %L 是型態不相容的與 source-expr 於 %L"
 
-#: fortran/resolve.c:7842
+#: fortran/resolve.c:7850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "allocate-object 於 %L 和 source-expr 於 %L 應該有相同 kind 型態參數"
 
-#: fortran/resolve.c:7856
+#: fortran/resolve.c:7864
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.c:7871
+#: fortran/resolve.c:7879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.c:7884
+#: fortran/resolve.c:7892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "配置 %s 的摘要基底類型於 %L 需要 type-spec 或 source-expr"
 
-#: fortran/resolve.c:7902
+#: fortran/resolve.c:7910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 於 %L 與 type-spec 需求相同 character-length 參數做為在中宣告"
 
-#: fortran/resolve.c:7983 fortran/resolve.c:7998
+#: fortran/resolve.c:7991 fortran/resolve.c:8006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7990
+#: fortran/resolve.c:7998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:8015
+#: fortran/resolve.c:8023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Coarray 規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:8024 fortran/resolve.c:8053 fortran/resolve.c:8081
+#: fortran/resolve.c:8032 fortran/resolve.c:8061 fortran/resolve.c:8089
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "不當的陣列規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:8030
+#: fortran/resolve.c:8038
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:8042
+#: fortran/resolve.c:8050
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8100
+#: fortran/resolve.c:8108
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "『%s』必須不出現在中陣列規格於 %L 在中相同配置敘述位置它是它自己配置"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "預期『*』在中 coindex 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "不當的 coarray 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:8158
+#: fortran/resolve.c:8166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable 於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:8181
+#: fortran/resolve.c:8189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:8192
+#: fortran/resolve.c:8200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG 於 %L 是無用的而無需 STAT 標籤"
 
-#: fortran/resolve.c:8208
+#: fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:8231
+#: fortran/resolve.c:8239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:8261
+#: fortran/resolve.c:8269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object 於 %L 也出現於 %L"
 
-#: fortran/resolve.c:8267 fortran/resolve.c:8273
+#: fortran/resolve.c:8275 fortran/resolve.c:8281
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
@@ -72455,285 +72520,285 @@ msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8501
+#: fortran/resolve.c:8509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.c:8552
+#: fortran/resolve.c:8560
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L 處 CASE 敘述中的運算式必須具有 %s 類型"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "運算式在中條件敘述於 %L 必須是的 kind %d"
 
-#: fortran/resolve.c:8576
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L 處 CASE 敘述中的運算式必須為標量"
 
-#: fortran/resolve.c:8622
+#: fortran/resolve.c:8630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "選擇運算式在中計算的前往敘述於 %L 必須是純量整數運算式"
 
-#: fortran/resolve.c:8641
+#: fortran/resolve.c:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:8651
+#: fortran/resolve.c:8659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:8669 fortran/resolve.c:8677
+#: fortran/resolve.c:8677 fortran/resolve.c:8685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "運算式在中條件敘述於 %L 不是在中範圍的 %s"
 
-#: fortran/resolve.c:8739 fortran/resolve.c:9391
+#: fortran/resolve.c:8747 fortran/resolve.c:9399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "預設大小寫於 %L 無法在之後秒預設大小寫於 %L"
 
-#: fortran/resolve.c:8765
+#: fortran/resolve.c:8773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "邏輯的範圍在中條件敘述於 %L 未被允許"
 
-#: fortran/resolve.c:8777
+#: fortran/resolve.c:8785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "常數邏輯的值在中條件敘述被重複於 %L"
 
-#: fortran/resolve.c:8792
+#: fortran/resolve.c:8800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "範圍規格於 %L 可以永不被匹配"
 
-#: fortran/resolve.c:8895
+#: fortran/resolve.c:8903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "邏輯的選取大小寫區塊於 %L 有更多該兩大小寫"
 
-#: fortran/resolve.c:8946
+#: fortran/resolve.c:8954
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/resolve.c:8955
+#: fortran/resolve.c:8963
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "名稱「%s」在 %C 處不能做為已定義的運算子"
 
-#: fortran/resolve.c:8972
+#: fortran/resolve.c:8980
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.c:8988
+#: fortran/resolve.c:8996
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8995
+#: fortran/resolve.c:9003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:9000
+#: fortran/resolve.c:9008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:9022
+#: fortran/resolve.c:9030
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.c:9033
+#: fortran/resolve.c:9041
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9263
+#: fortran/resolve.c:9271
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "選擇器應該是 polymorphic 在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:9301 fortran/resolve.c:9313
+#: fortran/resolve.c:9309 fortran/resolve.c:9321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:9342
+#: fortran/resolve.c:9350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.c:9354
+#: fortran/resolve.c:9362
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.c:9366
+#: fortran/resolve.c:9374
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "衍生類型『%s』於 %L 必須是延伸的『%s』"
 
-#: fortran/resolve.c:9369
+#: fortran/resolve.c:9377
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/resolve.c:9379
+#: fortran/resolve.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
 
-#: fortran/resolve.c:9626
+#: fortran/resolve.c:9634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "雙倍類別是區塊在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:9760
+#: fortran/resolve.c:9768
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9769
+#: fortran/resolve.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9772
+#: fortran/resolve.c:9780
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9782 fortran/resolve.c:9787
+#: fortran/resolve.c:9790 fortran/resolve.c:9795
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9896
+#: fortran/resolve.c:9904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.c:9948
+#: fortran/resolve.c:9956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "停止編碼於 %L 必須是純量"
 
-#: fortran/resolve.c:9958
+#: fortran/resolve.c:9966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法 polymorphic 除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9971
+#: fortran/resolve.c:9979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9980
+#: fortran/resolve.c:9988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "資料轉移元件於 %L 無法有程序指標成分"
 
-#: fortran/resolve.c:9987
+#: fortran/resolve.c:9995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有 ALLOCATABLE 成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9998
+#: fortran/resolve.c:10006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "資料轉移元件於 %L 無法有私人的成分"
 
-#: fortran/resolve.c:10004
+#: fortran/resolve.c:10012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:10019
+#: fortran/resolve.c:10027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "資料轉移元件於 %L 無法全部參考到 assumed-size 陣列"
 
-#: fortran/resolve.c:10076
+#: fortran/resolve.c:10084
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.c:10086
+#: fortran/resolve.c:10094
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.c:10090
+#: fortran/resolve.c:10098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.c:10093
+#: fortran/resolve.c:10101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.c:10100 fortran/resolve.c:10222
+#: fortran/resolve.c:10108 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:10112 fortran/resolve.c:10230
+#: fortran/resolve.c:10120 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:10124
+#: fortran/resolve.c:10132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=引數於 %L 必須是純量邏輯的變數"
 
-#: fortran/resolve.c:10137
+#: fortran/resolve.c:10145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.c:10198
+#: fortran/resolve.c:10206
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.c:10202 fortran/resolve.c:10212
+#: fortran/resolve.c:10210 fortran/resolve.c:10220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset 引數於 %L 必須介於 1 和 numimages()(_I)"
 
-#: fortran/resolve.c:10257
+#: fortran/resolve.c:10265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "敘述於 %L 並非有效分支目標敘述用於分支敘述於 %L"
 
-#: fortran/resolve.c:10267
+#: fortran/resolve.c:10275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "分支於 %L 也許會導致無窮迴圈"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10284 fortran/resolve.c:10307
+#: fortran/resolve.c:10292 fortran/resolve.c:10315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往敘述於 %L 樹葉重要建構用於標貼於 %L"
 
-#: fortran/resolve.c:10288 fortran/resolve.c:10313
+#: fortran/resolve.c:10296 fortran/resolve.c:10321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
@@ -72741,197 +72806,197 @@ msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10328
+#: fortran/resolve.c:10336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "標貼於 %L 不是在中相同區塊做為前往敘述於 %L"
 
-#: fortran/resolve.c:10400
+#: fortran/resolve.c:10408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "位置遮罩於 %L 有不一致形狀"
 
-#: fortran/resolve.c:10416
+#: fortran/resolve.c:10424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "位置指派目標於 %L 有不一致形狀"
 
-#: fortran/resolve.c:10424 fortran/resolve.c:10511
+#: fortran/resolve.c:10432 fortran/resolve.c:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL 使用者定義的指派在中位置於 %L"
 
-#: fortran/resolve.c:10434 fortran/resolve.c:10521
+#: fortran/resolve.c:10442 fortran/resolve.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L 處在 WHERE 內不支援的敘述"
 
-#: fortran/resolve.c:10465
+#: fortran/resolve.c:10473
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:10474
+#: fortran/resolve.c:10482
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL 與索引『%s』未被使用左側的側邊的指派於 %L 和因而也許造成多重指派到這個物件"
 
-#: fortran/resolve.c:10621
+#: fortran/resolve.c:10629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Fortran 2008:區塊建構於 %C"
 
-#: fortran/resolve.c:10642
+#: fortran/resolve.c:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.c:10652
+#: fortran/resolve.c:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "外 FORALL 建構已經有索引與這個名稱 %L"
 
-#: fortran/resolve.c:10729
+#: fortran/resolve.c:10737
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L 處的 WHERE/ELSEWHERE 子句需要一個 LOGICAL 陣列"
 
-#: fortran/resolve.c:10831
+#: fortran/resolve.c:10839
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10944
+#: fortran/resolve.c:10952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "字元運算式將被截斷在中指派 (%d/%d) 於 %L"
 
-#: fortran/resolve.c:10976
+#: fortran/resolve.c:10984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Coindexed 運算式於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10982
+#: fortran/resolve.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10994
+#: fortran/resolve.c:11002
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "指派到 coindexed 變數於 %L 在中 PURE 程序"
 
-#: fortran/resolve.c:11026
+#: fortran/resolve.c:11034
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:11030
+#: fortran/resolve.c:11038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:11035
+#: fortran/resolve.c:11043
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:11042
+#: fortran/resolve.c:11050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "變數必須不是 polymorphic 在中 intrinsic 指派於 %L - 檢查該有匹配特定的副常式用於『=』運算子"
 
-#: fortran/resolve.c:11053
+#: fortran/resolve.c:11061
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Coindexed 變數必須不是有 allocatable ultimate 成分在中指派於 %L"
 
-#: fortran/resolve.c:11373
+#: fortran/resolve.c:11381
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11615
+#: fortran/resolve.c:11623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "無效的程序指標指派於 %L"
 
-#: fortran/resolve.c:11627
+#: fortran/resolve.c:11635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/resolve.c:11882
+#: fortran/resolve.c:11890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "指派的前往敘述於 %L 需求整數變數"
 
-#: fortran/resolve.c:11886
+#: fortran/resolve.c:11894
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "變數「%s」在 %L 尚未指派到目標標籤"
 
-#: fortran/resolve.c:11897
+#: fortran/resolve.c:11905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "交替回傳敘述於 %L 需要 SCALAR-INTEGER 回傳說明符"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "指派敘述於 %L 需要純量預設整數變數"
 
-#: fortran/resolve.c:12009
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.c:12013
+#: fortran/resolve.c:12022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "算術如果敘述於 %L 需要數值運算式"
 
-#: fortran/resolve.c:12074
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "離開條件的做當迴圈於 %L 必須是純量邏輯的運算式"
 
-#: fortran/resolve.c:12163
+#: fortran/resolve.c:12172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL 遮罩子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/resolve.c:12245
+#: fortran/resolve.c:12254
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/resolve.c:12266
+#: fortran/resolve.c:12275
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "未使用的參數『%s』宣告的於 %L"
 
-#: fortran/resolve.c:12360
+#: fortran/resolve.c:12369
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12374
+#: fortran/resolve.c:12383
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -72939,981 +73004,981 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12393
+#: fortran/resolve.c:12402
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
-#: fortran/resolve.c:12479
+#: fortran/resolve.c:12488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "字串長度於 %L 太大"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12722
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可指派的陣列「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:12717
+#: fortran/resolve.c:12726
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "純量物件『%s』於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:12725
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "陣列指標「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:12736
+#: fortran/resolve.c:12745
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "陣列「%s」在 %L 處不能有延遲的外形"
 
-#: fortran/resolve.c:12752
+#: fortran/resolve.c:12761
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "型態『%s』的類別變數『%s』於 %L 不是 extensible"
 
-#: fortran/resolve.c:12764
+#: fortran/resolve.c:12773
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "類別變數『%s』於 %L 必須是虛設，allocatable 或指標"
 
-#: fortran/resolve.c:12797
+#: fortran/resolve.c:12806
 #, fuzzy, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "型態『%s』無法主機關聯的於 %L 因為它被阻斷由不相容的物件的同名宣告的於 %L"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12828
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008:意味著的儲存用於模組變數『%s』於 %L, 所需的由於預設初始化"
 
-#: fortran/resolve.c:12850
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12886
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "模組或主程式陣列「%s」在 %L 處必須有常態的外形"
 
-#: fortran/resolve.c:12911
+#: fortran/resolve.c:12920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "實體與假設的字元長度於 %L 必須是虛引數或參數"
 
-#: fortran/resolve.c:12932
+#: fortran/resolve.c:12941
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "『%s』於 %L 必須有常數字元長度在中這個語境"
 
-#: fortran/resolve.c:12939
+#: fortran/resolve.c:12948
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.c:12986
+#: fortran/resolve.c:12995
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可指派的「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12989
+#: fortran/resolve.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12992
+#: fortran/resolve.c:13001
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12995
+#: fortran/resolve.c:13004
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "內建函式「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12998
+#: fortran/resolve.c:13007
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函式結果「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:13001
+#: fortran/resolve.c:13010
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自動陣列「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:13043
+#: fortran/resolve.c:13052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，於 %s:%d"
 
-#: fortran/resolve.c:13075
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Character-valued 敘述函式『%s』於 %L 必須有常數長度"
 
-#: fortran/resolve.c:13098
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:『%s』是的私人的型態和無法虛引數的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:13120
+#: fortran/resolve.c:13129
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003:程序『%s』在中公用的介面『%s』於 %L 需虛引數的『%s』該項是私人的"
 
-#: fortran/resolve.c:13138
+#: fortran/resolve.c:13147
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函式『%s』於 %L 無法有初始設定式"
 
-#: fortran/resolve.c:13150
+#: fortran/resolve.c:13159
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部物件「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:13159
+#: fortran/resolve.c:13168
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL 函式『%s』於 %L 必須有純量結果"
 
-#: fortran/resolve.c:13169
+#: fortran/resolve.c:13178
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "敘述函式『%s』於 %L 可能無法有指標或 allocatable 屬性"
 
-#: fortran/resolve.c:13188
+#: fortran/resolve.c:13197
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以陣列賦值"
 
-#: fortran/resolve.c:13192
+#: fortran/resolve.c:13201
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 
-#: fortran/resolve.c:13196
+#: fortran/resolve.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:13200
+#: fortran/resolve.c:13209
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "字元 (*) 函式『%s』於 %L 無法遞迴"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13222
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:13224
+#: fortran/resolve.c:13233
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "程序『%s』在中 %s 於 %L 沒有任何明確的介面"
 
-#: fortran/resolve.c:13230
+#: fortran/resolve.c:13239
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "虛設程序『%s』於 %C 無法有通用介面"
 
-#: fortran/resolve.c:13250
+#: fortran/resolve.c:13259
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:13307
+#: fortran/resolve.c:13316
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "程序屬性衝突與儲存屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:13313
+#: fortran/resolve.c:13322
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "程序屬性衝突與含義屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13328
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "程序屬性衝突與結果屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:13327
+#: fortran/resolve.c:13336
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "外部屬性衝突與函式屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:13333
+#: fortran/resolve.c:13342
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "程序指標結果『%s』於 %L 缺少指標屬性"
 
-#: fortran/resolve.c:13376
+#: fortran/resolve.c:13385
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13384
+#: fortran/resolve.c:13393
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13392
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13401
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13485
+#: fortran/resolve.c:13494
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "最後的程序『%s』於 %L 並非副常式"
 
-#: fortran/resolve.c:13494
+#: fortran/resolve.c:13503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "最後的程序於 %L 必須有精確的一個引數"
 
-#: fortran/resolve.c:13503
+#: fortran/resolve.c:13512
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "引數的最後的程序於 %L 必須是的型態『%s』"
 
-#: fortran/resolve.c:13511
+#: fortran/resolve.c:13520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "引數的最後的程序於 %L 必須不是指標"
 
-#: fortran/resolve.c:13517
+#: fortran/resolve.c:13526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "引數的最後的程序於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:13523
+#: fortran/resolve.c:13532
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "引數的最後的程序於 %L 必須不是可選的"
 
-#: fortran/resolve.c:13531
+#: fortran/resolve.c:13540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "引數的最後的程序於 %L 必須不是含義 (出)"
 
-#: fortran/resolve.c:13540
+#: fortran/resolve.c:13549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Non-scalar 最後的程序於 %L 應該已假設形狀引數"
 
-#: fortran/resolve.c:13562
+#: fortran/resolve.c:13571
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "最後的程序『%s』宣告的於 %L 有同級 (%d) 做為『%s』"
 
-#: fortran/resolve.c:13599
+#: fortran/resolve.c:13608
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "只有陣列最後的程序宣告的用於衍生類型『%s』定義的於 %L, 建議也純量一個"
 
-#: fortran/resolve.c:13639
+#: fortran/resolve.c:13648
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "『%s』和『%s』無法混合的函式/副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.c:13675
+#: fortran/resolve.c:13684
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "『%s』和『%s』用於通用『%s』於 %L 是模稜兩可的"
 
-#: fortran/resolve.c:13734
+#: fortran/resolve.c:13743
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定義的特定的繫結『%s』做為目標的通用『%s』於 %L"
 
-#: fortran/resolve.c:13746
+#: fortran/resolve.c:13755
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "通用『%s』於 %L 必須目標特定的繫結，『%s』是通用，太"
 
-#: fortran/resolve.c:13774
+#: fortran/resolve.c:13783
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "通用『%s』於 %L 無法覆寫特定的繫結與同名"
 
-#: fortran/resolve.c:13830
+#: fortran/resolve.c:13839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Type-bound 運算子於 %L 無法 NOPASS"
 
-#: fortran/resolve.c:14042
+#: fortran/resolve.c:14051
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "『%s』必須是模組程序或外部程序與明確的介面於 %L"
 
-#: fortran/resolve.c:14085
+#: fortran/resolve.c:14094
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:14099
+#: fortran/resolve.c:14108
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "程序『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:14113 fortran/resolve.c:14599
+#: fortran/resolve.c:14122 fortran/resolve.c:14608
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Non-polymorphic passed-object 虛引數的『%s』於 %L"
 
-#: fortran/resolve.c:14121
+#: fortran/resolve.c:14130
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:14130
+#: fortran/resolve.c:14139
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是純量"
 
-#: fortran/resolve.c:14136
+#: fortran/resolve.c:14145
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:14142
+#: fortran/resolve.c:14151
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是指標"
 
-#: fortran/resolve.c:14171
+#: fortran/resolve.c:14180
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "程序『%s』於 %L 有同名做為成分的『%s』"
 
-#: fortran/resolve.c:14181
+#: fortran/resolve.c:14190
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "程序『%s』於 %L 有同名做為繼承的成分的『%s』"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "衍生類型『%s』宣告的於 %L 必須是摘要因為『%s』是已推遲和無法 overridden"
 
-#: fortran/resolve.c:14379
+#: fortran/resolve.c:14388
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Coarray 成分『%s』於 %L 必須是 allocatable 與已推遲形狀"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14397
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:14398
+#: fortran/resolve.c:14407
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14432
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "成分『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L 處 ICHAR 的參數長度必須為 1"
 
-#: fortran/resolve.c:14532
+#: fortran/resolve.c:14541
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序指標成分『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:14546
+#: fortran/resolve.c:14555
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "程序指標成分『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14571
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:14572
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是純量"
 
-#: fortran/resolve.c:14581
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法有指標屬性"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14599
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:14632
+#: fortran/resolve.c:14641
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "成分『%s』的『%s』於 %L 有同名做為繼承 type-bound 程序"
 
-#: fortran/resolve.c:14645
+#: fortran/resolve.c:14654
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "字元長度的成分『%s』需要是常數規格運算式於 %L"
 
-#: fortran/resolve.c:14656
+#: fortran/resolve.c:14665
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字元成分『%s』的『%s』於 %L 與已推遲長度必須是指標或 ALLOCATABLE"
 
-#: fortran/resolve.c:14689
+#: fortran/resolve.c:14698
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:成分『%s』是私人的型態和無法成分的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:14697
+#: fortran/resolve.c:14706
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 於 %L 在中序列或繫結©型態 %s"
 
-#: fortran/resolve.c:14706
+#: fortran/resolve.c:14715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "成分 %s 的序列型態宣告的於 %L 沒有序列屬性"
 
-#: fortran/resolve.c:14792
+#: fortran/resolve.c:14801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "衝突在中屬性的函式引數於 %C"
 
-#: fortran/resolve.c:14837
+#: fortran/resolve.c:14846
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "做為延伸型態『%s』於 %L 有 coarray 成分，親代型態『%s』應該也有一個"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14859
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Non-extensible 衍生類型『%s』於 %L 必須不是摘要"
 
-#: fortran/resolve.c:14914
+#: fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14947
+#: fortran/resolve.c:14956
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003:通用名稱『%s』的函式『%s』於 %L 相同名稱做為衍生類型於 %L"
 
-#: fortran/resolve.c:14961
+#: fortran/resolve.c:14970
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.c:15026
+#: fortran/resolve.c:15035
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %L 未被允許"
 
-#: fortran/resolve.c:15032
+#: fortran/resolve.c:15041
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與假設的形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:15038
+#: fortran/resolve.c:15047
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與 nonconstant 形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:15046
+#: fortran/resolve.c:15055
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列物件『%s』與 nonconstant 字元長度在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15072
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』被宣告私人的和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:15085
+#: fortran/resolve.c:15094
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "名稱表列物件『%s』已 use-associated 私人的成分和無法成員的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:15096
+#: fortran/resolve.c:15105
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』有私人的成分和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15132
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "程序屬性衝突與名稱表列屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:15142
+#: fortran/resolve.c:15151
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "參數陣列『%s』於 %L 無法自動或的已推遲形狀"
 
-#: fortran/resolve.c:15158
+#: fortran/resolve.c:15167
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "隱含地型態的參數『%s』於 %L 不匹配稍後隱含的型態"
 
-#: fortran/resolve.c:15169
+#: fortran/resolve.c:15178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "不相容的衍生類型在中參數於 %L"
 
-#: fortran/resolve.c:15177
+#: fortran/resolve.c:15186
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "共同區塊『%s』於 %L 無法有外部屬性"
 
-#: fortran/resolve.c:15228
+#: fortran/resolve.c:15237
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
-#: fortran/resolve.c:15239
+#: fortran/resolve.c:15248
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15246
+#: fortran/resolve.c:15255
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15286
+#: fortran/resolve.c:15295
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15350
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "保護的屬性衝突與外部屬性於 %L"
 
-#: fortran/resolve.c:15353
+#: fortran/resolve.c:15362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "程序屬性衝突與保護的屬性於 %L"
 
-#: fortran/resolve.c:15453
+#: fortran/resolve.c:15462
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標或 assumed-shape 陣列"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "不當的規格用於假設的大小陣列於 %C"
 
-#: fortran/resolve.c:15487
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "假定大小的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:15490
+#: fortran/resolve.c:15499
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:15500
+#: fortran/resolve.c:15509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15516
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15520
+#: fortran/resolve.c:15529
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L 處的符號不是一個 DUMMY 變數"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15535
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "『%s』於 %L 無法有值屬性因為它並非虛引數"
 
-#: fortran/resolve.c:15536
+#: fortran/resolve.c:15545
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "字元虛設變數『%s』於 %L 與值屬性必須有常數長度"
 
-#: fortran/resolve.c:15545
+#: fortran/resolve.c:15554
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C 可交流的字元虛設變數『%s』於 %L 與值屬性必須有長度一個"
 
-#: fortran/resolve.c:15558 fortran/resolve.c:15735
+#: fortran/resolve.c:15567 fortran/resolve.c:15744
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "衍生類型『%s』於 %L 是的型態『%s』，該項未被定義"
 
-#: fortran/resolve.c:15572
+#: fortran/resolve.c:15581
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15581
+#: fortran/resolve.c:15590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15590
+#: fortran/resolve.c:15599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:15598
+#: fortran/resolve.c:15607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:15605
+#: fortran/resolve.c:15614
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15625
+#: fortran/resolve.c:15634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "假設的形狀陣列『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/resolve.c:15632
+#: fortran/resolve.c:15641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:15639
+#: fortran/resolve.c:15648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:15646
+#: fortran/resolve.c:15655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/resolve.c:15672
+#: fortran/resolve.c:15681
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "變數『%s』於 %L 無法繫結©因為它是 neither 共同區塊 nor 宣告的於模組等級範圍"
 
-#: fortran/resolve.c:15682
+#: fortran/resolve.c:15691
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "%s 的參數(位於 %L)長度必須為 1"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15770
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003:公用的 %s『%s』於 %L 的私人的衍生類型『%s』"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:15789
+#: fortran/resolve.c:15798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:15807
+#: fortran/resolve.c:15816
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "含義 (出) 虛引數『%s』於 %L 是假設的大小和因而無法有預設初始設定式"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15828
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:15841
+#: fortran/resolve.c:15850
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函數計算結果『%s』於 %L 不應該是 coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:15850
+#: fortran/resolve.c:15859
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "變數『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:15863
+#: fortran/resolve.c:15872
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "變數『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:15879
+#: fortran/resolve.c:15888
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "變數『%s』於 %L 是 coarray 和不是 ALLOCATABLE，儲存 nor 虛引數"
 
-#: fortran/resolve.c:15887
+#: fortran/resolve.c:15896
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:15894
+#: fortran/resolve.c:15903
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allocatable coarray 變數『%s』於 %L 必須已已推遲形狀"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15916
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "變數『%s』於 %L 是含義 (出) 和可以因而無法是 allocatable coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:15916
+#: fortran/resolve.c:15925
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15932
+#: fortran/resolve.c:15941
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15938
+#: fortran/resolve.c:15947
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15963
+#: fortran/resolve.c:15972
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/resolve.c:16033
+#: fortran/resolve.c:16042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate 於 %L 不是儲存"
 
-#: fortran/resolve.c:16044
+#: fortran/resolve.c:16053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16149
+#: fortran/resolve.c:16158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "預期具名的實體清單的於 %C"
 
-#: fortran/resolve.c:16157
+#: fortran/resolve.c:16166
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "區塊資料元素『%s』於 %L 必須是在中共同"
 
-#: fortran/resolve.c:16164
+#: fortran/resolve.c:16173
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "資料陣列『%s』於 %L 必須被指定的在中前一個宣告"
 
-#: fortran/resolve.c:16171
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "資料元素『%s』於 %L 無法有 coindex"
 
-#: fortran/resolve.c:16187
+#: fortran/resolve.c:16196
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "資料元素『%s』於 %L 是指標和因而必須是全部陣列"
 
-#: fortran/resolve.c:16194
+#: fortran/resolve.c:16203
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16203
+#: fortran/resolve.c:16212
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "引數『%s』的 elemental 程序於 %L 無法有 ALLOCATABLE 屬性"
 
-#: fortran/resolve.c:16249
+#: fortran/resolve.c:16258
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Nonconstant 陣列區段於 %L 在中資料敘述"
 
-#: fortran/resolve.c:16262
+#: fortran/resolve.c:16271
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "資料敘述於 %L 有更多變數比值"
 
-#: fortran/resolve.c:16361
+#: fortran/resolve.c:16370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "開始的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:16369
+#: fortran/resolve.c:16378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "結束的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:16377
+#: fortran/resolve.c:16386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:16384
+#: fortran/resolve.c:16393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:16509
+#: fortran/resolve.c:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "資料敘述於 %L 有更多值比變數"
 
-#: fortran/resolve.c:16675
+#: fortran/resolve.c:16684
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "標籤 %d 於 %L 經定義但未被使用"
 
-#: fortran/resolve.c:16681
+#: fortran/resolve.c:16690
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "標籤 %d 於 %L 經定義但無法被使用"
 
-#: fortran/resolve.c:16765
+#: fortran/resolve.c:16774
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 必須有序列屬性為等價物件"
 
-#: fortran/resolve.c:16774
+#: fortran/resolve.c:16783
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 無法有 ALLOCATABLE 成分為等價物件"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16791
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "衍生類型變數『%s』於 %L 與預設初始化無法在中等價與變數在中共同"
 
-#: fortran/resolve.c:16798
+#: fortran/resolve.c:16807
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 與指標成分無法等價物件"
 
-#: fortran/resolve.c:16901
+#: fortran/resolve.c:16910
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L 處 EQUIVALENCE 敘述語法錯誤"
 
-#: fortran/resolve.c:16916
+#: fortran/resolve.c:16925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "還是所有或沒有任何物件在中等價設定於 %L 應該有保護的屬性"
 
-#: fortran/resolve.c:16941
+#: fortran/resolve.c:16950
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "共同區塊成員『%s』於 %L 無法等價物件在中 pure 程序『%s』"
 
-#: fortran/resolve.c:16950
+#: fortran/resolve.c:16959
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "具名的常數『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:17023
+#: fortran/resolve.c:17032
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "陣列『%s』於 %L 與 non-constant 邊界無法等價物件"
 
-#: fortran/resolve.c:17034
+#: fortran/resolve.c:17043
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "結構成分『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:17045
+#: fortran/resolve.c:17054
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字串長度為零"
 
-#: fortran/resolve.c:17076
+#: fortran/resolve.c:17085
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C 處指定字元長度時語法錯誤"
 
-#: fortran/resolve.c:17143
+#: fortran/resolve.c:17152
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003:公用的函式『%s』於 %L 的私人的型態『%s』"
 
-#: fortran/resolve.c:17156
+#: fortran/resolve.c:17165
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:17176
+#: fortran/resolve.c:17185
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "使用者運算子程序『%s』於 %L 必須是函式"
 
-#: fortran/resolve.c:17186
+#: fortran/resolve.c:17195
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "使用者運算子程序『%s』於 %L 無法假設的字元長度"
 
-#: fortran/resolve.c:17194
+#: fortran/resolve.c:17203
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "使用者運算子程序『%s』於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:17208
+#: fortran/resolve.c:17217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "第一個引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:17226
+#: fortran/resolve.c:17235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "秒引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:17233
+#: fortran/resolve.c:17242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "運算子介面於 %L 必須有，最多，兩引數"
 
-#: fortran/resolve.c:17312
+#: fortran/resolve.c:17321
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "包含的程序『%s』於 %L 的 PURE 程序必須也是 PURE"
@@ -74802,17 +74867,17 @@ msgstr "重疊 unequal 初始設定式在中等價於 %L"
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.c:6171
+#: fortran/trans-array.c:6138
 #, fuzzy, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "元件號碼的在中陣列建構子於 %L 需求增加的允許 %d 上限。  參看 -fmax-array-constructor 選項"
 
-#: fortran/trans-array.c:8204
+#: fortran/trans-array.c:8171
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "建立陣列暫時的於 %L 用於引數『%s』"
 
-#: fortran/trans-array.c:11392
+#: fortran/trans-array.c:11360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "不當的運算式型態在的期間遍歷 (%d)"
@@ -74904,108 +74969,108 @@ msgstr "non-constant 初始化運算式於 %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1763
+#: fortran/trans-decl.c:1764
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "內建函式變數不是一個程序"
 
-#: fortran/trans-decl.c:4594 fortran/trans-decl.c:6958
+#: fortran/trans-decl.c:4599 fortran/trans-decl.c:6963
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "傳回值的函式『%s』於 %L 無法設定"
 
-#: fortran/trans-decl.c:5082
+#: fortran/trans-decl.c:5087
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "已推遲型態參數尚未支援"
 
-#: fortran/trans-decl.c:5322
+#: fortran/trans-decl.c:5327
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "模組變數 %s 的後端程式宣告已存在"
 
-#: fortran/trans-decl.c:5335
+#: fortran/trans-decl.c:5340
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "未使用的變數『%s』宣告的於 %L"
 
-#: fortran/trans-decl.c:5960
+#: fortran/trans-decl.c:5965
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "虛引數『%s』於 %L 被宣告含義 (出) 但是不是設定"
 
-#: fortran/trans-decl.c:5966
+#: fortran/trans-decl.c:5971
 #, fuzzy, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "衍生類型虛引數『%s』於 %L 被宣告含義 (出) 但是不是設定和沒有預設初始設定式"
 
-#: fortran/trans-decl.c:5977 fortran/trans-decl.c:6123
+#: fortran/trans-decl.c:5982 fortran/trans-decl.c:6128
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "未使用的虛引數『%s』於 %L"
 
-#: fortran/trans-decl.c:5993
+#: fortran/trans-decl.c:5998
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "未使用的模組變數『%s』該項已被明確的匯入的於 %L"
 
-#: fortran/trans-decl.c:6012
+#: fortran/trans-decl.c:6017
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "未使用的變數『%s』宣告的於 %L"
 
-#: fortran/trans-decl.c:6061
+#: fortran/trans-decl.c:6066
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "未使用的參數『%s』宣告的於 %L"
 
-#: fortran/trans-decl.c:6065
+#: fortran/trans-decl.c:6070
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "未使用的參數『%s』該項已被明確的匯入的於 %L"
 
-#: fortran/trans-decl.c:6095
+#: fortran/trans-decl.c:6100
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "傳回值『%s』的函式『%s』宣告的於 %L 無法設定"
 
-#: fortran/trans-decl.c:6687
+#: fortran/trans-decl.c:6692
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.c:1030
+#: fortran/trans-expr.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.c:1798
+#: fortran/trans-expr.c:1835
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:2115
+#: fortran/trans-expr.c:2152
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:2124
+#: fortran/trans-expr.c:2161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "無限制的多型於 %C 尚未支援"
 
-#: fortran/trans-expr.c:3793
+#: fortran/trans-expr.c:3830
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "不明的內建作業"
 
-#: fortran/trans-expr.c:5292
+#: fortran/trans-expr.c:5329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "不明引數清單函式於 %L"
 
-#: fortran/trans-expr.c:9511
+#: fortran/trans-expr.c:9560
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -75160,7 +75225,7 @@ msgstr ""
 msgid "gfc_validate_kind(): Got bad kind"
 msgstr ""
 
-#: fortran/trans.c:2220
+#: fortran/trans.c:2230
 #, gcc-internal-format
 msgid "gfc_trans_code(): Bad statement code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
@@ -75289,7 +75354,7 @@ msgstr "-fwpa 和 -fltrans 彼此互斥"
 
 #: lto/lto-lang.c:898
 #, fuzzy, gcc-internal-format
-msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "-fwpa 和 -fltrans 彼此互斥"
 
 #: lto/lto-object.c:107
@@ -76400,7 +76465,7 @@ msgstr "無法辨識的選項到 -finit-real：%s"
 msgid "Unrecognized option to floating-point init value: %qs"
 msgstr "無法辨識的選項到 -finit-real：%s"
 
-#: fortran/lang.opt:775
+#: fortran/lang.opt:771
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized option '-%s'"
 msgid "Unrecognized option: %qs"
@@ -76419,15 +76484,15 @@ msgstr "%qs 後缺少巨集名"
 
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
-#: c-family/c.opt:236 c-family/c.opt:2120 c-family/c.opt:2128 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3319
+#: c-family/c.opt:236 c-family/c.opt:2107 c-family/c.opt:2115 brig/lang.opt:44
+#: config/darwin.opt:30 common.opt:324 common.opt:327 common.opt:3323
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "%qs 後缺少檔案名稱"
 
 #: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
-#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2116
-#: c-family/c.opt:2136 c-family/c.opt:2140 c-family/c.opt:2144
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:2103
+#: c-family/c.opt:2123 c-family/c.opt:2127 c-family/c.opt:2131
 #, gcc-internal-format
 msgid "missing path after %qs"
 msgstr "%qs 後缺少路徑"
@@ -76482,7 +76547,7 @@ msgstr "缺少左括號"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "無法辨識的可視性值 %qs"
 
-#: c-family/c.opt:1980
+#: c-family/c.opt:1967
 #, fuzzy, gcc-internal-format
 msgid "unrecognized scalar storage order value %qs"
 msgstr "無法辨識的暫存器名稱 %qs"
@@ -76567,93 +76632,93 @@ msgstr "%qE 被不宜用"
 msgid "unknown linker output %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1502
+#: common.opt:1506
 #, fuzzy, gcc-internal-format
 msgid "unknown excess precision style %qs"
 msgstr "不明過剩精確度樣式 %qs"
 
-#: common.opt:1517
+#: common.opt:1521
 #, gcc-internal-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1561
+#: common.opt:1565
 #, fuzzy, gcc-internal-format
 msgid "unknown floating point contraction style %qs"
 msgstr "不明浮點數合約樣式 %qs"
 
-#: common.opt:1718
+#: common.opt:1722
 #, fuzzy, gcc-internal-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy, gcc-internal-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy, gcc-internal-format
 msgid "unknown IRA algorithm %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: common.opt:1902
+#: common.opt:1906
 #, fuzzy, gcc-internal-format
 msgid "unknown IRA region %qs"
 msgstr "不明 IRA 區域 %qs"
 
-#: common.opt:1980
+#: common.opt:1984
 #, fuzzy, gcc-internal-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2082
+#: common.opt:2086
 #, fuzzy, gcc-internal-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs 後判定語"
 
-#: common.opt:2090
+#: common.opt:2094
 #, fuzzy, gcc-internal-format
 msgid "unknown offload ABI %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy, gcc-internal-format
 msgid "unknown profile reproducibility method %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2248
+#: common.opt:2252
 #, fuzzy, gcc-internal-format
 msgid "unknown profile update method %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2350
+#: common.opt:2354
 #, fuzzy, gcc-internal-format
 msgid "unknown Live-Patching Level %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy, gcc-internal-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: common.opt:2690
+#: common.opt:2694
 #, fuzzy, gcc-internal-format
 msgid "unknown TLS model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:3026
+#: common.opt:3030
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:3067
+#: common.opt:3071
 #, fuzzy, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "無法辨識的可視性值 %qs"
 
-#: common.opt:3086
+#: common.opt:3090
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
@@ -76997,6 +77062,10 @@ msgstr "不明 TLS 式樣 %qs"
 #~ msgid "%qT has a mutable member"
 #~ msgstr "%q#T 有指標資料成員"
 
+#, fuzzy
+#~ msgid "cannot deduce template arguments for %qT from %<()%>"
+#~ msgstr "在中模板引數用於型態 %qT "
+
 #, fuzzy
 #~ msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 #~ msgstr "未預期的垃圾之後 $OMP 主敘述於 %C"
@@ -79930,10 +79999,6 @@ msgstr "不明 TLS 式樣 %qs"
 #~ msgid "%qE does not have class type"
 #~ msgstr "%qE 不是一個類別"
 
-#, fuzzy
-#~ msgid "lambda-expression in unevaluated context"
-#~ msgstr "lambda-expression 在中 unevaluated 語境"
-
 #, fuzzy
 #~ msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 #~ msgstr "range-based %<for%> 運算式的型態 %qT 有 %<end%>成員並不是 %<begin%>"

From 3b6cd127eba4866ef81287c480422b5226d45bc6 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Thu, 29 Apr 2021 00:18:37 +0000
Subject: [PATCH 026/164] Daily bump.

---
 gcc/ChangeLog           | 45 +++++++++++++++++++++++++++++++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/po/ChangeLog        |  6 ++++++
 gcc/testsuite/ChangeLog |  7 +++++++
 libstdc++-v3/ChangeLog  | 20 ++++++++++++++++++
 5 files changed, 79 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index be1611a62d9aa..7aa0363874902 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,48 @@
+2021-04-28  YiFei Zhu  <zhuyifei1999@gmail.com>
+
+	Backported from master:
+	2021-04-23  YiFei Zhu  <zhuyifei1999@gmail.com>
+
+	* config/bpf/bpf.h (ASM_OUTPUT_ALIGNED_BSS): Use .type and .lcomm.
+
+2021-04-28  YiFei Zhu  <zhuyifei1999@gmail.com>
+
+	Backported from master:
+	2021-04-23  YiFei Zhu  <zhuyifei1999@gmail.com>
+
+	* config/bpf/bpf.h (FUNCTION_BOUNDARY): Set to 64.
+
+2021-04-28  Richard Earnshaw  <rearnsha@arm.com>
+
+	Backported from master:
+	2021-04-27  Richard Earnshaw  <rearnsha@arm.com>
+
+	PR target/100236
+	* config/arm/arm.c (THUMB2_WORK_REGS): Check PIC_OFFSET_TABLE_REGNUM
+	is valid before including it in the mask.
+
+2021-04-28  Uroš Bizjak  <ubizjak@gmail.com>
+
+	PR target/100182
+	* config/i386/sync.md (FILD_ATOMIC/FIST_ATOMIC FP load peephole2):
+	Copy operand 3 to operand 4.  Use sse_reg_operand
+	as operand 3 predicate.
+	(FILD_ATOMIC/FIST_ATOMIC FP load peephole2 with mem blockage): Ditto.
+	(LDX_ATOMIC/STX_ATOMIC FP load peephole2): Ditto.
+	(LDX_ATOMIC/LDX_ATOMIC FP load peephole2 with mem blockage): Ditto.
+	(FILD_ATOMIC/FIST_ATOMIC FP store peephole2):
+	Copy operand 1 to operand 0.
+	(FILD_ATOMIC/FIST_ATOMIC FP store peephole2 with mem blockage): Ditto.
+	(LDX_ATOMIC/STX_ATOMIC FP store peephole2): Ditto.
+	(LDX_ATOMIC/LDX_ATOMIC FP store peephole2 with mem blockage): Ditto.
+
+2021-04-28  Cui,Lili  <lili.cui@intel.com>
+
+	* common/config/i386/i386-common.c (processor_names):
+	Sync processor_names with processor_type.
+	* config/i386/i386-options.c (processor_cost_table):
+	Sync processor_cost_table with processor_type.
+
 2021-04-27  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 5bc3f0e75f04b..d04d9806e5b7e 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210428
+20210429
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index 87bd29a9e2932..c1928e8ccb90c 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,9 @@
+2021-04-28  Joseph Myers  <joseph@codesourcery.com>
+
+	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
+	ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
+	zh_TW.po: Update.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index aef2d12433222..d52369c3ea1a7 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,10 @@
+2021-04-28  Uroš Bizjak  <ubizjak@gmail.com>
+
+	PR target/100182
+	* gcc.target/i386/pr100182.c: New test.
+	* gcc.target/i386/pr71245-1.c (dg-final): Xfail scan-assembler-not.
+	* gcc.target/i386/pr71245-2.c (dg-final): Ditto.
+
 2021-04-27  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index a65b843c4a3be..9c33b60fc35fe 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,23 @@
+2021-04-28  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-04-28  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/100298
+	* include/bits/std_thread.h (thread::hardware_concurrency): Add
+	missing noexcept to inline definition for non-gthreads targets.
+
+2021-04-28  Jakub Jelinek  <jakub@redhat.com>
+
+	Revert:
+	2021-04-22  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/100182
+	* testsuite/29_atomics/atomic_float/1.cc: Add dg-xfail-run-if for
+	ia32.
+	* testsuite/29_atomics/atomic_float/wait_notify.cc: Add dg-skip-if for
+	ia32.
+
 2021-04-27  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:

From b6c6d7947759255dd9d1c8cac31f9aa423b020e7 Mon Sep 17 00:00:00 2001
From: Tobias Burnus <tobias@codesourcery.com>
Date: Wed, 28 Apr 2021 22:35:06 +0200
Subject: [PATCH 027/164] Fortran/OpenMP: Fix var-list expr parsing with
 array/dt

gcc/fortran/ChangeLog:

	* openmp.c (gfc_match_omp_variable_list): Gobble whitespace before
	checking whether a '%' or parenthesis-open follows as next character.

gcc/testsuite/ChangeLog:

	* gfortran.dg/gomp/map-5.f90: New test.

(cherry picked from commit e4aefface2a0e34d84b85844b11652eb28f2cf0c)
---
 gcc/fortran/openmp.c                     |  1 +
 gcc/testsuite/gfortran.dg/gomp/map-5.f90 | 13 +++++++++++++
 2 files changed, 14 insertions(+)
 create mode 100644 gcc/testsuite/gfortran.dg/gomp/map-5.f90

diff --git a/gcc/fortran/openmp.c b/gcc/fortran/openmp.c
index 1f1920cf0e12e..8e4527bfbc693 100644
--- a/gcc/fortran/openmp.c
+++ b/gcc/fortran/openmp.c
@@ -261,6 +261,7 @@ gfc_match_omp_variable_list (const char *str, gfc_omp_namelist **list,
 	case MATCH_YES:
 	  gfc_expr *expr;
 	  expr = NULL;
+	  gfc_gobble_whitespace ();
 	  if ((allow_sections && gfc_peek_ascii_char () == '(')
 	      || (allow_derived && gfc_peek_ascii_char () == '%'))
 	    {
diff --git a/gcc/testsuite/gfortran.dg/gomp/map-5.f90 b/gcc/testsuite/gfortran.dg/gomp/map-5.f90
new file mode 100644
index 0000000000000..2b4b341bc515d
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/gomp/map-5.f90
@@ -0,0 +1,13 @@
+implicit none
+type t
+  integer :: b(5)
+end type t
+integer :: a(5), x, y(5)
+type(t) :: b
+!$omp target enter data map( to: a (:) )
+!$omp target enter data map( to: b % b )
+!$omp target enter data map( to: a(:) )
+!$omp target depend(out: y (2)) nowait
+!$omp end target
+
+end

From dfaa29b5441689ce05e3c09012d3afe269770e94 Mon Sep 17 00:00:00 2001
From: Richard Sandiford <richard.sandiford@arm.com>
Date: Thu, 29 Apr 2021 09:27:51 +0100
Subject: [PATCH 028/164] aarch64: Handle SVE attributes in
 comp_type_attributes [PR100270]

Even though "SVE type" and "SVE sizeless type" are marked as
affecting type identity, the middle end doesn't truly believe
it unless we also handle them in comp_type_attributes.

gcc/
	PR target/100270
	* config/aarch64/aarch64.c (aarch64_comp_type_attributes): Handle
	SVE attributes.

gcc/testsuite/
	PR target/100270
	* gcc.target/aarch64/sve/acle/general-c/pr100270_1.c: New test.
	* gcc.target/aarch64/sve/acle/general-c/sizeless-2.c: Change
	expected error message when subtracting pointers to different
	vector types.  Expect warnings when mixing them elsewhere.
	* gcc.target/aarch64/sve/acle/general/attributes_7.c: Remove
	XFAILs.  Tweak error messages for some cases.

(cherry picked from commit 4cea5b8cb715e40e10174e6de405f26202fa3d6a)
---
 gcc/config/aarch64/aarch64.c                  |   4 +
 .../aarch64/sve/acle/general-c/pr100270_1.c   | 103 ++++++++++++++++++
 .../aarch64/sve/acle/general-c/sizeless-2.c   |  36 +++---
 .../aarch64/sve/acle/general/attributes_7.c   |  72 ++++++------
 4 files changed, 166 insertions(+), 49 deletions(-)
 create mode 100644 gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/pr100270_1.c

diff --git a/gcc/config/aarch64/aarch64.c b/gcc/config/aarch64/aarch64.c
index e979a51f3afd7..a863af17b5bac 100644
--- a/gcc/config/aarch64/aarch64.c
+++ b/gcc/config/aarch64/aarch64.c
@@ -25173,6 +25173,10 @@ aarch64_comp_type_attributes (const_tree type1, const_tree type2)
     return 0;
   if (!check_attr ("Advanced SIMD type"))
     return 0;
+  if (!check_attr ("SVE type"))
+    return 0;
+  if (!check_attr ("SVE sizeless type"))
+    return 0;
   return 1;
 }
 
diff --git a/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/pr100270_1.c b/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/pr100270_1.c
new file mode 100644
index 0000000000000..05232d79325f5
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/pr100270_1.c
@@ -0,0 +1,103 @@
+/* { dg-options "-msve-vector-bits=256" } */
+
+#include <arm_sve.h>
+
+typedef svint32_t vls_svint32_t __attribute__((arm_sve_vector_bits(256)));
+typedef svuint32_t vls_svuint32_t __attribute__((arm_sve_vector_bits(256)));
+
+typedef int32_t gnu_svint32_t __attribute__((vector_size(32)));
+typedef uint32_t gnu_svuint32_t __attribute__((vector_size(32)));
+
+#define X_gnu_svint32_t 1
+#define X_gnu_svuint32_t 2
+#define X_vls_svint32_t 3
+#define X_vls_svuint32_t 4
+
+#define CHECK(T) T: X_##T
+
+#define CHECK_TYPE(EXPR, TYPE) \
+  do { \
+    int x[_Generic (EXPR, \
+		    CHECK (gnu_svint32_t), \
+		    CHECK (gnu_svuint32_t), \
+		    CHECK (vls_svint32_t), \
+		    CHECK (vls_svuint32_t), \
+		    default : 0) == X_##TYPE ? 1 : -1]; \
+  } while (0)
+
+void
+f (gnu_svint32_t sg, gnu_svuint32_t ug, vls_svint32_t sn, vls_svuint32_t un, int c)
+{
+  CHECK_TYPE (sg, gnu_svint32_t);
+  CHECK_TYPE (ug, gnu_svuint32_t);
+  CHECK_TYPE (sn, vls_svint32_t);
+  CHECK_TYPE (un, vls_svuint32_t);
+
+  CHECK_TYPE (sg + 1, gnu_svint32_t);
+  CHECK_TYPE (ug + 1, gnu_svuint32_t);
+  CHECK_TYPE (sn + 1, vls_svint32_t);
+  CHECK_TYPE (un + 1, vls_svuint32_t);
+
+  CHECK_TYPE (1 + sg, gnu_svint32_t);
+  CHECK_TYPE (1 + ug, gnu_svuint32_t);
+  CHECK_TYPE (1 + sn, vls_svint32_t);
+  CHECK_TYPE (1 + un, vls_svuint32_t);
+
+  CHECK_TYPE (sg + sg, gnu_svint32_t);
+  CHECK_TYPE (ug + ug, gnu_svuint32_t);
+  CHECK_TYPE (sn + sn, vls_svint32_t);
+  CHECK_TYPE (un + un, vls_svuint32_t);
+
+  /* Traditional behavior for mixed signs is to pick the signedness of the
+     first operand.  We don't have any Arm-specific reason for preferring that
+     behavior.  */
+  CHECK_TYPE (sg + ug, gnu_svint32_t);
+  CHECK_TYPE (ug + sg, gnu_svuint32_t);
+  CHECK_TYPE (sn + un, vls_svint32_t);
+  CHECK_TYPE (un + sn, vls_svuint32_t);
+
+  CHECK_TYPE (c ? sg + sg : sg, gnu_svint32_t);
+  CHECK_TYPE (c ? ug + ug : ug, gnu_svuint32_t);
+  CHECK_TYPE (c ? sn + sn : sn, vls_svint32_t);
+  CHECK_TYPE (c ? un + un : un, vls_svuint32_t);
+
+  CHECK_TYPE (c ? sg + 1 : sg, gnu_svint32_t);
+  CHECK_TYPE (c ? ug + 1 : ug, gnu_svuint32_t);
+  CHECK_TYPE (c ? sn + 1 : sn, vls_svint32_t);
+  CHECK_TYPE (c ? un + 1 : un, vls_svuint32_t);
+
+  CHECK_TYPE (c ? 1 + sg : sg, gnu_svint32_t);
+  CHECK_TYPE (c ? 1 + ug : ug, gnu_svuint32_t);
+  CHECK_TYPE (c ? 1 + sn : sn, vls_svint32_t);
+  CHECK_TYPE (c ? 1 + un : un, vls_svuint32_t);
+
+  CHECK_TYPE (c ? sg : sg + sg, gnu_svint32_t);
+  CHECK_TYPE (c ? ug : ug + ug, gnu_svuint32_t);
+  CHECK_TYPE (c ? sn : sn + sn, vls_svint32_t);
+  CHECK_TYPE (c ? un : un + un, vls_svuint32_t);
+
+  CHECK_TYPE (c ? sg : sg + 1, gnu_svint32_t);
+  CHECK_TYPE (c ? ug : ug + 1, gnu_svuint32_t);
+  CHECK_TYPE (c ? sn : sn + 1, vls_svint32_t);
+  CHECK_TYPE (c ? un : un + 1, vls_svuint32_t);
+
+  CHECK_TYPE (c ? sg : 1 + sg, gnu_svint32_t);
+  CHECK_TYPE (c ? ug : 1 + ug, gnu_svuint32_t);
+  CHECK_TYPE (c ? sn : 1 + sn, vls_svint32_t);
+  CHECK_TYPE (c ? un : 1 + un, vls_svuint32_t);
+
+  CHECK_TYPE (c ? sg + sg : sg + sg, gnu_svint32_t);
+  CHECK_TYPE (c ? ug + ug : ug + ug, gnu_svuint32_t);
+  CHECK_TYPE (c ? sn + sn : sn + sn, vls_svint32_t);
+  CHECK_TYPE (c ? un + un : un + un, vls_svuint32_t);
+
+  CHECK_TYPE (c ? sg + sg : sg + 1, gnu_svint32_t);
+  CHECK_TYPE (c ? ug + ug : ug + 1, gnu_svuint32_t);
+  CHECK_TYPE (c ? sn + sn : sn + 1, vls_svint32_t);
+  CHECK_TYPE (c ? un + un : un + 1, vls_svuint32_t);
+
+  CHECK_TYPE (c ? 1 + sg : sg + sg, gnu_svint32_t);
+  CHECK_TYPE (c ? 1 + ug : ug + ug, gnu_svuint32_t);
+  CHECK_TYPE (c ? 1 + sn : sn + sn, vls_svint32_t);
+  CHECK_TYPE (c ? 1 + un : un + un, vls_svuint32_t);
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/sizeless-2.c b/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/sizeless-2.c
index 3af36de99945d..c575492c1f810 100644
--- a/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/sizeless-2.c
+++ b/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/sizeless-2.c
@@ -106,8 +106,8 @@ statements (int n)
 
   /* Pointer assignment.  */
 
-  gnu_sc_ptr = sve_sc_ptr;
-  sve_sc_ptr = gnu_sc_ptr;
+  gnu_sc_ptr = sve_sc_ptr; /* { dg-warning {incompatible pointer type} } */
+  sve_sc_ptr = gnu_sc_ptr; /* { dg-warning {incompatible pointer type} } */
 
   /* Pointer arithmetic.  */
 
@@ -120,8 +120,8 @@ statements (int n)
   sve_sc_ptr -= 0; /* { dg-error {arithmetic on pointer to SVE type 'svint8_t'} } */
   sve_sc_ptr -= 1; /* { dg-error {arithmetic on pointer to SVE type 'svint8_t'} } */
   sve_sc_ptr - sve_sc_ptr; /* { dg-error {arithmetic on pointer to SVE type 'svint8_t'} } */
-  gnu_sc_ptr - sve_sc_ptr; /* { dg-error {arithmetic on pointer to SVE type 'svint8_t'} } */
-  sve_sc_ptr - gnu_sc_ptr; /* { dg-error {arithmetic on pointer to SVE type 'svint8_t'} } */
+  gnu_sc_ptr - sve_sc_ptr; /* { dg-error {invalid operands to binary -} } */
+  sve_sc_ptr - gnu_sc_ptr; /* { dg-error {invalid operands to binary -} } */
   sve_sc1 = sve_sc_ptr[0]; /* { dg-error {arithmetic on pointer to SVE type 'svint8_t'} } */
   sve_sc1 = sve_sc_ptr[1]; /* { dg-error {arithmetic on pointer to SVE type 'svint8_t'} } */
 
@@ -133,18 +133,18 @@ statements (int n)
   sve_sc_ptr <= &sve_sc1;
   sve_sc_ptr > &sve_sc1;
   sve_sc_ptr >= &sve_sc1;
-  gnu_sc_ptr == sve_sc_ptr;
-  gnu_sc_ptr != sve_sc_ptr;
-  gnu_sc_ptr < sve_sc_ptr;
-  gnu_sc_ptr <= sve_sc_ptr;
-  gnu_sc_ptr > sve_sc_ptr;
-  gnu_sc_ptr >= sve_sc_ptr;
-  sve_sc_ptr == gnu_sc_ptr;
-  sve_sc_ptr != gnu_sc_ptr;
-  sve_sc_ptr < gnu_sc_ptr;
-  sve_sc_ptr <= gnu_sc_ptr;
-  sve_sc_ptr > gnu_sc_ptr;
-  sve_sc_ptr >= gnu_sc_ptr;
+  gnu_sc_ptr == sve_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  gnu_sc_ptr != sve_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  gnu_sc_ptr < sve_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  gnu_sc_ptr <= sve_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  gnu_sc_ptr > sve_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  gnu_sc_ptr >= sve_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  sve_sc_ptr == gnu_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  sve_sc_ptr != gnu_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  sve_sc_ptr < gnu_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  sve_sc_ptr <= gnu_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  sve_sc_ptr > gnu_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
+  sve_sc_ptr >= gnu_sc_ptr; /* { dg-warning {comparison of distinct pointer types} } */
 
   /* Conditional expressions.  */
 
@@ -154,8 +154,8 @@ statements (int n)
   0 ? 0 : sve_sc1; /* { dg-error {type mismatch in conditional expression} } */
   0 ?: sve_sc1; /* { dg-error {type mismatch in conditional expression} } */
   0 ? sve_sc_ptr : sve_sc_ptr;
-  0 ? sve_sc_ptr : gnu_sc_ptr;
-  0 ? gnu_sc_ptr : sve_sc_ptr;
+  0 ? sve_sc_ptr : gnu_sc_ptr; /* { dg-warning {pointer type mismatch} } */
+  0 ? gnu_sc_ptr : sve_sc_ptr; /* { dg-warning {pointer type mismatch} } */
 
   /* Generic associations.  */
 
diff --git a/gcc/testsuite/gcc.target/aarch64/sve/acle/general/attributes_7.c b/gcc/testsuite/gcc.target/aarch64/sve/acle/general/attributes_7.c
index e2e74700a0117..621666ce6c92a 100644
--- a/gcc/testsuite/gcc.target/aarch64/sve/acle/general/attributes_7.c
+++ b/gcc/testsuite/gcc.target/aarch64/sve/acle/general/attributes_7.c
@@ -85,19 +85,19 @@ f (int c)
 
   (void) (c ? fs8 : ss8); // { dg-error {type mismatch|different types} }
   (void) (c ? fs8 : fs8);
-  (void) (c ? fs8 : gs8); // { dg-error {type mismatch|different types} "" { xfail c++ } }
+  (void) (c ? fs8 : gs8); // { dg-error {type mismatch|different types} }
 
   (void) (c ? gs8 : ss8); // { dg-error {type mismatch|different types} }
-  (void) (c ? gs8 : fs8); // { dg-error {type mismatch|different types} "" { xfail c++ } }
+  (void) (c ? gs8 : fs8); // { dg-error {type mismatch|different types} }
   (void) (c ? gs8 : gs8);
 
   sb = fb;
   fb = sb;
 
   (void) (c ? sb : sb);
-  (void) (c ? sb : fb); // { dg-error {type mismatch|different types} "" { xfail *-*-* } }
+  (void) (c ? sb : fb); // { dg-error {type mismatch|different types} "" { xfail c } }
 
-  (void) (c ? fb : sb); // { dg-error {type mismatch|different types} "" { xfail *-*-* } }
+  (void) (c ? fb : sb); // { dg-error {type mismatch|different types} "" { xfail c } }
   (void) (c ? fb : fb);
 }
 
@@ -123,24 +123,22 @@ g (int c)
   void *select __attribute__((unused));
 
   diff = ss8 - ss8; // { dg-error {arithmetic on pointer to SVE type 'svint8_t'} }
-  diff = ss8 - fs8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" { xfail c } }
-		    // { dg-error {arithmetic on pointer to SVE type 'svint8_t'} "bogus" { target c } .-1 }
-  diff = ss8 - gs8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" { xfail c } }
-		    // { dg-error {arithmetic on pointer to SVE type 'svint8_t'} "bogus" { target c } .-1 }
+  diff = ss8 - fs8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" }
+  diff = ss8 - gs8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" }
 
-  diff = fs8 - ss8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" { xfail c } }
-		    // { dg-error {arithmetic on pointer to SVE type 'svint8_t'} "bogus" { target c } .-1 }
+  diff = fs8 - ss8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" }
   diff = fs8 - fs8;
-  diff = fs8 - gs8;
+  diff = fs8 - gs8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" }
 
-  diff = gs8 - ss8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" { xfail c } }
-		    // { dg-error {arithmetic on pointer to SVE type 'svint8_t'} "bogus" { target c } .-1 }
-  diff = gs8 - fs8;
+  diff = gs8 - ss8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" }
+  diff = gs8 - fs8; // { dg-error {invalid operands [^\n]* binary[^\n]*\-} "" }
   diff = gs8 - gs8;
 
-  fs8 = ss8; // { dg-error {invalid conversion} "" { xfail c } }
+  fs8 = ss8; // { dg-error {invalid conversion} "" { target c++ } }
+	     // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
   fs8 = fs8;
-  fs8 = gs8;
+  fs8 = gs8; // { dg-error {invalid conversion} "" { target c++ } }
+	     // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
 
   fs8 = su8; // { dg-error {cannot convert} "c++" { target c++ } }
 	     // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
@@ -150,36 +148,48 @@ g (int c)
 	     // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
 
   fs8 = ss16; // { dg-error {cannot convert} "c++" { target c++ } }
-              // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
+	      // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
   fs8 = fs16; // { dg-error {cannot convert} "c++" { target c++ } }
-              // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
+	      // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
   fs8 = gs16; // { dg-error {cannot convert} "c++" { target c++ } }
-              // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
+	      // { dg-warning {incompatible pointer type} "c" { target c } .-1 }
 
   select = c ? ss8 : ss8;
-  select = c ? ss8 : fs8; // { dg-error {distinct pointer types} "" { xfail c } }
-  select = c ? ss8 : gs8; // { dg-error {distinct pointer types} "" { xfail c } }
+  select = c ? ss8 : fs8; // { dg-error {distinct pointer types} "" { target c++ } }
+			  // { dg-warning {pointer type mismatch} "c" { target c } .-1 }
+  select = c ? ss8 : gs8; // { dg-error {distinct pointer types} "" { target c++ } }
+			  // { dg-warning {pointer type mismatch} "c" { target c } .-1 }
 
-  select = c ? fs8 : ss8; // { dg-error {distinct pointer types} "" { xfail c } }
+  select = c ? fs8 : ss8; // { dg-error {distinct pointer types} "" { target c++ } }
+			  // { dg-warning {pointer type mismatch} "c" { target c } .-1 }
   select = c ? fs8 : fs8;
-  select = c ? fs8 : gs8; // { dg-error {distinct pointer types} "" { xfail *-*-* } }
+  select = c ? fs8 : gs8; // { dg-error {distinct pointer types} "" { target c++ } }
+			  // { dg-warning {pointer type mismatch} "c" { target c } .-1 }
 
-  select = c ? gs8 : ss8; // { dg-error {distinct pointer types} "" { xfail c } }
-  select = c ? gs8 : fs8; // { dg-error {distinct pointer types} "" { xfail *-*-* } }
+  select = c ? gs8 : ss8; // { dg-error {distinct pointer types} "" { target c++ } }
+			  // { dg-warning {pointer type mismatch} "c" { target c } .-1 }
+  select = c ? gs8 : fs8; // { dg-error {distinct pointer types} "" { target c++ } }
+			  // { dg-warning {pointer type mismatch} "c" { target c } .-1 }
   select = c ? gs8 : gs8;
 
   diff = sb - sb; // { dg-error {arithmetic on pointer to SVE type 'svbool_t'} }
-  diff = sb - fb; // { dg-error {arithmetic on pointer to SVE type 'svbool_t'} }
+  diff = sb - fb; // { dg-error {invalid operands} "" { target c++ }  }
+		  // { dg-error {arithmetic on pointer to SVE type 'svbool_t'} "c" { target c } .-1 }
 
-  diff = fb - sb; // { dg-error {arithmetic on pointer to SVE type 'svbool_t'} }
+  diff = fb - sb; // { dg-error {invalid operands} "" { target c++ }  }
+		  // { dg-error {arithmetic on pointer to SVE type 'svbool_t'} "c" { target c } .-1 }
   diff = fb - fb;
 
-  sb = fb;
-  fb = sb;
+  sb = fb; // { dg-error {invalid conversion} "" { target c++ } }
+	   // { dg-warning {incompatible pointer type} "c" { target c xfail c } .-1 }
+  fb = sb; // { dg-error {invalid conversion} "" { target c++ } }
+	   // { dg-warning {incompatible pointer type} "c" { target c xfail c } .-1 }
 
   select = c ? sb : sb;
-  select = c ? sb : fb; // { dg-error {type mismatch|different types} "" { xfail *-*-* } }
+  select = c ? sb : fb; // { dg-error {distinct pointer types} "" { target c++ } }
+			// { dg-warning {pointer type mismatch} "c" { target c xfail c } .-1 }
 
-  select = c ? fb : sb; // { dg-error {type mismatch|different types} "" { xfail *-*-* } }
+  select = c ? fb : sb; // { dg-error {distinct pointer types} "" { target c++ } }
+			// { dg-warning {pointer type mismatch} "c" { target c xfail c } .-1 }
   select = c ? fb : fb;
 }

From cd0a059bd384da58d43674496a79ecb7de610800 Mon Sep 17 00:00:00 2001
From: Richard Sandiford <richard.sandiford@arm.com>
Date: Thu, 29 Apr 2021 09:27:52 +0100
Subject: [PATCH 029/164] aarch64: Fix address mode for vec_concat pattern
 [PR100305]
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

The load_pair_lanes<mode> patterns match a vec_concat of two
adjacent 64-bit memory locations as a single 128-bit load.
The Utq constraint made sure that the address was suitable
for a 128-bit vector, but this meant that it allowed some
addresses that aren't valid for the 64-bit element mode.

Two obvious fixes were:

(1) Continue to accept addresses that aren't valid for the element
    modes.  This would mean changing the mode of operands[1] before
    printing it.  It would also mean using a custom predicate instead
    of the current memory_operand.

(2) Restrict addresses to the intersection of those that are valid
    element and vector addresses.

The problem with (1) is that, as well as being more complicated,
it doesn't deal with the fact that we still have a memory_operand
for the second element.  If we encourage the first operand to be
outside the range of a normal element memory_operand, we'll have
to reload the second operand to make it valid.  This reload will
often be dead code, but will be kept around because the RTL
pattern makes it look as though the second element address
is still needed.

This patch therefore does (2) instead.

As mentioned in the PR notes, I think we have a general problem
with the way that the aarch64 port deals with paired addresses.
There's nothing to guarantee that the two addresses will be
reloaded in a way that keeps them “obviously” adjacent, so the
rtx_equal_p conditions could fail if something rechecked them
later.

For this particular pattern, I think it would be better to teach
simplify-rtx.c to fold the vec_concat to a normal vector memory
reference, to remove any suggestion that targets should try to
match the unsimplified form.  That obviously wouldn't be suitable
for backports though.

gcc/
	PR target/100305
	* config/aarch64/constraints.md (Utq): Require the address to
	be valid for both the element mode and for V2DImode.

gcc/testsuite/
	PR target/100305
	* gcc.c-torture/compile/pr100305.c: New test.

(cherry picked from commit 668df9e769e7d89bcefa07f72b68dcae9a8f3970)
---
 gcc/config/aarch64/constraints.md              |  2 ++
 gcc/testsuite/gcc.c-torture/compile/pr100305.c | 13 +++++++++++++
 2 files changed, 15 insertions(+)
 create mode 100644 gcc/testsuite/gcc.c-torture/compile/pr100305.c

diff --git a/gcc/config/aarch64/constraints.md b/gcc/config/aarch64/constraints.md
index fd3e925e9a35a..3b49b452119c4 100644
--- a/gcc/config/aarch64/constraints.md
+++ b/gcc/config/aarch64/constraints.md
@@ -327,6 +327,8 @@
   "@internal
    An address valid for loading or storing a 128-bit AdvSIMD register"
   (and (match_code "mem")
+       (match_test "aarch64_legitimate_address_p (GET_MODE (op),
+						  XEXP (op, 0), 1)")
        (match_test "aarch64_legitimate_address_p (V2DImode,
 						  XEXP (op, 0), 1)")))
 
diff --git a/gcc/testsuite/gcc.c-torture/compile/pr100305.c b/gcc/testsuite/gcc.c-torture/compile/pr100305.c
new file mode 100644
index 0000000000000..e098b90b58923
--- /dev/null
+++ b/gcc/testsuite/gcc.c-torture/compile/pr100305.c
@@ -0,0 +1,13 @@
+/* { dg-options "-O" } */
+
+typedef double v2df __attribute__((vector_size(16)));
+
+#define N 4096
+void consume (void *);
+v2df
+foo (void)
+{
+  double x[N+2];
+  consume (x);
+  return (v2df) { x[N], x[N + 1] };
+}

From f94c6caac7f03815c26c03a532f834c37517519c Mon Sep 17 00:00:00 2001
From: Tom de Vries <tdevries@suse.de>
Date: Wed, 28 Apr 2021 16:00:01 +0200
Subject: [PATCH 030/164] [omp, simt] Fix expand_GOMP_SIMT_*

When running the test-case included in this patch using an
nvptx accelerator, it fails in execution.

The problem is that the expansion of GOMP_SIMT_XCHG_BFLY is optimized away
during pass_jump as "trivially dead insns".

This is caused by this code in expand_GOMP_SIMT_XCHG_BFLY:
...
  class expand_operand ops[3];
  create_output_operand (&ops[0], target, mode);
  ...
  expand_insn (targetm.code_for_omp_simt_xchg_bfly, 3, ops);
...
which doesn't guarantee that target is assigned to by the expanded insn.

F.i., if target is:
...
(gdb) call debug_rtx ( target )
(subreg/s/u:QI (reg:SI 40 [ _61 ]) 0)
...
then after expand_insn, we have:
...
(gdb) call debug_rtx ( ops[0].value )
(reg:QI 57)
...

See commit 3af3bec2e4d "internal-fn: Avoid dropping the lhs of some
calls [PR94941]" for a similar problem.

Fix this in the same way, by adding:
...
  if (!rtx_equal_p (target, ops[0].value))
    emit_move_insn (target, ops[0].value);
...
where applicable in the expand_GOMP_SIMT_* functions.

Tested libgomp on x86_64 with nvptx accelerator.

gcc/ChangeLog:

2021-04-28  Tom de Vries  <tdevries@suse.de>

	PR target/100232
	* internal-fn.c (expand_GOMP_SIMT_ENTER_ALLOC)
	(expand_GOMP_SIMT_LAST_LANE, expand_GOMP_SIMT_ORDERED_PRED)
	(expand_GOMP_SIMT_VOTE_ANY, expand_GOMP_SIMT_XCHG_BFLY)
	(expand_GOMP_SIMT_XCHG_IDX): Ensure target is assigned to.

(cherry picked from commit 4d7c874e2c64ebf7631049ace642d246843febae)
---
 gcc/internal-fn.c                       | 12 ++++++++++++
 libgomp/testsuite/libgomp.c/target-43.c | 24 ++++++++++++++++++++++++
 2 files changed, 36 insertions(+)
 create mode 100644 libgomp/testsuite/libgomp.c/target-43.c

diff --git a/gcc/internal-fn.c b/gcc/internal-fn.c
index dd7173126fbb9..d209a52f8235c 100644
--- a/gcc/internal-fn.c
+++ b/gcc/internal-fn.c
@@ -243,6 +243,8 @@ expand_GOMP_SIMT_ENTER_ALLOC (internal_fn, gcall *stmt)
   create_input_operand (&ops[2], align, Pmode);
   gcc_assert (targetm.have_omp_simt_enter ());
   expand_insn (targetm.code_for_omp_simt_enter, 3, ops);
+  if (!rtx_equal_p (target, ops[0].value))
+    emit_move_insn (target, ops[0].value);
 }
 
 /* Deallocate per-lane storage and leave non-uniform execution region.  */
@@ -300,6 +302,8 @@ expand_GOMP_SIMT_LAST_LANE (internal_fn, gcall *stmt)
   create_input_operand (&ops[1], cond, mode);
   gcc_assert (targetm.have_omp_simt_last_lane ());
   expand_insn (targetm.code_for_omp_simt_last_lane, 2, ops);
+  if (!rtx_equal_p (target, ops[0].value))
+    emit_move_insn (target, ops[0].value);
 }
 
 /* Non-transparent predicate used in SIMT lowering of OpenMP "ordered".  */
@@ -319,6 +323,8 @@ expand_GOMP_SIMT_ORDERED_PRED (internal_fn, gcall *stmt)
   create_input_operand (&ops[1], ctr, mode);
   gcc_assert (targetm.have_omp_simt_ordered ());
   expand_insn (targetm.code_for_omp_simt_ordered, 2, ops);
+  if (!rtx_equal_p (target, ops[0].value))
+    emit_move_insn (target, ops[0].value);
 }
 
 /* "Or" boolean reduction across SIMT lanes: return non-zero in all lanes if
@@ -339,6 +345,8 @@ expand_GOMP_SIMT_VOTE_ANY (internal_fn, gcall *stmt)
   create_input_operand (&ops[1], cond, mode);
   gcc_assert (targetm.have_omp_simt_vote_any ());
   expand_insn (targetm.code_for_omp_simt_vote_any, 2, ops);
+  if (!rtx_equal_p (target, ops[0].value))
+    emit_move_insn (target, ops[0].value);
 }
 
 /* Exchange between SIMT lanes with a "butterfly" pattern: source lane index
@@ -361,6 +369,8 @@ expand_GOMP_SIMT_XCHG_BFLY (internal_fn, gcall *stmt)
   create_input_operand (&ops[2], idx, SImode);
   gcc_assert (targetm.have_omp_simt_xchg_bfly ());
   expand_insn (targetm.code_for_omp_simt_xchg_bfly, 3, ops);
+  if (!rtx_equal_p (target, ops[0].value))
+    emit_move_insn (target, ops[0].value);
 }
 
 /* Exchange between SIMT lanes according to given source lane index.  */
@@ -382,6 +392,8 @@ expand_GOMP_SIMT_XCHG_IDX (internal_fn, gcall *stmt)
   create_input_operand (&ops[2], idx, SImode);
   gcc_assert (targetm.have_omp_simt_xchg_idx ());
   expand_insn (targetm.code_for_omp_simt_xchg_idx, 3, ops);
+  if (!rtx_equal_p (target, ops[0].value))
+    emit_move_insn (target, ops[0].value);
 }
 
 /* This should get expanded in adjust_simduid_builtins.  */
diff --git a/libgomp/testsuite/libgomp.c/target-43.c b/libgomp/testsuite/libgomp.c/target-43.c
new file mode 100644
index 0000000000000..46b1cfc5b200e
--- /dev/null
+++ b/libgomp/testsuite/libgomp.c/target-43.c
@@ -0,0 +1,24 @@
+/* { dg-do run } */
+#include <stdlib.h>
+
+#define N 32
+#define TYPE char
+
+int
+main (void)
+{
+  TYPE result = 1;
+  TYPE a[N];
+  for (int x = 0; x < N; ++x)
+    a[x] = 1;
+
+#pragma omp target map(tofrom: result) map(to:a)
+#pragma omp for simd reduction(&&:result)
+  for (int x = 0; x < N; ++x)
+    result = result && a[x];
+
+  if (result != 1)
+    abort ();
+
+  return 0;
+}

From 50c826db7a3ee672be2a0b41a937651e1834a837 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Thu, 29 Apr 2021 11:11:37 +0200
Subject: [PATCH 031/164] c++: Fix up detach clause vs. data-sharing clause
 checking [PR100319]

The standard says that "The event-handle will be considered as if it
was specified on a firstprivate clause." which means that it can't
be explicitly specified in some other data-sharing clause.
The checking is implemented correctly for C, but for C++ when detach_seen
is true (i.e. the construct had detach clause) we were comparing
OMP_CLAUSE_DECL (c) with t, which was previously initialized to
OMP_CLAUSE_DECL (c), which means it complained about any explicit
data-sharing clause on the same construct with a detach clause.

Fixed by remembering the detach clause in detach_seen (instead of a boolean
flag) and comparing against its OMP_CLAUSE_DECL.

2021-04-29  Jakub Jelinek  <jakub@redhat.com>

	PR c++/100319
	* semantics.c (finish_omp_clauses): Fix up check that variable
	mentioned in detach clause doesn't appear in data-sharing clauses.

	* c-c++-common/gomp/task-detach-3.c: New test.

(cherry picked from commit 1b462deabf70e0f4bebb1f85118827d9c2eeffb5)
---
 gcc/cp/semantics.c                            |  6 +++---
 .../c-c++-common/gomp/task-detach-3.c         | 19 +++++++++++++++++++
 2 files changed, 22 insertions(+), 3 deletions(-)
 create mode 100644 gcc/testsuite/c-c++-common/gomp/task-detach-3.c

diff --git a/gcc/cp/semantics.c b/gcc/cp/semantics.c
index 4520181d4e594..3a6468fd5f3b5 100644
--- a/gcc/cp/semantics.c
+++ b/gcc/cp/semantics.c
@@ -6527,7 +6527,7 @@ finish_omp_clauses (tree clauses, enum c_omp_region_type ort)
      has been seen, -2 if mixed inscan/normal reduction diagnosed.  */
   int reduction_seen = 0;
   bool allocate_seen = false;
-  bool detach_seen = false;
+  tree detach_seen = NULL_TREE;
   bool mergeable_seen = false;
 
   bitmap_obstack_initialize (NULL);
@@ -7578,7 +7578,7 @@ finish_omp_clauses (tree clauses, enum c_omp_region_type ort)
 			    type);
 		  remove = true;
 		}
-	      detach_seen = true;
+	      detach_seen = c;
 	      cxx_mark_addressable (t);
 	    }
 	  break;
@@ -8548,7 +8548,7 @@ finish_omp_clauses (tree clauses, enum c_omp_region_type ort)
 	      || OMP_CLAUSE_CODE (c) == OMP_CLAUSE_PRIVATE
 	      || OMP_CLAUSE_CODE (c) == OMP_CLAUSE_FIRSTPRIVATE
 	      || OMP_CLAUSE_CODE (c) == OMP_CLAUSE_LASTPRIVATE)
-	  && OMP_CLAUSE_DECL (c) == t)
+	  && OMP_CLAUSE_DECL (c) == OMP_CLAUSE_DECL (detach_seen))
 	{
 	  error_at (OMP_CLAUSE_LOCATION (c),
 		    "the event handle of a %<detach%> clause "
diff --git a/gcc/testsuite/c-c++-common/gomp/task-detach-3.c b/gcc/testsuite/c-c++-common/gomp/task-detach-3.c
new file mode 100644
index 0000000000000..97e622de2cd0e
--- /dev/null
+++ b/gcc/testsuite/c-c++-common/gomp/task-detach-3.c
@@ -0,0 +1,19 @@
+/* PR c++/100319 */
+/* { dg-do compile } */
+/* { dg-options "-fopenmp" } */
+
+typedef enum omp_event_handle_t
+{
+  __omp_event_handle_t_max__ = __UINTPTR_MAX__
+} omp_event_handle_t;
+
+extern void omp_fulfill_event (omp_event_handle_t);
+
+void f (omp_event_handle_t x, omp_event_handle_t y, int z)
+{
+  #pragma omp task detach (x) firstprivate (y, z)	/* { dg-bogus "the event handle of a 'detach' clause should not be in a data-sharing clause" } */
+    ;
+
+  #pragma omp task detach (x) shared (y)		/* { dg-bogus "the event handle of a 'detach' clause should not be in a data-sharing clause" } */
+    ;
+}

From 5ac1313f32c5cd875ad047f6575dd4608e1949cf Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Thu, 29 Apr 2021 11:34:50 +0200
Subject: [PATCH 032/164] aarch64: Fix ICE in aarch64_add_offset_1_temporaries
 [PR100302]

In PR94121 I've changed aarch64_add_offset_1 to use absu_hwi instead of
abs_hwi because offset can be HOST_WIDE_INT_MIN.  As can be seen with
the testcase below, aarch64_add_offset_1_temporaries suffers from the same
problem and should be in sync with aarch64_add_offset_1, i.e. for
HOST_WIDE_INT_MIN it needs a temporary.

2021-04-29  Jakub Jelinek  <jakub@redhat.com>

	PR target/100302
	* config/aarch64/aarch64.c (aarch64_add_offset_1_temporaries): Use
	absu_hwi instead of abs_hwi.

	* gcc.target/aarch64/sve/pr100302.c: New test.

(cherry picked from commit 1bb3e2c0ce6ed363c72caf814a6ba6d7b17c3e0a)
---
 gcc/config/aarch64/aarch64.c                    |  2 +-
 gcc/testsuite/gcc.target/aarch64/sve/pr100302.c | 12 ++++++++++++
 2 files changed, 13 insertions(+), 1 deletion(-)
 create mode 100644 gcc/testsuite/gcc.target/aarch64/sve/pr100302.c

diff --git a/gcc/config/aarch64/aarch64.c b/gcc/config/aarch64/aarch64.c
index a863af17b5bac..c2f4b27f6e4bc 100644
--- a/gcc/config/aarch64/aarch64.c
+++ b/gcc/config/aarch64/aarch64.c
@@ -4736,7 +4736,7 @@ aarch64_mov128_immediate (rtx imm)
 static unsigned int
 aarch64_add_offset_1_temporaries (HOST_WIDE_INT offset)
 {
-  return abs_hwi (offset) < 0x1000000 ? 0 : 1;
+  return absu_hwi (offset) < 0x1000000 ? 0 : 1;
 }
 
 /* A subroutine of aarch64_add_offset.  Set DEST to SRC + OFFSET for
diff --git a/gcc/testsuite/gcc.target/aarch64/sve/pr100302.c b/gcc/testsuite/gcc.target/aarch64/sve/pr100302.c
new file mode 100644
index 0000000000000..de6e8f206461d
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/sve/pr100302.c
@@ -0,0 +1,12 @@
+/* PR target/100302 */
+/* { dg-do compile } */
+/* { dg-options "-march=armv8.2-a+sve -O1 -ftree-loop-vectorize -fno-tree-scev-cprop --param vect-partial-vector-usage=0 -fvect-cost-model=unlimited" } */
+
+long int x;
+
+void
+foo (void)
+{
+  for (x = 0; x >= 0; ++x)
+    ;
+}

From a515ce926b9d779922debc33ecad424c9ac22c65 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Thu, 29 Apr 2021 11:42:08 +0200
Subject: [PATCH 033/164] testsuite: Remove dg-options from pr100305.c
 [PR100305]

The test FAILs on i?86-linux (due to -Wpsabi warnings).  But, on closer
inspection it seems there is another problem, the dg-options in the testcase
means that the test is compiled with -O0 -O, -O1 -O, -O2 -O, -O3 -O, -Os -O
etc. options, so effectively is tested multiple times with the same options.

Fixed by dropping the dg-options line, then we have -w by default and iterate
over all the optimization levels (including the -O).

2021-04-29  Jakub Jelinek  <jakub@redhat.com>

	PR target/100305
	* gcc.c-torture/compile/pr100305.c: Remove dg-options.  Add PR line.

(cherry picked from commit 62a44a9797edce11b1f7051ea0016ee975d41233)
---
 gcc/testsuite/gcc.c-torture/compile/pr100305.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/testsuite/gcc.c-torture/compile/pr100305.c b/gcc/testsuite/gcc.c-torture/compile/pr100305.c
index e098b90b58923..43d78bf654280 100644
--- a/gcc/testsuite/gcc.c-torture/compile/pr100305.c
+++ b/gcc/testsuite/gcc.c-torture/compile/pr100305.c
@@ -1,4 +1,4 @@
-/* { dg-options "-O" } */
+/* PR target/100305 */
 
 typedef double v2df __attribute__((vector_size(16)));
 

From bda407c9a0da4aacdc62306c85712b93afa1bbc3 Mon Sep 17 00:00:00 2001
From: Richard Earnshaw <rearnsha@arm.com>
Date: Wed, 28 Apr 2021 17:56:38 +0100
Subject: [PATCH 034/164] arm: fix UB due to missing mode check [PR100311]

Some places in the compiler iterate over all the fixed registers to
check if that register can be used in a particular mode.  The idiom is
to iterate over the register and then for that register, if it
supports the current mode to check all that register and any
additional registers needed (HARD_REGNO_NREGS).  If these two checks
are not fully aligned then it is possible to generate a buffer overrun
when testing data objects that are sized by the number of hard regs in
the machine.

The VPR register is a case where these checks were not consistent and
because this is the last HARD register the result was that we ended up
overflowing the fixed_regs array.

gcc:
	PR target/100311
	* config/arm/arm.c (arm_hard_regno_mode_ok): Only allow VPR to be
	used in HImode.
(cherry picked from commit 59f5d16f2c5db4d9592c8ce6453afe81334bb012)
---
 gcc/config/arm/arm.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/config/arm/arm.c b/gcc/config/arm/arm.c
index 352b2cd6e8392..a201088a6fd49 100644
--- a/gcc/config/arm/arm.c
+++ b/gcc/config/arm/arm.c
@@ -25269,7 +25269,7 @@ arm_hard_regno_mode_ok (unsigned int regno, machine_mode mode)
     return false;
 
   if (IS_VPR_REGNUM (regno))
-    return true;
+    return mode == HImode;
 
   if (TARGET_THUMB1)
     /* For the Thumb we only allow values bigger than SImode in

From b222ba525fc4f3d71b8d615b58aefcdcc2198f0f Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Wed, 28 Apr 2021 15:56:04 +0100
Subject: [PATCH 035/164] libstdc++: Define __cpp_lib_constexpr_string macro

As noted in r11-1339-gb6ab9ecd550227684643b41e9e33a4d3466724d8 we define
a non-standard __cpp_lib_constexpr_char_traits feature test macro to
indicate support for P0426R1 and P1032R1. At some point last year the
__cpp_lib_constexpr_string macro was retconned to indicate support for
those papers. This adds the new macro (which we didn't previously
define, because it referred to P0980R1 "Making std::string constexpr"
which we don't support).

libstdc++-v3/ChangeLog:

	* include/bits/basic_string.h (__cpp_lib_constexpr_string): Define.
	* include/std/version (__cpp_lib_constexpr_string): Define.
	* testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc:
	Check for __cpp_lib_constexpr_string.
	* testsuite/21_strings/char_traits/requirements/constexpr_functions_c++20.cc:
	Likewise.
	* testsuite/21_strings/char_traits/requirements/version.cc: New test.

(cherry picked from commit 3da80ed7efd582575e7850a403ce693ec882d087)
---
 libstdc++-v3/include/bits/basic_string.h         |  9 ++++++++-
 libstdc++-v3/include/std/version                 |  2 ++
 .../requirements/constexpr_functions_c++17.cc    | 11 ++++++++---
 .../requirements/constexpr_functions_c++20.cc    |  7 +++++++
 .../char_traits/requirements/version.cc          | 16 ++++++++++++++++
 5 files changed, 41 insertions(+), 4 deletions(-)
 create mode 100644 libstdc++-v3/testsuite/21_strings/char_traits/requirements/version.cc

diff --git a/libstdc++-v3/include/bits/basic_string.h b/libstdc++-v3/include/bits/basic_string.h
index 3c5309d16e67c..41d781c698e7f 100644
--- a/libstdc++-v3/include/bits/basic_string.h
+++ b/libstdc++-v3/include/bits/basic_string.h
@@ -48,11 +48,18 @@
 # include <string_view>
 #endif
 
-
 namespace std _GLIBCXX_VISIBILITY(default)
 {
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
+#if __cplusplus == 201703L
+// Support P0426R1 changes to char_traits in C++17.
+# define __cpp_lib_constexpr_string 201611L
+#else
+// Also support P1032R1 in C++20 (but not P0980R1 yet).
+# define __cpp_lib_constexpr_string 201811L
+#endif
+
 #if _GLIBCXX_USE_CXX11_ABI
 _GLIBCXX_BEGIN_NAMESPACE_CXX11
   /**
diff --git a/libstdc++-v3/include/std/version b/libstdc++-v3/include/std/version
index d9f6a3c3dfd38..09e67a40d0c2f 100644
--- a/libstdc++-v3/include/std/version
+++ b/libstdc++-v3/include/std/version
@@ -131,6 +131,7 @@
 #define __cpp_lib_clamp 201603
 #if __cplusplus == 201703L // N.B. updated value in C++20
 # define __cpp_lib_constexpr_char_traits 201611L
+# define __cpp_lib_constexpr_string 201611L
 #endif
 #define __cpp_lib_enable_shared_from_this 201603
 #define __cpp_lib_execution 201902L // FIXME: should be 201603L
@@ -219,6 +220,7 @@
 #define __cpp_lib_constexpr_iterator 201811L
 #define __cpp_lib_constexpr_memory 201811L
 #define __cpp_lib_constexpr_numeric 201911L
+#define __cpp_lib_constexpr_string 201811L
 #define __cpp_lib_constexpr_string_view 201811L
 #define __cpp_lib_constexpr_tuple 201811L
 #define __cpp_lib_constexpr_utility 201811L
diff --git a/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc
index 803fb68df0993..32e31e13abbaf 100644
--- a/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc
+++ b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc
@@ -73,12 +73,17 @@ template<typename CT>
     return true;
   }
 
+#ifndef __cpp_lib_constexpr_string
+# error Feature-test macro for constexpr char_traits is missing
+#elif __cpp_lib_constexpr_string < (__cplusplus == 201703 ? 201611 : 201811)
+# error Feature-test macro for constexpr char_traits has the wrong value
+#endif
+
+// We also provide this non-standard macro for P0426R1 (and P1032R1 in C++20).
 #ifndef __cpp_lib_constexpr_char_traits
 # error Feature-test macro for constexpr char_traits is missing
-#elif __cpp_lib_constexpr_char_traits < 201611
+#elif __cpp_lib_constexpr_char_traits != (__cplusplus == 201703 ? 201611 : 201811)
 # error Feature-test macro for constexpr char_traits has the wrong value
-#elif __cpp_lib_constexpr_char_traits > 201611 && __cplusplus == 201703
-# error Feature-test macro for constexpr char_traits has wrong value for C++17
 #endif
 
 static_assert( test_assign<std::char_traits<char>>() );
diff --git a/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++20.cc b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++20.cc
index 0c1329f903d56..0d1595fe030b5 100644
--- a/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++20.cc
+++ b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++20.cc
@@ -30,6 +30,13 @@ template<typename CT>
     return s1[0]==char_type{1} && s1[1]==char_type{1} && s1[2]==char_type{2};
   }
 
+#ifndef __cpp_lib_constexpr_string
+# error Feature-test macro for constexpr char_traits is missing
+#elif __cpp_lib_constexpr_string < 201811
+# error Feature-test macro for constexpr char_traits has the wrong value
+#endif
+
+// We also provide this non-standard macro for P0426R1 and P1032R1.
 #ifndef __cpp_lib_constexpr_char_traits
 # error Feature-test macro for constexpr char_traits is missing
 #elif __cpp_lib_constexpr_char_traits != 201811
diff --git a/libstdc++-v3/testsuite/21_strings/char_traits/requirements/version.cc b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/version.cc
new file mode 100644
index 0000000000000..6f571f48010f1
--- /dev/null
+++ b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/version.cc
@@ -0,0 +1,16 @@
+// { dg-do compile { target c++17 } }
+
+#include <version>
+
+#ifndef __cpp_lib_constexpr_string
+# error Feature-test macro for constexpr char_traits is missing in <version>
+#elif __cpp_lib_constexpr_string < (__cplusplus == 201703 ? 201611 : 201811)
+# error Feature-test macro for constexpr char_traits has the wrong value in <version>
+#endif
+
+// We also provide this non-standard macro for P0426R1 and P1032R1.
+#ifndef __cpp_lib_constexpr_char_traits
+# error Feature-test macro for constexpr char_traits is missing in <version>
+#elif __cpp_lib_constexpr_char_traits != (__cplusplus == 201703 ? 201611 : 201811)
+# error Feature-test macro for constexpr char_traits has the wrong value in <version>
+#endif

From 4e54a34eed4f941cf09f27245bb3a5bfdb406a16 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 26 Apr 2021 11:37:38 +0100
Subject: [PATCH 036/164] libstdc++: Add missing 'inline' specifiers to net::ip
 functions [PR 100259]

libstdc++-v3/ChangeLog:

	PR libstdc++/100259
	* include/experimental/internet (net::ip::make_error_code)
	(net::ip::make_error_condition, net::ip::make_network_v4)
	(net::ip::operator==(const udp&, const udp&)): Add 'inline'.

(cherry picked from commit 3f4aa4579a6c03e0a0b0a6aec68aa5a301264d45)
---
 libstdc++-v3/include/experimental/internet | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/libstdc++-v3/include/experimental/internet b/libstdc++-v3/include/experimental/internet
index c79e6d4b2b323..cd19de59e709a 100644
--- a/libstdc++-v3/include/experimental/internet
+++ b/libstdc++-v3/include/experimental/internet
@@ -101,10 +101,10 @@ namespace ip
     return __c;
   }
 
-  error_code make_error_code(resolver_errc __e) noexcept
+  inline error_code make_error_code(resolver_errc __e) noexcept
   { return error_code(static_cast<int>(__e), resolver_category()); }
 
-  error_condition make_error_condition(resolver_errc __e) noexcept
+  inline error_condition make_error_condition(resolver_errc __e) noexcept
   { return error_condition(static_cast<int>(__e), resolver_category()); }
 
   /// @}
@@ -1334,7 +1334,7 @@ namespace ip
   make_network_v4(const address_v4& __a, int __prefix_len)
   { return network_v4{__a, __prefix_len}; }
 
-  network_v4
+  inline network_v4
   make_network_v4(const address_v4& __a, const address_v4& __mask)
   { return network_v4{ __a, __mask }; }
 
@@ -2157,7 +2157,7 @@ namespace ip
    * @{
    */
 
-  bool
+  inline bool
   operator==(const udp& __a, const udp& __b)
   { return __a.family() == __b.family(); }
 

From 8a87946e20eac08659d52062dd99cec94a7adb2f Mon Sep 17 00:00:00 2001
From: Joseph Myers <joseph@codesourcery.com>
Date: Thu, 29 Apr 2021 16:38:30 +0000
Subject: [PATCH 037/164] Update gcc fr.po.

	* fr.po: Update.
---
 gcc/po/fr.po | 103 ++++++++++++++++++++-------------------------------
 1 file changed, 41 insertions(+), 62 deletions(-)

diff --git a/gcc/po/fr.po b/gcc/po/fr.po
index c13512fb62f1e..21710702fb3b3 100644
--- a/gcc/po/fr.po
+++ b/gcc/po/fr.po
@@ -97,10 +97,10 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 11.1-b20210321\n"
+"Project-Id-Version: gcc 11.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
 "POT-Creation-Date: 2021-04-20 18:19+0000\n"
-"PO-Revision-Date: 2021-03-25 13:27+0100\n"
+"PO-Revision-Date: 2021-04-29 11:08+0200\n"
 "Last-Translator: Frédéric Marchal <fmarchal@perso.be>\n"
 "Language-Team: French <traduc@traduc.org>\n"
 "Language: fr\n"
@@ -6403,8 +6403,7 @@ msgid "Warn for deallocation calls with arguments returned from mismatched alloc
 msgstr "Avertir à propos d'appels de désallocation avec des arguments retournés par des fonctions d'allocation non correspondantes."
 
 #: c-family/c.opt:803
-#, fuzzy, no-c-format
-#| msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+#, no-c-format
 msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr "Avertir à propos de désaccords entre les appels à l'opérateur « new » ou « delete » et l'appel correspondant à la fonction d'allocation ou de désallocation."
 
@@ -8087,10 +8086,9 @@ msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified
 msgstr "-fversion=<niveau|ident>\tCompiler en code version >= <niveau> ou identifié par <ident>."
 
 #: d/lang.opt:326
-#, fuzzy, no-c-format
-#| msgid "Emit implicit instantiations of templates."
+#, no-c-format
 msgid "Emit template instantiations as weak symbols."
-msgstr "Produire des instanciations implicites pour les patrons."
+msgstr "Produire des instanciations de patron en tant que symboles faibles."
 
 #: d/lang.opt:346
 #, no-c-format
@@ -19158,7 +19156,7 @@ msgstr "--param=evrp-mode=[legacy|ranger|legacy-first|ranger-first|ranger-trace|
 #: params.opt:162
 #, no-c-format
 msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
-msgstr ""
+msgstr "La profondeur maximale de l'évaluation d'expressions logiques qui sera examinée en évaluant les portées des arrêtes sortantes."
 
 #: params.opt:167
 #, no-c-format
@@ -19922,10 +19920,9 @@ msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be consi
 msgstr "Si -ftree-vectorize est utilisé, la limite minimale de boucle d'une boucle prise en compte pour la vectorisation."
 
 #: params.opt:787
-#, fuzzy, no-c-format
-#| msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+#, no-c-format
 msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr "-fopenacc-kernels=[decompose|parloops]\tSpécifier le mode de gestion des constructions « kernels » OpenACC."
+msgstr "--param=openacc-kernels=[decompose|parloops]\tSpécifier le mode de gestion des constructions « kernels » OpenACC."
 
 #: params.opt:800
 #, no-c-format
@@ -33967,10 +33964,9 @@ msgid "embedded NUL in CFString literal"
 msgstr "NUL inclus dans une CFString littérale"
 
 #: config/host-darwin.c:65
-#, fuzzy, gcc-internal-format
-#| msgid "could not unmap %<pch_address_space%> %m"
+#, gcc-internal-format
 msgid "could not unmap %<pch_address_space%>: %m"
-msgstr "ne peut délier la mémoire %<pch_address_space%> %m"
+msgstr "ne peut délier la mémoire %<pch_address_space%> : %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
 #, gcc-internal-format
@@ -35083,8 +35079,7 @@ msgid "target CPU does not support unaligned accesses"
 msgstr "le processeur cible ne supporte pas les accès non alignés"
 
 #: config/arm/arm.c:3244
-#, fuzzy, gcc-internal-format
-#| msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
+#, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
 msgstr "l'option %<-mcpu=%s%> est en conflit avec l'option %<-march=%s%>"
 
@@ -35189,10 +35184,9 @@ msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr "Les extensions de sécurité ARMv8-M sont incompatibles avec le FPU sélectionné"
 
 #: config/arm/arm.c:3864
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+#, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
-msgstr "%<-mfloat-abi=hard%>: le processeur sélectionné n'a pas de FPU"
+msgstr "%<-mfloat-abi=hard%>: l'architecture sélectionnée n'a pas de FPU"
 
 #: config/arm/arm.c:3872
 #, gcc-internal-format
@@ -39021,10 +39015,9 @@ msgid "the layout of aggregates containing vectors with %d-byte alignment has ch
 msgstr "l'agencement des agrégats contenant des vecteurs alignés sur %d octets a changé avec GCC 5"
 
 #: config/rs6000/rs6000.c:10675
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is an opaque type, and you can't set it to other values."
+#, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
-msgstr "%qs est un type opaque et vous ne pouvez pas le remplacer avec d'autres valeurs."
+msgstr "%qs est un type opaque et vous ne pouvez pas le remplacer avec d'autres valeurs"
 
 #: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
@@ -39052,8 +39045,7 @@ msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<complex%> dans les types AltiVec est invalide"
 
 #: config/rs6000/rs6000.c:20172
-#, fuzzy, gcc-internal-format
-#| msgid "use of decimal floating point types in AltiVec types is invalid"
+#, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "l'utilisation de types décimaux en virgule flottante dans les types AltiVec est invalide"
 
@@ -39362,10 +39354,9 @@ msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite pour le type cible"
 
 #: config/s390/s390.c:762
-#, fuzzy, gcc-internal-format
-#| msgid "constant argument %d for builtin %qF is out of range ("
+#, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
-msgstr "l'argument constant %d de la fonction interne %qF est hors limite ("
+msgstr "l'argument constant %d de la fonction interne %qF est invalide (%s)"
 
 #: config/s390/s390.c:766
 #, gcc-internal-format
@@ -39903,10 +39894,9 @@ msgid "STABS debugging information for Ada is obsolete and not supported anymore
 msgstr "les informations de débogage STABS de Ada sont obsolètes et ne sont plus supportées"
 
 #: ada/gcc-interface/trans.c:332
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "STOP code at %C contains too many digits"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s contains too many lines"
-msgstr "Le code de STOP à %C contient trop de chiffres"
+msgstr "%s contient trop de lignes"
 
 #: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
@@ -45981,10 +45971,8 @@ msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "impossible de lier la référence d'une r-valeur de type %qH à une l-valeur de type %qI"
 
 #: cp/call.c:7906
-#, fuzzy
-#| msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
-msgstr "impossible de lier la référence d'une l-valeur non constante de type %qH à une r-valeur de type %qI"
+msgstr "impossible de lier la référence d'une l-valeur non constante de type %qH à une valeur de type %qI"
 
 #: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
@@ -48314,10 +48302,9 @@ msgid "%qD used without template arguments"
 msgstr "%qD utilisé sans arguments du patron"
 
 #: cp/decl.c:4061
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a function template"
+#, gcc-internal-format
 msgid "%qD is a function, not a type"
-msgstr "%qD n'est pas un patron de fonction"
+msgstr "%qD est une fonction, pas un type"
 
 #: cp/decl.c:4072
 #, gcc-internal-format
@@ -48911,7 +48898,7 @@ msgstr "alors que %qT se décompose en %E éléments"
 #: cp/decl.c:8640
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
-msgstr ""
+msgstr "%<std::tuple_element<%u, %T>::type%> est %<void%>"
 
 #: cp/decl.c:8646
 #, gcc-internal-format
@@ -49234,10 +49221,9 @@ msgid "a non-template variable cannot be %<concept%>"
 msgstr "une variable qui n'est pas un patron ne peut pas avoir %<concept%>"
 
 #: cp/decl.c:10371
-#, fuzzy, gcc-internal-format
-#| msgid "deduction guide %qD must be declared at namespace scope"
+#, gcc-internal-format
 msgid "concept must be defined at namespace scope"
-msgstr "le guide de déduction %qD doit être déclaré au niveau de l'espace de noms"
+msgstr "le concept doit être défini au niveau de l'espace de noms"
 
 #: cp/decl.c:10378
 #, gcc-internal-format
@@ -53058,10 +53044,9 @@ msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "des types ne peuvent pas être définis dans %<__builtin_offsetof%>"
 
 #: cp/parser.c:10809
-#, fuzzy, gcc-internal-format
-#| msgid "lambda-expression in template-argument"
+#, gcc-internal-format
 msgid "lambda-expression in template parameter type"
-msgstr "expression lambda dans l'argument du patron"
+msgstr "expression lambda dans le type du paramètre du patron"
 
 #: cp/parser.c:10819
 #, gcc-internal-format
@@ -57915,10 +57900,9 @@ msgid "converting from %qH to %qI"
 msgstr "conversion de %qH vers %qI"
 
 #: cp/typeck.c:7963
-#, fuzzy, gcc-internal-format
-#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
-msgstr "transtypage invalide d'une expression r-valeur du type %qT vers le type %qT"
+msgstr "transtypage invalide d'une expression pr-valeur du type %qT vers le type %qT"
 
 #: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
@@ -58585,10 +58569,9 @@ msgid "cannot be declared to be a function"
 msgstr "ne peut pas être déclaré comme étant une fonction"
 
 #: d/dmd/dsymbolsem.c:418
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "no definition of struct %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "no definition of struct `%s`"
-msgstr "pas de définition de struct %s"
+msgstr "pas de définition de la structure « %s »"
 
 #: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
@@ -58734,10 +58717,9 @@ msgid "char 0x%04x not allowed in mangled name"
 msgstr "le caractères 0x%04x n'est pas permis dans le nom décoré"
 
 #: d/dmd/dsymbolsem.c:1465
-#, fuzzy, gcc-internal-format
-#| msgid "no arguments"
+#, gcc-internal-format
 msgid "takes no argument"
-msgstr "pas d'argument"
+msgstr "ne prend pas d'argument"
 
 #: d/dmd/dsymbolsem.c:1526
 #, gcc-internal-format
@@ -58851,12 +58833,12 @@ msgstr "ne peut être, à la fois, final et abstract"
 #: d/dmd/dsymbolsem.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
-msgstr ""
+msgstr "les fonctions « oragma(%s) » doivent être « extern(C) %s %s([paramètres…], const(char)*, …) » pas « %s »"
 
 #: d/dmd/dsymbolsem.c:2835
 #, gcc-internal-format, gfc-internal-format
 msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
-msgstr ""
+msgstr "les fonctions « pargma(%s » doivent être « extern(C) %s %s([paramètres…], const(char)*n va_list) »"
 
 #: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
@@ -59132,16 +59114,14 @@ msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr "impossible d'appeler super() implicitement car il est annoté avec @disable"
 
 #: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "has no return statement, but is expected to return a value of type %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "has no `return` statement, but is expected to return a value of type `%s`"
-msgstr "n'a pas d'instruction de retour mais une valeur de retour de type %s est attendue"
+msgstr "n'a pas d'instruction de retour mais une valeur de retour de type « %s » est attendue"
 
 #: d/dmd/semantic3.c:864
-#, fuzzy, gcc-internal-format
-#| msgid "no return exp; or assert(0); at end of function"
+#, gcc-internal-format
 msgid "no `return exp;` or `assert(0);` at end of function"
-msgstr "pas d'expression de retour ou de assert(0) à la fin de la fonction"
+msgstr "pas de « return exp; » ni de « assert(0); » à la fin de la fonction"
 
 #: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
@@ -72666,8 +72646,7 @@ msgid "%<-fwpa%> and %<-fltrans%> are mutually exclusive"
 msgstr "%<-fwpa%> et %<-fltrans%> sont mutuellement exclusifs"
 
 #: lto/lto-lang.c:898
-#, fuzzy, gcc-internal-format
-#| msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+#, gcc-internal-format
 msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "%<-flinker-output=rel%> et %<-fltrans%> sont mutuellement exclusifs"
 

From 575cc089af3ad0bde8abb1f459bfe1f2ae7b1b29 Mon Sep 17 00:00:00 2001
From: Joseph Myers <joseph@codesourcery.com>
Date: Thu, 29 Apr 2021 20:09:41 +0000
Subject: [PATCH 038/164] Update gcc sv.po.

	* sv.po: Update.
---
 gcc/po/sv.po | 108 +++++++++++++++++++--------------------------------
 1 file changed, 41 insertions(+), 67 deletions(-)

diff --git a/gcc/po/sv.po b/gcc/po/sv.po
index c42e5182f1c7e..c9834c70ccdf6 100644
--- a/gcc/po/sv.po
+++ b/gcc/po/sv.po
@@ -25,10 +25,10 @@
 # thunk			snutt
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 11.1-b20210321\n"
+"Project-Id-Version: gcc 11.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
 "POT-Creation-Date: 2021-04-20 18:19+0000\n"
-"PO-Revision-Date: 2021-04-12 18:31+0200\n"
+"PO-Revision-Date: 2021-04-29 21:46+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
 "Language: sv\n"
@@ -6335,10 +6335,8 @@ msgstr "Varna när indenteringen av koden inte avspeglar blockstrukturen."
 msgid "Warn for deallocation calls with arguments returned from mismatched allocation functions."
 msgstr "Varna för avallokeringsanrop med argument returnerade från allokeringsfunktioner som inte passar ihop."
 
-# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99883
 #: c-family/c.opt:803
-#, fuzzy, no-c-format
-#| msgid "Warn for mismatches between calls to operator new or delete and the corrsponding call to the allocation or deallocation function."
+#, no-c-format
 msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
 msgstr "Varna för anrop som inte stämmer överens mellan anrop till operatorn new eller delete och det motsvarande anropet till allokerings- eller avallokeringsfunktionen."
 
@@ -8020,10 +8018,9 @@ msgid "-fversion=<level|ident>\tCompile in version code >= <level> or identified
 msgstr "-fversion=<nivå|ident>\tKompilera in versionskod ≥ <nivå> eller identifierad av <ident>."
 
 #: d/lang.opt:326
-#, fuzzy, no-c-format
-#| msgid "Emit implicit instantiations of templates."
+#, no-c-format
 msgid "Emit template instantiations as weak symbols."
-msgstr "Skapa implicita instansieringar av mallar."
+msgstr "Skapa mallinstansieringar som svaga symboler."
 
 #: d/lang.opt:346
 #, no-c-format
@@ -19081,7 +19078,7 @@ msgstr "--param=evrp-mode=[legacy|ranger|legacy-first|ranger-first|ranger-trace|
 #: params.opt:162
 #, no-c-format
 msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
-msgstr ""
+msgstr "Maximalt djup på beräkningsintervallare av logiska uttryck kommer att titta igenom vid beräkning av utgående bågintervall."
 
 #: params.opt:167
 #, no-c-format
@@ -19846,10 +19843,9 @@ msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be consi
 msgstr "Om -ftree-vectorize används, den minimala slinggränsen på en slinga för att den skall övervägas för vektorisering."
 
 #: params.opt:787
-#, fuzzy, no-c-format
-#| msgid "-fopenacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+#, no-c-format
 msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
-msgstr "-fopenacc-kernels=[decompose|parloops]\tAnge läge för hantering av OpenACC ”kernels”-kontruktioner."
+msgstr "--param=openacc-kernels=[decompose|parloops]\tAnge läge för hantering av OpenACC ”kernels”-kontruktioner."
 
 #: params.opt:800
 #, no-c-format
@@ -33863,10 +33859,9 @@ msgid "embedded NUL in CFString literal"
 msgstr "inbäddad NUL i CFString-litteral"
 
 #: config/host-darwin.c:65
-#, fuzzy, gcc-internal-format
-#| msgid "could not unmap %<pch_address_space%> %m"
+#, gcc-internal-format
 msgid "could not unmap %<pch_address_space%>: %m"
-msgstr "det gick inte att avmappa %<pch_address_space%> %m"
+msgstr "det gick inte att avmappa %<pch_address_space%>: %m"
 
 #: config/sol2-c.c:91 config/sol2-c.c:107
 #, gcc-internal-format
@@ -34979,8 +34974,7 @@ msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessorn stödjer inte ojusterade åtkomster"
 
 #: config/arm/arm.c:3244
-#, fuzzy, gcc-internal-format
-#| msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
+#, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
 msgstr "flaggan %<-mcpu=%s%> står i konflikt med flaggan %<-march=%s%>"
 
@@ -35085,10 +35079,9 @@ msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr "ARMv8-M Security Extensions är inkompatibelt med den valda FPU:n"
 
 #: config/arm/arm.c:3864
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
+#, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
-msgstr "%<-mfloat-abi=hard%>: den valda processorn saknar en FPU"
+msgstr "%<-mfloat-abi=hard%>: den valda arkitekturen saknar en FPU"
 
 #: config/arm/arm.c:3872
 #, gcc-internal-format
@@ -38921,10 +38914,9 @@ msgid "the layout of aggregates containing vectors with %d-byte alignment has ch
 msgstr "layouten av aggregat som innehåller vektorer med %d-bytejustering har ändrats i GCC 5"
 
 #: config/rs6000/rs6000.c:10675
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is an opaque type, and you can't set it to other values."
+#, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
-msgstr "%qs är en ogenomskinlig typ, och det går inte att sätta den till andra värden."
+msgstr "%qs är en ogenomskinlig typ, och det går inte att sätta den till andra värden"
 
 #: config/rs6000/rs6000.c:17794
 #, gcc-internal-format
@@ -38952,8 +38944,7 @@ msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "användning av %<complex%> i AltiVec-typer är ogiltigt"
 
 #: config/rs6000/rs6000.c:20172
-#, fuzzy, gcc-internal-format
-#| msgid "use of decimal floating point types in AltiVec types is invalid"
+#, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "användning av decimala flyttalstyper i AltiVec-typer är ogiltigt"
 
@@ -39262,10 +39253,9 @@ msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "det konstanta argumentet %d till den inbyggda %qF är utanför intervallet för måltypen"
 
 #: config/s390/s390.c:762
-#, fuzzy, gcc-internal-format
-#| msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
+#, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
-msgstr "det konstanta argumentet %d till den inbyggda %qF ligger utanför intervallet (0..%wu)"
+msgstr "det konstanta argumentet %d till den inbyggda %qF är ogiltigt (%s)"
 
 #: config/s390/s390.c:766
 #, gcc-internal-format
@@ -39807,10 +39797,9 @@ msgid "STABS debugging information for Ada is obsolete and not supported anymore
 msgstr "STABS-felsökningsinformation för Ada är föråldrat och stödjs inte längre"
 
 #: ada/gcc-interface/trans.c:332
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "STOP code at %C contains too many digits"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s contains too many lines"
-msgstr "STOP-kod vid %C innehåller för många siffror"
+msgstr "%s innehåller för många rader"
 
 #: ada/gcc-interface/trans.c:1642
 #, gcc-internal-format
@@ -45883,10 +45872,8 @@ msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "kan inte binda r-värdesreferens av typen %qH till ett l-värde av typ %qI"
 
 #: cp/call.c:7906
-#, fuzzy
-#| msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
-msgstr "kan inte binda icke-const-l-värde av typen %qH till ett r-värde av typ %qI"
+msgstr "kan inte binda icke-const-l-värde av typen %qH till ett värde av typ %qI"
 
 #: cp/call.c:7911
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
@@ -48216,10 +48203,9 @@ msgid "%qD used without template arguments"
 msgstr "%qD använd utan mallargument"
 
 #: cp/decl.c:4061
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a function template"
+#, gcc-internal-format
 msgid "%qD is a function, not a type"
-msgstr "%qD är inte en funktionsmall"
+msgstr "%qD är en funktion, inte en typ"
 
 #: cp/decl.c:4072
 #, gcc-internal-format
@@ -48812,7 +48798,7 @@ msgstr "medan %qT dekomponeras till %E element"
 #: cp/decl.c:8640
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
-msgstr ""
+msgstr "%<std::tuple_element<%u, %T>::type%> är %<void%>"
 
 #: cp/decl.c:8646
 #, gcc-internal-format
@@ -49135,10 +49121,9 @@ msgid "a non-template variable cannot be %<concept%>"
 msgstr "en icke-mallvariabel variabel kan inte vara %<concept%>"
 
 #: cp/decl.c:10371
-#, fuzzy, gcc-internal-format
-#| msgid "deduction guide %qD must be declared at namespace scope"
+#, gcc-internal-format
 msgid "concept must be defined at namespace scope"
-msgstr "härledningsguiden %qD måste deklareras med namnrymdsräckvidd"
+msgstr "koncept måste definieras med namnrymdsräckvidd"
 
 #: cp/decl.c:10378
 #, gcc-internal-format
@@ -52957,10 +52942,9 @@ msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "typer får inte definieras i %<__builtin_offsetof%>"
 
 #: cp/parser.c:10809
-#, fuzzy, gcc-internal-format
-#| msgid "definition of %q#T inside template parameter list"
+#, gcc-internal-format
 msgid "lambda-expression in template parameter type"
-msgstr "definition av %q#T inuti mallparameterlista"
+msgstr "lambda-uttryck i mallparametertyp"
 
 #: cp/parser.c:10819
 #, gcc-internal-format
@@ -57812,10 +57796,9 @@ msgid "converting from %qH to %qI"
 msgstr "konvertering från %qH till %qI"
 
 #: cp/typeck.c:7963
-#, fuzzy, gcc-internal-format
-#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
-msgstr "ogiltig typkonvertering av ett rvärdeuttryck av typ %qT till typ %qT"
+msgstr "ogiltig typkonvertering av ett pr-värdeuttryck av typ %qT till typ %qT"
 
 #: cp/typeck.c:8033
 msgid "cast from %qH to %qI loses precision"
@@ -58482,10 +58465,9 @@ msgid "cannot be declared to be a function"
 msgstr "kan inte deklareras till att vara en funktion"
 
 #: d/dmd/dsymbolsem.c:418
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "no definition of struct %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "no definition of struct `%s`"
-msgstr "ingen definition av struct %s"
+msgstr "ingen definition av struct ”%s”"
 
 #: d/dmd/dsymbolsem.c:434
 #, gcc-internal-format
@@ -58631,10 +58613,9 @@ msgid "char 0x%04x not allowed in mangled name"
 msgstr "tecknet 0x%04x är inte tillåtet i manglade namn"
 
 #: d/dmd/dsymbolsem.c:1465
-#, fuzzy, gcc-internal-format
-#| msgid "no arguments"
+#, gcc-internal-format
 msgid "takes no argument"
-msgstr "inga argument"
+msgstr "tar inga argument"
 
 #: d/dmd/dsymbolsem.c:1526
 #, gcc-internal-format
@@ -58748,12 +58729,12 @@ msgstr "det går inte att vara både slutlig och abstrakt"
 #: d/dmd/dsymbolsem.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, ...)` not `%s`"
-msgstr ""
+msgstr "”pragma(%s)”-funktioner måste vara ”extern(C) %s %s([parameter…], const(char)*, ...)” inte ”%s”"
 
 #: d/dmd/dsymbolsem.c:2835
 #, gcc-internal-format, gfc-internal-format
 msgid "`pragma(%s)` functions must be `extern(C) %s %s([parameters...], const(char)*, va_list)`"
-msgstr ""
+msgstr "”pragma(%s)”-funktioner måste vara ”extern(C) %s %s([parameter…], const(char)*, va_list)”"
 
 #: d/dmd/dsymbolsem.c:2851
 #, gcc-internal-format, gfc-internal-format
@@ -59029,16 +59010,14 @@ msgid "cannot call super() implicitly because it is annotated with @disable"
 msgstr "kan inte anropa super() implicit för att den är annoterad med @disable"
 
 #: d/dmd/semantic3.c:862
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "has no return statement, but is expected to return a value of type %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "has no `return` statement, but is expected to return a value of type `%s`"
-msgstr "har ingen retursats, men förväntas returnera ett värde av typen %s"
+msgstr "har ingen ”return”-sats, men förväntas returnera ett värde av typen ”%s”"
 
 #: d/dmd/semantic3.c:864
-#, fuzzy, gcc-internal-format
-#| msgid "no return exp; or assert(0); at end of function"
+#, gcc-internal-format
 msgid "no `return exp;` or `assert(0);` at end of function"
-msgstr "inget returuttryck; eller assert(0); vid slutet av funktionen"
+msgstr "inget ”return uttr;” eller ”assert(0);” vid slutet av funktionen"
 
 #: d/dmd/semantic3.c:1171
 #, gcc-internal-format, gfc-internal-format
@@ -72545,10 +72524,8 @@ msgstr "Inte konfigurerad med %<--enable-gather-detailed-mem-stats%>."
 msgid "%<-fwpa%> and %<-fltrans%> are mutually exclusive"
 msgstr "%<-fwpa%> och %<-fltrans%> är ömsesidigt uteslutande"
 
-# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99883
 #: lto/lto-lang.c:898
-#, fuzzy, gcc-internal-format
-#| msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
+#, gcc-internal-format
 msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
 msgstr "%<-flinker-output=rel%> och %<-fltrans%> är ömsesidigt uteslutande"
 
@@ -73903,6 +73880,3 @@ msgstr "okänd initieringsprioritet för vtable-verifiering %qs"
 #, gcc-internal-format
 msgid "unknown evrp mode %qs"
 msgstr "okänt evrp-läge %qs"
-
-#~ msgid "cannot deduce template arguments for %qT from %<()%>"
-#~ msgstr "kan inte härleda mallargument för %qT från %<()%>"

From d5bfe5a43a68133be0c0e8a8e013ac36711f37bf Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Fri, 30 Apr 2021 00:18:18 +0000
Subject: [PATCH 039/164] Daily bump.

---
 gcc/ChangeLog           | 47 +++++++++++++++++++++++++++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/cp/ChangeLog        |  9 +++++++
 gcc/fortran/ChangeLog   |  8 +++++++
 gcc/po/ChangeLog        |  8 +++++++
 gcc/testsuite/ChangeLog | 52 +++++++++++++++++++++++++++++++++++++++++
 libgomp/ChangeLog       |  8 +++++++
 libstdc++-v3/ChangeLog  | 23 ++++++++++++++++++
 8 files changed, 156 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 7aa0363874902..40b2e350e8a94 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,50 @@
+2021-04-29  Richard Earnshaw  <rearnsha@arm.com>
+
+	Backported from master:
+	2021-04-28  Richard Earnshaw  <rearnsha@arm.com>
+
+	PR target/100311
+	* config/arm/arm.c (arm_hard_regno_mode_ok): Only allow VPR to be
+	used in HImode.
+
+2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/100302
+	* config/aarch64/aarch64.c (aarch64_add_offset_1_temporaries): Use
+	absu_hwi instead of abs_hwi.
+
+2021-04-29  Tom de Vries  <tdevries@suse.de>
+
+	Backported from master:
+	2021-04-29  Tom de Vries  <tdevries@suse.de>
+
+	PR target/100232
+	* internal-fn.c (expand_GOMP_SIMT_ENTER_ALLOC)
+	(expand_GOMP_SIMT_LAST_LANE, expand_GOMP_SIMT_ORDERED_PRED)
+	(expand_GOMP_SIMT_VOTE_ANY, expand_GOMP_SIMT_XCHG_BFLY)
+	(expand_GOMP_SIMT_XCHG_IDX): Ensure target is assigned to.
+
+2021-04-29  Richard Sandiford  <richard.sandiford@arm.com>
+
+	Backported from master:
+	2021-04-28  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR target/100305
+	* config/aarch64/constraints.md (Utq): Require the address to
+	be valid for both the element mode and for V2DImode.
+
+2021-04-29  Richard Sandiford  <richard.sandiford@arm.com>
+
+	Backported from master:
+	2021-04-27  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR target/100270
+	* config/aarch64/aarch64.c (aarch64_comp_type_attributes): Handle
+	SVE attributes.
+
 2021-04-28  YiFei Zhu  <zhuyifei1999@gmail.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index d04d9806e5b7e..e485971526caf 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210429
+20210430
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 15b44f3585408..0ac9d0673acea 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,12 @@
+2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/100319
+	* semantics.c (finish_omp_clauses): Fix up check that variable
+	mentioned in detach clause doesn't appear in data-sharing clauses.
+
 2021-04-27  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index 1a552875160a3..7dbb014463aca 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,11 @@
+2021-04-29  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-04-28  Tobias Burnus  <tobias@codesourcery.com>
+
+	* openmp.c (gfc_match_omp_variable_list): Gobble whitespace before
+	checking whether a '%' or parenthesis-open follows as next character.
+
 2021-04-27  Harald Anlauf  <anlauf@gmx.de>
 
 	Backported from master:
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index c1928e8ccb90c..961db425e0650 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,11 @@
+2021-04-29  Joseph Myers  <joseph@codesourcery.com>
+
+	* sv.po: Update.
+
+2021-04-29  Joseph Myers  <joseph@codesourcery.com>
+
+	* fr.po: Update.
+
 2021-04-28  Joseph Myers  <joseph@codesourcery.com>
 
 	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index d52369c3ea1a7..54aa671926b80 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,55 @@
+2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/100305
+	* gcc.c-torture/compile/pr100305.c: Remove dg-options.  Add PR line.
+
+2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/100302
+	* gcc.target/aarch64/sve/pr100302.c: New test.
+
+2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-04-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/100319
+	* c-c++-common/gomp/task-detach-3.c: New test.
+
+2021-04-29  Richard Sandiford  <richard.sandiford@arm.com>
+
+	Backported from master:
+	2021-04-28  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR target/100305
+	* gcc.c-torture/compile/pr100305.c: New test.
+
+2021-04-29  Richard Sandiford  <richard.sandiford@arm.com>
+
+	Backported from master:
+	2021-04-27  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR target/100270
+	* gcc.target/aarch64/sve/acle/general-c/pr100270_1.c: New test.
+	* gcc.target/aarch64/sve/acle/general-c/sizeless-2.c: Change
+	expected error message when subtracting pointers to different
+	vector types.  Expect warnings when mixing them elsewhere.
+	* gcc.target/aarch64/sve/acle/general/attributes_7.c: Remove
+	XFAILs.  Tweak error messages for some cases.
+
+2021-04-29  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-04-28  Tobias Burnus  <tobias@codesourcery.com>
+
+	* gfortran.dg/gomp/map-5.f90: New test.
+
 2021-04-28  Uroš Bizjak  <ubizjak@gmail.com>
 
 	PR target/100182
diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
index f987714219193..7c682e9a07d03 100644
--- a/libgomp/ChangeLog
+++ b/libgomp/ChangeLog
@@ -1,3 +1,11 @@
+2021-04-29  Tom de Vries  <tdevries@suse.de>
+
+	Backported from master:
+	2021-04-29  Tom de Vries  <tdevries@suse.de>
+
+	PR target/100232
+	* testsuite/libgomp.c/target-43.c: New file.
+
 2021-04-27  Tobias Burnus  <tobias@codesourcery.com>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 9c33b60fc35fe..8c0b4c00918de 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,26 @@
+2021-04-29  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-04-26  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/100259
+	* include/experimental/internet (net::ip::make_error_code)
+	(net::ip::make_error_condition, net::ip::make_network_v4)
+	(net::ip::operator==(const udp&, const udp&)): Add 'inline'.
+
+2021-04-29  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-04-28  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/basic_string.h (__cpp_lib_constexpr_string): Define.
+	* include/std/version (__cpp_lib_constexpr_string): Define.
+	* testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc:
+	Check for __cpp_lib_constexpr_string.
+	* testsuite/21_strings/char_traits/requirements/constexpr_functions_c++20.cc:
+	Likewise.
+	* testsuite/21_strings/char_traits/requirements/version.cc: New test.
+
 2021-04-28  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

From c5aa0e1416d9a9704e4846ca2ae722403684fec8 Mon Sep 17 00:00:00 2001
From: Richard Biener <rguenther@suse.de>
Date: Fri, 30 Apr 2021 11:13:42 +0200
Subject: [PATCH 040/164] tree-optimization/96513 - add testcase for fixed bug

This adds a testcase for a bug that was fixed with the
hybrid SLP detection rewrite.

2021-04-30  Richard Biener  <rguenther@suse.de>

	PR tree-optimization/96513
	* gcc.dg/torture/pr96513.c: New testcase.
---
 gcc/testsuite/gcc.dg/torture/pr96513.c | 26 ++++++++++++++++++++++++++
 1 file changed, 26 insertions(+)
 create mode 100644 gcc/testsuite/gcc.dg/torture/pr96513.c

diff --git a/gcc/testsuite/gcc.dg/torture/pr96513.c b/gcc/testsuite/gcc.dg/torture/pr96513.c
new file mode 100644
index 0000000000000..5ee040e96c8e9
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/torture/pr96513.c
@@ -0,0 +1,26 @@
+/* { dg-do compile } */
+
+typedef struct {
+  short a;
+  short b;
+} c;
+c *d;
+int e, f, i, j, k, l, m, n, o, p;
+c g, h;
+void q() {
+  do {
+    if (o) {
+      (*d).a = (*d).b = d[e].a = d[e].a * 3 + 1 >> 15;
+      d[e].b = d[e].b * 3 + 1 >> 15;
+    }
+    n = -(d[e].b * g.b) >> 5;
+    m = d[e].b * g.a + 1 >> 5;
+    l = d[f].a * -d[f].b * h.b + 1 >> 5;
+    k = d[f].a * h.b + d[f].b * h.a + 1 >> 5;
+    j = n + l;
+    i = m - k;
+    (*d).a += j;
+    d[e].a -= i;
+    ++d;
+  } while (--p);
+}

From 88393a07a8df489df2583e77fce8adc9b1db8163 Mon Sep 17 00:00:00 2001
From: Richard Biener <rguenther@suse.de>
Date: Fri, 30 Apr 2021 14:14:48 +0200
Subject: [PATCH 041/164] c++/98032 - add testcase

This adds another testcase for PR95719.

2021-04-30  Richard Biener  <rguenther@suse.de>

	PR c++/98032
	* g++.dg/pr98032.C: New testcase.

(cherry picked from commit dfc70841eb0ca42637826177f329cf6c98ee00ad)
---
 gcc/testsuite/g++.dg/pr98032.C | 20 ++++++++++++++++++++
 1 file changed, 20 insertions(+)
 create mode 100644 gcc/testsuite/g++.dg/pr98032.C

diff --git a/gcc/testsuite/g++.dg/pr98032.C b/gcc/testsuite/g++.dg/pr98032.C
new file mode 100644
index 0000000000000..d7eef27666813
--- /dev/null
+++ b/gcc/testsuite/g++.dg/pr98032.C
@@ -0,0 +1,20 @@
+// { dg-do compile }
+
+namespace osl {
+class Thread {
+public:
+  virtual ~Thread();
+  virtual void join();
+};
+} // namespace osl
+class SimpleReferenceObject {
+protected:
+  virtual ~SimpleReferenceObject();
+};
+class Thread : SimpleReferenceObject, osl::Thread {
+public:
+  using osl::Thread::join;
+};
+class RenderThread : Thread {
+  RenderThread() { join(); }
+};

From 991ac2d157e8612c02beaa59778ffabd88f484a7 Mon Sep 17 00:00:00 2001
From: Alex Coplan <alex.coplan@arm.com>
Date: Fri, 23 Apr 2021 14:09:15 +0100
Subject: [PATCH 042/164] early-remat.c: Fix new/delete mismatch [PR100230]

This simple patch fixes a mistmatched operator new/delete in
early-remat.c which triggers ASan errors on (at least) AArch64 when
compiling SVE code.

gcc/ChangeLog:

	PR rtl-optimization/100230
	* early-remat.c (early_remat::sort_candidates): Use delete[]
	instead of delete for array allocated with new[].

(cherry picked from commit 5d87c2251c441f056e0a44f928ffcb8a8a679b6b)
---
 gcc/early-remat.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/early-remat.c b/gcc/early-remat.c
index c8d4fee937d84..92077d094aed5 100644
--- a/gcc/early-remat.c
+++ b/gcc/early-remat.c
@@ -1059,7 +1059,7 @@ early_remat::sort_candidates (void)
 
   m_candidates.qsort (compare_candidates);
 
-  delete postorder_index;
+  delete[] postorder_index;
 }
 
 /* Commit to the current candidate indices and initialize cross-references.  */

From 7f37c47c1eb4d84badba67bc81a6879f6676faf1 Mon Sep 17 00:00:00 2001
From: David Edelsohn <dje.gcc@gmail.com>
Date: Fri, 30 Apr 2021 14:09:13 -0400
Subject: [PATCH 043/164] aix: Alias -m64 to -maix64 and -m32 to -maix32.

GCC on AIX historically has used -maix64 and -maix32 to switch to 64 bit mode
or 32 bit mode, unlike other ports that use -m64 and -m32.  The Alias()
directive for options cannot be used because aix64 is expected in multiple
parts of the compiler infrastructure and one cannot switch to -m64 due to
backward compatibility.

This patch defines DRIVER_SELF_SPECS to translate -m64 to -maix64 and
-m32 to -maix32 so that the command line option compatible with other
targets can be used while continuing to allow the historical options.

gcc/ChangeLog:

	* config/rs6000/aix.h (SUBTARGET_DRIVER_SELF_SPECS): New.
	* config/rs6000/aix64.opt (m64): New.
	(m32): New.

(cherry picked from commit 0366e2b40e9ea5fc61c9a694de0c8c76a238b03c)
---
 gcc/config/rs6000/aix.h     | 5 +++++
 gcc/config/rs6000/aix64.opt | 6 ++++++
 2 files changed, 11 insertions(+)

diff --git a/gcc/config/rs6000/aix.h b/gcc/config/rs6000/aix.h
index 7fccb31307bbd..2d20fcad8dec6 100644
--- a/gcc/config/rs6000/aix.h
+++ b/gcc/config/rs6000/aix.h
@@ -279,3 +279,8 @@
 /* Use standard DWARF numbering for DWARF debugging information.  */
 #define RS6000_USE_DWARF_NUMBERING
 
+/* Replace -m64 with -maix64 and -m32 with -maix32.  */
+#undef SUBTARGET_DRIVER_SELF_SPECS
+#define SUBTARGET_DRIVER_SELF_SPECS	\
+"%{m64:-maix64} %<m64",			\
+"%{m32:-maix32} %<m32"
diff --git a/gcc/config/rs6000/aix64.opt b/gcc/config/rs6000/aix64.opt
index 7673c91e0135f..15d863fa0a2b8 100644
--- a/gcc/config/rs6000/aix64.opt
+++ b/gcc/config/rs6000/aix64.opt
@@ -53,3 +53,9 @@ Driver
 
 pthread
 Driver
+
+m64
+Driver
+
+m32
+Driver

From 0081f6165bc00ed52514016b50b02e54b5cac41b Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Fri, 30 Apr 2021 20:32:05 +0100
Subject: [PATCH 044/164] libstdc++: Fix inconsistent feature test macros

The __cpp_lib_constexpr_string and __cpp_lib_semaphore feature test
macros are not defined consistently in <version> and the relevant header
for the feature.

libstdc++-v3/ChangeLog:

	* include/bits/basic_string.h (__cpp_lib_constexpr_string):
	Only define for C++17 and later.
	* include/std/version (__cpp_lib_semaphore): Fix condition
	to match the one in <semaphore>.

(cherry picked from commit 3215d4f5b3d08e0087a88df9e155c779927ace1a)
---
 libstdc++-v3/include/bits/basic_string.h | 2 +-
 libstdc++-v3/include/std/version         | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/libstdc++-v3/include/bits/basic_string.h b/libstdc++-v3/include/bits/basic_string.h
index 41d781c698e7f..fba7c6f335418 100644
--- a/libstdc++-v3/include/bits/basic_string.h
+++ b/libstdc++-v3/include/bits/basic_string.h
@@ -55,7 +55,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 #if __cplusplus == 201703L
 // Support P0426R1 changes to char_traits in C++17.
 # define __cpp_lib_constexpr_string 201611L
-#else
+#elif __cplusplus > 201703L
 // Also support P1032R1 in C++20 (but not P0980R1 yet).
 # define __cpp_lib_constexpr_string 201811L
 #endif
diff --git a/libstdc++-v3/include/std/version b/libstdc++-v3/include/std/version
index 09e67a40d0c2f..ea0e18a3f9dcf 100644
--- a/libstdc++-v3/include/std/version
+++ b/libstdc++-v3/include/std/version
@@ -241,7 +241,7 @@
 #if __cpp_lib_concepts
 # define __cpp_lib_ranges 201911L
 #endif
-#if __cpp_lib_atomic_wait
+#if __cpp_lib_atomic_wait || _GLIBCXX_HAVE_POSIX_SEMAPHORE
 # define __cpp_lib_semaphore 201907L
 #endif
 #define __cpp_lib_shift 201806L

From b5440b56552524f421a65682eb15853a73e27baf Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Sat, 1 May 2021 00:18:07 +0000
Subject: [PATCH 045/164] Daily bump.

---
 gcc/ChangeLog           | 18 ++++++++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/testsuite/ChangeLog | 13 +++++++++++++
 libstdc++-v3/ChangeLog  | 10 ++++++++++
 4 files changed, 42 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 40b2e350e8a94..67fdef6aefdc2 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,21 @@
+2021-04-30  David Edelsohn  <dje.gcc@gmail.com>
+
+	Backported from master:
+	2021-04-27  David Edelsohn  <dje.gcc@gmail.com>
+
+	* config/rs6000/aix.h (SUBTARGET_DRIVER_SELF_SPECS): New.
+	* config/rs6000/aix64.opt (m64): New.
+	(m32): New.
+
+2021-04-30  Alex Coplan  <alex.coplan@arm.com>
+
+	Backported from master:
+	2021-04-23  Alex Coplan  <alex.coplan@arm.com>
+
+	PR rtl-optimization/100230
+	* early-remat.c (early_remat::sort_candidates): Use delete[]
+	instead of delete for array allocated with new[].
+
 2021-04-29  Richard Earnshaw  <rearnsha@arm.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index e485971526caf..e86ec869849c5 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210430
+20210501
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 54aa671926b80..e54ae674ab2e8 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,16 @@
+2021-04-30  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-04-30  Richard Biener  <rguenther@suse.de>
+
+	PR c++/98032
+	* g++.dg/pr98032.C: New testcase.
+
+2021-04-30  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/96513
+	* gcc.dg/torture/pr96513.c: New testcase.
+
 2021-04-29  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 8c0b4c00918de..c76d4817517d6 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,13 @@
+2021-04-30  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-04-30  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/basic_string.h (__cpp_lib_constexpr_string):
+	Only define for C++17 and later.
+	* include/std/version (__cpp_lib_semaphore): Fix condition
+	to match the one in <semaphore>.
+
 2021-04-29  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

From 204213fdf23d8228084ded03e1ca9f8acd91d39a Mon Sep 17 00:00:00 2001
From: "Maciej W. Rozycki" <macro@orcam.me.uk>
Date: Wed, 21 Apr 2021 23:33:25 +0200
Subject: [PATCH 046/164] VAX: Accept ASHIFT in address expressions

Fix regressions:

FAIL: gcc.c-torture/execute/20090113-2.c   -O1  (internal compiler error)
FAIL: gcc.c-torture/execute/20090113-2.c   -O1  (test for excess errors)
FAIL: gcc.c-torture/execute/20090113-3.c   -O1  (internal compiler error)
FAIL: gcc.c-torture/execute/20090113-3.c   -O1  (test for excess errors)

triggering if LRA is used rather than old reload and caused by:

(plus:SI (plus:SI (mult:SI (reg:SI 30 [ _10 ])
            (const_int 4 [0x4]))
        (reg/f:SI 26 [ _6 ]))
    (const_int 12 [0xc]))

coming from:

(insn 58 57 59 10 (set (reg:SI 33 [ _13 ])
        (zero_extract:SI (mem:SI (plus:SI (plus:SI (mult:SI (reg:SI 30 [ _10 ])
                            (const_int 4 [0x4]))
                        (reg/f:SI 26 [ _6 ]))
                    (const_int 12 [0xc])) [4 _6->bits[_10]+0 S4 A32])
            (reg:QI 56)
            (reg:SI 53)))
".../gcc/testsuite/gcc.c-torture/execute/20090113-2.c":64:12 490 {*extzv_non_const}
     (expr_list:REG_DEAD (reg:QI 56)
        (expr_list:REG_DEAD (reg:SI 53)
            (expr_list:REG_DEAD (reg:SI 30 [ _10 ])
                (expr_list:REG_DEAD (reg/f:SI 26 [ _6 ])
                    (nil))))))

being converted into:

(plus:SI (plus:SI (ashift:SI (reg:SI 30 [ _10 ])
            (const_int 2 [0x2]))
        (reg/f:SI 26 [ _6 ]))
    (const_int 12 [0xc]))

which is an rtx the VAX backend currently does not recognize as a valid
machine address, although apparently it is only inside MEM rtx's that
indexed addressing is supposed to be canonicalized to a MULT rather than
ASHIFT form.  Handle the ASHIFT form too throughout the backend then.

The change appears to also improve code generation with old reload and
code size stats are as follows, collected from 18153 executables built
in `check-c' GCC testing:

              samples average  median
--------------------------------------
regressions        47  0.702%  0.521%
unchanged       17503  0.000%  0.000%
progressions      603 -0.920% -0.403%
--------------------------------------
total           18153 -0.029%  0.000%

with a small number of outliers (over 5% size change):

old     new     change  %change filename
----------------------------------------------------
1885    1645    -240   -12.7320 pr53505.exe
1331    1221    -110    -8.2644 pr89634.exe
1553    1473    -80     -5.1513 stdatomic-vm.exe
1413    1341    -72     -5.0955 pr45830.exe
1415    1343    -72     -5.0883 stdatomic-vm.exe
25765   24463   -1302   -5.0533 strlen-5.exe
25765   24463   -1302   -5.0533 strlen-5.exe
25765   24463   -1302   -5.0533 strlen-5.exe
1191    1131    -60     -5.0377 20050527-1.exe

(all changes on the expansion side are below 5%).

	gcc/
	* config/vax/vax.c (print_operand_address, vax_address_cost_1)
	(index_term_p): Handle ASHIFT too.

(cherry picked from commit c605a8bf92708e81d771426a87b3baddc32082dd)
---
 gcc/config/vax/vax.c | 34 +++++++++++++++++++++-------------
 1 file changed, 21 insertions(+), 13 deletions(-)

diff --git a/gcc/config/vax/vax.c b/gcc/config/vax/vax.c
index 726c371913822..e71e1b23a6bec 100644
--- a/gcc/config/vax/vax.c
+++ b/gcc/config/vax/vax.c
@@ -333,12 +333,12 @@ print_operand_address (FILE * file, rtx addr)
 
     case PLUS:
       /* There can be either two or three things added here.  One must be a
-	 REG.  One can be either a REG or a MULT of a REG and an appropriate
-	 constant, and the third can only be a constant or a MEM.
+	 REG.  One can be either a REG or a MULT/ASHIFT of a REG and an
+	 appropriate constant, and the third can only be a constant or a MEM.
 
 	 We get these two or three things and put the constant or MEM in
-	 OFFSET, the MULT or REG in IREG, and the REG in BREG.  If we have
-	 a register and can't tell yet if it is a base or index register,
+	 OFFSET, the MULT/ASHIFT or REG in IREG, and the REG in BREG.  If we
+	 have a register and can't tell yet if it is a base or index register,
 	 put it into REG1.  */
 
       reg1 = 0; ireg = 0; breg = 0; offset = 0;
@@ -355,12 +355,14 @@ print_operand_address (FILE * file, rtx addr)
 	  offset = XEXP (addr, 1);
 	  addr = XEXP (addr, 0);
 	}
-      else if (GET_CODE (XEXP (addr, 1)) == MULT)
+      else if (GET_CODE (XEXP (addr, 1)) == MULT
+	       || GET_CODE (XEXP (addr, 1)) == ASHIFT)
 	{
 	  ireg = XEXP (addr, 1);
 	  addr = XEXP (addr, 0);
 	}
-      else if (GET_CODE (XEXP (addr, 0)) == MULT)
+      else if (GET_CODE (XEXP (addr, 0)) == MULT
+	       || GET_CODE (XEXP (addr, 0)) == ASHIFT)
 	{
 	  ireg = XEXP (addr, 0);
 	  addr = XEXP (addr, 1);
@@ -385,7 +387,7 @@ print_operand_address (FILE * file, rtx addr)
 	  else
 	    reg1 = addr;
 	}
-      else if (GET_CODE (addr) == MULT)
+      else if (GET_CODE (addr) == MULT || GET_CODE (addr) == ASHIFT)
 	ireg = addr;
       else
 	{
@@ -416,7 +418,8 @@ print_operand_address (FILE * file, rtx addr)
 	    }
 	  else
 	    {
-	      gcc_assert (GET_CODE (XEXP (addr, 0)) == MULT);
+	      gcc_assert (GET_CODE (XEXP (addr, 0)) == MULT
+			  || GET_CODE (XEXP (addr, 0)) == ASHIFT);
 	      gcc_assert (!ireg);
 	      ireg = XEXP (addr, 0);
 	    }
@@ -447,7 +450,8 @@ print_operand_address (FILE * file, rtx addr)
 	    }
 	  else
 	    {
-	      gcc_assert (GET_CODE (XEXP (addr, 1)) == MULT);
+	      gcc_assert (GET_CODE (XEXP (addr, 1)) == MULT
+			  || GET_CODE (XEXP (addr, 1)) == ASHIFT);
 	      gcc_assert (!ireg);
 	      ireg = XEXP (addr, 1);
 	    }
@@ -506,7 +510,7 @@ print_operand_address (FILE * file, rtx addr)
 
       if (ireg != 0)
 	{
-	  if (GET_CODE (ireg) == MULT)
+	  if (GET_CODE (ireg) == MULT || GET_CODE (ireg) == ASHIFT)
 	    ireg = XEXP (ireg, 0);
 	  gcc_assert (REG_P (ireg));
 	  fprintf (file, "[%s]", reg_names[REGNO (ireg)]);
@@ -707,6 +711,7 @@ vax_address_cost_1 (rtx addr)
       reg = 1;
       break;
     case MULT:
+    case ASHIFT:
       indexed = 1;	/* 2 on VAX 2 */
       break;
     case CONST_INT:
@@ -1824,23 +1829,26 @@ static bool
 index_term_p (rtx prod, machine_mode mode, bool strict)
 {
   rtx xfoo0, xfoo1;
+  bool log_p;
 
   if (GET_MODE_SIZE (mode) == 1)
     return BASE_REGISTER_P (prod, strict);
 
-  if (GET_CODE (prod) != MULT || GET_MODE_SIZE (mode) > 8)
+  if ((GET_CODE (prod) != MULT && GET_CODE (prod) != ASHIFT)
+      || GET_MODE_SIZE (mode) > 8)
     return false;
 
+  log_p = GET_CODE (prod) == ASHIFT;
   xfoo0 = XEXP (prod, 0);
   xfoo1 = XEXP (prod, 1);
 
   if (CONST_INT_P (xfoo0)
-      && INTVAL (xfoo0) == (int)GET_MODE_SIZE (mode)
+      && GET_MODE_SIZE (mode) == (log_p ? 1 << INTVAL (xfoo0) : INTVAL (xfoo0))
       && INDEX_REGISTER_P (xfoo1, strict))
     return true;
 
   if (CONST_INT_P (xfoo1)
-      && INTVAL (xfoo1) == (int)GET_MODE_SIZE (mode)
+      && GET_MODE_SIZE (mode) == (log_p ? 1 << INTVAL (xfoo1) : INTVAL (xfoo1))
       && INDEX_REGISTER_P (xfoo0, strict))
     return true;
 

From 8ec4974ed051901ec30e54c7e739ebb71651513b Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Sun, 2 May 2021 00:17:55 +0000
Subject: [PATCH 047/164] Daily bump.

---
 gcc/ChangeLog | 8 ++++++++
 gcc/DATESTAMP | 2 +-
 2 files changed, 9 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 67fdef6aefdc2..50441316a50f1 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,11 @@
+2021-05-01  Maciej W. Rozycki  <macro@orcam.me.uk>
+
+	Backported from master:
+	2021-04-27  Maciej W. Rozycki  <macro@orcam.me.uk>
+
+	* config/vax/vax.c (print_operand_address, vax_address_cost_1)
+	(index_term_p): Handle ASHIFT too.
+
 2021-04-30  David Edelsohn  <dje.gcc@gmail.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index e86ec869849c5..c2c5100c82327 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210501
+20210502

From e90b46894e7b614d1e47d081e144f61ca8960f4c Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Mon, 3 May 2021 00:17:59 +0000
Subject: [PATCH 048/164] Daily bump.

---
 gcc/DATESTAMP | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index c2c5100c82327..891293d2df122 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210502
+20210503

From 107ca5c2fd6dcb53c3cba788ae388e7e4e789ed8 Mon Sep 17 00:00:00 2001
From: Tobias Burnus <tobias@codesourcery.com>
Date: Sun, 2 May 2021 18:16:17 +0200
Subject: [PATCH 049/164] Fortran: Async I/O - avoid unlocked unlocking
 [PR100352]

Follow up to PR100352, which moved unit unlocking to st_*_done_worker to
avoid lock order reversal; however, as async_io uses a different lock,
the (unlocked locked) unit lock shall not be unlocked there.

libgfortran/ChangeLog:

	PR libgomp/100352
	* io/transfer.c (st_read_done_worker, st_write_done_worker): Add new
	arg whether to unlock unit.
	(st_read_done, st_write_done): Call it with true.
	* io/async.c (async_io): Call it with false.
	* io/io.h (st_write_done_worker, st_read_done_worker): Update prototype.

(cherry picked from commit a13a50047ef1814a7bda2392f728bf28f81b17ce)
---
 libgfortran/io/async.c    |  4 ++--
 libgfortran/io/io.h       |  4 ++--
 libgfortran/io/transfer.c | 14 ++++++++------
 3 files changed, 12 insertions(+), 10 deletions(-)

diff --git a/libgfortran/io/async.c b/libgfortran/io/async.c
index d216ace1947cb..247008ca801d2 100644
--- a/libgfortran/io/async.c
+++ b/libgfortran/io/async.c
@@ -117,13 +117,13 @@ async_io (void *arg)
 		{
 		case AIO_WRITE_DONE:
 		  NOTE ("Finalizing write");
-		  st_write_done_worker (au->pdt);
+		  st_write_done_worker (au->pdt, false);
 		  UNLOCK (&au->io_lock);
 		  break;
 
 		case AIO_READ_DONE:
 		  NOTE ("Finalizing read");
-		  st_read_done_worker (au->pdt);
+		  st_read_done_worker (au->pdt, false);
 		  UNLOCK (&au->io_lock);
 		  break;
 
diff --git a/libgfortran/io/io.h b/libgfortran/io/io.h
index e0007c6bfe572..3355bc2fd8d08 100644
--- a/libgfortran/io/io.h
+++ b/libgfortran/io/io.h
@@ -1083,11 +1083,11 @@ default_precision_for_float (int kind)
 #endif
 
 extern void
-st_write_done_worker (st_parameter_dt *);
+st_write_done_worker (st_parameter_dt *, bool);
 internal_proto (st_write_done_worker);
 
 extern void
-st_read_done_worker (st_parameter_dt *);
+st_read_done_worker (st_parameter_dt *, bool);
 internal_proto (st_read_done_worker);
 
 extern void
diff --git a/libgfortran/io/transfer.c b/libgfortran/io/transfer.c
index 71a935652e37b..36e35b48cd32c 100644
--- a/libgfortran/io/transfer.c
+++ b/libgfortran/io/transfer.c
@@ -4337,7 +4337,7 @@ extern void st_read_done (st_parameter_dt *);
 export_proto(st_read_done);
 
 void
-st_read_done_worker (st_parameter_dt *dtp)
+st_read_done_worker (st_parameter_dt *dtp, bool unlock)
 {
   bool free_newunit = false;
   finalize_transfer (dtp);
@@ -4367,7 +4367,8 @@ st_read_done_worker (st_parameter_dt *dtp)
 	  free_format (dtp);
 	}
     }
-   unlock_unit (dtp->u.p.current_unit);
+   if (unlock)
+     unlock_unit (dtp->u.p.current_unit);
    if (free_newunit)
      {
        /* Avoid inverse lock issues by placing after unlock_unit.  */
@@ -4394,7 +4395,7 @@ st_read_done (st_parameter_dt *dtp)
 	  unlock_unit (dtp->u.p.current_unit);
 	}
       else
-	st_read_done_worker (dtp);  /* Calls unlock_unit.  */
+	st_read_done_worker (dtp, true);  /* Calls unlock_unit.  */
     }
 
   library_end ();
@@ -4412,7 +4413,7 @@ st_write (st_parameter_dt *dtp)
 
 
 void
-st_write_done_worker (st_parameter_dt *dtp)
+st_write_done_worker (st_parameter_dt *dtp, bool unlock)
 {
   bool free_newunit = false;
   finalize_transfer (dtp);
@@ -4463,7 +4464,8 @@ st_write_done_worker (st_parameter_dt *dtp)
 	  free_format (dtp);
 	}
     }
-   unlock_unit (dtp->u.p.current_unit);
+   if (unlock)
+     unlock_unit (dtp->u.p.current_unit);
    if (free_newunit)
      {
        /* Avoid inverse lock issues by placing after unlock_unit.  */
@@ -4496,7 +4498,7 @@ st_write_done (st_parameter_dt *dtp)
 	  unlock_unit (dtp->u.p.current_unit);
 	}
       else
-	st_write_done_worker (dtp);  /* Calls unlock_unit.  */
+	st_write_done_worker (dtp, true);  /* Calls unlock_unit.  */
     }
 
   library_end ();

From a32b7d03210f1763a5ccd017181ad88bd95b07d1 Mon Sep 17 00:00:00 2001
From: Patrick Palka <ppalka@redhat.com>
Date: Mon, 3 May 2021 13:35:37 -0400
Subject: [PATCH 050/164] c++: base-clause parsing and implicit 'this'
 [PR100362]

My r11-6815 change to defer access checking when processing a
base-clause removed a pair of pushclass / popclass calls that seemed to
be unnecessary now that we'd also defer access checking while parsing
the base-clause.

But it turns out these calls make a difference in the below testcase,
where we have a local class whose base-clause implicitly uses the 'this'
of the enclosing class.  Before r11-6815, while parsing the base-clause
of the local class, maybe_resolve_dummy would fail to resolve the dummy
'this' object because the current scope would be the local class.  Now,
since the current scope is the lambda, maybe_resolve_dummy succeeds and
returns the 'this' for the enclosing class Qux.  Later, during deferred
instantiation of the local class, we get confused trying to resolve the
access of 'a_' through this non-dummy 'this'.

So this patch just reinstates the calls to pushclass / popclass that
were removed in r11-6815.

gcc/cp/ChangeLog:

	PR c++/100362
	* parser.c (cp_parser_class_head): Reinstate calls to pushclass
	and popclass when parsing the base-clause that were removed in
	r11-6815.

gcc/testsuite/ChangeLog:

	PR c++/100362
	* g++.dg/cpp1y/lambda-generic-100362.C: New test.

(cherry picked from commit 2a6fc19e655e696bf0df9b7aaedf9848b23f07f3)
---
 gcc/cp/parser.c                               |  8 +++++-
 .../g++.dg/cpp1y/lambda-generic-100362.C      | 25 +++++++++++++++++++
 2 files changed, 32 insertions(+), 1 deletion(-)
 create mode 100644 gcc/testsuite/g++.dg/cpp1y/lambda-generic-100362.C

diff --git a/gcc/cp/parser.c b/gcc/cp/parser.c
index fba516efa23d5..a3dae3164ce14 100644
--- a/gcc/cp/parser.c
+++ b/gcc/cp/parser.c
@@ -25680,7 +25680,13 @@ cp_parser_class_head (cp_parser* parser,
      until the entire list has been seen, as per [class.access.general].  */
   push_deferring_access_checks (dk_deferred);
   if (cp_lexer_next_token_is (parser->lexer, CPP_COLON))
-    bases = cp_parser_base_clause (parser);
+    {
+      if (type)
+	pushclass (type);
+      bases = cp_parser_base_clause (parser);
+      if (type)
+	popclass ();
+    }
   else
     bases = NULL_TREE;
 
diff --git a/gcc/testsuite/g++.dg/cpp1y/lambda-generic-100362.C b/gcc/testsuite/g++.dg/cpp1y/lambda-generic-100362.C
new file mode 100644
index 0000000000000..283c2c9477ef0
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp1y/lambda-generic-100362.C
@@ -0,0 +1,25 @@
+// PR c++/100362
+// { dg-do compile { target c++14 } }
+
+template <class>
+struct Qux {
+  struct A { } a_;
+  A f();
+
+  void AsyncOp() {
+    [](auto) {
+      struct local : decltype(a_) {};
+      local ptr;
+    }(0);
+
+    [](auto) {
+      struct local : decltype(f()) {};
+      local ptr;
+    }(0);
+  }
+};
+
+void corge() {
+  Qux<int> qux;
+  qux.AsyncOp();
+}

From a7b9706482fbf241d57c090554cc9f0b19b57fa6 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Tue, 4 May 2021 00:18:36 +0000
Subject: [PATCH 051/164] Daily bump.

---
 gcc/DATESTAMP           |  2 +-
 gcc/cp/ChangeLog        | 10 ++++++++++
 gcc/testsuite/ChangeLog |  8 ++++++++
 libgfortran/ChangeLog   | 12 ++++++++++++
 4 files changed, 31 insertions(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 891293d2df122..a96c930f221a2 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210503
+20210504
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 0ac9d0673acea..7b1a09e529f6f 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,13 @@
+2021-05-03  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2021-05-03  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/100362
+	* parser.c (cp_parser_class_head): Reinstate calls to pushclass
+	and popclass when parsing the base-clause that were removed in
+	r11-6815.
+
 2021-04-29  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index e54ae674ab2e8..31fb63f4a0f3a 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,11 @@
+2021-05-03  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2021-05-03  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/100362
+	* g++.dg/cpp1y/lambda-generic-100362.C: New test.
+
 2021-04-30  Richard Biener  <rguenther@suse.de>
 
 	Backported from master:
diff --git a/libgfortran/ChangeLog b/libgfortran/ChangeLog
index 1aa357c6a5cbb..fbc9a1b472492 100644
--- a/libgfortran/ChangeLog
+++ b/libgfortran/ChangeLog
@@ -1,3 +1,15 @@
+2021-05-03  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-05-02  Tobias Burnus  <tobias@codesourcery.com>
+
+	PR libgomp/100352
+	* io/transfer.c (st_read_done_worker, st_write_done_worker): Add new
+	arg whether to unlock unit.
+	(st_read_done, st_write_done): Call it with true.
+	* io/async.c (async_io): Call it with false.
+	* io/io.h (st_write_done_worker, st_read_done_worker): Update prototype.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.

From da9c085ddbfe61e5954c8ec4e996240fa3a994c0 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Sun, 2 May 2021 14:17:23 +0200
Subject: [PATCH 052/164] nvptx: Fix up nvptx build against latest libstdc++
 [PR100375]

The r12-220-gd96db15967e78d7cecea3b1cf3169ceb924678ac change
deprecated some non-standard std::pair constructors and that apparently
broke nvptx.c build, where pseudo_node_t is std::pair<struct basic_block_def *, int>
and so nullptr (or NULL) needs to be used for the first argument of the
ctors instead of 0.

2021-05-02  Jakub Jelinek  <jakub@redhat.com>

	PR target/100375
	* config/nvptx/nvptx.c (nvptx_sese_pseudo): Use nullptr instead of 0
	as first argument of pseudo_node_t constructors.

(cherry picked from commit 7911a905276781c20f704f5a91b5125e0184d072)
---
 gcc/config/nvptx/nvptx.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/gcc/config/nvptx/nvptx.c b/gcc/config/nvptx/nvptx.c
index 794c5a69db03b..7a7a9130e8415 100644
--- a/gcc/config/nvptx/nvptx.c
+++ b/gcc/config/nvptx/nvptx.c
@@ -3682,9 +3682,9 @@ nvptx_sese_pseudo (basic_block me, bb_sese *sese, int depth, int dir,
   edge e;
   edge_iterator ei;
   int hi_back = depth;
-  pseudo_node_t node_back (0, depth);
+  pseudo_node_t node_back (nullptr, depth);
   int hi_child = depth;
-  pseudo_node_t node_child (0, depth);
+  pseudo_node_t node_child (nullptr, depth);
   basic_block child = NULL;
   unsigned num_children = 0;
   int usd = -dir * sese->dir;
@@ -3751,7 +3751,7 @@ nvptx_sese_pseudo (basic_block me, bb_sese *sese, int depth, int dir,
       else
 	{ /* Fallen off graph, backlink to entry node.  */
 	  hi_back = 0;
-	  node_back = pseudo_node_t (0, 0);
+	  node_back = pseudo_node_t (nullptr, 0);
 	}
     }
 
@@ -3772,7 +3772,7 @@ nvptx_sese_pseudo (basic_block me, bb_sese *sese, int depth, int dir,
       else
 	{
 	  /* back edge to entry node */
-	  sese->push (pseudo_node_t (0, 0));
+	  sese->push (pseudo_node_t (nullptr, 0));
 	}
     }
   
@@ -3781,7 +3781,7 @@ nvptx_sese_pseudo (basic_block me, bb_sese *sese, int depth, int dir,
   if (!sese->brackets.length () || !edges || !edges->length ())
     {
       hi_back = 0;
-      node_back = pseudo_node_t (0, 0);
+      node_back = pseudo_node_t (nullptr, 0);
       sese->push (node_back);
     }
 

From e71d9316e002e2705738b975185786907443453c Mon Sep 17 00:00:00 2001
From: Patrick Palka <ppalka@redhat.com>
Date: Fri, 30 Apr 2021 11:05:22 -0400
Subject: [PATCH 053/164] libstdc++: Implement proposed resolution for LWG 3532

libstdc++-v3/ChangeLog:

	* include/std/ranges (split_view::_InnerIter::operator++):
	Depend on _Base instead of _Vp directly, as per LWG 3532.

(cherry picked from commit 71834be5b68e0c9839f0647e1bbf1eec4e4bbf49)
---
 libstdc++-v3/include/std/ranges | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/libstdc++-v3/include/std/ranges b/libstdc++-v3/include/std/ranges
index 09115e9b45f99..606ce81f824a4 100644
--- a/libstdc++-v3/include/std/ranges
+++ b/libstdc++-v3/include/std/ranges
@@ -2895,7 +2895,7 @@ namespace views::__adaptor
 	  constexpr decltype(auto)
 	  operator++(int)
 	  {
-	    if constexpr (forward_range<_Vp>)
+	    if constexpr (forward_range<_Base>)
 	      {
 		auto __tmp = *this;
 		++*this;

From 2a9847e9fe2f952c32217b104e148668ba80ec47 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Wed, 5 May 2021 00:18:33 +0000
Subject: [PATCH 054/164] Daily bump.

---
 gcc/ChangeLog          | 9 +++++++++
 gcc/DATESTAMP          | 2 +-
 libstdc++-v3/ChangeLog | 8 ++++++++
 3 files changed, 18 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 50441316a50f1..4e1f11d250f8e 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,12 @@
+2021-05-04  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-02  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/100375
+	* config/nvptx/nvptx.c (nvptx_sese_pseudo): Use nullptr instead of 0
+	as first argument of pseudo_node_t constructors.
+
 2021-05-01  Maciej W. Rozycki  <macro@orcam.me.uk>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index a96c930f221a2..eb085aa83ab23 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210504
+20210505
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index c76d4817517d6..428f42cd87efe 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,11 @@
+2021-05-04  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2021-04-30  Patrick Palka  <ppalka@redhat.com>
+
+	* include/std/ranges (split_view::_InnerIter::operator++):
+	Depend on _Base instead of _Vp directly, as per LWG 3532.
+
 2021-04-30  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

From a0302c041b108cf680189bd8e79e9d4478c4e22c Mon Sep 17 00:00:00 2001
From: Richard Biener <rguenther@suse.de>
Date: Tue, 4 May 2021 10:07:35 +0200
Subject: [PATCH 055/164] tree-optimization/100329 - avoid reassociating asm
 goto defs

This avoids reassociating asm goto defs because we have no idea
on which outgoing edge to insert defs.

2021-05-04  Richard Biener  <rguenther@suse.de>

	PR tree-optimization/100329
	* tree-ssa-reassoc.c (can_reassociate_p): Do not reassociate
	asm goto defs.
	(insert_stmt_after): Assert we're not running into asm goto.

	* gcc.dg/torture/pr100329.c: New testcase.

(cherry picked from commit a310bb73edc9548e08d1fa28e7a56246caf27757)
---
 gcc/testsuite/gcc.dg/torture/pr100329.c | 16 ++++++++++++++++
 gcc/tree-ssa-reassoc.c                  | 10 ++++++++++
 2 files changed, 26 insertions(+)
 create mode 100644 gcc/testsuite/gcc.dg/torture/pr100329.c

diff --git a/gcc/testsuite/gcc.dg/torture/pr100329.c b/gcc/testsuite/gcc.dg/torture/pr100329.c
new file mode 100644
index 0000000000000..b90700dd5f0c0
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/torture/pr100329.c
@@ -0,0 +1,16 @@
+/* { dg-do compile } */
+/* { dg-additional-options "--param tree-reassoc-width=2" } */
+
+unsigned int a0;
+
+unsigned int
+foo (unsigned int a1, unsigned int a2)
+{
+  unsigned int x;
+
+  asm goto ("" : "=r" (x) : : : lab);
+  a0 = x;
+
+ lab:
+  return x + a1 + a2 + 1;
+}
diff --git a/gcc/tree-ssa-reassoc.c b/gcc/tree-ssa-reassoc.c
index 8e2a4896d14b7..359367c9382c1 100644
--- a/gcc/tree-ssa-reassoc.c
+++ b/gcc/tree-ssa-reassoc.c
@@ -1446,6 +1446,10 @@ insert_stmt_after (gimple *stmt, gimple *insert_point)
       gsi_insert_after (&gsi, stmt, GSI_NEW_STMT);
       return;
     }
+  else if (gimple_code (insert_point) == GIMPLE_ASM)
+    /* We have no idea where to insert - it depends on where the
+       uses will be placed.  */
+    gcc_unreachable ();
   else
     /* We assume INSERT_POINT is a SSA_NAME_DEF_STMT of some SSA_NAME,
        thus if it must end a basic block, it should be a call that can
@@ -5893,6 +5897,12 @@ can_reassociate_p (tree op)
   tree type = TREE_TYPE (op);
   if (TREE_CODE (op) == SSA_NAME && SSA_NAME_OCCURS_IN_ABNORMAL_PHI (op))
     return false;
+  /* Make sure asm goto outputs do not participate in reassociation since
+     we have no way to find an insertion place after asm goto.  */
+  if (TREE_CODE (op) == SSA_NAME
+      && gimple_code (SSA_NAME_DEF_STMT (op)) == GIMPLE_ASM
+      && gimple_asm_nlabels (as_a <gasm *> (SSA_NAME_DEF_STMT (op))) != 0)
+    return false;
   if ((ANY_INTEGRAL_TYPE_P (type) && TYPE_OVERFLOW_WRAPS (type))
       || NON_SAT_FIXED_POINT_TYPE_P (type)
       || (flag_associative_math && FLOAT_TYPE_P (type)))

From 12ff76b01f07fff049cbfeb0ef536ce42f1f178b Mon Sep 17 00:00:00 2001
From: Richard Biener <rguenther@suse.de>
Date: Tue, 4 May 2021 13:39:14 +0200
Subject: [PATCH 056/164] tree-optimization/100414 - compute dominance info in
 phiopt

phiopt now has dominator queries but fails to compute dominance
info.

2021-05-04  Richard Biener  <rguenther@suse.de>

	PR tree-optimization/100414
	* tree-ssa-phiopt.c (get_non_trapping): Do not compute dominance
	info here.
	(tree_ssa_phiopt_worker): But unconditionally here.

	* gcc.dg/pr100414.c: New testcase.

(cherry picked from commit 7a3897661151cf8cc77d11f7a98fc64259210748)
---
 gcc/testsuite/gcc.dg/pr100414.c | 9 +++++++++
 gcc/tree-ssa-phiopt.c           | 5 ++---
 2 files changed, 11 insertions(+), 3 deletions(-)
 create mode 100644 gcc/testsuite/gcc.dg/pr100414.c

diff --git a/gcc/testsuite/gcc.dg/pr100414.c b/gcc/testsuite/gcc.dg/pr100414.c
new file mode 100644
index 0000000000000..7876f6b56e9b3
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr100414.c
@@ -0,0 +1,9 @@
+/* { dg-do compile } */
+/* { dg-options "-O -fno-tree-dce -fno-tree-dse -fchecking" } */
+
+int i;
+void
+foo (void)
+{
+  i &= i && __builtin_bswap16 (i);
+}
diff --git a/gcc/tree-ssa-phiopt.c b/gcc/tree-ssa-phiopt.c
index aa48f447d23c4..5831a7764a49e 100644
--- a/gcc/tree-ssa-phiopt.c
+++ b/gcc/tree-ssa-phiopt.c
@@ -174,6 +174,8 @@ tree_ssa_phiopt_worker (bool do_store_elim, bool do_hoist_loads, bool early_p)
   bool cfgchanged = false;
   hash_set<tree> *nontrap = 0;
 
+  calculate_dominance_info (CDI_DOMINATORS);
+
   if (do_store_elim)
     /* Calculate the set of non-trapping memory accesses.  */
     nontrap = get_non_trapping ();
@@ -2438,9 +2440,6 @@ get_non_trapping (void)
 {
   nt_call_phase = 0;
   hash_set<tree> *nontrap = new hash_set<tree>;
-  /* We're going to do a dominator walk, so ensure that we have
-     dominance information.  */
-  calculate_dominance_info (CDI_DOMINATORS);
 
   nontrapping_dom_walker (CDI_DOMINATORS, nontrap)
     .walk (cfun->cfg->x_entry_block_ptr);

From d941869a62060182d5ffe265144bdd87d8943c7a Mon Sep 17 00:00:00 2001
From: Richard Biener <rguenther@suse.de>
Date: Wed, 28 Apr 2021 09:34:03 +0200
Subject: [PATCH 057/164] ipa/100308 - properly update the callgraph when
 pruning EH in IPA CP

This makes sure to fall into the delete_unreachable_blocks_update_callgraph
handling to remove blocks becoming unreachable when removing EH edges
by tracking blocks to need EH cleanup and doing that after releasing
dominance info.

This fixes an ICE seen with gfortran.dg/gomp/pr88933.f90 when enhancing
DSE.

2021-04-28  Richard Biener  <rguenther@suse.de>

	PR ipa/100308
	* ipa-prop.c (ipcp_modif_dom_walker::before_dom_children):
	Track blocks to cleanup EH in new m_need_eh_cleanup.
	(ipcp_modif_dom_walker::cleanup_eh): New.
	(ipcp_transform_function): Release dominator info before
	doing EH cleanup.

(cherry picked from commit 8ddce3f7d0db060885df24e41dd289173ec774a0)
---
 gcc/ipa-prop.c | 23 +++++++++++++----------
 1 file changed, 13 insertions(+), 10 deletions(-)

diff --git a/gcc/ipa-prop.c b/gcc/ipa-prop.c
index 010c43f33e83d..02c483b10dd16 100644
--- a/gcc/ipa-prop.c
+++ b/gcc/ipa-prop.c
@@ -5514,17 +5514,20 @@ class ipcp_modif_dom_walker : public dom_walker
   ipcp_modif_dom_walker (struct ipa_func_body_info *fbi,
 			 vec<ipa_param_descriptor, va_gc> *descs,
 			 struct ipa_agg_replacement_value *av,
-			 bool *sc, bool *cc)
+			 bool *sc)
     : dom_walker (CDI_DOMINATORS), m_fbi (fbi), m_descriptors (descs),
-      m_aggval (av), m_something_changed (sc), m_cfg_changed (cc) {}
+      m_aggval (av), m_something_changed (sc) {}
 
   virtual edge before_dom_children (basic_block);
+  bool cleanup_eh ()
+    { return gimple_purge_all_dead_eh_edges (m_need_eh_cleanup); }
 
 private:
   struct ipa_func_body_info *m_fbi;
   vec<ipa_param_descriptor, va_gc> *m_descriptors;
   struct ipa_agg_replacement_value *m_aggval;
-  bool *m_something_changed, *m_cfg_changed;
+  bool *m_something_changed;
+  auto_bitmap m_need_eh_cleanup;
 };
 
 edge
@@ -5616,9 +5619,8 @@ ipcp_modif_dom_walker::before_dom_children (basic_block bb)
 	}
 
       *m_something_changed = true;
-      if (maybe_clean_eh_stmt (stmt)
-	  && gimple_purge_dead_eh_edges (gimple_bb (stmt)))
-	*m_cfg_changed = true;
+      if (maybe_clean_eh_stmt (stmt))
+	bitmap_set_bit (m_need_eh_cleanup, bb->index);
     }
   return NULL;
 }
@@ -5876,7 +5878,7 @@ ipcp_transform_function (struct cgraph_node *node)
   struct ipa_func_body_info fbi;
   struct ipa_agg_replacement_value *aggval;
   int param_count;
-  bool cfg_changed = false, something_changed = false;
+  bool something_changed = false;
 
   gcc_checking_assert (cfun);
   gcc_checking_assert (current_function_decl);
@@ -5907,15 +5909,16 @@ ipcp_transform_function (struct cgraph_node *node)
   vec_safe_grow_cleared (descriptors, param_count, true);
   ipa_populate_param_decls (node, *descriptors);
   calculate_dominance_info (CDI_DOMINATORS);
-  ipcp_modif_dom_walker (&fbi, descriptors, aggval, &something_changed,
-			 &cfg_changed).walk (ENTRY_BLOCK_PTR_FOR_FN (cfun));
+  ipcp_modif_dom_walker walker (&fbi, descriptors, aggval, &something_changed);
+  walker.walk (ENTRY_BLOCK_PTR_FOR_FN (cfun));
+  free_dominance_info (CDI_DOMINATORS);
+  bool cfg_changed = walker.cleanup_eh ();
 
   int i;
   struct ipa_bb_info *bi;
   FOR_EACH_VEC_ELT (fbi.bb_infos, i, bi)
     free_ipa_bb_info (bi);
   fbi.bb_infos.release ();
-  free_dominance_info (CDI_DOMINATORS);
 
   ipcp_transformation *s = ipcp_transformation_sum->get (node);
   s->agg_values = NULL;

From 3ac56ea477ec72340ebbce44af93c7712b579109 Mon Sep 17 00:00:00 2001
From: Richard Biener <rguenther@suse.de>
Date: Tue, 27 Apr 2021 09:41:38 +0200
Subject: [PATCH 058/164] tree-optimization/100278 - handle mismatched code in
 TBAA adjust of PRE

PRE has code to adjust TBAA behavior for refs that expects the base
operation code to match.  The testcase shows a case where we have
a VAR_DECL vs. a MEM_REF so add code to give up in such cases.

2021-04-27  Richard Biener  <rguenther@suse.de>

	PR tree-optimization/100278
	* tree-ssa-pre.c (compute_avail): Give up when we cannot
	adjust TBAA beacuse of mismatching bases.

	* gcc.dg/tree-ssa/pr100278.c: New testcase.

(cherry picked from commit acfe5290406cc70485df8899d14982278a9371f8)
---
 gcc/testsuite/gcc.dg/tree-ssa/pr100278.c | 17 +++++++++++++++++
 gcc/tree-ssa-pre.c                       | 10 ++++++++++
 2 files changed, 27 insertions(+)
 create mode 100644 gcc/testsuite/gcc.dg/tree-ssa/pr100278.c

diff --git a/gcc/testsuite/gcc.dg/tree-ssa/pr100278.c b/gcc/testsuite/gcc.dg/tree-ssa/pr100278.c
new file mode 100644
index 0000000000000..8d702284c3ae9
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/tree-ssa/pr100278.c
@@ -0,0 +1,17 @@
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+void a()
+{
+#if defined __s390__
+  register int b asm("r5");
+#elif defined __x86_64__
+  register int b asm("eax");
+#else
+  volatile int b;
+#endif
+  if (b)
+    b = 1;
+  for (; b;)
+    ;
+}
diff --git a/gcc/tree-ssa-pre.c b/gcc/tree-ssa-pre.c
index 91dd49200c302..5a710db9795c7 100644
--- a/gcc/tree-ssa-pre.c
+++ b/gcc/tree-ssa-pre.c
@@ -4152,6 +4152,16 @@ compute_avail (void)
 		      if (ref->set == set
 			  || alias_set_subset_of (set, ref->set))
 			;
+		      else if (ref1->opcode != ref2->opcode
+			       || (ref1->opcode != MEM_REF
+				   && ref1->opcode != TARGET_MEM_REF))
+			{
+			  /* With mismatching base opcodes or bases
+			     other than MEM_REF or TARGET_MEM_REF we
+			     can't do any easy TBAA adjustment.  */
+			  operands.release ();
+			  continue;
+			}
 		      else if (alias_set_subset_of (ref->set, set))
 			{
 			  ref->set = set;

From c980fbf5505dc2f50136d501b67dc3fbf4b08b0d Mon Sep 17 00:00:00 2001
From: Richard Biener <rguenther@suse.de>
Date: Thu, 29 Apr 2021 11:52:08 +0200
Subject: [PATCH 059/164] tree-optimization/100253 - fix bogus aligned
 vectorized loads/stores

At some point DR_MISALIGNMENT was supposed to be -1 when the
access was not element aligned.  That's obviously not true at this
point so this adjusts both store and load vectorizing to no longer
assume this which in turn allows simplifying the code.

2021-04-29  Richard Biener  <rguenther@suse.de>

	PR tree-optimization/100253
	* tree-vect-stmts.c (vectorizable_load): Do not assume
	element alignment when DR_MISALIGNMENT is -1.
	(vectorizable_store): Likewise.

	* g++.dg/pr100253.C: New testcase.

(cherry picked from commit af4ccaa7515b8e72449448c509916575831e6292)
---
 gcc/testsuite/g++.dg/pr100253.C | 33 +++++++++++++++++++++++++++++++++
 gcc/tree-vect-stmts.c           | 18 ++++--------------
 2 files changed, 37 insertions(+), 14 deletions(-)
 create mode 100644 gcc/testsuite/g++.dg/pr100253.C

diff --git a/gcc/testsuite/g++.dg/pr100253.C b/gcc/testsuite/g++.dg/pr100253.C
new file mode 100644
index 0000000000000..0102caa7df863
--- /dev/null
+++ b/gcc/testsuite/g++.dg/pr100253.C
@@ -0,0 +1,33 @@
+/* { dg-do run } */
+/* { dg-options "-O2 -fno-tree-bit-ccp -ftree-slp-vectorize" } */
+
+#include <vector>
+
+struct T
+{
+};
+
+struct S
+{
+  std::vector < std::vector < T > > v;
+  char x;
+  char y[16];
+  char z[16];
+};
+
+S s, g[1];
+
+void
+foo (char *buf)
+{
+  s = g[*buf];
+}
+
+char c;
+
+int
+main ()
+{
+  foo (&c);
+  return 0;
+}
diff --git a/gcc/tree-vect-stmts.c b/gcc/tree-vect-stmts.c
index 4c01e82ff394f..bd2a1c89e6708 100644
--- a/gcc/tree-vect-stmts.c
+++ b/gcc/tree-vect-stmts.c
@@ -8166,6 +8166,7 @@ vectorizable_store (vec_info *vinfo,
 		  && TREE_CODE (dataref_ptr) == SSA_NAME)
 		set_ptr_info_alignment (get_ptr_info (dataref_ptr), align,
 					misalign);
+	      align = least_bit_hwi (misalign | align);
 
 	      if (memory_access_type == VMAT_CONTIGUOUS_REVERSE)
 		{
@@ -8187,7 +8188,6 @@ vectorizable_store (vec_info *vinfo,
 	      /* Arguments are ready.  Create the new vector stmt.  */
 	      if (final_mask)
 		{
-		  align = least_bit_hwi (misalign | align);
 		  tree ptr = build_int_cst (ref_type, align * BITS_PER_UNIT);
 		  gcall *call
 		    = gimple_build_call_internal (IFN_MASK_STORE, 4,
@@ -8202,7 +8202,6 @@ vectorizable_store (vec_info *vinfo,
 		  tree final_len
 		    = vect_get_loop_len (loop_vinfo, loop_lens,
 					 vec_num * ncopies, vec_num * j + i);
-		  align = least_bit_hwi (misalign | align);
 		  tree ptr = build_int_cst (ref_type, align * BITS_PER_UNIT);
 		  machine_mode vmode = TYPE_MODE (vectype);
 		  opt_machine_mode new_ovmode
@@ -8241,14 +8240,10 @@ vectorizable_store (vec_info *vinfo,
 					  : build_int_cst (ref_type, 0));
 		  if (aligned_access_p (first_dr_info))
 		    ;
-		  else if (DR_MISALIGNMENT (first_dr_info) == -1)
-		    TREE_TYPE (data_ref)
-		      = build_aligned_type (TREE_TYPE (data_ref),
-					    align * BITS_PER_UNIT);
 		  else
 		    TREE_TYPE (data_ref)
 		      = build_aligned_type (TREE_TYPE (data_ref),
-					    TYPE_ALIGN (elem_type));
+					    align * BITS_PER_UNIT);
 		  vect_copy_ref_info (data_ref, DR_REF (first_dr_info->dr));
 		  new_stmt = gimple_build_assign (data_ref, vec_oprnd);
 		  vect_finish_stmt_generation (vinfo, stmt_info, new_stmt, gsi);
@@ -9452,10 +9447,10 @@ vectorizable_load (vec_info *vinfo,
 			&& TREE_CODE (dataref_ptr) == SSA_NAME)
 		      set_ptr_info_alignment (get_ptr_info (dataref_ptr),
 					      align, misalign);
+		    align = least_bit_hwi (misalign | align);
 
 		    if (final_mask)
 		      {
-			align = least_bit_hwi (misalign | align);
 			tree ptr = build_int_cst (ref_type,
 						  align * BITS_PER_UNIT);
 			gcall *call
@@ -9472,7 +9467,6 @@ vectorizable_load (vec_info *vinfo,
 			  = vect_get_loop_len (loop_vinfo, loop_lens,
 					       vec_num * ncopies,
 					       vec_num * j + i);
-			align = least_bit_hwi (misalign | align);
 			tree ptr = build_int_cst (ref_type,
 						  align * BITS_PER_UNIT);
 			gcall *call
@@ -9548,14 +9542,10 @@ vectorizable_load (vec_info *vinfo,
 			  = fold_build2 (MEM_REF, ltype, dataref_ptr, offset);
 			if (alignment_support_scheme == dr_aligned)
 			  ;
-			else if (DR_MISALIGNMENT (first_dr_info) == -1)
-			  TREE_TYPE (data_ref)
-			    = build_aligned_type (TREE_TYPE (data_ref),
-						  align * BITS_PER_UNIT);
 			else
 			  TREE_TYPE (data_ref)
 			    = build_aligned_type (TREE_TYPE (data_ref),
-						  TYPE_ALIGN (elem_type));
+						  align * BITS_PER_UNIT);
 			if (ltype != vectype)
 			  {
 			    vect_copy_ref_info (data_ref,

From dcb23f439f3cf5601fb8bf49889accd16f3b30a1 Mon Sep 17 00:00:00 2001
From: Eric Botcazou <ebotcazou@adacore.com>
Date: Wed, 5 May 2021 16:50:55 +0200
Subject: [PATCH 060/164] Fix PR rtl-optimization/100411

This is the bootstrap failure of GCC 11 on MinGW64 configured with --enable-
tune=nocona.  The bottom line is that SEH does not support CFI for epilogues
but the x86 back-end nevertheless attaches it to instructions, so we have to
filter it out and this is done by detecting the end of the prologue by means
of the NOTE_INSN_PROLOGUE_END note.

But the compiler manages to generate a second epilogue before this note in
the RTL stream and this fools the aforementioned logic.  The root cause is
cross-jumping, which inserts a jump before the end of the prologue, in fact
just before the note; the rest (CFG cleanup, BB reordering, etc) is downhill
from there.

gcc/
	PR rtl-optimization/100411
	* cfgcleanup.c (try_crossjump_to_edge): Also skip end of prologue
	and beginning of function markers.
---
 gcc/cfgcleanup.c | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/gcc/cfgcleanup.c b/gcc/cfgcleanup.c
index 260a896ac4863..4086b64758522 100644
--- a/gcc/cfgcleanup.c
+++ b/gcc/cfgcleanup.c
@@ -2157,7 +2157,11 @@ try_crossjump_to_edge (int mode, edge e1, edge e2,
   if (NOTE_INSN_BASIC_BLOCK_P (newpos1))
     newpos1 = NEXT_INSN (newpos1);
 
-  while (DEBUG_INSN_P (newpos1))
+  /* Skip also prologue and function markers.  */
+  while (DEBUG_INSN_P (newpos1)
+	 || (NOTE_P (newpos1)
+	     && (NOTE_KIND (newpos1) == NOTE_INSN_PROLOGUE_END
+		 || NOTE_KIND (newpos1) == NOTE_INSN_FUNCTION_BEG)))
     newpos1 = NEXT_INSN (newpos1);
 
   redirect_from = split_block (src1, PREV_INSN (newpos1))->src;

From fcad2894215879b740dce74e72247b6efa326397 Mon Sep 17 00:00:00 2001
From: Stefan Schulze Frielinghaus <stefansf@linux.ibm.com>
Date: Wed, 5 May 2021 17:06:52 +0200
Subject: [PATCH 061/164] PR rtl-optimization/100263: Ensure register can
 change mode

For move2add_valid_value_p we also have to ask the target whether a
register can be accessed in a different mode than it was set before.

gcc/ChangeLog:

	PR rtl-optimization/100263
	* postreload.c (move2add_valid_value_p): Ensure register can
	change mode.

(cherry picked from commit bb283170e7a1f39bf533651418daf10ad18eccfc)
---
 gcc/postreload.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/gcc/postreload.c b/gcc/postreload.c
index dc67643384d67..60a622dbaf3e9 100644
--- a/gcc/postreload.c
+++ b/gcc/postreload.c
@@ -1725,7 +1725,8 @@ move2add_valid_value_p (int regno, scalar_int_mode mode)
     {
       scalar_int_mode old_mode;
       if (!is_a <scalar_int_mode> (reg_mode[regno], &old_mode)
-	  || !MODES_OK_FOR_MOVE2ADD (mode, old_mode))
+	  || !MODES_OK_FOR_MOVE2ADD (mode, old_mode)
+	  || !REG_CAN_CHANGE_MODE_P (regno, old_mode, mode))
 	return false;
       /* The value loaded into regno in reg_mode[regno] is also valid in
 	 mode after truncation only if (REG:mode regno) is the lowpart of

From 81c705e64d462eae963a469f2173e7d895dd2030 Mon Sep 17 00:00:00 2001
From: Patrick Palka <ppalka@redhat.com>
Date: Wed, 5 May 2021 12:07:32 -0400
Subject: [PATCH 062/164] libstdc++: Implement LWG 3517/3520 for
 join_view/transform_view

libstdc++-v3/ChangeLog:

	* include/std/ranges (transform_view::_Iterator::iter_swap):
	Remove as per LWG 3520.
	(join_view::_Iterator::iter_swap): Add indirectly_swappable
	constraint as per LWG 3517.

(cherry picked from commit 2663727d853438ee4d67b200a08f94a318745486)
---
 libstdc++-v3/include/std/ranges | 7 +------
 1 file changed, 1 insertion(+), 6 deletions(-)

diff --git a/libstdc++-v3/include/std/ranges b/libstdc++-v3/include/std/ranges
index 606ce81f824a4..af3c108bec890 100644
--- a/libstdc++-v3/include/std/ranges
+++ b/libstdc++-v3/include/std/ranges
@@ -1578,12 +1578,6 @@ namespace views::__adaptor
 	      return *__i;
 	  }
 
-	  friend constexpr void
-	  iter_swap(const _Iterator& __x, const _Iterator& __y)
-	    noexcept(noexcept(ranges::iter_swap(__x._M_current, __y._M_current)))
-	    requires indirectly_swappable<_Base_iter>
-	  { return ranges::iter_swap(__x._M_current, __y._M_current); }
-
 	  friend _Iterator<!_Const>;
 	  template<bool> friend struct _Sentinel;
 	};
@@ -2460,6 +2454,7 @@ namespace views::__adaptor
 	  friend constexpr void
 	  iter_swap(const _Iterator& __x, const _Iterator& __y)
 	    noexcept(noexcept(ranges::iter_swap(__x._M_inner, __y._M_inner)))
+	    requires indirectly_swappable<_Inner_iter>
 	  { return ranges::iter_swap(__x._M_inner, __y._M_inner); }
 
 	  friend _Iterator<!_Const>;

From ba013672f723f87f0c3b0c685dda5b3b2f1b3f3a Mon Sep 17 00:00:00 2001
From: Harald Anlauf <anlauf@gmx.de>
Date: Wed, 5 May 2021 15:25:50 +0200
Subject: [PATCH 063/164] PR fortran/100274 - ICE in gfc_conv_procedure_call,
 at fortran/trans-expr.c:6131

When the check for the length of formal and actual character arguments
found a mismatch and emitted a warning, it would skip further checks
like that could lead to errors.  Fix that by continuing the checking.
Also catch a NULL pointer dereference.

gcc/fortran/ChangeLog:

	PR fortran/100274
	* interface.c (gfc_compare_actual_formal): Continue checks after
	emitting warning for argument length mismatch.
	* trans-expr.c (gfc_conv_procedure_call): Check for NULL pointer
	dereference.

gcc/testsuite/ChangeLog:

	PR fortran/100274
	* gfortran.dg/argument_checking_25.f90: New test.

(cherry picked from commit a8b79cc939d6786293f654c42a2d1b0ab040de0e)
---
 gcc/fortran/interface.c                            | 11 +++++++----
 gcc/fortran/trans-expr.c                           |  1 +
 gcc/testsuite/gfortran.dg/argument_checking_25.f90 | 12 ++++++++++++
 3 files changed, 20 insertions(+), 4 deletions(-)
 create mode 100644 gcc/testsuite/gfortran.dg/argument_checking_25.f90

diff --git a/gcc/fortran/interface.c b/gcc/fortran/interface.c
index 6073612355093..9e3e8aa9da9e6 100644
--- a/gcc/fortran/interface.c
+++ b/gcc/fortran/interface.c
@@ -3255,10 +3255,13 @@ gfc_compare_actual_formal (gfc_actual_arglist **ap, gfc_formal_arglist *formal,
 	  && f->sym->attr.flavor != FL_PROCEDURE)
 	{
 	  if (a->expr->ts.type == BT_CHARACTER && !f->sym->as && where)
-	    gfc_warning (0, "Character length of actual argument shorter "
-			 "than of dummy argument %qs (%lu/%lu) at %L",
-			 f->sym->name, actual_size, formal_size,
-			 &a->expr->where);
+	    {
+	      gfc_warning (0, "Character length of actual argument shorter "
+			   "than of dummy argument %qs (%lu/%lu) at %L",
+			   f->sym->name, actual_size, formal_size,
+			   &a->expr->where);
+	      goto skip_size_check;
+	    }
           else if (where)
 	    {
 	      /* Emit a warning for -std=legacy and an error otherwise. */
diff --git a/gcc/fortran/trans-expr.c b/gcc/fortran/trans-expr.c
index 213f32b0a672f..a10170c7dff09 100644
--- a/gcc/fortran/trans-expr.c
+++ b/gcc/fortran/trans-expr.c
@@ -6128,6 +6128,7 @@ gfc_conv_procedure_call (gfc_se * se, gfc_symbol * sym,
 		      bool add_clobber;
 		      add_clobber = fsym && fsym->attr.intent == INTENT_OUT
 			&& !fsym->attr.allocatable && !fsym->attr.pointer
+			&& e->symtree && e->symtree->n.sym
 			&& !e->symtree->n.sym->attr.dimension
 			&& !e->symtree->n.sym->attr.pointer
 			&& !e->symtree->n.sym->attr.allocatable
diff --git a/gcc/testsuite/gfortran.dg/argument_checking_25.f90 b/gcc/testsuite/gfortran.dg/argument_checking_25.f90
new file mode 100644
index 0000000000000..e699160fee15c
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/argument_checking_25.f90
@@ -0,0 +1,12 @@
+! { dg-do compile }
+! PR fortran/100274 - ICE in gfc_conv_procedure_call, at fortran/trans-expr.c:6131
+
+program p
+  call s('y')   ! { dg-warning "Character length of actual argument" }
+contains
+  subroutine s(x)
+    character(8), intent(out) :: x
+  end
+end
+
+! { dg-error "in variable definition context"  " " { target *-*-* } 5 }

From e9a8d6852c966e0511f2cfe40224fd81cbeaae24 Mon Sep 17 00:00:00 2001
From: Eric Botcazou <ebotcazou@adacore.com>
Date: Wed, 5 May 2021 22:48:51 +0200
Subject: [PATCH 064/164] Fix PR target/100402

This is a regression for 64-bit Windows present from mainline down to the 9
branch and introduced by the fix for PR target/99234.  Again SEH, but with
a twist related to the way MinGW implements setjmp/longjmp, which turns out
to be piggybacked on SEH with recent versions of MinGW, i.e. the longjmp
performs a bona-fide unwinding of the stack, because it calls RtlUnwindEx
with the second argument initially passed to setjmp, which is the result of
__builtin_frame_address (0) in the MinGW header file:

  define setjmp(BUF) _setjmp((BUF), __builtin_frame_address (0))

This means that we directly expose the frame pointer to the SEH machinery
here (unlike with regular exception handling where we use an intermediate
CFA) and thus that we cannot do whatever we want with it.  The old code
would leave it unaligned, i.e. not multiple of 16, whereas the new code
aligns it, but this breaks for some reason; at least it appears that a
.seh_setframe directive with 0 as second argument always works, so the
fix aligns it this way.

gcc/
	PR target/100402
	* config/i386/i386.c (ix86_compute_frame_layout): For a SEH target,
	always return the establisher frame for __builtin_frame_address (0).
gcc/testsuite/
	* gcc.c-torture/execute/20210505-1.c: New test.
---
 gcc/config/i386/i386.c                        | 23 ++++++++++++--
 .../gcc.c-torture/execute/20210505-1.c        | 31 +++++++++++++++++++
 2 files changed, 51 insertions(+), 3 deletions(-)
 create mode 100644 gcc/testsuite/gcc.c-torture/execute/20210505-1.c

diff --git a/gcc/config/i386/i386.c b/gcc/config/i386/i386.c
index 7c41302c75b5a..3bec713a0e8af 100644
--- a/gcc/config/i386/i386.c
+++ b/gcc/config/i386/i386.c
@@ -6671,12 +6671,29 @@ ix86_compute_frame_layout (void)
 	 area, see the SEH code in config/i386/winnt.c for the rationale.  */
       frame->hard_frame_pointer_offset = frame->sse_reg_save_offset;
 
-      /* If we can leave the frame pointer where it is, do so.  Also, return
+      /* If we can leave the frame pointer where it is, do so; however return
 	 the establisher frame for __builtin_frame_address (0) or else if the
-	 frame overflows the SEH maximum frame size.  */
+	 frame overflows the SEH maximum frame size.
+
+	 Note that the value returned by __builtin_frame_address (0) is quite
+	 constrained, because setjmp is piggybacked on the SEH machinery with
+	 recent versions of MinGW:
+
+	  #    elif defined(__SEH__)
+	  #     if defined(__aarch64__) || defined(_ARM64_)
+	  #      define setjmp(BUF) _setjmp((BUF), __builtin_sponentry())
+	  #     elif (__MINGW_GCC_VERSION < 40702)
+	  #      define setjmp(BUF) _setjmp((BUF), mingw_getsp())
+	  #     else
+	  #      define setjmp(BUF) _setjmp((BUF), __builtin_frame_address (0))
+	  #     endif
+
+	 and the second argument passed to _setjmp, if not null, is forwarded
+	 to the TargetFrame parameter of RtlUnwindEx by longjmp (after it has
+	 built an ExceptionRecord on the fly describing the setjmp buffer).  */
       const HOST_WIDE_INT diff
 	= frame->stack_pointer_offset - frame->hard_frame_pointer_offset;
-      if (diff <= 255)
+      if (diff <= 255 && !crtl->accesses_prior_frames)
 	{
 	  /* The resulting diff will be a multiple of 16 lower than 255,
 	     i.e. at most 240 as required by the unwind data structure.  */
diff --git a/gcc/testsuite/gcc.c-torture/execute/20210505-1.c b/gcc/testsuite/gcc.c-torture/execute/20210505-1.c
new file mode 100644
index 0000000000000..10a2de07921b7
--- /dev/null
+++ b/gcc/testsuite/gcc.c-torture/execute/20210505-1.c
@@ -0,0 +1,31 @@
+/* PR target/100402 */
+/* Testcase by Hannes Domani <ssbssa@yahoo.de> */
+
+/* { dg-require-effective-target indirect_jumps } */
+
+#include <setjmp.h>
+#include <stdbool.h>
+
+static jmp_buf buf;
+static _Bool stop = false;
+
+void call_func (void(*func)(void))
+{
+  func ();
+}
+
+void func (void)
+{
+  stop = true;
+  longjmp (buf, 1);
+}
+
+int main (void)
+{
+  setjmp (buf);
+
+  while (!stop)
+    call_func (func);
+
+  return 0;
+}

From 6c9cf075f7fccadd70ae6ce1779612fc920758a0 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Thu, 6 May 2021 00:18:13 +0000
Subject: [PATCH 065/164] Daily bump.

---
 gcc/ChangeLog           | 72 +++++++++++++++++++++++++++++++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/fortran/ChangeLog   | 11 +++++++
 gcc/testsuite/ChangeLog | 44 +++++++++++++++++++++++++
 libstdc++-v3/ChangeLog  | 10 ++++++
 5 files changed, 138 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 4e1f11d250f8e..877007450d522 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,75 @@
+2021-05-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR target/100402
+	* config/i386/i386.c (ix86_compute_frame_layout): For a SEH target,
+	always return the establisher frame for __builtin_frame_address (0).
+
+2021-05-05  Stefan Schulze Frielinghaus  <stefansf@linux.ibm.com>
+
+	Backported from master:
+	2021-05-05  Stefan Schulze Frielinghaus  <stefansf@linux.ibm.com>
+
+	PR rtl-optimization/100263
+	* postreload.c (move2add_valid_value_p): Ensure register can
+	change mode.
+
+2021-05-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR rtl-optimization/100411
+	* cfgcleanup.c (try_crossjump_to_edge): Also skip end of prologue
+	and beginning of function markers.
+
+2021-05-05  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-04-29  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100253
+	* tree-vect-stmts.c (vectorizable_load): Do not assume
+	element alignment when DR_MISALIGNMENT is -1.
+	(vectorizable_store): Likewise.
+
+2021-05-05  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-04-27  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100278
+	* tree-ssa-pre.c (compute_avail): Give up when we cannot
+	adjust TBAA beacuse of mismatching bases.
+
+2021-05-05  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-04-29  Richard Biener  <rguenther@suse.de>
+
+	PR ipa/100308
+	* ipa-prop.c (ipcp_modif_dom_walker::before_dom_children):
+	Track blocks to cleanup EH in new m_need_eh_cleanup.
+	(ipcp_modif_dom_walker::cleanup_eh): New.
+	(ipcp_transform_function): Release dominator info before
+	doing EH cleanup.
+
+2021-05-05  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-05-04  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100414
+	* tree-ssa-phiopt.c (get_non_trapping): Do not compute dominance
+	info here.
+	(tree_ssa_phiopt_worker): But unconditionally here.
+
+2021-05-05  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-05-04  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100329
+	* tree-ssa-reassoc.c (can_reassociate_p): Do not reassociate
+	asm goto defs.
+	(insert_stmt_after): Assert we're not running into asm goto.
+
 2021-05-04  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index eb085aa83ab23..8e159d5342000 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210505
+20210506
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index 7dbb014463aca..b072f2b4eb921 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,14 @@
+2021-05-05  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2021-05-05  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/100274
+	* interface.c (gfc_compare_actual_formal): Continue checks after
+	emitting warning for argument length mismatch.
+	* trans-expr.c (gfc_conv_procedure_call): Check for NULL pointer
+	dereference.
+
 2021-04-29  Tobias Burnus  <tobias@codesourcery.com>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 31fb63f4a0f3a..ddc62a3956a42 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,47 @@
+2021-05-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc.c-torture/execute/20210505-1.c: New test.
+
+2021-05-05  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2021-05-05  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/100274
+	* gfortran.dg/argument_checking_25.f90: New test.
+
+2021-05-05  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-04-29  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100253
+	* g++.dg/pr100253.C: New testcase.
+
+2021-05-05  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-04-27  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100278
+	* gcc.dg/tree-ssa/pr100278.c: New testcase.
+
+2021-05-05  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-05-04  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100414
+	* gcc.dg/pr100414.c: New testcase.
+
+2021-05-05  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-05-04  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100329
+	* gcc.dg/torture/pr100329.c: New testcase.
+
 2021-05-03  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 428f42cd87efe..64f000ff22dd8 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,13 @@
+2021-05-05  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2021-05-05  Patrick Palka  <ppalka@redhat.com>
+
+	* include/std/ranges (transform_view::_Iterator::iter_swap):
+	Remove as per LWG 3520.
+	(join_view::_Iterator::iter_swap): Add indirectly_swappable
+	constraint as per LWG 3517.
+
 2021-05-04  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:

From 445ce3cfb6832ec838caa10f2337c3bd00213517 Mon Sep 17 00:00:00 2001
From: Ilya Leoshkevich <iii@linux.ibm.com>
Date: Mon, 26 Apr 2021 14:12:08 +0200
Subject: [PATCH 066/164] IBM Z: Handle hard registers in s390_md_asm_adjust()

gen_fprx2_to_tf() and gen_tf_to_fprx2() cannot handle hard registers,
since the subregs they create do not pass validation.  Change
s390_md_asm_adjust() to manually copy between hard VRs and FPRs instead
of using these two functions.

gcc/ChangeLog:

	PR target/100217
	* config/s390/s390.c (s390_hard_fp_reg_p): New function.
	(s390_md_asm_adjust): Handle hard registers.

gcc/testsuite/ChangeLog:

	PR target/100217
	* gcc.target/s390/vector/long-double-asm-in-out-hard-fp-reg.c: New test.
	* gcc.target/s390/vector/long-double-asm-inout-hard-fp-reg.c: New test.
---
 gcc/config/s390/s390.c                        | 52 +++++++++++++++++--
 .../long-double-asm-in-out-hard-fp-reg.c      | 33 ++++++++++++
 .../long-double-asm-inout-hard-fp-reg.c       | 31 +++++++++++
 3 files changed, 112 insertions(+), 4 deletions(-)
 create mode 100644 gcc/testsuite/gcc.target/s390/vector/long-double-asm-in-out-hard-fp-reg.c
 create mode 100644 gcc/testsuite/gcc.target/s390/vector/long-double-asm-inout-hard-fp-reg.c

diff --git a/gcc/config/s390/s390.c b/gcc/config/s390/s390.c
index a9c945c5ee9c3..88361f98c7ef0 100644
--- a/gcc/config/s390/s390.c
+++ b/gcc/config/s390/s390.c
@@ -16754,6 +16754,23 @@ f_constraint_p (const char *constraint)
   return seen_f_p && !seen_v_p;
 }
 
+/* Return TRUE iff X is a hard floating-point (and not a vector) register.  */
+
+static bool
+s390_hard_fp_reg_p (rtx x)
+{
+  if (!(REG_P (x) && HARD_REGISTER_P (x) && REG_ATTRS (x)))
+    return false;
+
+  tree decl = REG_EXPR (x);
+  if (!(HAS_DECL_ASSEMBLER_NAME_P (decl) && DECL_ASSEMBLER_NAME_SET_P (decl)))
+    return false;
+
+  const char *name = IDENTIFIER_POINTER (DECL_ASSEMBLER_NAME (decl));
+
+  return name[0] == '*' && name[1] == 'f';
+}
+
 /* Implement TARGET_MD_ASM_ADJUST hook in order to fix up "f"
    constraints when long doubles are stored in vector registers.  */
 
@@ -16787,9 +16804,24 @@ s390_md_asm_adjust (vec<rtx> &outputs, vec<rtx> &inputs,
       gcc_assert (allows_reg);
       gcc_assert (!is_inout);
       /* Copy output value from a FPR pair into a vector register.  */
-      rtx fprx2 = gen_reg_rtx (FPRX2mode);
+      rtx fprx2;
       push_to_sequence2 (after_md_seq, after_md_end);
-      emit_insn (gen_fprx2_to_tf (outputs[i], fprx2));
+      if (s390_hard_fp_reg_p (outputs[i]))
+	{
+	  fprx2 = gen_rtx_REG (FPRX2mode, REGNO (outputs[i]));
+	  /* The first half is already at the correct location, copy only the
+	   * second one.  Use the UNSPEC pattern instead of the SUBREG one,
+	   * since s390_can_change_mode_class() rejects
+	   * (subreg:DF (reg:TF %fN) 8) and thus subreg validation fails.  */
+	  rtx v1 = gen_rtx_REG (V2DFmode, REGNO (outputs[i]));
+	  rtx v3 = gen_rtx_REG (V2DFmode, REGNO (outputs[i]) + 1);
+	  emit_insn (gen_vec_permiv2df (v1, v1, v3, const0_rtx));
+	}
+      else
+	{
+	  fprx2 = gen_reg_rtx (FPRX2mode);
+	  emit_insn (gen_fprx2_to_tf (outputs[i], fprx2));
+	}
       after_md_seq = get_insns ();
       after_md_end = get_last_insn ();
       end_sequence ();
@@ -16813,8 +16845,20 @@ s390_md_asm_adjust (vec<rtx> &outputs, vec<rtx> &inputs,
 	continue;
       gcc_assert (allows_reg);
       /* Copy input value from a vector register into a FPR pair.  */
-      rtx fprx2 = gen_reg_rtx (FPRX2mode);
-      emit_insn (gen_tf_to_fprx2 (fprx2, inputs[i]));
+      rtx fprx2;
+      if (s390_hard_fp_reg_p (inputs[i]))
+	{
+	  fprx2 = gen_rtx_REG (FPRX2mode, REGNO (inputs[i]));
+	  /* Copy only the second half.  */
+	  rtx v1 = gen_rtx_REG (V2DFmode, REGNO (inputs[i]) + 1);
+	  rtx v2 = gen_rtx_REG (V2DFmode, REGNO (inputs[i]));
+	  emit_insn (gen_vec_permiv2df (v1, v2, v1, GEN_INT (3)));
+	}
+      else
+	{
+	  fprx2 = gen_reg_rtx (FPRX2mode);
+	  emit_insn (gen_tf_to_fprx2 (fprx2, inputs[i]));
+	}
       inputs[i] = fprx2;
       input_modes[i] = FPRX2mode;
     }
diff --git a/gcc/testsuite/gcc.target/s390/vector/long-double-asm-in-out-hard-fp-reg.c b/gcc/testsuite/gcc.target/s390/vector/long-double-asm-in-out-hard-fp-reg.c
new file mode 100644
index 0000000000000..2dcaf08f00b1b
--- /dev/null
+++ b/gcc/testsuite/gcc.target/s390/vector/long-double-asm-in-out-hard-fp-reg.c
@@ -0,0 +1,33 @@
+/* { dg-do compile } */
+/* { dg-options "-O3 -march=z14 -mzarch --save-temps" } */
+/* { dg-do run { target { s390_z14_hw } } } */
+#include <assert.h>
+#include <stdint.h>
+
+__attribute__ ((noipa)) static long double
+sqxbr (long double x)
+{
+  register long double in asm("f0") = x;
+  register long double out asm("f1");
+
+  asm("sqxbr\t%0,%1" : "=f"(out) : "f"(in));
+  asm("# %0" : "+f"(out));
+
+  return out;
+}
+
+/* Ideally `vpdi %v3,%v1,%v3,5` should be optimized away, but the compiler
+ * can't do it, because the UNSPEC pattern operates on the whole register.
+ * Using the SUBREG pattern solves this problem, but it's fragile.
+ */
+/* { dg-final { scan-assembler-times {\n\tvpdi\t%v2,%v0,%v2,5\n} 1 } } */
+/* { dg-final { scan-assembler-times {\n\tvpdi\t%v1,%v1,%v3,0\n} 2 } } */
+/* { dg-final { scan-assembler-times {\n\tvpdi\t%v3,%v1,%v3,5\n} 1 } } */
+
+int
+main (void)
+{
+  long double x = 0x1.0000000000001p+0L,
+	      exp = 1.00000000000000011102230246251564788e+0L;
+  assert (sqxbr (x) == exp);
+}
diff --git a/gcc/testsuite/gcc.target/s390/vector/long-double-asm-inout-hard-fp-reg.c b/gcc/testsuite/gcc.target/s390/vector/long-double-asm-inout-hard-fp-reg.c
new file mode 100644
index 0000000000000..6c5f88d8652d2
--- /dev/null
+++ b/gcc/testsuite/gcc.target/s390/vector/long-double-asm-inout-hard-fp-reg.c
@@ -0,0 +1,31 @@
+/* { dg-do compile } */
+/* { dg-options "-O3 -march=z14 -mzarch --save-temps" } */
+/* { dg-do run { target { s390_z14_hw } } } */
+#include <assert.h>
+#include <stdint.h>
+
+__attribute__ ((noipa)) static long double
+sqxbr (long double x)
+{
+  register long double inout asm("f4") = x;
+
+  asm("sqxbr\t%0,%0" : "+f"(inout));
+  asm("# %0" : "+f"(inout));
+
+  return inout;
+}
+
+/* Ideally there should be just one `vpdi %v6,%v4,%v6,5`, but the compiler
+ * can't optimize it away, because the UNSPEC pattern operates on the whole
+ * register.  Using the SUBREG pattern solves this problem, but it's fragile.
+ */
+/* { dg-final { scan-assembler-times {\n\tvpdi\t%v6,%v4,%v6,5\n} 2 } } */
+/* { dg-final { scan-assembler-times {\n\tvpdi\t%v4,%v4,%v6,0\n} 2 } } */
+
+int
+main (void)
+{
+  long double x = 0x1.0000000000001p+0L,
+	      exp = 1.00000000000000011102230246251564788e+0L;
+  assert (sqxbr (x) == exp);
+}

From ccba1513d34cb1ad087a392621dbb5e0755bcab2 Mon Sep 17 00:00:00 2001
From: Roman Zhuykov <zhroma@ispras.ru>
Date: Thu, 6 May 2021 14:55:26 +0300
Subject: [PATCH 067/164] modulo-sched: skip loops with strange register defs
 [PR100225]

PR84878 fix adds an assertion which can fail, e.g. when stack pointer
is adjusted inside the loop.  We have to prevent it and search earlier
for any 'strange' instruction.  The solution is to skip the whole loop
if using 'note_stores' we found that one of hard registers is in
'df->regular_block_artificial_uses' set.

Also patch properly prohibit not single-set instruction in loop body.

gcc/ChangeLog:

	PR rtl-optimization/100225
	PR rtl-optimization/84878
	* modulo-sched.c (sms_schedule): Use note_stores to skip loops
	where we have an instruction which touches (writes) any hard
	register from df->regular_block_artificial_uses set.
	Allow not-single-set instruction only right before basic block
	tail.

gcc/testsuite/ChangeLog:

	PR rtl-optimization/100225
	PR rtl-optimization/84878
	* gcc.dg/pr100225.c: New test.

libgomp/ChangeLog:

	* testsuite/libgomp.oacc-c-c++-common/atomic_capture-3.c: New test.

(cherry picked from commit 4cf3b10f27b1994cf4a9eb12079d85412ebc7cad)
---
 gcc/modulo-sched.c                            |   56 +-
 gcc/testsuite/gcc.dg/pr100225.c               |   15 +
 .../atomic_capture-3.c                        | 1627 +++++++++++++++++
 3 files changed, 1677 insertions(+), 21 deletions(-)
 create mode 100644 gcc/testsuite/gcc.dg/pr100225.c
 create mode 100644 libgomp/testsuite/libgomp.oacc-c-c++-common/atomic_capture-3.c

diff --git a/gcc/modulo-sched.c b/gcc/modulo-sched.c
index 6ad960ec1f357..e72e46db387f7 100644
--- a/gcc/modulo-sched.c
+++ b/gcc/modulo-sched.c
@@ -43,6 +43,7 @@ along with GCC; see the file COPYING3.  If not see
 #include "tree-pass.h"
 #include "dbgcnt.h"
 #include "loop-unroll.h"
+#include "hard-reg-set.h"
 
 #ifdef INSN_SCHEDULING
 
@@ -1356,6 +1357,7 @@ sms_schedule (void)
   basic_block condition_bb = NULL;
   edge latch_edge;
   HOST_WIDE_INT trip_count, max_trip_count;
+  HARD_REG_SET prohibited_regs;
 
   loop_optimizer_init (LOOPS_HAVE_PREHEADERS
 		       | LOOPS_HAVE_RECORDED_EXITS);
@@ -1385,6 +1387,8 @@ sms_schedule (void)
      We use loop->num as index into this array.  */
   g_arr = XCNEWVEC (ddg_ptr, number_of_loops (cfun));
 
+  REG_SET_TO_HARD_REG_SET (prohibited_regs, &df->regular_block_artificial_uses);
+
   if (dump_file)
   {
     fprintf (dump_file, "\n\nSMS analysis phase\n");
@@ -1469,23 +1473,31 @@ sms_schedule (void)
       }
 
       /* Don't handle BBs with calls or barriers
-	 or !single_set with the exception of instructions that include
-	 count_reg---these instructions are part of the control part
-	 that do-loop recognizes.
+	 or !single_set with the exception of do-loop control part insns.
          ??? Should handle insns defining subregs.  */
-     for (insn = head; insn != NEXT_INSN (tail); insn = NEXT_INSN (insn))
-      {
-         rtx set;
-
-        if (CALL_P (insn)
-            || BARRIER_P (insn)
-            || (NONDEBUG_INSN_P (insn) && !JUMP_P (insn)
-                && !single_set (insn) && GET_CODE (PATTERN (insn)) != USE
-                && !reg_mentioned_p (count_reg, insn))
-            || (INSN_P (insn) && (set = single_set (insn))
-                && GET_CODE (SET_DEST (set)) == SUBREG))
-        break;
-      }
+      for (insn = head; insn != NEXT_INSN (tail); insn = NEXT_INSN (insn))
+	{
+	  if (INSN_P (insn))
+	    {
+	      HARD_REG_SET regs;
+	      CLEAR_HARD_REG_SET (regs);
+	      note_stores (insn, record_hard_reg_sets, &regs);
+	      if (hard_reg_set_intersect_p (regs, prohibited_regs))
+		break;
+	    }
+
+	  if (CALL_P (insn)
+	      || BARRIER_P (insn)
+	      || (INSN_P (insn) && single_set (insn)
+		  && GET_CODE (SET_DEST (single_set (insn))) == SUBREG)
+	      /* Not a single set.  */
+	      || (NONDEBUG_INSN_P (insn) && !JUMP_P (insn)
+		  && !single_set (insn) && GET_CODE (PATTERN (insn)) != USE
+		  /* But non-single-set allowed in one special case.  */
+		  && (insn != prev_nondebug_insn (tail)
+		      || !reg_mentioned_p (count_reg, insn))))
+	    break;
+	}
 
       if (insn != NEXT_INSN (tail))
 	{
@@ -1495,11 +1507,13 @@ sms_schedule (void)
 		fprintf (dump_file, "SMS loop-with-call\n");
 	      else if (BARRIER_P (insn))
 		fprintf (dump_file, "SMS loop-with-barrier\n");
-              else if ((NONDEBUG_INSN_P (insn) && !JUMP_P (insn)
-                && !single_set (insn) && GET_CODE (PATTERN (insn)) != USE))
-                fprintf (dump_file, "SMS loop-with-not-single-set\n");
-              else
-               fprintf (dump_file, "SMS loop with subreg in lhs\n");
+	      else if (INSN_P (insn) && single_set (insn)
+		       && GET_CODE (SET_DEST (single_set (insn))) == SUBREG)
+		fprintf (dump_file, "SMS loop with subreg in lhs\n");
+	      else
+		fprintf (dump_file,
+			 "SMS loop-with-not-single-set-or-prohibited-reg\n");
+
 	      print_rtl_single (dump_file, insn);
 	    }
 
diff --git a/gcc/testsuite/gcc.dg/pr100225.c b/gcc/testsuite/gcc.dg/pr100225.c
new file mode 100644
index 0000000000000..b32163441a3c3
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr100225.c
@@ -0,0 +1,15 @@
+/* PR rtl-optimization/100225 */
+/* { dg-do compile } */
+/* { dg-options "-O1 -fmodulo-sched" } */
+
+void
+vorbis_synthesis_lapout (void);
+
+void
+ov_info (int **lappcm, int ov_info_i)
+{
+  while (ov_info_i < 1)
+    lappcm[ov_info_i++] = __builtin_alloca (1);
+
+  vorbis_synthesis_lapout ();
+}
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/atomic_capture-3.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/atomic_capture-3.c
new file mode 100644
index 0000000000000..b976094998f2d
--- /dev/null
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/atomic_capture-3.c
@@ -0,0 +1,1627 @@
+/* { dg-do run } */
+/* { dg-additional-options "-fmodulo-sched -fmodulo-sched-allow-regmoves" } */
+
+#include <stdlib.h>
+
+int
+main(int argc, char **argv)
+{
+  int   iexp, igot, imax, imin;
+  long long lexp, lgot;
+  int   N = 32;
+  int	i;
+  int   idata[N];
+  long long ldata[N];
+  float fexp, fgot;
+  float fdata[N];
+
+  igot = 1234;
+  iexp = 31;
+
+  for (i = 0; i < N; i++)
+    idata[i] = i;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+#pragma acc atomic capture
+      { idata[i] = igot; igot = i; }
+  }
+
+  imax = 0;
+  imin = N;
+
+  for (i = 0; i < N; i++)
+    {
+      imax = idata[i] > imax ? idata[i] : imax;
+      imin = idata[i] < imin ? idata[i] : imin;
+    }
+
+  if (imax != 1234 || imin != 0)
+    abort ();
+
+  return 0;
+
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+#pragma acc atomic capture
+      { idata[i] = igot; igot++; }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+#pragma acc atomic capture
+      { idata[i] = igot; ++igot; }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+#pragma acc atomic capture
+      { ++igot; idata[i] = igot; }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+#pragma acc atomic capture
+      { igot++; idata[i] = igot; }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 32;
+  iexp = 0;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+#pragma acc atomic capture
+      { idata[i] = igot; igot--; }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 32;
+  iexp = 0;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+#pragma acc atomic capture
+      { idata[i] = igot; --igot; }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 32;
+  iexp = 0;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+#pragma acc atomic capture
+      { --igot; idata[i] = igot; }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 32;
+  iexp = 0;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+#pragma acc atomic capture
+      { igot--; idata[i] = igot; }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  /* BINOP = + */
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { idata[i] = igot; igot += expr; }
+      }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { igot += expr; idata[i] = igot; }
+      }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { idata[i] = igot; igot = igot + expr; }
+      }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { idata[i] = igot; igot = expr + igot; }
+      }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { igot = igot + expr; idata[i] = igot; }
+      }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+
+  igot = 0;
+  iexp = 32;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { igot = expr + igot; idata[i] = igot; }
+      }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  /* BINOP = * */
+  lgot = 1LL;
+  lexp = 1LL << 32;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      long long expr = 2LL;
+
+#pragma acc atomic capture
+      { ldata[i] = lgot; lgot *= expr; }
+    }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 1LL << 32;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 2LL;
+
+#pragma acc atomic capture
+        { lgot *= expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 1LL << 32;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 2LL;
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = lgot * expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 1LL << 32;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      long long expr = 2LL;
+
+#pragma acc atomic capture
+      { ldata[i] = lgot; lgot = expr * lgot; }
+    }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 1LL << 32;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 2LL;
+
+#pragma acc atomic capture
+        { lgot = lgot * expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 1LL << 32;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      long long expr = 2;
+
+#pragma acc atomic capture
+      { lgot = expr * lgot; ldata[i] = lgot; }
+    }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  /* BINOP = - */
+  igot = 32;
+  iexp = 0;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      int expr = 1;
+
+#pragma acc atomic capture
+      { idata[i] = igot; igot -= expr; }
+    }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 32;
+  iexp = 0;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { igot -= expr; idata[i] = igot; }
+      }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 32;
+  iexp = 0;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { idata[i] = igot; igot = igot - expr; }
+      }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 1;
+  iexp = 1;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      int expr = 1;
+
+#pragma acc atomic capture
+      { idata[i] = igot; igot = expr - igot; }
+    }
+  }
+
+  for (i = 0; i < N; i++)
+    if (i % 2 == 0)
+      {
+	if (idata[i] != 1)
+	  abort ();
+      }
+    else
+      {
+	if (idata[i] != 0)
+	  abort ();
+      }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 1;
+  iexp = -31;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { igot = igot - expr; idata[i] = igot; }
+      }
+  }
+
+  if (iexp != igot)
+    abort ();
+
+  igot = 1;
+  iexp = 1;
+
+#pragma acc data copy (igot, idata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        int expr = 1;
+
+#pragma acc atomic capture
+        { igot = expr - igot; idata[i] = igot; }
+      }
+  }
+
+  for (i = 0; i < N; i++)
+    if (i % 2 == 0)
+      {
+	if (idata[i] != 0)
+	  abort ();
+      }
+    else
+      {
+	if (idata[i] != 1)
+	  abort ();
+      }
+
+  if (iexp != igot)
+    abort ();
+
+  /* BINOP = / */
+  lgot = 1LL << 32;
+  lexp = 1LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 2LL;
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot /= expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL << 32;
+  lexp = 1LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 2LL;
+
+#pragma acc atomic capture
+        { lgot /= expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL << 32;
+  lexp = 1LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      long long expr = 2LL;
+
+#pragma acc atomic capture
+      { ldata[i] = lgot; lgot = lgot / expr; }
+    }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 2LL;
+  lexp = 2LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL << N;
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = expr / lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 2LL;
+  lexp = 2LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL << N;
+
+#pragma acc atomic capture
+        { lgot = lgot / expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 2LL;
+  lexp = 2LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL << N;
+
+#pragma acc atomic capture
+        { lgot = expr / lgot; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  /* BINOP = & */
+  lgot = ~0LL;
+  lexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot &= expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  iexp = 0LL; 
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { lgot &= expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  lexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = lgot & expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  lexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = expr & lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  iexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { lgot = lgot & expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  lexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+      { lgot = expr & lgot; ldata[i] = lgot; }
+    }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  /* BINOP = ^ */
+  lgot = ~0LL;
+  lexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      long long expr = 1 << i;
+
+#pragma acc atomic capture
+      { ldata[i] = lgot; lgot ^= expr; }
+    }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  iexp = 0LL; 
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { lgot ^= expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  lexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = lgot ^ expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  lexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+      { ldata[i] = lgot; lgot = expr ^ lgot; }
+    }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  iexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { lgot = lgot ^ expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = ~0LL;
+  lexp = 0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { lgot = expr ^ lgot; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  /* BINOP = | */
+  lgot = 0LL;
+  lexp = ~0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1 << i;
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot |= expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 0LL;
+  iexp = ~0LL; 
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { lgot |= expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 0LL;
+  lexp = ~0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = lgot | expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 0LL;
+  lexp = ~0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = expr | lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 0LL;
+  iexp = ~0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { lgot = lgot | expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 0LL;
+  lexp = ~0LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = ~(1 << i);
+
+#pragma acc atomic capture
+        { lgot = expr | lgot; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  /* BINOP = << */
+  lgot = 1LL;
+  lexp = 1LL << N;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL;
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot <<= expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  iexp = 1LL << N; 
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL;
+
+#pragma acc atomic capture
+        { lgot <<= expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 1LL << N;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL;
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = lgot << expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 2LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < 1; i++)
+      {
+        long long expr = 1LL;
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = expr << lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 2LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < 1; i++)
+      {
+        long long expr = 1LL;
+
+#pragma acc atomic capture
+        { lgot = lgot << expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 2LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < 1; i++)
+      {
+        long long expr = 1LL;
+
+#pragma acc atomic capture
+        { lgot = expr << lgot; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  /* BINOP = >> */
+  lgot = 1LL << N;
+  lexp = 1LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL;
+  
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot >>= expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL << N;
+  iexp = 1LL; 
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL;
+
+#pragma acc atomic capture
+        { lgot >>= expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL << N;
+  lexp = 1LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL;
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = lgot >> expr; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 1LL << (N - 1);
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < 1; i++)
+      {
+        long long expr = 1LL << N;
+
+#pragma acc atomic capture
+        { ldata[i] = lgot; lgot = expr >> lgot; }
+    }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL << N;
+  lexp = 1LL;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL;
+
+#pragma acc atomic capture
+        { lgot = lgot >> expr; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 1LL << (N - 1);
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < 1; i++)
+      {
+        long long expr = 1LL << N;
+
+#pragma acc atomic capture
+        { lgot = expr >> lgot; ldata[i] = lgot; }
+      }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  // FLOAT FLOAT FLOAT
+
+  /* BINOP = + */
+  fgot = 0.0;
+  fexp = 32.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      float expr = 1.0;
+
+#pragma acc atomic capture
+      { fdata[i] = fgot; fgot += expr; }
+    }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 0.0;
+  fexp = 32.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+
+#pragma acc atomic capture
+        { fgot += expr; fdata[i] = fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 0.0;
+  fexp = 32.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+
+#pragma acc atomic capture
+        { idata[i] = fgot; fgot = fgot + expr; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 0.0;
+  fexp = 32.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      float expr = 1.0;
+
+#pragma acc atomic capture
+      { fdata[i] = fgot; fgot = expr + fgot; }
+    }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 0.0;
+  fexp = 32.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+
+#pragma acc atomic capture
+        { fgot = fgot + expr; fdata[i] = fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 0.0;
+  fexp = 32.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+
+#pragma acc atomic capture
+        { fgot = expr + fgot; fdata[i] = fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  /* BINOP = * */
+  fgot = 1.0;
+  fexp = 8192.0*8192.0*64.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      float expr = 2.0;
+
+#pragma acc atomic capture
+      { fdata[i] = fgot; fgot *= expr; }
+    }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 1.0;
+  fexp = 8192.0*8192.0*64.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 2.0;
+
+#pragma acc atomic capture
+        { fgot *= expr; fdata[i] = fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 1.0;
+  fexp = 8192.0*8192.0*64.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 2.0;
+
+#pragma acc atomic capture
+        { fdata[i] = fgot; fgot = fgot * expr; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 1.0;
+  fexp = 8192.0*8192.0*64.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 2.0;
+
+#pragma acc atomic capture
+        { fdata[i] = fgot; fgot = expr * fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  lgot = 1LL;
+  lexp = 1LL << 32;
+
+#pragma acc data copy (lgot, ldata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      long long expr = 2LL;
+
+#pragma acc atomic capture
+      { lgot = lgot * expr; ldata[i] = lgot; }
+    }
+  }
+
+  if (lexp != lgot)
+    abort ();
+
+  fgot = 1.0;
+  fexp = 8192.0*8192.0*64.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 2;
+
+#pragma acc atomic capture
+        { fgot = expr * fgot; fdata[i] = fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  /* BINOP = - */
+  fgot = 32.0;
+  fexp = 0.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+  
+#pragma acc atomic capture
+        { fdata[i] = fgot; fgot -= expr; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 32.0;
+  fexp = 0.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+      float expr = 1.0;
+
+#pragma acc atomic capture
+      { fgot -= expr; fdata[i] = fgot; }
+    }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 32.0;
+  fexp = 0.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+
+#pragma acc atomic capture
+        { fdata[i] = fgot; fgot = fgot - expr; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 1.0;
+  fexp = 1.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+
+#pragma acc atomic capture
+        { fdata[i] = fgot; fgot = expr - fgot; }
+      }
+  }
+
+  for (i = 0; i < N; i++)
+    if (i % 2 == 0)
+      {
+	if (fdata[i] != 1.0)
+	  abort ();
+      }
+    else
+      {
+	if (fdata[i] != 0.0)
+	  abort ();
+      }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 1.0;
+  fexp = -31.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+
+#pragma acc atomic capture
+        { fgot = fgot - expr; fdata[i] = fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 1.0;
+  fexp = 1.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+
+#pragma acc atomic capture
+        { fgot = expr - fgot; fdata[i] = fgot; }
+      }
+  }
+
+  for (i = 0; i < N; i++)
+    if (i % 2 == 0)
+      {
+	if (fdata[i] != 0.0)
+	  abort ();
+      }
+    else
+      {
+	if (fdata[i] != 1.0)
+	  abort ();
+      }
+
+  if (fexp != fgot)
+    abort ();
+
+  /* BINOP = / */
+  fgot = 8192.0*8192.0*64.0;
+  fexp = 1.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 2.0;
+
+#pragma acc atomic capture
+        { fdata[i] = fgot; fgot /= expr; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 8192.0*8192.0*64.0;
+  fexp = 1.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 2.0;
+
+#pragma acc atomic capture
+        { fgot /= expr; fdata[i] = fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 8192.0*8192.0*64.0;
+  fexp = 1.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 2.0;
+
+#pragma acc atomic capture
+        { fdata[i] = fgot; fgot = fgot / expr; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 8192.0*8192.0*64.0;
+  fexp = 1.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 1.0;
+
+#pragma acc atomic capture
+        { fdata[i] = fgot; fgot = expr / fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 4.0;
+  fexp = 4.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        long long expr = 1LL << N;
+
+#pragma acc atomic capture
+        { fgot = fgot / expr; fdata[i] = fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  fgot = 4.0;
+  fexp = 4.0;
+
+#pragma acc data copy (fgot, fdata[0:N])
+  {
+#pragma acc parallel loop
+    for (i = 0; i < N; i++)
+      {
+        float expr = 2.0;
+
+#pragma acc atomic capture
+        { fgot = expr / fgot; fdata[i] = fgot; }
+      }
+  }
+
+  if (fexp != fgot)
+    abort ();
+
+  return 0;
+}

From d22de093a91a1488785907d69020b5e86c96d5b5 Mon Sep 17 00:00:00 2001
From: Marius Hillenbrand <mhillen@linux.ibm.com>
Date: Tue, 4 May 2021 13:30:05 +0200
Subject: [PATCH 068/164] IBM Z: Fix error checking for builtin vec_permi

The builtin vec_permi is peculiar in that its immediate operand is
encoded differently than the immediate operand that is backing the
builtin. This fixes the check for the immediate operand, adding a
regression test in the process.

This partially reverts commit 3191c1f4488d1f7563b563d7ae2a102a26f16d82

2021-05-06  Marius Hillenbrand  <mhillen@linux.ibm.com>

gcc/ChangeLog:

	* config/s390/s390-builtins.def (O_M5, O1_M5, ...): Remove unused macros.
	(s390_vec_permi_s64, s390_vec_permi_b64, s390_vec_permi_u64)
	(s390_vec_permi_dbl, s390_vpdi): Use the O3_U2 type for the immediate
	operand.
	* config/s390/s390.c (s390_const_operand_ok): Remove unused
	values.

gcc/testsuite/ChangeLog:

	* gcc.target/s390/zvector/imm-range-error-1.c: Fix test for
	__builtin_s390_vpdi.
	* gcc.target/s390/zvector/vec-permi.c: New test for builtin
	vec_permi.

(cherry picked from commit 3c33c00f43bfe585d9414dfb620f0f518e55a457)
---
 gcc/config/s390/s390-builtins.def             | 44 ++++++---------
 gcc/config/s390/s390.c                        |  7 ++-
 .../s390/zvector/imm-range-error-1.c          |  2 +-
 .../gcc.target/s390/zvector/vec-permi.c       | 54 +++++++++++++++++++
 4 files changed, 76 insertions(+), 31 deletions(-)
 create mode 100644 gcc/testsuite/gcc.target/s390/zvector/vec-permi.c

diff --git a/gcc/config/s390/s390-builtins.def b/gcc/config/s390/s390-builtins.def
index f77ab750d223c..8ca002dc55aed 100644
--- a/gcc/config/s390/s390-builtins.def
+++ b/gcc/config/s390/s390-builtins.def
@@ -29,7 +29,6 @@
 #undef O_U16
 #undef O_U32
 
-#undef O_M5
 #undef O_M12
 
 #undef O_S2
@@ -89,11 +88,6 @@
 #undef O3_U32
 #undef O4_U32
 
-#undef O1_M5
-#undef O2_M5
-#undef O3_M5
-#undef O4_M5
-
 #undef O1_M12
 #undef O2_M12
 #undef O3_M12
@@ -164,20 +158,19 @@
 #define O_U16    8 /* unsigned 16 bit literal */
 #define O_U32    9 /* unsigned 32 bit literal */
 
-#define O_M5    10 /* matches bitmask of 5 */
-#define O_M12   11 /* matches bitmask of 12 */
+#define O_M12   10 /* matches bitmask of 12 */
 
-#define O_S2    12 /* signed  2 bit literal */
-#define O_S3    13 /* signed  3 bit literal */
-#define O_S4    14 /* signed  4 bit literal */
-#define O_S5    15 /* signed  5 bit literal */
-#define O_S8    16 /* signed  8 bit literal */
-#define O_S12   17 /* signed 12 bit literal */
-#define O_S16   18 /* signed 16 bit literal */
-#define O_S32   19 /* signed 32 bit literal */
+#define O_S2    11 /* signed  2 bit literal */
+#define O_S3    12 /* signed  3 bit literal */
+#define O_S4    13 /* signed  4 bit literal */
+#define O_S5    14 /* signed  5 bit literal */
+#define O_S8    15 /* signed  8 bit literal */
+#define O_S12   16 /* signed 12 bit literal */
+#define O_S16   17 /* signed 16 bit literal */
+#define O_S32   18 /* signed 32 bit literal */
 
-#define O_ELEM  20 /* Element selector requiring modulo arithmetic. */
-#define O_LIT   21 /* Operand must be a literal fitting the target type.  */
+#define O_ELEM  19 /* Element selector requiring modulo arithmetic. */
+#define O_LIT   20 /* Operand must be a literal fitting the target type.  */
 
 #define O_SHIFT 5
 
@@ -230,11 +223,6 @@
 #define O3_U32 (O_U32 << (2 * O_SHIFT))
 #define O4_U32 (O_U32 << (3 * O_SHIFT))
 
-#define O1_M5 O_M5
-#define O2_M5 (O_M5 << O_SHIFT)
-#define O3_M5 (O_M5 << (2 * O_SHIFT))
-#define O4_M5 (O_M5 << (3 * O_SHIFT))
-
 #define O1_M12 O_M12
 #define O2_M12 (O_M12 << O_SHIFT)
 #define O3_M12 (O_M12 << (2 * O_SHIFT))
@@ -671,12 +659,12 @@ OB_DEF_VAR (s390_vec_perm_dbl,          s390_vperm,         0,
 B_DEF      (s390_vperm,                 vec_permv16qi,      0,                  B_VX,               0,                  BT_FN_UV16QI_UV16QI_UV16QI_UV16QI)
 
 OB_DEF     (s390_vec_permi,             s390_vec_permi_s64, s390_vec_permi_dbl, B_VX,               BT_FN_OV4SI_OV4SI_OV4SI_INT)
-OB_DEF_VAR (s390_vec_permi_s64,         s390_vpdi,          0,                  O3_M5,              BT_OV_V2DI_V2DI_V2DI_INT)
-OB_DEF_VAR (s390_vec_permi_b64,         s390_vpdi,          0,                  O3_M5,              BT_OV_BV2DI_BV2DI_BV2DI_INT)
-OB_DEF_VAR (s390_vec_permi_u64,         s390_vpdi,          0,                  O3_M5,              BT_OV_UV2DI_UV2DI_UV2DI_INT)
-OB_DEF_VAR (s390_vec_permi_dbl,         s390_vpdi,          0,                  O3_M5,              BT_OV_V2DF_V2DF_V2DF_INT)
+OB_DEF_VAR (s390_vec_permi_s64,         s390_vpdi,          0,                  O3_U2,              BT_OV_V2DI_V2DI_V2DI_INT)
+OB_DEF_VAR (s390_vec_permi_b64,         s390_vpdi,          0,                  O3_U2,              BT_OV_BV2DI_BV2DI_BV2DI_INT)
+OB_DEF_VAR (s390_vec_permi_u64,         s390_vpdi,          0,                  O3_U2,              BT_OV_UV2DI_UV2DI_UV2DI_INT)
+OB_DEF_VAR (s390_vec_permi_dbl,         s390_vpdi,          0,                  O3_U2,              BT_OV_V2DF_V2DF_V2DF_INT)
 
-B_DEF      (s390_vpdi,                  vec_permiv2di,      0,                  B_VX,               O3_M5,              BT_FN_UV2DI_UV2DI_UV2DI_INT)
+B_DEF      (s390_vpdi,                  vec_permiv2di,      0,                  B_VX,               O3_U2,              BT_FN_UV2DI_UV2DI_UV2DI_INT)
 
 OB_DEF     (s390_vec_splat,             s390_vec_splat2_s8, s390_vec_splat2_dbl,B_VX,               BT_FN_OV4SI_OV4SI_UCHAR)
 OB_DEF_VAR (s390_vec_splat2_s8,         s390_vrepb,         0,                  O2_U4,              BT_OV_V16QI_V16QI_UCHAR)
diff --git a/gcc/config/s390/s390.c b/gcc/config/s390/s390.c
index 88361f98c7ef0..6bbeb640e1fc9 100644
--- a/gcc/config/s390/s390.c
+++ b/gcc/config/s390/s390.c
@@ -734,11 +734,14 @@ s390_const_operand_ok (tree arg, int argnum, int op_flags, tree decl)
 {
   if (O_UIMM_P (op_flags))
     {
-      unsigned HOST_WIDE_INT bitwidths[] = { 1, 2, 3, 4, 5, 8, 12, 16, 32, 4,  4 };
-      unsigned HOST_WIDE_INT bitmasks[]  = { 0, 0, 0, 0, 0, 0,  0,  0,  0, 5, 12 };
+      unsigned HOST_WIDE_INT bitwidths[] = { 1, 2, 3, 4, 5, 8, 12, 16, 32, 4 };
+      unsigned HOST_WIDE_INT bitmasks[]  = { 0, 0, 0, 0, 0, 0,  0,  0,  0, 12 };
       unsigned HOST_WIDE_INT bitwidth = bitwidths[op_flags - O_U1];
       unsigned HOST_WIDE_INT bitmask = bitmasks[op_flags - O_U1];
 
+      gcc_assert(ARRAY_SIZE(bitwidths) == (O_M12 - O_U1 + 1));
+      gcc_assert(ARRAY_SIZE(bitmasks) == (O_M12 - O_U1 + 1));
+
       if (!tree_fits_uhwi_p (arg)
 	  || tree_to_uhwi (arg) > (HOST_WIDE_INT_1U << bitwidth) - 1
 	  || (bitmask && tree_to_uhwi (arg) & ~bitmask))
diff --git a/gcc/testsuite/gcc.target/s390/zvector/imm-range-error-1.c b/gcc/testsuite/gcc.target/s390/zvector/imm-range-error-1.c
index 1fe68f57e4f7b..021c8d297d2da 100644
--- a/gcc/testsuite/gcc.target/s390/zvector/imm-range-error-1.c
+++ b/gcc/testsuite/gcc.target/s390/zvector/imm-range-error-1.c
@@ -22,5 +22,5 @@ main ()
   __builtin_s390_vrepf (s,  4); /* { dg-error "constant argument 2 for builtin '__builtin_s390_vrepf' is out of range \\(0..3\\)" } */
   __builtin_s390_vrepg (d,  2); /* { dg-error "constant argument 2 for builtin '__builtin_s390_vrepg' is out of range \\(0..1\\)" } */
 
-  __builtin_s390_vpdi (d, d, 2); /* { dg-error "constant argument 3 for builtin '__builtin_s390_vpdi' is invalid \\(0, 1, 4, 5\\)" } */
+  __builtin_s390_vpdi (d, d, 4); /* { dg-error "constant argument 3 for builtin '__builtin_s390_vpdi' is out of range \\(0..3\\)" } */
 }
diff --git a/gcc/testsuite/gcc.target/s390/zvector/vec-permi.c b/gcc/testsuite/gcc.target/s390/zvector/vec-permi.c
new file mode 100644
index 0000000000000..c0a852b970300
--- /dev/null
+++ b/gcc/testsuite/gcc.target/s390/zvector/vec-permi.c
@@ -0,0 +1,54 @@
+/* { dg-do compile } */
+/* { dg-options "-O3 -march=z13 -mzarch --save-temps" } */
+/* { dg-do run { target { s390_z13_hw } } } */
+
+/*
+ * The vector intrinsic vec_permi(a, b, c) chooses one of the two eight-byte
+ * vector elements in each of a and b, depending on the value of c. The valid
+ * values for c differ from the encoding for the M4 field in assembly and in the
+ * binary instruction.
+ *
+ * selection | c | encoding in assembly
+ * a[0] b[0] | 0 | 0
+ * a[0] b[1] | 1 | 1
+ * a[1] b[0] | 2 | 4
+ * a[1] b[1] | 3 | 5
+ *
+ * (i.e., indices a[i] b[j] are encoded for c as (i<<1) | j, yet for the
+ * M4 field as (i<<2) | j.
+ */
+#include <assert.h>
+#include <vecintrin.h>
+
+typedef unsigned long long uv2di __attribute__((vector_size(16)));
+
+__attribute__ ((noipa)) static uv2di
+do_vec_permi(uv2di a, uv2di b, int c)
+{
+    switch(c) {
+	case 0: return vec_permi(a, b, 0);
+	case 1: return vec_permi(a, b, 1);
+	case 2: return vec_permi(a, b, 2);
+	case 3: return vec_permi(a, b, 3);
+	default: assert(0);
+    }
+}
+
+/* { dg-final { scan-assembler-times {\n\tvpdi\t%v\d+,%v\d+,%v\d+,0\n} 1 } } */
+/* { dg-final { scan-assembler-times {\n\tvpdi\t%v\d+,%v\d+,%v\d+,1\n} 1 } } */
+/* { dg-final { scan-assembler-times {\n\tvpdi\t%v\d+,%v\d+,%v\d+,4\n} 1 } } */
+/* { dg-final { scan-assembler-times {\n\tvpdi\t%v\d+,%v\d+,%v\d+,5\n} 1 } } */
+
+int
+main (void)
+{
+    uv2di a = { 0xa0, 0xa1 };
+    uv2di b = { 0xb0, 0xb1 };
+
+    for (int i = 0; i < 2; i++)
+	for (int j = 0; j < 2; j++) {
+	    uv2di res = do_vec_permi(a, b, (i<<1)|j);
+	    assert(res[0] == a[i]);
+	    assert(res[1] == b[j]);
+	}
+}

From e99763ee6da8e378073b847243d9ac2538903534 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Tue, 4 May 2021 12:16:46 +0100
Subject: [PATCH 069/164] libstdc++: Do not use deduced return type for
 std::visit [PR 100384]

This avoids errors outside the immediate context when std::visit is an
overload candidate because of ADL, but not actually viable.

The solution is to give std::visit a non-deduced return type. New
helpers are introduced for that, and existing ones refactored slightly.

libstdc++-v3/ChangeLog:

	PR libstdc++/100384
	* include/std/variant (__get_t): New alias template yielding the
	return type of std::get<N> on a variant.
	(__visit_result_t): New alias template yielding the result of
	std::visit.
	(__same_types): Move into namespace __detail::__variant.
	(__check_visitor_results): Likewise. Use __invoke_result_t and
	__get_t.
	(__check_visitor_result): Remove.
	(visit): Use __visit_result_t for return type.
	* testsuite/20_util/variant/100384.cc: New test.

(cherry picked from commit af5b2b911dd80ae9cc87404b7e7ab807cf6655d4)
---
 libstdc++-v3/include/std/variant              | 50 +++++++++----------
 .../testsuite/20_util/variant/100384.cc       |  9 ++++
 2 files changed, 34 insertions(+), 25 deletions(-)
 create mode 100644 libstdc++-v3/testsuite/20_util/variant/100384.cc

diff --git a/libstdc++-v3/include/std/variant b/libstdc++-v3/include/std/variant
index 1ef9b9725e23b..9b2bc440841fb 100644
--- a/libstdc++-v3/include/std/variant
+++ b/libstdc++-v3/include/std/variant
@@ -1063,6 +1063,25 @@ namespace __variant
 			      std::index_sequence<__indices...>>
     : _Base_dedup<__indices, __poison_hash<remove_const_t<_Types>>>... { };
 
+  template<size_t _Np, typename _Variant>
+    using __get_t = decltype(std::get<_Np>(std::declval<_Variant>()));
+
+  // Return type of std::visit.
+  template<typename _Visitor, typename... _Variants>
+    using __visit_result_t
+      = invoke_result_t<_Visitor, __get_t<0, _Variants>...>;
+
+  template<typename _Tp, typename... _Types>
+    constexpr inline bool __same_types = (is_same_v<_Tp, _Types> && ...);
+
+  template <typename _Visitor, typename _Variant, size_t... _Idxs>
+    constexpr bool __check_visitor_results(std::index_sequence<_Idxs...>)
+    {
+      return __same_types<
+	invoke_result_t<_Visitor, __get_t<_Idxs, _Variant>>...
+	>;
+    }
+
 } // namespace __variant
 } // namespace __detail
 
@@ -1248,7 +1267,8 @@ namespace __variant
 #endif
 
   template<typename _Visitor, typename... _Variants>
-    constexpr decltype(auto) visit(_Visitor&&, _Variants&&...);
+    constexpr __detail::__variant::__visit_result_t<_Visitor, _Variants...>
+    visit(_Visitor&&, _Variants&&...);
 
   template<typename... _Types>
     inline enable_if_t<(is_move_constructible_v<_Types> && ...)
@@ -1715,41 +1735,21 @@ namespace __variant
 			   std::forward<_Variants>(__variants)...);
     }
 
-  template<typename _Tp, typename... _Types>
-     constexpr inline bool __same_types = (is_same_v<_Tp, _Types> && ...);
-
-  template <size_t _Idx, typename _Visitor, typename _Variant>
-    decltype(auto)
-    __check_visitor_result(_Visitor&& __vis, _Variant&& __variant)
-    {
-      return std::__invoke(std::forward<_Visitor>(__vis),
-			   std::get<_Idx>(std::forward<_Variant>(__variant)));
-    }
-
-  template <typename _Visitor, typename _Variant, size_t... _Idxs>
-    constexpr bool __check_visitor_results(std::index_sequence<_Idxs...>)
-    {
-      return __same_types<decltype(__check_visitor_result<_Idxs>(
-	std::declval<_Visitor>(),
-	std::declval<_Variant>()))...>;
-    }
-
-
   template<typename _Visitor, typename... _Variants>
-    constexpr decltype(auto)
+    constexpr __detail::__variant::__visit_result_t<_Visitor, _Variants...>
     visit(_Visitor&& __visitor, _Variants&&... __variants)
     {
       if ((__variants.valueless_by_exception() || ...))
 	__throw_bad_variant_access("std::visit: variant is valueless");
 
-      using _Result_type = std::invoke_result_t<_Visitor,
-	decltype(std::get<0>(std::declval<_Variants>()))...>;
+      using _Result_type
+	= __detail::__variant::__visit_result_t<_Visitor, _Variants...>;
 
       using _Tag = __detail::__variant::__deduce_visit_result<_Result_type>;
 
       if constexpr (sizeof...(_Variants) == 1)
 	{
-	  constexpr bool __visit_rettypes_match =
+	  constexpr bool __visit_rettypes_match = __detail::__variant::
 	    __check_visitor_results<_Visitor, _Variants...>(
 	      std::make_index_sequence<
 	        std::variant_size<remove_reference_t<_Variants>...>::value>());
diff --git a/libstdc++-v3/testsuite/20_util/variant/100384.cc b/libstdc++-v3/testsuite/20_util/variant/100384.cc
new file mode 100644
index 0000000000000..4866aa017ffe7
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/variant/100384.cc
@@ -0,0 +1,9 @@
+// { dg-do compile { target c++17 } }
+
+#include <variant>
+
+int visit(int*, std::true_type) { return 0; }
+
+const std::true_type dat;
+
+int i = visit(nullptr, dat);

From cea2b1a52b3c5fe9f70daf460afe067e245bb1d7 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Tue, 4 May 2021 15:28:39 +0100
Subject: [PATCH 070/164] libstdc++: Fix undefined behaviour in testsuite

Fix some test bugs found by ubsan.

libstdc++-v3/ChangeLog:

	* testsuite/20_util/from_chars/3.cc: Use unsigned type to avoid
	overflow.
	* testsuite/24_iterators/reverse_iterator/2.cc: Do not add
	non-zero value to null pointer.
	* testsuite/25_algorithms/copy_backward/move_iterators/69478.cc:
	Use past-the-end iterator for result.
	* testsuite/25_algorithms/move_backward/69478.cc: Likewise.
	* testsuite/25_algorithms/move_backward/93872.cc: Likewise.

(cherry picked from commit 6fb8b67089119b737ccb38f75f403b8d279e2229)
---
 libstdc++-v3/testsuite/20_util/from_chars/3.cc            | 2 +-
 libstdc++-v3/testsuite/24_iterators/reverse_iterator/2.cc | 8 ++++----
 .../25_algorithms/copy_backward/move_iterators/69478.cc   | 2 +-
 .../testsuite/25_algorithms/move_backward/69478.cc        | 2 +-
 .../testsuite/25_algorithms/move_backward/93872.cc        | 2 +-
 5 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/libstdc++-v3/testsuite/20_util/from_chars/3.cc b/libstdc++-v3/testsuite/20_util/from_chars/3.cc
index c99353a728440..d3d70394ed949 100644
--- a/libstdc++-v3/testsuite/20_util/from_chars/3.cc
+++ b/libstdc++-v3/testsuite/20_util/from_chars/3.cc
@@ -29,7 +29,7 @@ long long
 read(const char* first, const char* last, int base)
 {
   long long val = 0;
-  long long place = 1;
+  unsigned long long place = 1;
   while (last > first)
   {
     val += (*--last - '0') * place;
diff --git a/libstdc++-v3/testsuite/24_iterators/reverse_iterator/2.cc b/libstdc++-v3/testsuite/24_iterators/reverse_iterator/2.cc
index a6d7d6b019135..633c1426b9650 100644
--- a/libstdc++-v3/testsuite/24_iterators/reverse_iterator/2.cc
+++ b/libstdc++-v3/testsuite/24_iterators/reverse_iterator/2.cc
@@ -27,7 +27,7 @@ void test02()
   iterator_type it01;
   iterator_type it02;
 
-  // Sanity check non-member operators and functions can be instantiated. 
+  // Sanity check non-member operators and functions can be instantiated.
   it01 == it02;
   it01 != it02;
   it01 < it02;
@@ -35,11 +35,11 @@ void test02()
   it01 > it02;
   it01 >= it02;
   it01 - it02;
-  5 + it02;
+  0 + it02;
 }
 
-int main() 
-{ 
+int main()
+{
   test02();
   return 0;
 }
diff --git a/libstdc++-v3/testsuite/25_algorithms/copy_backward/move_iterators/69478.cc b/libstdc++-v3/testsuite/25_algorithms/copy_backward/move_iterators/69478.cc
index 88a01b84a8eba..9c84cfb176c82 100644
--- a/libstdc++-v3/testsuite/25_algorithms/copy_backward/move_iterators/69478.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/copy_backward/move_iterators/69478.cc
@@ -35,6 +35,6 @@ test01()
   static_assert(std::is_trivial<trivial_rvalstruct>::value, "");
 
   trivial_rvalstruct a[1], b[1];
-  copy_backward(std::make_move_iterator(a), std::make_move_iterator(a+1), b);
+  copy_backward(std::make_move_iterator(a), std::make_move_iterator(a+1), b+1);
 }
 // { dg-prune-output "use of deleted" }
diff --git a/libstdc++-v3/testsuite/25_algorithms/move_backward/69478.cc b/libstdc++-v3/testsuite/25_algorithms/move_backward/69478.cc
index 25bfe29fc1443..10e31be1e08c3 100644
--- a/libstdc++-v3/testsuite/25_algorithms/move_backward/69478.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/move_backward/69478.cc
@@ -35,6 +35,6 @@ test01()
   static_assert(std::is_trivial<trivial_rvalstruct>::value, "");
 
   trivial_rvalstruct a[1], b[1];
-  std::move_backward(a, a + 1, b);
+  std::move_backward(a, a + 1, b + 1);
 }
 // { dg-prune-output "use of deleted" }
diff --git a/libstdc++-v3/testsuite/25_algorithms/move_backward/93872.cc b/libstdc++-v3/testsuite/25_algorithms/move_backward/93872.cc
index df96c94b39430..a9fd2697f5b14 100644
--- a/libstdc++-v3/testsuite/25_algorithms/move_backward/93872.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/move_backward/93872.cc
@@ -35,5 +35,5 @@ void
 test01()
 {
   X a[2], b[2];
-  std::move_backward(std::begin(a), std::end(a), std::begin(b));
+  std::move_backward(std::begin(a), std::end(a), std::end(b));
 }

From 00ddf72a6f5cfe137a70d385ae3fc7a92f6b2a98 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Tue, 4 May 2021 15:46:28 +0100
Subject: [PATCH 071/164] libstdc++: Fix null dereference in pb_ds containers

This fixes ubsan errors:

ext/pb_ds/detail/cc_hash_table_map_/cc_ht_map_.hpp:533:15: runtime error: member access within null pointer of type 'struct entry'

libstdc++-v3/ChangeLog:

	* include/ext/pb_ds/detail/cc_hash_table_map_/cc_ht_map_.hpp
	(find_key_pointer(key_const_reference, false_type))
	(find_key_pointer(key_const_reference, true_type)): Do not
	dereference null pointer.

(cherry picked from commit ca871701c2822c3c4537745d4aa44a7b8f408337)
---
 .../detail/cc_hash_table_map_/cc_ht_map_.hpp  | 26 ++++++++++++-------
 1 file changed, 16 insertions(+), 10 deletions(-)

diff --git a/libstdc++-v3/include/ext/pb_ds/detail/cc_hash_table_map_/cc_ht_map_.hpp b/libstdc++-v3/include/ext/pb_ds/detail/cc_hash_table_map_/cc_ht_map_.hpp
index aa5c94b9aed8b..c81bf3abfeffb 100644
--- a/libstdc++-v3/include/ext/pb_ds/detail/cc_hash_table_map_/cc_ht_map_.hpp
+++ b/libstdc++-v3/include/ext/pb_ds/detail/cc_hash_table_map_/cc_ht_map_.hpp
@@ -524,13 +524,16 @@ namespace __gnu_pbds
 
 	resize_base::notify_find_search_end();
 
-#ifdef _GLIBCXX_DEBUG
 	if (p_e == 0)
-	  PB_DS_CHECK_KEY_DOES_NOT_EXIST(r_key)
+	  {
+	    PB_DS_CHECK_KEY_DOES_NOT_EXIST(r_key)
+	    return 0;
+	  }
 	else
-	  PB_DS_CHECK_KEY_EXISTS(r_key)
-#endif
-	return &p_e->m_value;
+	  {
+	    PB_DS_CHECK_KEY_EXISTS(r_key)
+	    return &p_e->m_value;
+	  }
       }
 
       inline pointer
@@ -550,13 +553,16 @@ namespace __gnu_pbds
 
 	resize_base::notify_find_search_end();
 
-#ifdef _GLIBCXX_DEBUG
 	if (p_e == 0)
-	  PB_DS_CHECK_KEY_DOES_NOT_EXIST(r_key)
+	  {
+	    PB_DS_CHECK_KEY_DOES_NOT_EXIST(r_key)
+	    return 0;
+	  }
 	else
-	  PB_DS_CHECK_KEY_EXISTS(r_key)
-#endif
-	return &p_e->m_value;
+	  {
+	    PB_DS_CHECK_KEY_EXISTS(r_key)
+	    return &p_e->m_value;
+	  }
       }
 
       inline bool

From 48a3af6f6153ccb088fa2a7dc58cf0c2094a8270 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Tue, 4 May 2021 15:49:38 +0100
Subject: [PATCH 072/164] libstdc++: Fix undefined behaviour in std::string

This fixes a ubsan error when constructing a string with a null pointer:

bits/basic_string.h:534:21: runtime error: applying non-zero offset 18446744073709551615 to null pointer

The _M_construct function only cares whether the second pointer is
non-null, so create a non-null value without undefined arithmetic.

We can also pass the random_access_iterator_tag directly to the
_M_construct function, to avoid going via the tag dispatching
_M_construct_aux, because we know we have pointers not integers here.

libstdc++-v3/ChangeLog:

	* include/bits/basic_string.h (basic_string(const CharT*, const A&)):
	Do not do arithmetic on null pointer.

(cherry picked from commit 789c57bc5fe023fc6dc72ade4afcb0916ff788d3)
---
 libstdc++-v3/include/bits/basic_string.h | 7 ++++++-
 1 file changed, 6 insertions(+), 1 deletion(-)

diff --git a/libstdc++-v3/include/bits/basic_string.h b/libstdc++-v3/include/bits/basic_string.h
index fba7c6f335418..84356adc7ae5f 100644
--- a/libstdc++-v3/include/bits/basic_string.h
+++ b/libstdc++-v3/include/bits/basic_string.h
@@ -531,7 +531,12 @@ _GLIBCXX_BEGIN_NAMESPACE_CXX11
 #endif
       basic_string(const _CharT* __s, const _Alloc& __a = _Alloc())
       : _M_dataplus(_M_local_data(), __a)
-      { _M_construct(__s, __s ? __s + traits_type::length(__s) : __s+npos); }
+      {
+	const _CharT* __end = __s ? __s + traits_type::length(__s)
+	  // We just need a non-null pointer here to get an exception:
+	  : reinterpret_cast<const _CharT*>(__alignof__(_CharT));
+	_M_construct(__s, __end, random_access_iterator_tag());
+      }
 
       /**
        *  @brief  Construct string as multiple characters.

From 9ff7e01b7f772cbdf52deed61897c4a2533f7db6 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Tue, 4 May 2021 16:28:57 +0100
Subject: [PATCH 073/164] libstdc++: Fix null dereferences in std::promise

This fixes some ubsan errors in std::promise:

future:1153:34: runtime error: member call on null pointer of type 'struct element_type'
future:1153:34: runtime error: member access within null pointer of type 'struct element_type'

The problem is that the check for a null pointer is done inside the
_State::__Setter function, which is only evaluated after evaluating the
_M_future->_M_set_result postfix-expression.

This change adds a new promise::_M_state() helper for accessing
_M_future, and moves the check for no shared state into there, instead
of inside the __setter functions. The __setter functions are made
always_inline, to avoid the situation where the linker selects the old
version of set_value (without the _S_check call) and the new version of
__setter (without the _S_check call) and so there is no check. With the
always_inline attribute the old version of set_value will either inline
the old __setter or call an extern definition of it, and the new
set_value will do the check itself, so both versions do the check.

libstdc++-v3/ChangeLog:

	* include/std/future (promise::set_value): Check for existence
	of shared state before dereferncing it.
	(promise::set_exception, promise::set_value_at_thread_exit)
	(promise::set_exception_at_thread_exit): Likewise.
	(promise<R&>::set_value, promise<R&>::set_exception)
	(promise<R&>::set_value_at_thread_exit)
	(promise<R&>::set_exception_at_thread_exit): Likewise.
	(promise<void>::set_value, promise<void>::set_exception)
	(promise<void>::set_value_at_thread_exit)
	(promise<void>::set_exception_at_thread_exit): Likewise.
	* testsuite/30_threads/promise/members/at_thread_exit2.cc:
	Remove unused variable.

(cherry picked from commit 058d6acefe8bac4a66c8e7fb4951276db188e2d8)
---
 libstdc++-v3/include/std/future               | 64 +++++++++++++------
 .../promise/members/at_thread_exit2.cc        |  1 -
 2 files changed, 44 insertions(+), 21 deletions(-)

diff --git a/libstdc++-v3/include/std/future b/libstdc++-v3/include/std/future
index ef15fefa53c3c..09e54c3703baa 100644
--- a/libstdc++-v3/include/std/future
+++ b/libstdc++-v3/include/std/future
@@ -532,26 +532,26 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
         };
 
       template<typename _Res, typename _Arg>
+	__attribute__((__always_inline__))
         static _Setter<_Res, _Arg&&>
-        __setter(promise<_Res>* __prom, _Arg&& __arg)
+        __setter(promise<_Res>* __prom, _Arg&& __arg) noexcept
         {
-	  _S_check(__prom->_M_future);
           return _Setter<_Res, _Arg&&>{ __prom, std::__addressof(__arg) };
         }
 
       template<typename _Res>
+	__attribute__((__always_inline__))
         static _Setter<_Res, __exception_ptr_tag>
-        __setter(exception_ptr& __ex, promise<_Res>* __prom)
+        __setter(exception_ptr& __ex, promise<_Res>* __prom) noexcept
         {
-	  _S_check(__prom->_M_future);
           return _Setter<_Res, __exception_ptr_tag>{ __prom, &__ex };
         }
 
       template<typename _Res>
+	__attribute__((__always_inline__))
 	static _Setter<_Res, void>
-	__setter(promise<_Res>* __prom)
+	__setter(promise<_Res>* __prom) noexcept
 	{
-	  _S_check(__prom->_M_future);
 	  return _Setter<_Res, void>{ __prom };
 	}
 
@@ -1130,36 +1130,44 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       // Setting the result
       void
       set_value(const _Res& __r)
-      { _M_future->_M_set_result(_State::__setter(this, __r)); }
+      { _M_state()._M_set_result(_State::__setter(this, __r)); }
 
       void
       set_value(_Res&& __r)
-      { _M_future->_M_set_result(_State::__setter(this, std::move(__r))); }
+      { _M_state()._M_set_result(_State::__setter(this, std::move(__r))); }
 
       void
       set_exception(exception_ptr __p)
-      { _M_future->_M_set_result(_State::__setter(__p, this)); }
+      { _M_state()._M_set_result(_State::__setter(__p, this)); }
 
       void
       set_value_at_thread_exit(const _Res& __r)
       {
-	_M_future->_M_set_delayed_result(_State::__setter(this, __r),
+	_M_state()._M_set_delayed_result(_State::__setter(this, __r),
 					 _M_future);
       }
 
       void
       set_value_at_thread_exit(_Res&& __r)
       {
-	_M_future->_M_set_delayed_result(
+	_M_state()._M_set_delayed_result(
 	    _State::__setter(this, std::move(__r)), _M_future);
       }
 
       void
       set_exception_at_thread_exit(exception_ptr __p)
       {
-	_M_future->_M_set_delayed_result(_State::__setter(__p, this),
+	_M_state()._M_set_delayed_result(_State::__setter(__p, this),
 					 _M_future);
       }
+
+    private:
+      _State&
+      _M_state()
+      {
+	__future_base::_State_base::_S_check(_M_future);
+	return *_M_future;
+      }
     };
 
   template<typename _Res>
@@ -1241,25 +1249,33 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       // Setting the result
       void
       set_value(_Res& __r)
-      { _M_future->_M_set_result(_State::__setter(this, __r)); }
+      { _M_state()._M_set_result(_State::__setter(this, __r)); }
 
       void
       set_exception(exception_ptr __p)
-      { _M_future->_M_set_result(_State::__setter(__p, this)); }
+      { _M_state()._M_set_result(_State::__setter(__p, this)); }
 
       void
       set_value_at_thread_exit(_Res& __r)
       {
-	_M_future->_M_set_delayed_result(_State::__setter(this, __r),
+	_M_state()._M_set_delayed_result(_State::__setter(this, __r),
 					 _M_future);
       }
 
       void
       set_exception_at_thread_exit(exception_ptr __p)
       {
-	_M_future->_M_set_delayed_result(_State::__setter(__p, this),
+	_M_state()._M_set_delayed_result(_State::__setter(__p, this),
 					 _M_future);
       }
+
+    private:
+      _State&
+      _M_state()
+      {
+	__future_base::_State_base::_S_check(_M_future);
+	return *_M_future;
+      }
     };
 
   /// Explicit specialization for promise<void>
@@ -1333,22 +1349,30 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       // Setting the result
       void
       set_value()
-      { _M_future->_M_set_result(_State::__setter(this)); }
+      { _M_state()._M_set_result(_State::__setter(this)); }
 
       void
       set_exception(exception_ptr __p)
-      { _M_future->_M_set_result(_State::__setter(__p, this)); }
+      { _M_state()._M_set_result(_State::__setter(__p, this)); }
 
       void
       set_value_at_thread_exit()
-      { _M_future->_M_set_delayed_result(_State::__setter(this), _M_future); }
+      { _M_state()._M_set_delayed_result(_State::__setter(this), _M_future); }
 
       void
       set_exception_at_thread_exit(exception_ptr __p)
       {
-	_M_future->_M_set_delayed_result(_State::__setter(__p, this),
+	_M_state()._M_set_delayed_result(_State::__setter(__p, this),
 					 _M_future);
       }
+
+    private:
+      _State&
+      _M_state()
+      {
+	__future_base::_State_base::_S_check(_M_future);
+	return *_M_future;
+      }
     };
 
   template<typename _Ptr_type, typename _Fn, typename _Res>
diff --git a/libstdc++-v3/testsuite/30_threads/promise/members/at_thread_exit2.cc b/libstdc++-v3/testsuite/30_threads/promise/members/at_thread_exit2.cc
index 9f824efde52b0..679d580cee3cc 100644
--- a/libstdc++-v3/testsuite/30_threads/promise/members/at_thread_exit2.cc
+++ b/libstdc++-v3/testsuite/30_threads/promise/members/at_thread_exit2.cc
@@ -118,7 +118,6 @@ void test02()
 void test03()
 {
   std::promise<void> p1;
-  int i = 0;
   p1.set_value();
   try {
     p1.set_value_at_thread_exit();

From 4f354e7447c27f2a9dfa7fee392355a1c9ef046c Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Wed, 5 May 2021 12:41:14 +0100
Subject: [PATCH 074/164] libstdc++: Add tests for std::invoke feature test
 macro

libstdc++-v3/ChangeLog:

	* testsuite/20_util/function_objects/invoke/3.cc: Check feature
	test macro.
	* testsuite/20_util/function_objects/invoke/version.cc: New test.

(cherry picked from commit 29745bf06276b9628d08ef1c9e28890cc56df4aa)
---
 .../testsuite/20_util/function_objects/invoke/3.cc       | 7 ++++++-
 .../testsuite/20_util/function_objects/invoke/version.cc | 9 +++++++++
 2 files changed, 15 insertions(+), 1 deletion(-)
 create mode 100644 libstdc++-v3/testsuite/20_util/function_objects/invoke/version.cc

diff --git a/libstdc++-v3/testsuite/20_util/function_objects/invoke/3.cc b/libstdc++-v3/testsuite/20_util/function_objects/invoke/3.cc
index 5ffc5dedbab2a..40e068e86fd3a 100644
--- a/libstdc++-v3/testsuite/20_util/function_objects/invoke/3.cc
+++ b/libstdc++-v3/testsuite/20_util/function_objects/invoke/3.cc
@@ -15,11 +15,16 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <functional>
 
+#ifndef __cpp_lib_invoke
+# error Feature-test macro for invoke is missing in <functional>
+#elif __cpp_lib_invoke < 201411L
+# error Feature-test macro for invoke has the wrong value in <functional>
+#endif
+
 struct abstract {
   virtual ~abstract() = 0;
   void operator()() noexcept;
diff --git a/libstdc++-v3/testsuite/20_util/function_objects/invoke/version.cc b/libstdc++-v3/testsuite/20_util/function_objects/invoke/version.cc
new file mode 100644
index 0000000000000..cf1a46a1ada92
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/function_objects/invoke/version.cc
@@ -0,0 +1,9 @@
+// { dg-do compile { target c++17 } }
+
+#include <version>
+
+#ifndef __cpp_lib_invoke
+# error Feature-test macro for invoke is missing in <version>
+#elif __cpp_lib_invoke < 201411L
+# error Feature-test macro for invoke has the wrong value in <version>
+#endif

From ca7d2f2ec9142995179a5d832a946b50de05e659 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Fri, 30 Apr 2021 14:07:28 +0100
Subject: [PATCH 075/164] libstdc++: Implement LWG 1203 for rvalue iostreams

This implements the resolution of LWG 1203 so that the constraints for
rvalue stream insertion/extraction are simpler, and the return type is
the original rvalue stream type not its base class.

Signed-off-by: Jonathan Wakely <jwakely@redhat.com>

libstdc++-v3/ChangeLog:

	* include/std/istream (operator>>(Istream&&, x&)): Simplify, as
	per LWG 1203.
	* include/std/ostream (operator<<(Ostream&&, const x&)):
	Likewise.
	* testsuite/27_io/basic_istream/extractors_character/char/lwg2499_neg.cc:
	Adjust dg-error pattern.
	* testsuite/27_io/basic_istream/extractors_character/wchar_t/lwg2499_neg.cc:
	Likewise.
	* testsuite/27_io/basic_istream/extractors_other/char/4.cc: Define
	is_extractable trait to replace std::__is_extractable. Make it
	work with rvalue streams as well as lvalues, to replace f() and
	g() helper functions.
	* testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc:
	Likewise.
	* testsuite/27_io/basic_ostream/inserters_other/char/6.cc:
	Define is_insertable trait to replace std::__is_insertable. Make
	it work with rvalue streams as well as lvalues, to replace f()
	and g() helper functions.
	* testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/io/dr2989.cc: Prune additional
	errors from new constraints.
	* testsuite/27_io/rvalue_streams-2.cc: Remove PR 80675 checks,
	which are no longer expected to compile.
	* testsuite/27_io/rvalue_streams.cc: Adjust existing test.
	Verify LWG 1203 changes.

(cherry picked from commit aa475c4ac80733f85ba47b109fc1900f05e810e2)
---
 libstdc++-v3/include/std/istream              | 74 +++-------------
 libstdc++-v3/include/std/ostream              | 87 +++++++------------
 .../extractors_character/char/lwg2499_neg.cc  | 12 +--
 .../wchar_t/lwg2499_neg.cc                    |  4 +-
 .../basic_istream/extractors_other/char/4.cc  | 77 ++++++----------
 .../extractors_other/wchar_t/4.cc             | 77 ++++++----------
 .../basic_ostream/inserters_other/char/6.cc   | 78 ++++++-----------
 .../inserters_other/wchar_t/6.cc              | 78 ++++++-----------
 .../27_io/filesystem/path/io/dr2989.cc        |  1 +
 .../testsuite/27_io/rvalue_streams-2.cc       | 11 ---
 .../testsuite/27_io/rvalue_streams.cc         | 74 ++++++++++++++--
 11 files changed, 233 insertions(+), 340 deletions(-)

diff --git a/libstdc++-v3/include/std/istream b/libstdc++-v3/include/std/istream
index 1e5ebe4e88cd7..ea34cce62980b 100644
--- a/libstdc++-v3/include/std/istream
+++ b/libstdc++-v3/include/std/istream
@@ -953,80 +953,34 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     ws(basic_istream<_CharT, _Traits>& __is);
 
 #if __cplusplus >= 201103L
-  template<typename _Ch, typename _Up>
-    basic_istream<_Ch, _Up>&
-    __is_convertible_to_basic_istream_test(basic_istream<_Ch, _Up>*);
-
-  template<typename _Tp, typename = void>
-    struct __is_convertible_to_basic_istream_impl
-    {
-      using __istream_type = void;
-    };
-
-  template<typename _Tp>
-    using __do_is_convertible_to_basic_istream_impl =
-    decltype(__is_convertible_to_basic_istream_test
-	     (declval<typename remove_reference<_Tp>::type*>()));
-
-  template<typename _Tp>
-    struct __is_convertible_to_basic_istream_impl
-    <_Tp,
-     __void_t<__do_is_convertible_to_basic_istream_impl<_Tp>>>
-    {
-      using __istream_type =
-	__do_is_convertible_to_basic_istream_impl<_Tp>;
-    };
-
-  template<typename _Tp>
-    struct __is_convertible_to_basic_istream
-    : __is_convertible_to_basic_istream_impl<_Tp>
-    {
-    public:
-      using type = __not_<is_void<
-        typename __is_convertible_to_basic_istream_impl<_Tp>::__istream_type>>;
-      constexpr static bool value = type::value;
-    };
-
-  template<typename _Istream, typename _Tp, typename = void>
-    struct __is_extractable : false_type {};
-
-  template<typename _Istream, typename _Tp>
-    struct __is_extractable<_Istream, _Tp,
-			    __void_t<decltype(declval<_Istream&>()
-					      >> declval<_Tp>())>>
-    : true_type {};
-
-  template<typename _Istream>
-    using __rvalue_istream_type =
-      typename __is_convertible_to_basic_istream<
-	_Istream>::__istream_type;
-
-  // [27.7.1.6] Rvalue stream extraction
+  // C++11 27.7.2.6 Rvalue stream extraction [istream.rvalue]
   // _GLIBCXX_RESOLVE_LIB_DEFECTS
   // 2328. Rvalue stream extraction should use perfect forwarding
+  // 1203. More useful rvalue stream insertion
+
+  // SFINAE helper to check constraints for operator>>(Istream&&, T&&).
+  // If the constraints are satisfied, it is an alias for Istream&&.
+  template<typename _Is, typename _Tp,
+	   typename = decltype(std::__rval_streamable<_Is>()
+				 >> std::declval<_Tp>())>
+    using __rvalue_stream_extraction_t = _Is&&;
+
   /**
    *  @brief  Generic extractor for rvalue stream
    *  @param  __is  An input stream.
    *  @param  __x  A reference to the extraction target.
-   *  @return  is
+   *  @return  __is
    *
    *  This is just a forwarding function to allow extraction from
    *  rvalue streams since they won't bind to the extractor functions
    *  that take an lvalue reference.
   */
   template<typename _Istream, typename _Tp>
-    inline
-    typename enable_if<__and_<__not_<is_lvalue_reference<_Istream>>,
-			      __is_convertible_to_basic_istream<_Istream>,
-			      __is_extractable<
-				__rvalue_istream_type<_Istream>,
-				_Tp&&>>::value,
-		       __rvalue_istream_type<_Istream>>::type
+    inline __rvalue_stream_extraction_t<_Istream, _Tp>
     operator>>(_Istream&& __is, _Tp&& __x)
     {
-      __rvalue_istream_type<_Istream> __ret_is = __is;
-      __ret_is >> std::forward<_Tp>(__x);
-      return __ret_is;
+      __is >> std::forward<_Tp>(__x);
+      return std::move(__is);
     }
 #endif // C++11
 
diff --git a/libstdc++-v3/include/std/ostream b/libstdc++-v3/include/std/ostream
index a70221f251353..fdd2a87665cc2 100644
--- a/libstdc++-v3/include/std/ostream
+++ b/libstdc++-v3/include/std/ostream
@@ -704,77 +704,52 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     { return __os.flush(); }
 
 #if __cplusplus >= 201103L
-  template<typename _Ch, typename _Up>
-    basic_ostream<_Ch, _Up>&
-    __is_convertible_to_basic_ostream_test(basic_ostream<_Ch, _Up>*);
-
-  template<typename _Tp, typename = void>
-    struct __is_convertible_to_basic_ostream_impl
-    {
-      using __ostream_type = void;
-    };
-
+  // C++11 27.7.3.9 Rvalue stream insertion [ostream.rvalue]
+  // _GLIBCXX_RESOLVE_LIB_DEFECTS
+  // 1203. More useful rvalue stream insertion
+
+  // SFINAE helper to check constraints for operator<<(Ostream&&, const T&).
+  // If Ostream is publicly and unambiguously derived from ios_base, then
+  // __rval_streamable<Ostream>() is equivalent to declval<Ostream&>().
+  // Otherwise, it results in a substitution failure. Specifically, it will
+  // fail if Ostream is an lvalue reference or the same type as ios_base.
+  // Use concepts if possible because they're cheaper to evaluate.
+#if __cpp_lib_concepts
   template<typename _Tp>
-    using __do_is_convertible_to_basic_ostream_impl =
-    decltype(__is_convertible_to_basic_ostream_test
-	     (declval<typename remove_reference<_Tp>::type*>()));
-
-  template<typename _Tp>
-    struct __is_convertible_to_basic_ostream_impl
-    <_Tp,
-     __void_t<__do_is_convertible_to_basic_ostream_impl<_Tp>>>
-    {
-      using __ostream_type =
-	__do_is_convertible_to_basic_ostream_impl<_Tp>;
-    };
-
-  template<typename _Tp>
-    struct __is_convertible_to_basic_ostream
-    : __is_convertible_to_basic_ostream_impl<_Tp>
-    {
-    public:
-      using type = __not_<is_void<
-        typename __is_convertible_to_basic_ostream_impl<_Tp>::__ostream_type>>;
-      constexpr static bool value = type::value;
-    };
-
-  template<typename _Ostream, typename _Tp, typename = void>
-    struct __is_insertable : false_type {};
-
-  template<typename _Ostream, typename _Tp>
-    struct __is_insertable<_Ostream, _Tp,
-			   __void_t<decltype(declval<_Ostream&>()
-					     << declval<const _Tp&>())>>
-				    : true_type {};
+    requires (!is_same_v<_Tp, ios_base>)
+      && requires (_Tp* __t, ios_base* __b) { __b = __t; }
+    _Tp&
+    __rval_streamable();
+#else
+  template<typename _Tp,
+	   typename = _Require<__not_<__is_one_of<_Tp, _Tp&, ios_base>>>>
+    _Tp&
+    __rval_streamable(ios_base* = (_Tp*)nullptr);
+#endif
 
-  template<typename _Ostream>
-    using __rvalue_ostream_type =
-      typename __is_convertible_to_basic_ostream<
-	_Ostream>::__ostream_type;
+  // SFINAE helper to check constraints for operator<<(Ostream&&, const T&).
+  // If the constraints are satisfied, it is an alias for Ostream&&.
+  template<typename _Os, typename _Tp,
+	   typename = decltype(std::__rval_streamable<_Os>()
+				 << std::declval<const _Tp&>())>
+    using __rvalue_stream_insertion_t = _Os&&;
 
   /**
    *  @brief  Generic inserter for rvalue stream
    *  @param  __os  An input stream.
    *  @param  __x  A reference to the object being inserted.
-   *  @return  os
+   *  @return  __os
    *
    *  This is just a forwarding function to allow insertion to
    *  rvalue streams since they won't bind to the inserter functions
    *  that take an lvalue reference.
   */
   template<typename _Ostream, typename _Tp>
-    inline
-    typename enable_if<__and_<__not_<is_lvalue_reference<_Ostream>>,
-			      __is_convertible_to_basic_ostream<_Ostream>,
-			      __is_insertable<
-				__rvalue_ostream_type<_Ostream>,
-				const _Tp&>>::value,
-		       __rvalue_ostream_type<_Ostream>>::type
+    inline __rvalue_stream_insertion_t<_Ostream, _Tp>
     operator<<(_Ostream&& __os, const _Tp& __x)
     {
-      __rvalue_ostream_type<_Ostream> __ret_os = __os;
-      __ret_os << __x;
-      return __ret_os;
+      __os << __x;
+      return std::move(__os);
     }
 
 #if __cplusplus > 201703L && _GLIBCXX_USE_CXX11_ABI
diff --git a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_character/char/lwg2499_neg.cc b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_character/char/lwg2499_neg.cc
index 7a39e7c1a3cdd..abd68af8a9a89 100644
--- a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_character/char/lwg2499_neg.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_character/char/lwg2499_neg.cc
@@ -26,9 +26,9 @@
 void
 test01(std::istream& in, char* pc, signed char* sc, unsigned char* uc)
 {
-  in >> pc; // { dg-error "here" }
-  in >> sc; // { dg-error "here" }
-  in >> uc; // { dg-error "here" }
+  in >> pc; // { dg-error "no match" }
+  in >> sc; // { dg-error "no match" }
+  in >> uc; // { dg-error "no match" }
 }
 
 struct CT : std::char_traits<char> { };
@@ -37,9 +37,9 @@ void
 test02(std::basic_istream<char, CT>& in, char* pc, signed char* sc,
        unsigned char* uc)
 {
-  in >> pc; // { dg-error "here" }
-  in >> sc; // { dg-error "here" }
-  in >> uc; // { dg-error "here" }
+  in >> pc; // { dg-error "no match" }
+  in >> sc; // { dg-error "no match" }
+  in >> uc; // { dg-error "no match" }
 }
 
 // { dg-excess-errors "" }
diff --git a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_character/wchar_t/lwg2499_neg.cc b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_character/wchar_t/lwg2499_neg.cc
index bc8dfacf5f5b6..214f8d6a931f4 100644
--- a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_character/wchar_t/lwg2499_neg.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_character/wchar_t/lwg2499_neg.cc
@@ -26,7 +26,7 @@
 void
 test01(std::wistream& in, wchar_t* wc)
 {
-  in >> wc; // { dg-error "here" }
+  in >> wc; // { dg-error "no match" }
 }
 
 struct WT : std::char_traits<wchar_t> { };
@@ -34,7 +34,7 @@ struct WT : std::char_traits<wchar_t> { };
 void
 test02(std::basic_istream<wchar_t, WT>& in, wchar_t* wc)
 {
-  in >> wc; // { dg-error "here" }
+  in >> wc; // { dg-error "no match" }
 }
 
 // { dg-excess-errors "" }
diff --git a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/4.cc b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/4.cc
index 5ad1c1b4e47a1..9f1e293474fd3 100644
--- a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/4.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/4.cc
@@ -21,6 +21,21 @@
 
 #include <sstream>
 
+template<typename Istream, typename T, typename = void>
+  struct is_extractable : std::false_type
+  { };
+
+template<typename> using void_t = void;
+
+template<typename Istream, typename T>
+  using extract_result
+    = decltype(std::declval<Istream>() >> std::declval<const T&>());
+
+template<typename Istream, typename T>
+  struct is_extractable<Istream, T, void_t<extract_result<Istream, T>>>
+  : std::true_type
+  { };
+
 struct X {};
 std::istream& operator>>(std::istream&, X&) = delete;
 
@@ -30,20 +45,6 @@ std::istream& operator>>(std::istream& is, Y&&) {return is;}
 
 struct Z{};
 
-template <class T>
-auto f(T&&) -> decltype(void(std::declval<std::istream&>()
-			     >> std::declval<T&&>()),
-			std::true_type());
-
-std::false_type f(...);
-
-template <class T>
-auto g(T&&) -> decltype(void(std::declval<std::istream&&>()
-			     >> std::declval<T&&>()),
-			std::true_type());
-
-std::false_type g(...);
-
 void test01()
 {
   Y y;
@@ -52,42 +53,18 @@ void test01()
   is >> Y();
   std::istringstream() >> y;
   std::istringstream() >> Y();
-  static_assert(!std::__is_extractable<std::istream&, X&>::value, "");
-  static_assert(!std::__is_extractable<std::istream&&, X&>::value, "");
-  static_assert(!std::__is_extractable<std::istream&, X&&>::value, "");
-  static_assert(!std::__is_extractable<std::istream&&, X&&>::value, "");
-  static_assert(std::__is_extractable<std::istream&, Y&>::value, "");
-  static_assert(std::__is_extractable<std::istream&&, Y&>::value, "");
-  static_assert(std::__is_extractable<std::istream&, Y&&>::value, "");
-  static_assert(std::__is_extractable<std::istream&&, Y&&>::value, "");
-  static_assert(!std::__is_extractable<std::istream&, Z&>::value, "");
-  static_assert(!std::__is_extractable<std::istream&&, Z&>::value, "");
-  static_assert(!std::__is_extractable<std::istream&, Z&&>::value, "");
-  static_assert(!std::__is_extractable<std::istream&&, Z&&>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<X&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<X&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Y&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Y&&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Z&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Z&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<X&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<X&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Y&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Y&&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Z&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Z&&>())),
-		std::false_type>::value, "");
+  static_assert(!is_extractable<std::istream&, X&>::value, "");
+  static_assert(!is_extractable<std::istream&&, X&>::value, "");
+  static_assert(!is_extractable<std::istream&, X&&>::value, "");
+  static_assert(!is_extractable<std::istream&&, X&&>::value, "");
+  static_assert(is_extractable<std::istream&, Y&>::value, "");
+  static_assert(is_extractable<std::istream&&, Y&>::value, "");
+  static_assert(is_extractable<std::istream&, Y&&>::value, "");
+  static_assert(is_extractable<std::istream&&, Y&&>::value, "");
+  static_assert(!is_extractable<std::istream&, Z&>::value, "");
+  static_assert(!is_extractable<std::istream&&, Z&>::value, "");
+  static_assert(!is_extractable<std::istream&, Z&&>::value, "");
+  static_assert(!is_extractable<std::istream&&, Z&&>::value, "");
 }
 
 int main()
diff --git a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc
index 94f2d9da09db0..fc7f5505bf468 100644
--- a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc
@@ -21,6 +21,21 @@
 
 #include <sstream>
 
+template<typename Istream, typename T, typename = void>
+  struct is_extractable : std::false_type
+  { };
+
+template<typename> using void_t = void;
+
+template<typename Istream, typename T>
+  using extract_result
+    = decltype(std::declval<Istream>() >> std::declval<const T&>());
+
+template<typename Istream, typename T>
+  struct is_extractable<Istream, T, void_t<extract_result<Istream, T>>>
+  : std::true_type
+  { };
+
 struct X {};
 std::wistream& operator>>(std::wistream&, X&) = delete;
 
@@ -30,20 +45,6 @@ std::wistream& operator>>(std::wistream& is, Y&&) {return is;}
 
 struct Z{};
 
-template <class T>
-auto f(T&&) -> decltype(void(std::declval<std::wistream&>()
-			     >> std::declval<T&&>()),
-			std::true_type());
-
-std::false_type f(...);
-
-template <class T>
-auto g(T&&) -> decltype(void(std::declval<std::wistream&&>()
-			     >> std::declval<T&&>()),
-			std::true_type());
-
-std::false_type g(...);
-
 void test01()
 {
   Y y;
@@ -52,42 +53,18 @@ void test01()
   is >> Y();
   std::wistringstream() >> y;
   std::wistringstream() >> Y();
-  static_assert(!std::__is_extractable<std::wistream&, X&>::value, "");
-  static_assert(!std::__is_extractable<std::wistream&&, X&>::value, "");
-  static_assert(!std::__is_extractable<std::wistream&, X&&>::value, "");
-  static_assert(!std::__is_extractable<std::wistream&&, X&&>::value, "");
-  static_assert(std::__is_extractable<std::wistream&, Y&>::value, "");
-  static_assert(std::__is_extractable<std::wistream&&, Y&>::value, "");
-  static_assert(std::__is_extractable<std::wistream&, Y&&>::value, "");
-  static_assert(std::__is_extractable<std::wistream&&, Y&&>::value, "");
-  static_assert(!std::__is_extractable<std::wistream&, Z&>::value, "");
-  static_assert(!std::__is_extractable<std::wistream&&, Z&>::value, "");
-  static_assert(!std::__is_extractable<std::wistream&, Z&&>::value, "");
-  static_assert(!std::__is_extractable<std::wistream&&, Z&&>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<X&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<X&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Y&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Y&&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Z&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Z&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<X&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<X&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Y&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Y&&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Z&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Z&&>())),
-		std::false_type>::value, "");
+  static_assert(!is_extractable<std::wistream&, X&>::value, "");
+  static_assert(!is_extractable<std::wistream&&, X&>::value, "");
+  static_assert(!is_extractable<std::wistream&, X&&>::value, "");
+  static_assert(!is_extractable<std::wistream&&, X&&>::value, "");
+  static_assert(is_extractable<std::wistream&, Y&>::value, "");
+  static_assert(is_extractable<std::wistream&&, Y&>::value, "");
+  static_assert(is_extractable<std::wistream&, Y&&>::value, "");
+  static_assert(is_extractable<std::wistream&&, Y&&>::value, "");
+  static_assert(!is_extractable<std::wistream&, Z&>::value, "");
+  static_assert(!is_extractable<std::wistream&&, Z&>::value, "");
+  static_assert(!is_extractable<std::wistream&, Z&&>::value, "");
+  static_assert(!is_extractable<std::wistream&&, Z&&>::value, "");
 }
 
 int main()
diff --git a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/6.cc b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/6.cc
index b86763c60fd37..4801afcba6c07 100644
--- a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/6.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/6.cc
@@ -21,6 +21,22 @@
 
 #include <sstream>
 
+template<typename Ostream, typename T, typename = void>
+  struct is_insertable
+  : std::false_type
+  { };
+
+template<typename> using void_t = void;
+
+template<typename Ostream, typename T>
+  using insert_result
+    = decltype(std::declval<Ostream>() << std::declval<const T&>());
+
+template<typename Ostream, typename T>
+  struct is_insertable<Ostream, T, void_t<insert_result<Ostream, T>>>
+  : std::true_type
+  { };
+
 struct X {};
 std::ostream& operator<<(std::ostream&, const X&) = delete;
 
@@ -30,20 +46,6 @@ std::ostream& operator<<(std::ostream&& os, const Y&) {return os;}
 
 struct Z{};
 
-template <class T>
-auto f(T&&) -> decltype(void(std::declval<std::ostream&>()
-			     << std::declval<T&&>()),
-			std::true_type());
-
-std::false_type f(...);
-
-template <class T>
-auto g(T&&) -> decltype(void(std::declval<std::ostream&&>()
-			     << std::declval<T&&>()),
-			std::true_type());
-
-std::false_type g(...);
-
 void test01()
 {
   Y y;
@@ -52,42 +54,18 @@ void test01()
   os << Y();
   std::ostringstream() << y;
   std::ostringstream() << Y();
-  static_assert(!std::__is_insertable<std::ostream&, X&>::value, "");
-  static_assert(!std::__is_insertable<std::ostream&&, X&>::value, "");
-  static_assert(!std::__is_insertable<std::ostream&, X&&>::value, "");
-  static_assert(!std::__is_insertable<std::ostream&&, X&&>::value, "");
-  static_assert(std::__is_insertable<std::ostream&, Y&>::value, "");
-  static_assert(std::__is_insertable<std::ostream&&, Y&&>::value, "");
-  static_assert(std::__is_insertable<std::ostream&, Y&>::value, "");
-  static_assert(std::__is_insertable<std::ostream&&, Y&&>::value, "");
-  static_assert(!std::__is_insertable<std::ostream&, Z&>::value, "");
-  static_assert(!std::__is_insertable<std::ostream&&, Z&>::value, "");
-  static_assert(!std::__is_insertable<std::ostream&, Z&&>::value, "");
-  static_assert(!std::__is_insertable<std::ostream&&, Z&&>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<X&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<X&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Y&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Y&&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Z&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Z&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<X&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<X&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Y&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Y&&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Z&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Z&&>())),
-		std::false_type>::value, "");
+  static_assert(!is_insertable<std::ostream&, X&>::value, "");
+  static_assert(!is_insertable<std::ostream&&, X&>::value, "");
+  static_assert(!is_insertable<std::ostream&, X&&>::value, "");
+  static_assert(!is_insertable<std::ostream&&, X&&>::value, "");
+  static_assert(is_insertable<std::ostream&, Y&>::value, "");
+  static_assert(is_insertable<std::ostream&&, Y&&>::value, "");
+  static_assert(is_insertable<std::ostream&, Y&>::value, "");
+  static_assert(is_insertable<std::ostream&&, Y&&>::value, "");
+  static_assert(!is_insertable<std::ostream&, Z&>::value, "");
+  static_assert(!is_insertable<std::ostream&&, Z&>::value, "");
+  static_assert(!is_insertable<std::ostream&, Z&&>::value, "");
+  static_assert(!is_insertable<std::ostream&&, Z&&>::value, "");
 }
 
 int main()
diff --git a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc
index 0994a949652c9..3efeb804b00e4 100644
--- a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc
@@ -21,6 +21,22 @@
 
 #include <sstream>
 
+template<typename Ostream, typename T, typename = void>
+  struct is_insertable
+  : std::false_type
+  { };
+
+template<typename> using void_t = void;
+
+template<typename Ostream, typename T>
+  using insert_result
+    = decltype(std::declval<Ostream>() << std::declval<const T&>());
+
+template<typename Ostream, typename T>
+  struct is_insertable<Ostream, T, void_t<insert_result<Ostream, T>>>
+  : std::true_type
+  { };
+
 struct X {};
 std::wostream& operator<<(std::wostream&, const X&) = delete;
 
@@ -30,20 +46,6 @@ std::wostream& operator<<(std::wostream&& os, const Y&) {return os;}
 
 struct Z{};
 
-template <class T>
-auto f(T&&) -> decltype(void(std::declval<std::wostream&>()
-			     << std::declval<T&&>()),
-			std::true_type());
-
-std::false_type f(...);
-
-template <class T>
-auto g(T&&) -> decltype(void(std::declval<std::wostream&&>()
-			     << std::declval<T&&>()),
-			std::true_type());
-
-std::false_type g(...);
-
 void test01()
 {
   Y y;
@@ -52,42 +54,18 @@ void test01()
   os << Y();
   std::wostringstream() << y;
   std::wostringstream() << Y();
-  static_assert(!std::__is_insertable<std::wostream&, X&>::value, "");
-  static_assert(!std::__is_insertable<std::wostream&&, X&>::value, "");
-  static_assert(!std::__is_insertable<std::wostream&, X&&>::value, "");
-  static_assert(!std::__is_insertable<std::wostream&&, X&&>::value, "");
-  static_assert(std::__is_insertable<std::wostream&, Y&>::value, "");
-  static_assert(std::__is_insertable<std::wostream&&, Y&&>::value, "");
-  static_assert(std::__is_insertable<std::wostream&, Y&>::value, "");
-  static_assert(std::__is_insertable<std::wostream&&, Y&&>::value, "");
-  static_assert(!std::__is_insertable<std::wostream&, Z&>::value, "");
-  static_assert(!std::__is_insertable<std::wostream&&, Z&>::value, "");
-  static_assert(!std::__is_insertable<std::wostream&, Z&&>::value, "");
-  static_assert(!std::__is_insertable<std::wostream&&, Z&&>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<X&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<X&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Y&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Y&&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Z&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(f(std::declval<Z&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<X&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<X&&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Y&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Y&&>())),
-		std::true_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Z&>())),
-		std::false_type>::value, "");
-  static_assert(std::is_same<decltype(g(std::declval<Z&&>())),
-		std::false_type>::value, "");
+  static_assert(!is_insertable<std::wostream&, X&>::value, "");
+  static_assert(!is_insertable<std::wostream&&, X&>::value, "");
+  static_assert(!is_insertable<std::wostream&, X&&>::value, "");
+  static_assert(!is_insertable<std::wostream&&, X&&>::value, "");
+  static_assert(is_insertable<std::wostream&, Y&>::value, "");
+  static_assert(is_insertable<std::wostream&&, Y&&>::value, "");
+  static_assert(is_insertable<std::wostream&, Y&>::value, "");
+  static_assert(is_insertable<std::wostream&&, Y&&>::value, "");
+  static_assert(!is_insertable<std::wostream&, Z&>::value, "");
+  static_assert(!is_insertable<std::wostream&&, Z&>::value, "");
+  static_assert(!is_insertable<std::wostream&, Z&&>::value, "");
+  static_assert(!is_insertable<std::wostream&&, Z&&>::value, "");
 }
 
 int main()
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
index c5cda77647776..609f1c32a0e3c 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
@@ -33,3 +33,4 @@ void foo(std::iostream& s) {
   s >> p; // { dg-error "no match" }
 }
 // { dg-prune-output "no type .*enable_if" }
+// { dg-prune-output "no matching function for call to '__rval_streamable" }
diff --git a/libstdc++-v3/testsuite/27_io/rvalue_streams-2.cc b/libstdc++-v3/testsuite/27_io/rvalue_streams-2.cc
index 7aa09aef4713e..d2b6997e4b92b 100644
--- a/libstdc++-v3/testsuite/27_io/rvalue_streams-2.cc
+++ b/libstdc++-v3/testsuite/27_io/rvalue_streams-2.cc
@@ -58,16 +58,7 @@ struct X { };
 std::ostream& operator<<(std::ostream& os, const X&) { return os; }
 std::istream& operator>>(std::istream& is, X&&) { return is; }
 
-struct O : std::ostream { };
-
-void operator<<(O&, X) = delete;
-
-struct I : std::istream { };
-
-void operator>>(I&, X) = delete;
-
 // PR libstdc++/65543
-// PR libstdc++/80675
 // PR libstdc++/80940
 int main()
 {
@@ -82,6 +73,4 @@ int main()
   MyStream2 stream2{};
   stream2 << "aaa";
   stream2 >> msi;
-  O{} << X{};
-  I{} >> X{};
 }
diff --git a/libstdc++-v3/testsuite/27_io/rvalue_streams.cc b/libstdc++-v3/testsuite/27_io/rvalue_streams.cc
index def706999a310..3d359091b76a8 100644
--- a/libstdc++-v3/testsuite/27_io/rvalue_streams.cc
+++ b/libstdc++-v3/testsuite/27_io/rvalue_streams.cc
@@ -25,8 +25,6 @@ void
 test01()
 {
   int i = 1742;
-  // This usage isn't supported by the current draft.
-  // std::string result = (std::ostringstream() << i).str();
   std::ostringstream() << i;
   std::string result ("1742");
   int i2;
@@ -45,10 +43,10 @@ test02()
 {
   X x;
   std::istringstream is;
-  auto& ref1 = (std::move(is) >> x);
+  auto&& ref1 = (std::move(is) >> x);
   VERIFY( &ref1 == &is );
   VERIFY( x.as_rvalue == false );
-  auto& ref2 = (std::move(is) >> std::move(x));
+  auto&& ref2 = (std::move(is) >> std::move(x));
   VERIFY( &ref2 == &is );
   VERIFY( x.as_rvalue == true );
 
@@ -57,6 +55,71 @@ test02()
   std::istringstream("x") >> &arr[0];
 #endif
   std::istringstream("x") >> arr;
+  VERIFY( std::string(arr) == "x" );
+}
+
+// LWG 1203 More useful rvalue stream insertion
+void
+test03()
+{
+  int i = 1203;
+  std::string result = (std::ostringstream() << "i = " << i).str();
+  VERIFY( result == "i = 1203" );
+
+  std::ostringstream os;
+  std::ostringstream&& ros = std::move(os) << result;
+  VERIFY( &ros == &os );
+  VERIFY( ros.str() == result );
+
+  std::stringstream ss;
+  std::stringstream&& rss = std::move(ss) << result;
+  VERIFY( &rss == &ss );
+  VERIFY( rss.str() == result );
+
+  std::istringstream is("first second third");
+  std::istringstream&& ris = std::move(is) >> result;
+  VERIFY( &ris == &is );
+  VERIFY( result == "first" );
+
+  std::stringstream ss2("fourth fifth sixth");
+  std::stringstream&& rss2 = std::move(ss2) >> result;
+  VERIFY( &rss2 == &ss2 );
+  VERIFY( result == "fourth" );
+}
+
+struct A { friend void operator<<(std::ios_base&, A) { } };
+
+struct O : private std::ios_base { friend void operator<<(O&, int) { } };
+
+template<typename Ostream, typename T, typename = void>
+  struct is_insertable
+  : std::false_type
+  { };
+
+template<typename> using void_t = void;
+
+template<typename Ostream, typename T>
+  using insert_result
+    = decltype(std::declval<Ostream>() << std::declval<const T&>());
+
+template<typename Ostream, typename T>
+  struct is_insertable<Ostream, T, void_t<insert_result<Ostream, T>>>
+  : std::true_type
+  { };
+
+// LWG 1203 negative tests
+void
+test04()
+{
+  static_assert( is_insertable<std::ios_base&, A>::value,
+      "valid using the friend operator<<" );
+  static_assert( !is_insertable<std::ios_base&&, A>::value,
+      "ill-formed because ios_base is not derived from ios_base" );
+
+  static_assert( is_insertable<O&, int>::value,
+      "valid using the friend operator<<" );
+  static_assert( !is_insertable<O&&, int>::value,
+      "ill-formed because O is not publicly derived from ios_base" );
 }
 
 int
@@ -64,5 +127,6 @@ main()
 {
   test01();
   test02();
-  return 0;
+  test03();
+  test04();
 }

From 3068b39d129aaefecac642183a8f49e49bdee8bc Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Fri, 7 May 2021 00:18:16 +0000
Subject: [PATCH 076/164] Daily bump.

---
 gcc/ChangeLog           |  31 ++++++++++++
 gcc/DATESTAMP           |   2 +-
 gcc/testsuite/ChangeLog |  25 ++++++++++
 libgomp/ChangeLog       |   7 +++
 libstdc++-v3/ChangeLog  | 108 ++++++++++++++++++++++++++++++++++++++++
 5 files changed, 172 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 877007450d522..46971cf134403 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,34 @@
+2021-05-06  Marius Hillenbrand  <mhillen@linux.ibm.com>
+
+	Backported from master:
+	2021-05-06  Marius Hillenbrand  <mhillen@linux.ibm.com>
+
+	* config/s390/s390-builtins.def (O_M5, O1_M5, ...): Remove unused macros.
+	(s390_vec_permi_s64, s390_vec_permi_b64, s390_vec_permi_u64)
+	(s390_vec_permi_dbl, s390_vpdi): Use the O3_U2 type for the immediate
+	operand.
+	* config/s390/s390.c (s390_const_operand_ok): Remove unused
+	values.
+
+2021-05-06  Roman Zhuykov  <zhroma@ispras.ru>
+
+	Backported from master:
+	2021-04-30  Roman Zhuykov  <zhroma@ispras.ru>
+
+	PR rtl-optimization/100225
+	PR rtl-optimization/84878
+	* modulo-sched.c (sms_schedule): Use note_stores to skip loops
+	where we have an instruction which touches (writes) any hard
+	register from df->regular_block_artificial_uses set.
+	Allow not-single-set instruction only right before basic block
+	tail.
+
+2021-05-06  Ilya Leoshkevich  <iii@linux.ibm.com>
+
+	PR target/100217
+	* config/s390/s390.c (s390_hard_fp_reg_p): New function.
+	(s390_md_asm_adjust): Handle hard registers.
+
 2021-05-05  Eric Botcazou  <ebotcazou@adacore.com>
 
 	PR target/100402
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 8e159d5342000..b5beafed7dfab 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210506
+20210507
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index ddc62a3956a42..fb35a283fa326 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,28 @@
+2021-05-06  Marius Hillenbrand  <mhillen@linux.ibm.com>
+
+	Backported from master:
+	2021-05-06  Marius Hillenbrand  <mhillen@linux.ibm.com>
+
+	* gcc.target/s390/zvector/imm-range-error-1.c: Fix test for
+	__builtin_s390_vpdi.
+	* gcc.target/s390/zvector/vec-permi.c: New test for builtin
+	vec_permi.
+
+2021-05-06  Roman Zhuykov  <zhroma@ispras.ru>
+
+	Backported from master:
+	2021-04-30  Roman Zhuykov  <zhroma@ispras.ru>
+
+	PR rtl-optimization/100225
+	PR rtl-optimization/84878
+	* gcc.dg/pr100225.c: New test.
+
+2021-05-06  Ilya Leoshkevich  <iii@linux.ibm.com>
+
+	PR target/100217
+	* gcc.target/s390/vector/long-double-asm-in-out-hard-fp-reg.c: New test.
+	* gcc.target/s390/vector/long-double-asm-inout-hard-fp-reg.c: New test.
+
 2021-05-05  Eric Botcazou  <ebotcazou@adacore.com>
 
 	* gcc.c-torture/execute/20210505-1.c: New test.
diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
index 7c682e9a07d03..6531ccb746482 100644
--- a/libgomp/ChangeLog
+++ b/libgomp/ChangeLog
@@ -1,3 +1,10 @@
+2021-05-06  Roman Zhuykov  <zhroma@ispras.ru>
+
+	Backported from master:
+	2021-04-30  Roman Zhuykov  <zhroma@ispras.ru>
+
+	* testsuite/libgomp.oacc-c-c++-common/atomic_capture-3.c: New test.
+
 2021-04-29  Tom de Vries  <tdevries@suse.de>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 64f000ff22dd8..66cb27e701d9d 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,111 @@
+2021-05-06  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-04-30  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/istream (operator>>(Istream&&, x&)): Simplify, as
+	per LWG 1203.
+	* include/std/ostream (operator<<(Ostream&&, const x&)):
+	Likewise.
+	* testsuite/27_io/basic_istream/extractors_character/char/lwg2499_neg.cc:
+	Adjust dg-error pattern.
+	* testsuite/27_io/basic_istream/extractors_character/wchar_t/lwg2499_neg.cc:
+	Likewise.
+	* testsuite/27_io/basic_istream/extractors_other/char/4.cc: Define
+	is_extractable trait to replace std::__is_extractable. Make it
+	work with rvalue streams as well as lvalues, to replace f() and
+	g() helper functions.
+	* testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc:
+	Likewise.
+	* testsuite/27_io/basic_ostream/inserters_other/char/6.cc:
+	Define is_insertable trait to replace std::__is_insertable. Make
+	it work with rvalue streams as well as lvalues, to replace f()
+	and g() helper functions.
+	* testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/io/dr2989.cc: Prune additional
+	errors from new constraints.
+	* testsuite/27_io/rvalue_streams-2.cc: Remove PR 80675 checks,
+	which are no longer expected to compile.
+	* testsuite/27_io/rvalue_streams.cc: Adjust existing test.
+	Verify LWG 1203 changes.
+
+2021-05-06  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-05  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/20_util/function_objects/invoke/3.cc: Check feature
+	test macro.
+	* testsuite/20_util/function_objects/invoke/version.cc: New test.
+
+2021-05-06  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/future (promise::set_value): Check for existence
+	of shared state before dereferncing it.
+	(promise::set_exception, promise::set_value_at_thread_exit)
+	(promise::set_exception_at_thread_exit): Likewise.
+	(promise<R&>::set_value, promise<R&>::set_exception)
+	(promise<R&>::set_value_at_thread_exit)
+	(promise<R&>::set_exception_at_thread_exit): Likewise.
+	(promise<void>::set_value, promise<void>::set_exception)
+	(promise<void>::set_value_at_thread_exit)
+	(promise<void>::set_exception_at_thread_exit): Likewise.
+	* testsuite/30_threads/promise/members/at_thread_exit2.cc:
+	Remove unused variable.
+
+2021-05-06  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/basic_string.h (basic_string(const CharT*, const A&)):
+	Do not do arithmetic on null pointer.
+
+2021-05-06  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/ext/pb_ds/detail/cc_hash_table_map_/cc_ht_map_.hpp
+	(find_key_pointer(key_const_reference, false_type))
+	(find_key_pointer(key_const_reference, true_type)): Do not
+	dereference null pointer.
+
+2021-05-06  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/20_util/from_chars/3.cc: Use unsigned type to avoid
+	overflow.
+	* testsuite/24_iterators/reverse_iterator/2.cc: Do not add
+	non-zero value to null pointer.
+	* testsuite/25_algorithms/copy_backward/move_iterators/69478.cc:
+	Use past-the-end iterator for result.
+	* testsuite/25_algorithms/move_backward/69478.cc: Likewise.
+	* testsuite/25_algorithms/move_backward/93872.cc: Likewise.
+
+2021-05-06  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/100384
+	* include/std/variant (__get_t): New alias template yielding the
+	return type of std::get<N> on a variant.
+	(__visit_result_t): New alias template yielding the result of
+	std::visit.
+	(__same_types): Move into namespace __detail::__variant.
+	(__check_visitor_results): Likewise. Use __invoke_result_t and
+	__get_t.
+	(__check_visitor_result): Remove.
+	(visit): Use __visit_result_t for return type.
+	* testsuite/20_util/variant/100384.cc: New test.
+
 2021-05-05  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:

From 8482ed658ca77bfd7fc119cd62afd5b70a024500 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Fri, 7 May 2021 17:48:37 +0200
Subject: [PATCH 077/164] libcpp: Fix up pragma preprocessing [PR100450]

Since the r0-85991-ga25a8f3be322fe0f838947b679f73d6efc2a412c
https://gcc.gnu.org/legacy-ml/gcc-patches/2008-02/msg01329.html
changes, so that we handle macros inside of pragmas that should expand
macros, during preprocessing we print those pragmas token by token,
with CPP_PRAGMA printed as
      fputs ("#pragma ", print.outf);
      if (space)
        fprintf (print.outf, "%s %s", space, name);
      else
        fprintf (print.outf, "%s", name);
where name is some identifier (so e.g. print
 #pragma omp parallel
or
 #pragma omp for
etc.).  Because it ends in an identifier, we need to handle it like
an identifier (i.e. CPP_NAME) for the decision whether a space needs
to be emitted in between that #pragma whatever or #pragma whatever whatever
and following token, otherwise the attached testcase is preprocessed as
 #pragma omp forreduction(+:red)
rather than
 #pragma omp for reduction(+:red)
The cpp_avoid_paste function is only called for this purpose.

2021-05-07  Jakub Jelinek  <jakub@redhat.com>

	PR c/100450
	* lex.c (cpp_avoid_paste): Handle token1 CPP_PRAGMA like CPP_NAME.

	* c-c++-common/gomp/pr100450.c: New test.

(cherry picked from commit 170c850e4bd46745e2a5130b5eb09f9fceb98416)
---
 gcc/testsuite/c-c++-common/gomp/pr100450.c | 20 ++++++++++++++++++++
 libcpp/lex.c                               |  1 +
 2 files changed, 21 insertions(+)
 create mode 100644 gcc/testsuite/c-c++-common/gomp/pr100450.c

diff --git a/gcc/testsuite/c-c++-common/gomp/pr100450.c b/gcc/testsuite/c-c++-common/gomp/pr100450.c
new file mode 100644
index 0000000000000..a6d2a2829ff51
--- /dev/null
+++ b/gcc/testsuite/c-c++-common/gomp/pr100450.c
@@ -0,0 +1,20 @@
+/* PR c/100450 */
+/* { dg-do compile } */
+/* { dg-options "-fopenmp -save-temps -Wunknown-pragmas" } */
+
+#define TEST(T) { \
+     {T} \
+}
+#define CLAUSES reduction(+:red)
+#define PARALLEL_FOR(X) TEST({ \
+_Pragma("omp for CLAUSES") \
+X \
+})
+
+void foo()
+{
+  int red = 0;
+  int A[3] = {};
+  #pragma omp parallel shared(red)
+  PARALLEL_FOR( for(int i=0; i < 3; i++) red += A[i]; )
+}
diff --git a/libcpp/lex.c b/libcpp/lex.c
index 06bcc31c87e7d..27388754ea1d3 100644
--- a/libcpp/lex.c
+++ b/libcpp/lex.c
@@ -3709,6 +3709,7 @@ cpp_avoid_paste (cpp_reader *pfile, const cpp_token *token1,
     case CPP_DEREF:	return c == '*';
     case CPP_DOT:	return c == '.' || c == '%' || b == CPP_NUMBER;
     case CPP_HASH:	return c == '#' || c == '%'; /* Digraph form.  */
+    case CPP_PRAGMA:
     case CPP_NAME:	return ((b == CPP_NUMBER
 				 && name_p (pfile, &token2->val.str))
 				|| b == CPP_NAME

From 768feed93231fc75997e1bc0c53a8c8f108ecbc0 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Thu, 6 May 2021 19:14:42 +0100
Subject: [PATCH 078/164] libstdc++: Fix constraints for rvalue stream
 insertion/extraction

The __rval_streamable() function was an attempt to test for
convertibility cheaply and without confusing diagnostics. It doesn't
work with Clang though, and is probably ill-formed.

Replace that helper function with a check for derivation from ios_base,
and use that in the alias templates __rvalue_stream_insertion_t and
__rvalue_stream_extraction_t. Use concepts for the constraints when
available.

libstdc++-v3/ChangeLog:

	* include/std/istream (__rvalue_stream_extraction_t): Replace
	use of __rval_streamable.
	* include/std/ostream (__rvalue_stream_insertion_t): Likewise.
	(__rval_streamable): Remove.
	(_Require_derived_from_ios_base, __derived_from_ios_base): New
	helper for checking constraints.
	* testsuite/27_io/basic_istream/extractors_other/char/4.cc: Fix
	reference to the wrong subclause of the standard.
	* testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc:
	Likewise.
	* testsuite/27_io/basic_ostream/inserters_other/char/6.cc:
	Likewise.
	* testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc:
	Likewise.
	* testsuite/27_io/basic_ostream/inserters_other/char/99692.cc:
	New test.
	* testsuite/27_io/filesystem/path/io/dr2989.cc: Adjust pruned
	errors.

(cherry picked from commit a87ceadf17b4a899f3e74e2da8b6b209461d2742)
---
 libstdc++-v3/include/std/istream              | 13 ++++---
 libstdc++-v3/include/std/ostream              | 36 +++++++++----------
 .../basic_istream/extractors_other/char/4.cc  |  2 +-
 .../extractors_other/wchar_t/4.cc             |  2 +-
 .../basic_ostream/inserters_other/char/6.cc   |  2 +-
 .../inserters_other/char/99692.cc             | 34 ++++++++++++++++++
 .../inserters_other/wchar_t/6.cc              |  2 +-
 .../27_io/filesystem/path/io/dr2989.cc        |  1 -
 8 files changed, 64 insertions(+), 28 deletions(-)
 create mode 100644 libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/99692.cc

diff --git a/libstdc++-v3/include/std/istream b/libstdc++-v3/include/std/istream
index ea34cce62980b..5ad60dbd709f5 100644
--- a/libstdc++-v3/include/std/istream
+++ b/libstdc++-v3/include/std/istream
@@ -958,12 +958,17 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
   // 2328. Rvalue stream extraction should use perfect forwarding
   // 1203. More useful rvalue stream insertion
 
-  // SFINAE helper to check constraints for operator>>(Istream&&, T&&).
-  // If the constraints are satisfied, it is an alias for Istream&&.
+#if __cpp_lib_concepts
+  template<typename _Is, typename _Tp>
+    requires __derived_from_ios_base<_Is>
+      && requires (_Is& __is, _Tp&& __t) { __is >> std::forward<_Tp>(__t); }
+    using __rvalue_stream_extraction_t = _Is&&;
+#else
   template<typename _Is, typename _Tp,
-	   typename = decltype(std::__rval_streamable<_Is>()
-				 >> std::declval<_Tp>())>
+	   typename = _Require_derived_from_ios_base<_Is>,
+	   typename = decltype(std::declval<_Is&>() >> std::declval<_Tp>())>
     using __rvalue_stream_extraction_t = _Is&&;
+#endif
 
   /**
    *  @brief  Generic extractor for rvalue stream
diff --git a/libstdc++-v3/include/std/ostream b/libstdc++-v3/include/std/ostream
index fdd2a87665cc2..981697324c9d8 100644
--- a/libstdc++-v3/include/std/ostream
+++ b/libstdc++-v3/include/std/ostream
@@ -708,31 +708,29 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
   // _GLIBCXX_RESOLVE_LIB_DEFECTS
   // 1203. More useful rvalue stream insertion
 
-  // SFINAE helper to check constraints for operator<<(Ostream&&, const T&).
-  // If Ostream is publicly and unambiguously derived from ios_base, then
-  // __rval_streamable<Ostream>() is equivalent to declval<Ostream&>().
-  // Otherwise, it results in a substitution failure. Specifically, it will
-  // fail if Ostream is an lvalue reference or the same type as ios_base.
-  // Use concepts if possible because they're cheaper to evaluate.
 #if __cpp_lib_concepts
+  // Use concepts if possible because they're cheaper to evaluate.
   template<typename _Tp>
-    requires (!is_same_v<_Tp, ios_base>)
-      && requires (_Tp* __t, ios_base* __b) { __b = __t; }
-    _Tp&
-    __rval_streamable();
+    concept __derived_from_ios_base = is_class_v<_Tp>
+      && (!is_same_v<_Tp, ios_base>)
+      && requires (_Tp* __t, ios_base* __b) { __b = __t; };
+
+  template<typename _Os, typename _Tp>
+    requires __derived_from_ios_base<_Os>
+      && requires (_Os& __os, const _Tp& __t) { __os << __t; }
+    using __rvalue_stream_insertion_t = _Os&&;
 #else
-  template<typename _Tp,
-	   typename = _Require<__not_<__is_one_of<_Tp, _Tp&, ios_base>>>>
-    _Tp&
-    __rval_streamable(ios_base* = (_Tp*)nullptr);
-#endif
+  template<typename _Tp>
+    using _Require_derived_from_ios_base
+      = _Require<is_class<_Tp>, __not_<is_same<_Tp, ios_base>>,
+		 is_convertible<typename add_pointer<_Tp>::type, ios_base*>>;
 
-  // SFINAE helper to check constraints for operator<<(Ostream&&, const T&).
-  // If the constraints are satisfied, it is an alias for Ostream&&.
   template<typename _Os, typename _Tp,
-	   typename = decltype(std::__rval_streamable<_Os>()
-				 << std::declval<const _Tp&>())>
+	   typename = _Require_derived_from_ios_base<_Os>,
+	   typename
+	     = decltype(std::declval<_Os&>() << std::declval<const _Tp&>())>
     using __rvalue_stream_insertion_t = _Os&&;
+#endif
 
   /**
    *  @brief  Generic inserter for rvalue stream
diff --git a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/4.cc b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/4.cc
index 9f1e293474fd3..94e41a17e82c1 100644
--- a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/4.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/4.cc
@@ -17,7 +17,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// 27.6.2.5.3 basic_ostream manipulator inserters
+// C++11 27.7.2.6 Rvalue stream extraction [istream.rvalue]
 
 #include <sstream>
 
diff --git a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc
index fc7f5505bf468..b182be7ee3d36 100644
--- a/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc
@@ -17,7 +17,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// 27.6.2.5.3 basic_ostream manipulator inserters
+// C++11 27.7.2.6 Rvalue stream extraction [istream.rvalue]
 
 #include <sstream>
 
diff --git a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/6.cc b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/6.cc
index 4801afcba6c07..3a748cd630b8b 100644
--- a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/6.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/6.cc
@@ -17,7 +17,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// 27.6.2.5.3 basic_ostream manipulator inserters
+// C++11 27.7.3.9 Rvalue stream insertion [ostream.rvalue]
 
 #include <sstream>
 
diff --git a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/99692.cc b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/99692.cc
new file mode 100644
index 0000000000000..e41399a1bf154
--- /dev/null
+++ b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/99692.cc
@@ -0,0 +1,34 @@
+// { dg-do compile { target c++11 } }
+
+#include <ostream>
+
+struct CustomStream : std::ostream {};
+
+namespace N {
+    class A{};
+}
+
+std::ostream& operator<<(std::ostream& s, const N::A&)
+{
+    return s;
+}
+
+CustomStream&& operator<<(CustomStream&& s, const N::A& v)
+{
+    static_cast<std::ostream&>(s) << v;
+    return std::move(s);
+}
+
+void test_pr99692()
+{
+  // PR libstdc++/99692
+    CustomStream() << N::A{};
+}
+
+int test_shift_ios_enum()
+{
+  // https://gcc.gnu.org/pipermail/libstdc++/2021-May/052507.html
+  int i = 1 << std::ios::erase_event;
+
+  return i;
+}
diff --git a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc
index 3efeb804b00e4..8fc0694dddcc7 100644
--- a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc
@@ -17,7 +17,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// 27.6.2.5.3 basic_ostream manipulator inserters
+// C++11 27.7.3.9 Rvalue stream insertion [ostream.rvalue]
 
 #include <sstream>
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
index 609f1c32a0e3c..c5cda77647776 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
@@ -33,4 +33,3 @@ void foo(std::iostream& s) {
   s >> p; // { dg-error "no match" }
 }
 // { dg-prune-output "no type .*enable_if" }
-// { dg-prune-output "no matching function for call to '__rval_streamable" }

From 99964f67bab3cc1ddac51b470e7f1b616a537348 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Sat, 8 May 2021 00:18:04 +0000
Subject: [PATCH 079/164] Daily bump.

---
 gcc/DATESTAMP           |  2 +-
 gcc/testsuite/ChangeLog |  8 ++++++++
 libcpp/ChangeLog        |  8 ++++++++
 libstdc++-v3/ChangeLog  | 24 ++++++++++++++++++++++++
 4 files changed, 41 insertions(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index b5beafed7dfab..81f0a6bd0c26e 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210507
+20210508
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index fb35a283fa326..30a8c723e9233 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,11 @@
+2021-05-07  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-07  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/100450
+	* c-c++-common/gomp/pr100450.c: New test.
+
 2021-05-06  Marius Hillenbrand  <mhillen@linux.ibm.com>
 
 	Backported from master:
diff --git a/libcpp/ChangeLog b/libcpp/ChangeLog
index 92acd5061a3bb..059ab8bfc2859 100644
--- a/libcpp/ChangeLog
+++ b/libcpp/ChangeLog
@@ -1,3 +1,11 @@
+2021-05-07  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-07  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/100450
+	* lex.c (cpp_avoid_paste): Handle token1 CPP_PRAGMA like CPP_NAME.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 66cb27e701d9d..c7fbc03f39cac 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,27 @@
+2021-05-07  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-07  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/istream (__rvalue_stream_extraction_t): Replace
+	use of __rval_streamable.
+	* include/std/ostream (__rvalue_stream_insertion_t): Likewise.
+	(__rval_streamable): Remove.
+	(_Require_derived_from_ios_base, __derived_from_ios_base): New
+	helper for checking constraints.
+	* testsuite/27_io/basic_istream/extractors_other/char/4.cc: Fix
+	reference to the wrong subclause of the standard.
+	* testsuite/27_io/basic_istream/extractors_other/wchar_t/4.cc:
+	Likewise.
+	* testsuite/27_io/basic_ostream/inserters_other/char/6.cc:
+	Likewise.
+	* testsuite/27_io/basic_ostream/inserters_other/wchar_t/6.cc:
+	Likewise.
+	* testsuite/27_io/basic_ostream/inserters_other/char/99692.cc:
+	New test.
+	* testsuite/27_io/filesystem/path/io/dr2989.cc: Adjust pruned
+	errors.
+
 2021-05-06  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

From a6b45a8d16b3edc58920c3637daf2cbe97cb2651 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Sun, 9 May 2021 00:18:19 +0000
Subject: [PATCH 080/164] Daily bump.

---
 gcc/DATESTAMP | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 81f0a6bd0c26e..bbc364a17f3d2 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210508
+20210509

From a4a9cfee014992f0470d66b52cd5fbac3e05830a Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Mon, 10 May 2021 00:18:10 +0000
Subject: [PATCH 081/164] Daily bump.

---
 gcc/DATESTAMP | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index bbc364a17f3d2..06265954f0664 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210509
+20210510

From 270d1d643e88f652ba75cf06dde3fc887c4f8eed Mon Sep 17 00:00:00 2001
From: Iain Buclaw <ibuclaw@gdcproject.org>
Date: Wed, 5 May 2021 00:28:44 +0200
Subject: [PATCH 082/164] libphobos: Fix visibility of
 std.process.searchPathFor

This symbol is used by std.file.thisExePath on OpenBSD.

libphobos/ChangeLog:

	* src/std/process.d (searchPathFor): Change visibility to package.

(cherry picked from commit cecc437e952e35f8a7907553586605cbd0bba82a)
---
 libphobos/src/std/process.d | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/libphobos/src/std/process.d b/libphobos/src/std/process.d
index 9cbeca8e9a89f..63ec49365b925 100644
--- a/libphobos/src/std/process.d
+++ b/libphobos/src/std/process.d
@@ -887,7 +887,7 @@ version (Windows) @system unittest
 // Searches the PATH variable for the given executable file,
 // (checking that it is in fact executable).
 version (Posix)
-private string searchPathFor(in char[] executable)
+package(std) string searchPathFor(in char[] executable)
     @trusted //TODO: @safe nothrow
 {
     import std.algorithm.iteration : splitter;

From 23855a176609fe8dda6abaf2b21846b4517966eb Mon Sep 17 00:00:00 2001
From: Iain Buclaw <ibuclaw@gdcproject.org>
Date: Mon, 10 May 2021 12:03:19 +0200
Subject: [PATCH 083/164] d: Fix qualifier ignored in alias definition if
 parentheses are not present

Fixes regression where the qualifier was ignored in an alias definition
if parentheses were not present.

gcc/d/ChangeLog:

	* dmd/dsymbolsem.c (aliasInstanceSemantic): Merge storage class of old
	alias into new symbol.

gcc/testsuite/ChangeLog:

	* gdc.test/compilable/test21898.d: New test.

(cherry picked from commit a30ee3aa8210f14fa3b4ee84fd3974c6b6a93047)
---
 gcc/d/dmd/dsymbolsem.c                        | 7 +++++--
 gcc/testsuite/gdc.test/compilable/test21898.d | 7 +++++++
 2 files changed, 12 insertions(+), 2 deletions(-)
 create mode 100644 gcc/testsuite/gdc.test/compilable/test21898.d

diff --git a/gcc/d/dmd/dsymbolsem.c b/gcc/d/dmd/dsymbolsem.c
index 33f74edf6ba8e..7a44ed2c41d85 100644
--- a/gcc/d/dmd/dsymbolsem.c
+++ b/gcc/d/dmd/dsymbolsem.c
@@ -4880,8 +4880,11 @@ static void aliasInstanceSemantic(TemplateInstance *tempinst, Scope *sc, Templat
 
     TemplateTypeParameter *ttp = (*tempdecl->parameters)[0]->isTemplateTypeParameter();
     Type *ta = isType(tempinst->tdtypes[0]);
-    Declaration *d = new AliasDeclaration(tempinst->loc, ttp->ident, ta->addMod(tempdecl->onemember->isAliasDeclaration()->type->mod));
-    d->storage_class |= STCtemplateparameter;
+    AliasDeclaration *ad = tempdecl->onemember->isAliasDeclaration();
+
+    // Note: qualifiers can be in both 'ad.type.mod' and 'ad.storage_class'
+    Declaration *d = new AliasDeclaration(tempinst->loc, ttp->ident, ta->addMod(ad->type->mod));
+    d->storage_class |= STCtemplateparameter | ad->storage_class;
     dsymbolSemantic(d, sc);
 
     paramscope->pop();
diff --git a/gcc/testsuite/gdc.test/compilable/test21898.d b/gcc/testsuite/gdc.test/compilable/test21898.d
new file mode 100644
index 0000000000000..9ac18b8cb6b43
--- /dev/null
+++ b/gcc/testsuite/gdc.test/compilable/test21898.d
@@ -0,0 +1,7 @@
+// https://issues.dlang.org/show_bug.cgi?id=21898
+
+alias Works(T) = immutable(T);
+alias Fails(T) = immutable T;
+
+static assert(is(Works!int == immutable int));
+static assert(is(Fails!int == immutable int));

From cb5051e0927d65499505bc28463dd923146ebdcb Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Tue, 11 May 2021 00:18:10 +0000
Subject: [PATCH 084/164] Daily bump.

---
 gcc/DATESTAMP           | 2 +-
 gcc/d/ChangeLog         | 8 ++++++++
 gcc/testsuite/ChangeLog | 7 +++++++
 libphobos/ChangeLog     | 7 +++++++
 4 files changed, 23 insertions(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 06265954f0664..abf046def4857 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210510
+20210511
diff --git a/gcc/d/ChangeLog b/gcc/d/ChangeLog
index 2386b86d641b2..858bd615f1152 100644
--- a/gcc/d/ChangeLog
+++ b/gcc/d/ChangeLog
@@ -1,3 +1,11 @@
+2021-05-10  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	Backported from master:
+	2021-05-10  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	* dmd/dsymbolsem.c (aliasInstanceSemantic): Merge storage class of old
+	alias into new symbol.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 30a8c723e9233..f8a03d7b6497d 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,10 @@
+2021-05-10  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	Backported from master:
+	2021-05-10  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	* gdc.test/compilable/test21898.d: New test.
+
 2021-05-07  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/libphobos/ChangeLog b/libphobos/ChangeLog
index 726f44a6adc22..81f245c1d5cc8 100644
--- a/libphobos/ChangeLog
+++ b/libphobos/ChangeLog
@@ -1,3 +1,10 @@
+2021-05-10  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	Backported from master:
+	2021-05-10  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	* src/std/process.d (searchPathFor): Change visibility to package.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.

From 1011bb8bc67cf34c45a9237d72a801a14ad9ef0f Mon Sep 17 00:00:00 2001
From: Alex Coplan <alex.coplan@arm.com>
Date: Wed, 21 Apr 2021 14:42:04 +0100
Subject: [PATCH 085/164] aarch64: Avoid duplicating bti j insns for jump
 tables [PR99988]

This patch fixes PR99988 which shows us generating large (> 250)
sequences of back-to-back bti j instructions.

The fix is simply to avoid inserting bti j instructions at the target of
a jump table if we've already inserted one for a given label.

Co-Authored-By: Christophe Lyon <clyon@gcc.gnu.org>

gcc/ChangeLog:

	PR target/99988
	* config/aarch64/aarch64-bti-insert.c (aarch64_bti_j_insn_p): New.
	(rest_of_insert_bti): Avoid inserting duplicate bti j insns for
	jump table targets.

gcc/testsuite/ChangeLog:

	PR target/99988
	* gcc.target/aarch64/pr99988.c: New test.
---
 gcc/config/aarch64/aarch64-bti-insert.c    | 15 +++++
 gcc/testsuite/gcc.target/aarch64/pr99988.c | 66 ++++++++++++++++++++++
 2 files changed, 81 insertions(+)
 create mode 100644 gcc/testsuite/gcc.target/aarch64/pr99988.c

diff --git a/gcc/config/aarch64/aarch64-bti-insert.c b/gcc/config/aarch64/aarch64-bti-insert.c
index 936649769c7e8..5d6bc169d6bb0 100644
--- a/gcc/config/aarch64/aarch64-bti-insert.c
+++ b/gcc/config/aarch64/aarch64-bti-insert.c
@@ -120,6 +120,17 @@ aarch64_pac_insn_p (rtx x)
   return false;
 }
 
+/* Check if INSN is a BTI J insn.  */
+static bool
+aarch64_bti_j_insn_p (rtx_insn *insn)
+{
+  if (!insn || !INSN_P (insn))
+    return false;
+
+  rtx pat = PATTERN (insn);
+  return GET_CODE (pat) == UNSPEC_VOLATILE && XINT (pat, 1) == UNSPECV_BTI_J;
+}
+
 /* Insert the BTI instruction.  */
 /* This is implemented as a late RTL pass that runs before branch
    shortening and does the following.  */
@@ -165,6 +176,10 @@ rest_of_insert_bti (void)
 		  for (j = GET_NUM_ELEM (vec) - 1; j >= 0; --j)
 		    {
 		      label = as_a <rtx_insn *> (XEXP (RTVEC_ELT (vec, j), 0));
+		      rtx_insn *next = next_nonnote_nondebug_insn (label);
+		      if (aarch64_bti_j_insn_p (next))
+			continue;
+
 		      bti_insn = gen_bti_j ();
 		      emit_insn_after (bti_insn, label);
 		    }
diff --git a/gcc/testsuite/gcc.target/aarch64/pr99988.c b/gcc/testsuite/gcc.target/aarch64/pr99988.c
new file mode 100644
index 0000000000000..7cca496294461
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/pr99988.c
@@ -0,0 +1,66 @@
+/* { dg-do compile { target lp64 } } */
+/* { dg-options "-O2 -mbranch-protection=standard" } */
+/* { dg-final { scan-assembler-times {bti j} 13 } } */
+int a;
+int c();
+int d();
+int e();
+int f();
+int g();
+void h() {
+  switch (a) {
+  case 0:
+  case 56:
+  case 57:
+    break;
+  case 58:
+  case 59:
+  case 61:
+  case 62:
+    c();
+  case 64:
+  case 63:
+    d();
+  case 66:
+  case 65:
+    d();
+  case 68:
+  case 67:
+    d();
+  case 69:
+  case 70:
+    d();
+  case 71:
+  case 72:
+  case 88:
+  case 87:
+    d();
+  case 90:
+  case 89:
+    d();
+  case 92:
+  case 1:
+    d();
+  case 93:
+  case 73:
+  case 4:
+    e();
+  case 76:
+  case 5:
+    f();
+  case 7:
+  case 8:
+  case 84:
+  case 85:
+    break;
+  case 6:
+  case 299:
+  case 9:
+  case 80:
+  case 2:
+  case 3:
+    e();
+  default:
+    g();
+  }
+}

From 9d6ee0d3c42807596c50569fc01b3f31a6e0900a Mon Sep 17 00:00:00 2001
From: Patrick Palka <ppalka@redhat.com>
Date: Tue, 11 May 2021 13:19:46 -0400
Subject: [PATCH 086/164] libstdc++: Remove extern "C" from Ryu sources

floating_to_chars.cc includes the Ryu sources into an anonymous
namespace as a convenient way to give all its symbols internal linkage.
But an entity declared extern "C" always has external linkage even
from within an anonymous namespace, so this trick doesn't work in the
presence of extern "C", and it causes the Ryu function generic_to_chars
to be visible from libstdc++.a.

This patch removes the only use of extern "C" from our local copy of
Ryu along with some declarations for never-defined functions that GCC
now warns about.

libstdc++-v3/ChangeLog:

	* src/c++17/ryu/LOCAL_PATCHES: Update.
	* src/c++17/ryu/ryu_generic_128.h: Remove extern "C".
	Remove declarations for never-defined functions.
	* testsuite/20_util/to_chars/4.cc: New test.

(cherry picked from commit 84b384a16f388c68166b0603e50d0b477d0830a7)
---
 libstdc++-v3/src/c++17/ryu/LOCAL_PATCHES     |  1 +
 libstdc++-v3/src/c++17/ryu/ryu_generic_128.h | 21 ++----------
 libstdc++-v3/testsuite/20_util/to_chars/4.cc | 36 ++++++++++++++++++++
 3 files changed, 40 insertions(+), 18 deletions(-)
 create mode 100644 libstdc++-v3/testsuite/20_util/to_chars/4.cc

diff --git a/libstdc++-v3/src/c++17/ryu/LOCAL_PATCHES b/libstdc++-v3/src/c++17/ryu/LOCAL_PATCHES
index 51e504cb6ead5..011626f07e278 100644
--- a/libstdc++-v3/src/c++17/ryu/LOCAL_PATCHES
+++ b/libstdc++-v3/src/c++17/ryu/LOCAL_PATCHES
@@ -1,2 +1,3 @@
 r11-6248
 r11-7636
+r12-725
diff --git a/libstdc++-v3/src/c++17/ryu/ryu_generic_128.h b/libstdc++-v3/src/c++17/ryu/ryu_generic_128.h
index 2afbf274e1117..6d988ab01eb2b 100644
--- a/libstdc++-v3/src/c++17/ryu/ryu_generic_128.h
+++ b/libstdc++-v3/src/c++17/ryu/ryu_generic_128.h
@@ -18,9 +18,9 @@
 #define RYU_GENERIC_128_H
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+// NOTE: These symbols are declared extern "C" upstream, but we don't want that
+// because it'd override the internal linkage of the anonymous namespace into
+// which this header is included.
 
 // This is a generic 128-bit implementation of float to shortest conversion
 // using the Ryu algorithm. It can handle any IEEE-compatible floating-point
@@ -42,18 +42,6 @@ struct floating_decimal_128 {
   bool sign;
 };
 
-struct floating_decimal_128 float_to_fd128(float f);
-struct floating_decimal_128 double_to_fd128(double d);
-
-// According to wikipedia (https://en.wikipedia.org/wiki/Long_double), this likely only works on
-// x86 with specific compilers (clang?). May need an ifdef.
-struct floating_decimal_128 long_double_to_fd128(long double d);
-
-// Converts the given binary floating point number to the shortest decimal floating point number
-// that still accurately represents it.
-struct floating_decimal_128 generic_binary_to_decimal(
-    const uint128_t bits, const uint32_t mantissaBits, const uint32_t exponentBits, const bool explicitLeadingBit);
-
 // Converts the given decimal floating point number to a string, writing to result, and returning
 // the number characters written. Does not terminate the buffer with a 0. In the worst case, this
 // function can write up to 53 characters.
@@ -63,8 +51,5 @@ struct floating_decimal_128 generic_binary_to_decimal(
 // = 1 + 39 + 1 + 1 + 1 + 10 = 53
 int generic_to_chars(const struct floating_decimal_128 v, char* const result);
 
-#ifdef __cplusplus
-}
-#endif
 
 #endif // RYU_GENERIC_128_H
diff --git a/libstdc++-v3/testsuite/20_util/to_chars/4.cc b/libstdc++-v3/testsuite/20_util/to_chars/4.cc
new file mode 100644
index 0000000000000..00781ee637938
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/to_chars/4.cc
@@ -0,0 +1,36 @@
+// Copyright (C) 2021 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do link { target c++17 } }
+// { dg-require-effective-target ieee-floats }
+// { dg-require-static-libstdcxx }
+// { dg-additional-options "-static-libstdc++" }
+
+// Verify the Ryu symbol generic_to_chars doesn't inadvertently leak into
+// libstdc++.a.  If it did, this test would fail at link time with a multiple
+// definition error.
+
+#include <charconv>
+
+extern "C" void generic_to_chars(void) { }
+
+int
+main()
+{
+  char x[64];
+  std::to_chars(x, x+64, 42.L, std::chars_format::scientific);
+}

From dbb87d6a9c37c8eca80d77782717a8144515c16d Mon Sep 17 00:00:00 2001
From: Philippe Blain <levraiphilippeblain@gmail.com>
Date: Fri, 12 Mar 2021 19:26:46 -0500
Subject: [PATCH 087/164] libstdc++: Install libstdc++*-gdb.py more robustly
 [PR 99453]

In order for GDB to auto-load the pretty printers, they must be installed
as "libstdc++.$ext-gdb.py", where 'libstdc++.$ext' is the name of the
object file that is loaded by GDB [1], i.e. the libstdc++ shared library.

The approach taken in libstdc++-v3/python/Makefile.am is to loop over
files matching 'libstdc++*' in $(DESTDIR)$(toolexeclibdir) and choose
the last file matching that glob that is not a symlink, the Libtool
'*.la' file or a Python file.

That works fine for ELF targets where the matching names are:

  libstdc++.a
  libstdc++.so
  libstdc++.so.6
  libstdc++.so.6.0.29

But not for macOS with:

  libstdc++.6.dylib
  libstdc++.a

Or MinGW with:

  libstdc++-6.dll
  libstdc++.dll.a

Try to make a better job at installing the pretty printers with the
correct name by copying the approach taken by isl [2], that is, using
a sed invocation on the Libtool-generated 'libstdc++.la' to read the
correct name for the current platform.

[1] https://sourceware.org/gdb/onlinedocs/gdb/objfile_002dgdbdotext-file.html
[2] https://repo.or.cz/isl.git/blob/HEAD:/Makefile.am#l611

libstdc++-v3/ChangeLog:

	PR libstdc++/99453
	* python/Makefile.am: Install libstdc++*-gdb.py more robustly.
	* python/Makefile.in: Regenerate.

Co-authored-by: Jonathan Wakely <jwakely@redhat.com>
(cherry picked from commit c2fc1702cb3a3d5cc9c40de47f63b4c8f3f1d09c)
---
 libstdc++-v3/python/Makefile.am | 20 ++++----------------
 libstdc++-v3/python/Makefile.in | 14 ++------------
 2 files changed, 6 insertions(+), 28 deletions(-)

diff --git a/libstdc++-v3/python/Makefile.am b/libstdc++-v3/python/Makefile.am
index 01517a2a52219..0c2b207b86ebd 100644
--- a/libstdc++-v3/python/Makefile.am
+++ b/libstdc++-v3/python/Makefile.am
@@ -44,21 +44,9 @@ gdb.py: hook.in Makefile
 install-data-local: gdb.py
 	@$(mkdir_p) $(DESTDIR)$(toolexeclibdir)
 ## We want to install gdb.py as SOMETHING-gdb.py.  SOMETHING is the
-## full name of the final library.  We want to ignore symlinks, the
-## .la file, and any previous -gdb.py file.  This is inherently
-## fragile, but there does not seem to be a better option, because
-## libtool hides the real names from us.
-	@here=`pwd`; cd $(DESTDIR)$(toolexeclibdir); \
-	  for file in libstdc++.*; do \
-	    case $$file in \
-	      *-gdb.py) ;; \
-	      *.la) ;; \
-	      *) if test -h $$file; then \
-	           continue; \
-	         fi; \
-	         libname=$$file;; \
-	    esac; \
-	  done; \
-	cd $$here; \
+## full name of the final library.  We use the libtool .la file to get
+## the correct name.
+	@libname=`sed -ne "/^library_names=/{s/.*='//;s/'$$//;s/ .*//;p;}" \
+	          $(DESTDIR)$(toolexeclibdir)/libstdc++.la`; \
 	echo " $(INSTALL_DATA) gdb.py $(DESTDIR)$(toolexeclibdir)/$$libname-gdb.py"; \
 	$(INSTALL_DATA) gdb.py $(DESTDIR)$(toolexeclibdir)/$$libname-gdb.py
diff --git a/libstdc++-v3/python/Makefile.in b/libstdc++-v3/python/Makefile.in
index c35dbe559610f..2efe0b96a19b2 100644
--- a/libstdc++-v3/python/Makefile.in
+++ b/libstdc++-v3/python/Makefile.in
@@ -607,18 +607,8 @@ gdb.py: hook.in Makefile
 
 install-data-local: gdb.py
 	@$(mkdir_p) $(DESTDIR)$(toolexeclibdir)
-	@here=`pwd`; cd $(DESTDIR)$(toolexeclibdir); \
-	  for file in libstdc++.*; do \
-	    case $$file in \
-	      *-gdb.py) ;; \
-	      *.la) ;; \
-	      *) if test -h $$file; then \
-	           continue; \
-	         fi; \
-	         libname=$$file;; \
-	    esac; \
-	  done; \
-	cd $$here; \
+	@libname=`sed -ne "/^library_names=/{s/.*='//;s/'$$//;s/ .*//;p;}" \
+	          $(DESTDIR)$(toolexeclibdir)/libstdc++.la`; \
 	echo " $(INSTALL_DATA) gdb.py $(DESTDIR)$(toolexeclibdir)/$$libname-gdb.py"; \
 	$(INSTALL_DATA) gdb.py $(DESTDIR)$(toolexeclibdir)/$$libname-gdb.py
 

From ddfba2359d57167ed7a1efd184cae0cd5be2f31b Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Thu, 22 Apr 2021 15:46:51 +0100
Subject: [PATCH 088/164] libstdc++: Reject std::make_shared<T[]> [PR 99006]

Prior to C++20 it should be ill-formed to use std::make_shared with an
array type (and we don't support the C++20 feature to make it valid yet
anyway).

libstdc++-v3/ChangeLog:

	PR libstdc++/99006
	* include/bits/shared_ptr.h (allocate_shared): Assert that _Tp
	is not an array type.
	* include/bits/shared_ptr_base.h (__allocate_shared): Likewise.
	* testsuite/20_util/shared_ptr/creation/99006.cc: New test.

(cherry picked from commit 55650236cd97d81f42f9fdb4f6bcb12babafe51f)
---
 libstdc++-v3/include/bits/shared_ptr.h                   | 2 ++
 libstdc++-v3/include/bits/shared_ptr_base.h              | 2 ++
 .../testsuite/20_util/shared_ptr/creation/99006.cc       | 9 +++++++++
 3 files changed, 13 insertions(+)
 create mode 100644 libstdc++-v3/testsuite/20_util/shared_ptr/creation/99006.cc

diff --git a/libstdc++-v3/include/bits/shared_ptr.h b/libstdc++-v3/include/bits/shared_ptr.h
index ac4aa20b7943d..d5386ad535faf 100644
--- a/libstdc++-v3/include/bits/shared_ptr.h
+++ b/libstdc++-v3/include/bits/shared_ptr.h
@@ -857,6 +857,8 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     inline shared_ptr<_Tp>
     allocate_shared(const _Alloc& __a, _Args&&... __args)
     {
+      static_assert(!is_array<_Tp>::value, "make_shared<T[]> not supported");
+
       return shared_ptr<_Tp>(_Sp_alloc_shared_tag<_Alloc>{__a},
 			     std::forward<_Args>(__args)...);
     }
diff --git a/libstdc++-v3/include/bits/shared_ptr_base.h b/libstdc++-v3/include/bits/shared_ptr_base.h
index 8766b61fd8156..71099afbf7a4e 100644
--- a/libstdc++-v3/include/bits/shared_ptr_base.h
+++ b/libstdc++-v3/include/bits/shared_ptr_base.h
@@ -1831,6 +1831,8 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     inline __shared_ptr<_Tp, _Lp>
     __allocate_shared(const _Alloc& __a, _Args&&... __args)
     {
+      static_assert(!is_array<_Tp>::value, "make_shared<T[]> not supported");
+
       return __shared_ptr<_Tp, _Lp>(_Sp_alloc_shared_tag<_Alloc>{__a},
 				    std::forward<_Args>(__args)...);
     }
diff --git a/libstdc++-v3/testsuite/20_util/shared_ptr/creation/99006.cc b/libstdc++-v3/testsuite/20_util/shared_ptr/creation/99006.cc
new file mode 100644
index 0000000000000..d5f7a5da5e9d2
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/shared_ptr/creation/99006.cc
@@ -0,0 +1,9 @@
+// FIXME: This should use { target { ! c++20 } }
+// { dg-do compile }
+
+#include <memory>
+
+auto p = std::make_shared<int[]>(2); // { dg-error "here" }
+auto q = std::make_shared<int[2]>(1, 2); // { dg-error "here" }
+
+// { dg-prune-output "static assertion failed" }

From 43d3309d98c10f4fde6f12686220fa3e9f4044cf Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Thu, 6 May 2021 13:40:53 +0100
Subject: [PATCH 089/164] libstdc++: Fix definition of std::remove_cvref_t

I originally defined std::remove_cvref_t in terms of the internal
__remove_cvref_t trait, to avoid instantiating the remove_cvref class
template. However, as described in P1715R0 that is observable by users
and is thus non-conforming.

This defines remove_cvref_t as specified in the standard.

libstdc++-v3/ChangeLog:

	* include/std/type_traits (remove_cvref_t): Define in terms of
	remove_cvref.
	* testsuite/20_util/remove_cvref/value.cc: Check alias.

(cherry picked from commit 0e79e63026e43ad0577812ffb405dac8fa88af5b)
---
 libstdc++-v3/include/std/type_traits            | 17 +++++++++++++----
 .../testsuite/20_util/remove_cvref/value.cc     |  7 +++++++
 2 files changed, 20 insertions(+), 4 deletions(-)

diff --git a/libstdc++-v3/include/std/type_traits b/libstdc++-v3/include/std/type_traits
index 1f8b57b04a0d5..eaf06fcb036c8 100644
--- a/libstdc++-v3/include/std/type_traits
+++ b/libstdc++-v3/include/std/type_traits
@@ -3223,12 +3223,21 @@ template <typename _From, typename _To>
   /// Remove references and cv-qualifiers.
   template<typename _Tp>
     struct remove_cvref
-    {
-      using type = __remove_cvref_t<_Tp>;
-    };
+    : remove_cv<_Tp>
+    { };
+
+  template<typename _Tp>
+    struct remove_cvref<_Tp&>
+    : remove_cv<_Tp>
+    { };
+
+  template<typename _Tp>
+    struct remove_cvref<_Tp&&>
+    : remove_cv<_Tp>
+    { };
 
   template<typename _Tp>
-    using remove_cvref_t = __remove_cvref_t<_Tp>;
+    using remove_cvref_t = typename remove_cvref<_Tp>::type;
 
 #define __cpp_lib_type_identity 201806L
   /// Identity metafunction.
diff --git a/libstdc++-v3/testsuite/20_util/remove_cvref/value.cc b/libstdc++-v3/testsuite/20_util/remove_cvref/value.cc
index d4a2842297764..a4f50d433dcd7 100644
--- a/libstdc++-v3/testsuite/20_util/remove_cvref/value.cc
+++ b/libstdc++-v3/testsuite/20_util/remove_cvref/value.cc
@@ -48,3 +48,10 @@ void test01()
   static_assert(is_same<typename remove_cvref<const int(&)()>::type,
 			const int()>::value, "");
 }
+
+// Declare using nested name of class template
+template<typename T> T func(typename std::remove_cvref<T>::type);
+// Define using alias
+template<typename T> T func(std::remove_cvref_t<T> t) { return t; }
+// Call must not be ambiguous
+int i = func<int>(1);

From 441ff687457f0d713d20ae7440309d0b83dd202e Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 13:57:49 +0100
Subject: [PATCH 090/164] libstdc++: Rename test type to avoid clashing with
 std::any

When PCH are enabled this test file includes <any> and so the
using-directive brings std::any into the global scope. It isn't
currently a problem, because the -std option in the dg-options means
that PCH is not used. If that option is removed, the test fails with PCH
and passes without.

This just renames the type to avoid the name classh (and also the 'none'
type for consistency).

libstdc++-v3/ChangeLog:

	* testsuite/20_util/variant/compile.cc: Rename 'any' to avoid
	clash with std::any.

(cherry picked from commit 2bbacc18b35e44d45676a46eced26129f8f8378a)
---
 libstdc++-v3/testsuite/20_util/variant/compile.cc | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/libstdc++-v3/testsuite/20_util/variant/compile.cc b/libstdc++-v3/testsuite/20_util/variant/compile.cc
index 33f198c2cc377..e5042751e66e9 100644
--- a/libstdc++-v3/testsuite/20_util/variant/compile.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/compile.cc
@@ -172,15 +172,15 @@ void arbitrary_ctor()
   static_assert(is_constructible_v<variant<bool, int>, ConvertibleToBool>);
 }
 
-struct none { none() = delete; };
-struct any { template <typename T> any(T&&) {} };
+struct None { None() = delete; };
+struct Any { template <typename T> Any(T&&) {} };
 
 void in_place_index_ctor()
 {
   variant<string, string> a(in_place_index<0>, "a");
   variant<string, string> b(in_place_index<1>, {'a'});
 
-  static_assert(!is_constructible_v<variant<none, any>, std::in_place_index_t<0>>, "PR libstdc++/90165");
+  static_assert(!is_constructible_v<variant<None, Any>, std::in_place_index_t<0>>, "PR libstdc++/90165");
 }
 
 void in_place_type_ctor()
@@ -188,7 +188,7 @@ void in_place_type_ctor()
   variant<int, string, int> a(in_place_type<string>, "a");
   variant<int, string, int> b(in_place_type<string>, {'a'});
   static_assert(!is_constructible_v<variant<string, string>, in_place_type_t<string>, const char*>);
-  static_assert(!is_constructible_v<variant<none, any>, std::in_place_type_t<none>>, "PR libstdc++/90165");
+  static_assert(!is_constructible_v<variant<None, Any>, std::in_place_type_t<None>>, "PR libstdc++/90165");
 }
 
 void dtor()

From f9ae75fcbf1590722817f61277211a0a3ec4cab2 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 15:10:45 +0100
Subject: [PATCH 091/164] libstdc++: Adjust expected errors in tests when
 compiled as C++20

libstdc++-v3/ChangeLog:

	* testsuite/20_util/scoped_allocator/69293_neg.cc: Add dg-error
	for additional errors in C++20.
	* testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc:
	Likewise.
	* testsuite/20_util/uses_allocator/69293_neg.cc: Likewise.
	* testsuite/27_io/filesystem/path/io/dr2989.cc: Likewise.

(cherry picked from commit 23972128c83e62011b583f06b32c8501c096b7d8)
---
 libstdc++-v3/testsuite/20_util/scoped_allocator/69293_neg.cc    | 1 +
 .../memory_management_tools/destroy_neg.cc                      | 2 ++
 libstdc++-v3/testsuite/20_util/uses_allocator/69293_neg.cc      | 2 +-
 libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc       | 1 +
 4 files changed, 5 insertions(+), 1 deletion(-)

diff --git a/libstdc++-v3/testsuite/20_util/scoped_allocator/69293_neg.cc b/libstdc++-v3/testsuite/20_util/scoped_allocator/69293_neg.cc
index 5efd849ff36df..fd37374447f91 100644
--- a/libstdc++-v3/testsuite/20_util/scoped_allocator/69293_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/scoped_allocator/69293_neg.cc
@@ -47,6 +47,7 @@ test01()
   auto p = sa.allocate(1);
   sa.construct(p);  // this is required to be ill-formed
   // { dg-error "failed: .* uses_allocator is true" "" { target *-*-* } 0 }
+  // { dg-error "too many initializers for 'X'" "" { target c++2a } 0 }
 }
 
 // Needed because of PR c++/92193
diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc
index b17c6a0b90c72..626f2e1c6ee1a 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc
@@ -48,3 +48,5 @@ test02()
 }
 
 // { dg-error "value type is destructible" "" { target *-*-* } 0 }
+// { dg-error "use of deleted function" "" { target c++20 } 0 }
+// { dg-error "is private within this context" "" { target c++20 } 0 }
diff --git a/libstdc++-v3/testsuite/20_util/uses_allocator/69293_neg.cc b/libstdc++-v3/testsuite/20_util/uses_allocator/69293_neg.cc
index 921ebbc87de39..2c5a62190e88d 100644
--- a/libstdc++-v3/testsuite/20_util/uses_allocator/69293_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/uses_allocator/69293_neg.cc
@@ -45,5 +45,5 @@ test01()
   alloc_type a;
   std::tuple<X> t(std::allocator_arg, a); // this is required to be ill-formed
   // { dg-error "failed: .* uses_allocator is true" "" { target *-*-* } 0 }
-  // { dg-error "no matching function for call" "" { target c++2a } 0 }
+  // { dg-error "too many initializers for 'X'" "" { target c++2a } 0 }
 }
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
index c5cda77647776..e858e3508bda1 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
@@ -33,3 +33,4 @@ void foo(std::iostream& s) {
   s >> p; // { dg-error "no match" }
 }
 // { dg-prune-output "no type .*enable_if" }
+// { dg-prune-output "template constraint failure" }

From f91797541c7788cc253681e6784273903e678b2b Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 16:22:53 +0100
Subject: [PATCH 092/164] libstdc++: Remove redundant -std=gnu++17 options from
 PSTL tests

GCC defaults to -std=gnu++17 now anyway, and using it explicitly in the
dg-options directive prevents running these tests with different modes
such as -std=c++17 or -std=gnu++20.

libstdc++-v3/ChangeLog:

	* testsuite/20_util/specialized_algorithms/pstl/uninitialized_construct.cc:
	Remove -std=gnu++17 from dg-options.
	* testsuite/20_util/specialized_algorithms/pstl/uninitialized_copy_move.cc:
	Likewise.
	* testsuite/20_util/specialized_algorithms/pstl/uninitialized_fill_destroy.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_merge/inplace_merge.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_merge/merge.cc: Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/copy_if.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/copy_move.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/fill.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/generate.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/is_partitioned.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/partition.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/partition_copy.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/remove.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/remove_copy.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/replace.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/replace_copy.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/rotate.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/rotate_copy.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/swap_ranges.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/transform_binary.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/transform_unary.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/unique.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_modifying_operations/unique_copy_equal.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/adjacent_find.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/all_of.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/any_of.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/count.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/equal.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/find.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/find_end.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/find_first_of.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/find_if.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/for_each.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/mismatch.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/none_of.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/nth_element.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/reverse.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/reverse_copy.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_nonmodifying/search_n.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_sorting/includes.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_sorting/is_heap.cc: Likewise.
	* testsuite/25_algorithms/pstl/alg_sorting/is_sorted.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_sorting/lexicographical_compare.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_sorting/minmax_element.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_sorting/partial_sort.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_sorting/partial_sort_copy.cc:
	Likewise.
	* testsuite/25_algorithms/pstl/alg_sorting/set.cc: Likewise.
	* testsuite/25_algorithms/pstl/alg_sorting/sort.cc: Likewise.
	* testsuite/25_algorithms/pstl/feature_test-2.cc: Likewise.
	* testsuite/25_algorithms/pstl/feature_test-3.cc: Likewise.
	* testsuite/25_algorithms/pstl/feature_test-4.cc: Likewise.
	* testsuite/25_algorithms/pstl/feature_test-5.cc: Likewise.
	* testsuite/25_algorithms/pstl/feature_test.cc: Likewise.
	* testsuite/26_numerics/pstl/numeric_ops/adjacent_difference.cc:
	Likewise.
	* testsuite/26_numerics/pstl/numeric_ops/reduce.cc: Likewise.
	* testsuite/26_numerics/pstl/numeric_ops/scan.cc: Likewise.
	* testsuite/26_numerics/pstl/numeric_ops/transform_reduce.cc:
	Likewise.
	* testsuite/26_numerics/pstl/numeric_ops/transform_scan.cc:
	Likewise.

(cherry picked from commit 646e6c652448bfd8fca535d91f588b4606295a72)
---
 .../specialized_algorithms/pstl/uninitialized_construct.cc      | 2 +-
 .../specialized_algorithms/pstl/uninitialized_copy_move.cc      | 2 +-
 .../specialized_algorithms/pstl/uninitialized_fill_destroy.cc   | 2 +-
 .../testsuite/25_algorithms/pstl/alg_merge/inplace_merge.cc     | 2 +-
 libstdc++-v3/testsuite/25_algorithms/pstl/alg_merge/merge.cc    | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/copy_if.cc      | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/copy_move.cc    | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/fill.cc         | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/generate.cc     | 2 +-
 .../pstl/alg_modifying_operations/is_partitioned.cc             | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/partition.cc    | 2 +-
 .../pstl/alg_modifying_operations/partition_copy.cc             | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/remove.cc       | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/remove_copy.cc  | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/replace.cc      | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/replace_copy.cc | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/rotate.cc       | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/rotate_copy.cc  | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/swap_ranges.cc  | 2 +-
 .../pstl/alg_modifying_operations/transform_binary.cc           | 2 +-
 .../pstl/alg_modifying_operations/transform_unary.cc            | 2 +-
 .../25_algorithms/pstl/alg_modifying_operations/unique.cc       | 2 +-
 .../pstl/alg_modifying_operations/unique_copy_equal.cc          | 2 +-
 .../25_algorithms/pstl/alg_nonmodifying/adjacent_find.cc        | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/all_of.cc     | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/any_of.cc     | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/count.cc      | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/equal.cc      | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/find.cc       | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/find_end.cc   | 2 +-
 .../25_algorithms/pstl/alg_nonmodifying/find_first_of.cc        | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/find_if.cc    | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/for_each.cc   | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/mismatch.cc   | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/none_of.cc    | 2 +-
 .../25_algorithms/pstl/alg_nonmodifying/nth_element.cc          | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/reverse.cc    | 2 +-
 .../25_algorithms/pstl/alg_nonmodifying/reverse_copy.cc         | 2 +-
 .../testsuite/25_algorithms/pstl/alg_nonmodifying/search_n.cc   | 2 +-
 .../testsuite/25_algorithms/pstl/alg_sorting/includes.cc        | 2 +-
 .../testsuite/25_algorithms/pstl/alg_sorting/is_heap.cc         | 2 +-
 .../testsuite/25_algorithms/pstl/alg_sorting/is_sorted.cc       | 2 +-
 .../25_algorithms/pstl/alg_sorting/lexicographical_compare.cc   | 2 +-
 .../testsuite/25_algorithms/pstl/alg_sorting/minmax_element.cc  | 2 +-
 .../testsuite/25_algorithms/pstl/alg_sorting/partial_sort.cc    | 2 +-
 .../25_algorithms/pstl/alg_sorting/partial_sort_copy.cc         | 2 +-
 libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/set.cc    | 2 +-
 libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/sort.cc   | 2 +-
 libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-2.cc     | 1 -
 libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-3.cc     | 1 -
 libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-4.cc     | 1 -
 libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-5.cc     | 1 -
 libstdc++-v3/testsuite/25_algorithms/pstl/feature_test.cc       | 1 -
 .../26_numerics/pstl/numeric_ops/adjacent_difference.cc         | 2 +-
 libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/reduce.cc   | 2 +-
 libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/scan.cc     | 2 +-
 .../testsuite/26_numerics/pstl/numeric_ops/transform_reduce.cc  | 2 +-
 .../testsuite/26_numerics/pstl/numeric_ops/transform_scan.cc    | 2 +-
 58 files changed, 53 insertions(+), 58 deletions(-)

diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_construct.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_construct.cc
index a6dbe69b60ccc..c021ff2e8c926 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_construct.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_construct.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_copy_move.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_copy_move.cc
index 48b6a6a0ce3d9..40c40c5bc2e4e 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_copy_move.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_copy_move.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_fill_destroy.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_fill_destroy.cc
index 16a6ef24f9626..793c5241b78e6 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_fill_destroy.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/pstl/uninitialized_fill_destroy.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_merge/inplace_merge.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_merge/inplace_merge.cc
index 74af960901a2e..52b6271e95673 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_merge/inplace_merge.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_merge/inplace_merge.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_merge/merge.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_merge/merge.cc
index d6dea089af542..ec48b5fdb9e19 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_merge/merge.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_merge/merge.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/copy_if.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/copy_if.cc
index ac5d6437aa1eb..ad8dea0f0868d 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/copy_if.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/copy_if.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/copy_move.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/copy_move.cc
index 8adca5bba2ed6..cec0c14b04f53 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/copy_move.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/copy_move.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/fill.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/fill.cc
index 4e67d878b62b6..74a218382ec12 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/fill.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/fill.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/generate.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/generate.cc
index d732b5bda5426..277722a05d721 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/generate.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/generate.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/is_partitioned.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/is_partitioned.cc
index 055ec389c8f2d..f583d83ba8b49 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/is_partitioned.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/is_partitioned.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/partition.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/partition.cc
index dbda3d82d8136..a94eff614c674 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/partition.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/partition.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/partition_copy.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/partition_copy.cc
index 0f0606dfb5e59..fa8d05c679fb9 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/partition_copy.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/partition_copy.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/remove.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/remove.cc
index 3411a2d052bed..b9713ec218603 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/remove.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/remove.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/remove_copy.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/remove_copy.cc
index fc5aca4714421..12759dfbb4238 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/remove_copy.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/remove_copy.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/replace.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/replace.cc
index 18e990b64ddb4..624582aa32516 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/replace.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/replace.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/replace_copy.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/replace_copy.cc
index 7f7cfe1beed5f..d482960b035ba 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/replace_copy.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/replace_copy.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/rotate.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/rotate.cc
index 37fda264198f4..ef94f15f2faab 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/rotate.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/rotate.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/rotate_copy.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/rotate_copy.cc
index b3275ea3a7bf9..a75ab87a5b108 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/rotate_copy.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/rotate_copy.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/swap_ranges.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/swap_ranges.cc
index a6d4fa431afde..bf48221c8b032 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/swap_ranges.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/swap_ranges.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/transform_binary.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/transform_binary.cc
index 518647ab2bd1f..222dfcae30392 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/transform_binary.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/transform_binary.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/transform_unary.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/transform_unary.cc
index ffb5a5c789162..e33bb5989d174 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/transform_unary.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/transform_unary.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/unique.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/unique.cc
index c7a64586a8102..8fe7f9af80c07 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/unique.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/unique.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/unique_copy_equal.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/unique_copy_equal.cc
index 6102a32a14b09..6bba0ff1bc944 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/unique_copy_equal.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_modifying_operations/unique_copy_equal.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/adjacent_find.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/adjacent_find.cc
index 5cb830202df7c..b558d3a689fc4 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/adjacent_find.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/adjacent_find.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/all_of.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/all_of.cc
index b7e7fd9d1f49f..c4974b2ddc059 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/all_of.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/all_of.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/any_of.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/any_of.cc
index 31585c630a8e6..0e289785316d8 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/any_of.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/any_of.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/count.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/count.cc
index 42e57f4fe7557..c7486ba4fdbb1 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/count.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/count.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/equal.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/equal.cc
index fb8b30292fce0..d563d478a53d1 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/equal.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/equal.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find.cc
index 7bf6980609df6..d36532bc933fa 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_end.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_end.cc
index 08daa10417358..0b950e29396d3 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_end.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_end.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_first_of.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_first_of.cc
index 59e37caa3709d..5aa3d65858099 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_first_of.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_first_of.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_if.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_if.cc
index 39cc1352d0c9d..bc7187fa19258 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_if.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/find_if.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/for_each.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/for_each.cc
index fc4ab3a77f0d3..aace092ac4a0a 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/for_each.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/for_each.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/mismatch.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/mismatch.cc
index f792b5105c4ac..a40606dacfe07 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/mismatch.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/mismatch.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/none_of.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/none_of.cc
index 2883385e9a62e..5f44feefef131 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/none_of.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/none_of.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/nth_element.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/nth_element.cc
index 65b192f55793a..4befdfa2876fd 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/nth_element.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/nth_element.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/reverse.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/reverse.cc
index dd4de34624ab0..15bb34e187bb1 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/reverse.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/reverse.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/reverse_copy.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/reverse_copy.cc
index 2563cef060ee2..7d3bc5e76f368 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/reverse_copy.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/reverse_copy.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/search_n.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/search_n.cc
index 0720c377011fa..47067379699fa 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/search_n.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_nonmodifying/search_n.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/includes.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/includes.cc
index 0a61e4f44fb57..cb7871307e922 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/includes.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/includes.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/is_heap.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/is_heap.cc
index d9d77719339da..e444d920b19b2 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/is_heap.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/is_heap.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/is_sorted.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/is_sorted.cc
index daa1601e04e3a..36180e583b01e 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/is_sorted.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/is_sorted.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/lexicographical_compare.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/lexicographical_compare.cc
index fd758ba3dfa32..0bb9d93732c1b 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/lexicographical_compare.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/lexicographical_compare.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/minmax_element.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/minmax_element.cc
index 52306ec2c1cbf..ef0157a8043bd 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/minmax_element.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/minmax_element.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/partial_sort.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/partial_sort.cc
index 63f2a1c2e75c1..b868bdf79be1c 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/partial_sort.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/partial_sort.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/partial_sort_copy.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/partial_sort_copy.cc
index e4da0b3351f29..80a950cfb8441 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/partial_sort_copy.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/partial_sort_copy.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/set.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/set.cc
index 286a528c825fc..03e18fa7da567 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/set.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/set.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/sort.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/sort.cc
index f5cb00e1b2027..262e8a7f33c42 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/sort.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/alg_sorting/sort.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-2.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-2.cc
index 283a962dc3372..c932b3c5d51c1 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-2.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do preprocess { target c++17 } }
 // { dg-require-effective-target tbb-backend }
 
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-3.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-3.cc
index 267fe889da223..aeded124d1834 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-3.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-3.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do preprocess { target c++17 } }
 // { dg-require-effective-target tbb-backend }
 
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-4.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-4.cc
index 7087b58d889c5..eddd965300446 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-4.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-4.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do preprocess { target c++17 } }
 
 #include <version>
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-5.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-5.cc
index ccdb86dd6e547..4d0c7aaa3a23d 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-5.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test-5.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do preprocess { target c++17 } }
 // { dg-require-effective-target tbb-backend }
 
diff --git a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test.cc b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test.cc
index de01cc4f10923..8d3ffff776a82 100644
--- a/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/pstl/feature_test.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do preprocess { target c++17 } }
 // { dg-require-effective-target tbb-backend }
 
diff --git a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/adjacent_difference.cc b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/adjacent_difference.cc
index 26dc2803639a8..ffeb91ea79491 100644
--- a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/adjacent_difference.cc
+++ b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/adjacent_difference.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/reduce.cc b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/reduce.cc
index b31cdcc9c08fb..91a6ceea3685b 100644
--- a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/reduce.cc
+++ b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/reduce.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/scan.cc b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/scan.cc
index 41b92cb398480..e573f27617152 100644
--- a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/scan.cc
+++ b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/scan.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/transform_reduce.cc b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/transform_reduce.cc
index a083d9cb110c3..3087e54104e28 100644
--- a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/transform_reduce.cc
+++ b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/transform_reduce.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }
diff --git a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/transform_scan.cc b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/transform_scan.cc
index babe84e592d60..584e4f1c2d37e 100644
--- a/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/transform_scan.cc
+++ b/libstdc++-v3/testsuite/26_numerics/pstl/numeric_ops/transform_scan.cc
@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// { dg-options "-std=gnu++17 -ltbb" }
+// { dg-options "-ltbb" }
 // { dg-do run { target c++17 } }
 // { dg-timeout-factor 3 }
 // { dg-require-effective-target tbb-backend }

From 4c059278725c14c312fab293431843cd9da2d586 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 16:22:53 +0100
Subject: [PATCH 093/164] libstdc++: Remove redundant -std=gnu++17 options from
 filesystem tests

GCC defaults to -std=gnu++17 now anyway, and using it explicitly in the
dg-options directive prevents running these tests with different modes
such as -std=c++17 or -std=gnu++20.

libstdc++-v3/ChangeLog:

	* testsuite/27_io/basic_filebuf/open/char/path.cc: Remove
	-std=gnu++17 from dg-options directive.
	* testsuite/27_io/basic_fstream/cons/char/path.cc: Likewise.
	* testsuite/27_io/basic_fstream/open/char/path.cc: Likewise.
	* testsuite/27_io/basic_ifstream/cons/char/path.cc: Likewise.
	* testsuite/27_io/basic_ifstream/open/char/path.cc: Likewise.
	* testsuite/27_io/basic_ofstream/cons/char/path.cc: Likewise.
	* testsuite/27_io/basic_ofstream/open/char/path.cc: Likewise.
	* testsuite/27_io/filesystem/directory_entry/86597.cc: Likewise.
	* testsuite/27_io/filesystem/directory_entry/lwg3171.cc:
	Likewise.
	* testsuite/27_io/filesystem/file_status/1.cc: Likewise.
	* testsuite/27_io/filesystem/filesystem_error/cons.cc: Likewise.
	* testsuite/27_io/filesystem/filesystem_error/copy.cc: Likewise.
	* testsuite/27_io/filesystem/iterators/91067.cc: Likewise.
	* testsuite/27_io/filesystem/iterators/caching.cc: Likewise.
	* testsuite/27_io/filesystem/iterators/directory_iterator.cc:
	Likewise.
	* testsuite/27_io/filesystem/iterators/pop.cc: Likewise.
	* testsuite/27_io/filesystem/iterators/recursion_pending.cc:
	Likewise.
	* testsuite/27_io/filesystem/iterators/recursive_directory_iterator.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/absolute.cc: Likewise.
	* testsuite/27_io/filesystem/operations/all.cc: Likewise.
	* testsuite/27_io/filesystem/operations/canonical.cc: Likewise.
	* testsuite/27_io/filesystem/operations/copy.cc: Likewise.
	* testsuite/27_io/filesystem/operations/copy_file.cc: Likewise.
	* testsuite/27_io/filesystem/operations/create_directories.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/create_directory.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/create_symlink.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/current_path.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/equivalent.cc: Likewise.
	* testsuite/27_io/filesystem/operations/exists.cc: Likewise.
	* testsuite/27_io/filesystem/operations/file_size.cc: Likewise.
	* testsuite/27_io/filesystem/operations/is_empty.cc: Likewise.
	* testsuite/27_io/filesystem/operations/last_write_time.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/permissions.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/proximate.cc: Likewise.
	* testsuite/27_io/filesystem/operations/read_symlink.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/relative.cc: Likewise.
	* testsuite/27_io/filesystem/operations/remove.cc: Likewise.
	* testsuite/27_io/filesystem/operations/remove_all.cc: Likewise.
	* testsuite/27_io/filesystem/operations/rename.cc: Likewise.
	* testsuite/27_io/filesystem/operations/resize_file.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/space.cc: Likewise.
	* testsuite/27_io/filesystem/operations/status.cc: Likewise.
	* testsuite/27_io/filesystem/operations/symlink_status.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/temp_directory_path.cc:
	Likewise.
	* testsuite/27_io/filesystem/operations/weakly_canonical.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/append/path.cc: Likewise.
	* testsuite/27_io/filesystem/path/append/source.cc: Likewise.
	* testsuite/27_io/filesystem/path/assign/assign.cc: Likewise.
	* testsuite/27_io/filesystem/path/assign/copy.cc: Likewise.
	* testsuite/27_io/filesystem/path/compare/compare.cc: Likewise.
	* testsuite/27_io/filesystem/path/compare/lwg2936.cc: Likewise.
	* testsuite/27_io/filesystem/path/compare/path.cc: Likewise.
	* testsuite/27_io/filesystem/path/compare/strings.cc: Likewise.
	* testsuite/27_io/filesystem/path/concat/92853.cc: Likewise.
	* testsuite/27_io/filesystem/path/concat/94063.cc: Likewise.
	* testsuite/27_io/filesystem/path/concat/path.cc: Likewise.
	* testsuite/27_io/filesystem/path/concat/strings.cc: Likewise.
	* testsuite/27_io/filesystem/path/construct/80762.cc: Likewise.
	* testsuite/27_io/filesystem/path/construct/90281.cc: Likewise.
	* testsuite/27_io/filesystem/path/construct/90634.cc: Likewise.
	* testsuite/27_io/filesystem/path/construct/copy.cc: Likewise.
	* testsuite/27_io/filesystem/path/construct/default.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/construct/format.cc: Likewise.
	* testsuite/27_io/filesystem/path/construct/locale.cc: Likewise.
	* testsuite/27_io/filesystem/path/construct/range.cc: Likewise.
	* testsuite/27_io/filesystem/path/construct/string_view.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/decompose/extension.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/decompose/filename.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/decompose/parent_path.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/decompose/relative_path.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/decompose/root_directory.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/decompose/root_name.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/decompose/root_path.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/decompose/stem.cc: Likewise.
	* testsuite/27_io/filesystem/path/factory/u8path-char8_t.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/factory/u8path.cc: Likewise.
	* testsuite/27_io/filesystem/path/generation/normal.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/generation/normal2.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/generation/proximate.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/generation/relative.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/generic/94242.cc: Likewise.
	* testsuite/27_io/filesystem/path/generic/generic_string.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/generic/utf.cc: Likewise.
	* testsuite/27_io/filesystem/path/generic/wchar_t.cc: Likewise.
	* testsuite/27_io/filesystem/path/io/dr2989.cc: Likewise.
	* testsuite/27_io/filesystem/path/itr/components.cc: Likewise.
	* testsuite/27_io/filesystem/path/itr/traversal.cc: Likewise.
	* testsuite/27_io/filesystem/path/modifiers/clear.cc: Likewise.
	* testsuite/27_io/filesystem/path/modifiers/make_preferred.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/modifiers/remove_filename.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/modifiers/replace_extension.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/modifiers/replace_filename.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/modifiers/swap.cc: Likewise.
	* testsuite/27_io/filesystem/path/native/alloc.cc: Likewise.
	* testsuite/27_io/filesystem/path/native/string-char8_t.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/native/string.cc: Likewise.
	* testsuite/27_io/filesystem/path/nonmember/append.cc: Likewise.
	* testsuite/27_io/filesystem/path/nonmember/cmp.cc: Likewise.
	* testsuite/27_io/filesystem/path/nonmember/hash_value.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/query/empty.cc: Likewise.
	* testsuite/27_io/filesystem/path/query/empty_neg.cc:
	* testsuite/27_io/filesystem/path/query/has_extension.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/query/has_filename.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/query/has_parent_path.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/query/has_relative_path.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/query/has_root_directory.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/query/has_root_name.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/query/has_root_path.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/query/has_stem.cc: Likewise.
	* testsuite/27_io/filesystem/path/query/is_absolute.cc:
	Likewise.
	* testsuite/27_io/filesystem/path/query/is_relative.cc:
	Likewise.
	* testsuite/experimental/filesystem/path/construct/string_view.cc:
	Likewise.

(cherry picked from commit aa60ff1c8879f67557efc188b1d18d008458c76a)
---
 libstdc++-v3/testsuite/27_io/basic_filebuf/open/char/path.cc    | 2 +-
 libstdc++-v3/testsuite/27_io/basic_fstream/cons/char/path.cc    | 2 +-
 libstdc++-v3/testsuite/27_io/basic_fstream/open/char/path.cc    | 2 +-
 libstdc++-v3/testsuite/27_io/basic_ifstream/cons/char/path.cc   | 2 +-
 libstdc++-v3/testsuite/27_io/basic_ifstream/open/char/path.cc   | 2 +-
 libstdc++-v3/testsuite/27_io/basic_ofstream/cons/char/path.cc   | 2 +-
 libstdc++-v3/testsuite/27_io/basic_ofstream/open/char/path.cc   | 2 +-
 .../testsuite/27_io/filesystem/directory_entry/86597.cc         | 1 -
 .../testsuite/27_io/filesystem/directory_entry/lwg3171.cc       | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/file_status/1.cc        | 1 -
 .../testsuite/27_io/filesystem/filesystem_error/cons.cc         | 1 -
 .../testsuite/27_io/filesystem/filesystem_error/copy.cc         | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/iterators/91067.cc      | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/iterators/caching.cc    | 1 -
 .../testsuite/27_io/filesystem/iterators/directory_iterator.cc  | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/iterators/pop.cc        | 1 -
 .../testsuite/27_io/filesystem/iterators/recursion_pending.cc   | 1 -
 .../27_io/filesystem/iterators/recursive_directory_iterator.cc  | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/absolute.cc  | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/all.cc       | 2 +-
 libstdc++-v3/testsuite/27_io/filesystem/operations/canonical.cc | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/copy.cc      | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/copy_file.cc | 1 -
 .../testsuite/27_io/filesystem/operations/create_directories.cc | 1 -
 .../testsuite/27_io/filesystem/operations/create_directory.cc   | 1 -
 .../testsuite/27_io/filesystem/operations/create_symlink.cc     | 1 -
 .../testsuite/27_io/filesystem/operations/current_path.cc       | 1 -
 .../testsuite/27_io/filesystem/operations/equivalent.cc         | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/exists.cc    | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/file_size.cc | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/is_empty.cc  | 1 -
 .../testsuite/27_io/filesystem/operations/last_write_time.cc    | 1 -
 .../testsuite/27_io/filesystem/operations/permissions.cc        | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/proximate.cc | 1 -
 .../testsuite/27_io/filesystem/operations/read_symlink.cc       | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/relative.cc  | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/remove.cc    | 1 -
 .../testsuite/27_io/filesystem/operations/remove_all.cc         | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/rename.cc    | 1 -
 .../testsuite/27_io/filesystem/operations/resize_file.cc        | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/space.cc     | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/operations/status.cc    | 1 -
 .../testsuite/27_io/filesystem/operations/symlink_status.cc     | 1 -
 .../27_io/filesystem/operations/temp_directory_path.cc          | 1 -
 .../testsuite/27_io/filesystem/operations/weakly_canonical.cc   | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/append/path.cc     | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/append/source.cc   | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/assign/assign.cc   | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/assign/copy.cc     | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/compare/compare.cc | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/compare/lwg2936.cc | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/compare/path.cc    | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/compare/strings.cc | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/concat/92853.cc    | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/concat/94063.cc    | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/concat/path.cc     | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/concat/strings.cc  | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/construct/80762.cc | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/construct/90281.cc | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/construct/90634.cc | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/construct/copy.cc  | 1 -
 .../testsuite/27_io/filesystem/path/construct/default.cc        | 1 -
 .../testsuite/27_io/filesystem/path/construct/format.cc         | 1 -
 .../testsuite/27_io/filesystem/path/construct/locale.cc         | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/construct/range.cc | 1 -
 .../testsuite/27_io/filesystem/path/construct/string_view.cc    | 1 -
 .../testsuite/27_io/filesystem/path/decompose/extension.cc      | 1 -
 .../testsuite/27_io/filesystem/path/decompose/filename.cc       | 1 -
 .../testsuite/27_io/filesystem/path/decompose/parent_path.cc    | 1 -
 .../testsuite/27_io/filesystem/path/decompose/relative_path.cc  | 1 -
 .../testsuite/27_io/filesystem/path/decompose/root_directory.cc | 1 -
 .../testsuite/27_io/filesystem/path/decompose/root_name.cc      | 1 -
 .../testsuite/27_io/filesystem/path/decompose/root_path.cc      | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/decompose/stem.cc  | 1 -
 .../testsuite/27_io/filesystem/path/factory/u8path-char8_t.cc   | 2 +-
 libstdc++-v3/testsuite/27_io/filesystem/path/factory/u8path.cc  | 1 -
 .../testsuite/27_io/filesystem/path/generation/normal.cc        | 1 -
 .../testsuite/27_io/filesystem/path/generation/normal2.cc       | 1 -
 .../testsuite/27_io/filesystem/path/generation/proximate.cc     | 1 -
 .../testsuite/27_io/filesystem/path/generation/relative.cc      | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/generic/94242.cc   | 1 -
 .../testsuite/27_io/filesystem/path/generic/generic_string.cc   | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/generic/utf.cc     | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/generic/wchar_t.cc | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc       | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/itr/components.cc  | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/itr/traversal.cc   | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/clear.cc | 1 -
 .../testsuite/27_io/filesystem/path/modifiers/make_preferred.cc | 1 -
 .../27_io/filesystem/path/modifiers/remove_filename.cc          | 1 -
 .../27_io/filesystem/path/modifiers/replace_extension.cc        | 1 -
 .../27_io/filesystem/path/modifiers/replace_filename.cc         | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/swap.cc  | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/native/alloc.cc    | 1 -
 .../testsuite/27_io/filesystem/path/native/string-char8_t.cc    | 2 +-
 libstdc++-v3/testsuite/27_io/filesystem/path/native/string.cc   | 1 -
 .../testsuite/27_io/filesystem/path/nonmember/append.cc         | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/cmp.cc   | 1 -
 .../testsuite/27_io/filesystem/path/nonmember/hash_value.cc     | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/query/empty.cc     | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/query/empty_neg.cc | 1 -
 .../testsuite/27_io/filesystem/path/query/has_extension.cc      | 1 -
 .../testsuite/27_io/filesystem/path/query/has_filename.cc       | 1 -
 .../testsuite/27_io/filesystem/path/query/has_parent_path.cc    | 1 -
 .../testsuite/27_io/filesystem/path/query/has_relative_path.cc  | 1 -
 .../testsuite/27_io/filesystem/path/query/has_root_directory.cc | 1 -
 .../testsuite/27_io/filesystem/path/query/has_root_name.cc      | 1 -
 .../testsuite/27_io/filesystem/path/query/has_root_path.cc      | 1 -
 libstdc++-v3/testsuite/27_io/filesystem/path/query/has_stem.cc  | 1 -
 .../testsuite/27_io/filesystem/path/query/is_absolute.cc        | 1 -
 .../testsuite/27_io/filesystem/path/query/is_relative.cc        | 1 -
 .../experimental/filesystem/path/construct/string_view.cc       | 2 +-
 112 files changed, 11 insertions(+), 112 deletions(-)

diff --git a/libstdc++-v3/testsuite/27_io/basic_filebuf/open/char/path.cc b/libstdc++-v3/testsuite/27_io/basic_filebuf/open/char/path.cc
index 7655a0f349340..43a2dd5d9d688 100644
--- a/libstdc++-v3/testsuite/27_io/basic_filebuf/open/char/path.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_filebuf/open/char/path.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -lstdc++fs" }
+// { dg-options "-lstdc++fs" }
 // { dg-do run { target c++17 } }
 // { dg-require-fileio "" }
 // { dg-require-filesystem-ts "" }
diff --git a/libstdc++-v3/testsuite/27_io/basic_fstream/cons/char/path.cc b/libstdc++-v3/testsuite/27_io/basic_fstream/cons/char/path.cc
index b9303f76a343b..ae924b7a824fb 100644
--- a/libstdc++-v3/testsuite/27_io/basic_fstream/cons/char/path.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_fstream/cons/char/path.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -lstdc++fs" }
+// { dg-options "-lstdc++fs" }
 // { dg-do run { target c++17 } }
 // { dg-require-fileio "" }
 // { dg-require-filesystem-ts "" }
diff --git a/libstdc++-v3/testsuite/27_io/basic_fstream/open/char/path.cc b/libstdc++-v3/testsuite/27_io/basic_fstream/open/char/path.cc
index b1898fd888d33..efbd462cd53db 100644
--- a/libstdc++-v3/testsuite/27_io/basic_fstream/open/char/path.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_fstream/open/char/path.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -lstdc++fs" }
+// { dg-options "-lstdc++fs" }
 // { dg-do run { target c++17 } }
 // { dg-require-fileio "" }
 // { dg-require-filesystem-ts "" }
diff --git a/libstdc++-v3/testsuite/27_io/basic_ifstream/cons/char/path.cc b/libstdc++-v3/testsuite/27_io/basic_ifstream/cons/char/path.cc
index e0768e4ec22c1..0dbf3e341426e 100644
--- a/libstdc++-v3/testsuite/27_io/basic_ifstream/cons/char/path.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_ifstream/cons/char/path.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -lstdc++fs" }
+// { dg-options "-lstdc++fs" }
 // { dg-do run { target c++17 } }
 // { dg-require-fileio "" }
 // { dg-require-filesystem-ts "" }
diff --git a/libstdc++-v3/testsuite/27_io/basic_ifstream/open/char/path.cc b/libstdc++-v3/testsuite/27_io/basic_ifstream/open/char/path.cc
index 25854cfde996a..df2c90198bbaa 100644
--- a/libstdc++-v3/testsuite/27_io/basic_ifstream/open/char/path.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_ifstream/open/char/path.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -lstdc++fs" }
+// { dg-options "-lstdc++fs" }
 // { dg-do run { target c++17 } }
 // { dg-require-fileio "" }
 // { dg-require-filesystem-ts "" }
diff --git a/libstdc++-v3/testsuite/27_io/basic_ofstream/cons/char/path.cc b/libstdc++-v3/testsuite/27_io/basic_ofstream/cons/char/path.cc
index 0e248ffb29aca..f5cb3512c681c 100644
--- a/libstdc++-v3/testsuite/27_io/basic_ofstream/cons/char/path.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_ofstream/cons/char/path.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -lstdc++fs" }
+// { dg-options "-lstdc++fs" }
 // { dg-do run { target c++17 } }
 // { dg-require-fileio "" }
 // { dg-require-filesystem-ts "" }
diff --git a/libstdc++-v3/testsuite/27_io/basic_ofstream/open/char/path.cc b/libstdc++-v3/testsuite/27_io/basic_ofstream/open/char/path.cc
index 429bcf141e901..87b1c8094c864 100644
--- a/libstdc++-v3/testsuite/27_io/basic_ofstream/open/char/path.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_ofstream/open/char/path.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -lstdc++fs" }
+// { dg-options "-lstdc++fs" }
 // { dg-do run { target c++17 } }
 // { dg-require-fileio "" }
 // { dg-require-filesystem-ts "" }
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/directory_entry/86597.cc b/libstdc++-v3/testsuite/27_io/filesystem/directory_entry/86597.cc
index 59be7dd2f1fde..d2882b54965e3 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/directory_entry/86597.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/directory_entry/86597.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/directory_entry/lwg3171.cc b/libstdc++-v3/testsuite/27_io/filesystem/directory_entry/lwg3171.cc
index 561a1d2dcb9d8..ddf9b29745c25 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/directory_entry/lwg3171.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/directory_entry/lwg3171.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/file_status/1.cc b/libstdc++-v3/testsuite/27_io/filesystem/file_status/1.cc
index 399443cbb672d..4dd26db484909 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/file_status/1.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/file_status/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/filesystem_error/cons.cc b/libstdc++-v3/testsuite/27_io/filesystem/filesystem_error/cons.cc
index 5c890968eb314..804caf8ea0f03 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/filesystem_error/cons.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/filesystem_error/cons.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/filesystem_error/copy.cc b/libstdc++-v3/testsuite/27_io/filesystem/filesystem_error/copy.cc
index 99cd1fba0c16e..d83976338db9a 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/filesystem_error/copy.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/filesystem_error/copy.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/iterators/91067.cc b/libstdc++-v3/testsuite/27_io/filesystem/iterators/91067.cc
index cfc28788d5568..8616b452f3c5b 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/iterators/91067.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/iterators/91067.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do link { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/iterators/caching.cc b/libstdc++-v3/testsuite/27_io/filesystem/iterators/caching.cc
index f2c65e79433a6..e44c3465e2d1b 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/iterators/caching.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/iterators/caching.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/iterators/directory_iterator.cc b/libstdc++-v3/testsuite/27_io/filesystem/iterators/directory_iterator.cc
index dae6ff4f77536..b49b4ae2feafb 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/iterators/directory_iterator.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/iterators/directory_iterator.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/iterators/pop.cc b/libstdc++-v3/testsuite/27_io/filesystem/iterators/pop.cc
index f903c4faee367..bc73de8a561c1 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/iterators/pop.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/iterators/pop.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/iterators/recursion_pending.cc b/libstdc++-v3/testsuite/27_io/filesystem/iterators/recursion_pending.cc
index 33c3b813456e6..9a6fcda5fb1f6 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/iterators/recursion_pending.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/iterators/recursion_pending.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/iterators/recursive_directory_iterator.cc b/libstdc++-v3/testsuite/27_io/filesystem/iterators/recursive_directory_iterator.cc
index 94a918499225f..4de25c780e0c7 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/iterators/recursive_directory_iterator.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/iterators/recursive_directory_iterator.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/absolute.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/absolute.cc
index fde1d07884f3d..24d59799ef1ee 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/absolute.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/absolute.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/all.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/all.cc
index 2bcf14abe1237..414c2d8d72c54 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/all.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/all.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -fno-inline" }
+// { dg-options "-fno-inline" }
 // { dg-do link { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/canonical.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/canonical.cc
index fe1b9d713b8e6..172ef09ee8572 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/canonical.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/canonical.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/copy.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/copy.cc
index 3d3ac67c7ca0d..761cfc29b13d2 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/copy.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/copy.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/copy_file.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/copy_file.cc
index 5500e6a46d2d2..0ad4bee862140 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/copy_file.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/copy_file.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/create_directories.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/create_directories.cc
index 4625b2270e063..393d6a5530925 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/create_directories.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/create_directories.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/create_directory.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/create_directory.cc
index 02bf0061fc4b9..a0e50471275a8 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/create_directory.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/create_directory.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/create_symlink.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/create_symlink.cc
index 20e3ee0b6ca63..f2d1a0feb1922 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/create_symlink.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/create_symlink.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/current_path.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/current_path.cc
index 7f5aae4d6037a..94bad970ded38 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/current_path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/current_path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/equivalent.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/equivalent.cc
index 8a340106bb4ed..9354de2e796de 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/equivalent.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/equivalent.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/exists.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/exists.cc
index 04f3b114ca86c..c4cb7648e917e 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/exists.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/exists.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/file_size.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/file_size.cc
index 0b4d27cd778f3..5f7db20d8407f 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/file_size.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/file_size.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/is_empty.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/is_empty.cc
index d2fbaa0410e5d..40d83eda6f3d8 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/is_empty.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/is_empty.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/last_write_time.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/last_write_time.cc
index 6ae64c482b6b6..b4c630f8e1e5f 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/last_write_time.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/last_write_time.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/permissions.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/permissions.cc
index 13548d767ef8e..5dc964d07343f 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/permissions.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/permissions.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 // { dg-xfail-if "permissions not supported" { *-*-mingw* } }
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/proximate.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/proximate.cc
index dc5b926b85893..7abf64e50b85e 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/proximate.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/proximate.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/read_symlink.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/read_symlink.cc
index bc71d03290fc4..3a8244b828030 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/read_symlink.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/read_symlink.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 // { dg-xfail-if "symlinks not supported" { *-*-mingw* } }
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/relative.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/relative.cc
index fc3d65871b968..fd0067f3773c1 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/relative.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/relative.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/remove.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/remove.cc
index 8308d2571a0a3..3136d9dddbe30 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/remove.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/remove.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/remove_all.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/remove_all.cc
index 986a8dfb2aef3..9a49dcaf03c58 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/remove_all.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/remove_all.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/rename.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/rename.cc
index c873811ad934b..4bd45ea2e2710 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/rename.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/rename.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/resize_file.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/resize_file.cc
index ae87a6a7e5e04..7fe4be42b6293 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/resize_file.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/resize_file.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/space.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/space.cc
index 3c67b1350b859..8a080214fe4bb 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/space.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/space.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/status.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/status.cc
index 94834d848abae..53489017669c8 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/status.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/status.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/symlink_status.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/symlink_status.cc
index f0f786cdab319..9920280897612 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/symlink_status.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/symlink_status.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 // { dg-xfail-if "symlinks not supported" { *-*-mingw* } }
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/temp_directory_path.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/temp_directory_path.cc
index 86f5ac730f678..ff84a0a453110 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/temp_directory_path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/temp_directory_path.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/weakly_canonical.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/weakly_canonical.cc
index 30bf6bfd16444..6d460d6f2c409 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/weakly_canonical.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/weakly_canonical.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/append/path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/append/path.cc
index b3596f2bd65fd..1e06b6161bc09 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/append/path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/append/path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/append/source.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/append/source.cc
index d28c147d34d19..3891a9bb7c2e5 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/append/source.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/append/source.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/assign/assign.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/assign/assign.cc
index 3b02d88fe4a64..1023ca6a69bd1 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/assign/assign.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/assign/assign.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/assign/copy.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/assign/copy.cc
index 00ead960e0238..8a5fdab1921b3 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/assign/copy.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/assign/copy.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/compare/compare.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/compare/compare.cc
index 6c413a0b54645..eac9a008d730d 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/compare/compare.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/compare/compare.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/compare/lwg2936.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/compare/lwg2936.cc
index 998be2aad6db4..ff383e659c018 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/compare/lwg2936.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/compare/lwg2936.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/compare/path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/compare/path.cc
index 4180f734ffb7a..721efcba5bed0 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/compare/path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/compare/path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/compare/strings.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/compare/strings.cc
index 24e8cffa57654..4878d2e35475a 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/compare/strings.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/compare/strings.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/concat/92853.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/concat/92853.cc
index bb0c50f294abe..777d6c9c3aaf1 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/concat/92853.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/concat/92853.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/concat/94063.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/concat/94063.cc
index b3189aa505e16..594a039c07739 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/concat/94063.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/concat/94063.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target { *-*-*mingw* || *-*-cygwin } } }
 // { dg-require-effective-target c++17 }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/concat/path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/concat/path.cc
index 90bf7bdd4311e..97915528d273b 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/concat/path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/concat/path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/concat/strings.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/concat/strings.cc
index 3d54558fcb4be..99a55162797cc 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/concat/strings.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/concat/strings.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/80762.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/80762.cc
index 950334583f08e..b431413308444 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/80762.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/80762.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/90281.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/90281.cc
index 9dfeb5ac60bb1..5480a986f4fef 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/90281.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/90281.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/90634.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/90634.cc
index ab5f6c1243fd4..23026489bce3d 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/90634.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/90634.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/copy.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/copy.cc
index 8d095ed6d72a4..63f1360b075ad 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/copy.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/copy.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/default.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/default.cc
index 509797097963f..d7a92451000ba 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/default.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/default.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/format.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/format.cc
index 6a295041b61b5..66ed22a6d6e8a 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/format.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/format.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/locale.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/locale.cc
index 9d7913f4a468a..2d4629a7ba83b 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/locale.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/locale.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/range.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/range.cc
index a98597a14322f..c39fbefba7888 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/range.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/range.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/string_view.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/string_view.cc
index 31f61800c7b1a..8d0748404afec 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/string_view.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/string_view.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/extension.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/extension.cc
index 71e53e3ef154e..1652e38790148 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/extension.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/extension.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/filename.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/filename.cc
index 6ed57932cb5fe..02e52a278e29d 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/filename.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/filename.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/parent_path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/parent_path.cc
index b6ca525bc82c3..be54a01fb7a2f 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/parent_path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/parent_path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/relative_path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/relative_path.cc
index b092f326841ce..2028970df5339 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/relative_path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/relative_path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_directory.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_directory.cc
index bb3f267729e0b..d55312e14d819 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_directory.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_directory.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_name.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_name.cc
index 655a7bf898d60..c9082ac8bcae6 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_name.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_name.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_path.cc
index 8de4fb5f9d077..3418f1eb562e0 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/root_path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/stem.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/stem.cc
index 31cfbaf113da3..5e835abbea633 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/stem.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/decompose/stem.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/factory/u8path-char8_t.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/factory/u8path-char8_t.cc
index 4d91ad55e59ff..f52900d7fdaaf 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/factory/u8path-char8_t.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/factory/u8path-char8_t.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -fchar8_t" }
+// { dg-options "-fchar8_t" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/factory/u8path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/factory/u8path.cc
index a0ca9d77dfc7a..b14f874069179 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/factory/u8path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/factory/u8path.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal.cc
index 34f50c20310a9..9a9f54065c330 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal2.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal2.cc
index ad48538425f84..75b5c6ee0bcff 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal2.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/generation/proximate.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/generation/proximate.cc
index 6b463c3886ac8..1fc0d160e107b 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/generation/proximate.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/generation/proximate.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/generation/relative.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/generation/relative.cc
index f56cf6ed4521b..b3d0167c60b9a 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/generation/relative.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/generation/relative.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/generic/94242.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/generic/94242.cc
index 097cce98a7763..f5c530f0db5c6 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/generic/94242.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/generic/94242.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2020-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/generic/generic_string.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/generic/generic_string.cc
index 2d0301b9def4d..85d564e159213 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/generic/generic_string.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/generic/generic_string.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/generic/utf.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/generic/utf.cc
index 57a2150b36a21..3fb7e5b5479fd 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/generic/utf.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/generic/utf.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/generic/wchar_t.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/generic/wchar_t.cc
index 88daab1d36501..0742a608d650e 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/generic/wchar_t.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/generic/wchar_t.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
index e858e3508bda1..8ed4f952695fb 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/io/dr2989.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <iostream>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/itr/components.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/itr/components.cc
index d8cb80471be32..55939007ca24e 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/itr/components.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/itr/components.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/itr/traversal.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/itr/traversal.cc
index 7fc2e06f27143..d326073e48650 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/itr/traversal.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/itr/traversal.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/clear.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/clear.cc
index 73cab39de12da..f7d24e82d83b9 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/clear.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/clear.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/make_preferred.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/make_preferred.cc
index e0cf84f9c99df..8f9e720f302a4 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/make_preferred.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/make_preferred.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/remove_filename.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/remove_filename.cc
index ecf83b48ce362..5e97e7e6101dd 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/remove_filename.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/remove_filename.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/replace_extension.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/replace_extension.cc
index 792a2b09226d8..a390ba733c31e 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/replace_extension.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/replace_extension.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/replace_filename.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/replace_filename.cc
index c77b76740dfdb..7d482bdf15fb5 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/replace_filename.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/replace_filename.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/swap.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/swap.cc
index 08848bb9fd914..847bf5794e473 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/swap.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/modifiers/swap.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/native/alloc.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/native/alloc.cc
index 8bf4db79c7b53..fb0b75d2efc38 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/native/alloc.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/native/alloc.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/native/string-char8_t.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/native/string-char8_t.cc
index 7ea108dab32c4..df0bb5f01567e 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/native/string-char8_t.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/native/string-char8_t.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -fchar8_t" }
+// { dg-options "-fchar8_t" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/native/string.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/native/string.cc
index e26a75c2f9525..b4f802d739f4a 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/native/string.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/native/string.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/append.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/append.cc
index 8634ee81d31a8..b0d01520ff0a8 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/append.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/append.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/cmp.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/cmp.cc
index c3242bfae8096..35337a64c0663 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/cmp.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/cmp.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2020-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/hash_value.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/hash_value.cc
index b0c215dd388da..7b7c912a6dfdd 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/hash_value.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/nonmember/hash_value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/empty.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/empty.cc
index ba74ac5795d39..0374a9ec15f27 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/empty.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/empty.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/empty_neg.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/empty_neg.cc
index 8d1c635121a2a..b86e3351457c3 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/empty_neg.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/empty_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <filesystem>
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_extension.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_extension.cc
index d8e43adb5647c..9d867c3afd6df 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_extension.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_extension.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_filename.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_filename.cc
index ceadb531752e4..fd3431d3fcacc 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_filename.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_filename.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_parent_path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_parent_path.cc
index cef4b57ae363d..bf17ed5b4170d 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_parent_path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_parent_path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_relative_path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_relative_path.cc
index 12b4536469ca0..d4ec956b58b13 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_relative_path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_relative_path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_directory.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_directory.cc
index b61f671df321b..07e36ae442be0 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_directory.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_directory.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_name.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_name.cc
index b32371ac852ca..03b2d856ab46b 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_name.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_name.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_path.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_path.cc
index a421f29d58873..f56277ffa68f4 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_path.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_root_path.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_stem.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_stem.cc
index f4a673eb87e9d..1076e1b5b78d5 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_stem.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/has_stem.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/is_absolute.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/is_absolute.cc
index a118f8e7c1c8b..910bed7733d4f 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/is_absolute.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/is_absolute.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/query/is_relative.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/query/is_relative.cc
index 22efc3c8e4084..d2a5f31e128ac 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/path/query/is_relative.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/query/is_relative.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/experimental/filesystem/path/construct/string_view.cc b/libstdc++-v3/testsuite/experimental/filesystem/path/construct/string_view.cc
index b7bc025e962ad..04bd46e36f847 100644
--- a/libstdc++-v3/testsuite/experimental/filesystem/path/construct/string_view.cc
+++ b/libstdc++-v3/testsuite/experimental/filesystem/path/construct/string_view.cc
@@ -1,4 +1,4 @@
-// { dg-options "-DUSE_FILESYSTEM_TS -lstdc++fs -std=gnu++17" }
+// { dg-options "-DUSE_FILESYSTEM_TS -lstdc++fs" }
 // { dg-do run { target c++17 } }
 // { dg-require-filesystem-ts "" }
 

From a49e815a6283f12dce00418b18b2ecb72a185a91 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 16:22:53 +0100
Subject: [PATCH 094/164] libstdc++: Remove redundant -std=gnu++17 option from
 any/optional/variant tests

GCC defaults to -std=gnu++17 now anyway, and using it explicitly in the
dg-options directive prevents running these tests with different modes
such as -std=c++17 or -std=gnu++20.

libstdc++-v3/ChangeLog:

	* testsuite/20_util/any/assign/1.cc: Remove -std=gnu++17 from
	dg-options directive.
	* testsuite/20_util/any/assign/2.cc: Likewise.
	* testsuite/20_util/any/assign/emplace.cc: Likewise.
	* testsuite/20_util/any/assign/exception.cc: Likewise.
	* testsuite/20_util/any/assign/self.cc: Likewise.
	* testsuite/20_util/any/cons/1.cc: Likewise.
	* testsuite/20_util/any/cons/2.cc: Likewise.
	* testsuite/20_util/any/cons/90415.cc: Likewise.
	* testsuite/20_util/any/cons/92156.cc: Likewise.
	* testsuite/20_util/any/cons/aligned.cc: Likewise.
	* testsuite/20_util/any/cons/explicit.cc: Likewise.
	* testsuite/20_util/any/cons/in_place.cc: Likewise.
	* testsuite/20_util/any/cons/nontrivial.cc: Likewise.
	* testsuite/20_util/any/make_any.cc: Likewise.
	* testsuite/20_util/any/misc/any_cast.cc: Likewise.
	* testsuite/20_util/any/misc/any_cast_neg.cc: Likewise.
	* testsuite/20_util/any/misc/any_cast_no_rtti.cc: Likewise.
	* testsuite/20_util/any/misc/swap.cc: Likewise.
	* testsuite/20_util/any/modifiers/1.cc: Likewise.
	* testsuite/20_util/any/modifiers/83658.cc: Likewise.
	* testsuite/20_util/any/modifiers/92156.cc: Likewise.
	* testsuite/20_util/any/observers/type.cc: Likewise.
	* testsuite/20_util/any/requirements.cc: Likewise.
	* testsuite/20_util/any/typedefs.cc: Likewise.
	* testsuite/20_util/optional/77288.cc: Likewise.
	* testsuite/20_util/optional/84601.cc: Likewise.
	* testsuite/20_util/optional/assignment/1.cc: Likewise.
	* testsuite/20_util/optional/assignment/2.cc: Likewise.
	* testsuite/20_util/optional/assignment/3.cc: Likewise.
	* testsuite/20_util/optional/assignment/4.cc: Likewise.
	* testsuite/20_util/optional/assignment/5.cc: Likewise.
	* testsuite/20_util/optional/assignment/6.cc: Likewise.
	* testsuite/20_util/optional/assignment/7.cc: Likewise.
	* testsuite/20_util/optional/assignment/8.cc: Likewise.
	* testsuite/20_util/optional/assignment/9.cc: Likewise.
	* testsuite/20_util/optional/bad_access.cc: Likewise.
	* testsuite/20_util/optional/cons/77727.cc: Likewise.
	* testsuite/20_util/optional/cons/85642.cc: Likewise.
	* testsuite/20_util/optional/cons/copy.cc: Likewise.
	* testsuite/20_util/optional/cons/deduction.cc: Likewise.
	* testsuite/20_util/optional/cons/default.cc: Likewise.
	* testsuite/20_util/optional/cons/move.cc: Likewise.
	* testsuite/20_util/optional/cons/trivial.cc: Likewise.
	* testsuite/20_util/optional/cons/value.cc: Likewise.
	* testsuite/20_util/optional/cons/value_neg.cc: Likewise.
	* testsuite/20_util/optional/constexpr/cons/default.cc:
	Likewise.
	* testsuite/20_util/optional/constexpr/cons/value.cc: Likewise.
	* testsuite/20_util/optional/constexpr/in_place.cc: Likewise.
	* testsuite/20_util/optional/constexpr/make_optional.cc:
	Likewise.
	* testsuite/20_util/optional/constexpr/nullopt.cc: Likewise.
	* testsuite/20_util/optional/constexpr/observers/1.cc: Likewise.
	* testsuite/20_util/optional/constexpr/observers/2.cc: Likewise.
	* testsuite/20_util/optional/constexpr/observers/3.cc: Likewise.
	* testsuite/20_util/optional/constexpr/observers/4.cc: Likewise.
	* testsuite/20_util/optional/constexpr/observers/5.cc: Likewise.
	* testsuite/20_util/optional/constexpr/relops/1.cc: Likewise.
	* testsuite/20_util/optional/constexpr/relops/2.cc: Likewise.
	* testsuite/20_util/optional/constexpr/relops/3.cc: Likewise.
	* testsuite/20_util/optional/constexpr/relops/4.cc: Likewise.
	* testsuite/20_util/optional/constexpr/relops/5.cc: Likewise.
	* testsuite/20_util/optional/constexpr/relops/6.cc: Likewise.
	* testsuite/20_util/optional/hash.cc: Likewise.
	* testsuite/20_util/optional/in_place.cc: Likewise.
	* testsuite/20_util/optional/make_optional.cc: Likewise.
	* testsuite/20_util/optional/nullopt.cc: Likewise.
	* testsuite/20_util/optional/observers/1.cc: Likewise.
	* testsuite/20_util/optional/observers/2.cc: Likewise.
	* testsuite/20_util/optional/observers/3.cc: Likewise.
	* testsuite/20_util/optional/observers/4.cc: Likewise.
	* testsuite/20_util/optional/observers/5.cc: Likewise.
	* testsuite/20_util/optional/observers/6.cc: Likewise.
	* testsuite/20_util/optional/relops/1.cc: Likewise.
	* testsuite/20_util/optional/relops/2.cc: Likewise.
	* testsuite/20_util/optional/relops/3.cc: Likewise.
	* testsuite/20_util/optional/relops/4.cc: Likewise.
	* testsuite/20_util/optional/relops/5.cc: Likewise.
	* testsuite/20_util/optional/relops/6.cc: Likewise.
	* testsuite/20_util/optional/relops/7.cc: Likewise.
	* testsuite/20_util/optional/requirements.cc: Likewise.
	* testsuite/20_util/optional/swap/1.cc: Likewise.
	* testsuite/20_util/optional/swap/2.cc: Likewise.
	* testsuite/20_util/optional/typedefs.cc: Likewise.
	* testsuite/20_util/variant/80165.cc: Likewise.
	* testsuite/20_util/variant/85183.cc: Likewise.
	* testsuite/20_util/variant/86874.cc: Likewise.
	* testsuite/20_util/variant/87431.cc: Likewise.
	* testsuite/20_util/variant/87619.cc: Likewise.
	* testsuite/20_util/variant/91807.cc: Likewise.
	* testsuite/20_util/variant/any.cc: Likewise.
	* testsuite/20_util/variant/compile.cc: Likewise.
	* testsuite/20_util/variant/deduction.cc: Likewise.
	* testsuite/20_util/variant/exception_safety.cc: Likewise.
	* testsuite/20_util/variant/hash.cc: Likewise.
	* testsuite/20_util/variant/index_type.cc: Likewise.
	* testsuite/20_util/variant/relops/89851.cc: Likewise.
	* testsuite/20_util/variant/relops/90008.cc: Likewise.
	* testsuite/20_util/variant/run.cc: Likewise.
	* testsuite/20_util/variant/visit.cc: Likewise.

(cherry picked from commit 8240175b87e331c87993876e782971eda46f9a6e)
---
 libstdc++-v3/testsuite/20_util/any/assign/1.cc               | 1 -
 libstdc++-v3/testsuite/20_util/any/assign/2.cc               | 1 -
 libstdc++-v3/testsuite/20_util/any/assign/emplace.cc         | 1 -
 libstdc++-v3/testsuite/20_util/any/assign/exception.cc       | 3 +--
 libstdc++-v3/testsuite/20_util/any/assign/self.cc            | 1 -
 libstdc++-v3/testsuite/20_util/any/cons/1.cc                 | 1 -
 libstdc++-v3/testsuite/20_util/any/cons/2.cc                 | 1 -
 libstdc++-v3/testsuite/20_util/any/cons/90415.cc             | 1 -
 libstdc++-v3/testsuite/20_util/any/cons/92156.cc             | 1 -
 libstdc++-v3/testsuite/20_util/any/cons/aligned.cc           | 1 -
 libstdc++-v3/testsuite/20_util/any/cons/explicit.cc          | 1 -
 libstdc++-v3/testsuite/20_util/any/cons/in_place.cc          | 1 -
 libstdc++-v3/testsuite/20_util/any/cons/nontrivial.cc        | 1 -
 libstdc++-v3/testsuite/20_util/any/make_any.cc               | 1 -
 libstdc++-v3/testsuite/20_util/any/misc/any_cast.cc          | 5 ++---
 libstdc++-v3/testsuite/20_util/any/misc/any_cast_neg.cc      | 1 -
 libstdc++-v3/testsuite/20_util/any/misc/any_cast_no_rtti.cc  | 2 +-
 libstdc++-v3/testsuite/20_util/any/misc/swap.cc              | 1 -
 libstdc++-v3/testsuite/20_util/any/modifiers/1.cc            | 1 -
 libstdc++-v3/testsuite/20_util/any/modifiers/83658.cc        | 1 -
 libstdc++-v3/testsuite/20_util/any/modifiers/92156.cc        | 1 -
 libstdc++-v3/testsuite/20_util/any/observers/type.cc         | 1 -
 libstdc++-v3/testsuite/20_util/any/requirements.cc           | 1 -
 libstdc++-v3/testsuite/20_util/any/typedefs.cc               | 1 -
 libstdc++-v3/testsuite/20_util/optional/77288.cc             | 1 -
 libstdc++-v3/testsuite/20_util/optional/84601.cc             | 1 -
 libstdc++-v3/testsuite/20_util/optional/assignment/1.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/assignment/2.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/assignment/3.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/assignment/4.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/assignment/5.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/assignment/6.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/assignment/7.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/assignment/8.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/assignment/9.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/bad_access.cc        | 1 -
 libstdc++-v3/testsuite/20_util/optional/cons/77727.cc        | 1 -
 libstdc++-v3/testsuite/20_util/optional/cons/85642.cc        | 1 -
 libstdc++-v3/testsuite/20_util/optional/cons/copy.cc         | 1 -
 libstdc++-v3/testsuite/20_util/optional/cons/deduction.cc    | 1 -
 libstdc++-v3/testsuite/20_util/optional/cons/default.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/cons/move.cc         | 1 -
 libstdc++-v3/testsuite/20_util/optional/cons/trivial.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/cons/value.cc        | 1 -
 libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc    | 1 -
 .../testsuite/20_util/optional/constexpr/cons/default.cc     | 1 -
 .../testsuite/20_util/optional/constexpr/cons/value.cc       | 1 -
 .../testsuite/20_util/optional/constexpr/in_place.cc         | 1 -
 .../testsuite/20_util/optional/constexpr/make_optional.cc    | 1 -
 libstdc++-v3/testsuite/20_util/optional/constexpr/nullopt.cc | 1 -
 .../testsuite/20_util/optional/constexpr/observers/1.cc      | 1 -
 .../testsuite/20_util/optional/constexpr/observers/2.cc      | 1 -
 .../testsuite/20_util/optional/constexpr/observers/3.cc      | 1 -
 .../testsuite/20_util/optional/constexpr/observers/4.cc      | 1 -
 .../testsuite/20_util/optional/constexpr/observers/5.cc      | 1 -
 .../testsuite/20_util/optional/constexpr/relops/1.cc         | 1 -
 .../testsuite/20_util/optional/constexpr/relops/2.cc         | 1 -
 .../testsuite/20_util/optional/constexpr/relops/3.cc         | 1 -
 .../testsuite/20_util/optional/constexpr/relops/4.cc         | 1 -
 .../testsuite/20_util/optional/constexpr/relops/5.cc         | 1 -
 .../testsuite/20_util/optional/constexpr/relops/6.cc         | 1 -
 libstdc++-v3/testsuite/20_util/optional/hash.cc              | 1 -
 libstdc++-v3/testsuite/20_util/optional/in_place.cc          | 1 -
 libstdc++-v3/testsuite/20_util/optional/make_optional.cc     | 1 -
 libstdc++-v3/testsuite/20_util/optional/nullopt.cc           | 1 -
 libstdc++-v3/testsuite/20_util/optional/observers/1.cc       | 1 -
 libstdc++-v3/testsuite/20_util/optional/observers/2.cc       | 1 -
 libstdc++-v3/testsuite/20_util/optional/observers/3.cc       | 1 -
 libstdc++-v3/testsuite/20_util/optional/observers/4.cc       | 1 -
 libstdc++-v3/testsuite/20_util/optional/observers/5.cc       | 1 -
 libstdc++-v3/testsuite/20_util/optional/observers/6.cc       | 1 -
 libstdc++-v3/testsuite/20_util/optional/relops/1.cc          | 1 -
 libstdc++-v3/testsuite/20_util/optional/relops/2.cc          | 1 -
 libstdc++-v3/testsuite/20_util/optional/relops/3.cc          | 1 -
 libstdc++-v3/testsuite/20_util/optional/relops/4.cc          | 1 -
 libstdc++-v3/testsuite/20_util/optional/relops/5.cc          | 1 -
 libstdc++-v3/testsuite/20_util/optional/relops/6.cc          | 1 -
 libstdc++-v3/testsuite/20_util/optional/relops/7.cc          | 1 -
 libstdc++-v3/testsuite/20_util/optional/requirements.cc      | 1 -
 libstdc++-v3/testsuite/20_util/optional/swap/1.cc            | 1 -
 libstdc++-v3/testsuite/20_util/optional/swap/2.cc            | 1 -
 libstdc++-v3/testsuite/20_util/optional/typedefs.cc          | 1 -
 libstdc++-v3/testsuite/20_util/variant/80165.cc              | 1 -
 libstdc++-v3/testsuite/20_util/variant/85183.cc              | 1 -
 libstdc++-v3/testsuite/20_util/variant/86874.cc              | 1 -
 libstdc++-v3/testsuite/20_util/variant/87431.cc              | 1 -
 libstdc++-v3/testsuite/20_util/variant/87619.cc              | 1 -
 libstdc++-v3/testsuite/20_util/variant/91807.cc              | 1 -
 libstdc++-v3/testsuite/20_util/variant/any.cc                | 1 -
 libstdc++-v3/testsuite/20_util/variant/compile.cc            | 1 -
 libstdc++-v3/testsuite/20_util/variant/deduction.cc          | 1 -
 libstdc++-v3/testsuite/20_util/variant/exception_safety.cc   | 1 -
 libstdc++-v3/testsuite/20_util/variant/hash.cc               | 1 -
 libstdc++-v3/testsuite/20_util/variant/index_type.cc         | 1 -
 libstdc++-v3/testsuite/20_util/variant/relops/89851.cc       | 1 -
 libstdc++-v3/testsuite/20_util/variant/relops/90008.cc       | 1 -
 libstdc++-v3/testsuite/20_util/variant/run.cc                | 1 -
 libstdc++-v3/testsuite/20_util/variant/visit.cc              | 1 -
 98 files changed, 4 insertions(+), 101 deletions(-)

diff --git a/libstdc++-v3/testsuite/20_util/any/assign/1.cc b/libstdc++-v3/testsuite/20_util/any/assign/1.cc
index 2e3a487b3aadb..f417f9b286f01 100644
--- a/libstdc++-v3/testsuite/20_util/any/assign/1.cc
+++ b/libstdc++-v3/testsuite/20_util/any/assign/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/assign/2.cc b/libstdc++-v3/testsuite/20_util/any/assign/2.cc
index ae703a781c206..a80e9638477c2 100644
--- a/libstdc++-v3/testsuite/20_util/any/assign/2.cc
+++ b/libstdc++-v3/testsuite/20_util/any/assign/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/assign/emplace.cc b/libstdc++-v3/testsuite/20_util/any/assign/emplace.cc
index 77d524d5c5d3e..9e699e22eb9ca 100644
--- a/libstdc++-v3/testsuite/20_util/any/assign/emplace.cc
+++ b/libstdc++-v3/testsuite/20_util/any/assign/emplace.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/assign/exception.cc b/libstdc++-v3/testsuite/20_util/any/assign/exception.cc
index edc7c0083d231..5e984c087104e 100644
--- a/libstdc++-v3/testsuite/20_util/any/assign/exception.cc
+++ b/libstdc++-v3/testsuite/20_util/any/assign/exception.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
@@ -38,7 +37,7 @@ struct Bad2
 };
 
 int del_count = 0;
-struct Good 
+struct Good
 {
   Good() = default;
   Good(const Good&) = default;
diff --git a/libstdc++-v3/testsuite/20_util/any/assign/self.cc b/libstdc++-v3/testsuite/20_util/any/assign/self.cc
index 1303ae2662716..fe2e588a2b800 100644
--- a/libstdc++-v3/testsuite/20_util/any/assign/self.cc
+++ b/libstdc++-v3/testsuite/20_util/any/assign/self.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <any>
diff --git a/libstdc++-v3/testsuite/20_util/any/cons/1.cc b/libstdc++-v3/testsuite/20_util/any/cons/1.cc
index 132c6dba801c7..97819fa81441c 100644
--- a/libstdc++-v3/testsuite/20_util/any/cons/1.cc
+++ b/libstdc++-v3/testsuite/20_util/any/cons/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/cons/2.cc b/libstdc++-v3/testsuite/20_util/any/cons/2.cc
index a696683f5be05..ea8dd898c5331 100644
--- a/libstdc++-v3/testsuite/20_util/any/cons/2.cc
+++ b/libstdc++-v3/testsuite/20_util/any/cons/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/cons/90415.cc b/libstdc++-v3/testsuite/20_util/any/cons/90415.cc
index e2b42ed8e0d57..ea0a14ad798a3 100644
--- a/libstdc++-v3/testsuite/20_util/any/cons/90415.cc
+++ b/libstdc++-v3/testsuite/20_util/any/cons/90415.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2020-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/cons/92156.cc b/libstdc++-v3/testsuite/20_util/any/cons/92156.cc
index 83fa4f7a04463..00a4449fc7ac7 100644
--- a/libstdc++-v3/testsuite/20_util/any/cons/92156.cc
+++ b/libstdc++-v3/testsuite/20_util/any/cons/92156.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2020-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/cons/aligned.cc b/libstdc++-v3/testsuite/20_util/any/cons/aligned.cc
index 7662e9e7b81a6..888898d05ab18 100644
--- a/libstdc++-v3/testsuite/20_util/any/cons/aligned.cc
+++ b/libstdc++-v3/testsuite/20_util/any/cons/aligned.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-cstdint "" }
 
diff --git a/libstdc++-v3/testsuite/20_util/any/cons/explicit.cc b/libstdc++-v3/testsuite/20_util/any/cons/explicit.cc
index eb5f2d86cf890..fc991d3e34e23 100644
--- a/libstdc++-v3/testsuite/20_util/any/cons/explicit.cc
+++ b/libstdc++-v3/testsuite/20_util/any/cons/explicit.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/cons/in_place.cc b/libstdc++-v3/testsuite/20_util/any/cons/in_place.cc
index 3b767d0dc3820..1d35e7a57708e 100644
--- a/libstdc++-v3/testsuite/20_util/any/cons/in_place.cc
+++ b/libstdc++-v3/testsuite/20_util/any/cons/in_place.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/cons/nontrivial.cc b/libstdc++-v3/testsuite/20_util/any/cons/nontrivial.cc
index 29a809f5a89ab..d783508803a17 100644
--- a/libstdc++-v3/testsuite/20_util/any/cons/nontrivial.cc
+++ b/libstdc++-v3/testsuite/20_util/any/cons/nontrivial.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <any>
diff --git a/libstdc++-v3/testsuite/20_util/any/make_any.cc b/libstdc++-v3/testsuite/20_util/any/make_any.cc
index ec122874920be..51689afbd06ff 100644
--- a/libstdc++-v3/testsuite/20_util/any/make_any.cc
+++ b/libstdc++-v3/testsuite/20_util/any/make_any.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/misc/any_cast.cc b/libstdc++-v3/testsuite/20_util/any/misc/any_cast.cc
index 52593dd7595e0..ea257660e8912 100644
--- a/libstdc++-v3/testsuite/20_util/any/misc/any_cast.cc
+++ b/libstdc++-v3/testsuite/20_util/any/misc/any_cast.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
@@ -37,7 +36,7 @@ void test01()
   any x(5);                                   // x holds int
   VERIFY(any_cast<int>(x) == 5);              // cast to value
   any_cast<int&>(x) = 10;                     // cast to reference
-  VERIFY(any_cast<int>(x) == 10); 
+  VERIFY(any_cast<int>(x) == 10);
 
   x = "Meow";                                 // x holds const char*
   VERIFY(strcmp(any_cast<const char*>(x), "Meow") == 0);
@@ -46,7 +45,7 @@ void test01()
 
   x = string("Meow");                         // x holds string
   string s, s2("Jane");
-  s = move(any_cast<string&>(x));             // move from any 
+  s = move(any_cast<string&>(x));             // move from any
   VERIFY(s == "Meow");
   any_cast<string&>(x) = move(s2);            // move to any
   VERIFY(any_cast<const string&>(x) == "Jane");
diff --git a/libstdc++-v3/testsuite/20_util/any/misc/any_cast_neg.cc b/libstdc++-v3/testsuite/20_util/any/misc/any_cast_neg.cc
index 2ff55585038d9..799304b1e1f03 100644
--- a/libstdc++-v3/testsuite/20_util/any/misc/any_cast_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/any/misc/any_cast_neg.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/misc/any_cast_no_rtti.cc b/libstdc++-v3/testsuite/20_util/any/misc/any_cast_no_rtti.cc
index 3bda2d6d7119c..201d7eea27251 100644
--- a/libstdc++-v3/testsuite/20_util/any/misc/any_cast_no_rtti.cc
+++ b/libstdc++-v3/testsuite/20_util/any/misc/any_cast_no_rtti.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -fno-rtti" }
+// { dg-options "-fno-rtti" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/misc/swap.cc b/libstdc++-v3/testsuite/20_util/any/misc/swap.cc
index 4b2ff76651b3e..2610f0fc3d8a9 100644
--- a/libstdc++-v3/testsuite/20_util/any/misc/swap.cc
+++ b/libstdc++-v3/testsuite/20_util/any/misc/swap.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/modifiers/1.cc b/libstdc++-v3/testsuite/20_util/any/modifiers/1.cc
index 1e8af5f94ca4e..f5bb4aabbcfbc 100644
--- a/libstdc++-v3/testsuite/20_util/any/modifiers/1.cc
+++ b/libstdc++-v3/testsuite/20_util/any/modifiers/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/modifiers/83658.cc b/libstdc++-v3/testsuite/20_util/any/modifiers/83658.cc
index 47d762ac01306..f4a72ed04128e 100644
--- a/libstdc++-v3/testsuite/20_util/any/modifiers/83658.cc
+++ b/libstdc++-v3/testsuite/20_util/any/modifiers/83658.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <any>
diff --git a/libstdc++-v3/testsuite/20_util/any/modifiers/92156.cc b/libstdc++-v3/testsuite/20_util/any/modifiers/92156.cc
index 7127f3e61f0ba..6b04db2f10ec3 100644
--- a/libstdc++-v3/testsuite/20_util/any/modifiers/92156.cc
+++ b/libstdc++-v3/testsuite/20_util/any/modifiers/92156.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2020-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/observers/type.cc b/libstdc++-v3/testsuite/20_util/any/observers/type.cc
index 613966142b035..f9b3668a090c5 100644
--- a/libstdc++-v3/testsuite/20_util/any/observers/type.cc
+++ b/libstdc++-v3/testsuite/20_util/any/observers/type.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/requirements.cc b/libstdc++-v3/testsuite/20_util/any/requirements.cc
index 9609277d3d773..0affcc8d82da0 100644
--- a/libstdc++-v3/testsuite/20_util/any/requirements.cc
+++ b/libstdc++-v3/testsuite/20_util/any/requirements.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/any/typedefs.cc b/libstdc++-v3/testsuite/20_util/any/typedefs.cc
index 47acd63bd7fa6..a13cdf24abd1b 100644
--- a/libstdc++-v3/testsuite/20_util/any/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/any/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/77288.cc b/libstdc++-v3/testsuite/20_util/optional/77288.cc
index 551fef174dc0c..f61b73a1fe5d9 100644
--- a/libstdc++-v3/testsuite/20_util/optional/77288.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/77288.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/84601.cc b/libstdc++-v3/testsuite/20_util/optional/84601.cc
index b8a1706d271c7..ddac999d49eea 100644
--- a/libstdc++-v3/testsuite/20_util/optional/84601.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/84601.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 #include <optional>
diff --git a/libstdc++-v3/testsuite/20_util/optional/assignment/1.cc b/libstdc++-v3/testsuite/20_util/optional/assignment/1.cc
index fabd9e2e0cbf2..05c348556d6e8 100644
--- a/libstdc++-v3/testsuite/20_util/optional/assignment/1.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/assignment/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/assignment/2.cc b/libstdc++-v3/testsuite/20_util/optional/assignment/2.cc
index 7ef1e0ba88df9..fce659a414c2e 100644
--- a/libstdc++-v3/testsuite/20_util/optional/assignment/2.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/assignment/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/assignment/3.cc b/libstdc++-v3/testsuite/20_util/optional/assignment/3.cc
index 69124834ce653..0a57f132b2820 100644
--- a/libstdc++-v3/testsuite/20_util/optional/assignment/3.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/assignment/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/assignment/4.cc b/libstdc++-v3/testsuite/20_util/optional/assignment/4.cc
index 1889c9362131d..303df38e96c41 100644
--- a/libstdc++-v3/testsuite/20_util/optional/assignment/4.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/assignment/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/assignment/5.cc b/libstdc++-v3/testsuite/20_util/optional/assignment/5.cc
index ae2f35cceb3dc..cd6056d446694 100644
--- a/libstdc++-v3/testsuite/20_util/optional/assignment/5.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/assignment/5.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/assignment/6.cc b/libstdc++-v3/testsuite/20_util/optional/assignment/6.cc
index 5dd1bb4d29578..75cee462ade55 100644
--- a/libstdc++-v3/testsuite/20_util/optional/assignment/6.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/assignment/6.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/assignment/7.cc b/libstdc++-v3/testsuite/20_util/optional/assignment/7.cc
index 1bda92b6bf9a8..12fda375c5ce7 100644
--- a/libstdc++-v3/testsuite/20_util/optional/assignment/7.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/assignment/7.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/assignment/8.cc b/libstdc++-v3/testsuite/20_util/optional/assignment/8.cc
index c3b96984ed1cc..b2bafce334f6c 100644
--- a/libstdc++-v3/testsuite/20_util/optional/assignment/8.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/assignment/8.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/assignment/9.cc b/libstdc++-v3/testsuite/20_util/optional/assignment/9.cc
index 68abfb0e1e691..49643f88cdbcc 100644
--- a/libstdc++-v3/testsuite/20_util/optional/assignment/9.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/assignment/9.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/bad_access.cc b/libstdc++-v3/testsuite/20_util/optional/bad_access.cc
index 01ec6f113871c..ce5f3e00ca83b 100644
--- a/libstdc++-v3/testsuite/20_util/optional/bad_access.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/bad_access.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <optional>
diff --git a/libstdc++-v3/testsuite/20_util/optional/cons/77727.cc b/libstdc++-v3/testsuite/20_util/optional/cons/77727.cc
index 4159f12aa496b..bd853529ab141 100644
--- a/libstdc++-v3/testsuite/20_util/optional/cons/77727.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/cons/77727.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/cons/85642.cc b/libstdc++-v3/testsuite/20_util/optional/cons/85642.cc
index 3cf35caadd993..39e4853db36e5 100644
--- a/libstdc++-v3/testsuite/20_util/optional/cons/85642.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/cons/85642.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <optional>
diff --git a/libstdc++-v3/testsuite/20_util/optional/cons/copy.cc b/libstdc++-v3/testsuite/20_util/optional/cons/copy.cc
index 0051cae03f1cf..88511068da2cc 100644
--- a/libstdc++-v3/testsuite/20_util/optional/cons/copy.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/cons/copy.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/cons/deduction.cc b/libstdc++-v3/testsuite/20_util/optional/cons/deduction.cc
index 6ff8bec7f6241..4d57571a094c1 100644
--- a/libstdc++-v3/testsuite/20_util/optional/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 #include <optional>
diff --git a/libstdc++-v3/testsuite/20_util/optional/cons/default.cc b/libstdc++-v3/testsuite/20_util/optional/cons/default.cc
index 01d0914a3aac0..790cbed308562 100644
--- a/libstdc++-v3/testsuite/20_util/optional/cons/default.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/cons/default.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/cons/move.cc b/libstdc++-v3/testsuite/20_util/optional/cons/move.cc
index 9b481796b9ba8..481ef4a52880f 100644
--- a/libstdc++-v3/testsuite/20_util/optional/cons/move.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/cons/move.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/cons/trivial.cc b/libstdc++-v3/testsuite/20_util/optional/cons/trivial.cc
index 908edeed6c0f6..575272e036432 100644
--- a/libstdc++-v3/testsuite/20_util/optional/cons/trivial.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/cons/trivial.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/cons/value.cc b/libstdc++-v3/testsuite/20_util/optional/cons/value.cc
index a942e8f89f9d7..0621c6606797a 100644
--- a/libstdc++-v3/testsuite/20_util/optional/cons/value.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/cons/value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc b/libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc
index c9bb137a2e256..3d17a1a175cf5 100644
--- a/libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/cons/default.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/cons/default.cc
index 48a58ac128c76..fca3759cc899a 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/cons/default.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/cons/default.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/cons/value.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/cons/value.cc
index ff20fb0ae4eff..12990243bec5b 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/cons/value.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/cons/value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/in_place.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/in_place.cc
index d90e28aaf181f..70925c3c5a2c2 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/in_place.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/in_place.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/make_optional.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/make_optional.cc
index 9feb6e35834b6..058bcb62a0ba7 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/make_optional.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/make_optional.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/nullopt.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/nullopt.cc
index 617e4601ecc79..33b8b13fbf234 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/nullopt.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/nullopt.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/1.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/1.cc
index 76f7536f40fd3..6127f115d36bf 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/1.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/2.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/2.cc
index e9ff4deccdf91..5d62b86589a1f 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/2.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/3.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/3.cc
index 3a8b22456969b..837dae8715d64 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/3.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/4.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/4.cc
index 7a9ee82a8fa2b..ebaa7a8fc6ebc 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/4.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/5.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/5.cc
index 66224ce23cc2f..c1e6b5e42de2e 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/5.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/observers/5.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/1.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/1.cc
index 74b4e2102ef3e..99a7dd6009eff 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/1.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/2.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/2.cc
index dd1b62d622998..caecac30c44c7 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/2.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/3.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/3.cc
index e334c1fb5329a..df23c7a48be39 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/3.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/4.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/4.cc
index bc652c3dd4fb2..3b8edeee8cf75 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/4.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/5.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/5.cc
index 535d70201b635..67fc9816f6acd 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/5.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/5.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/6.cc b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/6.cc
index fc8da93364f6f..a50ff9189d51d 100644
--- a/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/6.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/constexpr/relops/6.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/hash.cc b/libstdc++-v3/testsuite/20_util/optional/hash.cc
index 138f2bbc0959d..4e05781b9c950 100644
--- a/libstdc++-v3/testsuite/20_util/optional/hash.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/hash.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/in_place.cc b/libstdc++-v3/testsuite/20_util/optional/in_place.cc
index 9c0f7fd1fe82c..2c0715b1620a1 100644
--- a/libstdc++-v3/testsuite/20_util/optional/in_place.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/in_place.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/make_optional.cc b/libstdc++-v3/testsuite/20_util/optional/make_optional.cc
index 1acf153a2b466..f012eea0ba1d0 100644
--- a/libstdc++-v3/testsuite/20_util/optional/make_optional.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/make_optional.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/nullopt.cc b/libstdc++-v3/testsuite/20_util/optional/nullopt.cc
index 863c1fc027564..b513f0636b89d 100644
--- a/libstdc++-v3/testsuite/20_util/optional/nullopt.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/nullopt.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/observers/1.cc b/libstdc++-v3/testsuite/20_util/optional/observers/1.cc
index 599e61e10eac8..315874a64edca 100644
--- a/libstdc++-v3/testsuite/20_util/optional/observers/1.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/observers/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/observers/2.cc b/libstdc++-v3/testsuite/20_util/optional/observers/2.cc
index 21ffa1b76d8e9..2438929c17d67 100644
--- a/libstdc++-v3/testsuite/20_util/optional/observers/2.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/observers/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/observers/3.cc b/libstdc++-v3/testsuite/20_util/optional/observers/3.cc
index be8e23c836b6f..7da1650b72b4e 100644
--- a/libstdc++-v3/testsuite/20_util/optional/observers/3.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/observers/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/observers/4.cc b/libstdc++-v3/testsuite/20_util/optional/observers/4.cc
index 70ed935598dca..61d0a78cdeea4 100644
--- a/libstdc++-v3/testsuite/20_util/optional/observers/4.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/observers/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/observers/5.cc b/libstdc++-v3/testsuite/20_util/optional/observers/5.cc
index fbb386ce07315..7869f568cbb9d 100644
--- a/libstdc++-v3/testsuite/20_util/optional/observers/5.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/observers/5.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/observers/6.cc b/libstdc++-v3/testsuite/20_util/optional/observers/6.cc
index f9db361d76437..2e7669f94d393 100644
--- a/libstdc++-v3/testsuite/20_util/optional/observers/6.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/observers/6.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/relops/1.cc b/libstdc++-v3/testsuite/20_util/optional/relops/1.cc
index 88b5b40fa09c5..c6ccb70bf1b0b 100644
--- a/libstdc++-v3/testsuite/20_util/optional/relops/1.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/relops/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/relops/2.cc b/libstdc++-v3/testsuite/20_util/optional/relops/2.cc
index c540232e88d20..dd8ce55998b93 100644
--- a/libstdc++-v3/testsuite/20_util/optional/relops/2.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/relops/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/relops/3.cc b/libstdc++-v3/testsuite/20_util/optional/relops/3.cc
index 488e3a39d56ba..e385a441193ba 100644
--- a/libstdc++-v3/testsuite/20_util/optional/relops/3.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/relops/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/relops/4.cc b/libstdc++-v3/testsuite/20_util/optional/relops/4.cc
index f16fe0d33e255..71697bdeb608a 100644
--- a/libstdc++-v3/testsuite/20_util/optional/relops/4.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/relops/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/relops/5.cc b/libstdc++-v3/testsuite/20_util/optional/relops/5.cc
index 2cbf1b825d8ca..575023ec2be21 100644
--- a/libstdc++-v3/testsuite/20_util/optional/relops/5.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/relops/5.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/relops/6.cc b/libstdc++-v3/testsuite/20_util/optional/relops/6.cc
index 6b6535db1c2d7..b313fc9e545a5 100644
--- a/libstdc++-v3/testsuite/20_util/optional/relops/6.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/relops/6.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/relops/7.cc b/libstdc++-v3/testsuite/20_util/optional/relops/7.cc
index 8f307c6d28154..20bc84a619b0d 100644
--- a/libstdc++-v3/testsuite/20_util/optional/relops/7.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/relops/7.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/requirements.cc b/libstdc++-v3/testsuite/20_util/optional/requirements.cc
index a3753ecc2d9fa..550c0c4eac0bd 100644
--- a/libstdc++-v3/testsuite/20_util/optional/requirements.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/requirements.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/swap/1.cc b/libstdc++-v3/testsuite/20_util/optional/swap/1.cc
index b8f7017bc0f4c..b3814f3e8a4ea 100644
--- a/libstdc++-v3/testsuite/20_util/optional/swap/1.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/swap/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 }  }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/swap/2.cc b/libstdc++-v3/testsuite/20_util/optional/swap/2.cc
index a1c0a2920bd4a..b21475d28d05a 100644
--- a/libstdc++-v3/testsuite/20_util/optional/swap/2.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/swap/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/optional/typedefs.cc b/libstdc++-v3/testsuite/20_util/optional/typedefs.cc
index f8735855af0bf..1b49ce19e901b 100644
--- a/libstdc++-v3/testsuite/20_util/optional/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/optional/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 }  }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/variant/80165.cc b/libstdc++-v3/testsuite/20_util/variant/80165.cc
index add976c72569d..621585b47dcad 100644
--- a/libstdc++-v3/testsuite/20_util/variant/80165.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/80165.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <tuple>
diff --git a/libstdc++-v3/testsuite/20_util/variant/85183.cc b/libstdc++-v3/testsuite/20_util/variant/85183.cc
index 5f4342b28bb84..f3a6bcdde6d45 100644
--- a/libstdc++-v3/testsuite/20_util/variant/85183.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/85183.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <variant>
diff --git a/libstdc++-v3/testsuite/20_util/variant/86874.cc b/libstdc++-v3/testsuite/20_util/variant/86874.cc
index 6a9844e4f16df..3f104d424993e 100644
--- a/libstdc++-v3/testsuite/20_util/variant/86874.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/86874.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <variant>
diff --git a/libstdc++-v3/testsuite/20_util/variant/87431.cc b/libstdc++-v3/testsuite/20_util/variant/87431.cc
index b829d61e116e6..9ee554b40fcda 100644
--- a/libstdc++-v3/testsuite/20_util/variant/87431.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/87431.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <variant>
diff --git a/libstdc++-v3/testsuite/20_util/variant/87619.cc b/libstdc++-v3/testsuite/20_util/variant/87619.cc
index fdb7e54133ead..e83fa0306b611 100644
--- a/libstdc++-v3/testsuite/20_util/variant/87619.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/87619.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <variant>
diff --git a/libstdc++-v3/testsuite/20_util/variant/91807.cc b/libstdc++-v3/testsuite/20_util/variant/91807.cc
index fc60bc4da704b..19be5953fe484 100644
--- a/libstdc++-v3/testsuite/20_util/variant/91807.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/91807.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2020-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/variant/any.cc b/libstdc++-v3/testsuite/20_util/variant/any.cc
index e865f9cdecfea..b3febf8aed78e 100644
--- a/libstdc++-v3/testsuite/20_util/variant/any.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/any.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/variant/compile.cc b/libstdc++-v3/testsuite/20_util/variant/compile.cc
index e5042751e66e9..3a2e972475743 100644
--- a/libstdc++-v3/testsuite/20_util/variant/compile.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/compile.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/variant/deduction.cc b/libstdc++-v3/testsuite/20_util/variant/deduction.cc
index 869eeb76a7204..8aa7a7044bd8e 100644
--- a/libstdc++-v3/testsuite/20_util/variant/deduction.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/variant/exception_safety.cc b/libstdc++-v3/testsuite/20_util/variant/exception_safety.cc
index 7a3401980ffaa..b386c9e36f41f 100644
--- a/libstdc++-v3/testsuite/20_util/variant/exception_safety.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/exception_safety.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <variant>
diff --git a/libstdc++-v3/testsuite/20_util/variant/hash.cc b/libstdc++-v3/testsuite/20_util/variant/hash.cc
index ee36c72384e55..4d47593c2d6d6 100644
--- a/libstdc++-v3/testsuite/20_util/variant/hash.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/hash.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/variant/index_type.cc b/libstdc++-v3/testsuite/20_util/variant/index_type.cc
index 97acf785c2105..c24e6842367f9 100644
--- a/libstdc++-v3/testsuite/20_util/variant/index_type.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/index_type.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target { ilp32 || lp64 } } }
 // { dg-require-effective-target c++17 }
 
diff --git a/libstdc++-v3/testsuite/20_util/variant/relops/89851.cc b/libstdc++-v3/testsuite/20_util/variant/relops/89851.cc
index 32a3c774a017b..fcf851a5f33a6 100644
--- a/libstdc++-v3/testsuite/20_util/variant/relops/89851.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/relops/89851.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <variant>
diff --git a/libstdc++-v3/testsuite/20_util/variant/relops/90008.cc b/libstdc++-v3/testsuite/20_util/variant/relops/90008.cc
index 2c16c848623ac..1309d54bf24d5 100644
--- a/libstdc++-v3/testsuite/20_util/variant/relops/90008.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/relops/90008.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <variant>
diff --git a/libstdc++-v3/testsuite/20_util/variant/run.cc b/libstdc++-v3/testsuite/20_util/variant/run.cc
index 7fe46d8eebb5f..95edd4d7e304c 100644
--- a/libstdc++-v3/testsuite/20_util/variant/run.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/run.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/variant/visit.cc b/libstdc++-v3/testsuite/20_util/variant/visit.cc
index ebe0344b58582..81cab0878f6ed 100644
--- a/libstdc++-v3/testsuite/20_util/variant/visit.cc
+++ b/libstdc++-v3/testsuite/20_util/variant/visit.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <variant>

From 3cb0751e19388721a49c4cd6a56d1be77630d281 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 16:22:53 +0100
Subject: [PATCH 095/164] libstdc++: Remove redundant -std=gnu++17 option from
 concurrency tests

GCC defaults to -std=gnu++17 now anyway, and using it explicitly in the
dg-options directive prevents running these tests with different modes
such as -std=c++17 or -std=gnu++20.

libstdc++-v3/ChangeLog:

	* testsuite/29_atomics/atomic/69769.cc: Remove -std=gnu++17 from
	dg-options.
	* testsuite/29_atomics/atomic/is_always_lock_free.cc:
	* testsuite/29_atomics/atomic/requirements/typedefs.cc:
	* testsuite/29_atomics/atomic_integral/is_always_lock_free.cc:
	* testsuite/29_atomics/atomic_integral/requirements/typedefs.cc:
	* testsuite/30_threads/lock_guard/cons/deduction.cc: Likewise.
	* testsuite/30_threads/scoped_lock/cons/1.cc: Likewise.
	* testsuite/30_threads/scoped_lock/cons/deduction.cc: Likewise.
	* testsuite/30_threads/scoped_lock/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/30_threads/scoped_lock/requirements/typedefs.cc:
	Likewise.
	* testsuite/30_threads/shared_lock/70766.cc: Likewise.
	* testsuite/30_threads/shared_mutex/cons/1.cc: Likewise.
	* testsuite/30_threads/shared_mutex/cons/assign_neg.cc:
	Likewise.
	* testsuite/30_threads/shared_mutex/cons/copy_neg.cc: Likewise.
	* testsuite/30_threads/shared_mutex/requirements/standard_layout.cc:
	Likewise.
	* testsuite/30_threads/shared_mutex/try_lock/1.cc: Likewise.
	* testsuite/30_threads/shared_mutex/try_lock/2.cc: Likewise.
	* testsuite/30_threads/shared_mutex/unlock/1.cc: Likewise.
	* testsuite/30_threads/unique_lock/cons/deduction.cc: Likewise.

(cherry picked from commit 9cd88c022fcad783997cd4111b2e6c3700c4b15b)
---
 libstdc++-v3/testsuite/29_atomics/atomic/69769.cc                | 1 -
 libstdc++-v3/testsuite/29_atomics/atomic/is_always_lock_free.cc  | 1 -
 .../testsuite/29_atomics/atomic/requirements/typedefs.cc         | 1 -
 .../testsuite/29_atomics/atomic_integral/is_always_lock_free.cc  | 1 -
 .../29_atomics/atomic_integral/requirements/typedefs.cc          | 1 -
 libstdc++-v3/testsuite/30_threads/lock_guard/cons/deduction.cc   | 1 -
 libstdc++-v3/testsuite/30_threads/scoped_lock/cons/1.cc          | 1 -
 libstdc++-v3/testsuite/30_threads/scoped_lock/cons/deduction.cc  | 1 -
 .../scoped_lock/requirements/explicit_instantiation.cc           | 1 -
 .../testsuite/30_threads/scoped_lock/requirements/typedefs.cc    | 1 -
 libstdc++-v3/testsuite/30_threads/shared_lock/70766.cc           | 1 -
 libstdc++-v3/testsuite/30_threads/shared_mutex/cons/1.cc         | 1 -
 .../testsuite/30_threads/shared_mutex/cons/assign_neg.cc         | 1 -
 libstdc++-v3/testsuite/30_threads/shared_mutex/cons/copy_neg.cc  | 1 -
 .../30_threads/shared_mutex/requirements/standard_layout.cc      | 1 -
 libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/1.cc     | 1 -
 libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/2.cc     | 1 -
 libstdc++-v3/testsuite/30_threads/shared_mutex/unlock/1.cc       | 1 -
 libstdc++-v3/testsuite/30_threads/unique_lock/cons/deduction.cc  | 1 -
 19 files changed, 19 deletions(-)

diff --git a/libstdc++-v3/testsuite/29_atomics/atomic/69769.cc b/libstdc++-v3/testsuite/29_atomics/atomic/69769.cc
index 8258594e67c9f..d9d0821b8f291 100644
--- a/libstdc++-v3/testsuite/29_atomics/atomic/69769.cc
+++ b/libstdc++-v3/testsuite/29_atomics/atomic/69769.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-atomic-builtins "" }
 
diff --git a/libstdc++-v3/testsuite/29_atomics/atomic/is_always_lock_free.cc b/libstdc++-v3/testsuite/29_atomics/atomic/is_always_lock_free.cc
index 063076ad27480..2fa3a40e98cf8 100644
--- a/libstdc++-v3/testsuite/29_atomics/atomic/is_always_lock_free.cc
+++ b/libstdc++-v3/testsuite/29_atomics/atomic/is_always_lock_free.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <atomic>
diff --git a/libstdc++-v3/testsuite/29_atomics/atomic/requirements/typedefs.cc b/libstdc++-v3/testsuite/29_atomics/atomic/requirements/typedefs.cc
index 28adc6759396d..c730e1ab117c7 100644
--- a/libstdc++-v3/testsuite/29_atomics/atomic/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/29_atomics/atomic/requirements/typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-atomic-builtins "" }
 
diff --git a/libstdc++-v3/testsuite/29_atomics/atomic_integral/is_always_lock_free.cc b/libstdc++-v3/testsuite/29_atomics/atomic_integral/is_always_lock_free.cc
index 1d18c93092df8..c866118943c9a 100644
--- a/libstdc++-v3/testsuite/29_atomics/atomic_integral/is_always_lock_free.cc
+++ b/libstdc++-v3/testsuite/29_atomics/atomic_integral/is_always_lock_free.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <atomic>
diff --git a/libstdc++-v3/testsuite/29_atomics/atomic_integral/requirements/typedefs.cc b/libstdc++-v3/testsuite/29_atomics/atomic_integral/requirements/typedefs.cc
index da27c48e97d22..981a85bb50424 100644
--- a/libstdc++-v3/testsuite/29_atomics/atomic_integral/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/29_atomics/atomic_integral/requirements/typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-atomic-builtins "" }
 
diff --git a/libstdc++-v3/testsuite/30_threads/lock_guard/cons/deduction.cc b/libstdc++-v3/testsuite/30_threads/lock_guard/cons/deduction.cc
index 9dfe6b9706369..98091601d5297 100644
--- a/libstdc++-v3/testsuite/30_threads/lock_guard/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/30_threads/lock_guard/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <mutex>
diff --git a/libstdc++-v3/testsuite/30_threads/scoped_lock/cons/1.cc b/libstdc++-v3/testsuite/30_threads/scoped_lock/cons/1.cc
index 278fd8578e7fb..eef4a7faaafd2 100644
--- a/libstdc++-v3/testsuite/30_threads/scoped_lock/cons/1.cc
+++ b/libstdc++-v3/testsuite/30_threads/scoped_lock/cons/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/30_threads/scoped_lock/cons/deduction.cc b/libstdc++-v3/testsuite/30_threads/scoped_lock/cons/deduction.cc
index ca7dc2459c23f..2b5ea203a0d10 100644
--- a/libstdc++-v3/testsuite/30_threads/scoped_lock/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/30_threads/scoped_lock/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <mutex>
diff --git a/libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/explicit_instantiation.cc
index 0e6e68087a6c5..6d6ccb04effa2 100644
--- a/libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-gthreads "" }
 
diff --git a/libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/typedefs.cc b/libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/typedefs.cc
index dd9626cf09082..8cb02cfe54dcd 100644
--- a/libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-gthreads "" }
 
diff --git a/libstdc++-v3/testsuite/30_threads/shared_lock/70766.cc b/libstdc++-v3/testsuite/30_threads/shared_lock/70766.cc
index c8e28dd36c9eb..6d5755bfd50e7 100644
--- a/libstdc++-v3/testsuite/30_threads/shared_lock/70766.cc
+++ b/libstdc++-v3/testsuite/30_threads/shared_lock/70766.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <shared_mutex>
diff --git a/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/1.cc b/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/1.cc
index 7c23b9c5f9bc7..b83de46fea863 100644
--- a/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/1.cc
+++ b/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-additional-options "-pthread" { target pthread } }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/assign_neg.cc b/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/assign_neg.cc
index 6eb9a65319396..667aec5ae56b3 100644
--- a/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/assign_neg.cc
+++ b/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/assign_neg.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-gthreads "" }
 
diff --git a/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/copy_neg.cc b/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/copy_neg.cc
index 4152981e5bba3..67a6a5597db9d 100644
--- a/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/copy_neg.cc
+++ b/libstdc++-v3/testsuite/30_threads/shared_mutex/cons/copy_neg.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-gthreads "" }
 
diff --git a/libstdc++-v3/testsuite/30_threads/shared_mutex/requirements/standard_layout.cc b/libstdc++-v3/testsuite/30_threads/shared_mutex/requirements/standard_layout.cc
index ffb8b044a74d1..733935442bcf3 100644
--- a/libstdc++-v3/testsuite/30_threads/shared_mutex/requirements/standard_layout.cc
+++ b/libstdc++-v3/testsuite/30_threads/shared_mutex/requirements/standard_layout.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-gthreads "" }
 
diff --git a/libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/1.cc b/libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/1.cc
index e5665ab0ce5fc..42063e7ca2187 100644
--- a/libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/1.cc
+++ b/libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-additional-options "-pthread" { target pthread } }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/2.cc b/libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/2.cc
index 5e03cd144fe1a..9f68cec828a23 100644
--- a/libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/2.cc
+++ b/libstdc++-v3/testsuite/30_threads/shared_mutex/try_lock/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-additional-options "-pthread" { target pthread } }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/30_threads/shared_mutex/unlock/1.cc b/libstdc++-v3/testsuite/30_threads/shared_mutex/unlock/1.cc
index d9f2e5ec97d20..0427f0f8a0501 100644
--- a/libstdc++-v3/testsuite/30_threads/shared_mutex/unlock/1.cc
+++ b/libstdc++-v3/testsuite/30_threads/shared_mutex/unlock/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-additional-options "-pthread" { target pthread } }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/30_threads/unique_lock/cons/deduction.cc b/libstdc++-v3/testsuite/30_threads/unique_lock/cons/deduction.cc
index b9e0fbceeb2af..b676444c755c5 100644
--- a/libstdc++-v3/testsuite/30_threads/unique_lock/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/30_threads/unique_lock/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <mutex>

From 4e3d4243e58b3158488eb69337cbf12b5815cfb8 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 16:22:53 +0100
Subject: [PATCH 096/164] libstdc++: Remove redundant -std=gnu++17 option from
 PMR tests

GCC defaults to -std=gnu++17 now anyway, and using it explicitly in the
dg-options directive prevents running these tests with different modes
such as -std=c++17 or -std=gnu++20.

libstdc++-v3/ChangeLog:

	* testsuite/20_util/memory_resource/1.cc: Remove -std=gnu++17
	from dg-options directive.
	* testsuite/20_util/memory_resource/2.cc: Likewise.
	* testsuite/20_util/monotonic_buffer_resource/1.cc: Likewise.
	* testsuite/20_util/monotonic_buffer_resource/93208.cc:
	Likewise.
	* testsuite/20_util/monotonic_buffer_resource/allocate.cc:
	Likewise.
	* testsuite/20_util/monotonic_buffer_resource/deallocate.cc:
	Likewise.
	* testsuite/20_util/monotonic_buffer_resource/release.cc:
	Likewise.
	* testsuite/20_util/monotonic_buffer_resource/upstream_resource.cc:
	Likewise.
	* testsuite/20_util/polymorphic_allocator/1.cc: Likewise.
	* testsuite/20_util/polymorphic_allocator/construct_pair.cc:
	Likewise.
	* testsuite/20_util/polymorphic_allocator/resource.cc: Likewise.
	* testsuite/20_util/polymorphic_allocator/select.cc: Likewise.
	* testsuite/20_util/synchronized_pool_resource/allocate.cc:
	Likewise.
	* testsuite/20_util/synchronized_pool_resource/allocate_single.cc:
	Likewise.
	* testsuite/20_util/synchronized_pool_resource/cons.cc:
	Likewise.
	* testsuite/20_util/synchronized_pool_resource/cons_single.cc:
	Likewise.
	* testsuite/20_util/synchronized_pool_resource/is_equal.cc:
	Likewise.
	* testsuite/20_util/synchronized_pool_resource/multithreaded.cc:
	Likewise.
	* testsuite/20_util/synchronized_pool_resource/options.cc:
	Likewise.
	* testsuite/20_util/synchronized_pool_resource/release.cc:
	Likewise.
	* testsuite/20_util/synchronized_pool_resource/release_single.cc:
	Likewise.
	* testsuite/20_util/unsynchronized_pool_resource/allocate-max-chunks.cc:
	Likewise.
	* testsuite/20_util/unsynchronized_pool_resource/allocate.cc:
	Likewise.
	* testsuite/20_util/unsynchronized_pool_resource/cons.cc:
	Likewise.
	* testsuite/20_util/unsynchronized_pool_resource/is_equal.cc:
	Likewise.
	* testsuite/20_util/unsynchronized_pool_resource/options.cc:
	Likewise.
	* testsuite/20_util/unsynchronized_pool_resource/release.cc:
	Likewise.
	* testsuite/21_strings/basic_string/types/pmr_typedefs.cc:
	Likewise.
	* testsuite/23_containers/deque/types/pmr_typedefs.cc: Likewise.
	* testsuite/23_containers/deque/types/pmr_typedefs_debug.cc:
	Likewise.
	* testsuite/23_containers/forward_list/pmr_typedefs.cc:
	Likewise.
	* testsuite/23_containers/forward_list/pmr_typedefs_debug.cc:
	Likewise.
	* testsuite/23_containers/list/pmr_typedefs.cc: Likewise.
	* testsuite/23_containers/list/pmr_typedefs_debug.cc: Likewise.
	* testsuite/23_containers/map/pmr_typedefs.cc: Likewise.
	* testsuite/23_containers/map/pmr_typedefs_debug.cc: Likewise.
	* testsuite/23_containers/multimap/pmr_typedefs.cc: Likewise.
	* testsuite/23_containers/multimap/pmr_typedefs_debug.cc:
	Likewise.
	* testsuite/23_containers/multiset/pmr_typedefs.cc: Likewise.
	* testsuite/23_containers/multiset/pmr_typedefs_debug.cc:
	Likewise.
	* testsuite/23_containers/set/pmr_typedefs.cc: Likewise.
	* testsuite/23_containers/set/pmr_typedefs_debug.cc: Likewise.
	* testsuite/23_containers/unordered_map/pmr_typedefs.cc:
	Likewise.
	* testsuite/23_containers/unordered_map/pmr_typedefs_debug.cc:
	Likewise.
	* testsuite/23_containers/unordered_multimap/pmr_typedefs.cc:
	Likewise.
	* testsuite/23_containers/unordered_multimap/pmr_typedefs_debug.cc:
	Likewise.
	* testsuite/23_containers/unordered_multiset/pmr_typedefs.cc:
	Likewise.
	* testsuite/23_containers/unordered_multiset/pmr_typedefs_debug.cc:
	Likewise.
	* testsuite/23_containers/unordered_set/pmr_typedefs.cc:
	Likewise.
	* testsuite/23_containers/unordered_set/pmr_typedefs_debug.cc:
	Likewise.
	* testsuite/23_containers/vector/pmr_typedefs.cc: Likewise.
	* testsuite/23_containers/vector/types/pmr_typedefs_debug.cc:
	Likewise.
	* testsuite/28_regex/match_results/pmr_typedefs.cc: Likewise.

(cherry picked from commit 7a4e52e44a8c9e6c59060adc691de5144d3c6940)
---
 libstdc++-v3/testsuite/20_util/memory_resource/1.cc             | 1 -
 libstdc++-v3/testsuite/20_util/memory_resource/2.cc             | 1 -
 libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/1.cc   | 1 -
 .../testsuite/20_util/monotonic_buffer_resource/93208.cc        | 1 -
 .../testsuite/20_util/monotonic_buffer_resource/allocate.cc     | 1 -
 .../testsuite/20_util/monotonic_buffer_resource/deallocate.cc   | 1 -
 .../testsuite/20_util/monotonic_buffer_resource/release.cc      | 1 -
 .../20_util/monotonic_buffer_resource/upstream_resource.cc      | 1 -
 libstdc++-v3/testsuite/20_util/polymorphic_allocator/1.cc       | 1 -
 .../testsuite/20_util/polymorphic_allocator/construct_pair.cc   | 1 -
 .../testsuite/20_util/polymorphic_allocator/resource.cc         | 1 -
 libstdc++-v3/testsuite/20_util/polymorphic_allocator/select.cc  | 1 -
 .../testsuite/20_util/synchronized_pool_resource/allocate.cc    | 2 +-
 .../20_util/synchronized_pool_resource/allocate_single.cc       | 1 -
 .../testsuite/20_util/synchronized_pool_resource/cons.cc        | 2 +-
 .../testsuite/20_util/synchronized_pool_resource/cons_single.cc | 1 -
 .../testsuite/20_util/synchronized_pool_resource/is_equal.cc    | 2 +-
 .../20_util/synchronized_pool_resource/multithreaded.cc         | 2 +-
 .../testsuite/20_util/synchronized_pool_resource/options.cc     | 2 +-
 .../testsuite/20_util/synchronized_pool_resource/release.cc     | 2 +-
 .../20_util/synchronized_pool_resource/release_single.cc        | 1 -
 .../20_util/unsynchronized_pool_resource/allocate-max-chunks.cc | 1 -
 .../testsuite/20_util/unsynchronized_pool_resource/allocate.cc  | 1 -
 .../testsuite/20_util/unsynchronized_pool_resource/cons.cc      | 1 -
 .../testsuite/20_util/unsynchronized_pool_resource/is_equal.cc  | 1 -
 .../testsuite/20_util/unsynchronized_pool_resource/options.cc   | 1 -
 .../testsuite/20_util/unsynchronized_pool_resource/release.cc   | 1 -
 .../testsuite/21_strings/basic_string/types/pmr_typedefs.cc     | 1 -
 .../testsuite/23_containers/deque/types/pmr_typedefs.cc         | 1 -
 .../testsuite/23_containers/deque/types/pmr_typedefs_debug.cc   | 2 +-
 .../testsuite/23_containers/forward_list/pmr_typedefs.cc        | 1 -
 .../testsuite/23_containers/forward_list/pmr_typedefs_debug.cc  | 2 +-
 libstdc++-v3/testsuite/23_containers/list/pmr_typedefs.cc       | 1 -
 libstdc++-v3/testsuite/23_containers/list/pmr_typedefs_debug.cc | 2 +-
 libstdc++-v3/testsuite/23_containers/map/pmr_typedefs.cc        | 1 -
 libstdc++-v3/testsuite/23_containers/map/pmr_typedefs_debug.cc  | 2 +-
 libstdc++-v3/testsuite/23_containers/multimap/pmr_typedefs.cc   | 1 -
 .../testsuite/23_containers/multimap/pmr_typedefs_debug.cc      | 2 +-
 libstdc++-v3/testsuite/23_containers/multiset/pmr_typedefs.cc   | 1 -
 .../testsuite/23_containers/multiset/pmr_typedefs_debug.cc      | 2 +-
 libstdc++-v3/testsuite/23_containers/set/pmr_typedefs.cc        | 1 -
 libstdc++-v3/testsuite/23_containers/set/pmr_typedefs_debug.cc  | 2 +-
 .../testsuite/23_containers/unordered_map/pmr_typedefs.cc       | 1 -
 .../testsuite/23_containers/unordered_map/pmr_typedefs_debug.cc | 2 +-
 .../testsuite/23_containers/unordered_multimap/pmr_typedefs.cc  | 1 -
 .../23_containers/unordered_multimap/pmr_typedefs_debug.cc      | 2 +-
 .../testsuite/23_containers/unordered_multiset/pmr_typedefs.cc  | 1 -
 .../23_containers/unordered_multiset/pmr_typedefs_debug.cc      | 2 +-
 .../testsuite/23_containers/unordered_set/pmr_typedefs.cc       | 1 -
 .../testsuite/23_containers/unordered_set/pmr_typedefs_debug.cc | 2 +-
 libstdc++-v3/testsuite/23_containers/vector/pmr_typedefs.cc     | 1 -
 .../testsuite/23_containers/vector/types/pmr_typedefs_debug.cc  | 2 +-
 libstdc++-v3/testsuite/28_regex/match_results/pmr_typedefs.cc   | 1 -
 53 files changed, 18 insertions(+), 53 deletions(-)

diff --git a/libstdc++-v3/testsuite/20_util/memory_resource/1.cc b/libstdc++-v3/testsuite/20_util/memory_resource/1.cc
index cc96a3e546d00..174949da27bab 100644
--- a/libstdc++-v3/testsuite/20_util/memory_resource/1.cc
+++ b/libstdc++-v3/testsuite/20_util/memory_resource/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/memory_resource/2.cc b/libstdc++-v3/testsuite/20_util/memory_resource/2.cc
index 725a216d3808b..0c88e0b8b7e1a 100644
--- a/libstdc++-v3/testsuite/20_util/memory_resource/2.cc
+++ b/libstdc++-v3/testsuite/20_util/memory_resource/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-skip-if "" { *-*-* } { -fno-aligned-new } }
 
diff --git a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/1.cc b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/1.cc
index 9cd243c4c2f87..eb7e20483e50d 100644
--- a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/1.cc
+++ b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/93208.cc b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/93208.cc
index 3e3d3404df787..89f1d00540bbb 100644
--- a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/93208.cc
+++ b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/93208.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-final { scan-assembler-not "_ZT\[IS\]NSt3pmr15memory_resourceE" } }
 // { dg-final { scan-assembler-not "_ZT\[IS\]NSt3pmr25monotonic\[a-z_\]*E" } }
diff --git a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/allocate.cc b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/allocate.cc
index 95d512d4b825c..40180223bae34 100644
--- a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/allocate.cc
+++ b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/allocate.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-cstdint "" }
 
diff --git a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/deallocate.cc b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/deallocate.cc
index 73acdbaa75463..3fcaf2b4c9835 100644
--- a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/deallocate.cc
+++ b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/deallocate.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-cstdint "" }
 
diff --git a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/release.cc b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/release.cc
index 0e12632debc1b..5f1599434997c 100644
--- a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/release.cc
+++ b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/release.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/upstream_resource.cc b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/upstream_resource.cc
index 641a0d21cf6e0..51f6d07d01770 100644
--- a/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/upstream_resource.cc
+++ b/libstdc++-v3/testsuite/20_util/monotonic_buffer_resource/upstream_resource.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/polymorphic_allocator/1.cc b/libstdc++-v3/testsuite/20_util/polymorphic_allocator/1.cc
index 5ac106488d24e..12a4322fdc4b1 100644
--- a/libstdc++-v3/testsuite/20_util/polymorphic_allocator/1.cc
+++ b/libstdc++-v3/testsuite/20_util/polymorphic_allocator/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/polymorphic_allocator/construct_pair.cc b/libstdc++-v3/testsuite/20_util/polymorphic_allocator/construct_pair.cc
index ee2737a60e7d3..c7dedd0d3b10e 100644
--- a/libstdc++-v3/testsuite/20_util/polymorphic_allocator/construct_pair.cc
+++ b/libstdc++-v3/testsuite/20_util/polymorphic_allocator/construct_pair.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/polymorphic_allocator/resource.cc b/libstdc++-v3/testsuite/20_util/polymorphic_allocator/resource.cc
index 01bafabbc1442..ad0821611f389 100644
--- a/libstdc++-v3/testsuite/20_util/polymorphic_allocator/resource.cc
+++ b/libstdc++-v3/testsuite/20_util/polymorphic_allocator/resource.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-skip-if "" { *-*-* } { -fno-aligned-new } }
 
diff --git a/libstdc++-v3/testsuite/20_util/polymorphic_allocator/select.cc b/libstdc++-v3/testsuite/20_util/polymorphic_allocator/select.cc
index 71a7097576dea..f53462969f5d4 100644
--- a/libstdc++-v3/testsuite/20_util/polymorphic_allocator/select.cc
+++ b/libstdc++-v3/testsuite/20_util/polymorphic_allocator/select.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-skip-if "" { *-*-* } { -fno-aligned-new } }
 
diff --git a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/allocate.cc b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/allocate.cc
index f7af9b695ef46..51445d65f7104 100644
--- a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/allocate.cc
+++ b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/allocate.cc
@@ -16,7 +16,7 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-do run }
-// { dg-options "-std=gnu++17 -pthread" }
+// { dg-options "-pthread" }
 // { dg-require-effective-target c++17 }
 // { dg-require-effective-target pthread }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/allocate_single.cc b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/allocate_single.cc
index df9c317456b50..1d03a60f3ebec 100644
--- a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/allocate_single.cc
+++ b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/allocate_single.cc
@@ -16,7 +16,6 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-do run }
-// { dg-options "-std=gnu++17" }
 // { dg-require-effective-target c++17 }
 // { dg-require-gthreads "" }
 
diff --git a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/cons.cc b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/cons.cc
index 065a6e91550de..0d42bfeea89ad 100644
--- a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/cons.cc
+++ b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/cons.cc
@@ -16,7 +16,7 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-do run }
-// { dg-options "-std=gnu++17 -pthread" }
+// { dg-options "-pthread" }
 // { dg-require-effective-target c++17 }
 // { dg-require-effective-target pthread }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/cons_single.cc b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/cons_single.cc
index 3b370745f2091..d02bb86b88aa5 100644
--- a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/cons_single.cc
+++ b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/cons_single.cc
@@ -16,7 +16,6 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-do run }
-// { dg-options "-std=gnu++17" }
 // { dg-require-effective-target c++17 }
 // { dg-require-gthreads "" }
 
diff --git a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/is_equal.cc b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/is_equal.cc
index ee2b974fff78b..53804d347af4b 100644
--- a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/is_equal.cc
+++ b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/is_equal.cc
@@ -16,7 +16,7 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-do run }
-// { dg-options "-std=gnu++17 -pthread" }
+// { dg-options "-pthread" }
 // { dg-require-effective-target c++17 }
 // { dg-require-effective-target pthread }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/multithreaded.cc b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/multithreaded.cc
index 4bf54ea955aba..45a5a5bfef75a 100644
--- a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/multithreaded.cc
+++ b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/multithreaded.cc
@@ -16,7 +16,7 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-do run }
-// { dg-options "-std=gnu++17 -pthread" }
+// { dg-options "-pthread" }
 // { dg-require-effective-target c++17 }
 // { dg-require-effective-target pthread }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/options.cc b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/options.cc
index 7a41e647c1169..c324c5341efb2 100644
--- a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/options.cc
+++ b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/options.cc
@@ -16,7 +16,7 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-do run }
-// { dg-options "-std=gnu++17 -pthread" }
+// { dg-options "-pthread" }
 // { dg-require-effective-target c++17 }
 // { dg-require-effective-target pthread }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/release.cc b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/release.cc
index 074d3f85d8559..1580304baabde 100644
--- a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/release.cc
+++ b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/release.cc
@@ -16,7 +16,7 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-do run }
-// { dg-options "-std=gnu++17 -pthread" }
+// { dg-options "-pthread" }
 // { dg-require-effective-target c++17 }
 // { dg-require-effective-target pthread }
 // { dg-require-gthreads "" }
diff --git a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/release_single.cc b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/release_single.cc
index 5e2067d08000a..250920443bd95 100644
--- a/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/release_single.cc
+++ b/libstdc++-v3/testsuite/20_util/synchronized_pool_resource/release_single.cc
@@ -16,7 +16,6 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-do run }
-// { dg-options "-std=gnu++17" }
 // { dg-require-effective-target c++17 }
 // { dg-require-gthreads "" }
 
diff --git a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/allocate-max-chunks.cc b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/allocate-max-chunks.cc
index fea3e18ccbbfd..c3cc858b12bff 100644
--- a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/allocate-max-chunks.cc
+++ b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/allocate-max-chunks.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/allocate.cc b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/allocate.cc
index 79fac01fb2584..a76afbe87a2ee 100644
--- a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/allocate.cc
+++ b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/allocate.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/cons.cc b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/cons.cc
index 86b55ee47b9eb..fd9113368d7aa 100644
--- a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/cons.cc
+++ b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/cons.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/is_equal.cc b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/is_equal.cc
index 8ffc5dc7f2f86..2707167cf6f3b 100644
--- a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/is_equal.cc
+++ b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/is_equal.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/options.cc b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/options.cc
index d746a6a21ebe0..f3989a144e85e 100644
--- a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/options.cc
+++ b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/options.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/release.cc b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/release.cc
index bd2ccd2eda832..3ff6bd4168908 100644
--- a/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/release.cc
+++ b/libstdc++-v3/testsuite/20_util/unsynchronized_pool_resource/release.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory_resource>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/types/pmr_typedefs.cc b/libstdc++-v3/testsuite/21_strings/basic_string/types/pmr_typedefs.cc
index 431603b2ae4fc..cb597a743121e 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/types/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/types/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-effective-target cxx11-abi }
 
diff --git a/libstdc++-v3/testsuite/23_containers/deque/types/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/deque/types/pmr_typedefs.cc
index 0e447197ba625..4c428214b20c3 100644
--- a/libstdc++-v3/testsuite/23_containers/deque/types/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/deque/types/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <deque>
diff --git a/libstdc++-v3/testsuite/23_containers/deque/types/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/deque/types/pmr_typedefs_debug.cc
index 401f4a88586e4..90c19027dbb5b 100644
--- a/libstdc++-v3/testsuite/23_containers/deque/types/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/deque/types/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/forward_list/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/forward_list/pmr_typedefs.cc
index a8aac325caade..107d764fb26a3 100644
--- a/libstdc++-v3/testsuite/23_containers/forward_list/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/forward_list/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <forward_list>
diff --git a/libstdc++-v3/testsuite/23_containers/forward_list/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/forward_list/pmr_typedefs_debug.cc
index ecd9da004f336..c183b2f195966 100644
--- a/libstdc++-v3/testsuite/23_containers/forward_list/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/forward_list/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/list/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/list/pmr_typedefs.cc
index d647c71ccaddb..f4908b91f96a3 100644
--- a/libstdc++-v3/testsuite/23_containers/list/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/list/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <list>
diff --git a/libstdc++-v3/testsuite/23_containers/list/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/list/pmr_typedefs_debug.cc
index 58e973afcad26..4be0b7fe50355 100644
--- a/libstdc++-v3/testsuite/23_containers/list/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/list/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/map/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/map/pmr_typedefs.cc
index 1cab36ba59aed..7ea3b6a20738a 100644
--- a/libstdc++-v3/testsuite/23_containers/map/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/map/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <map>
diff --git a/libstdc++-v3/testsuite/23_containers/map/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/map/pmr_typedefs_debug.cc
index aed35cc0075c9..f07e68a809840 100644
--- a/libstdc++-v3/testsuite/23_containers/map/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/map/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/multimap/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/multimap/pmr_typedefs.cc
index 70345958a6619..54119f8c8504c 100644
--- a/libstdc++-v3/testsuite/23_containers/multimap/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/multimap/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <map>
diff --git a/libstdc++-v3/testsuite/23_containers/multimap/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/multimap/pmr_typedefs_debug.cc
index 45c85f1a9fe76..6f466754a3250 100644
--- a/libstdc++-v3/testsuite/23_containers/multimap/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/multimap/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/multiset/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/multiset/pmr_typedefs.cc
index 4fd7dc70de288..075bb8f25f8be 100644
--- a/libstdc++-v3/testsuite/23_containers/multiset/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/multiset/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <set>
diff --git a/libstdc++-v3/testsuite/23_containers/multiset/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/multiset/pmr_typedefs_debug.cc
index 287b5da41c05a..c13da382284eb 100644
--- a/libstdc++-v3/testsuite/23_containers/multiset/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/multiset/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/set/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/set/pmr_typedefs.cc
index 13e77fce91eb8..2a0551f5127a2 100644
--- a/libstdc++-v3/testsuite/23_containers/set/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/set/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <set>
diff --git a/libstdc++-v3/testsuite/23_containers/set/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/set/pmr_typedefs_debug.cc
index f937d9f6d25e5..7a4d05146cf39 100644
--- a/libstdc++-v3/testsuite/23_containers/set/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/set/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_map/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/unordered_map/pmr_typedefs.cc
index de5db5ea873f3..aeb94a1c78f31 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_map/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_map/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <unordered_map>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_map/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/unordered_map/pmr_typedefs_debug.cc
index cf41df0f23021..2830b70cb8208 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_map/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_map/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multimap/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/unordered_multimap/pmr_typedefs.cc
index 9bfcbdea09e89..e10f9adae3451 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multimap/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multimap/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <unordered_map>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multimap/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/unordered_multimap/pmr_typedefs_debug.cc
index 80a018898ebb8..72d4997ee9ac8 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multimap/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multimap/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multiset/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/unordered_multiset/pmr_typedefs.cc
index 255ad01e74c2e..d9e5e4c838c94 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multiset/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multiset/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <unordered_set>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multiset/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/unordered_multiset/pmr_typedefs_debug.cc
index a76b5f3b3a3d1..5318275535b51 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multiset/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multiset/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_set/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/unordered_set/pmr_typedefs.cc
index 280309293d0f8..14e4cf36ca6cd 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_set/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_set/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <unordered_set>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_set/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/unordered_set/pmr_typedefs_debug.cc
index b647f5c872e7a..db06d8b6d170c 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_set/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_set/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/23_containers/vector/pmr_typedefs.cc b/libstdc++-v3/testsuite/23_containers/vector/pmr_typedefs.cc
index 09a3568fd44e9..38ff8e7d505de 100644
--- a/libstdc++-v3/testsuite/23_containers/vector/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/23_containers/vector/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <vector>
diff --git a/libstdc++-v3/testsuite/23_containers/vector/types/pmr_typedefs_debug.cc b/libstdc++-v3/testsuite/23_containers/vector/types/pmr_typedefs_debug.cc
index fbe7a2a1a34bd..8eb9802be58a7 100644
--- a/libstdc++-v3/testsuite/23_containers/vector/types/pmr_typedefs_debug.cc
+++ b/libstdc++-v3/testsuite/23_containers/vector/types/pmr_typedefs_debug.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_DEBUG" }
+// { dg-options "-D_GLIBCXX_DEBUG" }
 // { dg-do compile { target c++17 } }
 // { dg-skip-if "" { *-*-* } { "-D_GLIBCXX_PARALLEL" } }
 
diff --git a/libstdc++-v3/testsuite/28_regex/match_results/pmr_typedefs.cc b/libstdc++-v3/testsuite/28_regex/match_results/pmr_typedefs.cc
index fcb63e5dc846b..3df502d5bf73c 100644
--- a/libstdc++-v3/testsuite/28_regex/match_results/pmr_typedefs.cc
+++ b/libstdc++-v3/testsuite/28_regex/match_results/pmr_typedefs.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-timeout-factor 2 }
 // { dg-require-effective-target cxx11-abi }

From b2f518f3c7f944840d9c216410b0ba62fae48b01 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 16:22:53 +0100
Subject: [PATCH 097/164] libstdc++: Remove redundant -std=gnu++17 option from
 strings tests

GCC defaults to -std=gnu++17 now anyway, and using it explicitly in the
dg-options directive prevents running these tests with different modes
such as -std=c++17 or -std=gnu++20.

libstdc++-v3/ChangeLog:

	* testsuite/21_strings/basic_string/79162.cc: Remove
	-std=gnu++17 from dg-options directive.
	* testsuite/21_strings/basic_string/cons/char/7.cc: Likewise.
	* testsuite/21_strings/basic_string/cons/char/79162.cc:
	Likewise.
	* testsuite/21_strings/basic_string/cons/char/86138.cc:
	Likewise.
	* testsuite/21_strings/basic_string/cons/char/9.cc: Likewise.
	* testsuite/21_strings/basic_string/cons/char/deduction.cc:
	Likewise.
	* testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc:
	Likewise.
	* testsuite/21_strings/basic_string/cons/wchar_t/7.cc: Likewise.
	* testsuite/21_strings/basic_string/cons/wchar_t/79162.cc:
	Likewise.
	* testsuite/21_strings/basic_string/cons/wchar_t/86138.cc:
	Likewise.
	* testsuite/21_strings/basic_string/cons/wchar_t/9.cc: Likewise.
	* testsuite/21_strings/basic_string/cons/wchar_t/deduction.cc:
	Likewise.
	* testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc:
	Likewise.
	* testsuite/21_strings/basic_string/hash/hash.cc: Likewise.
	* testsuite/21_strings/basic_string/lwg2758.cc: Likewise.
	* testsuite/21_strings/basic_string/lwg2946.cc: Likewise.
	* testsuite/21_strings/basic_string/modifiers/append/char/4.cc:
	Likewise.
	* testsuite/21_strings/basic_string/modifiers/append/wchar_t/4.cc:
	Likewise.
	* testsuite/21_strings/basic_string/modifiers/assign/char/4.cc:
	Likewise.
	* testsuite/21_strings/basic_string/modifiers/assign/wchar_t/4.cc:
	Likewise.
	* testsuite/21_strings/basic_string/modifiers/insert/char/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string/modifiers/insert/wchar_t/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string/modifiers/replace/char/7.cc:
	Likewise.
	* testsuite/21_strings/basic_string/modifiers/replace/wchar_t/7.cc:
	Likewise.
	* testsuite/21_strings/basic_string/operations/compare/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string/operations/compare/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string/operations/data/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string/operations/data/char/86169.cc:
	Likewise.
	* testsuite/21_strings/basic_string/operations/data/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string/operations/find/char/5.cc:
	Likewise.
	* testsuite/21_strings/basic_string/operations/find/wchar_t/5.cc:
	Likewise.
	* testsuite/21_strings/basic_string/operators/char/5.cc:
	Likewise.
	* testsuite/21_strings/basic_string/operators/wchar_t/5.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/capacity/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/capacity/empty_neg.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/cons/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/cons/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/cons/char/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/cons/char/nonnull.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/cons/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/cons/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/cons/wchar_t/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/cons/wchar_t/nonnull.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/char/back_constexpr_neg.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/char/constexpr.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/char/constexpr_neg.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/char/empty.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/char/front_back.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/char/front_back_constexpr.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/char/front_constexpr_neg.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/wchar_t/back_constexpr_neg.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr_neg.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/wchar_t/empty.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/wchar_t/front_back.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/element_access/wchar_t/front_constexpr_neg.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/include.cc: Likewise.
	* testsuite/21_strings/basic_string_view/inserters/94051.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/inserters/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/inserters/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/inserters/char/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/inserters/pod/10081-out.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/inserters/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/inserters/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/inserters/wchar_t/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/literals/types-char8_t.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/literals/types.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/literals/values-char8_t.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/literals/values.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/modifiers/remove_prefix/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/modifiers/remove_prefix/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/modifiers/remove_suffix/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/modifiers/remove_suffix/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/compare/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/compare/char/13650.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/compare/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/compare/char/70483.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/compare/char/nonnull.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/compare/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/compare/wchar_t/13650.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/compare/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/copy/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/copy/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/copy/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/copy/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/data/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/data/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/find/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/find/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/find/char/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/find/char/4.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/find/char/nonnull.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/4.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/rfind/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/rfind/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/rfind/char/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/rfind/char/nonnull.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/3.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/string_conversion/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/substr/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/substr/char/83511.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/substr/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operations/substr/wchar_t/83511.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operators/char/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operators/char/89446.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/operators/wchar_t/89446.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/range_access/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char16_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char32_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char8_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/wchar_t/1.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/requirements/traits_neg.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/requirements/typedefs.cc:
	Likewise.
	* testsuite/21_strings/basic_string_view/typedefs.cc: Likewise.
	* testsuite/21_strings/basic_string_view/types/1.cc: Likewise.
	* testsuite/21_strings/char_traits/requirements/char/99181.cc:
	Likewise.
	* testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc:

(cherry picked from commit 8087e70267ce6fa0787152963339ba987e7b514d)
---
 libstdc++-v3/testsuite/21_strings/basic_string/79162.cc         | 1 -
 libstdc++-v3/testsuite/21_strings/basic_string/cons/char/7.cc   | 1 -
 .../testsuite/21_strings/basic_string/cons/char/79162.cc        | 1 -
 .../testsuite/21_strings/basic_string/cons/char/86138.cc        | 1 -
 libstdc++-v3/testsuite/21_strings/basic_string/cons/char/9.cc   | 1 -
 .../testsuite/21_strings/basic_string/cons/char/deduction.cc    | 1 -
 .../21_strings/basic_string/cons/char/moveable2_c++17.cc        | 1 -
 .../testsuite/21_strings/basic_string/cons/wchar_t/7.cc         | 1 -
 .../testsuite/21_strings/basic_string/cons/wchar_t/79162.cc     | 1 -
 .../testsuite/21_strings/basic_string/cons/wchar_t/86138.cc     | 1 -
 .../testsuite/21_strings/basic_string/cons/wchar_t/9.cc         | 1 -
 .../testsuite/21_strings/basic_string/cons/wchar_t/deduction.cc | 1 -
 .../21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc     | 1 -
 libstdc++-v3/testsuite/21_strings/basic_string/hash/hash.cc     | 1 -
 libstdc++-v3/testsuite/21_strings/basic_string/lwg2758.cc       | 1 -
 libstdc++-v3/testsuite/21_strings/basic_string/lwg2946.cc       | 1 -
 .../21_strings/basic_string/modifiers/append/char/4.cc          | 1 -
 .../21_strings/basic_string/modifiers/append/wchar_t/4.cc       | 1 -
 .../21_strings/basic_string/modifiers/assign/char/4.cc          | 1 -
 .../21_strings/basic_string/modifiers/assign/wchar_t/4.cc       | 1 -
 .../21_strings/basic_string/modifiers/insert/char/3.cc          | 1 -
 .../21_strings/basic_string/modifiers/insert/wchar_t/3.cc       | 1 -
 .../21_strings/basic_string/modifiers/replace/char/7.cc         | 1 -
 .../21_strings/basic_string/modifiers/replace/wchar_t/7.cc      | 1 -
 .../21_strings/basic_string/operations/compare/char/2.cc        | 1 -
 .../21_strings/basic_string/operations/compare/wchar_t/2.cc     | 1 -
 .../testsuite/21_strings/basic_string/operations/data/char/2.cc | 1 -
 .../21_strings/basic_string/operations/data/char/86169.cc       | 1 -
 .../21_strings/basic_string/operations/data/wchar_t/2.cc        | 1 -
 .../testsuite/21_strings/basic_string/operations/find/char/5.cc | 1 -
 .../21_strings/basic_string/operations/find/wchar_t/5.cc        | 1 -
 .../testsuite/21_strings/basic_string/operators/char/5.cc       | 1 -
 .../testsuite/21_strings/basic_string/operators/wchar_t/5.cc    | 1 -
 .../testsuite/21_strings/basic_string_view/capacity/1.cc        | 1 -
 .../21_strings/basic_string_view/capacity/empty_neg.cc          | 1 -
 .../testsuite/21_strings/basic_string_view/cons/char/1.cc       | 1 -
 .../testsuite/21_strings/basic_string_view/cons/char/2.cc       | 1 -
 .../testsuite/21_strings/basic_string_view/cons/char/3.cc       | 1 -
 .../testsuite/21_strings/basic_string_view/cons/char/nonnull.cc | 2 +-
 .../testsuite/21_strings/basic_string_view/cons/wchar_t/1.cc    | 1 -
 .../testsuite/21_strings/basic_string_view/cons/wchar_t/2.cc    | 1 -
 .../testsuite/21_strings/basic_string_view/cons/wchar_t/3.cc    | 1 -
 .../21_strings/basic_string_view/cons/wchar_t/nonnull.cc        | 2 +-
 .../21_strings/basic_string_view/element_access/char/1.cc       | 1 -
 .../21_strings/basic_string_view/element_access/char/2.cc       | 2 +-
 .../basic_string_view/element_access/char/back_constexpr_neg.cc | 2 +-
 .../basic_string_view/element_access/char/constexpr.cc          | 1 -
 .../basic_string_view/element_access/char/constexpr_neg.cc      | 2 +-
 .../21_strings/basic_string_view/element_access/char/empty.cc   | 1 -
 .../basic_string_view/element_access/char/front_back.cc         | 1 -
 .../element_access/char/front_back_constexpr.cc                 | 1 -
 .../element_access/char/front_constexpr_neg.cc                  | 2 +-
 .../21_strings/basic_string_view/element_access/wchar_t/1.cc    | 1 -
 .../21_strings/basic_string_view/element_access/wchar_t/2.cc    | 2 +-
 .../element_access/wchar_t/back_constexpr_neg.cc                | 2 +-
 .../basic_string_view/element_access/wchar_t/constexpr.cc       | 1 -
 .../basic_string_view/element_access/wchar_t/constexpr_neg.cc   | 2 +-
 .../basic_string_view/element_access/wchar_t/empty.cc           | 1 -
 .../basic_string_view/element_access/wchar_t/front_back.cc      | 1 -
 .../element_access/wchar_t/front_constexpr_neg.cc               | 2 +-
 libstdc++-v3/testsuite/21_strings/basic_string_view/include.cc  | 2 +-
 .../testsuite/21_strings/basic_string_view/inserters/94051.cc   | 1 -
 .../testsuite/21_strings/basic_string_view/inserters/char/1.cc  | 1 -
 .../testsuite/21_strings/basic_string_view/inserters/char/2.cc  | 1 -
 .../testsuite/21_strings/basic_string_view/inserters/char/3.cc  | 1 -
 .../21_strings/basic_string_view/inserters/pod/10081-out.cc     | 1 -
 .../21_strings/basic_string_view/inserters/wchar_t/1.cc         | 1 -
 .../21_strings/basic_string_view/inserters/wchar_t/2.cc         | 1 -
 .../21_strings/basic_string_view/inserters/wchar_t/3.cc         | 1 -
 .../21_strings/basic_string_view/literals/types-char8_t.cc      | 2 +-
 .../testsuite/21_strings/basic_string_view/literals/types.cc    | 1 -
 .../21_strings/basic_string_view/literals/values-char8_t.cc     | 2 +-
 .../testsuite/21_strings/basic_string_view/literals/values.cc   | 1 -
 .../basic_string_view/modifiers/remove_prefix/char/1.cc         | 1 -
 .../basic_string_view/modifiers/remove_prefix/wchar_t/1.cc      | 1 -
 .../basic_string_view/modifiers/remove_suffix/char/1.cc         | 1 -
 .../basic_string_view/modifiers/remove_suffix/wchar_t/1.cc      | 1 -
 .../21_strings/basic_string_view/modifiers/swap/char/1.cc       | 1 -
 .../21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc    | 1 -
 .../21_strings/basic_string_view/operations/compare/char/1.cc   | 1 -
 .../basic_string_view/operations/compare/char/13650.cc          | 1 -
 .../21_strings/basic_string_view/operations/compare/char/2.cc   | 1 -
 .../basic_string_view/operations/compare/char/70483.cc          | 1 -
 .../basic_string_view/operations/compare/char/nonnull.cc        | 2 +-
 .../basic_string_view/operations/compare/wchar_t/1.cc           | 1 -
 .../basic_string_view/operations/compare/wchar_t/13650.cc       | 1 -
 .../basic_string_view/operations/compare/wchar_t/2.cc           | 1 -
 .../21_strings/basic_string_view/operations/copy/char/1.cc      | 1 -
 .../21_strings/basic_string_view/operations/copy/char/2.cc      | 1 -
 .../21_strings/basic_string_view/operations/copy/wchar_t/1.cc   | 1 -
 .../21_strings/basic_string_view/operations/copy/wchar_t/2.cc   | 1 -
 .../21_strings/basic_string_view/operations/data/char/1.cc      | 1 -
 .../21_strings/basic_string_view/operations/data/wchar_t/1.cc   | 1 -
 .../21_strings/basic_string_view/operations/find/char/1.cc      | 1 -
 .../21_strings/basic_string_view/operations/find/char/2.cc      | 1 -
 .../21_strings/basic_string_view/operations/find/char/3.cc      | 1 -
 .../21_strings/basic_string_view/operations/find/char/4.cc      | 1 -
 .../basic_string_view/operations/find/char/nonnull.cc           | 2 +-
 .../21_strings/basic_string_view/operations/find/wchar_t/1.cc   | 1 -
 .../21_strings/basic_string_view/operations/find/wchar_t/2.cc   | 1 -
 .../21_strings/basic_string_view/operations/find/wchar_t/3.cc   | 1 -
 .../21_strings/basic_string_view/operations/find/wchar_t/4.cc   | 1 -
 .../21_strings/basic_string_view/operations/rfind/char/1.cc     | 1 -
 .../21_strings/basic_string_view/operations/rfind/char/2.cc     | 1 -
 .../21_strings/basic_string_view/operations/rfind/char/3.cc     | 1 -
 .../basic_string_view/operations/rfind/char/nonnull.cc          | 2 +-
 .../21_strings/basic_string_view/operations/rfind/wchar_t/1.cc  | 1 -
 .../21_strings/basic_string_view/operations/rfind/wchar_t/2.cc  | 1 -
 .../21_strings/basic_string_view/operations/rfind/wchar_t/3.cc  | 1 -
 .../basic_string_view/operations/string_conversion/1.cc         | 1 -
 .../21_strings/basic_string_view/operations/substr/char/1.cc    | 1 -
 .../basic_string_view/operations/substr/char/83511.cc           | 1 -
 .../21_strings/basic_string_view/operations/substr/wchar_t/1.cc | 1 -
 .../basic_string_view/operations/substr/wchar_t/83511.cc        | 1 -
 .../testsuite/21_strings/basic_string_view/operators/char/2.cc  | 1 -
 .../21_strings/basic_string_view/operators/char/89446.cc        | 2 +-
 .../21_strings/basic_string_view/operators/wchar_t/2.cc         | 1 -
 .../21_strings/basic_string_view/operators/wchar_t/89446.cc     | 2 +-
 .../21_strings/basic_string_view/range_access/char/1.cc         | 1 -
 .../21_strings/basic_string_view/range_access/wchar_t/1.cc      | 1 -
 .../basic_string_view/requirements/explicit_instantiation/1.cc  | 1 -
 .../requirements/explicit_instantiation/char/1.cc               | 1 -
 .../requirements/explicit_instantiation/char16_t/1.cc           | 1 -
 .../requirements/explicit_instantiation/char32_t/1.cc           | 1 -
 .../requirements/explicit_instantiation/char8_t/1.cc            | 2 +-
 .../requirements/explicit_instantiation/wchar_t/1.cc            | 1 -
 .../21_strings/basic_string_view/requirements/traits_neg.cc     | 1 -
 .../21_strings/basic_string_view/requirements/typedefs.cc       | 1 -
 libstdc++-v3/testsuite/21_strings/basic_string_view/typedefs.cc | 1 -
 libstdc++-v3/testsuite/21_strings/basic_string_view/types/1.cc  | 1 -
 .../testsuite/21_strings/char_traits/requirements/char/99181.cc | 1 -
 .../char_traits/requirements/constexpr_functions_c++17.cc       | 1 -
 132 files changed, 19 insertions(+), 132 deletions(-)

diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/79162.cc b/libstdc++-v3/testsuite/21_strings/basic_string/79162.cc
index 0f296f4770aa8..9b639b701fc88 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/79162.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/79162.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/7.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/7.cc
index 0119855636d7e..e5261f8e02ff2 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/7.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/7.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/79162.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/79162.cc
index 3e315ec894d32..0492dbbc2bd1e 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/79162.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/79162.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/86138.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/86138.cc
index bd40cab3a16d5..134b7ef9a5a43 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/86138.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/86138.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-final { scan-assembler-not "_ZNSs4_Rep20_S_empty_rep_storageE:" } }
 
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/9.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/9.cc
index ccb7431f42722..d8718e23167cc 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/9.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/9.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <string>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/deduction.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/deduction.cc
index 49d42cdef4bb0..de4748ec5f774 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/deduction.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc
index 5d577dbdc5776..1caedcccfce44 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2011-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/7.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/7.cc
index aef1b4a8ebc98..da8a26a52d4f2 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/7.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/7.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/79162.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/79162.cc
index 3e315ec894d32..0492dbbc2bd1e 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/79162.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/79162.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/86138.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/86138.cc
index dffd521f3be3f..d63d9006c3396 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/86138.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/86138.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-final { scan-assembler-not "_ZNSbIwSt11char_traitsIwESaIwEE4_Rep20_S_empty_rep_storageE:" } }
 
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/9.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/9.cc
index 483768327e335..42e3484d48de0 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/9.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/9.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <string>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/deduction.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/deduction.cc
index 19bb988d7bc7b..5262869db7429 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/deduction.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc
index 1e994be2176e4..d3e4744ff347b 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2011-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/hash/hash.cc b/libstdc++-v3/testsuite/21_strings/basic_string/hash/hash.cc
index 03fecadc1297d..e5d0a4dc5ee31 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/hash/hash.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/hash/hash.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <string>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/lwg2758.cc b/libstdc++-v3/testsuite/21_strings/basic_string/lwg2758.cc
index 0f8a2e8592c3c..9201785c26640 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/lwg2758.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/lwg2758.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/lwg2946.cc b/libstdc++-v3/testsuite/21_strings/basic_string/lwg2946.cc
index 8dc2fafe858da..15c4167d04822 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/lwg2946.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/lwg2946.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/append/char/4.cc b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/append/char/4.cc
index fd511bcb23123..472b06ed6c613 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/append/char/4.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/append/char/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/append/wchar_t/4.cc b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/append/wchar_t/4.cc
index 7dcefae54920e..995ec481b4672 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/append/wchar_t/4.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/append/wchar_t/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/assign/char/4.cc b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/assign/char/4.cc
index 5e5927b7e8025..0866783f0b878 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/assign/char/4.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/assign/char/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/assign/wchar_t/4.cc b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/assign/wchar_t/4.cc
index 9b25974c5d3f7..4f9287449f32e 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/assign/wchar_t/4.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/assign/wchar_t/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/insert/char/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/insert/char/3.cc
index 6e1c8727bb34e..b47542946c94a 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/insert/char/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/insert/char/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/insert/wchar_t/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/insert/wchar_t/3.cc
index ebb5bba1b2c82..38cf5bbc74af7 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/insert/wchar_t/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/insert/wchar_t/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/replace/char/7.cc b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/replace/char/7.cc
index 9a27d6f598bdd..ab17b26379315 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/replace/char/7.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/replace/char/7.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/replace/wchar_t/7.cc b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/replace/wchar_t/7.cc
index 99568bacb5e29..4fdc4ef659a93 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/replace/wchar_t/7.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/modifiers/replace/wchar_t/7.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/operations/compare/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string/operations/compare/char/2.cc
index afb5858032252..84c458707bf1d 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/operations/compare/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/operations/compare/char/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/operations/compare/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string/operations/compare/wchar_t/2.cc
index f6708ad89c910..40a92f710f40b 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/operations/compare/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/operations/compare/wchar_t/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/char/2.cc
index edd7029a7079e..4c654fe7452de 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/char/2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // C++17 21.3.1.7 [string.ops] string operations
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/char/86169.cc b/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/char/86169.cc
index 92ba287aefe5e..5043347740031 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/char/86169.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/char/86169.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // PR libstdc++/86169
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/wchar_t/2.cc
index 7099695e739e9..fc3cc1c512cff 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/operations/data/wchar_t/2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // C++17 21.3.1.7 [string.ops] string operations
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/operations/find/char/5.cc b/libstdc++-v3/testsuite/21_strings/basic_string/operations/find/char/5.cc
index 54ab1ec9b5d21..b98d546a1b416 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/operations/find/char/5.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/operations/find/char/5.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/operations/find/wchar_t/5.cc b/libstdc++-v3/testsuite/21_strings/basic_string/operations/find/wchar_t/5.cc
index c2ce143cd96ba..5afb80a359283 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/operations/find/wchar_t/5.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/operations/find/wchar_t/5.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/operators/char/5.cc b/libstdc++-v3/testsuite/21_strings/basic_string/operators/char/5.cc
index 435a1ce7e7894..58f6967f75a40 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/operators/char/5.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/operators/char/5.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/operators/wchar_t/5.cc b/libstdc++-v3/testsuite/21_strings/basic_string/operators/wchar_t/5.cc
index d362883e95f17..e4508948c1450 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string/operators/wchar_t/5.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/operators/wchar_t/5.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/capacity/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/capacity/1.cc
index f0ae6f2de31ad..c61018174a6af 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/capacity/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/capacity/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/capacity/empty_neg.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/capacity/empty_neg.cc
index 1fda0952b0458..71fb73f3465a5 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/capacity/empty_neg.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/capacity/empty_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/1.cc
index 13d1e770c078c..8b21a8be12f57 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/2.cc
index bda4da77616cb..c4867f8f04ece 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/3.cc
index f3bf986e05832..0103e30ba8ba7 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/nonnull.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/nonnull.cc
index 6a30eacc7099b..b33af088a3d75 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/nonnull.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/char/nonnull.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -Wnonnull" }
+// { dg-options "-Wnonnull" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/1.cc
index 2e587a294bddf..783ea2326dcf1 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/2.cc
index e6b55a9f28f57..ceeed2caefa5e 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/3.cc
index 970abfd029c66..eddd5218eb3b2 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/nonnull.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/nonnull.cc
index 23928ed6b66f3..4c1013177ebd1 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/nonnull.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/cons/wchar_t/nonnull.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -Wnonnull" }
+// { dg-options "-Wnonnull" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/1.cc
index 80b46ed88cd99..7551f71b91c1d 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/2.cc
index 1604b5e8229cc..2c74568aebf95 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/2.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -O0" }
+// { dg-options "-O0" }
 // { dg-do run { target c++17 } }
 // { dg-require-debug-mode "" }
 // { dg-xfail-run-if "expect debug mode assertion to fail" { *-*-* } }
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/back_constexpr_neg.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/back_constexpr_neg.cc
index 427eefbd9ee41..0f731c9a4856d 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/back_constexpr_neg.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/back_constexpr_neg.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_ASSERTIONS" }
+// { dg-options "-D_GLIBCXX_ASSERTIONS" }
 // { dg-do compile { target c++17 xfail *-*-* } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/constexpr.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/constexpr.cc
index 9596c83154e4f..f8f9de9667a6c 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/constexpr.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/constexpr.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/constexpr_neg.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/constexpr_neg.cc
index 85fcd0c63c63c..5dd206f1a2964 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/constexpr_neg.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/constexpr_neg.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_ASSERTIONS" }
+// { dg-options "-D_GLIBCXX_ASSERTIONS" }
 // { dg-do compile { target c++17 xfail *-*-* } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/empty.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/empty.cc
index 748429cb5c911..3be7e6c744810 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/empty.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/empty.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_back.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_back.cc
index b7b5e4eba087e..a8a68c3115f31 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_back.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_back.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-string-conversions "" }
 
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_back_constexpr.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_back_constexpr.cc
index d4a04be0652b0..03190554a2f32 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_back_constexpr.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_back_constexpr.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_constexpr_neg.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_constexpr_neg.cc
index 40d3b2648ce13..9c846116bb928 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_constexpr_neg.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/char/front_constexpr_neg.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_ASSERTIONS" }
+// { dg-options "-D_GLIBCXX_ASSERTIONS" }
 // { dg-do compile { target c++17 xfail *-*-* } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/1.cc
index 88f887da20f59..aec3df446d89f 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/2.cc
index f0fda1744adee..aeae1a2bef676 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/2.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -O0" }
+// { dg-options "-O0" }
 // { dg-do run { target c++17 } }
 // { dg-require-debug-mode "" }
 // { dg-xfail-run-if "expect debug mode assertion to fail" { *-*-* } }
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/back_constexpr_neg.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/back_constexpr_neg.cc
index e1d7236931c4a..26d2d4da54b2f 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/back_constexpr_neg.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/back_constexpr_neg.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_ASSERTIONS" }
+// { dg-options "-D_GLIBCXX_ASSERTIONS" }
 // { dg-do compile { target c++17 xfail *-*-* } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr.cc
index 4ed3742fefa88..11a759ccbc231 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr_neg.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr_neg.cc
index 664652c5bfa2d..c853dada7dc72 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr_neg.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr_neg.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_ASSERTIONS" }
+// { dg-options "-D_GLIBCXX_ASSERTIONS" }
 // { dg-do compile { target c++17 xfail *-*-* } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/empty.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/empty.cc
index cab5bc9be12b8..b5f10f426c874 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/empty.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/empty.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/front_back.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/front_back.cc
index d67a29b1b6a06..8197f7ee072b9 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/front_back.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/front_back.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-string-conversions "" }
 
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/front_constexpr_neg.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/front_constexpr_neg.cc
index bd32d88482acf..fdcabd7363d26 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/front_constexpr_neg.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/element_access/wchar_t/front_constexpr_neg.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -D_GLIBCXX_ASSERTIONS" }
+// { dg-options "-D_GLIBCXX_ASSERTIONS" }
 // { dg-do compile { target c++17 xfail *-*-* } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/include.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/include.cc
index 6dea6c4b44ba3..e913254059181 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/include.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/include.cc
@@ -19,7 +19,7 @@
 
 // NB: This issue affected only debug-mode.
 
-// { dg-options "-std=gnu++17 -fno-rtti" }
+// { dg-options "-fno-rtti" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/94051.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/94051.cc
index 74c3b22936b01..60416dcbe3e0e 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/94051.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/94051.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <iosfwd>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/1.cc
index 895fc9d168b33..15ceeddf9303e 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/2.cc
index b808cf18105da..ba1861bf065e3 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/2.cc
@@ -22,7 +22,6 @@
 // working, not to mention other major details like char_traits, and
 // all of the string_view class.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-fileio "" }
 
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/3.cc
index ec1bb5dc2390c..eca66f652ed95 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/char/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/pod/10081-out.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/pod/10081-out.cc
index 3dd056a985378..4dc9dd75139f3 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/pod/10081-out.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/pod/10081-out.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/1.cc
index 25177768cd91b..35b7689c31887 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/2.cc
index 2f424f27cec24..566517d2303bd 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-fileio "" }
 
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/3.cc
index cfcb8e84d207a..08260a08e4b0b 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/inserters/wchar_t/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/types-char8_t.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/types-char8_t.cc
index 3086f28262f56..60713667c91be 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/types-char8_t.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/types-char8_t.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -fchar8_t" }
+// { dg-options "-fchar8_t" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/types.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/types.cc
index 9a30a6cabeed2..8a562f0cf11a5 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/types.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/types.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/values-char8_t.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/values-char8_t.cc
index a491a4e9bf751..04550d6e669db 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/values-char8_t.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/values-char8_t.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -fchar8_t" }
+// { dg-options "-fchar8_t" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/values.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/values.cc
index 447b12050e9d0..79033d8d7eab5 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/values.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/literals/values.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/char/1.cc
index 112ff072a846a..3ef4fe22a1fd1 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/wchar_t/1.cc
index 3ff036fcb9b62..ef1a26e8d9e5f 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/char/1.cc
index 7fe9c41227b2b..5e49949a749dc 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/wchar_t/1.cc
index c546c11387504..38e6770ef391a 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc
index 3688c66944ddd..d4547cfeda7d0 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc
index 898faba8e5985..0e4091fb6c49c 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/1.cc
index 5d64081ae8cf9..79baca278b4d8 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/13650.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/13650.cc
index e58c94133a408..06a18b52b99c4 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/13650.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/13650.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/2.cc
index 0d46eddcea0f6..76f398cdf466c 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/70483.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/70483.cc
index b506111182046..4cd71d6d67723 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/70483.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/70483.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/nonnull.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/nonnull.cc
index 17ee76bbc6d73..6cbd79ba334be 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/nonnull.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/nonnull.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -Wnonnull" }
+// { dg-options "-Wnonnull" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/1.cc
index 978e70fc80156..25132a5a371db 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/13650.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/13650.cc
index f550ab1c76e62..79c3d6351d7da 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/13650.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/13650.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/2.cc
index 686838f6e5437..4d0db13f73d29 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/char/1.cc
index 3cca58caeb476..cfd2d56d93b01 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/char/2.cc
index 932918c6a1244..6505f32fb4c4d 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/char/2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/wchar_t/1.cc
index f96a7df0fccad..d9482100ae21d 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/wchar_t/2.cc
index 0031a4c5cae6e..9240e3ad952b4 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/copy/wchar_t/2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/data/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/data/char/1.cc
index 8a0dfd990bb9b..cce1105c2552d 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/data/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/data/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2014 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/data/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/data/wchar_t/1.cc
index f4c9a51cd50fa..6c6aee2efb7d8 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/data/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/data/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2014 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/1.cc
index 054329031f568..8e5692aa78cbd 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/2.cc
index 750de8f8e9391..185ee3e954722 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/3.cc
index 99d717c2f42f4..dc84c7d03ecd8 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/4.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/4.cc
index 61b6a4d7da2a7..ac635dc8527e3 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/4.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/nonnull.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/nonnull.cc
index 8e3edd02c3e1c..257bdcaf15e4e 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/nonnull.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/nonnull.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -Wnonnull" }
+// { dg-options "-Wnonnull" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc
index 63e6eaaf7d5f7..e4be1aacd3c93 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc
index 70013e7fbcdc1..5bdf21070424d 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc
index 24cd37271d4b1..1e12923f083ad 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/4.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/4.cc
index c873d2d414791..09e02e02e3458 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/4.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/4.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/1.cc
index 909ca9693e19b..03133b6875496 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/2.cc
index 5040750c80f01..a21e0de8303dc 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/3.cc
index f1eedc237d1d6..701b7226aa83f 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/nonnull.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/nonnull.cc
index e75e96f678e08..a2f2bf9672055 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/nonnull.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/char/nonnull.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -Wnonnull" }
+// { dg-options "-Wnonnull" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/1.cc
index 38bf2c93afcff..1521ff5e359bb 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/2.cc
index edf62afdc184e..fd4e16085e419 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/3.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/3.cc
index f67c2d76b7bad..0c5e2de06068a 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/3.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/3.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/string_conversion/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/string_conversion/1.cc
index 7125b41ae8f9d..4b8abb9d387d1 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/string_conversion/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/string_conversion/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/char/1.cc
index 4c6779c49f534..1bf4de383a766 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/char/83511.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/char/83511.cc
index 29514ecec94ae..c287f9b98acc1 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/char/83511.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/char/83511.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/wchar_t/1.cc
index f801cc188ffe1..a1cc6ea46badb 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/wchar_t/83511.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/wchar_t/83511.cc
index f7e05e6f9e7d0..b8d53dfa07d47 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/wchar_t/83511.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operations/substr/wchar_t/83511.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/2.cc
index 43bc49e44e50a..ef11c5e9819b4 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/89446.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/89446.cc
index 61e3051f292b7..3d21df83fb6aa 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/89446.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/89446.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -fexceptions -fnon-call-exceptions -O1" }
+// { dg-options "-fexceptions -fnon-call-exceptions -O1" }
 // { dg-do run { target { powerpc*-*-linux* i?86-*-linux* x86_64-*-linux* } } }
 // { dg-require-effective-target c++17 }
 
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc
index e032c76bb61a5..f3394784adbf8 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/89446.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/89446.cc
index 2f3131f7fe991..d593627b4d178 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/89446.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/89446.cc
@@ -15,7 +15,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17 -fexceptions -fnon-call-exceptions -O1" }
+// { dg-options "-fexceptions -fnon-call-exceptions -O1" }
 // { dg-do run { target { powerpc*-*-linux* i?86-*-linux* x86_64-*-linux* } } }
 // { dg-require-effective-target c++17 }
 
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/char/1.cc
index 3d398f48b5c59..856aafde55296 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc
index e557109af0ca6..c6d83c47bfdb8 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/1.cc
index 7457cfaa4bcff..664fa07fd4ff3 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/1.cc
@@ -20,7 +20,6 @@
 
 #include <string_view>
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 template class std::basic_string_view<int, std::char_traits<int>>;
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char/1.cc
index 3b050020ba03f..b5b246f716940 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char16_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char16_t/1.cc
index c444632ac52d4..abf26e1c4d7a0 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char16_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char16_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char32_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char32_t/1.cc
index 91bff846530ec..7f4956a289a36 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char32_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char32_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char8_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char8_t/1.cc
index 0206aca00dd1e..5b216c94a026a 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char8_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char8_t/1.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -fchar8_t" }
+// { dg-options "-fchar8_t" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/wchar_t/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/wchar_t/1.cc
index f8c248da95f34..f8f9637c75023 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/wchar_t/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/wchar_t/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/traits_neg.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/traits_neg.cc
index ecc12db0b864b..a6cdf91efa504 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/traits_neg.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/traits_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/typedefs.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/typedefs.cc
index 1171d3379faaf..a3282fb032342 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/requirements/typedefs.cc
@@ -1,5 +1,4 @@
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2013-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/typedefs.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/typedefs.cc
index 855d3201a0e0f..26cbc20350195 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/typedefs.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string_view/types/1.cc b/libstdc++-v3/testsuite/21_strings/basic_string_view/types/1.cc
index 6de859de3a8c5..f9d16acd786e2 100644
--- a/libstdc++-v3/testsuite/21_strings/basic_string_view/types/1.cc
+++ b/libstdc++-v3/testsuite/21_strings/basic_string_view/types/1.cc
@@ -17,7 +17,6 @@
 // <http://www.gnu.org/licenses/>.
 //
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <string_view>
diff --git a/libstdc++-v3/testsuite/21_strings/char_traits/requirements/char/99181.cc b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/char/99181.cc
index 01a70da046c53..af690fcb5253a 100644
--- a/libstdc++-v3/testsuite/21_strings/char_traits/requirements/char/99181.cc
+++ b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/char/99181.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc
index 32e31e13abbaf..7db31031b8ac3 100644
--- a/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc
+++ b/libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.

From 24eeefa9e41d130c5fb10a7074a20cddcbc592fc Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 16:22:53 +0100
Subject: [PATCH 098/164] libstdc++: Remove redundant -std=gnu++17 option from
 containers tests

GCC defaults to -std=gnu++17 now anyway, and using it explicitly in the
dg-options directive prevents running these tests with different modes
such as -std=c++17 or -std=gnu++20.

libstdc++-v3/ChangeLog:

	* testsuite/23_containers/array/cons/deduction.cc: Remove
	-std=gnu++17 from dg-options directive.
	* testsuite/23_containers/array/cons/deduction_neg.cc: Likewise.
	* testsuite/23_containers/array/element_access/constexpr_c++17.cc:
	Likewise.
	* testsuite/23_containers/array/requirements/constexpr_iter.cc:
	Likewise.
	* testsuite/23_containers/array/specialized_algorithms/swap_cxx17.cc:
	Likewise.
	* testsuite/23_containers/deque/cons/deduction.cc: Likewise.
	* testsuite/23_containers/deque/modifiers/emplace/cxx17_return.cc:
	Likewise.
	* testsuite/23_containers/forward_list/cons/deduction.cc:
	Likewise.
	* testsuite/23_containers/forward_list/modifiers/emplace_cxx17_return.cc:
	Likewise.
	* testsuite/23_containers/list/cons/deduction.cc: Likewise.
	* testsuite/23_containers/list/modifiers/emplace/cxx17_return.cc:
	Likewise.
	* testsuite/23_containers/map/cons/deduction.cc: Likewise.
	* testsuite/23_containers/map/modifiers/extract.cc: Likewise.
	* testsuite/23_containers/map/modifiers/insert/83226.cc:
	Likewise.
	* testsuite/23_containers/map/modifiers/insert_or_assign/1.cc:
	Likewise.
	* testsuite/23_containers/map/modifiers/merge.cc: Likewise.
	* testsuite/23_containers/map/modifiers/try_emplace/1.cc:
	Likewise.
	* testsuite/23_containers/multimap/cons/deduction.cc: Likewise.
	* testsuite/23_containers/multimap/modifiers/extract.cc:
	Likewise.
	* testsuite/23_containers/multimap/modifiers/merge.cc: Likewise.
	* testsuite/23_containers/multiset/cons/deduction.cc: Likewise.
	* testsuite/23_containers/multiset/modifiers/extract.cc:
	Likewise.
	* testsuite/23_containers/multiset/modifiers/merge.cc: Likewise.
	* testsuite/23_containers/priority_queue/deduction.cc: Likewise.
	* testsuite/23_containers/queue/deduction.cc: Likewise.
	* testsuite/23_containers/queue/members/emplace_cxx17_return.cc:
	Likewise.
	* testsuite/23_containers/set/cons/deduction.cc: Likewise.
	* testsuite/23_containers/set/modifiers/extract.cc: Likewise.
	* testsuite/23_containers/set/modifiers/merge.cc: Likewise.
	* testsuite/23_containers/set/modifiers/node_swap.cc: Likewise.
	* testsuite/23_containers/stack/deduction.cc: Likewise.
	* testsuite/23_containers/stack/members/emplace_cxx17_return.cc:
	Likewise.
	* testsuite/23_containers/unordered_map/cons/deduction.cc:
	Likewise.
	* testsuite/23_containers/unordered_map/modifiers/extract.cc:
	Likewise.
	* testsuite/23_containers/unordered_map/modifiers/insert_or_assign.cc:
	Likewise.
	* testsuite/23_containers/unordered_map/modifiers/merge.cc:
	Likewise.
	* testsuite/23_containers/unordered_map/modifiers/try_emplace.cc:
	Likewise.
	* testsuite/23_containers/unordered_multimap/cons/deduction.cc:
	Likewise.
	* testsuite/23_containers/unordered_multimap/modifiers/extract.cc:
	Likewise.
	* testsuite/23_containers/unordered_multimap/modifiers/merge.cc:
	Likewise.
	* testsuite/23_containers/unordered_multiset/cons/deduction.cc:
	Likewise.
	* testsuite/23_containers/unordered_multiset/modifiers/extract.cc:
	Likewise.
	* testsuite/23_containers/unordered_multiset/modifiers/merge.cc:
	Likewise.
	* testsuite/23_containers/unordered_set/cons/deduction.cc:
	Likewise.
	* testsuite/23_containers/unordered_set/modifiers/extract.cc:
	Likewise.
	* testsuite/23_containers/unordered_set/modifiers/merge.cc:
	Likewise.
	* testsuite/23_containers/vector/bool/emplace_cxx17_return.cc:
	Likewise.
	* testsuite/23_containers/vector/cons/89164_c++17.cc: Likewise.
	* testsuite/23_containers/vector/cons/deduction.cc: Likewise.
	* testsuite/23_containers/vector/modifiers/emplace/cxx17_return.cc:
	Likewise.

(cherry picked from commit 7c85abec763095045ba3f78c6656117dd8f1fd01)
---
 libstdc++-v3/testsuite/23_containers/array/cons/deduction.cc   | 1 -
 .../testsuite/23_containers/array/cons/deduction_neg.cc        | 3 +--
 .../23_containers/array/element_access/constexpr_c++17.cc      | 1 -
 .../23_containers/array/requirements/constexpr_iter.cc         | 1 -
 .../23_containers/array/specialized_algorithms/swap_cxx17.cc   | 1 -
 libstdc++-v3/testsuite/23_containers/deque/cons/deduction.cc   | 1 -
 .../23_containers/deque/modifiers/emplace/cxx17_return.cc      | 1 -
 .../testsuite/23_containers/forward_list/cons/deduction.cc     | 1 -
 .../forward_list/modifiers/emplace_cxx17_return.cc             | 1 -
 libstdc++-v3/testsuite/23_containers/list/cons/deduction.cc    | 1 -
 .../23_containers/list/modifiers/emplace/cxx17_return.cc       | 1 -
 libstdc++-v3/testsuite/23_containers/map/cons/deduction.cc     | 1 -
 libstdc++-v3/testsuite/23_containers/map/modifiers/extract.cc  | 1 -
 .../testsuite/23_containers/map/modifiers/insert/83226.cc      | 1 -
 .../23_containers/map/modifiers/insert_or_assign/1.cc          | 1 -
 libstdc++-v3/testsuite/23_containers/map/modifiers/merge.cc    | 1 -
 .../testsuite/23_containers/map/modifiers/try_emplace/1.cc     | 1 -
 .../testsuite/23_containers/multimap/cons/deduction.cc         | 1 -
 .../testsuite/23_containers/multimap/modifiers/extract.cc      | 1 -
 .../testsuite/23_containers/multimap/modifiers/merge.cc        | 1 -
 .../testsuite/23_containers/multiset/cons/deduction.cc         | 1 -
 .../testsuite/23_containers/multiset/modifiers/extract.cc      | 1 -
 .../testsuite/23_containers/multiset/modifiers/merge.cc        | 1 -
 .../testsuite/23_containers/priority_queue/deduction.cc        | 1 -
 libstdc++-v3/testsuite/23_containers/queue/deduction.cc        | 1 -
 .../23_containers/queue/members/emplace_cxx17_return.cc        | 1 -
 libstdc++-v3/testsuite/23_containers/set/cons/deduction.cc     | 1 -
 libstdc++-v3/testsuite/23_containers/set/modifiers/extract.cc  | 1 -
 libstdc++-v3/testsuite/23_containers/set/modifiers/merge.cc    | 1 -
 .../testsuite/23_containers/set/modifiers/node_swap.cc         | 1 -
 libstdc++-v3/testsuite/23_containers/stack/deduction.cc        | 1 -
 .../23_containers/stack/members/emplace_cxx17_return.cc        | 1 -
 .../testsuite/23_containers/unordered_map/cons/deduction.cc    | 1 -
 .../testsuite/23_containers/unordered_map/modifiers/extract.cc | 1 -
 .../23_containers/unordered_map/modifiers/insert_or_assign.cc  | 1 -
 .../testsuite/23_containers/unordered_map/modifiers/merge.cc   | 1 -
 .../23_containers/unordered_map/modifiers/try_emplace.cc       | 1 -
 .../23_containers/unordered_multimap/cons/deduction.cc         | 1 -
 .../23_containers/unordered_multimap/modifiers/extract.cc      | 1 -
 .../23_containers/unordered_multimap/modifiers/merge.cc        | 1 -
 .../23_containers/unordered_multiset/cons/deduction.cc         | 1 -
 .../23_containers/unordered_multiset/modifiers/extract.cc      | 1 -
 .../23_containers/unordered_multiset/modifiers/merge.cc        | 1 -
 .../testsuite/23_containers/unordered_set/cons/deduction.cc    | 1 -
 .../testsuite/23_containers/unordered_set/modifiers/extract.cc | 1 -
 .../testsuite/23_containers/unordered_set/modifiers/merge.cc   | 1 -
 .../23_containers/vector/bool/emplace_cxx17_return.cc          | 1 -
 .../testsuite/23_containers/vector/cons/89164_c++17.cc         | 1 -
 libstdc++-v3/testsuite/23_containers/vector/cons/deduction.cc  | 1 -
 .../23_containers/vector/modifiers/emplace/cxx17_return.cc     | 1 -
 50 files changed, 1 insertion(+), 51 deletions(-)

diff --git a/libstdc++-v3/testsuite/23_containers/array/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/array/cons/deduction.cc
index 5697e3e0fddd7..00fe19281438b 100644
--- a/libstdc++-v3/testsuite/23_containers/array/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/array/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <array>
diff --git a/libstdc++-v3/testsuite/23_containers/array/cons/deduction_neg.cc b/libstdc++-v3/testsuite/23_containers/array/cons/deduction_neg.cc
index c85ffe5324f78..f4471a2d33767 100644
--- a/libstdc++-v3/testsuite/23_containers/array/cons/deduction_neg.cc
+++ b/libstdc++-v3/testsuite/23_containers/array/cons/deduction_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <array>
@@ -26,6 +25,6 @@ test01()
   std::array a1{}; // { dg-error "class template argument deduction failed" }
   std::array a2{1, 2u, 3}; // { dg-error "class template argument deduction failed" }
 }
+// { dg-error "no matching function for call" "" { target *-*-* } 25 }
 // { dg-error "no matching function for call" "" { target *-*-* } 26 }
-// { dg-error "no matching function for call" "" { target *-*-* } 27 }
 // { dg-error "no type named .*enable_if" "" { target *-*-* } 0 }
diff --git a/libstdc++-v3/testsuite/23_containers/array/element_access/constexpr_c++17.cc b/libstdc++-v3/testsuite/23_containers/array/element_access/constexpr_c++17.cc
index 37dd539f4c4c2..1b1c41b92b040 100644
--- a/libstdc++-v3/testsuite/23_containers/array/element_access/constexpr_c++17.cc
+++ b/libstdc++-v3/testsuite/23_containers/array/element_access/constexpr_c++17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2011-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/23_containers/array/requirements/constexpr_iter.cc b/libstdc++-v3/testsuite/23_containers/array/requirements/constexpr_iter.cc
index 584019889287c..f1662cd28f709 100644
--- a/libstdc++-v3/testsuite/23_containers/array/requirements/constexpr_iter.cc
+++ b/libstdc++-v3/testsuite/23_containers/array/requirements/constexpr_iter.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 //
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/23_containers/array/specialized_algorithms/swap_cxx17.cc b/libstdc++-v3/testsuite/23_containers/array/specialized_algorithms/swap_cxx17.cc
index 9129a1c180780..f10d9f01e17e8 100644
--- a/libstdc++-v3/testsuite/23_containers/array/specialized_algorithms/swap_cxx17.cc
+++ b/libstdc++-v3/testsuite/23_containers/array/specialized_algorithms/swap_cxx17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/23_containers/deque/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/deque/cons/deduction.cc
index 8fd3b051696ed..8a38351e52421 100644
--- a/libstdc++-v3/testsuite/23_containers/deque/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/deque/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <deque>
diff --git a/libstdc++-v3/testsuite/23_containers/deque/modifiers/emplace/cxx17_return.cc b/libstdc++-v3/testsuite/23_containers/deque/modifiers/emplace/cxx17_return.cc
index 5987d7b055ed4..659b84a2ccf72 100644
--- a/libstdc++-v3/testsuite/23_containers/deque/modifiers/emplace/cxx17_return.cc
+++ b/libstdc++-v3/testsuite/23_containers/deque/modifiers/emplace/cxx17_return.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <deque>
diff --git a/libstdc++-v3/testsuite/23_containers/forward_list/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/forward_list/cons/deduction.cc
index 59fe68c9f13a9..eb39682f483be 100644
--- a/libstdc++-v3/testsuite/23_containers/forward_list/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/forward_list/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <forward_list>
diff --git a/libstdc++-v3/testsuite/23_containers/forward_list/modifiers/emplace_cxx17_return.cc b/libstdc++-v3/testsuite/23_containers/forward_list/modifiers/emplace_cxx17_return.cc
index f8e2b3675a71f..fdea5ee9c866e 100644
--- a/libstdc++-v3/testsuite/23_containers/forward_list/modifiers/emplace_cxx17_return.cc
+++ b/libstdc++-v3/testsuite/23_containers/forward_list/modifiers/emplace_cxx17_return.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <forward_list>
diff --git a/libstdc++-v3/testsuite/23_containers/list/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/list/cons/deduction.cc
index 72c38f50cff20..3ad1d3f6cb55c 100644
--- a/libstdc++-v3/testsuite/23_containers/list/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/list/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <list>
diff --git a/libstdc++-v3/testsuite/23_containers/list/modifiers/emplace/cxx17_return.cc b/libstdc++-v3/testsuite/23_containers/list/modifiers/emplace/cxx17_return.cc
index 19a1a176da243..e8418b0e52c95 100644
--- a/libstdc++-v3/testsuite/23_containers/list/modifiers/emplace/cxx17_return.cc
+++ b/libstdc++-v3/testsuite/23_containers/list/modifiers/emplace/cxx17_return.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <list>
diff --git a/libstdc++-v3/testsuite/23_containers/map/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/map/cons/deduction.cc
index a42d8d6b8810b..e9628c4ac32b5 100644
--- a/libstdc++-v3/testsuite/23_containers/map/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/map/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <map>
diff --git a/libstdc++-v3/testsuite/23_containers/map/modifiers/extract.cc b/libstdc++-v3/testsuite/23_containers/map/modifiers/extract.cc
index 541496211a758..e078d53e1651f 100644
--- a/libstdc++-v3/testsuite/23_containers/map/modifiers/extract.cc
+++ b/libstdc++-v3/testsuite/23_containers/map/modifiers/extract.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <map>
diff --git a/libstdc++-v3/testsuite/23_containers/map/modifiers/insert/83226.cc b/libstdc++-v3/testsuite/23_containers/map/modifiers/insert/83226.cc
index aa0f089ae2838..97b526b995d97 100644
--- a/libstdc++-v3/testsuite/23_containers/map/modifiers/insert/83226.cc
+++ b/libstdc++-v3/testsuite/23_containers/map/modifiers/insert/83226.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <map>
diff --git a/libstdc++-v3/testsuite/23_containers/map/modifiers/insert_or_assign/1.cc b/libstdc++-v3/testsuite/23_containers/map/modifiers/insert_or_assign/1.cc
index 52618d9ecfb3e..5056a2e5316f9 100644
--- a/libstdc++-v3/testsuite/23_containers/map/modifiers/insert_or_assign/1.cc
+++ b/libstdc++-v3/testsuite/23_containers/map/modifiers/insert_or_assign/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/23_containers/map/modifiers/merge.cc b/libstdc++-v3/testsuite/23_containers/map/modifiers/merge.cc
index 326104e1283d8..4674f9e1ca56a 100644
--- a/libstdc++-v3/testsuite/23_containers/map/modifiers/merge.cc
+++ b/libstdc++-v3/testsuite/23_containers/map/modifiers/merge.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <map>
diff --git a/libstdc++-v3/testsuite/23_containers/map/modifiers/try_emplace/1.cc b/libstdc++-v3/testsuite/23_containers/map/modifiers/try_emplace/1.cc
index 137f4635f1319..ef92254305b2a 100644
--- a/libstdc++-v3/testsuite/23_containers/map/modifiers/try_emplace/1.cc
+++ b/libstdc++-v3/testsuite/23_containers/map/modifiers/try_emplace/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/23_containers/multimap/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/multimap/cons/deduction.cc
index 2f9373a5befd0..791cc96347989 100644
--- a/libstdc++-v3/testsuite/23_containers/multimap/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/multimap/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <map>
diff --git a/libstdc++-v3/testsuite/23_containers/multimap/modifiers/extract.cc b/libstdc++-v3/testsuite/23_containers/multimap/modifiers/extract.cc
index c365e788b8eef..4fe53b6134ee3 100644
--- a/libstdc++-v3/testsuite/23_containers/multimap/modifiers/extract.cc
+++ b/libstdc++-v3/testsuite/23_containers/multimap/modifiers/extract.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <map>
diff --git a/libstdc++-v3/testsuite/23_containers/multimap/modifiers/merge.cc b/libstdc++-v3/testsuite/23_containers/multimap/modifiers/merge.cc
index 9c8b1b64cd67f..ec0ca500b3b65 100644
--- a/libstdc++-v3/testsuite/23_containers/multimap/modifiers/merge.cc
+++ b/libstdc++-v3/testsuite/23_containers/multimap/modifiers/merge.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <map>
diff --git a/libstdc++-v3/testsuite/23_containers/multiset/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/multiset/cons/deduction.cc
index 6fe2704da179d..ad12755ccc69e 100644
--- a/libstdc++-v3/testsuite/23_containers/multiset/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/multiset/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <set>
diff --git a/libstdc++-v3/testsuite/23_containers/multiset/modifiers/extract.cc b/libstdc++-v3/testsuite/23_containers/multiset/modifiers/extract.cc
index f508fb323c10e..012f58c05329b 100644
--- a/libstdc++-v3/testsuite/23_containers/multiset/modifiers/extract.cc
+++ b/libstdc++-v3/testsuite/23_containers/multiset/modifiers/extract.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <set>
diff --git a/libstdc++-v3/testsuite/23_containers/multiset/modifiers/merge.cc b/libstdc++-v3/testsuite/23_containers/multiset/modifiers/merge.cc
index d70c9990aa8f8..50464d534ddd4 100644
--- a/libstdc++-v3/testsuite/23_containers/multiset/modifiers/merge.cc
+++ b/libstdc++-v3/testsuite/23_containers/multiset/modifiers/merge.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <set>
diff --git a/libstdc++-v3/testsuite/23_containers/priority_queue/deduction.cc b/libstdc++-v3/testsuite/23_containers/priority_queue/deduction.cc
index b18a2ebb609c1..05c4c570ad568 100644
--- a/libstdc++-v3/testsuite/23_containers/priority_queue/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/priority_queue/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <queue>
diff --git a/libstdc++-v3/testsuite/23_containers/queue/deduction.cc b/libstdc++-v3/testsuite/23_containers/queue/deduction.cc
index 7b3a0e0d48e48..ab28f83aa2bec 100644
--- a/libstdc++-v3/testsuite/23_containers/queue/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/queue/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <queue>
diff --git a/libstdc++-v3/testsuite/23_containers/queue/members/emplace_cxx17_return.cc b/libstdc++-v3/testsuite/23_containers/queue/members/emplace_cxx17_return.cc
index 1be450a36b7b3..8851e64ed609f 100644
--- a/libstdc++-v3/testsuite/23_containers/queue/members/emplace_cxx17_return.cc
+++ b/libstdc++-v3/testsuite/23_containers/queue/members/emplace_cxx17_return.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <queue>
diff --git a/libstdc++-v3/testsuite/23_containers/set/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/set/cons/deduction.cc
index df89fa28dd008..89a2c43b9376d 100644
--- a/libstdc++-v3/testsuite/23_containers/set/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/set/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <set>
diff --git a/libstdc++-v3/testsuite/23_containers/set/modifiers/extract.cc b/libstdc++-v3/testsuite/23_containers/set/modifiers/extract.cc
index 713502e0bfdc9..8ef539042f3e8 100644
--- a/libstdc++-v3/testsuite/23_containers/set/modifiers/extract.cc
+++ b/libstdc++-v3/testsuite/23_containers/set/modifiers/extract.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <set>
diff --git a/libstdc++-v3/testsuite/23_containers/set/modifiers/merge.cc b/libstdc++-v3/testsuite/23_containers/set/modifiers/merge.cc
index 60313d4752ae4..d5a81a1dfc781 100644
--- a/libstdc++-v3/testsuite/23_containers/set/modifiers/merge.cc
+++ b/libstdc++-v3/testsuite/23_containers/set/modifiers/merge.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <set>
diff --git a/libstdc++-v3/testsuite/23_containers/set/modifiers/node_swap.cc b/libstdc++-v3/testsuite/23_containers/set/modifiers/node_swap.cc
index 1fdfc5b0de315..baf5f01845521 100644
--- a/libstdc++-v3/testsuite/23_containers/set/modifiers/node_swap.cc
+++ b/libstdc++-v3/testsuite/23_containers/set/modifiers/node_swap.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <set>
diff --git a/libstdc++-v3/testsuite/23_containers/stack/deduction.cc b/libstdc++-v3/testsuite/23_containers/stack/deduction.cc
index d746fb0986d4e..db8e31e2bdaae 100644
--- a/libstdc++-v3/testsuite/23_containers/stack/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/stack/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <stack>
diff --git a/libstdc++-v3/testsuite/23_containers/stack/members/emplace_cxx17_return.cc b/libstdc++-v3/testsuite/23_containers/stack/members/emplace_cxx17_return.cc
index 6a07fd636b39b..cb053ed742854 100644
--- a/libstdc++-v3/testsuite/23_containers/stack/members/emplace_cxx17_return.cc
+++ b/libstdc++-v3/testsuite/23_containers/stack/members/emplace_cxx17_return.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <stack>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_map/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/unordered_map/cons/deduction.cc
index 979a56c949766..d8489b23f8a0c 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_map/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_map/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <unordered_map>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/extract.cc b/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/extract.cc
index a52e6d969bd23..41b1f025b8530 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/extract.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/extract.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <unordered_map>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/insert_or_assign.cc b/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/insert_or_assign.cc
index 1d1af9cd2db81..13e0c0b96b382 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/insert_or_assign.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/insert_or_assign.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/merge.cc b/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/merge.cc
index a51f175b42238..9ea4865310a1b 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/merge.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/merge.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <unordered_map>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/try_emplace.cc b/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/try_emplace.cc
index eb72ad2a1ba65..f8211654682a8 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/try_emplace.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_map/modifiers/try_emplace.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multimap/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/unordered_multimap/cons/deduction.cc
index 72b2d07149aa0..13f54d4345106 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multimap/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multimap/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <unordered_map>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multimap/modifiers/extract.cc b/libstdc++-v3/testsuite/23_containers/unordered_multimap/modifiers/extract.cc
index 93771a69084e4..408df682a9be0 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multimap/modifiers/extract.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multimap/modifiers/extract.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <unordered_map>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multimap/modifiers/merge.cc b/libstdc++-v3/testsuite/23_containers/unordered_multimap/modifiers/merge.cc
index d98140d0c31ef..dc4423ac5c1ef 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multimap/modifiers/merge.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multimap/modifiers/merge.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <unordered_map>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multiset/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/unordered_multiset/cons/deduction.cc
index fa895d7ff5490..1850237e44c15 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multiset/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multiset/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <unordered_set>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multiset/modifiers/extract.cc b/libstdc++-v3/testsuite/23_containers/unordered_multiset/modifiers/extract.cc
index 2e1071d095cef..4ac843af2c0ec 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multiset/modifiers/extract.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multiset/modifiers/extract.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <unordered_set>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_multiset/modifiers/merge.cc b/libstdc++-v3/testsuite/23_containers/unordered_multiset/modifiers/merge.cc
index 7765f3ed4cbc3..1ed2ce234a19c 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_multiset/modifiers/merge.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_multiset/modifiers/merge.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <unordered_set>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_set/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/unordered_set/cons/deduction.cc
index 61f21d2b1f42f..a745dce0fbae1 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_set/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_set/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <unordered_set>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_set/modifiers/extract.cc b/libstdc++-v3/testsuite/23_containers/unordered_set/modifiers/extract.cc
index ca5f4ec165310..817b2a14b39ca 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_set/modifiers/extract.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_set/modifiers/extract.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <unordered_set>
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_set/modifiers/merge.cc b/libstdc++-v3/testsuite/23_containers/unordered_set/modifiers/merge.cc
index 7cc2ce11cee04..c9c8a60fd5400 100644
--- a/libstdc++-v3/testsuite/23_containers/unordered_set/modifiers/merge.cc
+++ b/libstdc++-v3/testsuite/23_containers/unordered_set/modifiers/merge.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <unordered_set>
diff --git a/libstdc++-v3/testsuite/23_containers/vector/bool/emplace_cxx17_return.cc b/libstdc++-v3/testsuite/23_containers/vector/bool/emplace_cxx17_return.cc
index b3668824576ef..393adffb8f305 100644
--- a/libstdc++-v3/testsuite/23_containers/vector/bool/emplace_cxx17_return.cc
+++ b/libstdc++-v3/testsuite/23_containers/vector/bool/emplace_cxx17_return.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <vector>
diff --git a/libstdc++-v3/testsuite/23_containers/vector/cons/89164_c++17.cc b/libstdc++-v3/testsuite/23_containers/vector/cons/89164_c++17.cc
index 76f1378f89b2b..78aadc4798b3f 100644
--- a/libstdc++-v3/testsuite/23_containers/vector/cons/89164_c++17.cc
+++ b/libstdc++-v3/testsuite/23_containers/vector/cons/89164_c++17.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <vector>
diff --git a/libstdc++-v3/testsuite/23_containers/vector/cons/deduction.cc b/libstdc++-v3/testsuite/23_containers/vector/cons/deduction.cc
index 7e6775b67f803..9f7b7612c93c4 100644
--- a/libstdc++-v3/testsuite/23_containers/vector/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/23_containers/vector/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <vector>
diff --git a/libstdc++-v3/testsuite/23_containers/vector/modifiers/emplace/cxx17_return.cc b/libstdc++-v3/testsuite/23_containers/vector/modifiers/emplace/cxx17_return.cc
index 0f425248d90fa..28aa00f5b8d2a 100644
--- a/libstdc++-v3/testsuite/23_containers/vector/modifiers/emplace/cxx17_return.cc
+++ b/libstdc++-v3/testsuite/23_containers/vector/modifiers/emplace/cxx17_return.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <vector>

From e0c05ec749ad13611e20c62c2f0295bff922212d Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 16:22:54 +0100
Subject: [PATCH 099/164] libstdc++: Remove redundant -std=gnu++17 option from
 algorithm tests

GCC defaults to -std=gnu++17 now anyway, and using it explicitly in the
dg-options directive prevents running these tests with different modes
such as -std=c++17 or -std=gnu++20.

libstdc++-v3/ChangeLog:

	* testsuite/20_util/function_objects/searchers.cc: Remove
	-std=gnu++17 from dg-options directive.
	* testsuite/20_util/specialized_algorithms/memory_management_tools/1.cc:
	Likewise.
	* testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc:
	Likewise.
	* testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94540.cc:
	Likewise.
	* testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94831.cc:
	Likewise.
	* testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/94540.cc:
	Likewise.
	* testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/sizes.cc:
	Likewise.
	* testsuite/20_util/unique_ptr/specialized_algorithms/swap_cxx17.cc:
	Likewise.
	* testsuite/25_algorithms/clamp/1.cc: Likewise.
	* testsuite/25_algorithms/clamp/2.cc: Likewise.
	* testsuite/25_algorithms/clamp/constexpr.cc: Likewise.
	* testsuite/25_algorithms/clamp/requirements/explicit_instantiation/1.cc:
	Likewise.
	* testsuite/25_algorithms/clamp/requirements/explicit_instantiation/pod.cc:
	Likewise.
	* testsuite/25_algorithms/for_each/for_each_n.cc: Likewise.
	* testsuite/25_algorithms/for_each/for_each_n_debug.cc:
	Likewise.
	* testsuite/25_algorithms/sample/1.cc: Likewise.
	* testsuite/25_algorithms/sample/2.cc: Likewise.
	* testsuite/25_algorithms/sample/3.cc: Likewise.
	* testsuite/25_algorithms/sample/81221.cc: Likewise.
	* testsuite/25_algorithms/search/searcher.cc: Likewise.
	* testsuite/26_numerics/exclusive_scan/1.cc: Likewise.
	* testsuite/26_numerics/inclusive_scan/1.cc: Likewise.
	* testsuite/26_numerics/reduce/1.cc: Likewise.
	* testsuite/26_numerics/reduce/2.cc: Likewise.
	* testsuite/26_numerics/transform_exclusive_scan/1.cc: Likewise.
	* testsuite/26_numerics/transform_inclusive_scan/1.cc: Likewise.
	* testsuite/26_numerics/transform_reduce/1.cc: Likewise.

(cherry picked from commit d7b2d92747f8d236050af3ec5741786f0f878716)
---
 libstdc++-v3/testsuite/20_util/function_objects/searchers.cc     | 1 -
 .../20_util/specialized_algorithms/memory_management_tools/1.cc  | 1 -
 .../memory_management_tools/destroy_neg.cc                       | 1 -
 .../uninitialized_value_construct/94540.cc                       | 1 -
 .../uninitialized_value_construct/94831.cc                       | 1 -
 .../uninitialized_value_construct_n/94540.cc                     | 1 -
 .../uninitialized_value_construct_n/sizes.cc                     | 1 -
 .../20_util/unique_ptr/specialized_algorithms/swap_cxx17.cc      | 1 -
 libstdc++-v3/testsuite/25_algorithms/clamp/1.cc                  | 1 -
 libstdc++-v3/testsuite/25_algorithms/clamp/2.cc                  | 1 -
 libstdc++-v3/testsuite/25_algorithms/clamp/constexpr.cc          | 1 -
 .../25_algorithms/clamp/requirements/explicit_instantiation/1.cc | 1 -
 .../clamp/requirements/explicit_instantiation/pod.cc             | 1 -
 libstdc++-v3/testsuite/25_algorithms/for_each/for_each_n.cc      | 1 -
 .../testsuite/25_algorithms/for_each/for_each_n_debug.cc         | 1 -
 libstdc++-v3/testsuite/25_algorithms/sample/1.cc                 | 1 -
 libstdc++-v3/testsuite/25_algorithms/sample/2.cc                 | 1 -
 libstdc++-v3/testsuite/25_algorithms/sample/3.cc                 | 1 -
 libstdc++-v3/testsuite/25_algorithms/sample/81221.cc             | 1 -
 libstdc++-v3/testsuite/25_algorithms/search/searcher.cc          | 1 -
 libstdc++-v3/testsuite/26_numerics/exclusive_scan/1.cc           | 1 -
 libstdc++-v3/testsuite/26_numerics/inclusive_scan/1.cc           | 1 -
 libstdc++-v3/testsuite/26_numerics/reduce/1.cc                   | 1 -
 libstdc++-v3/testsuite/26_numerics/reduce/2.cc                   | 1 -
 libstdc++-v3/testsuite/26_numerics/transform_exclusive_scan/1.cc | 1 -
 libstdc++-v3/testsuite/26_numerics/transform_inclusive_scan/1.cc | 1 -
 libstdc++-v3/testsuite/26_numerics/transform_reduce/1.cc         | 1 -
 27 files changed, 27 deletions(-)

diff --git a/libstdc++-v3/testsuite/20_util/function_objects/searchers.cc b/libstdc++-v3/testsuite/20_util/function_objects/searchers.cc
index 4f134d91e0063..f8899659cbed4 100644
--- a/libstdc++-v3/testsuite/20_util/function_objects/searchers.cc
+++ b/libstdc++-v3/testsuite/20_util/function_objects/searchers.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/1.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/1.cc
index a4a7725ce3ce8..cabed8bd46108 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/1.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc
index 626f2e1c6ee1a..e114168842e4a 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94540.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94540.cc
index 51fb18949e4a5..865f29cddbde4 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94540.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94540.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target { c++17 && { ! simulator } } } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94831.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94831.cc
index 6d9635ee6c910..8ab9df3234765 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94831.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94831.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/94540.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/94540.cc
index 9de74c29074c7..5fd4e550f75dc 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/94540.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/94540.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target { c++17 && { ! simulator } } } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/sizes.cc b/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/sizes.cc
index 5833f7ed6c308..f1f4f1f46e45c 100644
--- a/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/sizes.cc
+++ b/libstdc++-v3/testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/sizes.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/20_util/unique_ptr/specialized_algorithms/swap_cxx17.cc b/libstdc++-v3/testsuite/20_util/unique_ptr/specialized_algorithms/swap_cxx17.cc
index fdb3cf89d1314..f1c17a426940a 100644
--- a/libstdc++-v3/testsuite/20_util/unique_ptr/specialized_algorithms/swap_cxx17.cc
+++ b/libstdc++-v3/testsuite/20_util/unique_ptr/specialized_algorithms/swap_cxx17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/25_algorithms/clamp/1.cc b/libstdc++-v3/testsuite/25_algorithms/clamp/1.cc
index e4719d7a13a2f..2a24c58cee684 100644
--- a/libstdc++-v3/testsuite/25_algorithms/clamp/1.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/clamp/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/25_algorithms/clamp/2.cc b/libstdc++-v3/testsuite/25_algorithms/clamp/2.cc
index 7884ede32c3f8..23256477147f8 100644
--- a/libstdc++-v3/testsuite/25_algorithms/clamp/2.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/clamp/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2000-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/25_algorithms/clamp/constexpr.cc b/libstdc++-v3/testsuite/25_algorithms/clamp/constexpr.cc
index 2f66bf858fcee..46bf0f5a22a01 100644
--- a/libstdc++-v3/testsuite/25_algorithms/clamp/constexpr.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/clamp/constexpr.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/25_algorithms/clamp/requirements/explicit_instantiation/1.cc b/libstdc++-v3/testsuite/25_algorithms/clamp/requirements/explicit_instantiation/1.cc
index 5017aacfee7c4..b64064017cc14 100644
--- a/libstdc++-v3/testsuite/25_algorithms/clamp/requirements/explicit_instantiation/1.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/clamp/requirements/explicit_instantiation/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/25_algorithms/clamp/requirements/explicit_instantiation/pod.cc b/libstdc++-v3/testsuite/25_algorithms/clamp/requirements/explicit_instantiation/pod.cc
index 50726161bb947..2ede166c00210 100644
--- a/libstdc++-v3/testsuite/25_algorithms/clamp/requirements/explicit_instantiation/pod.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/clamp/requirements/explicit_instantiation/pod.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/25_algorithms/for_each/for_each_n.cc b/libstdc++-v3/testsuite/25_algorithms/for_each/for_each_n.cc
index 72065d181bb94..625f3782e729f 100644
--- a/libstdc++-v3/testsuite/25_algorithms/for_each/for_each_n.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/for_each/for_each_n.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/25_algorithms/for_each/for_each_n_debug.cc b/libstdc++-v3/testsuite/25_algorithms/for_each/for_each_n_debug.cc
index 24ec995d90e74..43cb98db4a4fb 100644
--- a/libstdc++-v3/testsuite/25_algorithms/for_each/for_each_n_debug.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/for_each/for_each_n_debug.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <algorithm>
diff --git a/libstdc++-v3/testsuite/25_algorithms/sample/1.cc b/libstdc++-v3/testsuite/25_algorithms/sample/1.cc
index ade52b6cf7cca..d8adfbb49b2fd 100644
--- a/libstdc++-v3/testsuite/25_algorithms/sample/1.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/sample/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-cstdint "" }
 
diff --git a/libstdc++-v3/testsuite/25_algorithms/sample/2.cc b/libstdc++-v3/testsuite/25_algorithms/sample/2.cc
index 7d42b99ecba49..8144492a3c807 100644
--- a/libstdc++-v3/testsuite/25_algorithms/sample/2.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/sample/2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-cstdint "" }
 
diff --git a/libstdc++-v3/testsuite/25_algorithms/sample/3.cc b/libstdc++-v3/testsuite/25_algorithms/sample/3.cc
index 6aeb1a97f8bac..7b20c67690e9d 100644
--- a/libstdc++-v3/testsuite/25_algorithms/sample/3.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/sample/3.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-cstdint "" }
 
diff --git a/libstdc++-v3/testsuite/25_algorithms/sample/81221.cc b/libstdc++-v3/testsuite/25_algorithms/sample/81221.cc
index 36f504c758d2c..26301627b3ce4 100644
--- a/libstdc++-v3/testsuite/25_algorithms/sample/81221.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/sample/81221.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-parallel-mode "" }
 
diff --git a/libstdc++-v3/testsuite/25_algorithms/search/searcher.cc b/libstdc++-v3/testsuite/25_algorithms/search/searcher.cc
index d1b9e45f62221..fe477ba436126 100644
--- a/libstdc++-v3/testsuite/25_algorithms/search/searcher.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/search/searcher.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <algorithm>
diff --git a/libstdc++-v3/testsuite/26_numerics/exclusive_scan/1.cc b/libstdc++-v3/testsuite/26_numerics/exclusive_scan/1.cc
index 1c8c2352160da..b0f684aa5b3c5 100644
--- a/libstdc++-v3/testsuite/26_numerics/exclusive_scan/1.cc
+++ b/libstdc++-v3/testsuite/26_numerics/exclusive_scan/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/26_numerics/inclusive_scan/1.cc b/libstdc++-v3/testsuite/26_numerics/inclusive_scan/1.cc
index 183ef6294165e..ab330a12093a9 100644
--- a/libstdc++-v3/testsuite/26_numerics/inclusive_scan/1.cc
+++ b/libstdc++-v3/testsuite/26_numerics/inclusive_scan/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/26_numerics/reduce/1.cc b/libstdc++-v3/testsuite/26_numerics/reduce/1.cc
index eceb3bea76953..134874cc3440e 100644
--- a/libstdc++-v3/testsuite/26_numerics/reduce/1.cc
+++ b/libstdc++-v3/testsuite/26_numerics/reduce/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/26_numerics/reduce/2.cc b/libstdc++-v3/testsuite/26_numerics/reduce/2.cc
index 12396c6f37a39..7df4ef4b34e49 100644
--- a/libstdc++-v3/testsuite/26_numerics/reduce/2.cc
+++ b/libstdc++-v3/testsuite/26_numerics/reduce/2.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/26_numerics/transform_exclusive_scan/1.cc b/libstdc++-v3/testsuite/26_numerics/transform_exclusive_scan/1.cc
index 486c836ba070b..5bade1fa332a7 100644
--- a/libstdc++-v3/testsuite/26_numerics/transform_exclusive_scan/1.cc
+++ b/libstdc++-v3/testsuite/26_numerics/transform_exclusive_scan/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/26_numerics/transform_inclusive_scan/1.cc b/libstdc++-v3/testsuite/26_numerics/transform_inclusive_scan/1.cc
index 790d5f79ac506..8f36147763da6 100644
--- a/libstdc++-v3/testsuite/26_numerics/transform_inclusive_scan/1.cc
+++ b/libstdc++-v3/testsuite/26_numerics/transform_inclusive_scan/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/26_numerics/transform_reduce/1.cc b/libstdc++-v3/testsuite/26_numerics/transform_reduce/1.cc
index 20556289d6e86..5be79d93c82a0 100644
--- a/libstdc++-v3/testsuite/26_numerics/transform_reduce/1.cc
+++ b/libstdc++-v3/testsuite/26_numerics/transform_reduce/1.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.

From 0161bba22d41f731cfa40290120110acdb9f26ab Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 16:22:54 +0100
Subject: [PATCH 100/164] libstdc++: Remove redundant -std=gnu++17 option from
 remaining tests

GCC defaults to -std=gnu++17 now anyway, and using it explicitly in the
dg-options directive prevents running these tests with different modes
such as -std=c++17 or -std=gnu++20.

libstdc++-v3/ChangeLog:

	* testsuite/17_intro/headers/c++2017/all_attributes.cc: Remove
	-std=gnu++17 from dg-options directive.
	* testsuite/17_intro/headers/c++2017/all_no_exceptions.cc:
	Likewise.
	* testsuite/17_intro/headers/c++2017/all_pedantic_errors.cc:
	Likewise.
	* testsuite/17_intro/headers/c++2017/operator_names.cc:
	Likewise.
	* testsuite/17_intro/headers/c++2017/parallel_mode.cc: Likewise.
	* testsuite/17_intro/headers/c++2017/stdc++.cc: Likewise.
	* testsuite/17_intro/headers/c++2017/stdc++_multiple_inclusion.cc:
	Likewise.
	* testsuite/18_support/aligned_alloc/aligned_alloc.cc: Likewise.
	* testsuite/18_support/byte/81076.cc: Likewise.
	* testsuite/18_support/byte/global_neg.cc: Likewise.
	* testsuite/18_support/byte/ops.cc: Likewise.
	* testsuite/18_support/byte/requirements.cc: Likewise.
	* testsuite/18_support/headers/cfloat/values_c++17.cc: Likewise.
	* testsuite/18_support/launder/1.cc: Likewise.
	* testsuite/18_support/launder/nodiscard.cc: Likewise.
	* testsuite/18_support/launder/requirements.cc: Likewise.
	* testsuite/18_support/launder/requirements_neg.cc: Likewise.
	* testsuite/18_support/new_aligned.cc: Likewise.
	* testsuite/18_support/uncaught_exceptions/uncaught_exceptions.cc:
	Likewise.
	* testsuite/19_diagnostics/error_code/is_error_code_v.cc:
	Likewise.
	* testsuite/19_diagnostics/error_condition/hash.cc: Likewise.
	* testsuite/20_util/addressof/requirements/constexpr.cc:
	Likewise.
	* testsuite/20_util/as_const/1.cc: Likewise.
	* testsuite/20_util/as_const/rvalue_neg.cc: Likewise.
	* testsuite/20_util/bind/83427.cc: Likewise.
	* testsuite/20_util/bind/is_placeholder_v.cc: Likewise.
	* testsuite/20_util/bool_constant/requirements.cc: Likewise.
	* testsuite/20_util/duration/arithmetic/constexpr_c++17.cc:
	Likewise.
	* testsuite/20_util/duration/requirements/treat_as_floating_point_v.cc:
	Likewise.
	* testsuite/20_util/duration_cast/rounding.cc: Likewise.
	* testsuite/20_util/enable_shared_from_this/members/weak_from_this.cc:
	Likewise.
	* testsuite/20_util/from_chars/1_neg.cc: Likewise.
	* testsuite/20_util/from_chars/requirements.cc: Likewise.
	* testsuite/20_util/function/91456.cc: Likewise.
	* testsuite/20_util/function/cons/deduction.cc: Likewise.
	* testsuite/20_util/function_objects/83607.cc: Likewise.
	* testsuite/20_util/function_objects/invoke/59768.cc: Likewise.
	* testsuite/20_util/function_objects/mem_fn/80478.cc: Likewise.
	* testsuite/20_util/function_objects/not_fn/1.cc: Likewise.
	* testsuite/20_util/function_objects/not_fn/87538.cc: Likewise.
	* testsuite/20_util/has_unique_object_representations/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/20_util/has_unique_object_representations/requirements/typedefs.cc:
	Likewise.
	* testsuite/20_util/has_unique_object_representations/value.cc:
	Likewise.
	* testsuite/20_util/hash/nullptr.cc: Likewise.
	* testsuite/20_util/in_place/requirements.cc: Likewise.
	* testsuite/20_util/is_aggregate/incomplete_neg.cc: Likewise.
	* testsuite/20_util/is_aggregate/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/20_util/is_aggregate/requirements/typedefs.cc:
	Likewise.
	* testsuite/20_util/is_aggregate/value.cc: Likewise.
	* testsuite/20_util/is_invocable/83395.cc: Likewise.
	* testsuite/20_util/is_invocable/91456.cc: Likewise.
	* testsuite/20_util/is_invocable/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/20_util/is_invocable/requirements/typedefs.cc:
	Likewise.
	* testsuite/20_util/is_invocable/value.cc: Likewise.
	* testsuite/20_util/is_literal_type/deprecated-1z.cc: Likewise.
	* testsuite/20_util/is_nothrow_constructible/94003.cc: Likewise.
	* testsuite/20_util/is_nothrow_invocable/83395.cc: Likewise.
	* testsuite/20_util/is_nothrow_invocable/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/20_util/is_nothrow_invocable/requirements/typedefs.cc: Likewise.
	* testsuite/20_util/is_nothrow_invocable/value.cc: Likewise.
	* testsuite/20_util/is_nothrow_swappable/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/20_util/is_nothrow_swappable/requirements/typedefs.cc:
	Likewise.
	* testsuite/20_util/is_nothrow_swappable/value.cc: Likewise.
	* testsuite/20_util/is_nothrow_swappable_with/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/20_util/is_nothrow_swappable_with/requirements/typedefs.cc:
	Likewise.
	* testsuite/20_util/is_nothrow_swappable_with/value.cc:
	Likewise.
	* testsuite/20_util/is_swappable/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/20_util/is_swappable/requirements/typedefs.cc:
	Likewise.
	* testsuite/20_util/is_swappable/value.cc: Likewise.
	* testsuite/20_util/is_swappable_with/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/20_util/is_swappable_with/requirements/typedefs.cc:
	Likewise.
	* testsuite/20_util/is_swappable_with/value.cc: Likewise.
	* testsuite/20_util/logical_traits/83134.cc: Likewise.
	* testsuite/20_util/logical_traits/requirements/explicit_instantiation.cc:
	Likewise.
	* testsuite/20_util/logical_traits/requirements/typedefs.cc:
	Likewise.
	* testsuite/20_util/logical_traits/value.cc: Likewise.
	* testsuite/20_util/pair/cons/deduction.cc: Likewise.
	* testsuite/20_util/pair/swap_cxx17.cc: Likewise.
	* testsuite/20_util/ratio/requirements/ratio_equal_v.cc:
	Likewise.
	* testsuite/20_util/reference_wrapper/83427.cc: Likewise.
	* testsuite/20_util/reference_wrapper/deduction.cc: Likewise.
	* testsuite/20_util/shared_ptr/casts/reinterpret.cc: Likewise.
	* testsuite/20_util/shared_ptr/cons/deduction.cc: Likewise.
	* testsuite/20_util/shared_ptr/requirements/weak_type.cc:
	Likewise.
	* testsuite/20_util/time_point/arithmetic/constexpr.cc:
	Likewise.
	* testsuite/20_util/time_point_cast/rounding.cc: Likewise.
	* testsuite/20_util/to_chars/3.cc: Likewise.
	* testsuite/20_util/to_chars/chars_format.cc: Likewise.
	* testsuite/20_util/to_chars/lwg3266.cc: Likewise.
	* testsuite/20_util/to_chars/requirements.cc: Likewise.
	* testsuite/20_util/tuple/78939.cc: Likewise.
	* testsuite/20_util/tuple/apply/1.cc: Likewise.
	* testsuite/20_util/tuple/apply/2.cc: Likewise.
	* testsuite/20_util/tuple/cons/deduction.cc: Likewise.
	* testsuite/20_util/tuple/make_from_tuple/1.cc: Likewise.
	* testsuite/20_util/tuple/make_from_tuple/2.cc: Likewise.
	* testsuite/20_util/tuple/swap_cxx17.cc: Likewise.
	* testsuite/20_util/tuple/tuple_size_v.cc: Likewise.
	* testsuite/20_util/unique_ptr/cons/deduction_neg.cc: Likewise.
	* testsuite/20_util/uses_allocator/requirements/uses_allocator_v.cc:
	Likewise.
	* testsuite/20_util/variable_templates_for_traits.cc: Likewise.
	* testsuite/20_util/void_t/1.cc: Likewise.
	* testsuite/20_util/weak_ptr/cons/deduction.cc: Likewise.
	* testsuite/24_iterators/container_access.cc: Likewise.
	* testsuite/24_iterators/headers/iterator/range_access_c++17.cc:
	Likewise.
	* testsuite/24_iterators/headers/iterator/synopsis_c++17.cc:
	Likewise.
	* testsuite/24_iterators/range_access/range_access_cpp17.cc:
	Likewise.
	* testsuite/24_iterators/range_access/range_access_cpp17_neg.cc:
	Likewise.
	* testsuite/26_numerics/gcd/gcd_neg.cc: Likewise.
	* testsuite/26_numerics/headers/cmath/functions_std_c++17.cc:
	Likewise.
	* testsuite/26_numerics/headers/cmath/hypot.cc: Likewise.
	* testsuite/26_numerics/headers/cmath/special_functions_global.cc:
	Likewise.
	* testsuite/26_numerics/lcm/1.cc: Likewise.
	* testsuite/26_numerics/lcm/lcm_neg.cc: Likewise.
	* testsuite/26_numerics/valarray/deduction.cc: Likewise.
	* testsuite/27_io/basic_ostream/inserters_other/char/lwg2221.cc:
	Likewise.
	* testsuite/27_io/manipulators/standard/char/quoted_sv.cc:
	Likewise.
	* testsuite/27_io/manipulators/standard/wchar_t/quoted_sv.cc:
	Likewise.
	* testsuite/27_io/types/4.cc: Likewise.
	* testsuite/28_regex/basic_regex/ctors/deduction.cc: Likewise.
	* testsuite/libstdc++-prettyprinters/91997.cc: Likewise.
	* testsuite/libstdc++-prettyprinters/cxx17.cc: Likewise.

(cherry picked from commit 0498d2d09a2364aae1e6b5e085c8ebb8fc517684)
---
 .../testsuite/17_intro/headers/c++2017/all_attributes.cc     | 1 -
 .../testsuite/17_intro/headers/c++2017/all_no_exceptions.cc  | 2 +-
 .../17_intro/headers/c++2017/all_pedantic_errors.cc          | 2 +-
 .../testsuite/17_intro/headers/c++2017/operator_names.cc     | 2 +-
 .../testsuite/17_intro/headers/c++2017/parallel_mode.cc      | 1 -
 libstdc++-v3/testsuite/17_intro/headers/c++2017/stdc++.cc    | 1 -
 .../17_intro/headers/c++2017/stdc++_multiple_inclusion.cc    | 1 -
 .../testsuite/18_support/aligned_alloc/aligned_alloc.cc      | 1 -
 libstdc++-v3/testsuite/18_support/byte/81076.cc              | 1 -
 libstdc++-v3/testsuite/18_support/byte/global_neg.cc         | 3 ++-
 libstdc++-v3/testsuite/18_support/byte/ops.cc                | 1 -
 libstdc++-v3/testsuite/18_support/byte/requirements.cc       | 1 -
 .../testsuite/18_support/headers/cfloat/values_c++17.cc      | 1 -
 libstdc++-v3/testsuite/18_support/launder/1.cc               | 1 -
 libstdc++-v3/testsuite/18_support/launder/nodiscard.cc       | 1 -
 libstdc++-v3/testsuite/18_support/launder/requirements.cc    | 1 -
 .../testsuite/18_support/launder/requirements_neg.cc         | 1 -
 libstdc++-v3/testsuite/18_support/new_aligned.cc             | 1 -
 .../18_support/uncaught_exceptions/uncaught_exceptions.cc    | 1 -
 .../testsuite/19_diagnostics/error_code/is_error_code_v.cc   | 1 -
 .../testsuite/19_diagnostics/error_condition/hash.cc         | 1 -
 .../testsuite/20_util/addressof/requirements/constexpr.cc    | 1 -
 libstdc++-v3/testsuite/20_util/as_const/1.cc                 | 1 -
 libstdc++-v3/testsuite/20_util/as_const/rvalue_neg.cc        | 1 -
 libstdc++-v3/testsuite/20_util/bind/83427.cc                 | 1 -
 libstdc++-v3/testsuite/20_util/bind/is_placeholder_v.cc      | 1 -
 libstdc++-v3/testsuite/20_util/bool_constant/requirements.cc | 1 -
 .../testsuite/20_util/duration/arithmetic/constexpr_c++17.cc | 1 -
 .../duration/requirements/treat_as_floating_point_v.cc       | 1 -
 libstdc++-v3/testsuite/20_util/duration_cast/rounding.cc     | 1 -
 .../enable_shared_from_this/members/weak_from_this.cc        | 1 -
 libstdc++-v3/testsuite/20_util/from_chars/1_neg.cc           | 1 -
 libstdc++-v3/testsuite/20_util/from_chars/requirements.cc    | 1 -
 libstdc++-v3/testsuite/20_util/function/91456.cc             | 1 -
 libstdc++-v3/testsuite/20_util/function/cons/deduction.cc    | 1 -
 libstdc++-v3/testsuite/20_util/function_objects/83607.cc     | 1 -
 .../testsuite/20_util/function_objects/invoke/59768.cc       | 1 -
 .../testsuite/20_util/function_objects/mem_fn/80478.cc       | 1 -
 libstdc++-v3/testsuite/20_util/function_objects/not_fn/1.cc  | 1 -
 .../testsuite/20_util/function_objects/not_fn/87538.cc       | 1 -
 .../requirements/explicit_instantiation.cc                   | 1 -
 .../requirements/typedefs.cc                                 | 1 -
 .../20_util/has_unique_object_representations/value.cc       | 1 -
 libstdc++-v3/testsuite/20_util/hash/nullptr.cc               | 1 -
 libstdc++-v3/testsuite/20_util/in_place/requirements.cc      | 1 -
 .../testsuite/20_util/is_aggregate/incomplete_neg.cc         | 1 -
 .../is_aggregate/requirements/explicit_instantiation.cc      | 1 -
 .../testsuite/20_util/is_aggregate/requirements/typedefs.cc  | 1 -
 libstdc++-v3/testsuite/20_util/is_aggregate/value.cc         | 1 -
 libstdc++-v3/testsuite/20_util/is_invocable/83395.cc         | 1 -
 libstdc++-v3/testsuite/20_util/is_invocable/91456.cc         | 1 -
 .../is_invocable/requirements/explicit_instantiation.cc      | 1 -
 .../testsuite/20_util/is_invocable/requirements/typedefs.cc  | 1 -
 libstdc++-v3/testsuite/20_util/is_invocable/value.cc         | 1 -
 .../testsuite/20_util/is_literal_type/deprecated-1z.cc       | 1 -
 .../testsuite/20_util/is_nothrow_constructible/94003.cc      | 1 -
 libstdc++-v3/testsuite/20_util/is_nothrow_invocable/83395.cc | 1 -
 .../requirements/explicit_instantiation.cc                   | 1 -
 .../20_util/is_nothrow_invocable/requirements/typedefs.cc    | 1 -
 libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value.cc | 1 -
 .../requirements/explicit_instantiation.cc                   | 1 -
 .../20_util/is_nothrow_swappable/requirements/typedefs.cc    | 1 -
 libstdc++-v3/testsuite/20_util/is_nothrow_swappable/value.cc | 1 -
 .../requirements/explicit_instantiation.cc                   | 1 -
 .../is_nothrow_swappable_with/requirements/typedefs.cc       | 1 -
 .../testsuite/20_util/is_nothrow_swappable_with/value.cc     | 1 -
 .../is_swappable/requirements/explicit_instantiation.cc      | 1 -
 .../testsuite/20_util/is_swappable/requirements/typedefs.cc  | 1 -
 libstdc++-v3/testsuite/20_util/is_swappable/value.cc         | 1 -
 .../is_swappable_with/requirements/explicit_instantiation.cc | 1 -
 .../20_util/is_swappable_with/requirements/typedefs.cc       | 1 -
 libstdc++-v3/testsuite/20_util/is_swappable_with/value.cc    | 1 -
 libstdc++-v3/testsuite/20_util/logical_traits/83134.cc       | 1 -
 .../logical_traits/requirements/explicit_instantiation.cc    | 1 -
 .../20_util/logical_traits/requirements/typedefs.cc          | 1 -
 libstdc++-v3/testsuite/20_util/logical_traits/value.cc       | 1 -
 libstdc++-v3/testsuite/20_util/pair/cons/deduction.cc        | 1 -
 libstdc++-v3/testsuite/20_util/pair/swap_cxx17.cc            | 1 -
 .../testsuite/20_util/ratio/requirements/ratio_equal_v.cc    | 1 -
 libstdc++-v3/testsuite/20_util/reference_wrapper/83427.cc    | 1 -
 .../testsuite/20_util/reference_wrapper/deduction.cc         | 1 -
 .../testsuite/20_util/shared_ptr/casts/reinterpret.cc        | 1 -
 libstdc++-v3/testsuite/20_util/shared_ptr/cons/deduction.cc  | 1 -
 .../testsuite/20_util/shared_ptr/requirements/weak_type.cc   | 1 -
 .../testsuite/20_util/time_point/arithmetic/constexpr.cc     | 1 -
 libstdc++-v3/testsuite/20_util/time_point_cast/rounding.cc   | 1 -
 libstdc++-v3/testsuite/20_util/to_chars/3.cc                 | 1 -
 libstdc++-v3/testsuite/20_util/to_chars/chars_format.cc      | 1 -
 libstdc++-v3/testsuite/20_util/to_chars/lwg3266.cc           | 1 -
 libstdc++-v3/testsuite/20_util/to_chars/requirements.cc      | 1 -
 libstdc++-v3/testsuite/20_util/tuple/78939.cc                | 1 -
 libstdc++-v3/testsuite/20_util/tuple/apply/1.cc              | 1 -
 libstdc++-v3/testsuite/20_util/tuple/apply/2.cc              | 1 -
 libstdc++-v3/testsuite/20_util/tuple/cons/deduction.cc       | 1 -
 libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/1.cc    | 1 -
 libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/2.cc    | 1 -
 libstdc++-v3/testsuite/20_util/tuple/swap_cxx17.cc           | 1 -
 libstdc++-v3/testsuite/20_util/tuple/tuple_size_v.cc         | 1 -
 .../testsuite/20_util/unique_ptr/cons/deduction_neg.cc       | 5 ++---
 .../20_util/uses_allocator/requirements/uses_allocator_v.cc  | 1 -
 .../testsuite/20_util/variable_templates_for_traits.cc       | 1 -
 libstdc++-v3/testsuite/20_util/void_t/1.cc                   | 1 -
 libstdc++-v3/testsuite/20_util/weak_ptr/cons/deduction.cc    | 1 -
 libstdc++-v3/testsuite/24_iterators/container_access.cc      | 1 -
 .../24_iterators/headers/iterator/range_access_c++17.cc      | 1 -
 .../24_iterators/headers/iterator/synopsis_c++17.cc          | 1 -
 .../24_iterators/range_access/range_access_cpp17.cc          | 1 -
 .../24_iterators/range_access/range_access_cpp17_neg.cc      | 1 -
 libstdc++-v3/testsuite/26_numerics/gcd/gcd_neg.cc            | 1 -
 .../26_numerics/headers/cmath/functions_std_c++17.cc         | 1 -
 libstdc++-v3/testsuite/26_numerics/headers/cmath/hypot.cc    | 1 -
 .../26_numerics/headers/cmath/special_functions_global.cc    | 1 -
 libstdc++-v3/testsuite/26_numerics/lcm/1.cc                  | 1 -
 libstdc++-v3/testsuite/26_numerics/lcm/lcm_neg.cc            | 1 -
 libstdc++-v3/testsuite/26_numerics/valarray/deduction.cc     | 1 -
 .../27_io/basic_ostream/inserters_other/char/lwg2221.cc      | 2 +-
 .../testsuite/27_io/manipulators/standard/char/quoted_sv.cc  | 1 -
 .../27_io/manipulators/standard/wchar_t/quoted_sv.cc         | 1 -
 libstdc++-v3/testsuite/27_io/types/4.cc                      | 1 -
 .../testsuite/28_regex/basic_regex/ctors/deduction.cc        | 1 -
 libstdc++-v3/testsuite/libstdc++-prettyprinters/91997.cc     | 2 +-
 libstdc++-v3/testsuite/libstdc++-prettyprinters/cxx17.cc     | 2 +-
 122 files changed, 10 insertions(+), 124 deletions(-)

diff --git a/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_attributes.cc b/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_attributes.cc
index b23bbb91bc8c0..c4e38d6423a1a 100644
--- a/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_attributes.cc
+++ b/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_attributes.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Ensure the library only uses the __name__ form for attributes.
diff --git a/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_no_exceptions.cc b/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_no_exceptions.cc
index d5b7ba9f0bfa7..2d13a9153a25c 100644
--- a/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_no_exceptions.cc
+++ b/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_no_exceptions.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -fno-exceptions" }
+// { dg-options "-fno-exceptions" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_pedantic_errors.cc b/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_pedantic_errors.cc
index 87e718ef7a4ce..dec97d4709733 100644
--- a/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_pedantic_errors.cc
+++ b/libstdc++-v3/testsuite/17_intro/headers/c++2017/all_pedantic_errors.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -pedantic-errors" }
+// { dg-options "-pedantic-errors" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/17_intro/headers/c++2017/operator_names.cc b/libstdc++-v3/testsuite/17_intro/headers/c++2017/operator_names.cc
index 155c97233f32a..63b2918af75a9 100644
--- a/libstdc++-v3/testsuite/17_intro/headers/c++2017/operator_names.cc
+++ b/libstdc++-v3/testsuite/17_intro/headers/c++2017/operator_names.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -fno-operator-names" }
+// { dg-options "-fno-operator-names" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/17_intro/headers/c++2017/parallel_mode.cc b/libstdc++-v3/testsuite/17_intro/headers/c++2017/parallel_mode.cc
index cabd552181bd8..a82fe4fe965a0 100644
--- a/libstdc++-v3/testsuite/17_intro/headers/c++2017/parallel_mode.cc
+++ b/libstdc++-v3/testsuite/17_intro/headers/c++2017/parallel_mode.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-normal-mode "" }
 
diff --git a/libstdc++-v3/testsuite/17_intro/headers/c++2017/stdc++.cc b/libstdc++-v3/testsuite/17_intro/headers/c++2017/stdc++.cc
index 90f85412ff897..3a63e513769f1 100644
--- a/libstdc++-v3/testsuite/17_intro/headers/c++2017/stdc++.cc
+++ b/libstdc++-v3/testsuite/17_intro/headers/c++2017/stdc++.cc
@@ -1,5 +1,4 @@
 // FreeBSD wants warning clean system headers:
-// { dg-options "-std=gnu++17" }
 // { dg-additional-options "-Wall -Wsystem-headers" { target *-*-freebsd* *-*-dragonfly* } }
 // { dg-do compile { target c++17 } }
 
diff --git a/libstdc++-v3/testsuite/17_intro/headers/c++2017/stdc++_multiple_inclusion.cc b/libstdc++-v3/testsuite/17_intro/headers/c++2017/stdc++_multiple_inclusion.cc
index 9e199f564ee7e..97c73ee959d1e 100644
--- a/libstdc++-v3/testsuite/17_intro/headers/c++2017/stdc++_multiple_inclusion.cc
+++ b/libstdc++-v3/testsuite/17_intro/headers/c++2017/stdc++_multiple_inclusion.cc
@@ -1,5 +1,4 @@
 // FreeBSD wants warning clean system headers:
-// { dg-options "-std=gnu++17" }
 // { dg-additional-options "-Wall -Wsystem-headers" { target *-*-freebsd* *-*-dragonfly* } }
 // { dg-do compile { target c++17 } }
 
diff --git a/libstdc++-v3/testsuite/18_support/aligned_alloc/aligned_alloc.cc b/libstdc++-v3/testsuite/18_support/aligned_alloc/aligned_alloc.cc
index 76223cd255958..1ba58ff4d4c0f 100644
--- a/libstdc++-v3/testsuite/18_support/aligned_alloc/aligned_alloc.cc
+++ b/libstdc++-v3/testsuite/18_support/aligned_alloc/aligned_alloc.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-cstdint "" }
 
diff --git a/libstdc++-v3/testsuite/18_support/byte/81076.cc b/libstdc++-v3/testsuite/18_support/byte/81076.cc
index 6c17e4bd3c402..7917dcb0cbdaf 100644
--- a/libstdc++-v3/testsuite/18_support/byte/81076.cc
+++ b/libstdc++-v3/testsuite/18_support/byte/81076.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <cstddef>
diff --git a/libstdc++-v3/testsuite/18_support/byte/global_neg.cc b/libstdc++-v3/testsuite/18_support/byte/global_neg.cc
index c4d45d4bca1a5..fb1176f84964f 100644
--- a/libstdc++-v3/testsuite/18_support/byte/global_neg.cc
+++ b/libstdc++-v3/testsuite/18_support/byte/global_neg.cc
@@ -15,7 +15,8 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
+// Use -O0 just do disable PCH, otherwise std::byte is declared.
+// { dg-options "-O0" }
 // { dg-do compile { target c++17 } }
 
 #include <stddef.h>
diff --git a/libstdc++-v3/testsuite/18_support/byte/ops.cc b/libstdc++-v3/testsuite/18_support/byte/ops.cc
index 36f66f4c24eb7..a8fcf08cfc0e4 100644
--- a/libstdc++-v3/testsuite/18_support/byte/ops.cc
+++ b/libstdc++-v3/testsuite/18_support/byte/ops.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <cstddef>
diff --git a/libstdc++-v3/testsuite/18_support/byte/requirements.cc b/libstdc++-v3/testsuite/18_support/byte/requirements.cc
index 50a0f2132efe0..516ac2c303c92 100644
--- a/libstdc++-v3/testsuite/18_support/byte/requirements.cc
+++ b/libstdc++-v3/testsuite/18_support/byte/requirements.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <cstddef>
diff --git a/libstdc++-v3/testsuite/18_support/headers/cfloat/values_c++17.cc b/libstdc++-v3/testsuite/18_support/headers/cfloat/values_c++17.cc
index f6a99c75d5df3..e49a3a631782f 100644
--- a/libstdc++-v3/testsuite/18_support/headers/cfloat/values_c++17.cc
+++ b/libstdc++-v3/testsuite/18_support/headers/cfloat/values_c++17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/18_support/launder/1.cc b/libstdc++-v3/testsuite/18_support/launder/1.cc
index f6722d09d8795..2301631068f43 100644
--- a/libstdc++-v3/testsuite/18_support/launder/1.cc
+++ b/libstdc++-v3/testsuite/18_support/launder/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <new>
diff --git a/libstdc++-v3/testsuite/18_support/launder/nodiscard.cc b/libstdc++-v3/testsuite/18_support/launder/nodiscard.cc
index 01c89690368fd..20bd195b2594e 100644
--- a/libstdc++-v3/testsuite/18_support/launder/nodiscard.cc
+++ b/libstdc++-v3/testsuite/18_support/launder/nodiscard.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <new>
diff --git a/libstdc++-v3/testsuite/18_support/launder/requirements.cc b/libstdc++-v3/testsuite/18_support/launder/requirements.cc
index 039bfc39e68f3..8a17491f09f29 100644
--- a/libstdc++-v3/testsuite/18_support/launder/requirements.cc
+++ b/libstdc++-v3/testsuite/18_support/launder/requirements.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // NB: This file is for testing new with NO OTHER INCLUDES.
diff --git a/libstdc++-v3/testsuite/18_support/launder/requirements_neg.cc b/libstdc++-v3/testsuite/18_support/launder/requirements_neg.cc
index 62424c9a49b90..f486f06323878 100644
--- a/libstdc++-v3/testsuite/18_support/launder/requirements_neg.cc
+++ b/libstdc++-v3/testsuite/18_support/launder/requirements_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <new>
diff --git a/libstdc++-v3/testsuite/18_support/new_aligned.cc b/libstdc++-v3/testsuite/18_support/new_aligned.cc
index b20bb8855b491..b3943a47c23f6 100644
--- a/libstdc++-v3/testsuite/18_support/new_aligned.cc
+++ b/libstdc++-v3/testsuite/18_support/new_aligned.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <new>
diff --git a/libstdc++-v3/testsuite/18_support/uncaught_exceptions/uncaught_exceptions.cc b/libstdc++-v3/testsuite/18_support/uncaught_exceptions/uncaught_exceptions.cc
index 0c80c1d3c43b7..83200add683fe 100644
--- a/libstdc++-v3/testsuite/18_support/uncaught_exceptions/uncaught_exceptions.cc
+++ b/libstdc++-v3/testsuite/18_support/uncaught_exceptions/uncaught_exceptions.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <cassert>
diff --git a/libstdc++-v3/testsuite/19_diagnostics/error_code/is_error_code_v.cc b/libstdc++-v3/testsuite/19_diagnostics/error_code/is_error_code_v.cc
index a0166908ff215..1a46c876a570b 100644
--- a/libstdc++-v3/testsuite/19_diagnostics/error_code/is_error_code_v.cc
+++ b/libstdc++-v3/testsuite/19_diagnostics/error_code/is_error_code_v.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/19_diagnostics/error_condition/hash.cc b/libstdc++-v3/testsuite/19_diagnostics/error_condition/hash.cc
index 497aed8ce5651..87d43e0d09aa2 100644
--- a/libstdc++-v3/testsuite/19_diagnostics/error_condition/hash.cc
+++ b/libstdc++-v3/testsuite/19_diagnostics/error_condition/hash.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <system_error>
diff --git a/libstdc++-v3/testsuite/20_util/addressof/requirements/constexpr.cc b/libstdc++-v3/testsuite/20_util/addressof/requirements/constexpr.cc
index 95fd08e6234c5..fb13de9e72d78 100644
--- a/libstdc++-v3/testsuite/20_util/addressof/requirements/constexpr.cc
+++ b/libstdc++-v3/testsuite/20_util/addressof/requirements/constexpr.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <utility>
diff --git a/libstdc++-v3/testsuite/20_util/as_const/1.cc b/libstdc++-v3/testsuite/20_util/as_const/1.cc
index 0c68aa180d1f8..46e6b3c7594e3 100644
--- a/libstdc++-v3/testsuite/20_util/as_const/1.cc
+++ b/libstdc++-v3/testsuite/20_util/as_const/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <utility>
diff --git a/libstdc++-v3/testsuite/20_util/as_const/rvalue_neg.cc b/libstdc++-v3/testsuite/20_util/as_const/rvalue_neg.cc
index 4e6bdcb9d0dca..29fd6bbefa895 100644
--- a/libstdc++-v3/testsuite/20_util/as_const/rvalue_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/as_const/rvalue_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <utility>
diff --git a/libstdc++-v3/testsuite/20_util/bind/83427.cc b/libstdc++-v3/testsuite/20_util/bind/83427.cc
index fc8147dcbee20..7a865464e263b 100644
--- a/libstdc++-v3/testsuite/20_util/bind/83427.cc
+++ b/libstdc++-v3/testsuite/20_util/bind/83427.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/bind/is_placeholder_v.cc b/libstdc++-v3/testsuite/20_util/bind/is_placeholder_v.cc
index fc0a2c401bd3f..aefd23d97fbda 100644
--- a/libstdc++-v3/testsuite/20_util/bind/is_placeholder_v.cc
+++ b/libstdc++-v3/testsuite/20_util/bind/is_placeholder_v.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/bool_constant/requirements.cc b/libstdc++-v3/testsuite/20_util/bool_constant/requirements.cc
index 417a718f31614..09a23b0645c18 100644
--- a/libstdc++-v3/testsuite/20_util/bool_constant/requirements.cc
+++ b/libstdc++-v3/testsuite/20_util/bool_constant/requirements.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <type_traits>
diff --git a/libstdc++-v3/testsuite/20_util/duration/arithmetic/constexpr_c++17.cc b/libstdc++-v3/testsuite/20_util/duration/arithmetic/constexpr_c++17.cc
index bea7972550019..52d2a07bbbc53 100644
--- a/libstdc++-v3/testsuite/20_util/duration/arithmetic/constexpr_c++17.cc
+++ b/libstdc++-v3/testsuite/20_util/duration/arithmetic/constexpr_c++17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2011-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/duration/requirements/treat_as_floating_point_v.cc b/libstdc++-v3/testsuite/20_util/duration/requirements/treat_as_floating_point_v.cc
index 698ec5fc08bc9..4b08351e447d3 100644
--- a/libstdc++-v3/testsuite/20_util/duration/requirements/treat_as_floating_point_v.cc
+++ b/libstdc++-v3/testsuite/20_util/duration/requirements/treat_as_floating_point_v.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/duration_cast/rounding.cc b/libstdc++-v3/testsuite/20_util/duration_cast/rounding.cc
index a1ed0dae66d7d..3f8cb6cf79018 100644
--- a/libstdc++-v3/testsuite/20_util/duration_cast/rounding.cc
+++ b/libstdc++-v3/testsuite/20_util/duration_cast/rounding.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <chrono>
diff --git a/libstdc++-v3/testsuite/20_util/enable_shared_from_this/members/weak_from_this.cc b/libstdc++-v3/testsuite/20_util/enable_shared_from_this/members/weak_from_this.cc
index c3359df3fb40d..60d0e35ad5a0d 100644
--- a/libstdc++-v3/testsuite/20_util/enable_shared_from_this/members/weak_from_this.cc
+++ b/libstdc++-v3/testsuite/20_util/enable_shared_from_this/members/weak_from_this.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/20_util/from_chars/1_neg.cc b/libstdc++-v3/testsuite/20_util/from_chars/1_neg.cc
index ea1586c6b6d41..890cd826ee867 100644
--- a/libstdc++-v3/testsuite/20_util/from_chars/1_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/from_chars/1_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <charconv>
diff --git a/libstdc++-v3/testsuite/20_util/from_chars/requirements.cc b/libstdc++-v3/testsuite/20_util/from_chars/requirements.cc
index a671dbb5cec2e..2f101d6ac5ff3 100644
--- a/libstdc++-v3/testsuite/20_util/from_chars/requirements.cc
+++ b/libstdc++-v3/testsuite/20_util/from_chars/requirements.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-normal-namespace "" }
 
diff --git a/libstdc++-v3/testsuite/20_util/function/91456.cc b/libstdc++-v3/testsuite/20_util/function/91456.cc
index 2900c39005759..83c88f8d9a523 100644
--- a/libstdc++-v3/testsuite/20_util/function/91456.cc
+++ b/libstdc++-v3/testsuite/20_util/function/91456.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/function/cons/deduction.cc b/libstdc++-v3/testsuite/20_util/function/cons/deduction.cc
index 20f127f3858cb..8e1b4d45581f9 100644
--- a/libstdc++-v3/testsuite/20_util/function/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/20_util/function/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/function_objects/83607.cc b/libstdc++-v3/testsuite/20_util/function_objects/83607.cc
index 1bf11c1c4a766..ee82419a77970 100644
--- a/libstdc++-v3/testsuite/20_util/function_objects/83607.cc
+++ b/libstdc++-v3/testsuite/20_util/function_objects/83607.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/function_objects/invoke/59768.cc b/libstdc++-v3/testsuite/20_util/function_objects/invoke/59768.cc
index 90e2dfa63de71..e605b28084e31 100644
--- a/libstdc++-v3/testsuite/20_util/function_objects/invoke/59768.cc
+++ b/libstdc++-v3/testsuite/20_util/function_objects/invoke/59768.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/function_objects/mem_fn/80478.cc b/libstdc++-v3/testsuite/20_util/function_objects/mem_fn/80478.cc
index 964965f6c46ec..e5de8b18820a3 100644
--- a/libstdc++-v3/testsuite/20_util/function_objects/mem_fn/80478.cc
+++ b/libstdc++-v3/testsuite/20_util/function_objects/mem_fn/80478.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/function_objects/not_fn/1.cc b/libstdc++-v3/testsuite/20_util/function_objects/not_fn/1.cc
index c1e5d90d4a6c5..3837433efa297 100644
--- a/libstdc++-v3/testsuite/20_util/function_objects/not_fn/1.cc
+++ b/libstdc++-v3/testsuite/20_util/function_objects/not_fn/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/function_objects/not_fn/87538.cc b/libstdc++-v3/testsuite/20_util/function_objects/not_fn/87538.cc
index c4e11a1d0d053..db452a9fe9dbb 100644
--- a/libstdc++-v3/testsuite/20_util/function_objects/not_fn/87538.cc
+++ b/libstdc++-v3/testsuite/20_util/function_objects/not_fn/87538.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/has_unique_object_representations/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/20_util/has_unique_object_representations/requirements/explicit_instantiation.cc
index 39ac9d739e9d0..2b0cc75f64aa2 100644
--- a/libstdc++-v3/testsuite/20_util/has_unique_object_representations/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/20_util/has_unique_object_representations/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/has_unique_object_representations/requirements/typedefs.cc b/libstdc++-v3/testsuite/20_util/has_unique_object_representations/requirements/typedefs.cc
index b8dce4272a3a9..56c0555aaa100 100644
--- a/libstdc++-v3/testsuite/20_util/has_unique_object_representations/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/has_unique_object_representations/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/has_unique_object_representations/value.cc b/libstdc++-v3/testsuite/20_util/has_unique_object_representations/value.cc
index 7a49ffa55ce5b..d0c5005f34e31 100644
--- a/libstdc++-v3/testsuite/20_util/has_unique_object_representations/value.cc
+++ b/libstdc++-v3/testsuite/20_util/has_unique_object_representations/value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/hash/nullptr.cc b/libstdc++-v3/testsuite/20_util/hash/nullptr.cc
index 4f9b1c20f737e..7b4c3bfcbc4cb 100644
--- a/libstdc++-v3/testsuite/20_util/hash/nullptr.cc
+++ b/libstdc++-v3/testsuite/20_util/hash/nullptr.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/in_place/requirements.cc b/libstdc++-v3/testsuite/20_util/in_place/requirements.cc
index b380aac493e1d..707342ad2be27 100644
--- a/libstdc++-v3/testsuite/20_util/in_place/requirements.cc
+++ b/libstdc++-v3/testsuite/20_util/in_place/requirements.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_aggregate/incomplete_neg.cc b/libstdc++-v3/testsuite/20_util/is_aggregate/incomplete_neg.cc
index b30d93fc8c6ce..a9f606ddb10b6 100644
--- a/libstdc++-v3/testsuite/20_util/is_aggregate/incomplete_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/is_aggregate/incomplete_neg.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_aggregate/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/20_util/is_aggregate/requirements/explicit_instantiation.cc
index 4185f540b5e4a..80cb1f9e4c002 100644
--- a/libstdc++-v3/testsuite/20_util/is_aggregate/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/20_util/is_aggregate/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_aggregate/requirements/typedefs.cc b/libstdc++-v3/testsuite/20_util/is_aggregate/requirements/typedefs.cc
index cf17ecec6841c..377314de823b7 100644
--- a/libstdc++-v3/testsuite/20_util/is_aggregate/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/is_aggregate/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_aggregate/value.cc b/libstdc++-v3/testsuite/20_util/is_aggregate/value.cc
index a1b4ddba1597a..4d35334f748c6 100644
--- a/libstdc++-v3/testsuite/20_util/is_aggregate/value.cc
+++ b/libstdc++-v3/testsuite/20_util/is_aggregate/value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_invocable/83395.cc b/libstdc++-v3/testsuite/20_util/is_invocable/83395.cc
index 1be3be573d502..0b90f1d09ee86 100644
--- a/libstdc++-v3/testsuite/20_util/is_invocable/83395.cc
+++ b/libstdc++-v3/testsuite/20_util/is_invocable/83395.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <type_traits>
diff --git a/libstdc++-v3/testsuite/20_util/is_invocable/91456.cc b/libstdc++-v3/testsuite/20_util/is_invocable/91456.cc
index bdfc12a18582d..aa1570200e77f 100644
--- a/libstdc++-v3/testsuite/20_util/is_invocable/91456.cc
+++ b/libstdc++-v3/testsuite/20_util/is_invocable/91456.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <type_traits>
diff --git a/libstdc++-v3/testsuite/20_util/is_invocable/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/20_util/is_invocable/requirements/explicit_instantiation.cc
index 48ed5c34184ce..15b7155c165ee 100644
--- a/libstdc++-v3/testsuite/20_util/is_invocable/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/20_util/is_invocable/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_invocable/requirements/typedefs.cc b/libstdc++-v3/testsuite/20_util/is_invocable/requirements/typedefs.cc
index f0fa0bea69c7e..6515fc0636268 100644
--- a/libstdc++-v3/testsuite/20_util/is_invocable/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/is_invocable/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_invocable/value.cc b/libstdc++-v3/testsuite/20_util/is_invocable/value.cc
index 18afc8fe052c4..76f17f0cae992 100644
--- a/libstdc++-v3/testsuite/20_util/is_invocable/value.cc
+++ b/libstdc++-v3/testsuite/20_util/is_invocable/value.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <type_traits>
diff --git a/libstdc++-v3/testsuite/20_util/is_literal_type/deprecated-1z.cc b/libstdc++-v3/testsuite/20_util/is_literal_type/deprecated-1z.cc
index 6cc972f354138..121e46c577520 100644
--- a/libstdc++-v3/testsuite/20_util/is_literal_type/deprecated-1z.cc
+++ b/libstdc++-v3/testsuite/20_util/is_literal_type/deprecated-1z.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <type_traits>
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_constructible/94003.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_constructible/94003.cc
index aa0de5e0d294f..51ba6256d2bf9 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_constructible/94003.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_constructible/94003.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <optional>
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/83395.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/83395.cc
index 4c3fd82fb80c6..a4d396781cd11 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/83395.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/83395.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <type_traits>
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/requirements/explicit_instantiation.cc
index f6bf3466533ae..fb4b4c1fd492e 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/requirements/typedefs.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/requirements/typedefs.cc
index 3dc5fb99232a4..e9055f11d5882 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value.cc
index 0ef48522099a8..310addb91abb9 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <type_traits>
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/requirements/explicit_instantiation.cc
index 772319ebb8a46..9a2957f66c0e0 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/requirements/typedefs.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/requirements/typedefs.cc
index e98f98c8c6f97..8ea83ec4d906c 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/value.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/value.cc
index b6d8db6551a1a..c68c7c68411b4 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/value.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable/value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/requirements/explicit_instantiation.cc
index f3eb3b9fbc2d5..b7d1b3fa08eee 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/requirements/typedefs.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/requirements/typedefs.cc
index 7fc48266d99fe..ac6d7b8da1c1c 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/value.cc b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/value.cc
index 1e291c7909153..a076159398195 100644
--- a/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/value.cc
+++ b/libstdc++-v3/testsuite/20_util/is_nothrow_swappable_with/value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_swappable/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/20_util/is_swappable/requirements/explicit_instantiation.cc
index c68d72ec30437..b1b91a5e5be91 100644
--- a/libstdc++-v3/testsuite/20_util/is_swappable/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/20_util/is_swappable/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_swappable/requirements/typedefs.cc b/libstdc++-v3/testsuite/20_util/is_swappable/requirements/typedefs.cc
index 816db3a05682c..f088682c74d08 100644
--- a/libstdc++-v3/testsuite/20_util/is_swappable/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/is_swappable/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_swappable/value.cc b/libstdc++-v3/testsuite/20_util/is_swappable/value.cc
index d04760cd571dd..e67f1bc2f1a9b 100644
--- a/libstdc++-v3/testsuite/20_util/is_swappable/value.cc
+++ b/libstdc++-v3/testsuite/20_util/is_swappable/value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_swappable_with/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/20_util/is_swappable_with/requirements/explicit_instantiation.cc
index 3e2ab2860c24c..6b07d31477ed3 100644
--- a/libstdc++-v3/testsuite/20_util/is_swappable_with/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/20_util/is_swappable_with/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_swappable_with/requirements/typedefs.cc b/libstdc++-v3/testsuite/20_util/is_swappable_with/requirements/typedefs.cc
index 5cad2ee79f3bb..107041a414ada 100644
--- a/libstdc++-v3/testsuite/20_util/is_swappable_with/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/is_swappable_with/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/is_swappable_with/value.cc b/libstdc++-v3/testsuite/20_util/is_swappable_with/value.cc
index 4af7a31f51540..553e743446dd5 100644
--- a/libstdc++-v3/testsuite/20_util/is_swappable_with/value.cc
+++ b/libstdc++-v3/testsuite/20_util/is_swappable_with/value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/logical_traits/83134.cc b/libstdc++-v3/testsuite/20_util/logical_traits/83134.cc
index 4b16a4545e72d..925253e31e1fc 100644
--- a/libstdc++-v3/testsuite/20_util/logical_traits/83134.cc
+++ b/libstdc++-v3/testsuite/20_util/logical_traits/83134.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <type_traits>
diff --git a/libstdc++-v3/testsuite/20_util/logical_traits/requirements/explicit_instantiation.cc b/libstdc++-v3/testsuite/20_util/logical_traits/requirements/explicit_instantiation.cc
index 1c451691eb351..fa8abad90b9c7 100644
--- a/libstdc++-v3/testsuite/20_util/logical_traits/requirements/explicit_instantiation.cc
+++ b/libstdc++-v3/testsuite/20_util/logical_traits/requirements/explicit_instantiation.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/logical_traits/requirements/typedefs.cc b/libstdc++-v3/testsuite/20_util/logical_traits/requirements/typedefs.cc
index 11904ded489fe..e0b8a00a345bc 100644
--- a/libstdc++-v3/testsuite/20_util/logical_traits/requirements/typedefs.cc
+++ b/libstdc++-v3/testsuite/20_util/logical_traits/requirements/typedefs.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 //
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
 //
diff --git a/libstdc++-v3/testsuite/20_util/logical_traits/value.cc b/libstdc++-v3/testsuite/20_util/logical_traits/value.cc
index 1e384d5e7314b..1b3d94ee52d84 100644
--- a/libstdc++-v3/testsuite/20_util/logical_traits/value.cc
+++ b/libstdc++-v3/testsuite/20_util/logical_traits/value.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 //
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/pair/cons/deduction.cc b/libstdc++-v3/testsuite/20_util/pair/cons/deduction.cc
index 64818780bb410..65dd36022f8ca 100644
--- a/libstdc++-v3/testsuite/20_util/pair/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/20_util/pair/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/pair/swap_cxx17.cc b/libstdc++-v3/testsuite/20_util/pair/swap_cxx17.cc
index c1d54cfe3ac2e..8872ff0574814 100644
--- a/libstdc++-v3/testsuite/20_util/pair/swap_cxx17.cc
+++ b/libstdc++-v3/testsuite/20_util/pair/swap_cxx17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/ratio/requirements/ratio_equal_v.cc b/libstdc++-v3/testsuite/20_util/ratio/requirements/ratio_equal_v.cc
index bac0e351f1a7b..0720ebe9883ce 100644
--- a/libstdc++-v3/testsuite/20_util/ratio/requirements/ratio_equal_v.cc
+++ b/libstdc++-v3/testsuite/20_util/ratio/requirements/ratio_equal_v.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/reference_wrapper/83427.cc b/libstdc++-v3/testsuite/20_util/reference_wrapper/83427.cc
index bd0efb81e5bc5..eb26b906f92b2 100644
--- a/libstdc++-v3/testsuite/20_util/reference_wrapper/83427.cc
+++ b/libstdc++-v3/testsuite/20_util/reference_wrapper/83427.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17_only } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/reference_wrapper/deduction.cc b/libstdc++-v3/testsuite/20_util/reference_wrapper/deduction.cc
index fbdbd6f59f7b8..c89e08bba5808 100644
--- a/libstdc++-v3/testsuite/20_util/reference_wrapper/deduction.cc
+++ b/libstdc++-v3/testsuite/20_util/reference_wrapper/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <functional>
diff --git a/libstdc++-v3/testsuite/20_util/shared_ptr/casts/reinterpret.cc b/libstdc++-v3/testsuite/20_util/shared_ptr/casts/reinterpret.cc
index 667a756d88b75..281892996cf28 100644
--- a/libstdc++-v3/testsuite/20_util/shared_ptr/casts/reinterpret.cc
+++ b/libstdc++-v3/testsuite/20_util/shared_ptr/casts/reinterpret.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/shared_ptr/cons/deduction.cc b/libstdc++-v3/testsuite/20_util/shared_ptr/cons/deduction.cc
index be42289ee189d..8a3702cb245aa 100644
--- a/libstdc++-v3/testsuite/20_util/shared_ptr/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/20_util/shared_ptr/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/20_util/shared_ptr/requirements/weak_type.cc b/libstdc++-v3/testsuite/20_util/shared_ptr/requirements/weak_type.cc
index c3f5dbee5c1bf..1ab622db2cb7f 100644
--- a/libstdc++-v3/testsuite/20_util/shared_ptr/requirements/weak_type.cc
+++ b/libstdc++-v3/testsuite/20_util/shared_ptr/requirements/weak_type.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/20_util/time_point/arithmetic/constexpr.cc b/libstdc++-v3/testsuite/20_util/time_point/arithmetic/constexpr.cc
index fb50bd813b2ea..e868a2781b88e 100644
--- a/libstdc++-v3/testsuite/20_util/time_point/arithmetic/constexpr.cc
+++ b/libstdc++-v3/testsuite/20_util/time_point/arithmetic/constexpr.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2011-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/time_point_cast/rounding.cc b/libstdc++-v3/testsuite/20_util/time_point_cast/rounding.cc
index 5de87c7ecce24..0190ad1a8408b 100644
--- a/libstdc++-v3/testsuite/20_util/time_point_cast/rounding.cc
+++ b/libstdc++-v3/testsuite/20_util/time_point_cast/rounding.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <chrono>
diff --git a/libstdc++-v3/testsuite/20_util/to_chars/3.cc b/libstdc++-v3/testsuite/20_util/to_chars/3.cc
index e559f351b7837..30b02a539446f 100644
--- a/libstdc++-v3/testsuite/20_util/to_chars/3.cc
+++ b/libstdc++-v3/testsuite/20_util/to_chars/3.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 // { dg-require-string-conversions "" }
 
diff --git a/libstdc++-v3/testsuite/20_util/to_chars/chars_format.cc b/libstdc++-v3/testsuite/20_util/to_chars/chars_format.cc
index dbf41f9ffba9a..e13cb315b31d2 100644
--- a/libstdc++-v3/testsuite/20_util/to_chars/chars_format.cc
+++ b/libstdc++-v3/testsuite/20_util/to_chars/chars_format.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <charconv>
diff --git a/libstdc++-v3/testsuite/20_util/to_chars/lwg3266.cc b/libstdc++-v3/testsuite/20_util/to_chars/lwg3266.cc
index 28ce29a7b8c16..b9ab36a2b2514 100644
--- a/libstdc++-v3/testsuite/20_util/to_chars/lwg3266.cc
+++ b/libstdc++-v3/testsuite/20_util/to_chars/lwg3266.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <charconv>
diff --git a/libstdc++-v3/testsuite/20_util/to_chars/requirements.cc b/libstdc++-v3/testsuite/20_util/to_chars/requirements.cc
index ec8ed5c260633..42e857b2988e5 100644
--- a/libstdc++-v3/testsuite/20_util/to_chars/requirements.cc
+++ b/libstdc++-v3/testsuite/20_util/to_chars/requirements.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-normal-namespace "" }
 
diff --git a/libstdc++-v3/testsuite/20_util/tuple/78939.cc b/libstdc++-v3/testsuite/20_util/tuple/78939.cc
index 9934cda4a54bc..0a6cfa7b692d0 100644
--- a/libstdc++-v3/testsuite/20_util/tuple/78939.cc
+++ b/libstdc++-v3/testsuite/20_util/tuple/78939.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-additional-options "-Wno-deprecated" { target c++2a } }
 // { dg-do compile { target c++17 } }
 
diff --git a/libstdc++-v3/testsuite/20_util/tuple/apply/1.cc b/libstdc++-v3/testsuite/20_util/tuple/apply/1.cc
index 83c31a37ef7a5..e8352cfb6efac 100644
--- a/libstdc++-v3/testsuite/20_util/tuple/apply/1.cc
+++ b/libstdc++-v3/testsuite/20_util/tuple/apply/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <tuple>
diff --git a/libstdc++-v3/testsuite/20_util/tuple/apply/2.cc b/libstdc++-v3/testsuite/20_util/tuple/apply/2.cc
index be8fc7b473995..a2cdb62e44cc5 100644
--- a/libstdc++-v3/testsuite/20_util/tuple/apply/2.cc
+++ b/libstdc++-v3/testsuite/20_util/tuple/apply/2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Test noexcept-specifier on std::apply
diff --git a/libstdc++-v3/testsuite/20_util/tuple/cons/deduction.cc b/libstdc++-v3/testsuite/20_util/tuple/cons/deduction.cc
index af09c971f000e..70582d89bfa7e 100644
--- a/libstdc++-v3/testsuite/20_util/tuple/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/20_util/tuple/cons/deduction.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/1.cc b/libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/1.cc
index 42479d184c047..2d3ab9ad09473 100644
--- a/libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/1.cc
+++ b/libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <tuple>
diff --git a/libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/2.cc b/libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/2.cc
index b3e9486a1df7a..f12876b6d3523 100644
--- a/libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/2.cc
+++ b/libstdc++-v3/testsuite/20_util/tuple/make_from_tuple/2.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Test noexcept-specifier on std::make_from_tuple
diff --git a/libstdc++-v3/testsuite/20_util/tuple/swap_cxx17.cc b/libstdc++-v3/testsuite/20_util/tuple/swap_cxx17.cc
index 1f06be82059b3..96cfe44c1fc20 100644
--- a/libstdc++-v3/testsuite/20_util/tuple/swap_cxx17.cc
+++ b/libstdc++-v3/testsuite/20_util/tuple/swap_cxx17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/tuple/tuple_size_v.cc b/libstdc++-v3/testsuite/20_util/tuple/tuple_size_v.cc
index c2376418d1fef..2ecafff25d8cb 100644
--- a/libstdc++-v3/testsuite/20_util/tuple/tuple_size_v.cc
+++ b/libstdc++-v3/testsuite/20_util/tuple/tuple_size_v.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/unique_ptr/cons/deduction_neg.cc b/libstdc++-v3/testsuite/20_util/unique_ptr/cons/deduction_neg.cc
index 16646edd3b915..2a607291fd1a2 100644
--- a/libstdc++-v3/testsuite/20_util/unique_ptr/cons/deduction_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/unique_ptr/cons/deduction_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <memory>
@@ -32,5 +31,5 @@ test01()
   std::unique_ptr bad2{new double, D()}; // { dg-error "class template argument deduction failed" }
 }
 
-// { dg-error "no matching function" "" { target *-*-* } 29 }
-// { dg-error "no matching function" "" { target *-*-* } 32 }
+// { dg-error "no matching function" "" { target *-*-* } 28 }
+// { dg-error "no matching function" "" { target *-*-* } 31 }
diff --git a/libstdc++-v3/testsuite/20_util/uses_allocator/requirements/uses_allocator_v.cc b/libstdc++-v3/testsuite/20_util/uses_allocator/requirements/uses_allocator_v.cc
index e624cf568372a..bf405e07d2eec 100644
--- a/libstdc++-v3/testsuite/20_util/uses_allocator/requirements/uses_allocator_v.cc
+++ b/libstdc++-v3/testsuite/20_util/uses_allocator/requirements/uses_allocator_v.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/20_util/variable_templates_for_traits.cc b/libstdc++-v3/testsuite/20_util/variable_templates_for_traits.cc
index 60d7aa94938e4..a5c48fe5e3aa2 100644
--- a/libstdc++-v3/testsuite/20_util/variable_templates_for_traits.cc
+++ b/libstdc++-v3/testsuite/20_util/variable_templates_for_traits.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-additional-options "-Wno-deprecated" { target c++2a } }
 // { dg-do compile { target c++17 } }
 
diff --git a/libstdc++-v3/testsuite/20_util/void_t/1.cc b/libstdc++-v3/testsuite/20_util/void_t/1.cc
index ded6be168eb23..b8dc9e0c78147 100644
--- a/libstdc++-v3/testsuite/20_util/void_t/1.cc
+++ b/libstdc++-v3/testsuite/20_util/void_t/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <type_traits>
diff --git a/libstdc++-v3/testsuite/20_util/weak_ptr/cons/deduction.cc b/libstdc++-v3/testsuite/20_util/weak_ptr/cons/deduction.cc
index 2aa6abe4ae257..0333942db2906 100644
--- a/libstdc++-v3/testsuite/20_util/weak_ptr/cons/deduction.cc
+++ b/libstdc++-v3/testsuite/20_util/weak_ptr/cons/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <memory>
diff --git a/libstdc++-v3/testsuite/24_iterators/container_access.cc b/libstdc++-v3/testsuite/24_iterators/container_access.cc
index bcdc782512f77..d795eafae456f 100644
--- a/libstdc++-v3/testsuite/24_iterators/container_access.cc
+++ b/libstdc++-v3/testsuite/24_iterators/container_access.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2015-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/24_iterators/headers/iterator/range_access_c++17.cc b/libstdc++-v3/testsuite/24_iterators/headers/iterator/range_access_c++17.cc
index 506b18c7648b3..d0ae2d3b74042 100644
--- a/libstdc++-v3/testsuite/24_iterators/headers/iterator/range_access_c++17.cc
+++ b/libstdc++-v3/testsuite/24_iterators/headers/iterator/range_access_c++17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2016-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/24_iterators/headers/iterator/synopsis_c++17.cc b/libstdc++-v3/testsuite/24_iterators/headers/iterator/synopsis_c++17.cc
index 633288eafb42b..4039bd61f6236 100644
--- a/libstdc++-v3/testsuite/24_iterators/headers/iterator/synopsis_c++17.cc
+++ b/libstdc++-v3/testsuite/24_iterators/headers/iterator/synopsis_c++17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-require-normal-namespace "" }
 
diff --git a/libstdc++-v3/testsuite/24_iterators/range_access/range_access_cpp17.cc b/libstdc++-v3/testsuite/24_iterators/range_access/range_access_cpp17.cc
index 358e19345e128..33f724206c60a 100644
--- a/libstdc++-v3/testsuite/24_iterators/range_access/range_access_cpp17.cc
+++ b/libstdc++-v3/testsuite/24_iterators/range_access/range_access_cpp17.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // Copyright (C) 2017-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/24_iterators/range_access/range_access_cpp17_neg.cc b/libstdc++-v3/testsuite/24_iterators/range_access/range_access_cpp17_neg.cc
index a56a11057a9db..06055bf7e6a26 100644
--- a/libstdc++-v3/testsuite/24_iterators/range_access/range_access_cpp17_neg.cc
+++ b/libstdc++-v3/testsuite/24_iterators/range_access/range_access_cpp17_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <iterator>
diff --git a/libstdc++-v3/testsuite/26_numerics/gcd/gcd_neg.cc b/libstdc++-v3/testsuite/26_numerics/gcd/gcd_neg.cc
index 90aaee75af668..e68a051aaa491 100644
--- a/libstdc++-v3/testsuite/26_numerics/gcd/gcd_neg.cc
+++ b/libstdc++-v3/testsuite/26_numerics/gcd/gcd_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <numeric>
diff --git a/libstdc++-v3/testsuite/26_numerics/headers/cmath/functions_std_c++17.cc b/libstdc++-v3/testsuite/26_numerics/headers/cmath/functions_std_c++17.cc
index 3b337f83bf5bb..28d63bbbeb9c9 100644
--- a/libstdc++-v3/testsuite/26_numerics/headers/cmath/functions_std_c++17.cc
+++ b/libstdc++-v3/testsuite/26_numerics/headers/cmath/functions_std_c++17.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <cmath>
diff --git a/libstdc++-v3/testsuite/26_numerics/headers/cmath/hypot.cc b/libstdc++-v3/testsuite/26_numerics/headers/cmath/hypot.cc
index 1e50407091244..ad785459721cf 100644
--- a/libstdc++-v3/testsuite/26_numerics/headers/cmath/hypot.cc
+++ b/libstdc++-v3/testsuite/26_numerics/headers/cmath/hypot.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 #include <cmath>
diff --git a/libstdc++-v3/testsuite/26_numerics/headers/cmath/special_functions_global.cc b/libstdc++-v3/testsuite/26_numerics/headers/cmath/special_functions_global.cc
index c4856b227eddb..6ac8beef56a61 100644
--- a/libstdc++-v3/testsuite/26_numerics/headers/cmath/special_functions_global.cc
+++ b/libstdc++-v3/testsuite/26_numerics/headers/cmath/special_functions_global.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #undef __STDCPP_WANT_MATH_SPEC_FUNCS__
diff --git a/libstdc++-v3/testsuite/26_numerics/lcm/1.cc b/libstdc++-v3/testsuite/26_numerics/lcm/1.cc
index b23796c22da46..2495fa10ddde6 100644
--- a/libstdc++-v3/testsuite/26_numerics/lcm/1.cc
+++ b/libstdc++-v3/testsuite/26_numerics/lcm/1.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <numeric>
diff --git a/libstdc++-v3/testsuite/26_numerics/lcm/lcm_neg.cc b/libstdc++-v3/testsuite/26_numerics/lcm/lcm_neg.cc
index 485b9a4dd0167..dbe23ab7f266e 100644
--- a/libstdc++-v3/testsuite/26_numerics/lcm/lcm_neg.cc
+++ b/libstdc++-v3/testsuite/26_numerics/lcm/lcm_neg.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <numeric>
diff --git a/libstdc++-v3/testsuite/26_numerics/valarray/deduction.cc b/libstdc++-v3/testsuite/26_numerics/valarray/deduction.cc
index 5c709b779c4c2..52c8f8e44af43 100644
--- a/libstdc++-v3/testsuite/26_numerics/valarray/deduction.cc
+++ b/libstdc++-v3/testsuite/26_numerics/valarray/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 #include <valarray>
diff --git a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/lwg2221.cc b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/lwg2221.cc
index d7c6ad0521225..b410b7729c64d 100644
--- a/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/lwg2221.cc
+++ b/libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/lwg2221.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -fno-inline" }
+// { dg-options "-fno-inline" }
 // { dg-do link { target c++17 } }
 
 #include <iostream>
diff --git a/libstdc++-v3/testsuite/27_io/manipulators/standard/char/quoted_sv.cc b/libstdc++-v3/testsuite/27_io/manipulators/standard/char/quoted_sv.cc
index 3f76b5b8d8402..ec6041d27d5b1 100644
--- a/libstdc++-v3/testsuite/27_io/manipulators/standard/char/quoted_sv.cc
+++ b/libstdc++-v3/testsuite/27_io/manipulators/standard/char/quoted_sv.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/manipulators/standard/wchar_t/quoted_sv.cc b/libstdc++-v3/testsuite/27_io/manipulators/standard/wchar_t/quoted_sv.cc
index 282173a654d82..3881d33ae850d 100644
--- a/libstdc++-v3/testsuite/27_io/manipulators/standard/wchar_t/quoted_sv.cc
+++ b/libstdc++-v3/testsuite/27_io/manipulators/standard/wchar_t/quoted_sv.cc
@@ -1,4 +1,3 @@
-// { dg-options "-std=gnu++17" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2018-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/27_io/types/4.cc b/libstdc++-v3/testsuite/27_io/types/4.cc
index 99cf63b20932b..c9e1708ccd406 100644
--- a/libstdc++-v3/testsuite/27_io/types/4.cc
+++ b/libstdc++-v3/testsuite/27_io/types/4.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 
 // In C++17 these names are not reserved by the library.
diff --git a/libstdc++-v3/testsuite/28_regex/basic_regex/ctors/deduction.cc b/libstdc++-v3/testsuite/28_regex/basic_regex/ctors/deduction.cc
index aed7c5f2f6314..9064b77967974 100644
--- a/libstdc++-v3/testsuite/28_regex/basic_regex/ctors/deduction.cc
+++ b/libstdc++-v3/testsuite/28_regex/basic_regex/ctors/deduction.cc
@@ -15,7 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// { dg-options "-std=gnu++17" }
 // { dg-do compile { target c++17 } }
 // { dg-timeout-factor 3 }
 
diff --git a/libstdc++-v3/testsuite/libstdc++-prettyprinters/91997.cc b/libstdc++-v3/testsuite/libstdc++-prettyprinters/91997.cc
index d1bdf08b6b1b5..f47fbff4da740 100644
--- a/libstdc++-v3/testsuite/libstdc++-prettyprinters/91997.cc
+++ b/libstdc++-v3/testsuite/libstdc++-prettyprinters/91997.cc
@@ -1,4 +1,4 @@
-// { dg-options "-std=gnu++17 -g -O0 -Wno-unused" }
+// { dg-options "-g -O0 -Wno-unused" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2019-2021 Free Software Foundation, Inc.
diff --git a/libstdc++-v3/testsuite/libstdc++-prettyprinters/cxx17.cc b/libstdc++-v3/testsuite/libstdc++-prettyprinters/cxx17.cc
index 98e21e963fe59..72c66d3b785a7 100644
--- a/libstdc++-v3/testsuite/libstdc++-prettyprinters/cxx17.cc
+++ b/libstdc++-v3/testsuite/libstdc++-prettyprinters/cxx17.cc
@@ -1,4 +1,4 @@
-// { dg-options "-g -O0 -std=gnu++17" }
+// { dg-options "-g -O0" }
 // { dg-do run { target c++17 } }
 
 // Copyright (C) 2014-2021 Free Software Foundation, Inc.

From 66b308931e5c6f4e35dc4f0744963c0808ce2f38 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 20:46:38 +0100
Subject: [PATCH 101/164] libstdc++: Implement proposed resolution to LWG 3548

This has been tentatively approved by LWG. The deleter from a unique_ptr
can be moved into the shared_ptr (at least, since LWG 2802). This uses
std::forward<_Del>(__r.get_deleter()) not std::move(__r.get_deleter())
because we don't want to convert the deleter to an rvalue when _Del is
an lvalue reference type.

This also adds a missing is_move_constructible_v<D> constraint to the
shared_ptr(unique_ptr<Y, D>&&) constructor, which is inherited from the
shared_ptr(Y*, D) constructor due to the use of "equivalent to" in the
specified effects.

libstdc++-v3/ChangeLog:

	* include/bits/shared_ptr_base.h (__shared_count(unique_ptr&&)):
	Initialize a non-reference deleter from an rvalue, as per LWG
	3548.
	(__shared_ptr::_UniqCompatible): Add missing constraint.
	* testsuite/20_util/shared_ptr/cons/lwg3548.cc: New test.
	* testsuite/20_util/shared_ptr/cons/unique_ptr_deleter.cc: Check
	constraints.

(cherry picked from commit 5edc0c15f1667cc2a5deb664b25c007b35d259f6)
---
 libstdc++-v3/include/bits/shared_ptr_base.h     | 13 +++++++++----
 .../20_util/shared_ptr/cons/lwg3548.cc          | 16 ++++++++++++++++
 .../shared_ptr/cons/unique_ptr_deleter.cc       | 17 ++++++++++++++++-
 3 files changed, 41 insertions(+), 5 deletions(-)
 create mode 100644 libstdc++-v3/testsuite/20_util/shared_ptr/cons/lwg3548.cc

diff --git a/libstdc++-v3/include/bits/shared_ptr_base.h b/libstdc++-v3/include/bits/shared_ptr_base.h
index 71099afbf7a4e..eb9ad23ba1e3d 100644
--- a/libstdc++-v3/include/bits/shared_ptr_base.h
+++ b/libstdc++-v3/include/bits/shared_ptr_base.h
@@ -684,8 +684,11 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 	  using _Alloc_traits = allocator_traits<_Alloc>;
 	  _Alloc __a;
 	  _Sp_cd_type* __mem = _Alloc_traits::allocate(__a, 1);
+	  // _GLIBCXX_RESOLVE_LIB_DEFECTS
+	  // 3548. shared_ptr construction from unique_ptr should move
+	  // (not copy) the deleter
 	  _Alloc_traits::construct(__a, __mem, __r.release(),
-				   __r.get_deleter());  // non-throwing
+				   std::forward<_Del>(__r.get_deleter()));
 	  _M_pi = __mem;
 	}
 
@@ -1070,9 +1073,11 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       // Constraint for construction from unique_ptr:
       template<typename _Yp, typename _Del, typename _Res = void,
 	       typename _Ptr = typename unique_ptr<_Yp, _Del>::pointer>
-	using _UniqCompatible = typename enable_if<__and_<
-	  __sp_compatible_with<_Yp*, _Tp*>, is_convertible<_Ptr, element_type*>
-	  >::value, _Res>::type;
+	using _UniqCompatible = __enable_if_t<__and_<
+	  __sp_compatible_with<_Yp*, _Tp*>,
+	  is_convertible<_Ptr, element_type*>,
+	  is_move_constructible<_Del>
+	  >::value, _Res>;
 
       // Constraint for assignment from unique_ptr:
       template<typename _Yp, typename _Del>
diff --git a/libstdc++-v3/testsuite/20_util/shared_ptr/cons/lwg3548.cc b/libstdc++-v3/testsuite/20_util/shared_ptr/cons/lwg3548.cc
new file mode 100644
index 0000000000000..d6ec7b1d05789
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/shared_ptr/cons/lwg3548.cc
@@ -0,0 +1,16 @@
+// { dg-do compile { target c++11 } }
+
+#include <memory>
+
+// LWG 3548
+// shared_ptr construction from unique_ptr should move (not copy) the deleter
+
+struct D
+{
+  D() { }
+  D(D&&) { }
+  void operator()(int* p) const { delete p; }
+};
+
+std::unique_ptr<int, D> u;
+std::shared_ptr<int> s1(std::move(u));
diff --git a/libstdc++-v3/testsuite/20_util/shared_ptr/cons/unique_ptr_deleter.cc b/libstdc++-v3/testsuite/20_util/shared_ptr/cons/unique_ptr_deleter.cc
index f4cf3ddda2e46..d7ca51a4aa6e7 100644
--- a/libstdc++-v3/testsuite/20_util/shared_ptr/cons/unique_ptr_deleter.cc
+++ b/libstdc++-v3/testsuite/20_util/shared_ptr/cons/unique_ptr_deleter.cc
@@ -58,10 +58,25 @@ test02()
   VERIFY( D::count == 0 ); // LWG 2415
 }
 
+void
+test03()
+{
+  struct D
+  {
+    D() = default;
+    D(const D&) = delete; // not copyable or movable
+    void operator()(int* p) const { delete p; }
+  };
+
+  using namespace std;
+  static_assert( ! is_constructible<shared_ptr<int>, unique_ptr<int, D>>(),
+		 "Constraints: is_move_constructible_v<D> is true" );
+}
+
 int
 main()
 {
   test01();
   test02();
-  return 0;
+  test03();
 }

From 16255fd2fdbf801167c2a5f095048b2c7824f6be Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 10 May 2021 21:06:22 +0100
Subject: [PATCH 102/164] libstdc++: Remove TODO comment

We have a comment saying to replace the simple binary_semaphore type
with std::binary_semaphore, which has been done. However, that isn't
defined on all targets. So keep the simple one here that just implements
the parts of the API needed by <stop_token>, and remove the comment
suggesting it should be replaced.

libstdc++-v3/ChangeLog:

	* include/std/stop_token: Remove TODO comment.

(cherry picked from commit 151154a21da8b0784894b2463a117f4e283d5525)
---
 libstdc++-v3/include/std/stop_token | 1 -
 1 file changed, 1 deletion(-)

diff --git a/libstdc++-v3/include/std/stop_token b/libstdc++-v3/include/std/stop_token
index fffc215d2a847..d0cfcf3109760 100644
--- a/libstdc++-v3/include/std/stop_token
+++ b/libstdc++-v3/include/std/stop_token
@@ -107,7 +107,6 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     }
 
 #ifndef __cpp_lib_semaphore
-    // TODO: replace this with a real implementation of std::binary_semaphore
     struct binary_semaphore
     {
       explicit binary_semaphore(int __d) : _M_counter(__d > 0) { }

From db9dec545bf7c5be3120412444553ff993c7200d Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Tue, 11 May 2021 15:01:01 +0100
Subject: [PATCH 103/164] libstdc++: Fix missing members in
 std::allocator<void>

The changes in 75c6a925dab5b7af9ab47c10906cb0e140261cc2 were slightly
incorrect, because the converting constructor should be noexcept, and
the POCMA and is_always_equal traits should still be present in C++20.
This fixes it, and slightly refactors the preprocessor conditions and
order of members. Also add comments explaining things.

The non-standard construct and destroy members added for PR 78052 can be
private if allocator_traits<allocator<void>> is made a friend.

libstdc++-v3/ChangeLog:

	* include/bits/allocator.h (allocator<void>) [C++20]: Add
	missing noexcept to constructor. Restore missing POCMA and
	is_always_equal_traits.
	[C++17]: Make construct and destroy members private and
	declare allocator_traits as a friend.
	* include/bits/memoryfwd.h (allocator_traits): Declare.
	* include/ext/malloc_allocator.h (malloc_allocator::allocate):
	Add nodiscard attribute. Add static assertion for LWG 3307.
	* include/ext/new_allocator.h (new_allocator::allocate): Add
	static assertion for LWG 3307.
	* testsuite/20_util/allocator/void.cc: Check that converting
	constructor is noexcept. Check for propagation traits and
	size_type and difference_type. Check that pointer and
	const_pointer are gone in C++20.

(cherry picked from commit 5e3a1ea3d89d62972e1f036b2ede37a80b880bdf)
---
 libstdc++-v3/include/bits/allocator.h         | 44 ++++++++++++++-----
 libstdc++-v3/include/bits/memoryfwd.h         |  7 +--
 libstdc++-v3/include/ext/malloc_allocator.h   |  8 +++-
 libstdc++-v3/include/ext/new_allocator.h      |  8 +++-
 .../testsuite/20_util/allocator/void.cc       | 40 +++++++++++++++--
 5 files changed, 88 insertions(+), 19 deletions(-)

diff --git a/libstdc++-v3/include/bits/allocator.h b/libstdc++-v3/include/bits/allocator.h
index c5c1f28b3d049..73d5d7a25be1c 100644
--- a/libstdc++-v3/include/bits/allocator.h
+++ b/libstdc++-v3/include/bits/allocator.h
@@ -60,6 +60,13 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
    *  @{
    */
 
+  // Since C++20 the primary template should be used for allocator<void>,
+  // but then it would have a non-trivial default ctor and dtor, which
+  // would be an ABI change. So C++20 still uses the allocator<void> explicit
+  // specialization, with the historical ABI properties, but with the same
+  // members that are present in the primary template.
+
+#if ! _GLIBCXX_INLINE_VERSION
   /// allocator<void> specialization.
   template<>
     class allocator<void>
@@ -68,28 +75,40 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       typedef void        value_type;
       typedef size_t      size_type;
       typedef ptrdiff_t   difference_type;
+
 #if __cplusplus <= 201703L
+      // These were removed for C++20.
       typedef void*       pointer;
       typedef const void* const_pointer;
 
       template<typename _Tp1>
 	struct rebind
 	{ typedef allocator<_Tp1> other; };
-#else
-      allocator() = default;
-
-      template<typename _Up>
-	constexpr
-	allocator(const allocator<_Up>&) { }
-#endif // ! C++20
+#endif
 
-#if __cplusplus >= 201103L && __cplusplus <= 201703L
+#if __cplusplus >= 201103L
       // _GLIBCXX_RESOLVE_LIB_DEFECTS
       // 2103. std::allocator propagate_on_container_move_assignment
       typedef true_type propagate_on_container_move_assignment;
 
       typedef true_type is_always_equal;
 
+#if __cplusplus >= 202002L
+      allocator() = default;
+
+      template<typename _Up>
+	constexpr
+	allocator(const allocator<_Up>&) noexcept { }
+
+      // No allocate member because it's ill-formed by LWG 3307.
+      // No deallocate member because it would be undefined to call it
+      // with any pointer which wasn't obtained from allocate.
+
+#else // ! C++20
+    private:
+      // This uses construct and destroy in C++11/14/17 modes.
+      friend allocator_traits<allocator<void>>;
+
       template<typename _Up, typename... _Args>
 	void
 	construct(_Up* __p, _Args&&... __args)
@@ -101,11 +120,14 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 	destroy(_Up* __p)
 	noexcept(std::is_nothrow_destructible<_Up>::value)
 	{ __p->~_Up(); }
-#endif // C++11 to C++17
+#endif // C++17
+#endif // C++11
+
     };
+#endif // ! _GLIBCXX_INLINE_VERSION
 
   /**
-   * @brief  The @a standard allocator, as per [20.4].
+   * @brief  The @a standard allocator, as per C++03 [20.4.1].
    *
    *  See https://gcc.gnu.org/onlinedocs/libstdc++/manual/memory.html#std.util.memory.allocator
    *  for further details.
@@ -119,7 +141,9 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       typedef _Tp        value_type;
       typedef size_t     size_type;
       typedef ptrdiff_t  difference_type;
+
 #if __cplusplus <= 201703L
+      // These were removed for C++20.
       typedef _Tp*       pointer;
       typedef const _Tp* const_pointer;
       typedef _Tp&       reference;
diff --git a/libstdc++-v3/include/bits/memoryfwd.h b/libstdc++-v3/include/bits/memoryfwd.h
index 10a386c69d2be..b0f0307eb7b94 100644
--- a/libstdc++-v3/include/bits/memoryfwd.h
+++ b/libstdc++-v3/include/bits/memoryfwd.h
@@ -63,15 +63,16 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
   template<typename>
     class allocator;
 
-#if __cplusplus <= 201703L
   template<>
     class allocator<void>;
-#endif
 
 #if __cplusplus >= 201103L
-  /// Declare uses_allocator so it can be specialized in \<queue\> etc.
+  /// Declare uses_allocator so it can be specialized in `<queue>` etc.
   template<typename, typename>
     struct uses_allocator;
+
+  template<typename>
+    struct allocator_traits;
 #endif
 
   /// @} group memory
diff --git a/libstdc++-v3/include/ext/malloc_allocator.h b/libstdc++-v3/include/ext/malloc_allocator.h
index 3112f7f52bd91..1e90b179f5317 100644
--- a/libstdc++-v3/include/ext/malloc_allocator.h
+++ b/libstdc++-v3/include/ext/malloc_allocator.h
@@ -99,9 +99,15 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
       // NB: __n is permitted to be 0.  The C++ standard says nothing
       // about what the return value is when __n == 0.
-      _Tp*
+      _GLIBCXX_NODISCARD _Tp*
       allocate(size_type __n, const void* = 0)
       {
+#if __cplusplus >= 201103L
+	 // _GLIBCXX_RESOLVE_LIB_DEFECTS
+	 // 3308. std::allocator<void>().allocate(n)
+	 static_assert(sizeof(_Tp) != 0, "cannot allocate incomplete types");
+#endif
+
 	if (__builtin_expect(__n > this->_M_max_size(), false))
 	  {
 	    // _GLIBCXX_RESOLVE_LIB_DEFECTS
diff --git a/libstdc++-v3/include/ext/new_allocator.h b/libstdc++-v3/include/ext/new_allocator.h
index 9e624ba8b501e..3fb893be1523d 100644
--- a/libstdc++-v3/include/ext/new_allocator.h
+++ b/libstdc++-v3/include/ext/new_allocator.h
@@ -42,7 +42,7 @@ namespace __gnu_cxx _GLIBCXX_VISIBILITY(default)
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
   /**
-   *  @brief  An allocator that uses global new, as per [20.4].
+   *  @brief  An allocator that uses global new, as per C++03 [20.4.1].
    *  @ingroup allocators
    *
    *  This is precisely the allocator defined in the C++ Standard.
@@ -102,6 +102,12 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       _GLIBCXX_NODISCARD _Tp*
       allocate(size_type __n, const void* = static_cast<const void*>(0))
       {
+#if __cplusplus >= 201103L
+	 // _GLIBCXX_RESOLVE_LIB_DEFECTS
+	 // 3308. std::allocator<void>().allocate(n)
+	 static_assert(sizeof(_Tp) != 0, "cannot allocate incomplete types");
+#endif
+
 	if (__builtin_expect(__n > this->_M_max_size(), false))
 	  {
 	    // _GLIBCXX_RESOLVE_LIB_DEFECTS
diff --git a/libstdc++-v3/testsuite/20_util/allocator/void.cc b/libstdc++-v3/testsuite/20_util/allocator/void.cc
index a172606e174bf..e3d024d525b83 100644
--- a/libstdc++-v3/testsuite/20_util/allocator/void.cc
+++ b/libstdc++-v3/testsuite/20_util/allocator/void.cc
@@ -33,6 +33,18 @@ test01()
   std::allocator_traits<alloc_type>::destroy(a, &i);
 }
 
+static_assert( std::allocator<void>::propagate_on_container_move_assignment(),
+	       "POCMA trait should always be present" );
+static_assert( std::allocator<void>::is_always_equal(),
+	       "is_always_equal trait should always be present" );
+
+static_assert(
+    std::is_same<std::allocator<void>::size_type, std::size_t>(),
+    "size_type is size_t" );
+static_assert(
+    std::is_same<std::allocator<void>::difference_type, std::ptrdiff_t>(),
+    "size_type is size_t" );
+
 // These properties are formally unspecified, but have always been true for
 // the libstdc++ definition of allocator<void>.
 static_assert(
@@ -48,12 +60,32 @@ static_assert(
     std::is_trivially_destructible<std::allocator<void>>::value,
     "explicit specialization has trivial destructor");
 
-#if __cplusplus > 201703L
+#if __cplusplus >= 202002L
 // C++20 removes the allocator<void> explicit specialization, so it can now be
 // constructed using the converting constructor from other specializations.
-static_assert( std::is_constructible_v<std::allocator<void>,
-				       std::allocator<int>> );
-#endif
+static_assert( std::is_nothrow_constructible_v<std::allocator<void>,
+					       std::allocator<int>> );
+
+template<typename T>
+concept has_pointer = requires { typename T::pointer; };
+template<typename T>
+concept has_const_pointer = requires { typename T::const_pointer; };
+template<typename T>
+concept has_size_type = requires { typename T::size_type; };
+template<typename T>
+concept has_difference_type = requires { typename T::difference_type; };
+
+// These were removed for C++20
+static_assert( ! has_pointer<std::allocator<void>> );
+static_assert( ! has_const_pointer<std::allocator<void>> );
+
+#else
+static_assert(
+    std::is_same<std::allocator<void>::pointer, void*>(),
+    "pointer is void*" );
+static_assert( std::is_same<std::allocator<void>::const_pointer, const void*>(),
+    "const_pointer is const void*" );
+#endif // C++20
 
 int
 main()

From a46434cf23b999a5a37a1f3183a71e2a939b8f06 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Tue, 11 May 2021 17:14:26 +0100
Subject: [PATCH 104/164] libstdc++: Fix tests that fail in C++98 mode

The header synopsis test fails to define NOTHROW for C++98.

The shared_ptr test should be skipped for C++98.

The debug mode one should work for C++98 too, it just needs to avoid
C++11 syntax that isn't valid in C++98.

libstdc++-v3/ChangeLog:

	* testsuite/20_util/headers/memory/synopsis.cc: Define C++98
	alternative for macro.
	* testsuite/20_util/shared_ptr/creation/99006.cc: Add effective
	target keyword.
	* testsuite/25_algorithms/copy/debug/99402.cc: Avoid C++11
	syntax.

(cherry picked from commit 37407a2ae701c0a93377106a2938ab5474062fc3)
---
 libstdc++-v3/testsuite/20_util/headers/memory/synopsis.cc   | 2 ++
 libstdc++-v3/testsuite/20_util/shared_ptr/creation/99006.cc | 4 ++--
 libstdc++-v3/testsuite/25_algorithms/copy/debug/99402.cc    | 3 ++-
 3 files changed, 6 insertions(+), 3 deletions(-)

diff --git a/libstdc++-v3/testsuite/20_util/headers/memory/synopsis.cc b/libstdc++-v3/testsuite/20_util/headers/memory/synopsis.cc
index 1463fcf946863..9a4264a075955 100644
--- a/libstdc++-v3/testsuite/20_util/headers/memory/synopsis.cc
+++ b/libstdc++-v3/testsuite/20_util/headers/memory/synopsis.cc
@@ -22,6 +22,8 @@
 
 #if __cplusplus >= 201103L
 # define NOTHROW noexcept
+#else
+# define NOTHROW
 #endif
 
 namespace std {
diff --git a/libstdc++-v3/testsuite/20_util/shared_ptr/creation/99006.cc b/libstdc++-v3/testsuite/20_util/shared_ptr/creation/99006.cc
index d5f7a5da5e9d2..e070fb9d42057 100644
--- a/libstdc++-v3/testsuite/20_util/shared_ptr/creation/99006.cc
+++ b/libstdc++-v3/testsuite/20_util/shared_ptr/creation/99006.cc
@@ -1,5 +1,5 @@
-// FIXME: This should use { target { ! c++20 } }
-// { dg-do compile }
+// FIXME: This should use { target { c++11 && { ! c++20 } } }
+// { dg-do compile { target { c++11 } } }
 
 #include <memory>
 
diff --git a/libstdc++-v3/testsuite/25_algorithms/copy/debug/99402.cc b/libstdc++-v3/testsuite/25_algorithms/copy/debug/99402.cc
index 041d222d07900..9a9c97af6052d 100644
--- a/libstdc++-v3/testsuite/25_algorithms/copy/debug/99402.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/copy/debug/99402.cc
@@ -28,8 +28,9 @@ using namespace std;
 
 int main()
 {
+    int two[] = { 0, 1 };
     // any container with non-random access iterators:
-    const set<int> source = { 0, 1 };
+    const set<int> source(two, two + 2);
     vector<int> dest(1);
     copy(source.begin(), ++source.begin(), dest.begin());
 }

From 9625dd9e58b99fe934e67b280c1f26f332be644c Mon Sep 17 00:00:00 2001
From: Joseph Myers <joseph@codesourcery.com>
Date: Tue, 11 May 2021 21:07:26 +0000
Subject: [PATCH 105/164] Update gcc ja.po.

	* ja.po: Update.
---
 gcc/po/ja.po | 84 ++++++++++++++++++++++------------------------------
 1 file changed, 36 insertions(+), 48 deletions(-)

diff --git a/gcc/po/ja.po b/gcc/po/ja.po
index 049450eec1359..419991929b526 100644
--- a/gcc/po/ja.po
+++ b/gcc/po/ja.po
@@ -19,10 +19,10 @@
 # Hiroshi Takekawa <sian@big.or.jp>, <sian.ht@gmail.com>, 2020, 2021
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 11.1-b20210207\n"
+"Project-Id-Version: gcc 11.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
 "POT-Creation-Date: 2021-04-20 18:19+0000\n"
-"PO-Revision-Date: 2021-02-10 19:45+0900\n"
+"PO-Revision-Date: 2021-05-11 22:47+0900\n"
 "Last-Translator: Hiroshi Takekawa <sian@big.or.jp>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
 "Language: ja\n"
@@ -512,10 +512,6 @@ msgid ""
 "                           'none' means revert to the default behavior of\n"
 "                           guessing the language based on the file's extension.\n"
 msgstr ""
-"  -x <language>            これ以降入力するファイルの言語を指定する。\n"
-"                           指定可能な言語は: c c++ assembler none\n"
-"                           'none' が指定されるとデフォルトのふるまいである\n"
-"                           拡張子から言語を推測する。\n"
 
 #: gcc.c:3798
 #, c-format
@@ -908,14 +904,14 @@ msgid "  -p, --preserve-paths            Preserve all pathname components\n"
 msgstr "  -p, --preserve-paths            すべてのパス名要素を保護する\n"
 
 #: gcov.c:944
-#, fuzzy, c-format
+#, c-format
 msgid "  -q, --use-hotness-colors        Emit perf-like colored output for hot lines\n"
-msgstr "  -n, --no-output                 出力ファイルを作成しない\n"
+msgstr "  -q, --use-hotness-colors        perf のように hot line に色をつける\n"
 
 #: gcov.c:945
-#, fuzzy, c-format
+#, c-format
 msgid "  -r, --relative-only             Only show data for relative sources\n"
-msgstr "  -a, --all-blocks                各基本ブロックに関する情報を表示する\n"
+msgstr "  -r, --relative-only             相対ソースのデータのみ表示する\n"
 
 #: gcov.c:946
 #, c-format
@@ -1498,9 +1494,8 @@ msgid "function not considered for inlining"
 msgstr "inline に出来ると見なされていない関数です"
 
 #: cif-code.def:43
-#, fuzzy
 msgid "caller is not optimized"
-msgstr "%qE は初期化されていません"
+msgstr "caller は最適化されていません"
 
 #: cif-code.def:47
 msgid "function body not available"
@@ -1596,9 +1591,8 @@ msgid "callee refers to comdat-local symbols"
 msgstr ""
 
 #: cif-code.def:134
-#, fuzzy
 msgid "sanitizer function attribute mismatch"
-msgstr "関数属性が合いません"
+msgstr "sanitizer関数属性が合いません"
 
 #: cif-code.def:139
 msgid "function has external linkage when the user requests only inlining static for live patching"
@@ -1993,14 +1987,12 @@ msgid "invalid address mode"
 msgstr "無効なアドレスモードです"
 
 #: config/aarch64/aarch64.c:25211 config/arm/arm.c:33660
-#, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
-msgstr "%<__fpreg%> からの無効な変換です"
+msgstr "%<bfloat16_t%> からの無効な変換です"
 
 #: config/aarch64/aarch64.c:25213 config/arm/arm.c:33662
-#, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
-msgstr "無効なバージョン番号形式"
+msgstr "%<bfloat16_t%> への無効な変換です"
 
 #: config/aarch64/aarch64.c:25228 config/aarch64/aarch64.c:25244
 #: config/arm/arm.c:33677 config/arm/arm.c:33693
@@ -2008,9 +2000,8 @@ msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
 #: config/aarch64/aarch64.c:25252
-#, fuzzy
 msgid "cannot combine GNU and SVE vectors in a binary operation"
-msgstr "二進演算内で無効な被演算子です"
+msgstr "GNU と SVE ベクタの二項演算はできません"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13227
 #: config/rs6000/rs6000.c:14147 config/sparc/sparc.c:9323
@@ -2233,9 +2224,8 @@ msgid "operands to %T/%t must be reg + const_int:"
 msgstr "出力被演算子 %d は %<&%> 制約を使用しなければいけません"
 
 #: config/avr/avr.c:2863 config/avr/avr.c:2930
-#, fuzzy
 msgid "bad address, not an I/O address:"
-msgstr "誤ったアドレスです。(reg+disp) ではありません:"
+msgstr "誤ったアドレスです。I/O アドレスではありません:"
 
 #: config/avr/avr.c:2872
 msgid "bad address, not a constant:"
@@ -2304,9 +2294,8 @@ msgid "structure field"
 msgstr "構造体フィールド"
 
 #: config/avr/avr.c:10039
-#, fuzzy
 msgid "return type of function"
-msgstr "`%s' の宣言は関数の配列"
+msgstr "関数の戻り値の型"
 
 #: config/avr/avr.c:10044
 msgid "pointer"
@@ -2567,9 +2556,9 @@ msgid "operand %%xn code invalid for QImode"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'Y' です"
 
 #: config/gcn/gcn.c:6171
-#, fuzzy, c-format
+#, c-format
 msgid "invalid fp constant"
-msgstr "無効な命令:"
+msgstr "無効な浮動小数点定数です"
 
 #: config/h8300/h8300.c:1565 config/h8300/h8300.c:1573
 #: config/h8300/h8300.c:1581 config/h8300/h8300.c:1589
@@ -2584,9 +2573,9 @@ msgid "invalid UNSPEC as operand"
 msgstr "被演算子として無効な UNSPEC です"
 
 #: config/i386/i386.c:12591
-#, fuzzy, c-format
+#, c-format
 msgid "invalid use of register '%s'"
-msgstr "%<restrict%> の誤った使用法です"
+msgstr "'%s' の誤った用法です"
 
 #: config/i386/i386.c:12596
 #, fuzzy, c-format
@@ -2673,9 +2662,9 @@ msgid "unknown insn mode"
 msgstr "不明な命令モード"
 
 #: config/i386/djgpp.h:143
-#, fuzzy, c-format
+#, c-format
 msgid "-f%s ignored (not supported for DJGPP)\n"
-msgstr "Unicos/Mk 用としては -f%s は無視されました (サポートされていません)"
+msgstr "-f%s は (DJGPP ではサポートされていないので) 無視されました\n"
 
 #: config/ia64/ia64.c:5459
 #, c-format
@@ -2874,14 +2863,14 @@ msgid "invalid zero extract"
 msgstr "%<restrict%> の誤った使用法です"
 
 #: config/or1k/or1k.c:1116 config/or1k/or1k.c:1124
-#, fuzzy, c-format
+#, c-format
 msgid "invalid relocation"
-msgstr "無効な %%d 被演算子です"
+msgstr "無効な再配置です"
 
 #: config/or1k/or1k.c:1218
-#, fuzzy, c-format
+#, c-format
 msgid "invalid %%H value"
-msgstr "無効な %%J 値"
+msgstr "無効な %%H 値"
 
 #: config/or1k/or1k.c:1231 config/xtensa/xtensa.c:2473
 #, c-format
@@ -2919,14 +2908,14 @@ msgid "unsupported operand %s for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
 #: config/pru/pru.c:1870
-#, fuzzy, c-format
+#, c-format
 msgid "unexpected text address:"
-msgstr "アドレス内の予期しない副作用"
+msgstr "予期しないテキストアドレス:"
 
 #: config/pru/pru.c:1889
-#, fuzzy, c-format
+#, c-format
 msgid "unsupported constant address:"
-msgstr "サポートされていない組み合わせです: %s"
+msgstr "サポートされていない定数アドレス:"
 
 #: config/pru/pru.c:1950
 #, fuzzy, c-format
@@ -2991,7 +2980,7 @@ msgid "Bad 128-bit move"
 msgstr "誤った 128 ビット move"
 
 #: config/rs6000/rs6000.c:13589
-#, fuzzy, c-format
+#, c-format
 msgid "invalid %%A value"
 msgstr "無効な %%A 値"
 
@@ -3001,7 +2990,7 @@ msgid "invalid %%D value"
 msgstr "無効な %%D 値です"
 
 #: config/rs6000/rs6000.c:13613
-#, fuzzy, c-format
+#, c-format
 msgid "invalid %%e value"
 msgstr "無効な %%e 値"
 
@@ -3051,7 +3040,7 @@ msgid "invalid %%q value"
 msgstr "無効な %%q 値です"
 
 #: config/rs6000/rs6000.c:13858
-#, fuzzy, c-format
+#, c-format
 msgid "invalid %%t value"
 msgstr "無効な %%t 値"
 
@@ -3081,9 +3070,9 @@ msgid "invalid %%x value"
 msgstr "無効な %%x 値です"
 
 #: config/rs6000/rs6000.c:14025
-#, fuzzy, c-format
+#, c-format
 msgid "invalid %%z value"
-msgstr "無効な %%J 値"
+msgstr "無効な %%z 値"
 
 #: config/rs6000/rs6000.c:14094
 #, c-format
@@ -3114,14 +3103,12 @@ msgid "Bad GPR fusion"
 msgstr ""
 
 #: config/rs6000/rs6000.c:27776
-#, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
-msgstr "%<__fpreg%> からの無効な変換です"
+msgstr "%<__vector_quad%> からの無効な変換です"
 
 #: config/rs6000/rs6000.c:27778
-#, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
-msgstr "無効なバージョン番号形式"
+msgstr "%<__vector_quad%> への無効な変換です"
 
 #: config/rs6000/rs6000.c:27780
 #, fuzzy
@@ -58665,8 +58652,9 @@ msgstr "クラス名が予期されます"
 
 #: d/dmd/dsymbolsem.c:1372
 #, fuzzy, gcc-internal-format
+#| msgid "unexpected text address:"
 msgid "function name expected for start address"
-msgstr "アドレス内の予期しない副作用"
+msgstr "予期しないテキストアドレス:"
 
 #: d/dmd/dsymbolsem.c:1387
 #, gcc-internal-format, gfc-internal-format

From 0ffbf77146542299e3873a136bf64cb82ad0cbdc Mon Sep 17 00:00:00 2001
From: Geng Qi <gengqi@linux.alibaba.com>
Date: Wed, 28 Apr 2021 16:29:33 +0800
Subject: [PATCH 106/164] RISC-V: For '-march' and '-mabi' options, add
 'Negative' property mentions itself.

When use multi-lib riscv-tool-chain. A bug is triggered when there are two
'-march' at command line.
riscv64-unknown-elf-gcc -march=rv32gcp -mabi=ilp32f -march=rv32gcpzp64 HelloWorld.c
/lhome/gengq/riscv64-linux-ptest/lib/gcc/riscv64-unknown-elf/10.2.0/../../../../riscv64-unknown-elf/bin/ld: /lhome/gengq/riscv64-linux-ptest/lib/gcc/riscv64-unknown-elf/10.2.0/../../../../riscv64-unknown-elf/lib/crt0.o: ABI is incompatible with that of the selected emulation:
  target emulation `elf64-littleriscv' does not match `elf32-littleriscv'
/lhome/gengq/riscv64-linux-ptest/lib/gcc/riscv64-unknown-elf/10.2.0/../../../../riscv64-unknown-elf/bin/ld: failed to merge target specific data of file /lhome/gengq/riscv64-linux-ptest/lib/gcc/riscv64-unknown-elf/10.2.0/../../../../riscv64-unknown-elf/lib/crt0.o
/lhome/gengq/riscv64-linux-ptest/lib/gcc/riscv64-unknown-elf/10.2.0/../../../../riscv64-unknown-elf/bin/ld: /lhome/gengq/riscv64-linux-ptest/lib/gcc/riscv64-unknown-elf/10.2.0/crtbegin.o: ABI is incompatible with that of the selected emulation:
  target emulation `elf64-littleriscv' does not match `elf32-littleriscv'
/lhome/gengq/riscv64-linux-ptest/lib/gcc/riscv64-unknown-elf/10.2.0/../../../../riscv64-unknown-elf/bin/ld: failed to merge target specific data of file /lhome/gengq/riscv64-linux-ptest/lib/gcc/riscv64-unknown-elf/10.2.0/crtbegin.o
......

This patch fix it. And the DRIVER would prune the extra '-march' and '-mabi'
options and keep only the last one valid.

gcc/ChangeLog:
	* config/riscv/riscv.opt (march=,mabi=): Negative itself.

(cherry picked from commit 17f2908fcf058e145cff275966e34f8c7f57c2c5)
---
 gcc/config/riscv/riscv.opt | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gcc/config/riscv/riscv.opt b/gcc/config/riscv/riscv.opt
index e294e22315136..5ff85c2143077 100644
--- a/gcc/config/riscv/riscv.opt
+++ b/gcc/config/riscv/riscv.opt
@@ -38,7 +38,7 @@ Target Var(TARGET_PLT) Init(1)
 When generating -fpic code, allow the use of PLTs. Ignored for fno-pic.
 
 mabi=
-Target RejectNegative Joined Enum(abi_type) Var(riscv_abi) Init(ABI_ILP32)
+Target RejectNegative Joined Enum(abi_type) Var(riscv_abi) Init(ABI_ILP32) Negative(mabi=)
 Specify integer and floating-point calling convention.
 
 mpreferred-stack-boundary=
@@ -79,7 +79,7 @@ Target Mask(DIV)
 Use hardware instructions for integer division.
 
 march=
-Target RejectNegative Joined
+Target RejectNegative Joined Negative(march=)
 -march=	Generate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be
 lower-case.
 

From e3f08b40a1f7195f72bcb1651884562c4b891157 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Wed, 12 May 2021 08:52:58 +0000
Subject: [PATCH 107/164] Daily bump.

---
 gcc/ChangeLog           |   14 +
 gcc/DATESTAMP           |    2 +-
 gcc/po/ChangeLog        |    4 +
 gcc/testsuite/ChangeLog |    5 +
 libstdc++-v3/ChangeLog  | 1182 +++++++++++++++++++++++++++++++++++++++
 5 files changed, 1206 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 46971cf134403..6e23daffbbe47 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,17 @@
+2021-05-12  Geng Qi  <gengqi@linux.alibaba.com>
+
+	Backported from master:
+	2021-04-30  Geng Qi  <gengqi@linux.alibaba.com>
+
+	* config/riscv/riscv.opt (march=,mabi=): Negative itself.
+
+2021-05-11  Alex Coplan  <alex.coplan@arm.com>
+
+	PR target/99988
+	* config/aarch64/aarch64-bti-insert.c (aarch64_bti_j_insn_p): New.
+	(rest_of_insert_bti): Avoid inserting duplicate bti j insns for
+	jump table targets.
+
 2021-05-06  Marius Hillenbrand  <mhillen@linux.ibm.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index abf046def4857..d14314023a18d 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210511
+20210512
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index 961db425e0650..bda4fea6f2d8b 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,7 @@
+2021-05-11  Joseph Myers  <joseph@codesourcery.com>
+
+	* ja.po: Update.
+
 2021-04-29  Joseph Myers  <joseph@codesourcery.com>
 
 	* sv.po: Update.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index f8a03d7b6497d..1f99d9ed50d4e 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,8 @@
+2021-05-11  Alex Coplan  <alex.coplan@arm.com>
+
+	PR target/99988
+	* gcc.target/aarch64/pr99988.c: New test.
+
 2021-05-10  Iain Buclaw  <ibuclaw@gdcproject.org>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index c7fbc03f39cac..1dc99faf1fa9e 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,1185 @@
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/20_util/headers/memory/synopsis.cc: Define C++98
+	alternative for macro.
+	* testsuite/20_util/shared_ptr/creation/99006.cc: Add effective
+	target keyword.
+	* testsuite/25_algorithms/copy/debug/99402.cc: Avoid C++11
+	syntax.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/allocator.h (allocator<void>) [C++20]: Add
+	missing noexcept to constructor. Restore missing POCMA and
+	is_always_equal_traits.
+	[C++17]: Make construct and destroy members private and
+	declare allocator_traits as a friend.
+	* include/bits/memoryfwd.h (allocator_traits): Declare.
+	* include/ext/malloc_allocator.h (malloc_allocator::allocate):
+	Add nodiscard attribute. Add static assertion for LWG 3307.
+	* include/ext/new_allocator.h (new_allocator::allocate): Add
+	static assertion for LWG 3307.
+	* testsuite/20_util/allocator/void.cc: Check that converting
+	constructor is noexcept. Check for propagation traits and
+	size_type and difference_type. Check that pointer and
+	const_pointer are gone in C++20.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/stop_token: Remove TODO comment.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/shared_ptr_base.h (__shared_count(unique_ptr&&)):
+	Initialize a non-reference deleter from an rvalue, as per LWG
+	3548.
+	(__shared_ptr::_UniqCompatible): Add missing constraint.
+	* testsuite/20_util/shared_ptr/cons/lwg3548.cc: New test.
+	* testsuite/20_util/shared_ptr/cons/unique_ptr_deleter.cc: Check
+	constraints.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/17_intro/headers/c++2017/all_attributes.cc: Remove
+	-std=gnu++17 from dg-options directive.
+	* testsuite/17_intro/headers/c++2017/all_no_exceptions.cc:
+	Likewise.
+	* testsuite/17_intro/headers/c++2017/all_pedantic_errors.cc:
+	Likewise.
+	* testsuite/17_intro/headers/c++2017/operator_names.cc:
+	Likewise.
+	* testsuite/17_intro/headers/c++2017/parallel_mode.cc: Likewise.
+	* testsuite/17_intro/headers/c++2017/stdc++.cc: Likewise.
+	* testsuite/17_intro/headers/c++2017/stdc++_multiple_inclusion.cc:
+	Likewise.
+	* testsuite/18_support/aligned_alloc/aligned_alloc.cc: Likewise.
+	* testsuite/18_support/byte/81076.cc: Likewise.
+	* testsuite/18_support/byte/global_neg.cc: Likewise.
+	* testsuite/18_support/byte/ops.cc: Likewise.
+	* testsuite/18_support/byte/requirements.cc: Likewise.
+	* testsuite/18_support/headers/cfloat/values_c++17.cc: Likewise.
+	* testsuite/18_support/launder/1.cc: Likewise.
+	* testsuite/18_support/launder/nodiscard.cc: Likewise.
+	* testsuite/18_support/launder/requirements.cc: Likewise.
+	* testsuite/18_support/launder/requirements_neg.cc: Likewise.
+	* testsuite/18_support/new_aligned.cc: Likewise.
+	* testsuite/18_support/uncaught_exceptions/uncaught_exceptions.cc:
+	Likewise.
+	* testsuite/19_diagnostics/error_code/is_error_code_v.cc:
+	Likewise.
+	* testsuite/19_diagnostics/error_condition/hash.cc: Likewise.
+	* testsuite/20_util/addressof/requirements/constexpr.cc:
+	Likewise.
+	* testsuite/20_util/as_const/1.cc: Likewise.
+	* testsuite/20_util/as_const/rvalue_neg.cc: Likewise.
+	* testsuite/20_util/bind/83427.cc: Likewise.
+	* testsuite/20_util/bind/is_placeholder_v.cc: Likewise.
+	* testsuite/20_util/bool_constant/requirements.cc: Likewise.
+	* testsuite/20_util/duration/arithmetic/constexpr_c++17.cc:
+	Likewise.
+	* testsuite/20_util/duration/requirements/treat_as_floating_point_v.cc:
+	Likewise.
+	* testsuite/20_util/duration_cast/rounding.cc: Likewise.
+	* testsuite/20_util/enable_shared_from_this/members/weak_from_this.cc:
+	Likewise.
+	* testsuite/20_util/from_chars/1_neg.cc: Likewise.
+	* testsuite/20_util/from_chars/requirements.cc: Likewise.
+	* testsuite/20_util/function/91456.cc: Likewise.
+	* testsuite/20_util/function/cons/deduction.cc: Likewise.
+	* testsuite/20_util/function_objects/83607.cc: Likewise.
+	* testsuite/20_util/function_objects/invoke/59768.cc: Likewise.
+	* testsuite/20_util/function_objects/mem_fn/80478.cc: Likewise.
+	* testsuite/20_util/function_objects/not_fn/1.cc: Likewise.
+	* testsuite/20_util/function_objects/not_fn/87538.cc: Likewise.
+	* testsuite/20_util/has_unique_object_representations/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/20_util/has_unique_object_representations/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/20_util/has_unique_object_representations/value.cc:
+	Likewise.
+	* testsuite/20_util/hash/nullptr.cc: Likewise.
+	* testsuite/20_util/in_place/requirements.cc: Likewise.
+	* testsuite/20_util/is_aggregate/incomplete_neg.cc: Likewise.
+	* testsuite/20_util/is_aggregate/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/20_util/is_aggregate/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/20_util/is_aggregate/value.cc: Likewise.
+	* testsuite/20_util/is_invocable/83395.cc: Likewise.
+	* testsuite/20_util/is_invocable/91456.cc: Likewise.
+	* testsuite/20_util/is_invocable/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/20_util/is_invocable/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/20_util/is_invocable/value.cc: Likewise.
+	* testsuite/20_util/is_literal_type/deprecated-1z.cc: Likewise.
+	* testsuite/20_util/is_nothrow_constructible/94003.cc: Likewise.
+	* testsuite/20_util/is_nothrow_invocable/83395.cc: Likewise.
+	* testsuite/20_util/is_nothrow_invocable/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/20_util/is_nothrow_invocable/requirements/typedefs.cc: Likewise.
+	* testsuite/20_util/is_nothrow_invocable/value.cc: Likewise.
+	* testsuite/20_util/is_nothrow_swappable/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/20_util/is_nothrow_swappable/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/20_util/is_nothrow_swappable/value.cc: Likewise.
+	* testsuite/20_util/is_nothrow_swappable_with/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/20_util/is_nothrow_swappable_with/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/20_util/is_nothrow_swappable_with/value.cc:
+	Likewise.
+	* testsuite/20_util/is_swappable/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/20_util/is_swappable/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/20_util/is_swappable/value.cc: Likewise.
+	* testsuite/20_util/is_swappable_with/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/20_util/is_swappable_with/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/20_util/is_swappable_with/value.cc: Likewise.
+	* testsuite/20_util/logical_traits/83134.cc: Likewise.
+	* testsuite/20_util/logical_traits/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/20_util/logical_traits/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/20_util/logical_traits/value.cc: Likewise.
+	* testsuite/20_util/pair/cons/deduction.cc: Likewise.
+	* testsuite/20_util/pair/swap_cxx17.cc: Likewise.
+	* testsuite/20_util/ratio/requirements/ratio_equal_v.cc:
+	Likewise.
+	* testsuite/20_util/reference_wrapper/83427.cc: Likewise.
+	* testsuite/20_util/reference_wrapper/deduction.cc: Likewise.
+	* testsuite/20_util/shared_ptr/casts/reinterpret.cc: Likewise.
+	* testsuite/20_util/shared_ptr/cons/deduction.cc: Likewise.
+	* testsuite/20_util/shared_ptr/requirements/weak_type.cc:
+	Likewise.
+	* testsuite/20_util/time_point/arithmetic/constexpr.cc:
+	Likewise.
+	* testsuite/20_util/time_point_cast/rounding.cc: Likewise.
+	* testsuite/20_util/to_chars/3.cc: Likewise.
+	* testsuite/20_util/to_chars/chars_format.cc: Likewise.
+	* testsuite/20_util/to_chars/lwg3266.cc: Likewise.
+	* testsuite/20_util/to_chars/requirements.cc: Likewise.
+	* testsuite/20_util/tuple/78939.cc: Likewise.
+	* testsuite/20_util/tuple/apply/1.cc: Likewise.
+	* testsuite/20_util/tuple/apply/2.cc: Likewise.
+	* testsuite/20_util/tuple/cons/deduction.cc: Likewise.
+	* testsuite/20_util/tuple/make_from_tuple/1.cc: Likewise.
+	* testsuite/20_util/tuple/make_from_tuple/2.cc: Likewise.
+	* testsuite/20_util/tuple/swap_cxx17.cc: Likewise.
+	* testsuite/20_util/tuple/tuple_size_v.cc: Likewise.
+	* testsuite/20_util/unique_ptr/cons/deduction_neg.cc: Likewise.
+	* testsuite/20_util/uses_allocator/requirements/uses_allocator_v.cc:
+	Likewise.
+	* testsuite/20_util/variable_templates_for_traits.cc: Likewise.
+	* testsuite/20_util/void_t/1.cc: Likewise.
+	* testsuite/20_util/weak_ptr/cons/deduction.cc: Likewise.
+	* testsuite/24_iterators/container_access.cc: Likewise.
+	* testsuite/24_iterators/headers/iterator/range_access_c++17.cc:
+	Likewise.
+	* testsuite/24_iterators/headers/iterator/synopsis_c++17.cc:
+	Likewise.
+	* testsuite/24_iterators/range_access/range_access_cpp17.cc:
+	Likewise.
+	* testsuite/24_iterators/range_access/range_access_cpp17_neg.cc:
+	Likewise.
+	* testsuite/26_numerics/gcd/gcd_neg.cc: Likewise.
+	* testsuite/26_numerics/headers/cmath/functions_std_c++17.cc:
+	Likewise.
+	* testsuite/26_numerics/headers/cmath/hypot.cc: Likewise.
+	* testsuite/26_numerics/headers/cmath/special_functions_global.cc:
+	Likewise.
+	* testsuite/26_numerics/lcm/1.cc: Likewise.
+	* testsuite/26_numerics/lcm/lcm_neg.cc: Likewise.
+	* testsuite/26_numerics/valarray/deduction.cc: Likewise.
+	* testsuite/27_io/basic_ostream/inserters_other/char/lwg2221.cc:
+	Likewise.
+	* testsuite/27_io/manipulators/standard/char/quoted_sv.cc:
+	Likewise.
+	* testsuite/27_io/manipulators/standard/wchar_t/quoted_sv.cc:
+	Likewise.
+	* testsuite/27_io/types/4.cc: Likewise.
+	* testsuite/28_regex/basic_regex/ctors/deduction.cc: Likewise.
+	* testsuite/libstdc++-prettyprinters/91997.cc: Likewise.
+	* testsuite/libstdc++-prettyprinters/cxx17.cc: Likewise.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/20_util/function_objects/searchers.cc: Remove
+	-std=gnu++17 from dg-options directive.
+	* testsuite/20_util/specialized_algorithms/memory_management_tools/1.cc:
+	Likewise.
+	* testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc:
+	Likewise.
+	* testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94540.cc:
+	Likewise.
+	* testsuite/20_util/specialized_algorithms/uninitialized_value_construct/94831.cc:
+	Likewise.
+	* testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/94540.cc:
+	Likewise.
+	* testsuite/20_util/specialized_algorithms/uninitialized_value_construct_n/sizes.cc:
+	Likewise.
+	* testsuite/20_util/unique_ptr/specialized_algorithms/swap_cxx17.cc:
+	Likewise.
+	* testsuite/25_algorithms/clamp/1.cc: Likewise.
+	* testsuite/25_algorithms/clamp/2.cc: Likewise.
+	* testsuite/25_algorithms/clamp/constexpr.cc: Likewise.
+	* testsuite/25_algorithms/clamp/requirements/explicit_instantiation/1.cc:
+	Likewise.
+	* testsuite/25_algorithms/clamp/requirements/explicit_instantiation/pod.cc:
+	Likewise.
+	* testsuite/25_algorithms/for_each/for_each_n.cc: Likewise.
+	* testsuite/25_algorithms/for_each/for_each_n_debug.cc:
+	Likewise.
+	* testsuite/25_algorithms/sample/1.cc: Likewise.
+	* testsuite/25_algorithms/sample/2.cc: Likewise.
+	* testsuite/25_algorithms/sample/3.cc: Likewise.
+	* testsuite/25_algorithms/sample/81221.cc: Likewise.
+	* testsuite/25_algorithms/search/searcher.cc: Likewise.
+	* testsuite/26_numerics/exclusive_scan/1.cc: Likewise.
+	* testsuite/26_numerics/inclusive_scan/1.cc: Likewise.
+	* testsuite/26_numerics/reduce/1.cc: Likewise.
+	* testsuite/26_numerics/reduce/2.cc: Likewise.
+	* testsuite/26_numerics/transform_exclusive_scan/1.cc: Likewise.
+	* testsuite/26_numerics/transform_inclusive_scan/1.cc: Likewise.
+	* testsuite/26_numerics/transform_reduce/1.cc: Likewise.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/23_containers/array/cons/deduction.cc: Remove
+	-std=gnu++17 from dg-options directive.
+	* testsuite/23_containers/array/cons/deduction_neg.cc: Likewise.
+	* testsuite/23_containers/array/element_access/constexpr_c++17.cc:
+	Likewise.
+	* testsuite/23_containers/array/requirements/constexpr_iter.cc:
+	Likewise.
+	* testsuite/23_containers/array/specialized_algorithms/swap_cxx17.cc:
+	Likewise.
+	* testsuite/23_containers/deque/cons/deduction.cc: Likewise.
+	* testsuite/23_containers/deque/modifiers/emplace/cxx17_return.cc:
+	Likewise.
+	* testsuite/23_containers/forward_list/cons/deduction.cc:
+	Likewise.
+	* testsuite/23_containers/forward_list/modifiers/emplace_cxx17_return.cc:
+	Likewise.
+	* testsuite/23_containers/list/cons/deduction.cc: Likewise.
+	* testsuite/23_containers/list/modifiers/emplace/cxx17_return.cc:
+	Likewise.
+	* testsuite/23_containers/map/cons/deduction.cc: Likewise.
+	* testsuite/23_containers/map/modifiers/extract.cc: Likewise.
+	* testsuite/23_containers/map/modifiers/insert/83226.cc:
+	Likewise.
+	* testsuite/23_containers/map/modifiers/insert_or_assign/1.cc:
+	Likewise.
+	* testsuite/23_containers/map/modifiers/merge.cc: Likewise.
+	* testsuite/23_containers/map/modifiers/try_emplace/1.cc:
+	Likewise.
+	* testsuite/23_containers/multimap/cons/deduction.cc: Likewise.
+	* testsuite/23_containers/multimap/modifiers/extract.cc:
+	Likewise.
+	* testsuite/23_containers/multimap/modifiers/merge.cc: Likewise.
+	* testsuite/23_containers/multiset/cons/deduction.cc: Likewise.
+	* testsuite/23_containers/multiset/modifiers/extract.cc:
+	Likewise.
+	* testsuite/23_containers/multiset/modifiers/merge.cc: Likewise.
+	* testsuite/23_containers/priority_queue/deduction.cc: Likewise.
+	* testsuite/23_containers/queue/deduction.cc: Likewise.
+	* testsuite/23_containers/queue/members/emplace_cxx17_return.cc:
+	Likewise.
+	* testsuite/23_containers/set/cons/deduction.cc: Likewise.
+	* testsuite/23_containers/set/modifiers/extract.cc: Likewise.
+	* testsuite/23_containers/set/modifiers/merge.cc: Likewise.
+	* testsuite/23_containers/set/modifiers/node_swap.cc: Likewise.
+	* testsuite/23_containers/stack/deduction.cc: Likewise.
+	* testsuite/23_containers/stack/members/emplace_cxx17_return.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_map/cons/deduction.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_map/modifiers/extract.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_map/modifiers/insert_or_assign.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_map/modifiers/merge.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_map/modifiers/try_emplace.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multimap/cons/deduction.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multimap/modifiers/extract.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multimap/modifiers/merge.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multiset/cons/deduction.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multiset/modifiers/extract.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multiset/modifiers/merge.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_set/cons/deduction.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_set/modifiers/extract.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_set/modifiers/merge.cc:
+	Likewise.
+	* testsuite/23_containers/vector/bool/emplace_cxx17_return.cc:
+	Likewise.
+	* testsuite/23_containers/vector/cons/89164_c++17.cc: Likewise.
+	* testsuite/23_containers/vector/cons/deduction.cc: Likewise.
+	* testsuite/23_containers/vector/modifiers/emplace/cxx17_return.cc:
+	Likewise.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/21_strings/basic_string/79162.cc: Remove
+	-std=gnu++17 from dg-options directive.
+	* testsuite/21_strings/basic_string/cons/char/7.cc: Likewise.
+	* testsuite/21_strings/basic_string/cons/char/79162.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/cons/char/86138.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/cons/char/9.cc: Likewise.
+	* testsuite/21_strings/basic_string/cons/char/deduction.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/cons/wchar_t/7.cc: Likewise.
+	* testsuite/21_strings/basic_string/cons/wchar_t/79162.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/cons/wchar_t/86138.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/cons/wchar_t/9.cc: Likewise.
+	* testsuite/21_strings/basic_string/cons/wchar_t/deduction.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/hash/hash.cc: Likewise.
+	* testsuite/21_strings/basic_string/lwg2758.cc: Likewise.
+	* testsuite/21_strings/basic_string/lwg2946.cc: Likewise.
+	* testsuite/21_strings/basic_string/modifiers/append/char/4.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/modifiers/append/wchar_t/4.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/modifiers/assign/char/4.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/modifiers/assign/wchar_t/4.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/modifiers/insert/char/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/modifiers/insert/wchar_t/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/modifiers/replace/char/7.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/modifiers/replace/wchar_t/7.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/operations/compare/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/operations/compare/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/operations/data/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/operations/data/char/86169.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/operations/data/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/operations/find/char/5.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/operations/find/wchar_t/5.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/operators/char/5.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/operators/wchar_t/5.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/capacity/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/capacity/empty_neg.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/cons/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/cons/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/cons/char/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/cons/char/nonnull.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/cons/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/cons/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/cons/wchar_t/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/cons/wchar_t/nonnull.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/char/back_constexpr_neg.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/char/constexpr.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/char/constexpr_neg.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/char/empty.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/char/front_back.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/char/front_back_constexpr.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/char/front_constexpr_neg.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/wchar_t/back_constexpr_neg.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/wchar_t/constexpr_neg.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/wchar_t/empty.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/wchar_t/front_back.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/element_access/wchar_t/front_constexpr_neg.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/include.cc: Likewise.
+	* testsuite/21_strings/basic_string_view/inserters/94051.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/inserters/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/inserters/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/inserters/char/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/inserters/pod/10081-out.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/inserters/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/inserters/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/inserters/wchar_t/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/literals/types-char8_t.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/literals/types.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/literals/values-char8_t.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/literals/values.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/remove_prefix/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/remove_prefix/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/remove_suffix/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/remove_suffix/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/compare/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/compare/char/13650.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/compare/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/compare/char/70483.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/compare/char/nonnull.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/compare/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/compare/wchar_t/13650.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/compare/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/copy/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/copy/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/copy/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/copy/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/data/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/data/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/char/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/char/4.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/char/nonnull.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/4.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/rfind/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/rfind/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/rfind/char/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/rfind/char/nonnull.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/rfind/wchar_t/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/string_conversion/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/substr/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/substr/char/83511.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/substr/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/substr/wchar_t/83511.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operators/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operators/char/89446.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operators/wchar_t/89446.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/range_access/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char16_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char32_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/char8_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/requirements/explicit_instantiation/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/requirements/traits_neg.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/typedefs.cc: Likewise.
+	* testsuite/21_strings/basic_string_view/types/1.cc: Likewise.
+	* testsuite/21_strings/char_traits/requirements/char/99181.cc:
+	Likewise.
+	* testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc:
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/20_util/memory_resource/1.cc: Remove -std=gnu++17
+	from dg-options directive.
+	* testsuite/20_util/memory_resource/2.cc: Likewise.
+	* testsuite/20_util/monotonic_buffer_resource/1.cc: Likewise.
+	* testsuite/20_util/monotonic_buffer_resource/93208.cc:
+	Likewise.
+	* testsuite/20_util/monotonic_buffer_resource/allocate.cc:
+	Likewise.
+	* testsuite/20_util/monotonic_buffer_resource/deallocate.cc:
+	Likewise.
+	* testsuite/20_util/monotonic_buffer_resource/release.cc:
+	Likewise.
+	* testsuite/20_util/monotonic_buffer_resource/upstream_resource.cc:
+	Likewise.
+	* testsuite/20_util/polymorphic_allocator/1.cc: Likewise.
+	* testsuite/20_util/polymorphic_allocator/construct_pair.cc:
+	Likewise.
+	* testsuite/20_util/polymorphic_allocator/resource.cc: Likewise.
+	* testsuite/20_util/polymorphic_allocator/select.cc: Likewise.
+	* testsuite/20_util/synchronized_pool_resource/allocate.cc:
+	Likewise.
+	* testsuite/20_util/synchronized_pool_resource/allocate_single.cc:
+	Likewise.
+	* testsuite/20_util/synchronized_pool_resource/cons.cc:
+	Likewise.
+	* testsuite/20_util/synchronized_pool_resource/cons_single.cc:
+	Likewise.
+	* testsuite/20_util/synchronized_pool_resource/is_equal.cc:
+	Likewise.
+	* testsuite/20_util/synchronized_pool_resource/multithreaded.cc:
+	Likewise.
+	* testsuite/20_util/synchronized_pool_resource/options.cc:
+	Likewise.
+	* testsuite/20_util/synchronized_pool_resource/release.cc:
+	Likewise.
+	* testsuite/20_util/synchronized_pool_resource/release_single.cc:
+	Likewise.
+	* testsuite/20_util/unsynchronized_pool_resource/allocate-max-chunks.cc:
+	Likewise.
+	* testsuite/20_util/unsynchronized_pool_resource/allocate.cc:
+	Likewise.
+	* testsuite/20_util/unsynchronized_pool_resource/cons.cc:
+	Likewise.
+	* testsuite/20_util/unsynchronized_pool_resource/is_equal.cc:
+	Likewise.
+	* testsuite/20_util/unsynchronized_pool_resource/options.cc:
+	Likewise.
+	* testsuite/20_util/unsynchronized_pool_resource/release.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string/types/pmr_typedefs.cc:
+	Likewise.
+	* testsuite/23_containers/deque/types/pmr_typedefs.cc: Likewise.
+	* testsuite/23_containers/deque/types/pmr_typedefs_debug.cc:
+	Likewise.
+	* testsuite/23_containers/forward_list/pmr_typedefs.cc:
+	Likewise.
+	* testsuite/23_containers/forward_list/pmr_typedefs_debug.cc:
+	Likewise.
+	* testsuite/23_containers/list/pmr_typedefs.cc: Likewise.
+	* testsuite/23_containers/list/pmr_typedefs_debug.cc: Likewise.
+	* testsuite/23_containers/map/pmr_typedefs.cc: Likewise.
+	* testsuite/23_containers/map/pmr_typedefs_debug.cc: Likewise.
+	* testsuite/23_containers/multimap/pmr_typedefs.cc: Likewise.
+	* testsuite/23_containers/multimap/pmr_typedefs_debug.cc:
+	Likewise.
+	* testsuite/23_containers/multiset/pmr_typedefs.cc: Likewise.
+	* testsuite/23_containers/multiset/pmr_typedefs_debug.cc:
+	Likewise.
+	* testsuite/23_containers/set/pmr_typedefs.cc: Likewise.
+	* testsuite/23_containers/set/pmr_typedefs_debug.cc: Likewise.
+	* testsuite/23_containers/unordered_map/pmr_typedefs.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_map/pmr_typedefs_debug.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multimap/pmr_typedefs.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multimap/pmr_typedefs_debug.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multiset/pmr_typedefs.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_multiset/pmr_typedefs_debug.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_set/pmr_typedefs.cc:
+	Likewise.
+	* testsuite/23_containers/unordered_set/pmr_typedefs_debug.cc:
+	Likewise.
+	* testsuite/23_containers/vector/pmr_typedefs.cc: Likewise.
+	* testsuite/23_containers/vector/types/pmr_typedefs_debug.cc:
+	Likewise.
+	* testsuite/28_regex/match_results/pmr_typedefs.cc: Likewise.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/29_atomics/atomic/69769.cc: Remove -std=gnu++17 from
+	dg-options.
+	* testsuite/29_atomics/atomic/is_always_lock_free.cc:
+	* testsuite/29_atomics/atomic/requirements/typedefs.cc:
+	* testsuite/29_atomics/atomic_integral/is_always_lock_free.cc:
+	* testsuite/29_atomics/atomic_integral/requirements/typedefs.cc:
+	* testsuite/30_threads/lock_guard/cons/deduction.cc: Likewise.
+	* testsuite/30_threads/scoped_lock/cons/1.cc: Likewise.
+	* testsuite/30_threads/scoped_lock/cons/deduction.cc: Likewise.
+	* testsuite/30_threads/scoped_lock/requirements/explicit_instantiation.cc:
+	Likewise.
+	* testsuite/30_threads/scoped_lock/requirements/typedefs.cc:
+	Likewise.
+	* testsuite/30_threads/shared_lock/70766.cc: Likewise.
+	* testsuite/30_threads/shared_mutex/cons/1.cc: Likewise.
+	* testsuite/30_threads/shared_mutex/cons/assign_neg.cc:
+	Likewise.
+	* testsuite/30_threads/shared_mutex/cons/copy_neg.cc: Likewise.
+	* testsuite/30_threads/shared_mutex/requirements/standard_layout.cc:
+	Likewise.
+	* testsuite/30_threads/shared_mutex/try_lock/1.cc: Likewise.
+	* testsuite/30_threads/shared_mutex/try_lock/2.cc: Likewise.
+	* testsuite/30_threads/shared_mutex/unlock/1.cc: Likewise.
+	* testsuite/30_threads/unique_lock/cons/deduction.cc: Likewise.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/20_util/any/assign/1.cc: Remove -std=gnu++17 from
+	dg-options directive.
+	* testsuite/20_util/any/assign/2.cc: Likewise.
+	* testsuite/20_util/any/assign/emplace.cc: Likewise.
+	* testsuite/20_util/any/assign/exception.cc: Likewise.
+	* testsuite/20_util/any/assign/self.cc: Likewise.
+	* testsuite/20_util/any/cons/1.cc: Likewise.
+	* testsuite/20_util/any/cons/2.cc: Likewise.
+	* testsuite/20_util/any/cons/90415.cc: Likewise.
+	* testsuite/20_util/any/cons/92156.cc: Likewise.
+	* testsuite/20_util/any/cons/aligned.cc: Likewise.
+	* testsuite/20_util/any/cons/explicit.cc: Likewise.
+	* testsuite/20_util/any/cons/in_place.cc: Likewise.
+	* testsuite/20_util/any/cons/nontrivial.cc: Likewise.
+	* testsuite/20_util/any/make_any.cc: Likewise.
+	* testsuite/20_util/any/misc/any_cast.cc: Likewise.
+	* testsuite/20_util/any/misc/any_cast_neg.cc: Likewise.
+	* testsuite/20_util/any/misc/any_cast_no_rtti.cc: Likewise.
+	* testsuite/20_util/any/misc/swap.cc: Likewise.
+	* testsuite/20_util/any/modifiers/1.cc: Likewise.
+	* testsuite/20_util/any/modifiers/83658.cc: Likewise.
+	* testsuite/20_util/any/modifiers/92156.cc: Likewise.
+	* testsuite/20_util/any/observers/type.cc: Likewise.
+	* testsuite/20_util/any/requirements.cc: Likewise.
+	* testsuite/20_util/any/typedefs.cc: Likewise.
+	* testsuite/20_util/optional/77288.cc: Likewise.
+	* testsuite/20_util/optional/84601.cc: Likewise.
+	* testsuite/20_util/optional/assignment/1.cc: Likewise.
+	* testsuite/20_util/optional/assignment/2.cc: Likewise.
+	* testsuite/20_util/optional/assignment/3.cc: Likewise.
+	* testsuite/20_util/optional/assignment/4.cc: Likewise.
+	* testsuite/20_util/optional/assignment/5.cc: Likewise.
+	* testsuite/20_util/optional/assignment/6.cc: Likewise.
+	* testsuite/20_util/optional/assignment/7.cc: Likewise.
+	* testsuite/20_util/optional/assignment/8.cc: Likewise.
+	* testsuite/20_util/optional/assignment/9.cc: Likewise.
+	* testsuite/20_util/optional/bad_access.cc: Likewise.
+	* testsuite/20_util/optional/cons/77727.cc: Likewise.
+	* testsuite/20_util/optional/cons/85642.cc: Likewise.
+	* testsuite/20_util/optional/cons/copy.cc: Likewise.
+	* testsuite/20_util/optional/cons/deduction.cc: Likewise.
+	* testsuite/20_util/optional/cons/default.cc: Likewise.
+	* testsuite/20_util/optional/cons/move.cc: Likewise.
+	* testsuite/20_util/optional/cons/trivial.cc: Likewise.
+	* testsuite/20_util/optional/cons/value.cc: Likewise.
+	* testsuite/20_util/optional/cons/value_neg.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/cons/default.cc:
+	Likewise.
+	* testsuite/20_util/optional/constexpr/cons/value.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/in_place.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/make_optional.cc:
+	Likewise.
+	* testsuite/20_util/optional/constexpr/nullopt.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/observers/1.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/observers/2.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/observers/3.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/observers/4.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/observers/5.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/relops/1.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/relops/2.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/relops/3.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/relops/4.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/relops/5.cc: Likewise.
+	* testsuite/20_util/optional/constexpr/relops/6.cc: Likewise.
+	* testsuite/20_util/optional/hash.cc: Likewise.
+	* testsuite/20_util/optional/in_place.cc: Likewise.
+	* testsuite/20_util/optional/make_optional.cc: Likewise.
+	* testsuite/20_util/optional/nullopt.cc: Likewise.
+	* testsuite/20_util/optional/observers/1.cc: Likewise.
+	* testsuite/20_util/optional/observers/2.cc: Likewise.
+	* testsuite/20_util/optional/observers/3.cc: Likewise.
+	* testsuite/20_util/optional/observers/4.cc: Likewise.
+	* testsuite/20_util/optional/observers/5.cc: Likewise.
+	* testsuite/20_util/optional/observers/6.cc: Likewise.
+	* testsuite/20_util/optional/relops/1.cc: Likewise.
+	* testsuite/20_util/optional/relops/2.cc: Likewise.
+	* testsuite/20_util/optional/relops/3.cc: Likewise.
+	* testsuite/20_util/optional/relops/4.cc: Likewise.
+	* testsuite/20_util/optional/relops/5.cc: Likewise.
+	* testsuite/20_util/optional/relops/6.cc: Likewise.
+	* testsuite/20_util/optional/relops/7.cc: Likewise.
+	* testsuite/20_util/optional/requirements.cc: Likewise.
+	* testsuite/20_util/optional/swap/1.cc: Likewise.
+	* testsuite/20_util/optional/swap/2.cc: Likewise.
+	* testsuite/20_util/optional/typedefs.cc: Likewise.
+	* testsuite/20_util/variant/80165.cc: Likewise.
+	* testsuite/20_util/variant/85183.cc: Likewise.
+	* testsuite/20_util/variant/86874.cc: Likewise.
+	* testsuite/20_util/variant/87431.cc: Likewise.
+	* testsuite/20_util/variant/87619.cc: Likewise.
+	* testsuite/20_util/variant/91807.cc: Likewise.
+	* testsuite/20_util/variant/any.cc: Likewise.
+	* testsuite/20_util/variant/compile.cc: Likewise.
+	* testsuite/20_util/variant/deduction.cc: Likewise.
+	* testsuite/20_util/variant/exception_safety.cc: Likewise.
+	* testsuite/20_util/variant/hash.cc: Likewise.
+	* testsuite/20_util/variant/index_type.cc: Likewise.
+	* testsuite/20_util/variant/relops/89851.cc: Likewise.
+	* testsuite/20_util/variant/relops/90008.cc: Likewise.
+	* testsuite/20_util/variant/run.cc: Likewise.
+	* testsuite/20_util/variant/visit.cc: Likewise.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/27_io/basic_filebuf/open/char/path.cc: Remove
+	-std=gnu++17 from dg-options directive.
+	* testsuite/27_io/basic_fstream/cons/char/path.cc: Likewise.
+	* testsuite/27_io/basic_fstream/open/char/path.cc: Likewise.
+	* testsuite/27_io/basic_ifstream/cons/char/path.cc: Likewise.
+	* testsuite/27_io/basic_ifstream/open/char/path.cc: Likewise.
+	* testsuite/27_io/basic_ofstream/cons/char/path.cc: Likewise.
+	* testsuite/27_io/basic_ofstream/open/char/path.cc: Likewise.
+	* testsuite/27_io/filesystem/directory_entry/86597.cc: Likewise.
+	* testsuite/27_io/filesystem/directory_entry/lwg3171.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/file_status/1.cc: Likewise.
+	* testsuite/27_io/filesystem/filesystem_error/cons.cc: Likewise.
+	* testsuite/27_io/filesystem/filesystem_error/copy.cc: Likewise.
+	* testsuite/27_io/filesystem/iterators/91067.cc: Likewise.
+	* testsuite/27_io/filesystem/iterators/caching.cc: Likewise.
+	* testsuite/27_io/filesystem/iterators/directory_iterator.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/iterators/pop.cc: Likewise.
+	* testsuite/27_io/filesystem/iterators/recursion_pending.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/iterators/recursive_directory_iterator.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/absolute.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/all.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/canonical.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/copy.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/copy_file.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/create_directories.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/create_directory.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/create_symlink.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/current_path.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/equivalent.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/exists.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/file_size.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/is_empty.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/last_write_time.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/permissions.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/proximate.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/read_symlink.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/relative.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/remove.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/remove_all.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/rename.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/resize_file.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/space.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/status.cc: Likewise.
+	* testsuite/27_io/filesystem/operations/symlink_status.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/temp_directory_path.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/operations/weakly_canonical.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/append/path.cc: Likewise.
+	* testsuite/27_io/filesystem/path/append/source.cc: Likewise.
+	* testsuite/27_io/filesystem/path/assign/assign.cc: Likewise.
+	* testsuite/27_io/filesystem/path/assign/copy.cc: Likewise.
+	* testsuite/27_io/filesystem/path/compare/compare.cc: Likewise.
+	* testsuite/27_io/filesystem/path/compare/lwg2936.cc: Likewise.
+	* testsuite/27_io/filesystem/path/compare/path.cc: Likewise.
+	* testsuite/27_io/filesystem/path/compare/strings.cc: Likewise.
+	* testsuite/27_io/filesystem/path/concat/92853.cc: Likewise.
+	* testsuite/27_io/filesystem/path/concat/94063.cc: Likewise.
+	* testsuite/27_io/filesystem/path/concat/path.cc: Likewise.
+	* testsuite/27_io/filesystem/path/concat/strings.cc: Likewise.
+	* testsuite/27_io/filesystem/path/construct/80762.cc: Likewise.
+	* testsuite/27_io/filesystem/path/construct/90281.cc: Likewise.
+	* testsuite/27_io/filesystem/path/construct/90634.cc: Likewise.
+	* testsuite/27_io/filesystem/path/construct/copy.cc: Likewise.
+	* testsuite/27_io/filesystem/path/construct/default.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/construct/format.cc: Likewise.
+	* testsuite/27_io/filesystem/path/construct/locale.cc: Likewise.
+	* testsuite/27_io/filesystem/path/construct/range.cc: Likewise.
+	* testsuite/27_io/filesystem/path/construct/string_view.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/decompose/extension.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/decompose/filename.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/decompose/parent_path.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/decompose/relative_path.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/decompose/root_directory.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/decompose/root_name.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/decompose/root_path.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/decompose/stem.cc: Likewise.
+	* testsuite/27_io/filesystem/path/factory/u8path-char8_t.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/factory/u8path.cc: Likewise.
+	* testsuite/27_io/filesystem/path/generation/normal.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/generation/normal2.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/generation/proximate.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/generation/relative.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/generic/94242.cc: Likewise.
+	* testsuite/27_io/filesystem/path/generic/generic_string.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/generic/utf.cc: Likewise.
+	* testsuite/27_io/filesystem/path/generic/wchar_t.cc: Likewise.
+	* testsuite/27_io/filesystem/path/io/dr2989.cc: Likewise.
+	* testsuite/27_io/filesystem/path/itr/components.cc: Likewise.
+	* testsuite/27_io/filesystem/path/itr/traversal.cc: Likewise.
+	* testsuite/27_io/filesystem/path/modifiers/clear.cc: Likewise.
+	* testsuite/27_io/filesystem/path/modifiers/make_preferred.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/modifiers/remove_filename.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/modifiers/replace_extension.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/modifiers/replace_filename.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/modifiers/swap.cc: Likewise.
+	* testsuite/27_io/filesystem/path/native/alloc.cc: Likewise.
+	* testsuite/27_io/filesystem/path/native/string-char8_t.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/native/string.cc: Likewise.
+	* testsuite/27_io/filesystem/path/nonmember/append.cc: Likewise.
+	* testsuite/27_io/filesystem/path/nonmember/cmp.cc: Likewise.
+	* testsuite/27_io/filesystem/path/nonmember/hash_value.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/query/empty.cc: Likewise.
+	* testsuite/27_io/filesystem/path/query/empty_neg.cc:
+	* testsuite/27_io/filesystem/path/query/has_extension.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/query/has_filename.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/query/has_parent_path.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/query/has_relative_path.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/query/has_root_directory.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/query/has_root_name.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/query/has_root_path.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/query/has_stem.cc: Likewise.
+	* testsuite/27_io/filesystem/path/query/is_absolute.cc:
+	Likewise.
+	* testsuite/27_io/filesystem/path/query/is_relative.cc:
+	Likewise.
+	* testsuite/experimental/filesystem/path/construct/string_view.cc:
+	Likewise.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/20_util/specialized_algorithms/pstl/uninitialized_construct.cc:
+	Remove -std=gnu++17 from dg-options.
+	* testsuite/20_util/specialized_algorithms/pstl/uninitialized_copy_move.cc:
+	Likewise.
+	* testsuite/20_util/specialized_algorithms/pstl/uninitialized_fill_destroy.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_merge/inplace_merge.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_merge/merge.cc: Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/copy_if.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/copy_move.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/fill.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/generate.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/is_partitioned.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/partition.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/partition_copy.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/remove.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/remove_copy.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/replace.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/replace_copy.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/rotate.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/rotate_copy.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/swap_ranges.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/transform_binary.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/transform_unary.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/unique.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_modifying_operations/unique_copy_equal.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/adjacent_find.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/all_of.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/any_of.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/count.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/equal.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/find.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/find_end.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/find_first_of.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/find_if.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/for_each.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/mismatch.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/none_of.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/nth_element.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/reverse.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/reverse_copy.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_nonmodifying/search_n.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_sorting/includes.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_sorting/is_heap.cc: Likewise.
+	* testsuite/25_algorithms/pstl/alg_sorting/is_sorted.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_sorting/lexicographical_compare.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_sorting/minmax_element.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_sorting/partial_sort.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_sorting/partial_sort_copy.cc:
+	Likewise.
+	* testsuite/25_algorithms/pstl/alg_sorting/set.cc: Likewise.
+	* testsuite/25_algorithms/pstl/alg_sorting/sort.cc: Likewise.
+	* testsuite/25_algorithms/pstl/feature_test-2.cc: Likewise.
+	* testsuite/25_algorithms/pstl/feature_test-3.cc: Likewise.
+	* testsuite/25_algorithms/pstl/feature_test-4.cc: Likewise.
+	* testsuite/25_algorithms/pstl/feature_test-5.cc: Likewise.
+	* testsuite/25_algorithms/pstl/feature_test.cc: Likewise.
+	* testsuite/26_numerics/pstl/numeric_ops/adjacent_difference.cc:
+	Likewise.
+	* testsuite/26_numerics/pstl/numeric_ops/reduce.cc: Likewise.
+	* testsuite/26_numerics/pstl/numeric_ops/scan.cc: Likewise.
+	* testsuite/26_numerics/pstl/numeric_ops/transform_reduce.cc:
+	Likewise.
+	* testsuite/26_numerics/pstl/numeric_ops/transform_scan.cc:
+	Likewise.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/20_util/scoped_allocator/69293_neg.cc: Add dg-error
+	for additional errors in C++20.
+	* testsuite/20_util/specialized_algorithms/memory_management_tools/destroy_neg.cc:
+	Likewise.
+	* testsuite/20_util/uses_allocator/69293_neg.cc: Likewise.
+	* testsuite/27_io/filesystem/path/io/dr2989.cc: Likewise.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/20_util/variant/compile.cc: Rename 'any' to avoid
+	clash with std::any.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-06  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/type_traits (remove_cvref_t): Define in terms of
+	remove_cvref.
+	* testsuite/20_util/remove_cvref/value.cc: Check alias.
+
+2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-04-22  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/99006
+	* include/bits/shared_ptr.h (allocate_shared): Assert that _Tp
+	is not an array type.
+	* include/bits/shared_ptr_base.h (__allocate_shared): Likewise.
+	* testsuite/20_util/shared_ptr/creation/99006.cc: New test.
+
+2021-05-11  Philippe Blain  <levraiphilippeblain@gmail.com>
+
+	Backported from master:
+	2021-04-21  Philippe Blain  <levraiphilippeblain@gmail.com>
+		    Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/99453
+	* python/Makefile.am: Install libstdc++*-gdb.py more robustly.
+	* python/Makefile.in: Regenerate.
+
+2021-05-11  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2021-05-11  Patrick Palka  <ppalka@redhat.com>
+
+	* src/c++17/ryu/LOCAL_PATCHES: Update.
+	* src/c++17/ryu/ryu_generic_128.h: Remove extern "C".
+	Remove declarations for never-defined functions.
+	* testsuite/20_util/to_chars/4.cc: New test.
+
 2021-05-07  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

From 58ce04708738840fa1917c49f686ce0266ba6e77 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Tue, 11 May 2021 09:07:47 +0200
Subject: [PATCH 108/164] openmp: Fix up taskloop reduction ICE if taskloop has
 no iterations [PR100471]

When a taskloop doesn't have any iterations, GOMP_taskloop* takes an early
return, doesn't create any tasks and more importantly, doesn't create
a taskgroup and doesn't register task reductions.  But, the code emitted
in the callers assumes task reductions have been registered and performs
the reduction handling and task reduction unregistration.  The pointer
to the task reduction private variables is reused, on input it is the alignment
and only on output it is the pointer, so in the case taskloop with no iterations
the caller attempts to dereference the alignment value as if it was a pointer
and crashes.  We could in the early returns register the task reductions
only to have them looped over and unregistered in the caller, but I think
it is better to tell the caller there is nothing to task reduce and bypass
all that.

2021-05-11  Jakub Jelinek  <jakub@redhat.com>

	PR middle-end/100471
	* omp-low.c (lower_omp_task_reductions): For OMP_TASKLOOP, if data
	is 0, bypass the reduction loop including
	GOMP_taskgroup_reduction_unregister call.

	* taskloop.c (GOMP_taskloop): If GOMP_TASK_FLAG_REDUCTION and not
	GOMP_TASK_FLAG_NOGROUP, when doing early return clear the task
	reduction pointer.
	* testsuite/libgomp.c/task-reduction-4.c: New test.

(cherry picked from commit 98acbb3111fcb5e57d5e63d46c0d92f4e53e3c2a)
---
 gcc/omp-low.c                                 | 12 +++++++++-
 libgomp/taskloop.c                            | 22 ++++++++++++++-----
 .../testsuite/libgomp.c/task-reduction-4.c    | 21 ++++++++++++++++++
 3 files changed, 49 insertions(+), 6 deletions(-)
 create mode 100644 libgomp/testsuite/libgomp.c/task-reduction-4.c

diff --git a/gcc/omp-low.c b/gcc/omp-low.c
index 7b122059c6e83..1bb7f2b356156 100644
--- a/gcc/omp-low.c
+++ b/gcc/omp-low.c
@@ -8679,7 +8679,7 @@ lower_omp_task_reductions (omp_context *ctx, enum tree_code code, tree clauses,
   tree num_thr_sz = create_tmp_var (size_type_node);
   tree lab1 = create_artificial_label (UNKNOWN_LOCATION);
   tree lab2 = create_artificial_label (UNKNOWN_LOCATION);
-  tree lab3 = NULL_TREE;
+  tree lab3 = NULL_TREE, lab7 = NULL_TREE;
   gimple *g;
   if (code == OMP_FOR || code == OMP_SECTIONS)
     {
@@ -8744,6 +8744,14 @@ lower_omp_task_reductions (omp_context *ctx, enum tree_code code, tree clauses,
 	      NULL_TREE, NULL_TREE);
   tree data = create_tmp_var (pointer_sized_int_node);
   gimple_seq_add_stmt (end, gimple_build_assign (data, t));
+  if (code == OMP_TASKLOOP)
+    {
+      lab7 = create_artificial_label (UNKNOWN_LOCATION);
+      g = gimple_build_cond (NE_EXPR, data,
+			     build_zero_cst (pointer_sized_int_node),
+			     lab1, lab7);
+      gimple_seq_add_stmt (end, g);
+    }
   gimple_seq_add_stmt (end, gimple_build_label (lab1));
   tree ptr;
   if (TREE_CODE (TYPE_SIZE_UNIT (record_type)) == INTEGER_CST)
@@ -9107,6 +9115,8 @@ lower_omp_task_reductions (omp_context *ctx, enum tree_code code, tree clauses,
       g = gimple_build_call (t, 1, build_fold_addr_expr (avar));
     }
   gimple_seq_add_stmt (end, g);
+  if (lab7)
+    gimple_seq_add_stmt (end, gimple_build_label (lab7));
   t = build_constructor (atype, NULL);
   TREE_THIS_VOLATILE (t) = 1;
   gimple_seq_add_stmt (end, gimple_build_assign (avar, t));
diff --git a/libgomp/taskloop.c b/libgomp/taskloop.c
index 75697fecb8a4e..791178a1fd74e 100644
--- a/libgomp/taskloop.c
+++ b/libgomp/taskloop.c
@@ -51,20 +51,32 @@ GOMP_taskloop (void (*fn) (void *), void *data, void (*cpyfn) (void *, void *),
 
   /* If parallel or taskgroup has been cancelled, don't start new tasks.  */
   if (team && gomp_team_barrier_cancelled (&team->barrier))
-    return;
+    {
+    early_return:
+      if ((flags & (GOMP_TASK_FLAG_NOGROUP | GOMP_TASK_FLAG_REDUCTION))
+	  == GOMP_TASK_FLAG_REDUCTION)
+	{
+	  struct gomp_data_head { TYPE t1, t2; uintptr_t *ptr; };
+	  uintptr_t *ptr = ((struct gomp_data_head *) data)->ptr;
+	  /* Tell callers GOMP_taskgroup_reduction_register has not been
+	     called.  */
+	  ptr[2] = 0;
+	}
+      return;
+    }
 
 #ifdef TYPE_is_long
   TYPE s = step;
   if (step > 0)
     {
       if (start >= end)
-	return;
+	goto early_return;
       s--;
     }
   else
     {
       if (start <= end)
-	return;
+	goto early_return;
       s++;
     }
   UTYPE n = (end - start + s) / step;
@@ -73,13 +85,13 @@ GOMP_taskloop (void (*fn) (void *), void *data, void (*cpyfn) (void *, void *),
   if (flags & GOMP_TASK_FLAG_UP)
     {
       if (start >= end)
-	return;
+	goto early_return;
       n = (end - start + step - 1) / step;
     }
   else
     {
       if (start <= end)
-	return;
+	goto early_return;
       n = (start - end - step - 1) / -step;
     }
 #endif
diff --git a/libgomp/testsuite/libgomp.c/task-reduction-4.c b/libgomp/testsuite/libgomp.c/task-reduction-4.c
new file mode 100644
index 0000000000000..7ca1d02fa19e7
--- /dev/null
+++ b/libgomp/testsuite/libgomp.c/task-reduction-4.c
@@ -0,0 +1,21 @@
+/* PR middle-end/100471 */
+
+extern void abort (void);
+
+int c;
+
+int
+main ()
+{
+#pragma omp parallel
+#pragma omp single
+  {
+    int r = 0, i;
+    #pragma omp taskloop reduction(+:r)
+    for (i = 0; i < c; i++)
+      r++;
+    if (r != 0)
+      abort ();
+  }
+  return 0;
+}

From 5998192bff6313a49d1e78bb224f8d7600a6072d Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Wed, 12 May 2021 10:38:35 +0200
Subject: [PATCH 109/164] expand: Don't reuse DEBUG_EXPRs with vector type if
 they have different modes [PR100508]

The inliner doesn't remap DEBUG_EXPR_DECLs, so the same decls can appear
in multiple functions.
Furthermore, expansion reuses corresponding DEBUG_EXPRs too, so they again
can be reused in multiple functions.
Neither of that is a major problem, DEBUG_EXPRs are just magic value holders
and what value they stand for is independent in each function and driven by
what debug stmts or DEBUG_INSNs they are bound to.
Except for DEBUG_EXPR*s with vector types, TYPE_MODE can be either BLKmode
or some vector mode depending on whether current function's enabled ISAs
support that vector mode or not.  On the following testcase, we expand it
first in foo function without AVX2 enabled and so the DEBUG_EXPR is
BLKmode, but later the same DEBUG_EXPR_DECL is used in a simd clone with
AVX2 enabled and expansion ICEs because of a mode mismatch.

The following patch fixes that by forcing recreation of a DEBUG_EXPR if
there is a mode mismatch for vector typed DEBUG_EXPR_DECL, DEBUG_EXPRs
will be still reused in between functions otherwise and within the same
function the mode should be always the same.

2021-05-12  Jakub Jelinek  <jakub@redhat.com>

	PR middle-end/100508
	* cfgexpand.c (expand_debug_expr): For DEBUG_EXPR_DECL with vector
	type, don't reuse DECL_RTL if it has different mode, instead force
	creation of a new DEBUG_EXPR.

	* gcc.dg/gomp/pr100508.c: New test.

(cherry picked from commit 19040050aa2c8ee890fc58dda48639fc91bf0af0)
---
 gcc/cfgexpand.c                      |  7 ++++++-
 gcc/testsuite/gcc.dg/gomp/pr100508.c | 14 ++++++++++++++
 2 files changed, 20 insertions(+), 1 deletion(-)
 create mode 100644 gcc/testsuite/gcc.dg/gomp/pr100508.c

diff --git a/gcc/cfgexpand.c b/gcc/cfgexpand.c
index a6b48d3e48f0f..c221b4165caf1 100644
--- a/gcc/cfgexpand.c
+++ b/gcc/cfgexpand.c
@@ -4509,7 +4509,12 @@ expand_debug_expr (tree exp)
       op0 = DECL_RTL_IF_SET (exp);
 
       if (op0)
-	return op0;
+	{
+	  if (GET_MODE (op0) != mode)
+	    gcc_assert (VECTOR_TYPE_P (TREE_TYPE (exp)));
+	  else
+	    return op0;
+	}
 
       op0 = gen_rtx_DEBUG_EXPR (mode);
       DEBUG_EXPR_TREE_DECL (op0) = exp;
diff --git a/gcc/testsuite/gcc.dg/gomp/pr100508.c b/gcc/testsuite/gcc.dg/gomp/pr100508.c
new file mode 100644
index 0000000000000..c3fa2fc258e03
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/gomp/pr100508.c
@@ -0,0 +1,14 @@
+/* PR middle-end/100508 */
+/* { dg-do compile } */
+/* { dg-options "-O2 -g -fopenmp-simd" } */
+
+typedef int __attribute__((__vector_size__(32))) V;
+V j;
+
+#pragma omp declare simd
+int
+foo (void)
+{
+  V m = j;
+  return 0;
+}

From b6ecd493886891f8150905a2fd3b7d54e88fc7be Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Wed, 12 May 2021 15:14:35 +0200
Subject: [PATCH 110/164] libcpp: Fix up -fdirectives-only preprocessing of
 includes not ending with newline [PR100392]

If a header doesn't end with a new-line, with -fdirectives-only we right now
preprocess it as
int i = 1;# 2 "pr100392.c" 2
i.e. the line directive isn't on the next line, which means we fail to parse
it when compiling.

GCC 10 and earlier libcpp/directives-only.c had for this:
  if (!pfile->state.skipping && cur != base)
    {
      /* If the file was not newline terminated, add rlimit, which is
         guaranteed to point to a newline, to the end of our range.  */
      if (cur[-1] != '\n')
        {
          cur++;
          CPP_INCREMENT_LINE (pfile, 0);
          lines++;
        }

      cb->print_lines (lines, base, cur - base);
    }
and we have the assertion
      /* Files always end in a newline or carriage return.  We rely on this for
         character peeking safety.  */
      gcc_assert (buffer->rlimit[0] == '\n' || buffer->rlimit[0] == '\r');
So, this patch just does readd the more less same thing, so that we emit
a newline after the inline even when it wasn't there before.

2021-05-12  Jakub Jelinek  <jakub@redhat.com>

	PR preprocessor/100392
	* lex.c (cpp_directive_only_process): If buffer doesn't end with '\n',
	add buffer->rlimit[0] character to the printed range and
	CPP_INCREMENT_LINE and increment line_count.

	* gcc.dg/cpp/pr100392.c: New test.
	* gcc.dg/cpp/pr100392.h: New file.

(cherry picked from commit c6b664e2c4c127025e076d8b584abe0976694629)
---
 gcc/testsuite/gcc.dg/cpp/pr100392.c |  5 +++++
 gcc/testsuite/gcc.dg/cpp/pr100392.h |  4 ++++
 libcpp/lex.c                        | 13 ++++++++++++-
 3 files changed, 21 insertions(+), 1 deletion(-)
 create mode 100644 gcc/testsuite/gcc.dg/cpp/pr100392.c
 create mode 100644 gcc/testsuite/gcc.dg/cpp/pr100392.h

diff --git a/gcc/testsuite/gcc.dg/cpp/pr100392.c b/gcc/testsuite/gcc.dg/cpp/pr100392.c
new file mode 100644
index 0000000000000..670ad2b742ca2
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/cpp/pr100392.c
@@ -0,0 +1,5 @@
+/* PR preprocessor/100392 */
+/* { dg-do compile } */
+/* { dg-options "-save-temps -fdirectives-only" } */
+
+#include "pr100392.h"
diff --git a/gcc/testsuite/gcc.dg/cpp/pr100392.h b/gcc/testsuite/gcc.dg/cpp/pr100392.h
new file mode 100644
index 0000000000000..340bc92cd562c
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/cpp/pr100392.h
@@ -0,0 +1,4 @@
+/* PR preprocessor/100392 */
+
+/* No newline after ; below.  */
+int i = 1;
\ No newline at end of file
diff --git a/libcpp/lex.c b/libcpp/lex.c
index 27388754ea1d3..6c0ca8d2e2db0 100644
--- a/libcpp/lex.c
+++ b/libcpp/lex.c
@@ -4757,7 +4757,18 @@ cpp_directive_only_process (cpp_reader *pfile,
 	}
 
       if (buffer->rlimit > base && !pfile->state.skipping)
-	cb (pfile, CPP_DO_print, data, line_count, base, buffer->rlimit - base);
+	{
+	  const unsigned char *limit = buffer->rlimit;
+	  /* If the file was not newline terminated, add rlimit, which is
+	     guaranteed to point to a newline, to the end of our range.  */
+	  if (limit[-1] != '\n')
+	    {
+	      limit++;
+	      CPP_INCREMENT_LINE (pfile, 0);
+	      line_count++;
+	    }
+	  cb (pfile, CPP_DO_print, data, line_count, base, limit - base);
+	}
 
       _cpp_pop_buffer (pfile);
     }

From ce3c70e9ed265578be896b8f7711851b0a7273f1 Mon Sep 17 00:00:00 2001
From: Richard Biener <rguenther@suse.de>
Date: Wed, 12 May 2021 15:39:52 +0200
Subject: [PATCH 111/164] tree-optimization/100566 - fix another predication
 issue in VN

This amends the fix for PR100053 where I failed to amend all edge
tests in dominated_by_p_w_unex.

2021-05-12  Richard Biener  <rguenther@suse.de>

	PR tree-optimization/100566
	* tree-ssa-sccvn.c (dominated_by_p_w_unex): Properly handle
	allow_back for all edge queries.

	* gcc.dg/torture/pr100566.c: New testcase.

(cherry picked from commit 097fde5e7514e909f2e8472be2e008d0cab2260d)
---
 gcc/testsuite/gcc.dg/torture/pr100566.c | 36 +++++++++++++++++++++++++
 gcc/tree-ssa-sccvn.c                    |  6 +++--
 2 files changed, 40 insertions(+), 2 deletions(-)
 create mode 100644 gcc/testsuite/gcc.dg/torture/pr100566.c

diff --git a/gcc/testsuite/gcc.dg/torture/pr100566.c b/gcc/testsuite/gcc.dg/torture/pr100566.c
new file mode 100644
index 0000000000000..ed85691363981
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/torture/pr100566.c
@@ -0,0 +1,36 @@
+/* { dg-do run } */
+
+volatile int s, c;
+
+__attribute__((noipa)) void
+foo (void)
+{
+  if (c++ > 1)
+    __builtin_abort ();
+}
+
+__attribute__((noipa)) int
+bar (void)
+{
+  int i = 0, j = s;
+  if (j == 0)
+    goto lab;
+  for (i = 0; i < j; i++)
+    {
+    lab:
+      foo ();
+      if (!j)
+        goto lab;
+    }
+  return 0;
+}
+
+int
+main ()
+{
+  s = 1;
+  bar ();
+  if (c != 1)
+    __builtin_abort ();
+  return 0;
+}
diff --git a/gcc/tree-ssa-sccvn.c b/gcc/tree-ssa-sccvn.c
index ca0974d72b826..d4f0cafa18888 100644
--- a/gcc/tree-ssa-sccvn.c
+++ b/gcc/tree-ssa-sccvn.c
@@ -4529,7 +4529,8 @@ dominated_by_p_w_unex (basic_block bb1, basic_block bb2, bool allow_back)
   /* Iterate to the single executable bb2 successor.  */
   edge succe = NULL;
   FOR_EACH_EDGE (e, ei, bb2->succs)
-    if (e->flags & EDGE_EXECUTABLE)
+    if ((e->flags & EDGE_EXECUTABLE)
+	|| (!allow_back && (e->flags & EDGE_DFS_BACK)))
       {
 	if (succe)
 	  {
@@ -4547,7 +4548,8 @@ dominated_by_p_w_unex (basic_block bb1, basic_block bb2, bool allow_back)
 	{
 	  FOR_EACH_EDGE (e, ei, succe->dest->preds)
 	    if (e != succe
-		&& (e->flags & EDGE_EXECUTABLE))
+		&& ((e->flags & EDGE_EXECUTABLE)
+		    || (!allow_back && (e->flags & EDGE_DFS_BACK))))
 	      {
 		succe = NULL;
 		break;

From e3c9eb860c329ff97b0da5bf832dbe860d112b44 Mon Sep 17 00:00:00 2001
From: Patrick Palka <ppalka@redhat.com>
Date: Fri, 30 Apr 2021 10:59:20 -0400
Subject: [PATCH 112/164] libstdc++: Implement P2367 changes to avoid some
 list-initialization

This implements the wording changes of P2367R0 "Remove misuses of
list-initialization from Clause 24", modulo the parts that depend
on P1739R4 which we don't yet implement (due to LWG 3407).

libstdc++-v3/ChangeLog:

	* include/bits/ranges_util.h (subrange::subrange): Avoid
	list-initialization in delegating constructor.
	* include/std/ranges (single_view): Replace implicit guide
	with explicit deduction guide that decays its argument.
	(_Single::operator()): Avoid CTAD when constructing the
	single_view object.
	(_Iota::operator()): Avoid list-initialization.
	(__detail::__can_filter_view, _Filter::operator()): Likewise.
	(__detail::__can_transform_view, _Transform::operator()): Likewise.
	(take_view::begin): Likewise.
	(__detail::__can_take_view, _Take::operator()): Likewise.
	(__detail::__can_take_while_view, _TakeWhile::operator()): Likewise.
	(__detail::__can_drop_view, _Drop::operator()): Likewise.
	(__detail::__can_drop_while_view, _DropWhile::operator()): Likewise.
	(split_view::split_view): Use views::single when initializing
	_M_pattern.
	(__detail::__can_split_view, _Split::operator()): Avoid
	list-initialization.
	(_Counted::operator()): Likewise.
	* testsuite/std/ranges/p2367.cc: New test.

(cherry picked from commit 6e00d9bb113b531be15bc71cad2f1742648ba18a)
---
 libstdc++-v3/include/bits/ranges_util.h    |  2 +-
 libstdc++-v3/include/std/ranges            | 55 ++++++++++++----------
 libstdc++-v3/testsuite/std/ranges/p2367.cc | 48 +++++++++++++++++++
 3 files changed, 78 insertions(+), 27 deletions(-)
 create mode 100644 libstdc++-v3/testsuite/std/ranges/p2367.cc

diff --git a/libstdc++-v3/include/bits/ranges_util.h b/libstdc++-v3/include/bits/ranges_util.h
index 9d51e1b874eae..589886eb15752 100644
--- a/libstdc++-v3/include/bits/ranges_util.h
+++ b/libstdc++-v3/include/bits/ranges_util.h
@@ -251,7 +251,7 @@ namespace ranges
 	  && convertible_to<sentinel_t<_Rng>, _Sent>
 	constexpr
 	subrange(_Rng&& __r) requires (!_S_store_size)
-	: subrange{ranges::begin(__r), ranges::end(__r)}
+	: subrange(ranges::begin(__r), ranges::end(__r))
 	{ }
 
       template<borrowed_range _Rng>
diff --git a/libstdc++-v3/include/std/ranges b/libstdc++-v3/include/std/ranges
index af3c108bec890..df7d2a2361a45 100644
--- a/libstdc++-v3/include/std/ranges
+++ b/libstdc++-v3/include/std/ranges
@@ -246,6 +246,9 @@ namespace ranges
       [[no_unique_address]] __detail::__box<_Tp> _M_value;
     };
 
+  template<typename _Tp>
+    single_view(_Tp) -> single_view<_Tp>;
+
   namespace __detail
   {
     template<typename _Wp>
@@ -597,7 +600,7 @@ namespace views
     template<typename _Tp>
       constexpr auto
       operator()(_Tp&& __e) const
-      { return single_view{std::forward<_Tp>(__e)}; }
+      { return single_view<decay_t<_Tp>>(std::forward<_Tp>(__e)); }
   };
 
   inline constexpr _Single single{};
@@ -607,12 +610,12 @@ namespace views
     template<typename _Tp>
       constexpr auto
       operator()(_Tp&& __e) const
-      { return iota_view{std::forward<_Tp>(__e)}; }
+      { return iota_view(std::forward<_Tp>(__e)); }
 
     template<typename _Tp, typename _Up>
       constexpr auto
       operator()(_Tp&& __e, _Up&& __f) const
-      { return iota_view{std::forward<_Tp>(__e), std::forward<_Up>(__f)}; }
+      { return iota_view(std::forward<_Tp>(__e), std::forward<_Up>(__f)); }
   };
 
   inline constexpr _Iota iota{};
@@ -1336,7 +1339,7 @@ namespace views::__adaptor
     {
       template<typename _Range, typename _Pred>
 	concept __can_filter_view
-	  = requires { filter_view{std::declval<_Range>(), std::declval<_Pred>()}; };
+	  = requires { filter_view(std::declval<_Range>(), std::declval<_Pred>()); };
     } // namespace __detail
 
     struct _Filter : __adaptor::_RangeAdaptor<_Filter>
@@ -1346,7 +1349,7 @@ namespace views::__adaptor
 	constexpr auto
 	operator()(_Range&& __r, _Pred&& __p) const
 	{
-	  return filter_view{std::forward<_Range>(__r), std::forward<_Pred>(__p)};
+	  return filter_view(std::forward<_Range>(__r), std::forward<_Pred>(__p));
 	}
 
       using _RangeAdaptor<_Filter>::operator();
@@ -1711,7 +1714,7 @@ namespace views::__adaptor
     {
       template<typename _Range, typename _Fp>
 	concept __can_transform_view
-	  = requires { transform_view{std::declval<_Range>(), std::declval<_Fp>()}; };
+	  = requires { transform_view(std::declval<_Range>(), std::declval<_Fp>()); };
     } // namespace __detail
 
     struct _Transform : __adaptor::_RangeAdaptor<_Transform>
@@ -1721,7 +1724,7 @@ namespace views::__adaptor
 	constexpr auto
 	operator()(_Range&& __r, _Fp&& __f) const
 	{
-	  return transform_view{std::forward<_Range>(__r), std::forward<_Fp>(__f)};
+	  return transform_view(std::forward<_Range>(__r), std::forward<_Fp>(__f));
 	}
 
       using _RangeAdaptor<_Transform>::operator();
@@ -1807,11 +1810,11 @@ namespace views::__adaptor
 	    else
 	      {
 		auto __sz = size();
-		return counted_iterator{ranges::begin(_M_base), __sz};
+		return counted_iterator(ranges::begin(_M_base), __sz);
 	      }
 	  }
 	else
-	  return counted_iterator{ranges::begin(_M_base), _M_count};
+	  return counted_iterator(ranges::begin(_M_base), _M_count);
       }
 
       constexpr auto
@@ -1824,11 +1827,11 @@ namespace views::__adaptor
 	    else
 	      {
 		auto __sz = size();
-		return counted_iterator{ranges::begin(_M_base), __sz};
+		return counted_iterator(ranges::begin(_M_base), __sz);
 	      }
 	  }
 	else
-	  return counted_iterator{ranges::begin(_M_base), _M_count};
+	  return counted_iterator(ranges::begin(_M_base), _M_count);
       }
 
       constexpr auto
@@ -1891,7 +1894,7 @@ namespace views::__adaptor
     {
       template<typename _Range, typename _Tp>
 	concept __can_take_view
-	  = requires { take_view{std::declval<_Range>(), std::declval<_Tp>()}; };
+	  = requires { take_view(std::declval<_Range>(), std::declval<_Tp>()); };
     } // namespace __detail
 
     struct _Take : __adaptor::_RangeAdaptor<_Take>
@@ -1901,7 +1904,7 @@ namespace views::__adaptor
 	constexpr auto
 	operator()(_Range&& __r, _Tp&& __n) const
 	{
-	  return take_view{std::forward<_Range>(__r), std::forward<_Tp>(__n)};
+	  return take_view(std::forward<_Range>(__r), std::forward<_Tp>(__n));
 	}
 
       using _RangeAdaptor<_Take>::operator();
@@ -2010,7 +2013,7 @@ namespace views::__adaptor
     {
       template<typename _Range, typename _Pred>
 	concept __can_take_while_view
-	  = requires { take_while_view{std::declval<_Range>(), std::declval<_Pred>()}; };
+	  = requires { take_while_view(std::declval<_Range>(), std::declval<_Pred>()); };
     } // namespace __detail
 
     struct _TakeWhile : __adaptor::_RangeAdaptor<_TakeWhile>
@@ -2020,7 +2023,7 @@ namespace views::__adaptor
 	constexpr auto
 	operator()(_Range&& __r, _Pred&& __p) const
 	{
-	  return take_while_view{std::forward<_Range>(__r), std::forward<_Pred>(__p)};
+	  return take_while_view(std::forward<_Range>(__r), std::forward<_Pred>(__p));
 	}
 
       using _RangeAdaptor<_TakeWhile>::operator();
@@ -2129,7 +2132,7 @@ namespace views::__adaptor
     {
       template<typename _Range, typename _Tp>
 	concept __can_drop_view
-	  = requires { drop_view{std::declval<_Range>(), std::declval<_Tp>()}; };
+	  = requires { drop_view(std::declval<_Range>(), std::declval<_Tp>()); };
     } // namespace __detail
 
     struct _Drop : __adaptor::_RangeAdaptor<_Drop>
@@ -2139,7 +2142,7 @@ namespace views::__adaptor
 	constexpr auto
 	operator()(_Range&& __r, _Tp&& __n) const
 	{
-	  return drop_view{std::forward<_Range>(__r), std::forward<_Tp>(__n)};
+	  return drop_view(std::forward<_Range>(__r), std::forward<_Tp>(__n));
 	}
 
       using _RangeAdaptor<_Drop>::operator();
@@ -2211,7 +2214,7 @@ namespace views::__adaptor
     {
       template<typename _Range, typename _Pred>
 	concept __can_drop_while_view
-	  = requires { drop_while_view{std::declval<_Range>(), std::declval<_Pred>()}; };
+	  = requires { drop_while_view(std::declval<_Range>(), std::declval<_Pred>()); };
     } // namespace __detail
 
     struct _DropWhile : __adaptor::_RangeAdaptor<_DropWhile>
@@ -2221,8 +2224,8 @@ namespace views::__adaptor
 	constexpr auto
 	operator()(_Range&& __r, _Pred&& __p) const
 	{
-	  return drop_while_view{std::forward<_Range>(__r),
-				 std::forward<_Pred>(__p)};
+	  return drop_while_view(std::forward<_Range>(__r),
+				 std::forward<_Pred>(__p));
 	}
 
       using _RangeAdaptor<_DropWhile>::operator();
@@ -2943,7 +2946,7 @@ namespace views::__adaptor
 	  && constructible_from<_Pattern, single_view<range_value_t<_Range>>>
 	constexpr
 	split_view(_Range&& __r, range_value_t<_Range> __e)
-	  : _M_pattern(std::move(__e)),
+	  : _M_pattern(views::single(std::move(__e))),
 	    _M_base(views::all(std::forward<_Range>(__r)))
 	{ }
 
@@ -3007,7 +3010,7 @@ namespace views::__adaptor
     {
       template<typename _Range, typename _Pattern>
 	concept __can_split_view
-	  = requires { split_view{std::declval<_Range>(), std::declval<_Pattern>()}; };
+	  = requires { split_view(std::declval<_Range>(), std::declval<_Pattern>()); };
     } // namespace __detail
 
     struct _Split : __adaptor::_RangeAdaptor<_Split>
@@ -3017,7 +3020,7 @@ namespace views::__adaptor
 	constexpr auto
 	operator()(_Range&& __r, _Pattern&& __f) const
 	{
-	  return split_view{std::forward<_Range>(__r), std::forward<_Pattern>(__f)};
+	  return split_view(std::forward<_Range>(__r), std::forward<_Pattern>(__f));
 	}
 
       using _RangeAdaptor<_Split>::operator();
@@ -3036,10 +3039,10 @@ namespace views::__adaptor
       operator()(_Iter __i, iter_difference_t<_Iter> __n) const
       {
 	if constexpr (random_access_iterator<_Iter>)
-	  return subrange{__i, __i + __n};
+	  return subrange(__i, __i + __n);
 	else
-	  return subrange{counted_iterator{std::move(__i), __n},
-			  default_sentinel};
+	  return subrange(counted_iterator(std::move(__i), __n),
+			  default_sentinel);
       }
     };
 
diff --git a/libstdc++-v3/testsuite/std/ranges/p2367.cc b/libstdc++-v3/testsuite/std/ranges/p2367.cc
new file mode 100644
index 0000000000000..40875233d8870
--- /dev/null
+++ b/libstdc++-v3/testsuite/std/ranges/p2367.cc
@@ -0,0 +1,48 @@
+// Copyright (C) 2021 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++2a" }
+// { dg-do compile { target c++2a } }
+
+// Verify P2367 changes.
+
+#include <ranges>
+
+namespace ranges = std::ranges;
+namespace views = std::views;
+
+void
+test01()
+{
+  extern int (&x)[5];
+
+  // Verify changes to views::single.
+  using ranges::single_view;
+  using std::same_as;
+  same_as<single_view<int*>> auto v1 = views::single(x);
+  same_as<single_view<int>> auto v2 = views::single((const int)5);
+  same_as<single_view<single_view<int>>> auto v3 = views::single(v2);
+
+  // Verify changes to views::take.
+  auto v4 = views::take(x, 0ull);
+
+  // Verify changes to views::drop.
+  auto v5 = views::drop(x, 0ull);
+
+  // Verify changes to views::split.
+  auto v6 = views::split(x, 5u);
+}

From 3aac28720af42488fc8e5066fe55e05a20b8f983 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Thu, 13 May 2021 00:18:01 +0000
Subject: [PATCH 113/164] Daily bump.

---
 gcc/ChangeLog           | 29 +++++++++++++++++++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/testsuite/ChangeLog | 25 +++++++++++++++++++++++++
 libcpp/ChangeLog        | 10 ++++++++++
 libgomp/ChangeLog       | 11 +++++++++++
 libstdc++-v3/ChangeLog  | 26 ++++++++++++++++++++++++++
 6 files changed, 102 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 6e23daffbbe47..ac263a77e205f 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,32 @@
+2021-05-12  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-05-12  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100566
+	* tree-ssa-sccvn.c (dominated_by_p_w_unex): Properly handle
+	allow_back for all edge queries.
+
+2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/100508
+	* cfgexpand.c (expand_debug_expr): For DEBUG_EXPR_DECL with vector
+	type, don't reuse DECL_RTL if it has different mode, instead force
+	creation of a new DEBUG_EXPR.
+
+2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-11  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/100471
+	* omp-low.c (lower_omp_task_reductions): For OMP_TASKLOOP, if data
+	is 0, bypass the reduction loop including
+	GOMP_taskgroup_reduction_unregister call.
+
 2021-05-12  Geng Qi  <gengqi@linux.alibaba.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index d14314023a18d..92e74b65a6bb9 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210512
+20210513
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 1f99d9ed50d4e..03a714a4723b8 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,28 @@
+2021-05-12  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-05-12  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/100566
+	* gcc.dg/torture/pr100566.c: New testcase.
+
+2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR preprocessor/100392
+	* gcc.dg/cpp/pr100392.c: New test.
+	* gcc.dg/cpp/pr100392.h: New file.
+
+2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/100508
+	* gcc.dg/gomp/pr100508.c: New test.
+
 2021-05-11  Alex Coplan  <alex.coplan@arm.com>
 
 	PR target/99988
diff --git a/libcpp/ChangeLog b/libcpp/ChangeLog
index 059ab8bfc2859..a1f4f2cf9abb4 100644
--- a/libcpp/ChangeLog
+++ b/libcpp/ChangeLog
@@ -1,3 +1,13 @@
+2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR preprocessor/100392
+	* lex.c (cpp_directive_only_process): If buffer doesn't end with '\n',
+	add buffer->rlimit[0] character to the printed range and
+	CPP_INCREMENT_LINE and increment line_count.
+
 2021-05-07  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
index 6531ccb746482..93c189ea261fd 100644
--- a/libgomp/ChangeLog
+++ b/libgomp/ChangeLog
@@ -1,3 +1,14 @@
+2021-05-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-11  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/100471
+	* taskloop.c (GOMP_taskloop): If GOMP_TASK_FLAG_REDUCTION and not
+	GOMP_TASK_FLAG_NOGROUP, when doing early return clear the task
+	reduction pointer.
+	* testsuite/libgomp.c/task-reduction-4.c: New test.
+
 2021-05-06  Roman Zhuykov  <zhroma@ispras.ru>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 1dc99faf1fa9e..055b5f353c55f 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,29 @@
+2021-05-12  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2021-04-30  Patrick Palka  <ppalka@redhat.com>
+
+	* include/bits/ranges_util.h (subrange::subrange): Avoid
+	list-initialization in delegating constructor.
+	* include/std/ranges (single_view): Replace implicit guide
+	with explicit deduction guide that decays its argument.
+	(_Single::operator()): Avoid CTAD when constructing the
+	single_view object.
+	(_Iota::operator()): Avoid list-initialization.
+	(__detail::__can_filter_view, _Filter::operator()): Likewise.
+	(__detail::__can_transform_view, _Transform::operator()): Likewise.
+	(take_view::begin): Likewise.
+	(__detail::__can_take_view, _Take::operator()): Likewise.
+	(__detail::__can_take_while_view, _TakeWhile::operator()): Likewise.
+	(__detail::__can_drop_view, _Drop::operator()): Likewise.
+	(__detail::__can_drop_while_view, _DropWhile::operator()): Likewise.
+	(split_view::split_view): Use views::single when initializing
+	_M_pattern.
+	(__detail::__can_split_view, _Split::operator()): Avoid
+	list-initialization.
+	(_Counted::operator()): Likewise.
+	* testsuite/std/ranges/p2367.cc: New test.
+
 2021-05-11  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

From ecfb8658c04114d87e1000f9924d6c373df0e7fd Mon Sep 17 00:00:00 2001
From: Richard Earnshaw <rearnsha@arm.com>
Date: Thu, 13 May 2021 11:42:58 +0100
Subject: [PATCH 114/164] arm: correctly handle inequality comparisons against
 max constants [PR100563]

Normally we expect the gimple optimizers to fold away comparisons that
are always true, but at some lower optimization levels this is not
always the case, so the back-end has to be able to generate correct
code in these cases.

In this example, we have a comparison of the form

  (unsigned long long) op <= ~0ULL

which, of course is always true.

Normally, in the arm back-end we handle these expansions where the
immediate cannot be handled directly by adding 1 to the constant and
then adjusting the comparison operator:

  (unsigned long long) op < CONST + 1

but we cannot do that when the constant is already the largest value.

Fortunately, we observe that the comparisons we need to handle this
way are either always true or always false, so instead of forming a
comparison against the maximum value, we can replace it with a
comparison against the minimum value (which just happens to also be a
constant we can handle.  So

  op1 <= ~0ULL -> op1 >= 0U
  op1 > ~0ULL -> op1 < 0U

  op1 <= LONG_LONG_INT_MAX -> op1 >= (-LONG_LONG_INT_MAX - 1)
  op1 > LONG_LONG_INT_MAX -> op1 < (-LONG_LONG_INT_MAX - 1)

gcc:
	PR target/100563
	* config/arm/arm.c (arm_canonicalize_comparison): Correctly
	canonicalize DImode inequality comparisons against the
	maximum integral value.

gcc/testsuite:
	* gcc.dg/pr100563.c: New test.
---
 gcc/config/arm/arm.c            | 29 +++++++++++++++++++++++++----
 gcc/testsuite/gcc.dg/pr100563.c |  9 +++++++++
 2 files changed, 34 insertions(+), 4 deletions(-)
 create mode 100644 gcc/testsuite/gcc.dg/pr100563.c

diff --git a/gcc/config/arm/arm.c b/gcc/config/arm/arm.c
index a201088a6fd49..a488f56d91381 100644
--- a/gcc/config/arm/arm.c
+++ b/gcc/config/arm/arm.c
@@ -5563,9 +5563,20 @@ arm_canonicalize_comparison (int *code, rtx *op0, rtx *op1,
 			return;
 		      *op1 = GEN_INT (i + 1);
 		      *code = *code == GT ? GE : LT;
-		      return;
 		    }
-		  break;
+		  else
+		    {
+		      /* GT maxval is always false, LE maxval is always true.
+			 We can't fold that away here as we must make a
+			 comparison, but we can fold them to comparisons
+			 with the same result that can be handled:
+			   op0 GT maxval -> op0 LT minval
+			   op0 LE maxval -> op0 GE minval
+			 where minval = (-maxval - 1).  */
+		      *op1 = GEN_INT (-maxval - 1);
+		      *code = *code == GT ? LT : GE;
+		    }
+		  return;
 
 		case GTU:
 		case LEU:
@@ -5578,9 +5589,19 @@ arm_canonicalize_comparison (int *code, rtx *op0, rtx *op1,
 			return;
 		      *op1 = GEN_INT (i + 1);
 		      *code = *code == GTU ? GEU : LTU;
-		      return;
 		    }
-		  break;
+		  else
+		    {
+		      /* GTU ~0 is always false, LEU ~0 is always true.
+			 We can't fold that away here as we must make a
+			 comparison, but we can fold them to comparisons
+			 with the same result that can be handled:
+			   op0 GTU ~0 -> op0 LTU 0
+			   op0 LEU ~0 -> op0 GEU 0.  */
+		      *op1 = const0_rtx;
+		      *code = *code == GTU ? LTU : GEU;
+		    }
+		  return;
 
 		default:
 		  gcc_unreachable ();
diff --git a/gcc/testsuite/gcc.dg/pr100563.c b/gcc/testsuite/gcc.dg/pr100563.c
new file mode 100644
index 0000000000000..f6a5fcd3a47f5
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr100563.c
@@ -0,0 +1,9 @@
+/* { dg-do compile } */
+/* { dg-options "-Og -Wno-pointer-to-int-cast" } */
+unsigned long long e(void);
+void f(int);
+void a() {
+  short b = -1, c = (int)&b;
+  unsigned long long d = e();
+  f(b >= d);
+}

From ac5bab25cfd99dd530c8c83992d81e2c88e543d0 Mon Sep 17 00:00:00 2001
From: Srinath Parvathaneni <srinath.parvathaneni@arm.com>
Date: Tue, 11 May 2021 10:43:11 +0100
Subject: [PATCH 115/164] arm: Remove duplicate definitions from arm_mve.h
 (pr100419).

This patch removes several duplicated intrinsic definitions from
arm_mve.h mentioned in PR100419 and also fixes the wrong arguments
in few of intrinsics polymorphic variants.

gcc/ChangeLog:

2021-05-04  Srinath Parvathaneni  <srinath.parvathaneni@arm.com>

	PR target/100419
	* config/arm/arm_mve.h (__arm_vstrwq_scatter_offset): Fix wrong arguments.
	(__arm_vcmpneq): Remove duplicate definition.
	(__arm_vstrwq_scatter_offset_p): Likewise.
	(__arm_vmaxq_x): Likewise.
	(__arm_vmlsdavaq): Likewise.
	(__arm_vmlsdavaxq): Likewise.
	(__arm_vmlsdavq_p): Likewise.
	(__arm_vmlsdavxq_p): Likewise.
	(__arm_vrmlaldavhaq): Likewise.
	(__arm_vstrbq_p): Likewise.
	(__arm_vstrbq_scatter_offset): Likewise.
	(__arm_vstrbq_scatter_offset_p): Likewise.
	(__arm_vstrdq_scatter_offset): Likewise.
	(__arm_vstrdq_scatter_offset_p): Likewise.
	(__arm_vstrdq_scatter_shifted_offset): Likewise.
	(__arm_vstrdq_scatter_shifted_offset_p): Likewise.

Co-authored-by: Joe Ramsay  <joe.ramsay@arm.com>
(cherry picked from commit 9b905ba9ebba8d2cc805c26351225e7f74c02333)
---
 gcc/config/arm/arm_mve.h | 460 +++++++++++----------------------------
 1 file changed, 132 insertions(+), 328 deletions(-)

diff --git a/gcc/config/arm/arm_mve.h b/gcc/config/arm/arm_mve.h
index 3a40c6e68161b..dc1d874a6366e 100644
--- a/gcc/config/arm/arm_mve.h
+++ b/gcc/config/arm/arm_mve.h
@@ -37808,33 +37808,19 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_base_p_u32(p0, p1, __ARM_mve_coerce(__p2, uint32x4_t), p3), \
   int (*)[__ARM_mve_type_float32x4_t]: __arm_vstrwq_scatter_base_p_f32(p0, p1, __ARM_mve_coerce(__p2, float32x4_t), p3));})
 
-#define __arm_vstrwq_scatter_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
+#define __arm_vstrwq_scatter_offset(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_s32 (__ARM_mve_coerce(p0, int32_t *), __p1, __ARM_mve_coerce(__p2, int32x4_t)), \
-  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_u32 (__ARM_mve_coerce(p0, uint32_t *), __p1, __ARM_mve_coerce(__p2, uint32x4_t)), \
-  int (*)[__ARM_mve_type_float32_t_ptr][__ARM_mve_type_float32x4_t]: __arm_vstrwq_scatter_offset_f32 (__ARM_mve_coerce(p0, float32_t *), __p1, __ARM_mve_coerce(__p2, float32x4_t)));})
-
-#define __arm_vstrwq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_p_s32 (__ARM_mve_coerce(p0, int32_t *), __p1, __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_p_u32 (__ARM_mve_coerce(p0, uint32_t *), __p1, __ARM_mve_coerce(__p2, uint32x4_t), p3), \
-  int (*)[__ARM_mve_type_float32_t_ptr][__ARM_mve_type_float32x4_t]: __arm_vstrwq_scatter_offset_p_f32 (__ARM_mve_coerce(p0, float32_t *), __p1, __ARM_mve_coerce(__p2, float32x4_t), p3));})
-
-#define __arm_vstrwq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_p_s32 (__ARM_mve_coerce(p0, int32_t *), __p1, __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_p_u32 (__ARM_mve_coerce(p0, uint32_t *), __p1, __ARM_mve_coerce(__p2, uint32x4_t), p3), \
-  int (*)[__ARM_mve_type_float32_t_ptr][__ARM_mve_type_float32x4_t]: __arm_vstrwq_scatter_offset_p_f32 (__ARM_mve_coerce(p0, float32_t *), __p1, __ARM_mve_coerce(__p2, float32x4_t), p3));})
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_s32 (__ARM_mve_coerce(__p0, int32_t *), p1, __ARM_mve_coerce(__p2, int32x4_t)), \
+  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_u32 (__ARM_mve_coerce(__p0, uint32_t *), p1, __ARM_mve_coerce(__p2, uint32x4_t)), \
+  int (*)[__ARM_mve_type_float32_t_ptr][__ARM_mve_type_float32x4_t]: __arm_vstrwq_scatter_offset_f32 (__ARM_mve_coerce(__p0, float32_t *), p1, __ARM_mve_coerce(__p2, float32x4_t)));})
 
-#define __arm_vstrwq_scatter_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
+#define __arm_vstrwq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_s32 (__ARM_mve_coerce(p0, int32_t *), __p1, __ARM_mve_coerce(__p2, int32x4_t)), \
-  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_u32 (__ARM_mve_coerce(p0, uint32_t *), __p1, __ARM_mve_coerce(__p2, uint32x4_t)), \
-  int (*)[__ARM_mve_type_float32_t_ptr][__ARM_mve_type_float32x4_t]: __arm_vstrwq_scatter_offset_f32 (__ARM_mve_coerce(p0, float32_t *), __p1, __ARM_mve_coerce(__p2, float32x4_t)));})
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_p_s32 (__ARM_mve_coerce(__p0, int32_t *), p1, __ARM_mve_coerce(__p2, int32x4_t), p3), \
+  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_p_u32 (__ARM_mve_coerce(__p0, uint32_t *), p1, __ARM_mve_coerce(__p2, uint32x4_t), p3), \
+  int (*)[__ARM_mve_type_float32_t_ptr][__ARM_mve_type_float32x4_t]: __arm_vstrwq_scatter_offset_p_f32 (__ARM_mve_coerce(__p0, float32_t *), p1, __ARM_mve_coerce(__p2, float32x4_t), p3));})
 
 #define __arm_vstrwq_scatter_shifted_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
@@ -38422,6 +38408,12 @@ extern void *__ARM_undef;
 #define __arm_vcmpneq(p0,p1) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p1) __p1 = (p1); \
   _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
+  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8_t)), \
+  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16_t)), \
+  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32_t)), \
+  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_u8 (__ARM_mve_coerce(__p0, uint8x16_t), __ARM_mve_coerce(__p1, uint8_t)), \
+  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_u16 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint16_t)), \
+  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_u32 (__ARM_mve_coerce(__p0, uint32x4_t), __ARM_mve_coerce(__p1, uint32_t)), \
   int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vcmpneq_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t)), \
   int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vcmpneq_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t)), \
   int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vcmpneq_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t)), \
@@ -38871,23 +38863,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_int_n]: __arm_vcmpeqq_n_u16 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint16_t)), \
   int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_int_n]: __arm_vcmpeqq_n_u32 (__ARM_mve_coerce(__p0, uint32x4_t), __ARM_mve_coerce(__p1, uint32_t)));})
 
-#define __arm_vcmpneq(p0,p1) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vcmpneq_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t)), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vcmpneq_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t)), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vcmpneq_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t)), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vcmpneq_u8 (__ARM_mve_coerce(__p0, uint8x16_t), __ARM_mve_coerce(__p1, uint8x16_t)), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vcmpneq_u16 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint16x8_t)), \
-  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vcmpneq_u32 (__ARM_mve_coerce(__p0, uint32x4_t), __ARM_mve_coerce(__p1, uint32x4_t)), \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8_t)), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16_t)), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32_t)), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_u8 (__ARM_mve_coerce(__p0, uint8x16_t), __ARM_mve_coerce(__p1, uint8_t)), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_u16 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint16_t)), \
-  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_u32 (__ARM_mve_coerce(__p0, uint32x4_t), __ARM_mve_coerce(__p1, uint32_t)));})
-
-
 #define __arm_vqmovntq(p0,p1) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p1) __p1 = (p1); \
   _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
@@ -39036,22 +39011,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vcmpneq_m_u16 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint16x8_t), p2), \
   int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vcmpneq_m_u32 (__ARM_mve_coerce(__p0, uint32x4_t), __ARM_mve_coerce(__p1, uint32x4_t), p2));})
 
-#define __arm_vcmpneq(p0,p1) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vcmpneq_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t)), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vcmpneq_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t)), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vcmpneq_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t)), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vcmpneq_u8 (__ARM_mve_coerce(__p0, uint8x16_t), __ARM_mve_coerce(__p1, uint8x16_t)), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vcmpneq_u16 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint16x8_t)), \
-  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vcmpneq_u32 (__ARM_mve_coerce(__p0, uint32x4_t), __ARM_mve_coerce(__p1, uint32x4_t)), \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8_t)), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16_t)), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32_t)), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_u8 (__ARM_mve_coerce(__p0, uint8x16_t), __ARM_mve_coerce(__p1, uint8_t)), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_u16 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint16_t)), \
-  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_int_n]: __arm_vcmpneq_n_u32 (__ARM_mve_coerce(__p0, uint32x4_t), __ARM_mve_coerce(__p1, uint32_t)));})
-
 #define __arm_vshlcq(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
   _Generic( (int (*)[__ARM_mve_typeid(__p0)])0, \
   int (*)[__ARM_mve_type_int8x16_t]: __arm_vshlcq_s8 (__ARM_mve_coerce(__p0, int8x16_t), p1, p2), \
@@ -39367,52 +39326,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_int16x8_t]: __arm_vminaq_m_s16 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
   int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_int32x4_t]: __arm_vminaq_m_s32 (__ARM_mve_coerce(__p0, uint32x4_t), __ARM_mve_coerce(__p1, int32x4_t), p2));})
 
-#define __arm_vrmlaldavhaq(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vcmpltq_m_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vcmpltq_m_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vcmpltq_m_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t), p2), \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int_n]: __arm_vcmpltq_m_n_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int_n]: __arm_vcmpltq_m_n_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16_t), p2), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int_n]: __arm_vcmpltq_m_n_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32_t), p2));})
-
-#define __arm_vmlsdavxq_p(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vcmpleq_m_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vcmpleq_m_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vcmpleq_m_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t), p2), \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int_n]: __arm_vcmpleq_m_n_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int_n]: __arm_vcmpleq_m_n_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16_t), p2), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int_n]: __arm_vcmpleq_m_n_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32_t), p2));})
-
-#define __arm_vmlsdavq_p(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vcmpgtq_m_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vcmpgtq_m_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vcmpgtq_m_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t), p2), \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int_n]: __arm_vcmpgtq_m_n_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int_n]: __arm_vcmpgtq_m_n_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16_t), p2), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int_n]: __arm_vcmpgtq_m_n_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32_t), p2));})
-
-#define __arm_vmlsdavaxq(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int16x8_t]: __arm_vshrntq_n_s16 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int32x4_t]: __arm_vshrntq_n_s32 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int32x4_t), p2), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint16x8_t]: __arm_vshrntq_n_u16 (__ARM_mve_coerce(__p0, uint8x16_t), __ARM_mve_coerce(__p1, uint16x8_t), p2), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint32x4_t]: __arm_vshrntq_n_u32 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint32x4_t), p2));})
-
-#define __arm_vmlsdavaq(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int16x8_t]: __arm_vrshrntq_n_s16 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int32x4_t]: __arm_vrshrntq_n_s32 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int32x4_t), p2), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint16x8_t]: __arm_vrshrntq_n_u16 (__ARM_mve_coerce(__p0, uint8x16_t), __ARM_mve_coerce(__p1, uint16x8_t), p2), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint32x4_t]: __arm_vrshrntq_n_u32 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint32x4_t), p2));})
-
 #define __arm_vmovlbq_m(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p1) __p1 = (p1); \
   _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
@@ -39711,26 +39624,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vmulq_m_u16 (__ARM_mve_coerce(__p0, uint16x8_t), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
   int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vmulq_m_u32 (__ARM_mve_coerce(__p0, uint32x4_t), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
 
-#define __arm_vstrbq(p0,p1) ({ __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int8x16_t]: __arm_vstrbq_s8 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, int8x16_t)), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int16x8_t]: __arm_vstrbq_s16 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, int16x8_t)), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrbq_s32 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, int32x4_t)), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_u8 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t)), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_u16 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t)), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_u32 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t)));})
-
-#define __arm_vstrbq_scatter_offset(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_int8x16_t]: __arm_vstrbq_scatter_offset_s8 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, int8x16_t)), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_int16x8_t]: __arm_vstrbq_scatter_offset_s16 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, int16x8_t)), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_int32x4_t]: __arm_vstrbq_scatter_offset_s32 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, int32x4_t)), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_scatter_offset_u8 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t)), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_scatter_offset_u16 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t)), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_scatter_offset_u32 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t)));})
-
 #define __arm_vstrwq_scatter_base(p0,p1,p2) ({ __typeof(p2) __p2 = (p2); \
   _Generic( (int (*)[__ARM_mve_typeid(__p2)])0, \
   int (*)[__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_base_s32(p0, p1, __ARM_mve_coerce(__p2, int32x4_t)), \
@@ -39745,27 +39638,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t]: __arm_vldrbq_gather_offset_u16 (__ARM_mve_coerce(p0, uint8_t const *), __ARM_mve_coerce(__p1, uint16x8_t)), \
   int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vldrbq_gather_offset_u32 (__ARM_mve_coerce(p0, uint8_t const *), __ARM_mve_coerce(__p1, uint32x4_t)));})
 
-#define __arm_vstrbq_p(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int8x16_t]: __arm_vstrbq_p_s8 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, int8x16_t), p2), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int16x8_t]: __arm_vstrbq_p_s16 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, int16x8_t), p2), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrbq_p_s32 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, int32x4_t), p2), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_p_u8 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t), p2), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_p_u16 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t), p2), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_p_u32 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t), p2));})
-
-#define __arm_vstrbq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_int8x16_t]: __arm_vstrbq_scatter_offset_p_s8 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_int16x8_t]: __arm_vstrbq_scatter_offset_p_s16 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_int32x4_t]: __arm_vstrbq_scatter_offset_p_s32 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_scatter_offset_p_u8 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t), p3), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_scatter_offset_p_u16 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_scatter_offset_p_u32 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
-
 #define __arm_vstrwq_scatter_base_p(p0,p1,p2,p3) ({ __typeof(p2) __p2 = (p2); \
   _Generic( (int (*)[__ARM_mve_typeid(__p2)])0, \
   int (*)[__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_base_p_s32 (p0, p1, __ARM_mve_coerce(__p2, int32x4_t), p3), \
@@ -39921,34 +39793,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_base_s64 (p0, p1, __ARM_mve_coerce(__p2, int64x2_t)), \
   int (*)[__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_base_u64 (p0, p1, __ARM_mve_coerce(__p2, uint64x2_t)));})
 
-#define __arm_vstrdq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_offset_p_s64 (__ARM_mve_coerce(__p0, int64_t *), __p1, __ARM_mve_coerce(__p2, int64x2_t), p3), \
-  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_offset_p_u64 (__ARM_mve_coerce(__p0, uint64_t *), __p1, __ARM_mve_coerce(__p2, uint64x2_t), p3));})
-
-#define __arm_vstrdq_scatter_offset(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_offset_s64 (__ARM_mve_coerce(__p0, int64_t *), __p1, __ARM_mve_coerce(__p2, int64x2_t)), \
-  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_offset_u64 (__ARM_mve_coerce(__p0, uint64_t *), __p1, __ARM_mve_coerce(__p2, uint64x2_t)));})
-
-#define __arm_vstrdq_scatter_shifted_offset_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_shifted_offset_p_s64 (__ARM_mve_coerce(__p0, int64_t *), __p1, __ARM_mve_coerce(__p2, int64x2_t), p3), \
-  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_shifted_offset_p_u64 (__ARM_mve_coerce(__p0, uint64_t *), __p1, __ARM_mve_coerce(__p2, uint64x2_t), p3));})
-
-#define __arm_vstrdq_scatter_shifted_offset(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_shifted_offset_s64 (__ARM_mve_coerce(__p0, int64_t *), __p1, __ARM_mve_coerce(__p2, int64x2_t)), \
-  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_shifted_offset_u64 (__ARM_mve_coerce(__p0, uint64_t *), __p1, __ARM_mve_coerce(__p2, uint64x2_t)));})
-
 #define __arm_vstrhq_scatter_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
   _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
@@ -39981,29 +39825,17 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint16_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vstrhq_scatter_shifted_offset_p_u16 (__ARM_mve_coerce(p0, uint16_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
   int (*)[__ARM_mve_type_uint16_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vstrhq_scatter_shifted_offset_p_u32 (__ARM_mve_coerce(p0, uint16_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
 
-#define __arm_vstrwq_scatter_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_s32 (__ARM_mve_coerce(p0, int32_t *), __p1, __ARM_mve_coerce(__p2, int32x4_t)), \
-  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_u32 (__ARM_mve_coerce(p0, uint32_t *), __p1, __ARM_mve_coerce(__p2, uint32x4_t)));})
-
-#define __arm_vstrwq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_p_s32 (__ARM_mve_coerce(p0, int32_t *), __p1, __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_p_u32 (__ARM_mve_coerce(p0, uint32_t *), __p1, __ARM_mve_coerce(__p2, uint32x4_t)));})
-
-#define __arm_vstrwq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
+#define __arm_vstrwq_scatter_offset(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_p_s32 (__ARM_mve_coerce(p0, int32_t *), __p1, __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_p_u32 (__ARM_mve_coerce(p0, uint32_t *), __p1, __ARM_mve_coerce(__p2, uint32x4_t), p3));})
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_s32 (__ARM_mve_coerce(__p0, int32_t *), p1, __ARM_mve_coerce(__p2, int32x4_t)), \
+  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_u32 (__ARM_mve_coerce(__p0, uint32_t *), p1, __ARM_mve_coerce(__p2, uint32x4_t)));})
 
-#define __arm_vstrwq_scatter_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
+#define __arm_vstrwq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_s32 (__ARM_mve_coerce(p0, int32_t *), __p1, __ARM_mve_coerce(__p2, int32x4_t)), \
-  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_u32 (__ARM_mve_coerce(p0, uint32_t *), __p1, __ARM_mve_coerce(__p2, uint32x4_t)));})
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int32_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrwq_scatter_offset_p_s32 (__ARM_mve_coerce(__p0, int32_t *), p1, __ARM_mve_coerce(__p2, int32x4_t), p3), \
+  int (*)[__ARM_mve_type_uint32_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrwq_scatter_offset_p_u32 (__ARM_mve_coerce(__p0, uint32_t *), p1, __ARM_mve_coerce(__p2, uint32x4_t), p3));})
 
 #define __arm_vstrwq_scatter_shifted_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
@@ -40160,32 +39992,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_veorq_x_u16 (__ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
   int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_veorq_x_u32 (__ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
 
-#define __arm_vmaxq_x(p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmulq_x_s8 (__ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmulq_x_s16 (__ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmulq_x_s32 (__ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int_n]: __arm_vmulq_x_n_s8 (__ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8_t), p3), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int_n]: __arm_vmulq_x_n_s16 (__ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16_t), p3), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int_n]: __arm_vmulq_x_n_s32 (__ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32_t), p3), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vmulq_x_u8 (__ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t), p3), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vmulq_x_u16 (__ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
-  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vmulq_x_u32 (__ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_int_n]: __arm_vmulq_x_n_u8 (__ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8_t), p3), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_int_n]: __arm_vmulq_x_n_u16 (__ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16_t), p3), \
-  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_int_n]: __arm_vmulq_x_n_u32 (__ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32_t), p3));})
-
-#define __arm_vminq_x(p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vminq_x_s8 (__ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vminq_x_s16 (__ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vminq_x_s32 (__ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vminq_x_u8 (__ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t), p3), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vminq_x_u16 (__ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
-  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vminq_x_u32 (__ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
-
 #define __arm_vmovlbq_x(p1,p2) ({ __typeof(p1) __p1 = (p1); \
   _Generic( (int (*)[__ARM_mve_typeid(__p1)])0, \
   int (*)[__ARM_mve_type_int8x16_t]: __arm_vmovlbq_x_s8 (__ARM_mve_coerce(__p1, int8x16_t), p2), \
@@ -41013,13 +40819,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsldavaxq_p_s16(__p0, __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
   int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsldavaxq_p_s32(__p0, __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3));})
 
-#define __arm_vrmlaldavhaq_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int_n][__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vrmlaldavhaq_p_s32 (__ARM_mve_coerce(__p0, int64_t), __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_int_n][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vrmlaldavhaq_p_u32 (__ARM_mve_coerce(__p0, uint64_t), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
-
 #define __arm_vrmlaldavhaxq_p(p0,p1,p2,p3) __arm_vrmlaldavhaxq_p_s32(p0,p1,p2,p3)
 
 #define __arm_vrmlsldavhaq_p(p0,p1,p2,p3) __arm_vrmlsldavhaq_p_s32(p0,p1,p2,p3)
@@ -41343,21 +41142,47 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vqrdmladhxq_m_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
   int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vqrdmladhxq_m_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3));})
 
-#define __arm_vmlsdavaxq_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
+#define __arm_vmlsdavaxq_p(p0,p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
+  __typeof(p2) __p2 = (p2); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavaxq_p_s8 (p0, __ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
+  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavaxq_p_s16 (p0, __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
+  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavaxq_p_s32 (p0, __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3));})
+
+#define __arm_vmlsdavaq(p0,p1,p2) ({  __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
   _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavaxq_p_s8 (__p0, __ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavaxq_p_s16 (__p0, __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavaxq_p_s32 (__p0, __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3));})
+  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavaq_s8(p0, __ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t)), \
+  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavaq_s16(p0, __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t)), \
+  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavaq_s32(p0, __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t)));})
+
+#define __arm_vmlsdavaxq(p0,p1,p2) ({ __typeof(p2) __p2 = (p2); \
+  __typeof(p1) __p1 = (p1); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavaxq_s8(p0, __ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t)), \
+  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavaxq_s16(p0, __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t)), \
+  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavaxq_s32(p0, __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t)));})
+
+#define __arm_vmlsdavq_p(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p1) __p1 = (p1); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
+  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavq_p_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t), p2), \
+  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavq_p_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
+  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavq_p_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t), p2));})
 
-#define __arm_vmlsdavaq_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
+#define __arm_vmlsdavxq_p(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p1) __p1 = (p1); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
+  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavxq_p_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t), p2), \
+  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavxq_p_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
+  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavxq_p_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t), p2));})
+
+#define __arm_vmlsdavaq_p(p0,p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
   _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavaq_p_s8(__p0, __ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavaq_p_s16(__p0, __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavaq_p_s32(__p0, __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3));})
+  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavaq_p_s8(p0, __ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
+  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavaq_p_s16(p0, __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
+  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavaq_p_s32(p0, __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3));})
 
 #define __arm_vmladavaxq_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p1) __p1 = (p1); \
@@ -41445,8 +41270,8 @@ extern void *__ARM_undef;
 
 #define __arm_viwdupq_u16(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
   _Generic( (int (*)[__ARM_mve_typeid(__p0)])0, \
-  int (*)[__ARM_mve_type_int_n]: __arm_viwdupq_n_u16 (__ARM_mve_coerce(__p0, uint32_t), p1, p2), \
-  int (*)[__ARM_mve_type_uint32_t_ptr]: __arm_viwdupq_wb_u16 (__ARM_mve_coerce(__p0, uint32_t *), p1, p2));})
+  int (*)[__ARM_mve_type_int_n]: __arm_viwdupq_n_u16 (__ARM_mve_coerce(__p0, uint32_t), p1, (const int) p2), \
+  int (*)[__ARM_mve_type_uint32_t_ptr]: __arm_viwdupq_wb_u16 (__ARM_mve_coerce(__p0, uint32_t *), p1, (const int) p2));})
 
 #define __arm_viwdupq_u32(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
   _Generic( (int (*)[__ARM_mve_typeid(__p0)])0, \
@@ -41628,16 +41453,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_int_n][__ARM_mve_type_int16x8_t]: __arm_vmaxavq_p_s16 (__p0, __ARM_mve_coerce(__p1, int16x8_t), p2), \
   int (*)[__ARM_mve_type_int_n][__ARM_mve_type_int32x4_t]: __arm_vmaxavq_p_s32 (__p0, __ARM_mve_coerce(__p1, int32x4_t), p2));})
 
-#define __arm_vmaxq_x(p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmaxq_x_s8 (__ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmaxq_x_s16 (__ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmaxq_x_s32 (__ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vmaxq_x_u8( __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t), p3), \
-  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vmaxq_x_u16( __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
-  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vmaxq_x_u32( __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
-
 #define __arm_vmaxvq(p0,p1) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p1) __p1 = (p1); \
   _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
@@ -41672,6 +41487,16 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_int_n][__ARM_mve_type_int16x8_t]: __arm_vminavq_p_s16 (__p0, __ARM_mve_coerce(__p1, int16x8_t), p2), \
   int (*)[__ARM_mve_type_int_n][__ARM_mve_type_int32x4_t]: __arm_vminavq_p_s32 (__p0, __ARM_mve_coerce(__p1, int32x4_t), p2));})
 
+#define __arm_vmaxq_x(p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
+  __typeof(p2) __p2 = (p2); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmaxq_x_s8 (__ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
+  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmaxq_x_s16 (__ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
+  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmaxq_x_s32 (__ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3), \
+  int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vmaxq_x_u8 (__ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t), p3), \
+  int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vmaxq_x_u16 (__ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
+  int (*)[__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vmaxq_x_u32 (__ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
+
 #define __arm_vminq_x(p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
   _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
@@ -41810,22 +41635,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlaldavxq_p_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
   int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlaldavxq_p_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t), p2));})
 
-#define __arm_vmlsdavaq(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavaq_s8(__p0, __ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t)), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavaq_s16(__p0, __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t)), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavaq_s32(__p0, __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t)));})
-
-#define __arm_vmlsdavaxq(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavaxq_s8(__p0, __ARM_mve_coerce(__p1, int8x16_t), __ARM_mve_coerce(__p2, int8x16_t)), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavaxq_s16(__p0, __ARM_mve_coerce(__p1, int16x8_t), __ARM_mve_coerce(__p2, int16x8_t)), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavaxq_s32(__p0, __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t)));})
-
 #define __arm_vmlsdavq(p0,p1) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p1) __p1 = (p1); \
   _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
@@ -41833,13 +41642,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavq_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t)), \
   int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavq_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t)));})
 
-#define __arm_vmlsdavq_p(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavq_p_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavq_p_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavq_p_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t), p2));})
-
 #define __arm_vmlsdavxq(p0,p1) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p1) __p1 = (p1); \
   _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
@@ -41847,13 +41649,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavxq_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t)), \
   int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavxq_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t)));})
 
-#define __arm_vmlsdavxq_p(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8x16_t][__ARM_mve_type_int8x16_t]: __arm_vmlsdavxq_p_s8 (__ARM_mve_coerce(__p0, int8x16_t), __ARM_mve_coerce(__p1, int8x16_t), p2), \
-  int (*)[__ARM_mve_type_int16x8_t][__ARM_mve_type_int16x8_t]: __arm_vmlsdavxq_p_s16 (__ARM_mve_coerce(__p0, int16x8_t), __ARM_mve_coerce(__p1, int16x8_t), p2), \
-  int (*)[__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vmlsdavxq_p_s32 (__ARM_mve_coerce(__p0, int32x4_t), __ARM_mve_coerce(__p1, int32x4_t), p2));})
-
 #define __arm_vmlsldavaq(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
   __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
@@ -41948,13 +41743,6 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vmulltq_poly_x_p8 (__ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t), p3), \
   int (*)[__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vmulltq_poly_x_p16 (__ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3));})
 
-#define __arm_vrmlaldavhaq(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
-  __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int_n][__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vrmlaldavhaq_s32 (__ARM_mve_coerce(__p0, int64_t), __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t)), \
-  int (*)[__ARM_mve_type_int_n][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vrmlaldavhaq_u32 (__ARM_mve_coerce(__p0, uint64_t), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t)));})
-
 #define __arm_vrmlaldavhaxq(p0,p1,p2) __arm_vrmlaldavhaxq_s32(p0,p1,p2)
 
 #define __arm_vrmlaldavhq(p0,p1) ({ __typeof(p0) __p0 = (p0); \
@@ -41994,35 +41782,15 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_u16 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t)), \
   int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_u32 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t)));})
 
-#define __arm_vstrbq_p(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p1)])0, \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int8x16_t]: __arm_vstrbq_p_s8 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, int8x16_t), p2), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int16x8_t]: __arm_vstrbq_p_s16 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, int16x8_t), p2), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrbq_p_s32 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, int32x4_t), p2), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_p_u8 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t), p2), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_p_u16 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t), p2), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_p_u32 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t), p2));})
-
-#define __arm_vstrbq_scatter_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_int8x16_t]: __arm_vstrbq_scatter_offset_s8 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, int8x16_t)), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_int16x8_t]: __arm_vstrbq_scatter_offset_s16 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, int16x8_t)), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_int32x4_t]: __arm_vstrbq_scatter_offset_s32 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, int32x4_t)), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_scatter_offset_u8 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t)), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_scatter_offset_u16 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t)), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_scatter_offset_u32 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t)));})
-
-
-#define __arm_vstrbq_scatter_offset_p(p0,p1,p2,p3) ({__typeof(p1) __p1 = (p1); \
-  __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_int8x16_t]: __arm_vstrbq_scatter_offset_p_s8 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_int16x8_t]: __arm_vstrbq_scatter_offset_p_s16 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
-  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_int32x4_t]: __arm_vstrbq_scatter_offset_p_s32 (__ARM_mve_coerce(p0, int8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_scatter_offset_p_u8 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t), p3), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_scatter_offset_p_u16 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
-  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_scatter_offset_p_u32 (__ARM_mve_coerce(p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
+#define __arm_vstrbq_p(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p1) __p1 = (p1); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)])0, \
+  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int8x16_t]: __arm_vstrbq_p_s8 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, int8x16_t), p2), \
+  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int16x8_t]: __arm_vstrbq_p_s16 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, int16x8_t), p2), \
+  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_int32x4_t]: __arm_vstrbq_p_s32 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, int32x4_t), p2), \
+  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_p_u8 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t), p2), \
+  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_p_u16 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t), p2), \
+  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_p_u32 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t), p2));})
 
 #define __arm_vstrdq_scatter_base(p0,p1,p2) ({ __typeof(p2) __p2 = (p2); \
   _Generic( (int (*)[__ARM_mve_typeid(__p2)])0, \
@@ -42034,29 +41802,65 @@ extern void *__ARM_undef;
   int (*)[__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_base_p_s64 (p0, p1, __ARM_mve_coerce(__p2, int64x2_t), p3), \
   int (*)[__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_base_p_u64 (p0, p1, __ARM_mve_coerce(__p2, uint64x2_t), p3));})
 
-#define __arm_vstrdq_scatter_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
+#define __arm_vrmlaldavhaq(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_offset_s64 (__ARM_mve_coerce(p0, int64_t *), __p1, __ARM_mve_coerce(__p2, int64x2_t)), \
-  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_offset_u64 (__ARM_mve_coerce(p0, uint64_t *), __p1, __ARM_mve_coerce(__p2, uint64x2_t)));})
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int_n][__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vrmlaldavhaq_s32 (__ARM_mve_coerce(__p0, int64_t), __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t)), \
+  int (*)[__ARM_mve_type_int_n][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vrmlaldavhaq_u32 (__ARM_mve_coerce(__p0, uint64_t), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t)));})
 
-#define __arm_vstrdq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
+#define __arm_vrmlaldavhaq_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_offset_p_s64 (__ARM_mve_coerce(p0, int64_t *), __p1, __ARM_mve_coerce(__p2, int64x2_t), p3), \
-  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_offset_p_u64 (__ARM_mve_coerce(p0, uint64_t *), __p1, __ARM_mve_coerce(__p2, uint64x2_t), p3));})
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int_n][__ARM_mve_type_int32x4_t][__ARM_mve_type_int32x4_t]: __arm_vrmlaldavhaq_p_s32 (__ARM_mve_coerce(__p0, int64_t), __ARM_mve_coerce(__p1, int32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3), \
+  int (*)[__ARM_mve_type_int_n][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vrmlaldavhaq_p_u32 (__ARM_mve_coerce(__p0, uint64_t), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
 
-#define __arm_vstrdq_scatter_shifted_offset(p0,p1,p2) ({ __typeof(p1) __p1 = (p1); \
+#define __arm_vstrbq_scatter_offset(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_shifted_offset_s64 (__ARM_mve_coerce(p0, int64_t *), __p1, __ARM_mve_coerce(__p2, int64x2_t)), \
-  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_shifted_offset_u64 (__ARM_mve_coerce(p0, uint64_t *), __p1, __ARM_mve_coerce(__p2, uint64x2_t)));})
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_int8x16_t]: __arm_vstrbq_scatter_offset_s8 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, int8x16_t)), \
+  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_int16x8_t]: __arm_vstrbq_scatter_offset_s16 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, int16x8_t)), \
+  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_int32x4_t]: __arm_vstrbq_scatter_offset_s32 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, int32x4_t)), \
+  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_scatter_offset_u8 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t)), \
+  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_scatter_offset_u16 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t)), \
+  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_scatter_offset_u32 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t)));})
 
-#define __arm_vstrdq_scatter_shifted_offset_p(p0,p1,p2,p3) ({ __typeof(p1) __p1 = (p1); \
+#define __arm_vstrbq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p1) __p1 = (p1); \
   __typeof(p2) __p2 = (p2); \
-  _Generic( (int (*)[__ARM_mve_typeid(p0)][__ARM_mve_typeid(__p2)])0, \
-  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_shifted_offset_p_s64 (__ARM_mve_coerce(p0, int64_t *), __p1, __ARM_mve_coerce(__p2, int64x2_t), p3), \
-  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_shifted_offset_p_u64 (__ARM_mve_coerce(p0, uint64_t *), __p1, __ARM_mve_coerce(__p2, uint64x2_t), p3));})
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p1)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_int8x16_t]: __arm_vstrbq_scatter_offset_p_s8 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, int8x16_t), p3), \
+  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_int16x8_t]: __arm_vstrbq_scatter_offset_p_s16 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, int16x8_t), p3), \
+  int (*)[__ARM_mve_type_int8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_int32x4_t]: __arm_vstrbq_scatter_offset_p_s32 (__ARM_mve_coerce(__p0, int8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, int32x4_t), p3), \
+  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint8x16_t][__ARM_mve_type_uint8x16_t]: __arm_vstrbq_scatter_offset_p_u8 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint8x16_t), __ARM_mve_coerce(__p2, uint8x16_t), p3), \
+  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint16x8_t][__ARM_mve_type_uint16x8_t]: __arm_vstrbq_scatter_offset_p_u16 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint16x8_t), __ARM_mve_coerce(__p2, uint16x8_t), p3), \
+  int (*)[__ARM_mve_type_uint8_t_ptr][__ARM_mve_type_uint32x4_t][__ARM_mve_type_uint32x4_t]: __arm_vstrbq_scatter_offset_p_u32 (__ARM_mve_coerce(__p0, uint8_t *), __ARM_mve_coerce(__p1, uint32x4_t), __ARM_mve_coerce(__p2, uint32x4_t), p3));})
+
+#define __arm_vstrdq_scatter_offset_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p2) __p2 = (p2); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_offset_p_s64 (__ARM_mve_coerce(__p0, int64_t *), p1, __ARM_mve_coerce(__p2, int64x2_t), p3), \
+  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_offset_p_u64 (__ARM_mve_coerce(__p0, uint64_t *), p1, __ARM_mve_coerce(__p2, uint64x2_t), p3));})
+
+#define __arm_vstrdq_scatter_offset(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p2) __p2 = (p2); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_offset_s64 (__ARM_mve_coerce(__p0, int64_t *), p1, __ARM_mve_coerce(__p2, int64x2_t)), \
+  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_offset_u64 (__ARM_mve_coerce(__p0, uint64_t *), p1, __ARM_mve_coerce(__p2, uint64x2_t)));})
+
+#define __arm_vstrdq_scatter_shifted_offset_p(p0,p1,p2,p3) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p2) __p2 = (p2); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_shifted_offset_p_s64 (__ARM_mve_coerce(__p0, int64_t *), p1, __ARM_mve_coerce(__p2, int64x2_t), p3), \
+  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_shifted_offset_p_u64 (__ARM_mve_coerce(__p0, uint64_t *), p1, __ARM_mve_coerce(__p2, uint64x2_t), p3));})
+
+#define __arm_vstrdq_scatter_shifted_offset(p0,p1,p2) ({ __typeof(p0) __p0 = (p0); \
+  __typeof(p2) __p2 = (p2); \
+  _Generic( (int (*)[__ARM_mve_typeid(__p0)][__ARM_mve_typeid(__p2)])0, \
+  int (*)[__ARM_mve_type_int64_t_ptr][__ARM_mve_type_int64x2_t]: __arm_vstrdq_scatter_shifted_offset_s64 (__ARM_mve_coerce(__p0, int64_t *), p1, __ARM_mve_coerce(__p2, int64x2_t)), \
+  int (*)[__ARM_mve_type_uint64_t_ptr][__ARM_mve_type_uint64x2_t]: __arm_vstrdq_scatter_shifted_offset_u64 (__ARM_mve_coerce(__p0, uint64_t *), p1, __ARM_mve_coerce(__p2, uint64x2_t)));})
 
 #endif /* __cplusplus  */
 #endif /* __ARM_FEATURE_MVE  */

From 4415051422690e6eda2ff6644b4f35432fcd7707 Mon Sep 17 00:00:00 2001
From: Martin Sebor <msebor@redhat.com>
Date: Thu, 13 May 2021 10:45:32 -0600
Subject: [PATCH 116/164] PR c/100550 - ICE: in fold_convert_loc with function
 call VLA argument

gcc/c/ChangeLog:

	PR c/100550
	* c-decl.c (get_parm_array_spec): Avoid erroneous VLA bounds.

gcc/testsuite/ChangeLog:

	PR c/100550
	* gcc.dg/Wvla-parameter-9.c: New test.
---
 gcc/c/c-decl.c                          |  3 +++
 gcc/testsuite/gcc.dg/Wvla-parameter-9.c | 30 +++++++++++++++++++++++++
 2 files changed, 33 insertions(+)
 create mode 100644 gcc/testsuite/gcc.dg/Wvla-parameter-9.c

diff --git a/gcc/c/c-decl.c b/gcc/c/c-decl.c
index 3ea4708c5075d..53b2b5b637de2 100644
--- a/gcc/c/c-decl.c
+++ b/gcc/c/c-decl.c
@@ -5856,6 +5856,9 @@ get_parm_array_spec (const struct c_parm *parm, tree attrs)
 	  spec += buf;
 	  break;
 	}
+      else if (!INTEGRAL_TYPE_P (TREE_TYPE (nelts)))
+	/* Avoid invalid NELTS.  */
+	return attrs;
 
       /* Each variable VLA bound is represented by a dollar sign.  */
       spec += "$";
diff --git a/gcc/testsuite/gcc.dg/Wvla-parameter-9.c b/gcc/testsuite/gcc.dg/Wvla-parameter-9.c
new file mode 100644
index 0000000000000..6c8987a34eb0d
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/Wvla-parameter-9.c
@@ -0,0 +1,30 @@
+/* PR c/100550 - ICE: in fold_convert_loc with function call VLA argument
+   { dg-do compile }
+   { dg-options "-Wall" } */
+
+struct S { int i; };
+
+extern void v;
+extern void *pv;
+extern struct S s;
+void vf (void);
+
+/* Verify that a function redeclaration with an invalid VLA doesn't ICE.  */
+
+void f0 (int[]);
+void f0 (int[undeclared]);    // { dg-error "undeclared" }
+
+void f1 (int[]);
+void f1 (int[-1]);            // { dg-error "size" }
+
+void f2 (int[]);
+void f2 (int[v]);             // { dg-error "size" }
+
+void f3 (int[]);
+void f3 (int b[s]);           // { dg-error "size" }
+
+void f4 (int[]);
+void f4 (int c[pv]);          // { dg-error "size" }
+
+void f5 (int[]);
+void f5 (int d[vf ()]);       // { dg-error "size" }

From e218c2985d21dbdf747f39aa478cf696f85f226b Mon Sep 17 00:00:00 2001
From: Iain Buclaw <ibuclaw@gdcproject.org>
Date: Thu, 13 May 2021 19:09:48 +0200
Subject: [PATCH 117/164] libphobos: Fix static asserts on NetBSD, FreeBSD,
 DragonFlyBSD

The function declarations were updated to use `const scope', but the
static asserts were not.

libphobos/ChangeLog:

	* libdruntime/core/sys/dragonflybsd/dlfcn.d: Update static assert.
	* libdruntime/core/sys/freebsd/dlfcn.d: Likewise.
	* libdruntime/core/sys/netbsd/dlfcn.d: Likewise.
	* libdruntime/core/sys/posix/dlfcn.d: Replace 'in' with 'const scope'.

(cherry picked from commit 7677b501341d84e9889ddf0f3834b5d1ad2922f9)
---
 .../libdruntime/core/sys/dragonflybsd/dlfcn.d     | 15 ++++++---------
 libphobos/libdruntime/core/sys/freebsd/dlfcn.d    |  4 ++--
 libphobos/libdruntime/core/sys/netbsd/dlfcn.d     | 15 ++++++---------
 libphobos/libdruntime/core/sys/posix/dlfcn.d      |  4 ++--
 4 files changed, 16 insertions(+), 22 deletions(-)

diff --git a/libphobos/libdruntime/core/sys/dragonflybsd/dlfcn.d b/libphobos/libdruntime/core/sys/dragonflybsd/dlfcn.d
index 1d3812fc55bed..2c5d8d79c22bf 100644
--- a/libphobos/libdruntime/core/sys/dragonflybsd/dlfcn.d
+++ b/libphobos/libdruntime/core/sys/dragonflybsd/dlfcn.d
@@ -82,16 +82,13 @@ struct __dlfunc_arg {
 
 alias dlfunc_t = void function(__dlfunc_arg);
 
-private template __externC(RT, P...)
-{
-    alias __externC = extern(C) RT function(P) nothrow @nogc @system;
-}
-
 /* XSI functions first. */
-static assert(is(typeof(&dlclose) == __externC!(int, void*)));
-static assert(is(typeof(&dlerror) == __externC!(char*)));
-static assert(is(typeof(&dlopen)  == __externC!(void*, const char*, int)));
-static assert(is(typeof(&dlsym)   == __externC!(void*, void*, const char*)));
+extern(C) {
+    static assert(is(typeof(&dlclose) == int function(void*)));
+    static assert(is(typeof(&dlerror) == char* function()));
+    static assert(is(typeof(&dlopen)  == void* function(const scope char*, int)));
+    static assert(is(typeof(&dlsym)   == void* function(void*, const scope char*)));
+}
 
 void*    fdlopen(int, int);
 int      dladdr(const(void)*, Dl_info*);
diff --git a/libphobos/libdruntime/core/sys/freebsd/dlfcn.d b/libphobos/libdruntime/core/sys/freebsd/dlfcn.d
index fad91418e6d70..7baacfeeb7bcc 100644
--- a/libphobos/libdruntime/core/sys/freebsd/dlfcn.d
+++ b/libphobos/libdruntime/core/sys/freebsd/dlfcn.d
@@ -90,8 +90,8 @@ static if (__BSD_VISIBLE)
 extern(C) {
     static assert(is(typeof(&dlclose) == int function(void*)));
     static assert(is(typeof(&dlerror) == char* function()));
-    static assert(is(typeof(&dlopen)  == void* function(in char*, int)));
-    static assert(is(typeof(&dlsym)   == void* function(void*, in char*)));
+    static assert(is(typeof(&dlopen)  == void* function(const scope char*, int)));
+    static assert(is(typeof(&dlsym)   == void* function(void*, const scope char*)));
 }
 
 static if (__BSD_VISIBLE)
diff --git a/libphobos/libdruntime/core/sys/netbsd/dlfcn.d b/libphobos/libdruntime/core/sys/netbsd/dlfcn.d
index dbbcc7638fdbc..468ffbfe435e4 100644
--- a/libphobos/libdruntime/core/sys/netbsd/dlfcn.d
+++ b/libphobos/libdruntime/core/sys/netbsd/dlfcn.d
@@ -87,16 +87,13 @@ static if (__BSD_VISIBLE)
     }
 }
 
-private template __externC(RT, P...)
-{
-    alias __externC = extern(C) RT function(P) nothrow @nogc;
-}
-
 /* XSI functions first. */
-static assert(is(typeof(&dlclose) == __externC!(int, void*)));
-static assert(is(typeof(&dlerror) == __externC!(char*)));
-static assert(is(typeof(&dlopen)  == __externC!(void*, const char*, int)));
-static assert(is(typeof(&dlsym)   == __externC!(void*, void*, const char*)));
+extern(C) {
+    static assert(is(typeof(&dlclose) == int function(void*)));
+    static assert(is(typeof(&dlerror) == char* function()));
+    static assert(is(typeof(&dlopen)  == void* function(const scope char*, int)));
+    static assert(is(typeof(&dlsym)   == void* function(void*, const scope char*)));
+}
 
 static if (__BSD_VISIBLE)
 {
diff --git a/libphobos/libdruntime/core/sys/posix/dlfcn.d b/libphobos/libdruntime/core/sys/posix/dlfcn.d
index 2477e26dc53df..f6476ec31060c 100644
--- a/libphobos/libdruntime/core/sys/posix/dlfcn.d
+++ b/libphobos/libdruntime/core/sys/posix/dlfcn.d
@@ -158,8 +158,8 @@ else version (FreeBSD)
 
     int   dlclose(void*);
     char* dlerror();
-    void* dlopen(in char*, int);
-    void* dlsym(void*, in char*);
+    void* dlopen(const scope char*, int);
+    void* dlsym(void*, const scope char*);
     int   dladdr(const(void)* addr, Dl_info* info);
 
     struct Dl_info

From 211a9230491f340cfc23dfe92ad481548a2d511b Mon Sep 17 00:00:00 2001
From: Tobias Burnus <tobias@codesourcery.com>
Date: Thu, 13 May 2021 00:12:31 +0200
Subject: [PATCH 118/164] OpenMP: detach - fix firstprivate handling

gcc/ChangeLog:

	* omp-low.c (finish_taskreg_scan): Use the proper detach decl.

libgomp/ChangeLog:

	* testsuite/libgomp.c-c++-common/task-detach-12.c: New test.
	* testsuite/libgomp.fortran/task-detach-12.f90: New test.

(cherry picked from commit d21963ce7a87db3d4a6921a0fa98b72ea6f4e7f5)
---
 gcc/omp-low.c                                 |  2 +-
 .../libgomp.c-c++-common/task-detach-12.c     | 19 ++++++++++++++++
 .../libgomp.fortran/task-detach-12.f90        | 22 +++++++++++++++++++
 3 files changed, 42 insertions(+), 1 deletion(-)
 create mode 100644 libgomp/testsuite/libgomp.c-c++-common/task-detach-12.c
 create mode 100644 libgomp/testsuite/libgomp.fortran/task-detach-12.f90

diff --git a/gcc/omp-low.c b/gcc/omp-low.c
index 1bb7f2b356156..0817ee7091a43 100644
--- a/gcc/omp-low.c
+++ b/gcc/omp-low.c
@@ -2460,7 +2460,7 @@ finish_taskreg_scan (omp_context *ctx)
 	  TYPE_FIELDS (ctx->record_type) = field;
 	  if (ctx->srecord_type)
 	    {
-	      field = lookup_sfield (OMP_CLAUSE_DECL (detach_clause), ctx);
+	      field = lookup_sfield (OMP_CLAUSE_DECL (c), ctx);
 	      p = &TYPE_FIELDS (ctx->srecord_type);
 	      while (*p)
 		if (*p == field)
diff --git a/libgomp/testsuite/libgomp.c-c++-common/task-detach-12.c b/libgomp/testsuite/libgomp.c-c++-common/task-detach-12.c
new file mode 100644
index 0000000000000..65833189cd618
--- /dev/null
+++ b/libgomp/testsuite/libgomp.c-c++-common/task-detach-12.c
@@ -0,0 +1,19 @@
+/* { dg-do run } */
+/* { dg-options "-fopenmp" } */
+
+#include <omp.h>
+
+int
+main ()
+{
+  struct S { int a[7]; } s = { { 1, 2, 3, 4, 5, 6, 7 } };
+  omp_event_handle_t x;
+  #pragma omp parallel master
+  #pragma omp task firstprivate (s) detach (x)
+    {
+      if (s.a[3] != 4)
+	__builtin_abort ();
+      omp_fulfill_event (x);
+    }
+  return 0;
+}
diff --git a/libgomp/testsuite/libgomp.fortran/task-detach-12.f90 b/libgomp/testsuite/libgomp.fortran/task-detach-12.f90
new file mode 100644
index 0000000000000..88546fe473b25
--- /dev/null
+++ b/libgomp/testsuite/libgomp.fortran/task-detach-12.f90
@@ -0,0 +1,22 @@
+program test
+    use omp_lib
+    implicit none
+    integer(omp_event_handle_kind) :: oevent, ievent
+    integer :: i
+    integer, allocatable :: temp(:)
+    ALLOCATE(temp(5))
+
+    !$omp parallel num_threads(3)
+    !$omp single
+    DO i=1,5
+    !$omp task firstprivate(i) firstprivate(temp)  detach(oevent)
+          temp(:) = 0;
+          temp(1) = -1;
+          !print *,temp
+          call omp_fulfill_event(oevent)
+    !$omp end task
+    ENDDO
+    !$omp taskwait
+    !$omp end single
+    !$omp end parallel
+end program

From 075794604431d4de4002a0b216eba7f9f47bbbe4 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Fri, 14 May 2021 00:18:09 +0000
Subject: [PATCH 119/164] Daily bump.

---
 gcc/ChangeLog           | 38 ++++++++++++++++++++++++++++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/c/ChangeLog         |  5 +++++
 gcc/testsuite/ChangeLog |  9 +++++++++
 libgomp/ChangeLog       |  8 ++++++++
 libphobos/ChangeLog     | 10 ++++++++++
 6 files changed, 71 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index ac263a77e205f..4f91817afd857 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,41 @@
+2021-05-13  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-05-12  Tobias Burnus  <tobias@codesourcery.com>
+
+	* omp-low.c (finish_taskreg_scan): Use the proper detach decl.
+
+2021-05-13  Srinath Parvathaneni  <srinath.parvathaneni@arm.com>
+
+	Backported from master:
+	2021-05-11  Srinath Parvathaneni  <srinath.parvathaneni@arm.com>
+		    Joe Ramsay   <joe.ramsay@arm.com>
+
+	PR target/100419
+	* config/arm/arm_mve.h (__arm_vstrwq_scatter_offset): Fix wrong arguments.
+	(__arm_vcmpneq): Remove duplicate definition.
+	(__arm_vstrwq_scatter_offset_p): Likewise.
+	(__arm_vmaxq_x): Likewise.
+	(__arm_vmlsdavaq): Likewise.
+	(__arm_vmlsdavaxq): Likewise.
+	(__arm_vmlsdavq_p): Likewise.
+	(__arm_vmlsdavxq_p): Likewise.
+	(__arm_vrmlaldavhaq): Likewise.
+	(__arm_vstrbq_p): Likewise.
+	(__arm_vstrbq_scatter_offset): Likewise.
+	(__arm_vstrbq_scatter_offset_p): Likewise.
+	(__arm_vstrdq_scatter_offset): Likewise.
+	(__arm_vstrdq_scatter_offset_p): Likewise.
+	(__arm_vstrdq_scatter_shifted_offset): Likewise.
+	(__arm_vstrdq_scatter_shifted_offset_p): Likewise.
+
+2021-05-13  Richard Earnshaw  <rearnsha@arm.com>
+
+	PR target/100563
+	* config/arm/arm.c (arm_canonicalize_comparison): Correctly
+	canonicalize DImode inequality comparisons against the
+	maximum integral value.
+
 2021-05-12  Richard Biener  <rguenther@suse.de>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 92e74b65a6bb9..552c3b209c0f5 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210513
+20210514
diff --git a/gcc/c/ChangeLog b/gcc/c/ChangeLog
index cb602e0d50ab1..600456f1ebbb3 100644
--- a/gcc/c/ChangeLog
+++ b/gcc/c/ChangeLog
@@ -1,3 +1,8 @@
+2021-05-13  Martin Sebor  <msebor@redhat.com>
+
+	PR c/100550
+	* c-decl.c (get_parm_array_spec): Avoid erroneous VLA bounds.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 03a714a4723b8..401c1f57f965c 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,12 @@
+2021-05-13  Martin Sebor  <msebor@redhat.com>
+
+	PR c/100550
+	* gcc.dg/Wvla-parameter-9.c: New test.
+
+2021-05-13  Richard Earnshaw  <rearnsha@arm.com>
+
+	* gcc.dg/pr100563.c: New test.
+
 2021-05-12  Richard Biener  <rguenther@suse.de>
 
 	Backported from master:
diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
index 93c189ea261fd..7e0fe3d465900 100644
--- a/libgomp/ChangeLog
+++ b/libgomp/ChangeLog
@@ -1,3 +1,11 @@
+2021-05-13  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-05-12  Tobias Burnus  <tobias@codesourcery.com>
+
+	* testsuite/libgomp.c-c++-common/task-detach-12.c: New test.
+	* testsuite/libgomp.fortran/task-detach-12.f90: New test.
+
 2021-05-12  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/libphobos/ChangeLog b/libphobos/ChangeLog
index 81f245c1d5cc8..65122ac7345af 100644
--- a/libphobos/ChangeLog
+++ b/libphobos/ChangeLog
@@ -1,3 +1,13 @@
+2021-05-13  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	Backported from master:
+	2021-05-13  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	* libdruntime/core/sys/dragonflybsd/dlfcn.d: Update static assert.
+	* libdruntime/core/sys/freebsd/dlfcn.d: Likewise.
+	* libdruntime/core/sys/netbsd/dlfcn.d: Likewise.
+	* libdruntime/core/sys/posix/dlfcn.d: Replace 'in' with 'const scope'.
+
 2021-05-10  Iain Buclaw  <ibuclaw@gdcproject.org>
 
 	Backported from master:

From 919dcbb3a77cad24a0099ee7b43bcaaff813d770 Mon Sep 17 00:00:00 2001
From: Martin Liska <mliska@suse.cz>
Date: Fri, 14 May 2021 11:40:58 +0200
Subject: [PATCH 120/164] opts: add Warning keyword for 2 options

gcc/c-family/ChangeLog:

	* c.opt: Add Warning keyword for 2 options.

(cherry picked from commit 40a2f88838e5119799649a74692cbf38d774b706)
---
 gcc/c-family/c.opt | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gcc/c-family/c.opt b/gcc/c-family/c.opt
index 3f8b72cdc0065..2005b783c6828 100644
--- a/gcc/c-family/c.opt
+++ b/gcc/c-family/c.opt
@@ -592,7 +592,7 @@ C ObjC RejectNegative Warning Alias(Werror=, implicit-function-declaration)
 This switch is deprecated; use -Werror=implicit-function-declaration instead.
 
 Wexceptions
-C++ ObjC++ Var(warn_exceptions) Init(1)
+C++ ObjC++ Var(warn_exceptions) Init(1) Warning
 Warn when an exception handler is shadowed by another handler.
 
 Wextra
@@ -1737,7 +1737,7 @@ C++ ObjC Var(flag_module_version_ignore) Integer
 ; undocumented, Very dangerous, but occasionally useful
 
 Winvalid-imported-macros
-C++ ObjC++ Var(warn_imported_macros)
+C++ ObjC++ Var(warn_imported_macros) Warning
 Warn about macros that have conflicting header units definitions.
 
 flang-info-include-translate

From b59973ce8b86f82829fa9f92789ec56461b21b78 Mon Sep 17 00:00:00 2001
From: Jakub Jelinek <jakub@redhat.com>
Date: Fri, 14 May 2021 13:24:12 +0200
Subject: [PATCH 121/164] testsuite: Add testcase for already fixed PR
 [PR88872]

2021-05-14  Jakub Jelinek  <jakub@redhat.com>

	* g++.dg/cpp1y/pr88872.C: New test.

(cherry picked from commit f05627d404038368b99e92ac4df4c29f4ae4a5fa)
---
 gcc/testsuite/g++.dg/cpp1y/pr88872.C | 24 ++++++++++++++++++++++++
 1 file changed, 24 insertions(+)
 create mode 100644 gcc/testsuite/g++.dg/cpp1y/pr88872.C

diff --git a/gcc/testsuite/g++.dg/cpp1y/pr88872.C b/gcc/testsuite/g++.dg/cpp1y/pr88872.C
new file mode 100644
index 0000000000000..3719e395c0ee5
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp1y/pr88872.C
@@ -0,0 +1,24 @@
+// PR c++/88872
+// { dg-do compile { target c++14 } }
+
+struct a {
+  template <typename b> constexpr a(b) : c() {}
+  int c;
+};
+void d();
+template <char...> constexpr a operator"" _n() { return d; }
+struct e;
+struct f {
+  e operator[](int);
+};
+struct g {
+  void h();
+  f i;
+};
+template <typename> struct j {
+  void k() { [](auto) { constexpr auto l = 2_n; }(keywords); }
+  int keywords;
+};
+using m = j<int>;
+class e : public m {};
+void g::h() { i[0].k(); }

From 3196faf468e82d03f3d0785b029d1fbd26cd9db3 Mon Sep 17 00:00:00 2001
From: Martin Liska <mliska@suse.cz>
Date: Fri, 14 May 2021 14:10:33 +0200
Subject: [PATCH 122/164] gcc-changelog: sync scripts.

contrib/ChangeLog:

	* gcc-changelog/git_check_commit.py: Sync from master.
	* gcc-changelog/git_commit.py: Likewise.
	* gcc-changelog/git_email.py: Likewise.
	* gcc-changelog/git_repository.py: Likewise.
	* gcc-changelog/git_update_version.py: Likewise.
	* gcc-changelog/test_email.py: Likewise.
	* gcc-changelog/test_patches.txt: Likewise.
---
 contrib/gcc-changelog/git_check_commit.py   |   9 +-
 contrib/gcc-changelog/git_commit.py         |  43 +-
 contrib/gcc-changelog/git_email.py          |  23 +-
 contrib/gcc-changelog/git_repository.py     |   7 +-
 contrib/gcc-changelog/git_update_version.py |   9 +-
 contrib/gcc-changelog/test_email.py         |  23 +-
 contrib/gcc-changelog/test_patches.txt      | 430 +++++++-------------
 7 files changed, 218 insertions(+), 326 deletions(-)

diff --git a/contrib/gcc-changelog/git_check_commit.py b/contrib/gcc-changelog/git_check_commit.py
index 935425ef81321..9a4c5d448fb1c 100755
--- a/contrib/gcc-changelog/git_check_commit.py
+++ b/contrib/gcc-changelog/git_check_commit.py
@@ -23,19 +23,16 @@
 parser = argparse.ArgumentParser(description='Check git ChangeLog format '
                                  'of a commit')
 parser.add_argument('revisions', default='HEAD', nargs='?',
-                    help='Git revisions (e.g. hash~5..hash or just hash)')
+                    help='Git revisions (e.g. hash~5..hash or just hash) - '
+                    'if not specified: HEAD')
 parser.add_argument('-g', '--git-path', default='.',
                     help='Path to git repository')
 parser.add_argument('-p', '--print-changelog', action='store_true',
                     help='Print final changelog entires')
-parser.add_argument('-n', '--non-strict-mode', action='store_true',
-                    help='Use non-strict mode (allow changes in ChangeLog and '
-                    'other automatically updated files).')
 args = parser.parse_args()
 
 retval = 0
-for git_commit in parse_git_revisions(args.git_path, args.revisions,
-                                      not args.non_strict_mode):
+for git_commit in parse_git_revisions(args.git_path, args.revisions):
     res = 'OK' if git_commit.success else 'FAILED'
     print('Checking %s: %s' % (git_commit.original_info.hexsha, res))
     if git_commit.success:
diff --git a/contrib/gcc-changelog/git_commit.py b/contrib/gcc-changelog/git_commit.py
index b28f7deac230d..4958ab9c1595e 100755
--- a/contrib/gcc-changelog/git_commit.py
+++ b/contrib/gcc-changelog/git_commit.py
@@ -19,8 +19,9 @@
 import difflib
 import os
 import re
+import sys
 
-changelog_locations = {
+default_changelog_locations = {
     'c++tools',
     'config',
     'contrib',
@@ -200,7 +201,7 @@ def __init__(self, message, line=None):
     def __repr__(self):
         s = self.message
         if self.line:
-            s += ':"%s"' % self.line
+            s += ': "%s"' % self.line
         return s
 
 
@@ -287,7 +288,7 @@ def __init__(self, hexsha, date, author, lines, modified_files):
 
 
 class GitCommit:
-    def __init__(self, info, strict=True, commit_to_info_hook=None):
+    def __init__(self, info, commit_to_info_hook=None, ref_name=None):
         self.original_info = info
         self.info = info
         self.message = None
@@ -300,6 +301,7 @@ def __init__(self, info, strict=True, commit_to_info_hook=None):
         self.cherry_pick_commit = None
         self.revert_commit = None
         self.commit_to_info_hook = commit_to_info_hook
+        self.init_changelog_locations(ref_name)
 
         # Skip Update copyright years commits
         if self.info.lines and self.info.lines[0] == 'Update copyright years.':
@@ -323,7 +325,7 @@ def __init__(self, info, strict=True, commit_to_info_hook=None):
         if len(project_files) == len(self.info.modified_files):
             # All modified files are only MISC files
             return
-        elif project_files and strict:
+        elif project_files:
             self.errors.append(Error('ChangeLog, DATESTAMP, BASE-VER and '
                                      'DEV-PHASE updates should be done '
                                      'separately from normal commits'))
@@ -361,15 +363,14 @@ def is_changelog_filename(cls, path, allow_suffix=False):
         else:
             return False
 
-    @classmethod
-    def find_changelog_location(cls, name):
+    def find_changelog_location(self, name):
         if name.startswith('\t'):
             name = name[1:]
         if name.endswith(':'):
             name = name[:-1]
         if name.endswith('/'):
             name = name[:-1]
-        return name if name in changelog_locations else None
+        return name if name in self.changelog_locations else None
 
     @classmethod
     def format_git_author(cls, author):
@@ -389,6 +390,17 @@ def parse_git_name_status(cls, string):
                 modified_files.append((parts[2], 'A'))
         return modified_files
 
+    def init_changelog_locations(self, ref_name):
+        self.changelog_locations = list(default_changelog_locations)
+        if ref_name:
+            version = sys.maxsize
+            if 'releases/gcc-' in ref_name:
+                version = int(ref_name.split('-')[-1])
+            if version >= 12:
+                # HSA and BRIG were removed in GCC 12
+                self.changelog_locations.remove('gcc/brig')
+                self.changelog_locations.remove('libhsail-rt')
+
     def parse_lines(self, all_are_ignored):
         body = self.info.lines
 
@@ -397,7 +409,8 @@ def parse_lines(self, all_are_ignored):
                 continue
             if (changelog_regex.match(b) or self.find_changelog_location(b)
                     or star_prefix_regex.match(b) or pr_regex.match(b)
-                    or dr_regex.match(b) or author_line_regex.match(b)):
+                    or dr_regex.match(b) or author_line_regex.match(b)
+                    or b.lower().startswith(CO_AUTHORED_BY_PREFIX)):
                 self.changes = body[i:]
                 return
         if not all_are_ignored:
@@ -586,7 +599,7 @@ def deduce_changelog_locations(self):
                 for file in entry.files:
                     location = self.get_file_changelog_location(file)
                     if (location == ''
-                       or (location and location in changelog_locations)):
+                       or (location and location in self.changelog_locations)):
                         if changelog and changelog != location:
                             msg = 'could not deduce ChangeLog file, ' \
                                   'not unique location'
@@ -606,11 +619,10 @@ def in_ignored_location(cls, path):
                 return True
         return False
 
-    @classmethod
-    def get_changelog_by_path(cls, path):
+    def get_changelog_by_path(self, path):
         components = path.split('/')
         while components:
-            if '/'.join(components) in changelog_locations:
+            if '/'.join(components) in self.changelog_locations:
                 break
             components = components[:-1]
         return '/'.join(components)
@@ -629,7 +641,12 @@ def check_mentioned_files(self):
             assert not entry.folder.endswith('/')
             for file in entry.files:
                 if not self.is_changelog_filename(file):
-                    mentioned_files.add(os.path.join(entry.folder, file))
+                    item = os.path.join(entry.folder, file)
+                    if item in mentioned_files:
+                        msg = 'same file specified multiple times'
+                        self.errors.append(Error(msg, file))
+                    else:
+                        mentioned_files.add(item)
             for pattern in entry.file_patterns:
                 mentioned_patterns.append(os.path.join(entry.folder, pattern))
 
diff --git a/contrib/gcc-changelog/git_email.py b/contrib/gcc-changelog/git_email.py
index b0547b363aa30..6933e3d71fe53 100755
--- a/contrib/gcc-changelog/git_email.py
+++ b/contrib/gcc-changelog/git_email.py
@@ -32,7 +32,7 @@
 
 
 class GitEmail(GitCommit):
-    def __init__(self, filename, strict=False):
+    def __init__(self, filename):
         self.filename = filename
         diff = PatchSet.from_filename(filename)
         date = None
@@ -68,14 +68,27 @@ def __init__(self, filename, strict=False):
                 t = 'M'
             modified_files.append((target if t != 'D' else source, t))
         git_info = GitInfo(None, date, author, body, modified_files)
-        super().__init__(git_info, strict=strict,
+        super().__init__(git_info,
                          commit_to_info_hook=lambda x: None)
 
 
-# With zero arguments, process every patch file in the ./patches directory.
-# With one argument, process the named patch file.
-# Patch files must be in 'git format-patch' format.
+def show_help():
+    print("""usage: git_email.py [--help] [patch file ...]
+
+Check git ChangeLog format of a patch
+
+With zero arguments, process every patch file in the
+./patches directory.
+With one argument, process the named patch file.
+
+Patch files must be in 'git format-patch' format.""")
+    sys.exit(0)
+
+
 if __name__ == '__main__':
+    if len(sys.argv) == 2 and (sys.argv[1] == '-h' or sys.argv[1] == '--help'):
+        show_help()
+
     if len(sys.argv) == 1:
         allfiles = []
         for root, _dirs, files in os.walk('patches'):
diff --git a/contrib/gcc-changelog/git_repository.py b/contrib/gcc-changelog/git_repository.py
index a0e293d756d8b..2d688826ff84d 100755
--- a/contrib/gcc-changelog/git_repository.py
+++ b/contrib/gcc-changelog/git_repository.py
@@ -29,7 +29,7 @@
 from git_commit import GitCommit, GitInfo, decode_path
 
 
-def parse_git_revisions(repo_path, revisions, strict=True):
+def parse_git_revisions(repo_path, revisions, ref_name=None):
     repo = Repo(repo_path)
 
     def commit_to_info(commit):
@@ -72,7 +72,8 @@ def commit_to_info(commit):
         commits = [repo.commit(revisions)]
 
     for commit in commits:
-        git_commit = GitCommit(commit_to_info(commit.hexsha), strict=strict,
-                               commit_to_info_hook=commit_to_info)
+        git_commit = GitCommit(commit_to_info(commit.hexsha),
+                               commit_to_info_hook=commit_to_info,
+                               ref_name=ref_name)
         parsed_commits.append(git_commit)
     return parsed_commits
diff --git a/contrib/gcc-changelog/git_update_version.py b/contrib/gcc-changelog/git_update_version.py
index 1e2b22b008bf0..0508f19408427 100755
--- a/contrib/gcc-changelog/git_update_version.py
+++ b/contrib/gcc-changelog/git_update_version.py
@@ -57,7 +57,8 @@ def prepend_to_changelog_files(repo, folder, git_commit, add_to_git):
             repo.git.add(full_path)
 
 
-active_refs = ['master', 'releases/gcc-8', 'releases/gcc-9', 'releases/gcc-10']
+active_refs = ['master', 'releases/gcc-9', 'releases/gcc-10',
+               'releases/gcc-11']
 
 parser = argparse.ArgumentParser(description='Update DATESTAMP and generate '
                                  'ChangeLog entries')
@@ -77,7 +78,7 @@ def prepend_to_changelog_files(repo, folder, git_commit, add_to_git):
 origin = repo.remotes['origin']
 
 
-def update_current_branch():
+def update_current_branch(ref_name):
     commit = repo.head.commit
     commit_count = 1
     while commit:
@@ -100,7 +101,7 @@ def update_current_branch():
         if len(head.parents) == 2:
             head = head.parents[1]
         commits = parse_git_revisions(args.git_path, '%s..%s'
-                                      % (commit.hexsha, head.hexsha))
+                                      % (commit.hexsha, head.hexsha), ref_name)
         commits = [c for c in commits if c.info.hexsha not in IGNORED_COMMITS]
         for git_commit in reversed(commits):
             prepend_to_changelog_files(repo, args.git_path, git_commit,
@@ -144,6 +145,6 @@ def update_current_branch():
             branch.checkout()
             origin.pull(rebase=True)
             print('branch pulled and checked out')
-            update_current_branch()
+            update_current_branch(name)
             assert not repo.index.diff(None)
             print('branch is done\n', flush=True)
diff --git a/contrib/gcc-changelog/test_email.py b/contrib/gcc-changelog/test_email.py
index 8abf5c374874b..7472762e66da1 100755
--- a/contrib/gcc-changelog/test_email.py
+++ b/contrib/gcc-changelog/test_email.py
@@ -62,17 +62,17 @@ def tearDown(self):
             assert t.endswith('.patch')
             os.remove(t)
 
-    def get_git_email(self, filename, strict=False):
+    def get_git_email(self, filename):
         with tempfile.NamedTemporaryFile(mode='w+', suffix='.patch',
                                          delete=False) as f:
             f.write('\n'.join(self.patches[filename]))
             self.temps.append(f.name)
-        return GitEmail(f.name, strict)
+        return GitEmail(f.name)
 
-    def from_patch_glob(self, name, strict=False):
+    def from_patch_glob(self, name):
         files = [f for f in self.patches.keys() if f.startswith(name)]
         assert len(files) == 1
-        return self.get_git_email(files[0], strict)
+        return self.get_git_email(files[0])
 
     def test_simple_patch_format(self):
         email = self.get_git_email('0577-aarch64-Add-an-and.patch')
@@ -247,7 +247,7 @@ def test_unique_prs(self):
         assert email.changelog_entries[1].prs == []
 
     def test_multiple_prs_not_added(self):
-        email = self.from_patch_glob('0001-Add-patch_are')
+        email = self.from_patch_glob('0002-Add-patch_are')
         assert not email.errors
         assert email.changelog_entries[0].prs == ['PR target/93492']
         assert email.changelog_entries[1].prs == ['PR target/12345']
@@ -255,18 +255,17 @@ def test_multiple_prs_not_added(self):
         assert email.changelog_entries[2].folder == 'gcc/testsuite'
 
     def test_strict_mode(self):
-        email = self.from_patch_glob('0001-Add-patch_are',
-                                     True)
+        email = self.from_patch_glob('0001-Add-patch_are')
         msg = 'ChangeLog, DATESTAMP, BASE-VER and DEV-PHASE updates should ' \
               'be done separately from normal commits'
         assert email.errors[0].message == msg
 
     def test_strict_mode_normal_patch(self):
-        email = self.get_git_email('0001-Just-test-it.patch', True)
+        email = self.get_git_email('0001-Just-test-it.patch')
         assert not email.errors
 
     def test_strict_mode_datestamp_only(self):
-        email = self.get_git_email('0002-Bump-date.patch', True)
+        email = self.get_git_email('0002-Bump-date.patch')
         assert not email.errors
 
     def test_wrong_changelog_entry(self):
@@ -418,9 +417,13 @@ def test_multiline_bad_parentheses(self):
         assert email.errors[0].message == 'bad parentheses wrapping'
 
     def test_changelog_removal(self):
-        email = self.from_patch_glob('0001-ChangeLog-removal.patch', strict=True)
+        email = self.from_patch_glob('0001-ChangeLog-removal.patch')
         assert not email.errors
 
     def test_long_filenames(self):
         email = self.from_patch_glob('0001-long-filenames')
         assert not email.errors
+
+    def test_multi_same_file(self):
+        email = self.from_patch_glob('0001-OpenMP-Fix-SIMT')
+        assert email.errors[0].message == 'same file specified multiple times'
diff --git a/contrib/gcc-changelog/test_patches.txt b/contrib/gcc-changelog/test_patches.txt
index 3f9806dc0765b..39d40b8861829 100644
--- a/contrib/gcc-changelog/test_patches.txt
+++ b/contrib/gcc-changelog/test_patches.txt
@@ -68,13 +68,6 @@ xxxx-xx-xx  Claudiu Zissulescu  <claziss@synopsys.com>
  create mode 100644 gcc/testsuite/gcc.target/arc/uncached-7.c
  create mode 100644 gcc/testsuite/gcc.target/arc/uncached-8.c
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 91dfcd71a4b..2cc61d68cf3 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/config/arc/arc.c b/gcc/config/arc/arc.c
 index 22475f2732e..e1a865f02e6 100644
 --- a/gcc/config/arc/arc.c
@@ -88,13 +81,6 @@ index cf7aa8d83c9..46cb254ed28 100644
 +++ b/gcc/config/arc/arc.md
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 16ddef07516..991934272e0 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/gcc.target/arc/arc.exp b/gcc/testsuite/gcc.target/arc/arc.exp
 index 8d1844edd22..501d4589c53 100644
@@ -199,20 +185,6 @@ without any data fields.
  4 files changed, 36 insertions(+)
  create mode 100644 gcc/testsuite/g++.dg/tree-ssa/pr93667.C
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 77c2a9ad810..6b53f9a2f07 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 9b4fe11a6f6..8033fa0a3bb 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/testsuite/g++.dg/tree-ssa/pr93667.C b/gcc/testsuite/g++.dg/tree-ssa/pr93667.C
 new file mode 100644
 index 00000000000..d875f53d9ec
@@ -275,20 +247,6 @@ Subject: [PATCH 0413/2034] SRA: Total scalarization after access propagation
  5 files changed, 537 insertions(+), 184 deletions(-)
  create mode 100644 gcc/testsuite/gcc.dg/tree-ssa/pr92706-2.c
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 16247a59304..61da54df346 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 05518848829..38758207989 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/testsuite/gcc.dg/guality/pr59776.c b/gcc/testsuite/gcc.dg/guality/pr59776.c
 index 382abb622bb..6c1c8165b70 100644
 --- a/gcc/testsuite/gcc.dg/guality/pr59776.c
@@ -333,26 +291,12 @@ Subject: [PATCH 0334/2034] Do not generate a unique fnname for resolver.
  gcc/testsuite/gcc.target/i386/pr81213.c |  4 ++--
  4 files changed, 19 insertions(+), 17 deletions(-)
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 45075840824..59806baa757 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/config/i386/i386-features.c b/gcc/config/i386/i386-features.c
 index e580b26b995..b49e6f8d408 100644
 --- a/gcc/config/i386/i386-features.c
 +++ b/gcc/config/i386/i386-features.c
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 2de060843d9..22a37dd1ab2 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/gcc.target/i386/pr81213.c b/gcc/testsuite/gcc.target/i386/pr81213.c
 index 13e15d5fef0..89c47529861 100644
@@ -396,26 +340,12 @@ Co-Authored-By: Jakub Jelinek <jakub@redhat.com>
  8 files changed, 142 insertions(+), 22 deletions(-)
  create mode 100644 gcc/testsuite/g++.dg/pr94314-4.C
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 74dbeeb44c6..9e499ec9c86 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/cgraphclones.c b/gcc/cgraphclones.c
 index c73b8f810f0..8f541a28b6e 100644
 --- a/gcc/cgraphclones.c
 +++ b/gcc/cgraphclones.c
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 756f1d759e6..94d2312022d 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/g++.dg/pr94314-2.C b/gcc/testsuite/g++.dg/pr94314-2.C
 index 36b93ed6d4d..998ce601767 100644
@@ -492,13 +422,6 @@ https://gcc.gnu.org/ml/gcc-patches/2020-01/msg00809.html
  3 files changed, 24 insertions(+), 5 deletions(-)
  create mode 100644 gcc/testsuite/g++.dg/template/pr90916.C
 
-diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
-index 004ce0fdcdf..3cc7c48b490 100644
---- a/gcc/cp/ChangeLog
-+++ b/gcc/cp/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/cp/pt.c b/gcc/cp/pt.c
 index fa82ecad233..4fdc74f9ca8 100644
 --- a/gcc/cp/pt.c
@@ -539,13 +462,6 @@ not broken, but this is both safer and satisfies static analysis.
  libgomp/plugin/plugin-gcn.c | 8 ++++++++
  2 files changed, 17 insertions(+)
 
-diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
-index c524abbbfb6..ee1764d4ae3 100644
---- a/libgomp/ChangeLog
-+++ b/libgomp/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/libgomp/plugin/plugin-gcn.c b/libgomp/plugin/plugin-gcn.c
 index dc72c90962c..4c6a4c03b6e 100644
 --- a/libgomp/plugin/plugin-gcn.c
@@ -578,13 +494,6 @@ ChangeLog:
  gcc/tree-into-ssa.c | 59 ++++++++++++++++++++++++++++++++++++---------
  2 files changed, 55 insertions(+), 12 deletions(-)
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 8c17e5992d2..262f0d6506f 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/tree-into-ssa.c b/gcc/tree-into-ssa.c
 index c27bf2ce121..6528acac31a 100644
 --- a/gcc/tree-into-ssa.c
@@ -683,26 +592,12 @@ just the C-family ones that defined a forwarding macro.
  17 files changed, 146 insertions(+), 95 deletions(-)
  create mode 100644 gcc/testsuite/g++.dg/cpp/pr80005.C
 
-diff --git a/gcc/c-family/ChangeLog b/gcc/c-family/ChangeLog
-index 09ba2c8b40f..fdddb98a74d 100644
---- a/gcc/c-family/ChangeLog
-+++ b/gcc/c-family/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/c-family/c-cppbuiltin.c b/gcc/c-family/c-cppbuiltin.c
 index a6308921dc9..70a12055e27 100644
 --- a/gcc/c-family/c-cppbuiltin.c
 +++ b/gcc/c-family/c-cppbuiltin.c
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index a526e32ac89..67d5f2e9e28 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/g++.dg/cpp/pr80005.C b/gcc/testsuite/g++.dg/cpp/pr80005.C
 new file mode 100644
@@ -731,13 +626,6 @@ index dd15cd6af3c..82fd602f9f1 100644
 +++ b/gcc/testsuite/g++.dg/cpp2a/feat-cxx2a.C
 @@ -1 +1,2 @@
 
-+
-diff --git a/libcpp/ChangeLog b/libcpp/ChangeLog
-index 3249b93fe88..27a841bbdce 100644
---- a/libcpp/ChangeLog
-+++ b/libcpp/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/libcpp/directives.c b/libcpp/directives.c
 index 983206a5838..10735c8c668 100644
@@ -825,13 +713,6 @@ Subject: [PATCH 0004/2034] tree-opt: Fix bootstrap failure in
  gcc/tree-ssa-forwprop.c | 6 +++---
  2 files changed, 12 insertions(+), 3 deletions(-)
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index a195863212e..f7df07343d1 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/tree-ssa-forwprop.c b/gcc/tree-ssa-forwprop.c
 index aac31d02b6c..56c470f6ecf 100644
 --- a/gcc/tree-ssa-forwprop.c
@@ -898,13 +779,6 @@ Subject: [PATCH 0735/2034] PR 87488: Add --with-diagnostics-urls configuration
  gcc/pretty-print.h     |   5 +-
  11 files changed, 328 insertions(+), 26 deletions(-)
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index e6eb6ab4c21..22f990a3088 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/config.in b/gcc/config.in
 index 48292861842..01fb18dbbb5 100644
 --- a/gcc/config.in
@@ -1000,13 +874,6 @@ gcc/ChangeLog
  gcc/cfgloopanal.c | 5 ++++-
  2 files changed, 9 insertions(+), 1 deletion(-)
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 07e5bebe909..f3301b16464 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/cfgloopanal.c b/gcc/cfgloopanal.c
 index 392b1c337c4..0b33e8272a7 100644
 --- a/gcc/cfgloopanal.c
@@ -1073,13 +940,6 @@ Subject: [PATCH 0735/2034] PR 87488: Add --with-diagnostics-urls configuration
  gcc/pretty-print.h     |   5 +-
  11 files changed, 328 insertions(+), 26 deletions(-)
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index e6eb6ab4c21..22f990a3088 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/config.in b/gcc/config.in
 index 48292861842..01fb18dbbb5 100644
 --- a/gcc/config.in
@@ -1187,26 +1047,12 @@ co-authored-by: John Miller2 <jm2@example.com>
  8 files changed, 142 insertions(+), 22 deletions(-)
  create mode 100644 gcc/testsuite/g++.dg/pr94314-4.C
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 74dbeeb44c6..9e499ec9c86 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/cgraphclones.c b/gcc/cgraphclones.c
 index c73b8f810f0..8f541a28b6e 100644
 --- a/gcc/cgraphclones.c
 +++ b/gcc/cgraphclones.c
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 756f1d759e6..94d2312022d 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/g++.dg/pr94314-2.C b/gcc/testsuite/g++.dg/pr94314-2.C
 index 36b93ed6d4d..998ce601767 100644
@@ -1299,26 +1145,12 @@ if it isn't a REG or SUBREG of REG.
  4 files changed, 51 insertions(+), 19 deletions(-)
  create mode 100644 gcc/testsuite/gcc.dg/pr94291.c
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index a1ab9fb4ef3..12803e90b0a 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/combine.c b/gcc/combine.c
 index 58366a6d331..cff76cd3303 100644
 --- a/gcc/combine.c
 +++ b/gcc/combine.c
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 71b5a14bcbe..3cbf891d58d 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/gcc.dg/pr94291.c b/gcc/testsuite/gcc.dg/pr94291.c
 new file mode 100644
@@ -1389,13 +1221,6 @@ index e85a8e8813e..fb776ba5a0e 100644
 +++ b/gcc/ChangeLog
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/c-family/ChangeLog b/gcc/c-family/ChangeLog
-index c429b49e68c..69ea1fdc4f3 100644
---- a/gcc/c-family/ChangeLog
-+++ b/gcc/c-family/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/c-family/c-attribs.c b/gcc/c-family/c-attribs.c
 index ac936d5bbbb..a101312c581 100644
@@ -1432,10 +1257,122 @@ index c212a1a57dc..3dccef39701 100644
 @@ -1 +1,2 @@
 
 +
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 176aa117904..185f9ea725e 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
+diff --git a/gcc/testsuite/c-c++-common/patchable_function_entry-error-1.c b/gcc/testsuite/c-c++-common/patchable_function_entry-error-1.c
+new file mode 100644
+index 00000000000..f60bf46cfe3
+--- /dev/null
++++ b/gcc/testsuite/c-c++-common/patchable_function_entry-error-1.c
+@@ -0,0 +1 @@
++
+diff --git a/gcc/testsuite/c-c++-common/patchable_function_entry-error-2.c b/gcc/testsuite/c-c++-common/patchable_function_entry-error-2.c
+new file mode 100644
+index 00000000000..90f88c78be7
+--- /dev/null
++++ b/gcc/testsuite/c-c++-common/patchable_function_entry-error-2.c
+@@ -0,0 +1 @@
++
+diff --git a/gcc/testsuite/c-c++-common/patchable_function_entry-error-3.c b/gcc/testsuite/c-c++-common/patchable_function_entry-error-3.c
+new file mode 100644
+index 00000000000..4490e5c15ca
+--- /dev/null
++++ b/gcc/testsuite/c-c++-common/patchable_function_entry-error-3.c
+@@ -0,0 +1 @@
++
+diff --git a/gcc/varasm.c b/gcc/varasm.c
+index 271a67abf56..f062e48071f 100644
+--- a/gcc/varasm.c
++++ b/gcc/varasm.c
+@@ -1 +1,2 @@
+
++
+-- 
+2.26.2
+
+=== 0002-Add-patch_area_size-and-patch_area_entry-to-crtl.patch ===
+From 6607bdd99994c834f92fce924abdaea3405f62dc Mon Sep 17 00:00:00 2001
+From: "H.J. Lu" <hjl.tools@gmail.com>
+Date: Fri, 1 May 2020 21:03:10 -0700
+Subject: [PATCH] Add patch_area_size and patch_area_entry to crtl
+
+Currently patchable area is at the wrong place.  It is placed immediately
+after function label and before .cfi_startproc.  A backend should be able
+to add a pseudo patchable area instruction durectly into RTL.  This patch
+adds patch_area_size and patch_area_entry to crtl so that the patchable
+area info is available in RTL passes.
+
+It also limits patch_area_size and patch_area_entry to 65535, which is
+a reasonable maximum size for patchable area.
+
+gcc/
+
+	PR target/93492
+	* cfgexpand.c (pass_expand::execute): Set crtl->patch_area_size
+	and crtl->patch_area_entry.
+	* emit-rtl.h (rtl_data): Add patch_area_size and patch_area_entry.
+	* opts.c (common_handle_option): Limit
+	function_entry_patch_area_size and function_entry_patch_area_start
+	to USHRT_MAX.  Fix a typo in error message.
+	* varasm.c (assemble_start_function): Use crtl->patch_area_size
+	and crtl->patch_area_entry.
+	* doc/invoke.texi: Document the maximum value for
+	-fpatchable-function-entry.
+
+gcc/c-family/
+
+	PR target/12345
+	* c-attribs.c (handle_patchable_function_entry_attribute): Limit
+	value to USHRT_MAX (65535).
+
+---
+ gcc/ChangeLog                                 | 14 ++++++++
+ gcc/c-family/ChangeLog                        |  6 ++++
+ gcc/c-family/c-attribs.c                      |  9 +++++
+ gcc/cfgexpand.c                               | 33 +++++++++++++++++++
+ gcc/doc/invoke.texi                           |  1 +
+ gcc/emit-rtl.h                                |  6 ++++
+ gcc/opts.c                                    |  4 ++-
+ gcc/testsuite/ChangeLog                       |  7 ++++
+ .../patchable_function_entry-error-1.c        |  9 +++++
+ .../patchable_function_entry-error-2.c        |  9 +++++
+ .../patchable_function_entry-error-3.c        | 17 ++++++++++
+ gcc/varasm.c                                  | 30 ++---------------
+ 12 files changed, 116 insertions(+), 29 deletions(-)
+ create mode 100644 gcc/testsuite/c-c++-common/patchable_function_entry-error-1.c
+ create mode 100644 gcc/testsuite/c-c++-common/patchable_function_entry-error-2.c
+ create mode 100644 gcc/testsuite/c-c++-common/patchable_function_entry-error-3.c
+
+diff --git a/gcc/c-family/c-attribs.c b/gcc/c-family/c-attribs.c
+index ac936d5bbbb..a101312c581 100644
+--- a/gcc/c-family/c-attribs.c
++++ b/gcc/c-family/c-attribs.c
+@@ -1 +1,2 @@
+
++
+diff --git a/gcc/cfgexpand.c b/gcc/cfgexpand.c
+index a7ec77d5c85..86efa22bf60 100644
+--- a/gcc/cfgexpand.c
++++ b/gcc/cfgexpand.c
+@@ -1 +1,2 @@
+
++
+diff --git a/gcc/doc/invoke.texi b/gcc/doc/invoke.texi
+index 527d362533a..767d1f07801 100644
+--- a/gcc/doc/invoke.texi
++++ b/gcc/doc/invoke.texi
+@@ -1 +1,2 @@
+
++
+diff --git a/gcc/emit-rtl.h b/gcc/emit-rtl.h
+index a878efe3cf7..3d6565c8a30 100644
+--- a/gcc/emit-rtl.h
++++ b/gcc/emit-rtl.h
+@@ -1 +1,2 @@
+
++
+diff --git a/gcc/opts.c b/gcc/opts.c
+index c212a1a57dc..3dccef39701 100644
+--- a/gcc/opts.c
++++ b/gcc/opts.c
 @@ -1 +1,2 @@
 
 +
@@ -1497,13 +1434,6 @@ gcc/cp/ChangeLog
  3 files changed, 40 insertions(+), 18 deletions(-)
  create mode 100644 gcc/testsuite/g++.dg/cpp2a/lambda-generic-variadic20.C
 
-diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
-index 640e4948130..4b6691a77f0 100644
---- a/gcc/cp/ChangeLog
-+++ b/gcc/cp/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/cp/pt.c b/gcc/cp/pt.c
 index 7bf249cee5c..2fe7b66707c 100644
 --- a/gcc/cp/pt.c
@@ -1539,13 +1469,6 @@ concepts.
  3 files changed, 11 insertions(+)
  create mode 100644 gcc/testsuite/g++.dg/concepts/fn-concept3.C
 
-diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
-index 59646c70fa4..4729e3d331d 100644
---- a/gcc/cp/ChangeLog
-+++ b/gcc/cp/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/cp/except.c b/gcc/cp/except.c
 index e073bd4d2bc..55b4b6af442 100644
 --- a/gcc/cp/except.c
@@ -1573,13 +1496,6 @@ Subject: [PATCH 0129/2034] Add PR number to change log
  gcc/ChangeLog | 1 +
  1 file changed, 1 insertion(+)
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 6c6d586ca75..49ca5f92dec 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 -- 
 2.26.1
 
@@ -1616,13 +1532,6 @@ gcc/testsuite/
  6 files changed, 132 insertions(+)
  create mode 100644 gcc/testsuite/gcc.target/aarch64/movk_2.c
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index efbbbf08225..cea8ffee99c 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/config/aarch64/aarch64-protos.h b/gcc/config/aarch64/aarch64-protos.h
 index 24cc65a383a..d29975a8921 100644
 --- a/gcc/config/aarch64/aarch64-protos.h
@@ -1643,13 +1552,6 @@ index 90eebce85c0..9c1f17d0f85 100644
 +++ b/gcc/config/aarch64/aarch64.md
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 601bc336290..cdb26581b9c 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/gcc.target/aarch64/movk_2.c b/gcc/testsuite/gcc.target/aarch64/movk_2.c
 new file mode 100644
@@ -1836,26 +1738,12 @@ already).
  gcc/testsuite/g++.dg/tree-ssa/pr27830.C |  2 ++
  4 files changed, 47 insertions(+), 5 deletions(-)
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 06f7eda0033..93c3076eb86 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/config/rs6000/rs6000-call.c b/gcc/config/rs6000/rs6000-call.c
 index e08621ace27..a9ae7ab70ca 100644
 --- a/gcc/config/rs6000/rs6000-call.c
 +++ b/gcc/config/rs6000/rs6000-call.c
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 684e408c1a5..245c1512c76 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/g++.dg/tree-ssa/pr27830.C b/gcc/testsuite/g++.dg/tree-ssa/pr27830.C
 index 01c7fc18783..551ebc428cd 100644
@@ -1968,13 +1856,6 @@ index c212a1a57dc..3dccef39701 100644
 +++ b/gcc/opts.c
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 176aa117904..185f9ea725e 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/c-c++-common/patchable_function_entry-error-1.c b/gcc/testsuite/c-c++-common/patchable_function_entry-error-1.c
 new file mode 100644
@@ -2082,13 +1963,6 @@ Subject: [PATCH 0004/2034] tree-opt: Fix bootstrap failure in
  gcc/tree-ssa-forwprop.c | 6 +++---
  2 files changed, 12 insertions(+), 3 deletions(-)
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index a195863212e..f7df07343d1 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/tree-ssa-forwprop.c b/gcc/tree-ssa-forwprop.c
 index aac31d02b6c..56c470f6ecf 100644
 --- a/gcc/tree-ssa-forwprop.c
@@ -2125,13 +1999,6 @@ gcc/testsuite/ChangeLog:
  3 files changed, 89 insertions(+), 7 deletions(-)
  create mode 100644 gcc/testsuite/g++.dg/ext/is_constructible4.C
 
-diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
-index 3ca5d7a11b4..c37e461bcc5 100644
---- a/gcc/cp/ChangeLog
-+++ b/gcc/cp/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/cp/pt.c b/gcc/cp/pt.c
 index 9bb8cc13e5f..872f8ff8f52 100644
 --- a/gcc/cp/pt.c
@@ -2210,26 +2077,12 @@ Subject: [PATCH 0043/2034] Compare TREE_ADDRESSABLE and TYPE_MODE when ODR
  create mode 100644 gcc/testsuite/g++.dg/lto/odr-8_0.C
  create mode 100644 gcc/testsuite/g++.dg/lto/odr-8_1.C
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 38165123654..33ca91a6467 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/ipa-devirt.c b/gcc/ipa-devirt.c
 index f0031957375..b609a77701d 100644
 --- a/gcc/ipa-devirt.c
 +++ b/gcc/ipa-devirt.c
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 8e3b9105188..dc42601794b 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/g++.dg/lto/odr-8_0.C b/gcc/testsuite/g++.dg/lto/odr-8_0.C
 new file mode 100644
@@ -2302,13 +2155,6 @@ gcc/testsuite/ChangeLog:
  create mode 100755 gcc/testsuite/gcc.target/aarch64/advsimd-intrinsics/vdot-3-3.c
  create mode 100755 gcc/testsuite/gcc.target/aarch64/advsimd-intrinsics/vdot-3-4.c
 
-diff --git a/gcc/ChangeLog b/gcc/ChangeLog
-index 9a949980699..49dcecb6777 100644
---- a/gcc/ChangeLog
-+++ b/gcc/ChangeLog
-@@ -1 +1,2 @@
-
-+
 diff --git a/gcc/config/aarch64/aarch64-builtins.c b/gcc/config/aarch64/aarch64-builtins.c
 index f0e0461b7f0..f50c4857e1c 100644
 --- a/gcc/config/aarch64/aarch64-builtins.c
@@ -2343,13 +2189,6 @@ index b9843b83c5f..83720d9802a 100644
 +++ b/gcc/config/aarch64/iterators.md
 @@ -1 +1,2 @@
 
-+
-diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
-index 0d8aa6063a7..8b01aa06a40 100644
---- a/gcc/testsuite/ChangeLog
-+++ b/gcc/testsuite/ChangeLog
-@@ -1 +1,2 @@
-
 +
 diff --git a/gcc/testsuite/gcc.target/aarch64/advsimd-intrinsics/vdot-3-1.c b/gcc/testsuite/gcc.target/aarch64/advsimd-intrinsics/vdot-3-1.c
 new file mode 100755
@@ -3408,14 +3247,6 @@ Subject: [PATCH] Fix a changelog.
  gcc/ChangeLog-2020 | 1 +
  1 file changed, 1 insertion(+)
 
-diff --git a/gcc/ChangeLog-2020 b/gcc/ChangeLog-2020
-index 6553720acad..2c170ef014a 100644
---- a/gcc/ChangeLog-2020
-+++ b/gcc/ChangeLog-2020
-@@ -1 +1,2 @@
- 
-+
- 
 -- 
 2.29.2
 === 0001-Add-macro.patch ===
@@ -3546,3 +3377,32 @@ index 5ad82db1def..53b15f32516 100644
 @@ -1 +1,2 @@
  
 +
+
+=== 0001-OpenMP-Fix-SIMT ===
+From 33b647956caa977d1ae489f9baed9cef70b4f382 Mon Sep 17 00:00:00 2001
+From: Tobias Burnus <tobias@codesourcery.com>
+Date: Fri, 7 May 2021 12:11:51 +0200
+Subject: [PATCH] OpenMP: Fix SIMT for complex/float reduction with && and ||
+
+libgomp/ChangeLog:
+
+	* testsuite/libgomp.c-c++-common/reduction-5.c: New test, testing
+	complex/floating-point || + && reduction with 'omp target'.
+	* testsuite/libgomp.c-c++-common/reduction-5.c: Likewise.
+---
+diff --git a/libgomp/testsuite/libgomp.c-c++-common/reduction-5.c b/libgomp/testsuite/libgomp.c-c++-common/reduction-5.c
+new file mode 100644
+index 00000000000..21540512e23
+--- /dev/null
++++ b/libgomp/testsuite/libgomp.c-c++-common/reduction-5.c
+@@ -0,0 +1,1 @@
++
+diff --git a/libgomp/testsuite/libgomp.c-c++-common/reduction-6.c b/libgomp/testsuite/libgomp.c-c++-common/reduction-6.c
+new file mode 100644
+index 00000000000..21540512e23
+--- /dev/null
++++ b/libgomp/testsuite/libgomp.c-c++-common/reduction-6.c
+@@ -0,0 +1,1 @@
++
+-- 
+2.25.1

From 3f3bcc115c877500851d55bf81dcfa37f6aaf085 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Sat, 15 May 2021 00:18:06 +0000
Subject: [PATCH 123/164] Daily bump.

---
 contrib/ChangeLog       | 10 ++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/c-family/ChangeLog  |  7 +++++++
 gcc/testsuite/ChangeLog |  7 +++++++
 4 files changed, 25 insertions(+), 1 deletion(-)

diff --git a/contrib/ChangeLog b/contrib/ChangeLog
index fe2e2763aa5cb..f2705dd5d6886 100644
--- a/contrib/ChangeLog
+++ b/contrib/ChangeLog
@@ -1,3 +1,13 @@
+2021-05-14  Martin Liska  <mliska@suse.cz>
+
+	* gcc-changelog/git_check_commit.py: Sync from master.
+	* gcc-changelog/git_commit.py: Likewise.
+	* gcc-changelog/git_email.py: Likewise.
+	* gcc-changelog/git_repository.py: Likewise.
+	* gcc-changelog/git_update_version.py: Likewise.
+	* gcc-changelog/test_email.py: Likewise.
+	* gcc-changelog/test_patches.txt: Likewise.
+
 2021-04-27  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 552c3b209c0f5..40eb1cad583bc 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210514
+20210515
diff --git a/gcc/c-family/ChangeLog b/gcc/c-family/ChangeLog
index 786a4249ef8c8..ed95b4ae0565e 100644
--- a/gcc/c-family/ChangeLog
+++ b/gcc/c-family/ChangeLog
@@ -1,3 +1,10 @@
+2021-05-14  Martin Liska  <mliska@suse.cz>
+
+	Backported from master:
+	2021-05-14  Martin Liska  <mliska@suse.cz>
+
+	* c.opt: Add Warning keyword for 2 options.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 401c1f57f965c..e4fd12da0588c 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,10 @@
+2021-05-14  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2021-05-14  Jakub Jelinek  <jakub@redhat.com>
+
+	* g++.dg/cpp1y/pr88872.C: New test.
+
 2021-05-13  Martin Sebor  <msebor@redhat.com>
 
 	PR c/100550

From 77add0e7cf5aade93c183fe9b469aa2ef748ab0b Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Sun, 16 May 2021 00:18:13 +0000
Subject: [PATCH 124/164] Daily bump.

---
 gcc/DATESTAMP | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 40eb1cad583bc..a271d95c27f2a 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210515
+20210516

From 72b9eac123016b26c9514260f1a446e06b88b2f0 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Mon, 17 May 2021 00:18:10 +0000
Subject: [PATCH 125/164] Daily bump.

---
 gcc/DATESTAMP | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index a271d95c27f2a..915a0b235e74b 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210516
+20210517

From ca205a821cd35a1b903230f9a2bb5e96487717f6 Mon Sep 17 00:00:00 2001
From: Richard Biener <rguenther@suse.de>
Date: Mon, 17 May 2021 08:51:03 +0200
Subject: [PATCH 126/164] Update mpfr version to 3.1.6

This updates the mpfr version to 3.1.6 which is the last bugfix
release from the 3.1.x series and avoids printing the version
is buggy but acceptable from our configury.

2021-05-17  Richard Biener  <rguenther@suse.de>

contrib/ChangeLog:
	* download_prerequisites: Update mpfr version to 3.1.6.
	* prerequisites.md5: Update.
	* prerequisites.sha512: Likewise.

(cherry picked from commit 2ec80a3457a1be57736a70007d4851e676bce7e8)
---
 contrib/download_prerequisites | 2 +-
 contrib/prerequisites.md5      | 2 +-
 contrib/prerequisites.sha512   | 2 +-
 3 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/contrib/download_prerequisites b/contrib/download_prerequisites
index 7d0c4b5ea8dcf..51e715f69e1a6 100755
--- a/contrib/download_prerequisites
+++ b/contrib/download_prerequisites
@@ -28,7 +28,7 @@ version='(unversioned)'
 # `contrib/prerequisites.md5` with the new checksums.
 
 gmp='gmp-6.1.0.tar.bz2'
-mpfr='mpfr-3.1.4.tar.bz2'
+mpfr='mpfr-3.1.6.tar.bz2'
 mpc='mpc-1.0.3.tar.gz'
 isl='isl-0.18.tar.bz2'
 
diff --git a/contrib/prerequisites.md5 b/contrib/prerequisites.md5
index cc71e0f4de68a..272f7a429b6f2 100644
--- a/contrib/prerequisites.md5
+++ b/contrib/prerequisites.md5
@@ -1,4 +1,4 @@
 86ee6e54ebfc4a90b643a65e402c4048  gmp-6.1.0.tar.bz2
-b8a2f6b0e68bef46e53da2ac439e1cf4  mpfr-3.1.4.tar.bz2
+320c28198def956aeacdb240b46b8969  mpfr-3.1.6.tar.bz2
 d6a1d5f8ddea3abd2cc3e98f58352d26  mpc-1.0.3.tar.gz
 11436d6b205e516635b666090b94ab32  isl-0.18.tar.bz2
diff --git a/contrib/prerequisites.sha512 b/contrib/prerequisites.sha512
index cf6b93b8d6b81..71601457cfc5c 100644
--- a/contrib/prerequisites.sha512
+++ b/contrib/prerequisites.sha512
@@ -1,4 +1,4 @@
 3c82aeab9c1596d4da8afac2eec38e429e84f3211e1a572cf8fd2b546493c44c039b922a1133eaaa48bd7f3e11dbe795a384e21ed95cbe3ecc58d7ac02246117  gmp-6.1.0.tar.bz2
-51066066ff2c12ed2198605ecf68846b0c96b548adafa5b80e0c786d0df488411a5e8973358fce7192dc977ad4e68414cf14500e3c39746de62465eb145bb819  mpfr-3.1.4.tar.bz2
+0c310dd7956be527884f8059c195a5aca1042b089d0927ac6341e6310b1250a7059bc61aaaab4dfb76c6ab8b67e440878ca203f72674529bbcb46770ed9b6885  mpfr-3.1.6.tar.bz2
 0028b76df130720c1fad7de937a0d041224806ce5ef76589f19c7b49d956071a683e2f20d154c192a231e69756b19e48208f2889b0c13950ceb7b3cfaf059a43  mpc-1.0.3.tar.gz
 85d0b40f4dbf14cb99d17aa07048cdcab2dc3eb527d2fbb1e84c41b2de5f351025370e57448b63b2b8a8cf8a0843a089c3263f9baee1542d5c2e1cb37ed39d94  isl-0.18.tar.bz2

From da1f3245a8f0655b780c04d4f4cb0b96486547e4 Mon Sep 17 00:00:00 2001
From: Tobias Burnus <tobias@codesourcery.com>
Date: Fri, 14 May 2021 19:19:26 +0200
Subject: [PATCH 127/164] Fortran/OpenMP: Handle implicit SAVE for variables in
 main

gcc/fortran/ChangeLog:

	* resolve.c (resolve_symbol): Handle implicit SAVE of main-program
	for vars in 'omp threadprivate' and 'omp declare target'.

gcc/testsuite/ChangeLog:

	* gfortran.dg/gomp/implicit-save.f90: New test.

(cherry picked from commit 62e1bd651f60cfe3daaad91b41b7612bc7fa7460)
---
 gcc/fortran/resolve.c                            |  6 ++++--
 gcc/testsuite/gfortran.dg/gomp/implicit-save.f90 | 11 +++++++++++
 2 files changed, 15 insertions(+), 2 deletions(-)
 create mode 100644 gcc/testsuite/gfortran.dg/gomp/implicit-save.f90

diff --git a/gcc/fortran/resolve.c b/gcc/fortran/resolve.c
index dd4b26680e04f..fac24560c11fb 100644
--- a/gcc/fortran/resolve.c
+++ b/gcc/fortran/resolve.c
@@ -16038,7 +16038,8 @@ resolve_symbol (gfc_symbol *sym)
       && !(sym->ns->save_all && !sym->attr.automatic)
       && sym->module == NULL
       && (sym->ns->proc_name == NULL
-	  || sym->ns->proc_name->attr.flavor != FL_MODULE))
+	  || (sym->ns->proc_name->attr.flavor != FL_MODULE
+	      && !sym->ns->proc_name->attr.is_main_program)))
     gfc_error ("Threadprivate at %L isn't SAVEd", &sym->declared_at);
 
   /* Check omp declare target restrictions.  */
@@ -16049,7 +16050,8 @@ resolve_symbol (gfc_symbol *sym)
       && (!sym->attr.in_common
 	  && sym->module == NULL
 	  && (sym->ns->proc_name == NULL
-	      || sym->ns->proc_name->attr.flavor != FL_MODULE)))
+	      || (sym->ns->proc_name->attr.flavor != FL_MODULE
+		  && !sym->ns->proc_name->attr.is_main_program))))
     gfc_error ("!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd",
 	       sym->name, &sym->declared_at);
 
diff --git a/gcc/testsuite/gfortran.dg/gomp/implicit-save.f90 b/gcc/testsuite/gfortran.dg/gomp/implicit-save.f90
new file mode 100644
index 0000000000000..2af9647490e7e
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/gomp/implicit-save.f90
@@ -0,0 +1,11 @@
+subroutine foo
+  integer :: n = 5, m = 7
+  !$omp declare target to(n)
+  !$omp threadprivate (m)
+end
+
+program main
+  integer :: i, j
+  !$omp declare target to(i)
+  !$omp threadprivate (j)
+end

From a16952ddf9515aa08b8c9c02a80725801131cc94 Mon Sep 17 00:00:00 2001
From: Marius Hillenbrand <mhillen@linux.ibm.com>
Date: Wed, 12 May 2021 13:59:19 +0200
Subject: [PATCH 128/164] IBM Z: Avoid bash-specific substitution in configure

Fix a bootstrap error observed on NetBSD.

2021-05-17  Marius Hillenbrand  <mhillen@linux.ibm.com>

gcc/ChangeLog:

	PR bootstrap/100552
	* configure.ac: Replace pattern substitution with call to sed.
	* configure: Regenerate.

(cherry picked from commit 47abe2abf1210847629ebc271b1fc8c6d53f0d47)
---
 gcc/configure    | 3 ++-
 gcc/configure.ac | 3 ++-
 2 files changed, 4 insertions(+), 2 deletions(-)

diff --git a/gcc/configure b/gcc/configure
index e8ecb3b0297be..ced77073037a4 100755
--- a/gcc/configure
+++ b/gcc/configure
@@ -32111,7 +32111,8 @@ case $target in
       # cross build. are target headers available?
       # carefully coerce the build-system compiler to use target headers
       saved_CXXFLAGS="$CXXFLAGS"
-      CROSS_TEST_CXXFLAGS="-nostdinc ${XGCC_FLAGS_FOR_TARGET//-B/-idirafter/}"
+      fixed_XGCC_FLAGS_FOR_TARGET=`echo "$XGCC_FLAGS_FOR_TARGET" | sed 's/-B/-idirafter/g'`
+      CROSS_TEST_CXXFLAGS="-nostdinc $fixed_XGCC_FLAGS_FOR_TARGET"
       CXXFLAGS="$CROSS_TEST_CXXFLAGS"
       cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
diff --git a/gcc/configure.ac b/gcc/configure.ac
index 96a6f62b0d37f..3d31bbdecad34 100644
--- a/gcc/configure.ac
+++ b/gcc/configure.ac
@@ -7481,7 +7481,8 @@ case $target in
       # cross build. are target headers available?
       # carefully coerce the build-system compiler to use target headers
       saved_CXXFLAGS="$CXXFLAGS"
-      CROSS_TEST_CXXFLAGS="-nostdinc ${XGCC_FLAGS_FOR_TARGET//-B/-idirafter/}"
+      fixed_XGCC_FLAGS_FOR_TARGET=`echo "$XGCC_FLAGS_FOR_TARGET" | sed 's/-B/-idirafter/g'`
+      CROSS_TEST_CXXFLAGS="-nostdinc $fixed_XGCC_FLAGS_FOR_TARGET"
       CXXFLAGS="$CROSS_TEST_CXXFLAGS"
       AC_COMPILE_IFELSE([AC_LANG_SOURCE([[
 #include <math.h>

From c28df7197b4886fde6b4f7f47f2102f886339655 Mon Sep 17 00:00:00 2001
From: Alex Coplan <alex.coplan@arm.com>
Date: Tue, 27 Apr 2021 14:56:15 +0100
Subject: [PATCH 129/164] arm: Fix ICEs with compare-and-swap and
 -march=armv8-m.base [PR99977]

The PR shows two ICEs with __sync_bool_compare_and_swap and
-mcpu=cortex-m23 (equivalently, -march=armv8-m.base): one in LRA and one
later on, after the CAS insn is split.

The LRA ICE occurs because the
@atomic_compare_and_swap<CCSI:arch><SIDI:mode>_1 pattern attempts to tie
two output operands together (operands 0 and 1 in the third
alternative). LRA can't handle this, since it doesn't make sense for an
insn to assign to the same operand twice.

The later (post-splitting) ICE occurs because the expansion of the
cbranchsi4_scratch insn doesn't quite go according to plan. As it
stands, arm_split_compare_and_swap calls gen_cbranchsi4_scratch,
attempting to pass a register (neg_bval) to use as a scratch register.
However, since the RTL template has a match_scratch here,
gen_cbranchsi4_scratch ignores this argument and produces a scratch rtx.
Since this is all happening after RA, this is doomed to fail (and we get
an ICE about the insn not matching its constraints).

It seems that the motivation for the choice of constraints in the
atomic_compare_and_swap pattern comes from an attempt to satisfy the
constraints of the cbranchsi4_scratch insn. This insn requires the
scratch register to be the same as the input register in the case that
we use a larger negative immediate (one that satisfies J, but not L).

Of course, as noted above, LRA refuses to assign two output operands to
the same register, so this was never going to work.

The solution I'm proposing here is to collapse the alternatives to the
CAS insn (allowing the two output register operands to be matched to
different registers) and to ensure that the constraints for
cbranchsi4_scratch are met in arm_split_compare_and_swap. We do this by
inserting a move to ensure the source and destination registers match if
necessary (i.e. in the case of large negative immediates).

Another notable change here is that we only do:

  emit_move_insn (neg_bval, const1_rtx);

for non-negative immediates. This is because the ADDS instruction used in
the negative case suffices to leave a suitable value in neg_bval: if the
operands compare equal, we don't take the branch (so neg_bval will be
set by the load exclusive). Otherwise, the ADDS will leave a nonzero
value in neg_bval, which will correctly signal that the CAS has failed
when it is later negated.

gcc/ChangeLog:

	PR target/99977
	* config/arm/arm.c (arm_split_compare_and_swap): Fix up codegen
	with negative immediates: ensure we expand cbranchsi4_scratch
	correctly and ensure we satisfy its constraints.
	* config/arm/sync.md
	(@atomic_compare_and_swap<CCSI:arch><NARROW:mode>_1): Don't
	attempt to tie two output operands together with constraints;
	collapse two alternatives.
	(@atomic_compare_and_swap<CCSI:arch><SIDI:mode>_1): Likewise.
	* config/arm/thumb1.md (cbranchsi4_neg_late): New.

gcc/testsuite/ChangeLog:

	PR target/99977
	* gcc.target/arm/pr99977.c: New test.

(cherry picked from commit 42a10bb884c0d5af2583b8bfe4d239ce95bf9e43)
---
 gcc/config/arm/arm.c                   | 26 ++++++++++++++++++++----
 gcc/config/arm/sync.md                 | 28 +++++++++++++-------------
 gcc/config/arm/thumb1.md               | 15 ++++++++++++++
 gcc/testsuite/gcc.target/arm/pr99977.c |  6 ++++++
 4 files changed, 57 insertions(+), 18 deletions(-)
 create mode 100644 gcc/testsuite/gcc.target/arm/pr99977.c

diff --git a/gcc/config/arm/arm.c b/gcc/config/arm/arm.c
index a488f56d91381..28cbb26332466 100644
--- a/gcc/config/arm/arm.c
+++ b/gcc/config/arm/arm.c
@@ -30764,13 +30764,31 @@ arm_split_compare_and_swap (rtx operands[])
     }
   else
     {
-      emit_move_insn (neg_bval, const1_rtx);
       cond = gen_rtx_NE (VOIDmode, rval, oldval);
       if (thumb1_cmpneg_operand (oldval, SImode))
-	emit_unlikely_jump (gen_cbranchsi4_scratch (neg_bval, rval, oldval,
-						    label2, cond));
+	{
+	  rtx src = rval;
+	  if (!satisfies_constraint_L (oldval))
+	    {
+	      gcc_assert (satisfies_constraint_J (oldval));
+
+	      /* For such immediates, ADDS needs the source and destination regs
+		 to be the same.
+
+		 Normally this would be handled by RA, but this is all happening
+		 after RA.  */
+	      emit_move_insn (neg_bval, rval);
+	      src = neg_bval;
+	    }
+
+	  emit_unlikely_jump (gen_cbranchsi4_neg_late (neg_bval, src, oldval,
+						       label2, cond));
+	}
       else
-	emit_unlikely_jump (gen_cbranchsi4_insn (cond, rval, oldval, label2));
+	{
+	  emit_move_insn (neg_bval, const1_rtx);
+	  emit_unlikely_jump (gen_cbranchsi4_insn (cond, rval, oldval, label2));
+	}
     }
 
   arm_emit_store_exclusive (mode, neg_bval, mem, newval, use_release);
diff --git a/gcc/config/arm/sync.md b/gcc/config/arm/sync.md
index e4682c039b94f..b9fa870260652 100644
--- a/gcc/config/arm/sync.md
+++ b/gcc/config/arm/sync.md
@@ -187,20 +187,20 @@
 ;; Constraints of this pattern must be at least as strict as those of the
 ;; cbranchsi operations in thumb1.md and aim to be as permissive.
 (define_insn_and_split "@atomic_compare_and_swap<CCSI:arch><NARROW:mode>_1"
-  [(set (match_operand:CCSI 0 "cc_register_operand" "=&c,&l,&l,&l")	;; bool out
+  [(set (match_operand:CCSI 0 "cc_register_operand" "=&c,&l,&l")	;; bool out
 	(unspec_volatile:CCSI [(const_int 0)] VUNSPEC_ATOMIC_CAS))
-   (set (match_operand:SI 1 "s_register_operand" "=&r,&l,&0,&l*h")	;; val out
+   (set (match_operand:SI 1 "s_register_operand" "=&r,&l,&l*h")	;; val out
 	(zero_extend:SI
-	  (match_operand:NARROW 2 "mem_noofs_operand" "+Ua,Ua,Ua,Ua")))	;; memory
+	  (match_operand:NARROW 2 "mem_noofs_operand" "+Ua,Ua,Ua")))	;; memory
    (set (match_dup 2)
 	(unspec_volatile:NARROW
-	  [(match_operand:SI 3 "arm_add_operand" "rIL,lIL*h,J,*r")	;; expected
-	   (match_operand:NARROW 4 "s_register_operand" "r,r,r,r")	;; desired
+	  [(match_operand:SI 3 "arm_add_operand" "rIL,lILJ*h,*r")	;; expected
+	   (match_operand:NARROW 4 "s_register_operand" "r,r,r")	;; desired
 	   (match_operand:SI 5 "const_int_operand")		;; is_weak
 	   (match_operand:SI 6 "const_int_operand")		;; mod_s
 	   (match_operand:SI 7 "const_int_operand")]		;; mod_f
 	  VUNSPEC_ATOMIC_CAS))
-   (clobber (match_scratch:SI 8 "=&r,X,X,X"))]
+   (clobber (match_scratch:SI 8 "=&r,X,X"))]
   "<NARROW:sync_predtab>"
   "#"
   "&& reload_completed"
@@ -209,7 +209,7 @@
     arm_split_compare_and_swap (operands);
     DONE;
   }
-  [(set_attr "arch" "32,v8mb,v8mb,v8mb")])
+  [(set_attr "arch" "32,v8mb,v8mb")])
 
 (define_mode_attr cas_cmp_operand
   [(SI "arm_add_operand") (DI "cmpdi_operand")])
@@ -219,19 +219,19 @@
 ;; Constraints of this pattern must be at least as strict as those of the
 ;; cbranchsi operations in thumb1.md and aim to be as permissive.
 (define_insn_and_split "@atomic_compare_and_swap<CCSI:arch><SIDI:mode>_1"
-  [(set (match_operand:CCSI 0 "cc_register_operand" "=&c,&l,&l,&l")	;; bool out
+  [(set (match_operand:CCSI 0 "cc_register_operand" "=&c,&l,&l")	;; bool out
 	(unspec_volatile:CCSI [(const_int 0)] VUNSPEC_ATOMIC_CAS))
-   (set (match_operand:SIDI 1 "s_register_operand" "=&r,&l,&0,&l*h")	;; val out
-	(match_operand:SIDI 2 "mem_noofs_operand" "+Ua,Ua,Ua,Ua"))	;; memory
+   (set (match_operand:SIDI 1 "s_register_operand" "=&r,&l,&l*h")	;; val out
+	(match_operand:SIDI 2 "mem_noofs_operand" "+Ua,Ua,Ua"))	;; memory
    (set (match_dup 2)
 	(unspec_volatile:SIDI
-	  [(match_operand:SIDI 3 "<SIDI:cas_cmp_operand>" "<SIDI:cas_cmp_str>,lIL*h,J,*r") ;; expect
-	   (match_operand:SIDI 4 "s_register_operand" "r,r,r,r")	;; desired
+	  [(match_operand:SIDI 3 "<SIDI:cas_cmp_operand>" "<SIDI:cas_cmp_str>,lILJ*h,*r") ;; expect
+	   (match_operand:SIDI 4 "s_register_operand" "r,r,r")	;; desired
 	   (match_operand:SI 5 "const_int_operand")		;; is_weak
 	   (match_operand:SI 6 "const_int_operand")		;; mod_s
 	   (match_operand:SI 7 "const_int_operand")]		;; mod_f
 	  VUNSPEC_ATOMIC_CAS))
-   (clobber (match_scratch:SI 8 "=&r,X,X,X"))]
+   (clobber (match_scratch:SI 8 "=&r,X,X"))]
   "<SIDI:sync_predtab>"
   "#"
   "&& reload_completed"
@@ -240,7 +240,7 @@
     arm_split_compare_and_swap (operands);
     DONE;
   }
-  [(set_attr "arch" "32,v8mb,v8mb,v8mb")])
+  [(set_attr "arch" "32,v8mb,v8mb")])
 
 (define_insn_and_split "atomic_exchange<mode>"
   [(set (match_operand:QHSD 0 "s_register_operand" "=&r,&r")	;; output
diff --git a/gcc/config/arm/thumb1.md b/gcc/config/arm/thumb1.md
index c98b59c4fa7f8..084ed6597e0e2 100644
--- a/gcc/config/arm/thumb1.md
+++ b/gcc/config/arm/thumb1.md
@@ -1206,6 +1206,21 @@
    (set_attr "type" "multiple")]
 )
 
+;; An expander which makes use of the cbranchsi4_scratch insn, but can
+;; be used safely after RA.
+(define_expand "cbranchsi4_neg_late"
+  [(parallel [
+     (set (pc) (if_then_else
+		(match_operator 4 "arm_comparison_operator"
+		 [(match_operand:SI 1 "s_register_operand")
+		  (match_operand:SI 2 "thumb1_cmpneg_operand")])
+		(label_ref (match_operand 3 "" ""))
+		(pc)))
+     (clobber (match_operand:SI 0 "s_register_operand"))
+  ])]
+  "TARGET_THUMB1"
+)
+
 ;; Changes to the constraints of this pattern must be propagated to those of
 ;; atomic compare_and_swap splitters in sync.md.  These must be at least as
 ;; strict as the constraints here and aim to be as permissive.
diff --git a/gcc/testsuite/gcc.target/arm/pr99977.c b/gcc/testsuite/gcc.target/arm/pr99977.c
new file mode 100644
index 0000000000000..7911899d92846
--- /dev/null
+++ b/gcc/testsuite/gcc.target/arm/pr99977.c
@@ -0,0 +1,6 @@
+/* { dg-do compile } */
+/* { dg-options "-march=armv8-m.base -mfloat-abi=soft -O2" } */
+_Bool f1(int *p) { return __sync_bool_compare_and_swap (p, -1, 2); }
+_Bool f2(int *p) { return __sync_bool_compare_and_swap (p, -8, 2); }
+int g1(int *p) { return __sync_val_compare_and_swap (p, -1, 2); }
+int g2(int *p) { return __sync_val_compare_and_swap (p, -8, 3); }

From 2b5718610016b4c12cadc6f67be94b6020e68b8f Mon Sep 17 00:00:00 2001
From: Thomas Rodgers <rodgert@twrodgers.com>
Date: Mon, 17 May 2021 11:41:26 -0700
Subject: [PATCH 130/164] libstdc++: Fix wrong thread waking on notify
 [PR100334]

Fixes https://gcc.gnu.org/bugzilla/show_bug.cgi?id=100334

libstdc++-v3/ChangeLog:
	* include/bits/atomic_wait.h (__waiter::_M_do_wait_v): loop
	until value change observed.
	(__waiter_base::_M_laundered): New member.
	(__waiter_base::_M_notify): Check _M_laundered to determine
	whether to wake one or all.
	(__detail::__atomic_compare): Return true if call to
	__builtin_memcmp() == 0.
	(__waiter_base::_S_do_spin_v): Adjust predicate.
	* testsuite/29_atomics/atomic/wait_notify/100334.cc: New
	test.

(cherry picked from commit 346cbaf57828aef190de93271c0eb3f10c9aca61)
---
 libstdc++-v3/include/bits/atomic_wait.h       | 28 ++++--
 .../29_atomics/atomic/wait_notify/100334.cc   | 93 +++++++++++++++++++
 2 files changed, 113 insertions(+), 8 deletions(-)
 create mode 100644 libstdc++-v3/testsuite/29_atomics/atomic/wait_notify/100334.cc

diff --git a/libstdc++-v3/include/bits/atomic_wait.h b/libstdc++-v3/include/bits/atomic_wait.h
index 984ed70f16c98..07bb744d822b1 100644
--- a/libstdc++-v3/include/bits/atomic_wait.h
+++ b/libstdc++-v3/include/bits/atomic_wait.h
@@ -181,11 +181,12 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 	return false;
       }
 
+    // return true if equal
     template<typename _Tp>
       bool __atomic_compare(const _Tp& __a, const _Tp& __b)
       {
 	// TODO make this do the correct padding bit ignoring comparison
-	return __builtin_memcmp(&__a, &__b, sizeof(_Tp)) != 0;
+	return __builtin_memcmp(&__a, &__b, sizeof(_Tp)) == 0;
       }
 
     struct __waiter_pool_base
@@ -300,14 +301,20 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 	  explicit __waiter_base(const _Up* __addr) noexcept
 	    : _M_w(_S_for(__addr))
 	    , _M_addr(_S_wait_addr(__addr, &_M_w._M_ver))
-	  {
-	  }
+	  { }
+
+	bool
+	_M_laundered() const
+	{ return _M_addr == &_M_w._M_ver; }
 
 	void
 	_M_notify(bool __all, bool __bare = false)
 	{
-	  if (_M_addr == &_M_w._M_ver)
-	    __atomic_fetch_add(_M_addr, 1, __ATOMIC_ACQ_REL);
+	  if (_M_laundered())
+	    {
+	      __atomic_fetch_add(_M_addr, 1, __ATOMIC_ACQ_REL);
+	      __all = true;
+	    }
 	  _M_w._M_notify(_M_addr, __all, __bare);
 	}
 
@@ -320,7 +327,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 		       _Spin __spin = _Spin{ })
 	  {
 	    auto const __pred = [=]
-	      { return __detail::__atomic_compare(__old, __vfn()); };
+	      { return !__detail::__atomic_compare(__old, __vfn()); };
 
 	    if constexpr (__platform_wait_uses_type<_Up>)
 	      {
@@ -387,7 +394,12 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 	    __platform_wait_t __val;
 	    if (__base_type::_M_do_spin_v(__old, __vfn, __val))
 	      return;
-	    __base_type::_M_w._M_do_wait(__base_type::_M_addr, __val);
+
+	    do
+	      {
+		__base_type::_M_w._M_do_wait(__base_type::_M_addr, __val);
+	      }
+	    while (__detail::__atomic_compare(__old, __vfn()));
 	  }
 
 	template<typename _Pred>
@@ -452,7 +464,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     __atomic_notify_address(const _Tp* __addr, bool __all) noexcept
     {
       __detail::__bare_wait __w(__addr);
-      __w._M_notify(__all, true);
+      __w._M_notify(__all);
     }
 
   // This call is to be used by atomic types which track contention externally
diff --git a/libstdc++-v3/testsuite/29_atomics/atomic/wait_notify/100334.cc b/libstdc++-v3/testsuite/29_atomics/atomic/wait_notify/100334.cc
new file mode 100644
index 0000000000000..fceb709e06e2b
--- /dev/null
+++ b/libstdc++-v3/testsuite/29_atomics/atomic/wait_notify/100334.cc
@@ -0,0 +1,93 @@
+// { dg-options "-std=gnu++2a" }
+// { dg-do run { target c++2a } }
+// { dg-require-gthreads "" }
+// { dg-additional-options "-pthread" { target pthread } }
+// { dg-add-options libatomic }
+
+// Copyright (C) 2021 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+#include <atomic>
+#include <future>
+
+#include <testsuite_hooks.h>
+
+template <typename T>
+struct atomics_sharing_same_waiter
+{
+   std::atomic<T> tmp[49 * 4] = {};
+   std::atomic<T>* a[4] = {
+      { &tmp[0] },
+      { &tmp[16 * 4] },
+      { &tmp[32 * 4] },
+      { &tmp[48 * 4] }
+   };
+};
+
+constexpr unsigned key(void * a)
+{
+  constexpr uintptr_t ct = 16;
+  return (uintptr_t(a) >> 2) % ct;
+}
+
+int
+main()
+{
+  // all atomic share the same waiter
+//  atomics_sharing_same_waiter<char> atomics;
+  atomics_sharing_same_waiter<char> atomics;
+  for (auto& atom : atomics.a)
+  {
+    atom->store(0);
+  }
+
+  auto a = &std::__detail::__waiter_pool_base::_S_for(reinterpret_cast<char *>(atomics.a[0]));
+  auto b = &std::__detail::__waiter_pool_base::_S_for(reinterpret_cast<char *>(atomics.a[1]));
+  VERIFY( a == b );
+
+  auto fut0 = std::async(std::launch::async, [&] { atomics.a[0]->wait(0); });
+  auto fut1 = std::async(std::launch::async, [&] { atomics.a[1]->wait(0); });
+  auto fut2 = std::async(std::launch::async, [&] { atomics.a[2]->wait(0); });
+  auto fut3 = std::async(std::launch::async, [&] { atomics.a[3]->wait(0); });
+
+  // make sure the all threads already await
+  std::this_thread::sleep_for(std::chrono::milliseconds{100});
+
+  atomics.a[2]->store(1);
+  atomics.a[2]->notify_one();
+
+  VERIFY(std::future_status::timeout == fut0.wait_for(std::chrono::milliseconds{100}));
+  VERIFY(atomics.a[0]->load() == 0);
+
+  VERIFY(std::future_status::timeout == fut1.wait_for(std::chrono::milliseconds{100}));
+  VERIFY(atomics.a[1]->load() == 0);
+
+  VERIFY(std::future_status::ready == fut2.wait_for(std::chrono::milliseconds{100}));
+  VERIFY(atomics.a[2]->load() == 1);
+
+  VERIFY(std::future_status::timeout == fut3.wait_for(std::chrono::milliseconds{100}));
+  VERIFY(atomics.a[3]->load() == 0);
+
+  atomics.a[0]->store(1);
+  atomics.a[0]->notify_one();
+  atomics.a[1]->store(1);
+  atomics.a[1]->notify_one();
+  atomics.a[3]->store(1);
+  atomics.a[3]->notify_one();
+
+  return 0;
+}

From f8d2cef5c544dd0196ec5a6f479fbf96d2214d76 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Mon, 17 May 2021 11:54:06 +0100
Subject: [PATCH 131/164] libstdc++: Fix filesystem::path constraints for
 volatile [PR 100630]

The constraint check for filesystem::path construction uses
decltype(__is_path_src(declval<Source>())) which mean it considers
conversion from an rvalue.  When Source is a volatile-qualified type
it cannot use is_path_src(const Unknown&) because a const lvalue
reference can only bind to a non-volatile rvalue.

Since the relevant path members all have a const Source& parameter,
the constraint should be defined in terms of declval<const Source&>(),
not declval<Source>(). This avoids the problem of volatile-qualified
rvalues, because we no longer use an rvalue at all.

libstdc++-v3/ChangeLog:

	PR libstdc++/100630
	* include/experimental/bits/fs_path.h (__is_constructible_from):
	Test construction from a const lvalue, not an rvalue.
	* testsuite/27_io/filesystem/path/construct/100630.cc: New test.
	* testsuite/experimental/filesystem/path/construct/100630.cc:
	New test.

(cherry picked from commit 45aa7a447652e8541cc381d7ab128544f81ed857)
---
 libstdc++-v3/include/experimental/bits/fs_path.h   |  2 +-
 .../27_io/filesystem/path/construct/100630.cc      | 14 ++++++++++++++
 .../filesystem/path/construct/100630.cc            | 14 ++++++++++++++
 3 files changed, 29 insertions(+), 1 deletion(-)
 create mode 100644 libstdc++-v3/testsuite/27_io/filesystem/path/construct/100630.cc
 create mode 100644 libstdc++-v3/testsuite/experimental/filesystem/path/construct/100630.cc

diff --git a/libstdc++-v3/include/experimental/bits/fs_path.h b/libstdc++-v3/include/experimental/bits/fs_path.h
index 2df2bba3dcd32..1ecf2f3a7bd54 100644
--- a/libstdc++-v3/include/experimental/bits/fs_path.h
+++ b/libstdc++-v3/include/experimental/bits/fs_path.h
@@ -124,7 +124,7 @@ namespace __detail
 
   template<typename _Source>
     struct __constructible_from<_Source, void>
-    : decltype(__is_path_src(std::declval<_Source>(), 0))
+    : decltype(__is_path_src(std::declval<const _Source&>(), 0))
     { };
 
   template<typename _Tp1, typename _Tp2 = void,
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/path/construct/100630.cc b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/100630.cc
new file mode 100644
index 0000000000000..eb8473e600eb0
--- /dev/null
+++ b/libstdc++-v3/testsuite/27_io/filesystem/path/construct/100630.cc
@@ -0,0 +1,14 @@
+// { dg-options "-std=gnu++17" }
+// { dg-do compile { target c++17 } }
+
+#include <filesystem>
+
+void f(bool) { }
+void f(const std::filesystem::path&) { }
+
+void
+test_100630()
+{
+  volatile bool b = true;
+  f(b);
+}
diff --git a/libstdc++-v3/testsuite/experimental/filesystem/path/construct/100630.cc b/libstdc++-v3/testsuite/experimental/filesystem/path/construct/100630.cc
new file mode 100644
index 0000000000000..b2428ff74cf50
--- /dev/null
+++ b/libstdc++-v3/testsuite/experimental/filesystem/path/construct/100630.cc
@@ -0,0 +1,14 @@
+// { dg-do compile { target c++11 } }
+// { dg-require-filesystem-ts "" }
+
+#include <experimental/filesystem>
+
+void f(bool) { }
+void f(const std::experimental::filesystem::path&) { }
+
+void
+test_100630()
+{
+  volatile bool b = true;
+  f(b);
+}

From 7d91dd2efb3980a3fffae5188cbdff441193000f Mon Sep 17 00:00:00 2001
From: Kwok Cheung Yeung <kcy@codesourcery.com>
Date: Fri, 14 May 2021 09:59:11 -0700
Subject: [PATCH 132/164] openmp: Notify team barrier of pending tasks in
 omp_fulfill_event

The team barrier should be notified of any new tasks that become runnable
as the result of a completing task, otherwise the barrier threads might
not resume processing available tasks, resulting in a hang.

2021-05-17  Kwok Cheung Yeung  <kcy@codesourcery.com>

	libgomp/
	* task.c (omp_fulfill_event): Call gomp_team_barrier_set_task_pending
	if new tasks generated.
	* testsuite/libgomp.c-c++-common/task-detach-13.c: New.

(cherry picked from commit ba886d0c488ebea2eb2df95c2069a3e207704dac)
---
 libgomp/task.c                                |  1 +
 .../libgomp.c-c++-common/task-detach-13.c     | 59 +++++++++++++++++++
 2 files changed, 60 insertions(+)
 create mode 100644 libgomp/testsuite/libgomp.c-c++-common/task-detach-13.c

diff --git a/libgomp/task.c b/libgomp/task.c
index 1c73c759a8d1a..feb4796a3ac87 100644
--- a/libgomp/task.c
+++ b/libgomp/task.c
@@ -2460,6 +2460,7 @@ omp_fulfill_event (omp_event_handle_t event)
   if (new_tasks > 0)
     {
       /* Wake up threads to run new tasks.  */
+      gomp_team_barrier_set_task_pending (&team->barrier);
       do_wake = team->nthreads - team->task_running_count;
       if (do_wake > new_tasks)
 	do_wake = new_tasks;
diff --git a/libgomp/testsuite/libgomp.c-c++-common/task-detach-13.c b/libgomp/testsuite/libgomp.c-c++-common/task-detach-13.c
new file mode 100644
index 0000000000000..9622fd8251f0c
--- /dev/null
+++ b/libgomp/testsuite/libgomp.c-c++-common/task-detach-13.c
@@ -0,0 +1,59 @@
+/* { dg-do run { target *-*-linux* *-*-gnu* *-*-freebsd* } } */
+/* { dg-timeout 10 } */
+
+/* Test that omp_fulfill_event works when called from an external
+   non-OpenMP thread.  */
+
+#include <omp.h>
+#include <unistd.h>
+#include <pthread.h>
+#include <stdio.h>
+
+int finished = 0;
+int event_pending = 0;
+omp_event_handle_t detach_event;
+
+void *
+fulfill_thread (void *)
+{
+  while (!__atomic_load_n (&finished, __ATOMIC_RELAXED))
+    {
+      if (__atomic_load_n (&event_pending, __ATOMIC_ACQUIRE))
+	{
+	  omp_fulfill_event (detach_event);
+	  __atomic_store_n (&event_pending, 0, __ATOMIC_RELEASE);
+	}
+
+      sleep(1);
+    }
+
+  return 0;
+}
+
+int
+main (void)
+{
+  pthread_t thr;
+  int dep;
+  pthread_create (&thr, NULL, fulfill_thread, 0);
+
+  #pragma omp parallel
+    #pragma omp single
+    {
+      omp_event_handle_t ev;
+
+      #pragma omp task depend (out: dep) detach (ev)
+      {
+	detach_event = ev;
+	__atomic_store_n (&event_pending, 1, __ATOMIC_RELEASE);
+      }
+
+      #pragma omp task depend (in: dep)
+      {
+	__atomic_store_n (&finished, 1, __ATOMIC_RELAXED);
+      }
+    }
+
+  pthread_join (thr, 0);
+  return 0;
+}

From 0d9e251627200e4c2715cb563da01965e6ce9077 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Tue, 18 May 2021 00:18:33 +0000
Subject: [PATCH 133/164] Daily bump.

---
 contrib/ChangeLog       |  9 +++++++++
 gcc/ChangeLog           | 25 +++++++++++++++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/fortran/ChangeLog   |  8 ++++++++
 gcc/testsuite/ChangeLog | 15 +++++++++++++++
 libgomp/ChangeLog       |  9 +++++++++
 libstdc++-v3/ChangeLog  | 28 ++++++++++++++++++++++++++++
 7 files changed, 95 insertions(+), 1 deletion(-)

diff --git a/contrib/ChangeLog b/contrib/ChangeLog
index f2705dd5d6886..8a73b57ccca9f 100644
--- a/contrib/ChangeLog
+++ b/contrib/ChangeLog
@@ -1,3 +1,12 @@
+2021-05-17  Richard Biener  <rguenther@suse.de>
+
+	Backported from master:
+	2021-05-17  Richard Biener  <rguenther@suse.de>
+
+	* download_prerequisites: Update mpfr version to 3.1.6.
+	* prerequisites.md5: Update.
+	* prerequisites.sha512: Likewise.
+
 2021-05-14  Martin Liska  <mliska@suse.cz>
 
 	* gcc-changelog/git_check_commit.py: Sync from master.
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 4f91817afd857..23fcbed1120f7 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,28 @@
+2021-05-17  Alex Coplan  <alex.coplan@arm.com>
+
+	Backported from master:
+	2021-04-27  Alex Coplan  <alex.coplan@arm.com>
+
+	PR target/99977
+	* config/arm/arm.c (arm_split_compare_and_swap): Fix up codegen
+	with negative immediates: ensure we expand cbranchsi4_scratch
+	correctly and ensure we satisfy its constraints.
+	* config/arm/sync.md
+	(@atomic_compare_and_swap<CCSI:arch><NARROW:mode>_1): Don't
+	attempt to tie two output operands together with constraints;
+	collapse two alternatives.
+	(@atomic_compare_and_swap<CCSI:arch><SIDI:mode>_1): Likewise.
+	* config/arm/thumb1.md (cbranchsi4_neg_late): New.
+
+2021-05-17  Marius Hillenbrand  <mhillen@linux.ibm.com>
+
+	Backported from master:
+	2021-05-17  Marius Hillenbrand  <mhillen@linux.ibm.com>
+
+	PR bootstrap/100552
+	* configure.ac: Replace pattern substitution with call to sed.
+	* configure: Regenerate.
+
 2021-05-13  Tobias Burnus  <tobias@codesourcery.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 915a0b235e74b..7fa5a770779d4 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210517
+20210518
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index b072f2b4eb921..d4499fb1f1b05 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,11 @@
+2021-05-17  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-05-14  Tobias Burnus  <tobias@codesourcery.com>
+
+	* resolve.c (resolve_symbol): Handle implicit SAVE of main-program
+	for vars in 'omp threadprivate' and 'omp declare target'.
+
 2021-05-05  Harald Anlauf  <anlauf@gmx.de>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index e4fd12da0588c..7caed40d045ad 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,18 @@
+2021-05-17  Alex Coplan  <alex.coplan@arm.com>
+
+	Backported from master:
+	2021-04-27  Alex Coplan  <alex.coplan@arm.com>
+
+	PR target/99977
+	* gcc.target/arm/pr99977.c: New test.
+
+2021-05-17  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-05-14  Tobias Burnus  <tobias@codesourcery.com>
+
+	* gfortran.dg/gomp/implicit-save.f90: New test.
+
 2021-05-14  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
index 7e0fe3d465900..0ce541fa7ebda 100644
--- a/libgomp/ChangeLog
+++ b/libgomp/ChangeLog
@@ -1,3 +1,12 @@
+2021-05-17  Kwok Cheung Yeung  <kcy@codesourcery.com>
+
+	Backported from master:
+	2021-05-17  Kwok Cheung Yeung  <kcy@codesourcery.com>
+
+	* task.c (omp_fulfill_event): Call gomp_team_barrier_set_task_pending
+	if new tasks generated.
+	* testsuite/libgomp.c-c++-common/task-detach-13.c: New.
+
 2021-05-13  Tobias Burnus  <tobias@codesourcery.com>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 055b5f353c55f..e97734abdca8a 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,31 @@
+2021-05-17  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-17  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/100630
+	* include/experimental/bits/fs_path.h (__is_constructible_from):
+	Test construction from a const lvalue, not an rvalue.
+	* testsuite/27_io/filesystem/path/construct/100630.cc: New test.
+	* testsuite/experimental/filesystem/path/construct/100630.cc:
+	New test.
+
+2021-05-17  Thomas Rodgers  <rodgert@twrodgers.com>
+
+	Backported from master:
+	2021-05-17  Thomas Rodgers  <rodgert@twrodgers.com>
+
+	* include/bits/atomic_wait.h (__waiter::_M_do_wait_v): loop
+	until value change observed.
+	(__waiter_base::_M_laundered): New member.
+	(__waiter_base::_M_notify): Check _M_laundered to determine
+	whether to wake one or all.
+	(__detail::__atomic_compare): Return true if call to
+	__builtin_memcmp() == 0.
+	(__waiter_base::_S_do_spin_v): Adjust predicate.
+	* testsuite/29_atomics/atomic/wait_notify/100334.cc: New
+	test.
+
 2021-05-12  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:

From efb6bda7f5136d59be254b10d2b81ba28be8ecfb Mon Sep 17 00:00:00 2001
From: Tobias Burnus <tobias@codesourcery.com>
Date: Mon, 17 May 2021 13:20:27 +0200
Subject: [PATCH 134/164] OpenMP/Fortran: Reject nonintrinsic assignments in
 OMP WORKSHARE [PR100633]

	PR fortran/100633

gcc/fortran/ChangeLog:

	* resolve.c (gfc_resolve_code): Reject nonintrinsic assignments in
	OMP WORKSHARE.

gcc/testsuite/ChangeLog:

	* gfortran.dg/gomp/workshare-59.f90: New test.

(cherry picked from commit 582776eb1b62c32f5234566a01ea92247b7d6bcc)
---
 gcc/fortran/resolve.c                         |  6 +++++
 .../gfortran.dg/gomp/workshare-59.f90         | 26 +++++++++++++++++++
 2 files changed, 32 insertions(+)
 create mode 100644 gcc/testsuite/gfortran.dg/gomp/workshare-59.f90

diff --git a/gcc/fortran/resolve.c b/gcc/fortran/resolve.c
index fac24560c11fb..4ab876a25ab3c 100644
--- a/gcc/fortran/resolve.c
+++ b/gcc/fortran/resolve.c
@@ -11938,6 +11938,12 @@ gfc_resolve_code (gfc_code *code, gfc_namespace *ns)
 
 	  if (resolve_ordinary_assign (code, ns))
 	    {
+	      if (omp_workshare_flag)
+		{
+		  gfc_error ("Expected intrinsic assignment in OMP WORKSHARE "
+			     "at %L", &code->loc);
+		  break;
+		}
 	      if (code->op == EXEC_COMPCALL)
 		goto compcall;
 	      else
diff --git a/gcc/testsuite/gfortran.dg/gomp/workshare-59.f90 b/gcc/testsuite/gfortran.dg/gomp/workshare-59.f90
new file mode 100644
index 0000000000000..65d04c2b55d41
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/gomp/workshare-59.f90
@@ -0,0 +1,26 @@
+! PR fortran/100633
+
+module defined_assign
+  interface assignment(=)
+    module procedure work_assign
+  end interface
+
+  contains
+    subroutine work_assign(a,b)
+      integer, intent(out) :: a
+      logical, intent(in) :: b(:)
+    end subroutine work_assign
+end module defined_assign
+
+program omp_workshare
+  use defined_assign
+
+  integer :: a
+  logical :: l(10)
+  l = .TRUE.
+
+  !$omp workshare
+  a = l   ! { dg-error "Expected intrinsic assignment in OMP WORKSHARE" }
+  !$omp end workshare
+
+end program omp_workshare

From ba165eda006ebca642869f53ce321fc957051a86 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Tue, 18 May 2021 10:08:50 +0100
Subject: [PATCH 135/164] gcc-changelog: Remove use of non-strict mode

contrib/ChangeLog:

	* gcc-changelog/git_email.py: Remove use of non-strict mode.

(cherry picked from commit 7b4bae0acb14a1076df3234e905442bbdf9503dd)
---
 contrib/gcc-changelog/git_email.py | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/contrib/gcc-changelog/git_email.py b/contrib/gcc-changelog/git_email.py
index 6933e3d71fe53..fa62e3ad2f729 100755
--- a/contrib/gcc-changelog/git_email.py
+++ b/contrib/gcc-changelog/git_email.py
@@ -110,7 +110,7 @@ def show_help():
         print()
         print('Successfully parsed: %d/%d' % (success, len(allfiles)))
     else:
-        email = GitEmail(sys.argv[1], False)
+        email = GitEmail(sys.argv[1])
         if email.success:
             print('OK')
             email.print_output()

From b786dafe9eb933f23686c68c6d7110fef5656985 Mon Sep 17 00:00:00 2001
From: Jason Merrill <jason@redhat.com>
Date: Wed, 14 Apr 2021 11:24:50 -0400
Subject: [PATCH 136/164] c++: constant expressions are evaluated [PR93314]

My GCC 11 patch for PR93314 turned off cp_unevaluated_operand while
processing an id-expression that names a non-static data member, but the
broader issue is that in general, a constant-expression is evaluated even in
an unevaluated operand.

This also fixes 100205, introduced by the earlier patch that couldn't
distinguish between the different allow_non_constant_p cases.

	PR c++/100205
	PR c++/93314

gcc/cp/ChangeLog:

	* cp-tree.h (cp_evaluated): Add reset parm to constructor.
	* parser.c (cp_parser_constant_expression): Change
	allow_non_constant_p to int.  Use cp_evaluated.
	(cp_parser_initializer_clause): Pass 2 to allow_non_constant_p.
	* semantics.c (finish_id_expression_1): Don't mess with
	cp_unevaluated_operand here.

gcc/testsuite/ChangeLog:

	* g++.dg/cpp0x/decltype-nonstatic1.C: New test.
---
 gcc/cp/cp-tree.h                                 |  5 +++--
 gcc/cp/parser.c                                  | 15 +++++++++++----
 gcc/cp/semantics.c                               | 10 ----------
 gcc/testsuite/g++.dg/cpp0x/decltype-nonstatic1.C | 16 ++++++++++++++++
 4 files changed, 30 insertions(+), 16 deletions(-)
 create mode 100644 gcc/testsuite/g++.dg/cpp0x/decltype-nonstatic1.C

diff --git a/gcc/cp/cp-tree.h b/gcc/cp/cp-tree.h
index 23a77a2b2e072..fbf33b9150ee0 100644
--- a/gcc/cp/cp-tree.h
+++ b/gcc/cp/cp-tree.h
@@ -5480,9 +5480,10 @@ class cp_evaluated
 public:
   int uneval;
   int inhibit;
-  cp_evaluated ()
+  cp_evaluated (bool reset = true)
     : uneval(cp_unevaluated_operand), inhibit(c_inhibit_evaluation_warnings)
-  { cp_unevaluated_operand = c_inhibit_evaluation_warnings = 0; }
+  { if (reset)
+      cp_unevaluated_operand = c_inhibit_evaluation_warnings = 0; }
   ~cp_evaluated ()
   { cp_unevaluated_operand = uneval;
     c_inhibit_evaluation_warnings = inhibit; }
diff --git a/gcc/cp/parser.c b/gcc/cp/parser.c
index a3dae3164ce14..c1001713ac8a6 100644
--- a/gcc/cp/parser.c
+++ b/gcc/cp/parser.c
@@ -2163,7 +2163,7 @@ static enum tree_code cp_parser_assignment_operator_opt
 static cp_expr cp_parser_expression
   (cp_parser *, cp_id_kind * = NULL, bool = false, bool = false, bool = false);
 static cp_expr cp_parser_constant_expression
-  (cp_parser *, bool = false, bool * = NULL, bool = false);
+  (cp_parser *, int = 0, bool * = NULL, bool = false);
 static cp_expr cp_parser_builtin_offsetof
   (cp_parser *);
 static cp_expr cp_parser_lambda_expression
@@ -10374,13 +10374,15 @@ cp_parser_expression (cp_parser* parser, cp_id_kind * pidk,
   If ALLOW_NON_CONSTANT_P a non-constant expression is silently
   accepted.  If ALLOW_NON_CONSTANT_P is true and the expression is not
   constant, *NON_CONSTANT_P is set to TRUE.  If ALLOW_NON_CONSTANT_P
-  is false, NON_CONSTANT_P should be NULL.  If STRICT_P is true,
+  is false, NON_CONSTANT_P should be NULL.  If ALLOW_NON_CONSTANT_P is
+  greater than 1, this isn't really a constant-expression, only a
+  potentially constant-evaluated expression.  If STRICT_P is true,
   only parse a conditional-expression, otherwise parse an
   assignment-expression.  See below for rationale.  */
 
 static cp_expr
 cp_parser_constant_expression (cp_parser* parser,
-			       bool allow_non_constant_p,
+			       int allow_non_constant_p,
 			       bool *non_constant_p,
 			       bool strict_p)
 {
@@ -10416,6 +10418,11 @@ cp_parser_constant_expression (cp_parser* parser,
   parser->allow_non_integral_constant_expression_p
     = (allow_non_constant_p || cxx_dialect >= cxx11);
   parser->non_integral_constant_expression_p = false;
+
+  /* A manifestly constant-evaluated expression is evaluated even in an
+     unevaluated operand.  */
+  cp_evaluated ev (/*reset if*/allow_non_constant_p <= 1);
+
   /* Although the grammar says "conditional-expression", when not STRICT_P,
      we parse an "assignment-expression", which also permits
      "throw-expression" and the use of assignment operators.  In the case
@@ -24236,7 +24243,7 @@ cp_parser_initializer_clause (cp_parser* parser, bool* non_constant_p)
     {
       initializer
 	= cp_parser_constant_expression (parser,
-					/*allow_non_constant_p=*/true,
+					/*allow_non_constant_p=*/2,
 					non_constant_p);
     }
   else
diff --git a/gcc/cp/semantics.c b/gcc/cp/semantics.c
index 3a6468fd5f3b5..27a50d7089999 100644
--- a/gcc/cp/semantics.c
+++ b/gcc/cp/semantics.c
@@ -4093,12 +4093,6 @@ finish_id_expression_1 (tree id_expression,
 
 	  cp_warn_deprecated_use_scopes (scope);
 
-	  /* In a constant-expression context, turn off cp_unevaluated_operand
-	     so finish_non_static_data_member will complain (93314).  */
-	  auto eval = make_temp_override (cp_unevaluated_operand);
-	  if (integral_constant_expression_p && TREE_CODE (decl) == FIELD_DECL)
-	    cp_unevaluated_operand = 0;
-
 	  if (TYPE_P (scope))
 	    decl = finish_qualified_id_expr (scope,
 					     decl,
@@ -4112,10 +4106,6 @@ finish_id_expression_1 (tree id_expression,
 	}
       else if (TREE_CODE (decl) == FIELD_DECL)
 	{
-	  auto eval = make_temp_override (cp_unevaluated_operand);
-	  if (integral_constant_expression_p)
-	    cp_unevaluated_operand = 0;
-
 	  /* Since SCOPE is NULL here, this is an unqualified name.
 	     Access checking has been performed during name lookup
 	     already.  Turn off checking to avoid duplicate errors.  */
diff --git a/gcc/testsuite/g++.dg/cpp0x/decltype-nonstatic1.C b/gcc/testsuite/g++.dg/cpp0x/decltype-nonstatic1.C
new file mode 100644
index 0000000000000..bc488ff388ba5
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp0x/decltype-nonstatic1.C
@@ -0,0 +1,16 @@
+// PR c++/100205
+// { dg-do compile { target c++11 } }
+
+struct coordinate_matrix {
+  using index_t = unsigned;
+  struct convert_to_matrix_coordinate {
+    index_t column_id;
+  };
+  index_t column_id;
+
+  // does not work
+  using value_type2 = decltype(convert_to_matrix_coordinate{column_id});
+
+  // does work
+  using value_type5 = decltype(column_id);
+};

From 6384e940a6db379b0524465cf6cbbd0996b48485 Mon Sep 17 00:00:00 2001
From: Jason Merrill <jason@redhat.com>
Date: Tue, 18 May 2021 12:06:36 -0400
Subject: [PATCH 137/164] c++: "perfect" implicitly deleted move [PR100644]

Here we were ignoring the template constructor because the implicit move
constructor had all perfect conversions.  But CWG1402 says that an
implicitly deleted move constructor is ignored by overload resolution; we
implement that instead by preferring any other candidate in joust, to get
better diagnostics, but that means we need to handle that case here as well.

gcc/cp/ChangeLog:

	PR c++/100644
	* call.c (perfect_candidate_p): An implicitly deleted move
	is not perfect.

gcc/testsuite/ChangeLog:

	* g++.dg/cpp0x/implicit-delete1.C: New test.
---
 gcc/cp/call.c                                 |  5 +++++
 gcc/testsuite/g++.dg/cpp0x/implicit-delete1.C | 20 +++++++++++++++++++
 2 files changed, 25 insertions(+)
 create mode 100644 gcc/testsuite/g++.dg/cpp0x/implicit-delete1.C

diff --git a/gcc/cp/call.c b/gcc/cp/call.c
index 678e120a165ba..d0d55fcbb0b5a 100644
--- a/gcc/cp/call.c
+++ b/gcc/cp/call.c
@@ -5892,6 +5892,11 @@ perfect_candidate_p (z_candidate *cand)
 {
   if (cand->viable < 1)
     return false;
+  /* CWG1402 makes an implicitly deleted move op worse than other
+     candidates.  */
+  if (DECL_DELETED_FN (cand->fn) && DECL_DEFAULTED_FN (cand->fn)
+      && move_fn_p (cand->fn))
+    return false;
   int len = cand->num_convs;
   for (int i = 0; i < len; ++i)
     if (!perfect_conversion_p (cand->convs[i]))
diff --git a/gcc/testsuite/g++.dg/cpp0x/implicit-delete1.C b/gcc/testsuite/g++.dg/cpp0x/implicit-delete1.C
new file mode 100644
index 0000000000000..6dcced4fb2d52
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp0x/implicit-delete1.C
@@ -0,0 +1,20 @@
+// PR c++/100644
+// { dg-do compile { target c++11 } }
+
+struct NonMovable {
+  NonMovable(NonMovable&&) = delete;
+};
+
+template <class T>
+struct Maybe {
+  NonMovable mMember;
+
+  template <typename U>
+  Maybe(Maybe<U>&&);
+};
+
+void foo(Maybe<int>);
+
+void unlucky(Maybe<int>&& x) {
+  Maybe<int> var{(Maybe<int>&&)x};
+}

From c2aee0b9518a5bd8f94e994bee1c94a7134d5564 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Wed, 19 May 2021 00:18:23 +0000
Subject: [PATCH 138/164] Daily bump.

---
 contrib/ChangeLog       |  7 +++++++
 gcc/DATESTAMP           |  2 +-
 gcc/cp/ChangeLog        | 17 +++++++++++++++++
 gcc/fortran/ChangeLog   |  9 +++++++++
 gcc/testsuite/ChangeLog | 18 ++++++++++++++++++
 5 files changed, 52 insertions(+), 1 deletion(-)

diff --git a/contrib/ChangeLog b/contrib/ChangeLog
index 8a73b57ccca9f..fed75d63f1fb4 100644
--- a/contrib/ChangeLog
+++ b/contrib/ChangeLog
@@ -1,3 +1,10 @@
+2021-05-18  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-18  Jonathan Wakely  <jwakely@redhat.com>
+
+	* gcc-changelog/git_email.py: Remove use of non-strict mode.
+
 2021-05-17  Richard Biener  <rguenther@suse.de>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 7fa5a770779d4..da5d88b61f70b 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210518
+20210519
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 7b1a09e529f6f..0398d5385c2af 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,20 @@
+2021-05-18  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100644
+	* call.c (perfect_candidate_p): An implicitly deleted move
+	is not perfect.
+
+2021-05-18  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100205
+	PR c++/93314
+	* cp-tree.h (cp_evaluated): Add reset parm to constructor.
+	* parser.c (cp_parser_constant_expression): Change
+	allow_non_constant_p to int.  Use cp_evaluated.
+	(cp_parser_initializer_clause): Pass 2 to allow_non_constant_p.
+	* semantics.c (finish_id_expression_1): Don't mess with
+	cp_unevaluated_operand here.
+
 2021-05-03  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index d4499fb1f1b05..f868b797a002f 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,12 @@
+2021-05-18  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-05-17  Tobias Burnus  <tobias@codesourcery.com>
+
+	PR fortran/100633
+	* resolve.c (gfc_resolve_code): Reject nonintrinsic assignments in
+	OMP WORKSHARE.
+
 2021-05-17  Tobias Burnus  <tobias@codesourcery.com>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 7caed40d045ad..db7ba9e2638b2 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,21 @@
+2021-05-18  Jason Merrill  <jason@redhat.com>
+
+	* g++.dg/cpp0x/implicit-delete1.C: New test.
+
+2021-05-18  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100205
+	PR c++/93314
+	* g++.dg/cpp0x/decltype-nonstatic1.C: New test.
+
+2021-05-18  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-05-17  Tobias Burnus  <tobias@codesourcery.com>
+
+	PR fortran/100633
+	* gfortran.dg/gomp/workshare-59.f90: New test.
+
 2021-05-17  Alex Coplan  <alex.coplan@arm.com>
 
 	Backported from master:

From 74ad5558d2acddcf4f5e96129ec29dd2f3d47d3a Mon Sep 17 00:00:00 2001
From: Jason Merrill <jason@redhat.com>
Date: Tue, 18 May 2021 17:12:37 -0400
Subject: [PATCH 139/164] c++: template template parm pack expansion [PR100372]

Here we have a pack expansion of a template template parameter pack, of
which the pattern is a TEMPLATE_DECL, which strip_typedefs doesn't want to
see.

	PR c++/100372

gcc/cp/ChangeLog:

	* tree.c (strip_typedefs): Only look at the pattern of a
	TYPE_PACK_EXPANSION if it's a type.

gcc/testsuite/ChangeLog:

	* g++.dg/cpp0x/alias-decl-ttp1.C: New test.
---
 gcc/cp/tree.c                                | 19 ++++++++++++-------
 gcc/testsuite/g++.dg/cpp0x/alias-decl-ttp1.C |  6 ++++++
 2 files changed, 18 insertions(+), 7 deletions(-)
 create mode 100644 gcc/testsuite/g++.dg/cpp0x/alias-decl-ttp1.C

diff --git a/gcc/cp/tree.c b/gcc/cp/tree.c
index a8bfd5fc05319..ced7cb5e97740 100644
--- a/gcc/cp/tree.c
+++ b/gcc/cp/tree.c
@@ -1723,13 +1723,18 @@ strip_typedefs (tree t, bool *remove_attributes, unsigned int flags)
       result = finish_underlying_type (type);
       break;
     case TYPE_PACK_EXPANSION:
-      type = strip_typedefs (PACK_EXPANSION_PATTERN (t),
-			     remove_attributes, flags);
-      if (type != PACK_EXPANSION_PATTERN (t))
-	{
-	  result = copy_node (t);
-	  PACK_EXPANSION_PATTERN (result) = type;
-	}
+      {
+	tree pat = PACK_EXPANSION_PATTERN (t);
+	if (TYPE_P (pat))
+	  {
+	    type = strip_typedefs (pat, remove_attributes, flags);
+	    if (type != pat)
+	      {
+		result = copy_node (t);
+		PACK_EXPANSION_PATTERN (result) = type;
+	      }
+	  }
+      }
       break;
     default:
       break;
diff --git a/gcc/testsuite/g++.dg/cpp0x/alias-decl-ttp1.C b/gcc/testsuite/g++.dg/cpp0x/alias-decl-ttp1.C
new file mode 100644
index 0000000000000..d1af8d1bbb200
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp0x/alias-decl-ttp1.C
@@ -0,0 +1,6 @@
+// PR c++/100372
+// { dg-do compile { target c++14 } }
+
+template <bool> using enable_if_t = int;
+template <class> bool has_P_match_v;
+template <template <class> class... List> enable_if_t<has_P_match_v<List...>> a;

From fff482625ab184210d9121515b9ea98945dc0b6f Mon Sep 17 00:00:00 2001
From: Jason Merrill <jason@redhat.com>
Date: Tue, 18 May 2021 17:15:42 -0400
Subject: [PATCH 140/164] c++: ICE with bad definition of decimal32 [PR100261]

The change to only look at the global binding for non-classes meant that
here, when dealing with decimal32 which is magically mangled like its first
non-static data member, we got a collision with the mangling for float.
Fixed by also looking up an existing binding for such magical classes.

	PR c++/100261

gcc/cp/ChangeLog:

	* rtti.c (get_tinfo_decl_direct): Check TYPE_TRANSPARENT_AGGR.

gcc/testsuite/ChangeLog:

	* g++.dg/dfp/mangle-6.C: New test.
---
 gcc/cp/rtti.c                       |  2 +-
 gcc/testsuite/g++.dg/dfp/mangle-6.C | 19 +++++++++++++++++++
 2 files changed, 20 insertions(+), 1 deletion(-)
 create mode 100644 gcc/testsuite/g++.dg/dfp/mangle-6.C

diff --git a/gcc/cp/rtti.c b/gcc/cp/rtti.c
index 5a33b83afd0c8..82eaa286514da 100644
--- a/gcc/cp/rtti.c
+++ b/gcc/cp/rtti.c
@@ -433,7 +433,7 @@ get_tinfo_decl_direct (tree type, tree name, int pseudo_ix)
   if (!name)
     name = mangle_typeinfo_for_type (type);
 
-  if (!CLASS_TYPE_P (type))
+  if (!CLASS_TYPE_P (type) || TYPE_TRANSPARENT_AGGR (type))
     d = get_global_binding (name);
 
   if (!d)
diff --git a/gcc/testsuite/g++.dg/dfp/mangle-6.C b/gcc/testsuite/g++.dg/dfp/mangle-6.C
new file mode 100644
index 0000000000000..9cfb2a974bb49
--- /dev/null
+++ b/gcc/testsuite/g++.dg/dfp/mangle-6.C
@@ -0,0 +1,19 @@
+// PR c++/100261
+// { dg-do compile }
+
+#include <typeinfo>
+
+namespace std {
+  namespace decimal {
+    class decimal32 {
+      float private__decfloat32;
+    };
+  }
+}
+
+void
+foo ()
+{
+  typeid (float);
+  typeid (std::decimal::decimal32);
+}

From c412100235ba34ae9c133fb7a77cc52c2e93fc87 Mon Sep 17 00:00:00 2001
From: Christophe Lyon <christophe.lyon@linaro.org>
Date: Wed, 19 May 2021 14:45:54 +0000
Subject: [PATCH 141/164] arm/testsuite: Fix testcase for PR99977

Some targets (eg arm-none-uclinuxfdpiceabi) do not support Thumb-1,
and since the testcase forces -march=armv8-m.base, we need to check
whether this option is actually supported.

Using dg-add-options arm_arch_v8m_base ensure that we pass -mthumb as
needed too.

2021-05-19  Christophe Lyon  <christophe.lyon@linaro.org>

	PR target/99977
	gcc/testsuite/
	* gcc.target/arm/pr99977.c: Require arm_arch_v8m_base.
---
 gcc/testsuite/gcc.target/arm/pr99977.c | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/gcc/testsuite/gcc.target/arm/pr99977.c b/gcc/testsuite/gcc.target/arm/pr99977.c
index 7911899d92846..db330e4a4a3b1 100644
--- a/gcc/testsuite/gcc.target/arm/pr99977.c
+++ b/gcc/testsuite/gcc.target/arm/pr99977.c
@@ -1,5 +1,7 @@
 /* { dg-do compile } */
-/* { dg-options "-march=armv8-m.base -mfloat-abi=soft -O2" } */
+/* { dg-require-effective-target arm_arch_v8m_base_ok } */
+/* { dg-options "-O2" } */
+/* { dg-add-options arm_arch_v8m_base } */
 _Bool f1(int *p) { return __sync_bool_compare_and_swap (p, -1, 2); }
 _Bool f2(int *p) { return __sync_bool_compare_and_swap (p, -8, 2); }
 int g1(int *p) { return __sync_val_compare_and_swap (p, -1, 2); }

From b02eef7b28890f58efb922615811901cbc755c50 Mon Sep 17 00:00:00 2001
From: Jonathan Wakely <jwakely@redhat.com>
Date: Wed, 19 May 2021 11:11:11 +0100
Subject: [PATCH 142/164] doc: Update description of __GXX_EXPERIMENTAL_CXX0X__

This macro has been obsolete for years, and C++0x features are no longer
experimental or liable to be removed.

gcc/ChangeLog:

	* doc/cpp.texi (Common Predefined Macros): Update documentation
	for the __GXX_EXPERIMENTAL_CXX0X__ macro.

(cherry picked from commit 9b50282b0dcf79d3141979e466465a23d1816166)
---
 gcc/doc/cpp.texi | 12 +++++++-----
 1 file changed, 7 insertions(+), 5 deletions(-)

diff --git a/gcc/doc/cpp.texi b/gcc/doc/cpp.texi
index 2c109bbc5bd50..4b065b651b0fe 100644
--- a/gcc/doc/cpp.texi
+++ b/gcc/doc/cpp.texi
@@ -2312,11 +2312,13 @@ mechanism based on @code{setjmp} and @code{longjmp} for exception
 handling.
 
 @item __GXX_EXPERIMENTAL_CXX0X__
-This macro is defined when compiling a C++ source file with the option
-@option{-std=c++0x} or @option{-std=gnu++0x}. It indicates that some
-features likely to be included in C++0x are available. Note that these
-features are experimental, and may change or be removed in future
-versions of GCC.
+This macro is defined when compiling a C++ source file with C++11 features
+enabled, i.e., for all C++ language dialects except @option{-std=c++98}
+and @option{-std=gnu++98}. This macro is obsolete, but can be used to
+detect experimental C++0x features in very old versions of GCC. Since
+GCC 4.7.0 the @code{__cplusplus} macro is defined correctly, so most
+code should test @code{__cplusplus >= 201103L} instead of using this
+macro.
 
 @item __GXX_WEAK__
 This macro is defined when compiling a C++ source file.  It has the

From 3bdd3e45955ef94a1f2db51a2af1ded54d41f670 Mon Sep 17 00:00:00 2001
From: Jason Merrill <jason@redhat.com>
Date: Tue, 18 May 2021 12:29:33 -0400
Subject: [PATCH 143/164] c++: ICE with <=> fallback [PR100367]

Here, when genericizing lexicographical_compare_three_way, we haven't yet
walked the operands, so (a == a) still sees ADDR_EXPR <a>, but this is after
we've changed the type of a to REFERENCE_TYPE.  When we try to fold (a == a)
by constexpr evaluation, the constexpr code doesn't understand trying to
take the address of a reference, and we end up crashing.

Fixed by avoiding constexpr evaluation in genericize_spaceship, by using
fold_build2 instead of build_new_op on scalar operands.  Class operands
should have been expanded during parsing.

	PR c++/100367
	PR c++/96299

gcc/cp/ChangeLog:

	* method.c (genericize_spaceship): Use fold_build2 for scalar
	operands.

gcc/testsuite/ChangeLog:

	* g++.dg/cpp2a/spaceship-fallback1.C: New test.
---
 gcc/cp/method.c                               | 42 +++++++++++++++----
 .../g++.dg/cpp2a/spaceship-fallback1.C        | 17 ++++++++
 2 files changed, 52 insertions(+), 7 deletions(-)
 create mode 100644 gcc/testsuite/g++.dg/cpp2a/spaceship-fallback1.C

diff --git a/gcc/cp/method.c b/gcc/cp/method.c
index 0f416bec35b5e..1c3cf834bf497 100644
--- a/gcc/cp/method.c
+++ b/gcc/cp/method.c
@@ -1087,7 +1087,8 @@ genericize_spaceship (location_t loc, tree type, tree op0, tree op1)
   gcc_checking_assert (tag < cc_last);
 
   tree r;
-  if (SCALAR_TYPE_P (TREE_TYPE (op0)))
+  bool scalar = SCALAR_TYPE_P (TREE_TYPE (op0));
+  if (scalar)
     {
       op0 = save_expr (op0);
       op1 = save_expr (op1);
@@ -1097,26 +1098,53 @@ genericize_spaceship (location_t loc, tree type, tree op0, tree op1)
 
   int flags = LOOKUP_NORMAL;
   tsubst_flags_t complain = tf_none;
+  tree comp;
 
   if (tag == cc_partial_ordering)
     {
       /* op0 == op1 ? equivalent : op0 < op1 ? less :
 	 op1 < op0 ? greater : unordered */
       tree uo = lookup_comparison_result (tag, type, 3);
-      tree comp = build_new_op (loc, LT_EXPR, flags, op1, op0, complain);
-      r = build_conditional_expr (loc, comp, gt, uo, complain);
+      if (scalar)
+	{
+	  /* For scalars use the low level operations; using build_new_op causes
+	     trouble with constexpr eval in the middle of genericize (100367).  */
+	  comp = fold_build2 (LT_EXPR, boolean_type_node, op1, op0);
+	  r = fold_build3 (COND_EXPR, type, comp, gt, uo);
+	}
+      else
+	{
+	  comp = build_new_op (loc, LT_EXPR, flags, op1, op0, complain);
+	  r = build_conditional_expr (loc, comp, gt, uo, complain);
+	}
     }
   else
     /* op0 == op1 ? equal : op0 < op1 ? less : greater */
     r = gt;
 
   tree lt = lookup_comparison_result (tag, type, 2);
-  tree comp = build_new_op (loc, LT_EXPR, flags, op0, op1, complain);
-  r = build_conditional_expr (loc, comp, lt, r, complain);
+  if (scalar)
+    {
+      comp = fold_build2 (LT_EXPR, boolean_type_node, op0, op1);
+      r = fold_build3 (COND_EXPR, type, comp, lt, r);
+    }
+  else
+    {
+      comp = build_new_op (loc, LT_EXPR, flags, op0, op1, complain);
+      r = build_conditional_expr (loc, comp, lt, r, complain);
+    }
 
   tree eq = lookup_comparison_result (tag, type, 0);
-  comp = build_new_op (loc, EQ_EXPR, flags, op0, op1, complain);
-  r = build_conditional_expr (loc, comp, eq, r, complain);
+  if (scalar)
+    {
+      comp = fold_build2 (EQ_EXPR, boolean_type_node, op0, op1);
+      r = fold_build3 (COND_EXPR, type, comp, eq, r);
+    }
+  else
+    {
+      comp = build_new_op (loc, EQ_EXPR, flags, op0, op1, complain);
+      r = build_conditional_expr (loc, comp, eq, r, complain);
+    }
 
   return r;
 }
diff --git a/gcc/testsuite/g++.dg/cpp2a/spaceship-fallback1.C b/gcc/testsuite/g++.dg/cpp2a/spaceship-fallback1.C
new file mode 100644
index 0000000000000..5ce49490fe5af
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/spaceship-fallback1.C
@@ -0,0 +1,17 @@
+// PR c++/100367
+// { dg-do compile { target c++20 } }
+
+#include <compare>
+
+struct iter {
+  bool current;
+  iter(iter &);
+};
+
+constexpr bool operator==(const iter &, const iter &y) {
+  return y.current;
+}
+
+void lexicographical_compare_three_way(iter a) {
+  (a == a) <=> true;
+}

From 4ffe506d025e953a0ab3ef0392867d1a46bb9ff5 Mon Sep 17 00:00:00 2001
From: Bill Schmidt <wschmidt@linux.ibm.com>
Date: Fri, 14 May 2021 14:15:55 -0500
Subject: [PATCH 144/164] rs6000: Add -mrop-protect and -mprivileged flags

2021-05-14  Bill Schmidt  <wschmidt@linux.ibm.com>

gcc/
	* config/rs6000/rs6000.c (rs6000_option_override_internal):
	Disable shrink wrap when inserting ROP-protect instructions.
	* config/rs6000/rs6000.opt (mrop-protect): New option.
	(mprivileged): Likewise.
	* doc/invoke.texi: Document mrop-protect and mprivileged.
---
 gcc/config/rs6000/rs6000.c   |  4 ++++
 gcc/config/rs6000/rs6000.opt |  8 ++++++++
 gcc/doc/invoke.texi          | 20 ++++++++++++++++++--
 3 files changed, 30 insertions(+), 2 deletions(-)

diff --git a/gcc/config/rs6000/rs6000.c b/gcc/config/rs6000/rs6000.c
index 844fee88cf3c1..83ef1be6afef9 100644
--- a/gcc/config/rs6000/rs6000.c
+++ b/gcc/config/rs6000/rs6000.c
@@ -4036,6 +4036,10 @@ rs6000_option_override_internal (bool global_init_p)
       && ((rs6000_isa_flags_explicit & OPTION_MASK_QUAD_MEMORY_ATOMIC) == 0))
     rs6000_isa_flags |= OPTION_MASK_QUAD_MEMORY_ATOMIC;
 
+  /* If we are inserting ROP-protect instructions, disable shrink wrap.  */
+  if (rs6000_rop_protect)
+    flag_shrink_wrap = 0;
+
   /* If we can shrink-wrap the TOC register save separately, then use
      -msave-toc-indirect unless explicitly disabled.  */
   if ((rs6000_isa_flags_explicit & OPTION_MASK_SAVE_TOC_INDIRECT) == 0
diff --git a/gcc/config/rs6000/rs6000.opt b/gcc/config/rs6000/rs6000.opt
index 0dbdf75367353..2685fa715176e 100644
--- a/gcc/config/rs6000/rs6000.opt
+++ b/gcc/config/rs6000/rs6000.opt
@@ -619,3 +619,11 @@ Generate (do not generate) MMA instructions.
 
 mrelative-jumptables
 Target Undocumented Var(rs6000_relative_jumptables) Init(1) Save
+
+mrop-protect
+Target Var(rs6000_rop_protect) Init(0)
+Enable instructions that guard against return-oriented programming attacks.
+
+mprivileged
+Target Var(rs6000_privileged) Init(0)
+Generate code that will run in privileged state.
diff --git a/gcc/doc/invoke.texi b/gcc/doc/invoke.texi
index 4a87b9ef8e8c5..7f13ffb79e10c 100644
--- a/gcc/doc/invoke.texi
+++ b/gcc/doc/invoke.texi
@@ -1238,7 +1238,8 @@ See RS/6000 and PowerPC Options.
 -mgnu-attribute  -mno-gnu-attribute @gol
 -mstack-protector-guard=@var{guard} -mstack-protector-guard-reg=@var{reg} @gol
 -mstack-protector-guard-offset=@var{offset} -mprefixed -mno-prefixed @gol
--mpcrel -mno-pcrel -mmma -mno-mmma}
+-mpcrel -mno-pcrel -mmma -mno-mmma -mrop-protect -mno-rop-protect @gol
+-mprivileged -mno-privileged}
 
 @emph{RX Options}
 @gccoptlist{-m64bit-doubles  -m32bit-doubles  -fpu  -nofpu@gol
@@ -27019,7 +27020,8 @@ following options:
 -mmulhw  -mdlmzb  -mmfpgpr  -mvsx @gol
 -mcrypto  -mhtm  -mpower8-fusion  -mpower8-vector @gol
 -mquad-memory  -mquad-memory-atomic  -mfloat128 @gol
--mfloat128-hardware -mprefixed -mpcrel -mmma}
+-mfloat128-hardware -mprefixed -mpcrel -mmma @gol
+-mrop-protect}
 
 The particular options set for any particular CPU varies between
 compiler versions, depending on what setting seems to produce optimal
@@ -28024,6 +28026,20 @@ store instructions when the option @option{-mcpu=future} is used.
 Generate (do not generate) the MMA instructions when the option
 @option{-mcpu=future} is used.
 
+@item -mrop-protect
+@itemx -mno-rop-protect
+@opindex mrop-protect
+@opindex mno-rop-protect
+Generate (do not generate) ROP protection instructions when the target
+processor supports them.  Currently this option disables the shrink-wrap
+optimization (@option{-fshrink-wrap}).
+
+@item -mprivileged
+@itemx -mno-privileged
+@opindex mprivileged
+@opindex mno-privileged
+Generate (do not generate) code that will run in privileged state.
+
 @item -mblock-ops-unaligned-vsx
 @itemx -mno-block-ops-unaligned-vsx
 @opindex block-ops-unaligned-vsx

From 7db558884730cfe7a874e9316a5a66987b020964 Mon Sep 17 00:00:00 2001
From: Bill Schmidt <wschmidt@linux.ibm.com>
Date: Fri, 14 May 2021 14:25:25 -0500
Subject: [PATCH 145/164] rs6000: Emit ROP-mitigation instructions in prologue
 and epilogue

2021-05-14  Bill Schmidt  <wschmidt@linux.ibm.com>

gcc/
	* config/rs6000/rs6000-internal.h (rs6000_stack): Add
	rop_hash_save_offset and rop_hash_size.
	* config/rs6000/rs6000-logue.c (rs6000_stack_info): Compute
	rop_hash_size and rop_hash_save_offset.
	(debug_stack_info): Dump rop_hash_save_offset and rop_hash_size.
	(rs6000_emit_prologue): Emit hashst[p] in prologue.
	(rs6000_emit_epilogue): Emit hashchk[p] in epilogue.
	* config/rs6000/rs6000.md (unspec): Add UNSPEC_HASHST and
	UNSPEC_HASHCHK.
	(hashst): New define_insn.
	(hashchk): Likewise.
---
 gcc/config/rs6000/rs6000-internal.h |  2 +
 gcc/config/rs6000/rs6000-logue.c    | 74 ++++++++++++++++++++++++++---
 gcc/config/rs6000/rs6000.md         | 31 ++++++++++++
 3 files changed, 100 insertions(+), 7 deletions(-)

diff --git a/gcc/config/rs6000/rs6000-internal.h b/gcc/config/rs6000/rs6000-internal.h
index 428a7861a987c..88cf9bd56925d 100644
--- a/gcc/config/rs6000/rs6000-internal.h
+++ b/gcc/config/rs6000/rs6000-internal.h
@@ -39,6 +39,7 @@ typedef struct rs6000_stack {
   int gp_save_offset;		/* offset to save GP regs from initial SP */
   int fp_save_offset;		/* offset to save FP regs from initial SP */
   int altivec_save_offset;	/* offset to save AltiVec regs from initial SP */
+  int rop_hash_save_offset;	/* offset to save ROP hash from initial SP */
   int lr_save_offset;		/* offset to save LR from initial SP */
   int cr_save_offset;		/* offset to save CR from initial SP */
   int vrsave_save_offset;	/* offset to save VRSAVE from initial SP */
@@ -53,6 +54,7 @@ typedef struct rs6000_stack {
   int gp_size;			/* size of saved GP registers */
   int fp_size;			/* size of saved FP registers */
   int altivec_size;		/* size of saved AltiVec registers */
+  int rop_hash_size;		/* size of ROP hash slot */
   int cr_size;			/* size to hold CR if not in fixed area */
   int vrsave_size;		/* size to hold VRSAVE */
   int altivec_padding_size;	/* size of altivec alignment padding */
diff --git a/gcc/config/rs6000/rs6000-logue.c b/gcc/config/rs6000/rs6000-logue.c
index b0ac183ceff16..13c00e740d6ac 100644
--- a/gcc/config/rs6000/rs6000-logue.c
+++ b/gcc/config/rs6000/rs6000-logue.c
@@ -595,19 +595,21 @@ rs6000_savres_strategy (rs6000_stack_t *info,
 		+---------------------------------------+
 		| Parameter save area (+padding*) (P)	|  32
 		+---------------------------------------+
-		| Alloca space (A)			|  32+P
+		| Optional ROP hash slot (R)		|  32+P
 		+---------------------------------------+
-		| Local variable space (L)		|  32+P+A
+		| Alloca space (A)			|  32+P+R
 		+---------------------------------------+
-		| Save area for AltiVec registers (W)	|  32+P+A+L
+		| Local variable space (L)		|  32+P+R+A
 		+---------------------------------------+
-		| AltiVec alignment padding (Y)		|  32+P+A+L+W
+		| Save area for AltiVec registers (W)	|  32+P+R+A+L
 		+---------------------------------------+
-		| Save area for GP registers (G)	|  32+P+A+L+W+Y
+		| AltiVec alignment padding (Y)		|  32+P+R+A+L+W
 		+---------------------------------------+
-		| Save area for FP registers (F)	|  32+P+A+L+W+Y+G
+		| Save area for GP registers (G)	|  32+P+R+A+L+W+Y
 		+---------------------------------------+
-	old SP->| back chain to caller's caller		|  32+P+A+L+W+Y+G+F
+		| Save area for FP registers (F)	|  32+P+R+A+L+W+Y+G
+		+---------------------------------------+
+	old SP->| back chain to caller's caller		|  32+P+R+A+L+W+Y+G+F
 		+---------------------------------------+
 
      * If the alloca area is present, the parameter save area is
@@ -716,6 +718,19 @@ rs6000_stack_info (void)
 
   /* Does this function call anything (apart from sibling calls)?  */
   info->calls_p = (!crtl->is_leaf || cfun->machine->ra_needs_full_frame);
+  info->rop_hash_size = 0;
+
+  if (TARGET_POWER10
+      && info->calls_p
+      && DEFAULT_ABI == ABI_ELFv2
+      && rs6000_rop_protect)
+    info->rop_hash_size = 8;
+  else if (rs6000_rop_protect && DEFAULT_ABI != ABI_ELFv2)
+    {
+      /* We can't check this in rs6000_option_override_internal since
+	 DEFAULT_ABI isn't established yet.  */
+      error ("%qs requires the ELFv2 ABI", "-mrop-protect");
+    }
 
   /* Determine if we need to save the condition code registers.  */
   if (save_reg_p (CR2_REGNO)
@@ -808,6 +823,11 @@ rs6000_stack_info (void)
 
 	  /* Adjust for AltiVec case.  */
 	  info->ehrd_offset = info->altivec_save_offset - ehrd_size;
+
+	  /* Adjust for ROP protection.  */
+	  info->rop_hash_save_offset
+	    = info->altivec_save_offset - info->rop_hash_size;
+	  info->ehrd_offset -= info->rop_hash_size;
 	}
       else
 	info->ehrd_offset = info->gp_save_offset - ehrd_size;
@@ -849,6 +869,7 @@ rs6000_stack_info (void)
 				  + info->gp_size
 				  + info->altivec_size
 				  + info->altivec_padding_size
+				  + info->rop_hash_size
 				  + ehrd_size
 				  + ehcr_size
 				  + info->cr_size
@@ -987,6 +1008,10 @@ debug_stack_info (rs6000_stack_t *info)
     fprintf (stderr, "\tvrsave_save_offset  = %5d\n",
 	     info->vrsave_save_offset);
 
+  if (info->rop_hash_size)
+    fprintf (stderr, "\trop_hash_save_offset = %5d\n",
+	     info->rop_hash_save_offset);
+
   if (info->lr_save_p)
     fprintf (stderr, "\tlr_save_offset      = %5d\n", info->lr_save_offset);
 
@@ -1026,6 +1051,9 @@ debug_stack_info (rs6000_stack_t *info)
     fprintf (stderr, "\taltivec_padding_size= %5d\n",
 	     info->altivec_padding_size);
 
+  if (info->rop_hash_size)
+    fprintf (stderr, "\trop_hash_size       = %5d\n", info->rop_hash_size);
+
   if (info->cr_size)
     fprintf (stderr, "\tcr_size             = %5d\n", info->cr_size);
 
@@ -3252,6 +3280,22 @@ rs6000_emit_prologue (void)
 	}
     }
 
+  /* The ROP hash store must occur before a stack frame is created,
+     since the hash operates on r1.  */
+  /* NOTE: The hashst isn't needed if we're going to do a sibcall,
+     but there's no way to know that here.  Harmless except for
+     performance, of course.  */
+  if (TARGET_POWER10 && rs6000_rop_protect && info->rop_hash_size != 0)
+    {
+      gcc_assert (DEFAULT_ABI == ABI_ELFv2);
+      rtx stack_ptr = gen_rtx_REG (Pmode, STACK_POINTER_REGNUM);
+      rtx addr = gen_rtx_PLUS (Pmode, stack_ptr,
+			       GEN_INT (info->rop_hash_save_offset));
+      rtx mem = gen_rtx_MEM (Pmode, addr);
+      rtx reg0 = gen_rtx_REG (Pmode, 0);
+      emit_insn (gen_hashst (mem, reg0));
+    }
+
   /* If we need to save CR, put it into r12 or r11.  Choose r12 except when
      r12 will be needed by out-of-line gpr save.  */
   cr_save_regno = ((DEFAULT_ABI == ABI_AIX || DEFAULT_ABI == ABI_ELFv2)
@@ -4980,6 +5024,22 @@ rs6000_emit_epilogue (enum epilogue_type epilogue_type)
       emit_insn (gen_add3_insn (sp_reg_rtx, sp_reg_rtx, sa));
     }
 
+  /* The ROP hash check must occur after the stack pointer is restored
+     (since the hash involves r1), and is not performed for a sibcall.  */
+  if (TARGET_POWER10
+      && rs6000_rop_protect
+      && info->rop_hash_size != 0
+      && epilogue_type != EPILOGUE_TYPE_SIBCALL)
+    {
+      gcc_assert (DEFAULT_ABI == ABI_ELFv2);
+      rtx stack_ptr = gen_rtx_REG (Pmode, STACK_POINTER_REGNUM);
+      rtx addr = gen_rtx_PLUS (Pmode, stack_ptr,
+			       GEN_INT (info->rop_hash_save_offset));
+      rtx mem = gen_rtx_MEM (Pmode, addr);
+      rtx reg0 = gen_rtx_REG (Pmode, 0);
+      emit_insn (gen_hashchk (reg0, mem));
+    }
+
   if (epilogue_type != EPILOGUE_TYPE_SIBCALL && restoring_FPRs_inline)
     {
       if (cfa_restores)
diff --git a/gcc/config/rs6000/rs6000.md b/gcc/config/rs6000/rs6000.md
index c8cdc42533c1a..0bfeb24d9e872 100644
--- a/gcc/config/rs6000/rs6000.md
+++ b/gcc/config/rs6000/rs6000.md
@@ -154,6 +154,8 @@
    UNSPEC_CNTTZDM
    UNSPEC_PDEPD
    UNSPEC_PEXTD
+   UNSPEC_HASHST
+   UNSPEC_HASHCHK
   ])
 
 ;;
@@ -14948,6 +14950,35 @@
   "TARGET_P9_MISC && TARGET_64BIT"
   "cmpeqb %0,%1,%2"
   [(set_attr "type" "logical")])
+
+
+;; ROP mitigation instructions.
+
+(define_insn "hashst"
+  [(set (match_operand:DI 0 "simple_offsettable_mem_operand" "=m")
+        (unspec_volatile:DI [(match_operand:DI 1 "int_reg_operand" "r")]
+			    UNSPEC_HASHST))]
+  "TARGET_POWER10 && rs6000_rop_protect"
+{
+  static char templ[32];
+  const char *p = rs6000_privileged ? "p" : "";
+  sprintf (templ, "hashst%s %%1,%%0", p);
+  return templ;
+}
+  [(set_attr "type" "store")])
+
+(define_insn "hashchk"
+  [(unspec_volatile [(match_operand:DI 0 "int_reg_operand" "r")
+		     (match_operand:DI 1 "simple_offsettable_mem_operand" "m")]
+		    UNSPEC_HASHCHK)]
+  "TARGET_POWER10 && rs6000_rop_protect"
+{
+  static char templ[32];
+  const char *p = rs6000_privileged ? "p" : "";
+  sprintf (templ, "hashchk%s %%0,%%1", p);
+  return templ;
+}
+  [(set_attr "type" "load")])
 
 
 (include "sync.md")

From 426241cd9eac844b7f4f8741a8f540b4a2b5f4c7 Mon Sep 17 00:00:00 2001
From: Bill Schmidt <wschmidt@linux.ibm.com>
Date: Thu, 13 May 2021 13:10:10 -0500
Subject: [PATCH 146/164] rs6000: Conditionally define __ROP_PROTECT__

2021-05-13  Bill Schmidt  <wschmidt@linux.ibm.com>

gcc/
	* config/rs6000/rs6000-c.c (rs6000_target_modify_macros): Define
	__ROP_PROTECT__ if -mrop-protect is selected.
---
 gcc/config/rs6000/rs6000-c.c | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/gcc/config/rs6000/rs6000-c.c b/gcc/config/rs6000/rs6000-c.c
index 0f8a629ff5a06..afcb5bb6e39f7 100644
--- a/gcc/config/rs6000/rs6000-c.c
+++ b/gcc/config/rs6000/rs6000-c.c
@@ -602,6 +602,9 @@ rs6000_target_modify_macros (bool define_p, HOST_WIDE_INT flags,
   /* Whether pc-relative code is being generated.  */
   if ((flags & OPTION_MASK_PCREL) != 0)
     rs6000_define_or_undefine_macro (define_p, "__PCREL__");
+  /* Tell the user -mrop-protect is in play.  */
+  if (rs6000_rop_protect)
+    rs6000_define_or_undefine_macro (define_p, "__ROP_PROTECT__");
 }
 
 void

From 11bdfd3ab1cdc56cd25c00a0d5e4578a2007b76c Mon Sep 17 00:00:00 2001
From: Bill Schmidt <wschmidt@linux.ibm.com>
Date: Thu, 13 May 2021 13:33:35 -0500
Subject: [PATCH 147/164] rs6000: Add ROP tests

2021-05-13  Bill Schmidt  <wschmidt@linux.ibm.com>

gcc/testsuite/
	* gcc.target/powerpc/rop-1.c: New.
	* gcc.target/powerpc/rop-2.c: New.
	* gcc.target/powerpc/rop-3.c: New.
	* gcc.target/powerpc/rop-4.c: New.
	* gcc.target/powerpc/rop-5.c: New.
---
 gcc/testsuite/gcc.target/powerpc/rop-1.c | 17 +++++++++++++++++
 gcc/testsuite/gcc.target/powerpc/rop-2.c | 17 +++++++++++++++++
 gcc/testsuite/gcc.target/powerpc/rop-3.c | 18 ++++++++++++++++++
 gcc/testsuite/gcc.target/powerpc/rop-4.c | 15 +++++++++++++++
 gcc/testsuite/gcc.target/powerpc/rop-5.c | 13 +++++++++++++
 5 files changed, 80 insertions(+)
 create mode 100644 gcc/testsuite/gcc.target/powerpc/rop-1.c
 create mode 100644 gcc/testsuite/gcc.target/powerpc/rop-2.c
 create mode 100644 gcc/testsuite/gcc.target/powerpc/rop-3.c
 create mode 100644 gcc/testsuite/gcc.target/powerpc/rop-4.c
 create mode 100644 gcc/testsuite/gcc.target/powerpc/rop-5.c

diff --git a/gcc/testsuite/gcc.target/powerpc/rop-1.c b/gcc/testsuite/gcc.target/powerpc/rop-1.c
new file mode 100644
index 0000000000000..8cedcb6668aa0
--- /dev/null
+++ b/gcc/testsuite/gcc.target/powerpc/rop-1.c
@@ -0,0 +1,17 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -mdejagnu-cpu=power10 -mrop-protect" } */
+/* { dg-require-effective-target powerpc_elfv2 } */
+
+/* Verify that ROP-protect instructions are inserted when a
+   call is present.  */
+
+extern void foo (void);
+
+int bar ()
+{
+  foo ();
+  return 5;
+}
+
+/* { dg-final { scan-assembler-times {\mhashst\M} 1 } } */
+/* { dg-final { scan-assembler-times {\mhashchk\M} 1 } } */
diff --git a/gcc/testsuite/gcc.target/powerpc/rop-2.c b/gcc/testsuite/gcc.target/powerpc/rop-2.c
new file mode 100644
index 0000000000000..c556952aec1b2
--- /dev/null
+++ b/gcc/testsuite/gcc.target/powerpc/rop-2.c
@@ -0,0 +1,17 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -mdejagnu-cpu=power10 -mrop-protect -mprivileged" } */
+/* { dg-require-effective-target powerpc_elfv2 } */
+
+/* Verify that privileged ROP-protect instructions are inserted when a
+   call is present.  */
+
+extern void foo (void);
+
+int bar ()
+{
+  foo ();
+  return 5;
+}
+
+/* { dg-final { scan-assembler-times {\mhashstp\M} 1 } } */
+/* { dg-final { scan-assembler-times {\mhashchkp\M} 1 } } */
diff --git a/gcc/testsuite/gcc.target/powerpc/rop-3.c b/gcc/testsuite/gcc.target/powerpc/rop-3.c
new file mode 100644
index 0000000000000..8d03792e3e5e1
--- /dev/null
+++ b/gcc/testsuite/gcc.target/powerpc/rop-3.c
@@ -0,0 +1,18 @@
+/* { dg-do run { target { power10_hw } } } */
+/* { dg-require-effective-target powerpc_elfv2 } */
+/* { dg-options "-O2 -mdejagnu-cpu=power10 -mrop-protect" } */
+
+/* Verify that ROP-protect instructions execute correctly when a
+   call is present.  */
+
+void __attribute__((noipa)) foo ()
+{
+  asm ("");
+}
+
+int main ()
+{
+  foo ();
+  return 0;
+}
+
diff --git a/gcc/testsuite/gcc.target/powerpc/rop-4.c b/gcc/testsuite/gcc.target/powerpc/rop-4.c
new file mode 100644
index 0000000000000..dcf47c63fb794
--- /dev/null
+++ b/gcc/testsuite/gcc.target/powerpc/rop-4.c
@@ -0,0 +1,15 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -mdejagnu-cpu=power10 -mrop-protect" } */
+/* { dg-require-effective-target powerpc_elfv2 } */
+
+/* Verify that no ROP-protect instructions are inserted when no
+   call is present.  */
+
+
+int bar ()
+{
+  return 5;
+}
+
+/* { dg-final { scan-assembler-not {\mhashst\M} } } */
+/* { dg-final { scan-assembler-not {\mhashchk\M} } } */
diff --git a/gcc/testsuite/gcc.target/powerpc/rop-5.c b/gcc/testsuite/gcc.target/powerpc/rop-5.c
new file mode 100644
index 0000000000000..cf04ea90eeb43
--- /dev/null
+++ b/gcc/testsuite/gcc.target/powerpc/rop-5.c
@@ -0,0 +1,13 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -mdejagnu-cpu=power10 -mrop-protect" } */
+
+/* Verify that __ROP_PROTECT__ is predefined for -mrop-protect.  */
+
+int foo ()
+{
+#ifndef __ROP_PROTECT__
+  __ROP_PROTECT__ macro is not defined when it should be
+#endif
+  return 0;
+}
+

From c2e1b3d2981b2db51e7893edf3d0d87c66e28d71 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Thu, 20 May 2021 00:18:19 +0000
Subject: [PATCH 148/164] Daily bump.

---
 gcc/ChangeLog           | 35 +++++++++++++++++++++++++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/cp/ChangeLog        | 18 ++++++++++++++++++
 gcc/testsuite/ChangeLog | 29 +++++++++++++++++++++++++++++
 4 files changed, 83 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 23fcbed1120f7..e3051116b82cf 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,38 @@
+2021-05-19  Bill Schmidt  <wschmidt@linux.ibm.com>
+
+	* config/rs6000/rs6000-c.c (rs6000_target_modify_macros): Define
+	__ROP_PROTECT__ if -mrop-protect is selected.
+
+2021-05-19  Bill Schmidt  <wschmidt@linux.ibm.com>
+
+	* config/rs6000/rs6000-internal.h (rs6000_stack): Add
+	rop_hash_save_offset and rop_hash_size.
+	* config/rs6000/rs6000-logue.c (rs6000_stack_info): Compute
+	rop_hash_size and rop_hash_save_offset.
+	(debug_stack_info): Dump rop_hash_save_offset and rop_hash_size.
+	(rs6000_emit_prologue): Emit hashst[p] in prologue.
+	(rs6000_emit_epilogue): Emit hashchk[p] in epilogue.
+	* config/rs6000/rs6000.md (unspec): Add UNSPEC_HASHST and
+	UNSPEC_HASHCHK.
+	(hashst): New define_insn.
+	(hashchk): Likewise.
+
+2021-05-19  Bill Schmidt  <wschmidt@linux.ibm.com>
+
+	* config/rs6000/rs6000.c (rs6000_option_override_internal):
+	Disable shrink wrap when inserting ROP-protect instructions.
+	* config/rs6000/rs6000.opt (mrop-protect): New option.
+	(mprivileged): Likewise.
+	* doc/invoke.texi: Document mrop-protect and mprivileged.
+
+2021-05-19  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2021-05-19  Jonathan Wakely  <jwakely@redhat.com>
+
+	* doc/cpp.texi (Common Predefined Macros): Update documentation
+	for the __GXX_EXPERIMENTAL_CXX0X__ macro.
+
 2021-05-17  Alex Coplan  <alex.coplan@arm.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index da5d88b61f70b..e63f6d4142a92 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210519
+20210520
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 0398d5385c2af..a18dd9a1014d3 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,21 @@
+2021-05-19  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100367
+	PR c++/96299
+	* method.c (genericize_spaceship): Use fold_build2 for scalar
+	operands.
+
+2021-05-19  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100261
+	* rtti.c (get_tinfo_decl_direct): Check TYPE_TRANSPARENT_AGGR.
+
+2021-05-19  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100372
+	* tree.c (strip_typedefs): Only look at the pattern of a
+	TYPE_PACK_EXPANSION if it's a type.
+
 2021-05-18  Jason Merrill  <jason@redhat.com>
 
 	PR c++/100644
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index db7ba9e2638b2..573d53388511e 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,32 @@
+2021-05-19  Bill Schmidt  <wschmidt@linux.ibm.com>
+
+	* gcc.target/powerpc/rop-1.c: New.
+	* gcc.target/powerpc/rop-2.c: New.
+	* gcc.target/powerpc/rop-3.c: New.
+	* gcc.target/powerpc/rop-4.c: New.
+	* gcc.target/powerpc/rop-5.c: New.
+
+2021-05-19  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100367
+	PR c++/96299
+	* g++.dg/cpp2a/spaceship-fallback1.C: New test.
+
+2021-05-19  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	PR target/99977
+	* gcc.target/arm/pr99977.c: Require arm_arch_v8m_base.
+
+2021-05-19  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100261
+	* g++.dg/dfp/mangle-6.C: New test.
+
+2021-05-19  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100372
+	* g++.dg/cpp0x/alias-decl-ttp1.C: New test.
+
 2021-05-18  Jason Merrill  <jason@redhat.com>
 
 	* g++.dg/cpp0x/implicit-delete1.C: New test.

From 8b7212ebb80e854c08274228627ce0a3061db6b0 Mon Sep 17 00:00:00 2001
From: Jason Merrill <jason@redhat.com>
Date: Wed, 19 May 2021 16:40:24 -0400
Subject: [PATCH 149/164] c++: ICE with using and enum [PR100659]

Here the code for 'using enum' is confused by the combination of a
using-decl and an enum that are not from 'using enum'; this CONST_DECL is
from the normal unscoped enum scoping.

	PR c++/100659

gcc/cp/ChangeLog:

	* cp-tree.h (CONST_DECL_USING_P): Check for null TREE_TYPE.

gcc/testsuite/ChangeLog:

	* g++.dg/parse/access13.C: New test.
---
 gcc/cp/cp-tree.h                      | 1 +
 gcc/testsuite/g++.dg/parse/access13.C | 7 +++++++
 2 files changed, 8 insertions(+)
 create mode 100644 gcc/testsuite/g++.dg/parse/access13.C

diff --git a/gcc/cp/cp-tree.h b/gcc/cp/cp-tree.h
index fbf33b9150ee0..17ba7cbd22299 100644
--- a/gcc/cp/cp-tree.h
+++ b/gcc/cp/cp-tree.h
@@ -3529,6 +3529,7 @@ struct GTY(()) lang_decl {
    created by handle_using_decl.  */
 #define CONST_DECL_USING_P(NODE)			\
   (TREE_CODE (NODE) == CONST_DECL			\
+   && TREE_TYPE (NODE)					\
    && TREE_CODE (TREE_TYPE (NODE)) == ENUMERAL_TYPE	\
    && DECL_CONTEXT (NODE) != TREE_TYPE (NODE))
 
diff --git a/gcc/testsuite/g++.dg/parse/access13.C b/gcc/testsuite/g++.dg/parse/access13.C
new file mode 100644
index 0000000000000..41463c5dde5e2
--- /dev/null
+++ b/gcc/testsuite/g++.dg/parse/access13.C
@@ -0,0 +1,7 @@
+// PR c++/100659
+
+template <typename> struct A
+{
+  A::E::V;		       // { dg-warning "access decl" }
+  enum { V };		       // { dg-error "conflicts with a previous decl" }
+};

From b54e50285c716fabc3980c5383c4898018a60b28 Mon Sep 17 00:00:00 2001
From: Jason Merrill <jason@redhat.com>
Date: Wed, 19 May 2021 17:33:21 -0400
Subject: [PATCH 150/164] c++: _Complex template parameter [PR100634]

We were crashing because invalid_nontype_parm_type_p allowed _Complex
template parms, but convert_nontype_argument didn't know what to do for
them.  Let's just disallow it, people can and should use std::complex
instead.

	PR c++/100634

gcc/cp/ChangeLog:

	* pt.c (invalid_nontype_parm_type_p): Return true for COMPLEX_TYPE.

gcc/testsuite/ChangeLog:

	* g++.dg/cpp2a/nontype-complex1.C: New test.
---
 gcc/cp/pt.c                                   | 2 ++
 gcc/testsuite/g++.dg/cpp2a/nontype-complex1.C | 8 ++++++++
 2 files changed, 10 insertions(+)
 create mode 100644 gcc/testsuite/g++.dg/cpp2a/nontype-complex1.C

diff --git a/gcc/cp/pt.c b/gcc/cp/pt.c
index d30876ced9c59..1434beb80f4ba 100644
--- a/gcc/cp/pt.c
+++ b/gcc/cp/pt.c
@@ -26620,6 +26620,8 @@ invalid_nontype_parm_type_p (tree type, tsubst_flags_t complain)
   else if (cxx_dialect >= cxx11
 	   && TREE_CODE (type) == BOUND_TEMPLATE_TEMPLATE_PARM)
     return false;
+  else if (TREE_CODE (type) == COMPLEX_TYPE)
+    /* Fall through.  */;
   else if (VOID_TYPE_P (type))
     /* Fall through.  */;
   else if (cxx_dialect >= cxx20)
diff --git a/gcc/testsuite/g++.dg/cpp2a/nontype-complex1.C b/gcc/testsuite/g++.dg/cpp2a/nontype-complex1.C
new file mode 100644
index 0000000000000..4de2168ef60d1
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/nontype-complex1.C
@@ -0,0 +1,8 @@
+// PR c++/100634
+// { dg-do compile { target c++20 } }
+// { dg-options "" }
+
+// We could support _Complex template arguments, but better I think to make
+// people use a standard type instead.
+template<_Complex int> struct ComplexInt {}; // { dg-error "not a valid type" }
+using CI = ComplexInt<1 + 3i>;

From 271fc1caac433e84e6389e73a5bf07350ea545e2 Mon Sep 17 00:00:00 2001
From: Tobias Burnus <tobias@codesourcery.com>
Date: Thu, 20 May 2021 09:51:10 +0200
Subject: [PATCH 151/164] Testsuite/Fortran: gfortran.dg/pr96711.f90 - fix
 expected value for PowerPC [PR96983]

gcc/testsuite/ChangeLog:

	PR fortran/96983
	* gfortran.dg/pr96711.f90: Use 2**digit(x) instead of a hard-coded value;
	add comments regarding what the code does.

(cherry picked from commit 9e0a5e3ea37f9d7d2b6f2dab7c0bfbeaf08466a3)
---
 gcc/testsuite/gfortran.dg/pr96711.f90 | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/gcc/testsuite/gfortran.dg/pr96711.f90 b/gcc/testsuite/gfortran.dg/pr96711.f90
index 3761a8ea41613..3fa5d99cbf236 100644
--- a/gcc/testsuite/gfortran.dg/pr96711.f90
+++ b/gcc/testsuite/gfortran.dg/pr96711.f90
@@ -10,10 +10,12 @@ program p
   implicit none
   real(8)                :: x
   real(16)               :: y
+  ! Assume radix(x) == 2
+  ! 2/epsilon(x) = 2/(radix(x)**(1-digits(x)) = 2**digits(x) with that assumption
   integer(16), parameter :: k1 = nint (2 / epsilon (x), kind(k1))
   integer(16), parameter :: k2 = nint (2 / epsilon (y), kind(k2))
-  integer(16), parameter :: m1 = 9007199254740992_16                    !2**53
-  integer(16), parameter :: m2 = 10384593717069655257060992658440192_16 !2**113
+  integer(16), parameter :: m1 = 2_16**digits(x) ! IEEE: 2**53
+  integer(16), parameter :: m2 = 2_16**digits(y) ! IEEE: 2**113
   integer(16), volatile  :: m
   x = 2 / epsilon (x)
   y = 2 / epsilon (y)

From 5f772bd9847cdbf6a7a6d856de87cb65472d56f4 Mon Sep 17 00:00:00 2001
From: Joern Rennecke <joern.rennecke@riscy-ip.com>
Date: Thu, 20 May 2021 13:21:41 +0100
Subject: [PATCH 152/164] libstdc++: Disable floating_to_chars.cc on 16 bit
 targets

This patch conditionally disables the compilation of floating_to_chars.cc
on 16 bit targets, thus fixing a build failure for these targets as
the POW10_SPLIT_2 array exceeds the maximum object size.

libstdc++-v3/
	PR libstdc++/100361
	* include/std/charconv (to_chars): Hide the overloads for
	floating-point types for 16 bit targets.
	* src/c++17/floating_to_chars.cc: Don't compile for 16 bit targets.
	* testsuite/20_util/to_chars/double.cc: Run this test only on
	size32plus targets.
	* testsuite/20_util/to_chars/float.cc: Likewise.
	* testsuite/20_util/to_chars/long_double.cc: Likewise.
---
 libstdc++-v3/include/std/charconv                      | 3 ++-
 libstdc++-v3/src/c++17/floating_to_chars.cc            | 4 +++-
 libstdc++-v3/testsuite/20_util/to_chars/double.cc      | 1 +
 libstdc++-v3/testsuite/20_util/to_chars/float.cc       | 1 +
 libstdc++-v3/testsuite/20_util/to_chars/long_double.cc | 1 +
 5 files changed, 8 insertions(+), 2 deletions(-)

diff --git a/libstdc++-v3/include/std/charconv b/libstdc++-v3/include/std/charconv
index 6e407f31e30b0..64a6606bb3387 100644
--- a/libstdc++-v3/include/std/charconv
+++ b/libstdc++-v3/include/std/charconv
@@ -703,7 +703,8 @@ namespace __detail
 	     chars_format __fmt = chars_format::general) noexcept;
 #endif
 
-#if _GLIBCXX_FLOAT_IS_IEEE_BINARY32 && _GLIBCXX_DOUBLE_IS_IEEE_BINARY64
+#if _GLIBCXX_FLOAT_IS_IEEE_BINARY32 && _GLIBCXX_DOUBLE_IS_IEEE_BINARY64 \
+    && __SIZE_WIDTH__ >= 32
   // Floating-point std::to_chars
 
   // Overloads for float.
diff --git a/libstdc++-v3/src/c++17/floating_to_chars.cc b/libstdc++-v3/src/c++17/floating_to_chars.cc
index 1a0abb9e80f86..44f547a77b4c2 100644
--- a/libstdc++-v3/src/c++17/floating_to_chars.cc
+++ b/libstdc++-v3/src/c++17/floating_to_chars.cc
@@ -50,7 +50,9 @@ extern "C" int __sprintfieee128(char*, const char*, ...);
 
 // This implementation crucially assumes float/double have the
 // IEEE binary32/binary64 formats.
-#if _GLIBCXX_FLOAT_IS_IEEE_BINARY32 && _GLIBCXX_DOUBLE_IS_IEEE_BINARY64
+#if _GLIBCXX_FLOAT_IS_IEEE_BINARY32 && _GLIBCXX_DOUBLE_IS_IEEE_BINARY64 \
+    /* And it also assumes that uint64_t POW10_SPLIT_2[3133][3] is valid.  */\
+    && __SIZE_WIDTH__ >= 32
 
 // Determine the binary format of 'long double'.
 
diff --git a/libstdc++-v3/testsuite/20_util/to_chars/double.cc b/libstdc++-v3/testsuite/20_util/to_chars/double.cc
index bb6f74424edf7..64e62213044af 100644
--- a/libstdc++-v3/testsuite/20_util/to_chars/double.cc
+++ b/libstdc++-v3/testsuite/20_util/to_chars/double.cc
@@ -33,6 +33,7 @@
 
 // { dg-do run { target c++17 } }
 // { dg-require-effective-target ieee-floats }
+// { dg-require-effective-target size32plus }
 
 #include <charconv>
 
diff --git a/libstdc++-v3/testsuite/20_util/to_chars/float.cc b/libstdc++-v3/testsuite/20_util/to_chars/float.cc
index 0c8dd4f66dfda..73b9081d4ff96 100644
--- a/libstdc++-v3/testsuite/20_util/to_chars/float.cc
+++ b/libstdc++-v3/testsuite/20_util/to_chars/float.cc
@@ -33,6 +33,7 @@
 
 // { dg-do run { target c++17 } }
 // { dg-require-effective-target ieee-floats }
+// { dg-require-effective-target size32plus }
 
 #include <charconv>
 
diff --git a/libstdc++-v3/testsuite/20_util/to_chars/long_double.cc b/libstdc++-v3/testsuite/20_util/to_chars/long_double.cc
index 8cf45ad5e9418..447e5368811a6 100644
--- a/libstdc++-v3/testsuite/20_util/to_chars/long_double.cc
+++ b/libstdc++-v3/testsuite/20_util/to_chars/long_double.cc
@@ -35,6 +35,7 @@
 // { dg-xfail-run-if "Non-conforming printf (see PR98384)" { *-*-solaris* *-*-darwin* } }
 
 // { dg-require-effective-target ieee-floats }
+// { dg-require-effective-target size32plus }
 
 #include <charconv>
 

From a470d058707bf3e555f30adc68237f422d0a7d47 Mon Sep 17 00:00:00 2001
From: Eric Botcazou <ebotcazou@adacore.com>
Date: Thu, 20 May 2021 17:12:11 +0200
Subject: [PATCH 153/164] Fix gnat.dg spurious failures on PowerPC64 LE

gcc/testsuite
	PR testsuite/96488
	* gnat.dg/unchecked_convert5.adb: Do not run on PowerPC64 LE.
	* gnat.dg/unchecked_convert6.adb: Likewise.
---
 gcc/testsuite/gnat.dg/unchecked_convert5.adb | 2 +-
 gcc/testsuite/gnat.dg/unchecked_convert6.adb | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/gcc/testsuite/gnat.dg/unchecked_convert5.adb b/gcc/testsuite/gnat.dg/unchecked_convert5.adb
index e3e4312d73107..9c24d669063aa 100644
--- a/gcc/testsuite/gnat.dg/unchecked_convert5.adb
+++ b/gcc/testsuite/gnat.dg/unchecked_convert5.adb
@@ -1,4 +1,4 @@
--- { dg-do run { target hppa*-*-* sparc*-*-* powerpc*-*-* } }
+-- { dg-do run { target hppa*-*-* sparc*-*-* powerpc-*-* powerpc64-*-* } }
 
 with Unchecked_Conversion;
 
diff --git a/gcc/testsuite/gnat.dg/unchecked_convert6.adb b/gcc/testsuite/gnat.dg/unchecked_convert6.adb
index a26a6a9b762a1..ce8cc10b93bf1 100644
--- a/gcc/testsuite/gnat.dg/unchecked_convert6.adb
+++ b/gcc/testsuite/gnat.dg/unchecked_convert6.adb
@@ -1,4 +1,4 @@
--- { dg-do run { target hppa*-*-* sparc*-*-* powerpc*-*-* } }
+-- { dg-do run { target hppa*-*-* sparc*-*-* powerpc-*-* powerpc64-*-* } }
 
 with Unchecked_Conversion;
 

From e43f47686980e9d0081aa765b619bdc89189b51a Mon Sep 17 00:00:00 2001
From: Andreas Krebbel <krebbel@linux.ibm.com>
Date: Tue, 27 Apr 2021 10:09:06 +0200
Subject: [PATCH 154/164] PR100281 C++: Fix SImode pointer handling

The problem appears to be triggered by two locations in the front-end
where non-POINTER_SIZE pointers aren't handled right now.

1. An assertion in strip_typedefs is triggered because the alignment
of the types don't match. This in turn is caused by creating the new
type with build_pointer_type instead of taking the type of the
original pointer into account.

2. An assertion in cp_convert_to_pointer is triggered which expects
the target type to always have POINTER_SIZE.

gcc/cp/ChangeLog:

	PR c++/100281
	* cvt.c (cp_convert_to_pointer): Use the size of the target
	pointer type.
	* tree.c (cp_build_reference_type): Call
	cp_build_reference_type_for_mode with VOIDmode.
	(cp_build_reference_type_for_mode): Rename from
	cp_build_reference_type.  Add MODE argument and invoke
	build_reference_type_for_mode.
	(strip_typedefs): Use build_pointer_type_for_mode and
	cp_build_reference_type_for_mode for pointers and references.

gcc/ChangeLog:

	PR c++/100281
	* tree.c (build_reference_type_for_mode)
	(build_pointer_type_for_mode): Pick pointer mode if MODE argument
	is VOIDmode.
	(build_reference_type, build_pointer_type): Invoke
	build_*_type_for_mode with VOIDmode.

gcc/testsuite/ChangeLog:

	PR c++/100281
	* g++.target/s390/pr100281-1.C: New test.
	* g++.target/s390/pr100281-2.C: New test.

(cherry picked from commit 720dff974ea0487c35c0a4bfa527f30df5066ce1)
---
 gcc/cp/cvt.c                               |  2 +-
 gcc/cp/tree.c                              | 25 ++++++++++++++-----
 gcc/testsuite/g++.target/s390/pr100281-1.C | 10 ++++++++
 gcc/testsuite/g++.target/s390/pr100281-2.C |  9 +++++++
 gcc/tree.c                                 | 29 ++++++++++++++--------
 5 files changed, 57 insertions(+), 18 deletions(-)
 create mode 100644 gcc/testsuite/g++.target/s390/pr100281-1.C
 create mode 100644 gcc/testsuite/g++.target/s390/pr100281-2.C

diff --git a/gcc/cp/cvt.c b/gcc/cp/cvt.c
index f1687e804d1c5..7fa6e8df52b55 100644
--- a/gcc/cp/cvt.c
+++ b/gcc/cp/cvt.c
@@ -232,7 +232,7 @@ cp_convert_to_pointer (tree type, tree expr, bool dofold,
     {
       if (TYPE_PRECISION (intype) == POINTER_SIZE)
 	return build1 (CONVERT_EXPR, type, expr);
-      expr = cp_convert (c_common_type_for_size (POINTER_SIZE, 0), expr,
+      expr = cp_convert (c_common_type_for_size (TYPE_PRECISION (type), 0), expr,
 			 complain);
       /* Modes may be different but sizes should be the same.  There
 	 is supposed to be some integral type that is the same width
diff --git a/gcc/cp/tree.c b/gcc/cp/tree.c
index ced7cb5e97740..4930c29271184 100644
--- a/gcc/cp/tree.c
+++ b/gcc/cp/tree.c
@@ -1201,12 +1201,14 @@ vla_type_p (tree t)
   return false;
 }
 
-/* Return a reference type node referring to TO_TYPE.  If RVAL is
+
+/* Return a reference type node of MODE referring to TO_TYPE.  If MODE
+   is VOIDmode the standard pointer mode will be picked.  If RVAL is
    true, return an rvalue reference type, otherwise return an lvalue
    reference type.  If a type node exists, reuse it, otherwise create
    a new one.  */
 tree
-cp_build_reference_type (tree to_type, bool rval)
+cp_build_reference_type_for_mode (tree to_type, machine_mode mode, bool rval)
 {
   tree lvalue_ref, t;
 
@@ -1219,7 +1221,8 @@ cp_build_reference_type (tree to_type, bool rval)
       to_type = TREE_TYPE (to_type);
     }
 
-  lvalue_ref = build_reference_type (to_type);
+  lvalue_ref = build_reference_type_for_mode (to_type, mode, false);
+
   if (!rval)
     return lvalue_ref;
 
@@ -1245,7 +1248,7 @@ cp_build_reference_type (tree to_type, bool rval)
     SET_TYPE_STRUCTURAL_EQUALITY (t);
   else if (TYPE_CANONICAL (to_type) != to_type)
     TYPE_CANONICAL (t) 
-      = cp_build_reference_type (TYPE_CANONICAL (to_type), rval);
+      = cp_build_reference_type_for_mode (TYPE_CANONICAL (to_type), mode, rval);
   else
     TYPE_CANONICAL (t) = t;
 
@@ -1255,6 +1258,16 @@ cp_build_reference_type (tree to_type, bool rval)
 
 }
 
+/* Return a reference type node referring to TO_TYPE.  If RVAL is
+   true, return an rvalue reference type, otherwise return an lvalue
+   reference type.  If a type node exists, reuse it, otherwise create
+   a new one.  */
+tree
+cp_build_reference_type (tree to_type, bool rval)
+{
+  return cp_build_reference_type_for_mode (to_type, VOIDmode, rval);
+}
+
 /* Returns EXPR cast to rvalue reference type, like std::move.  */
 
 tree
@@ -1556,11 +1569,11 @@ strip_typedefs (tree t, bool *remove_attributes, unsigned int flags)
     {
     case POINTER_TYPE:
       type = strip_typedefs (TREE_TYPE (t), remove_attributes, flags);
-      result = build_pointer_type (type);
+      result = build_pointer_type_for_mode (type, TYPE_MODE (t), false);
       break;
     case REFERENCE_TYPE:
       type = strip_typedefs (TREE_TYPE (t), remove_attributes, flags);
-      result = cp_build_reference_type (type, TYPE_REF_IS_RVALUE (t));
+      result = cp_build_reference_type_for_mode (type, TYPE_MODE (t), TYPE_REF_IS_RVALUE (t));
       break;
     case OFFSET_TYPE:
       t0 = strip_typedefs (TYPE_OFFSET_BASETYPE (t), remove_attributes, flags);
diff --git a/gcc/testsuite/g++.target/s390/pr100281-1.C b/gcc/testsuite/g++.target/s390/pr100281-1.C
new file mode 100644
index 0000000000000..b82e27b64e93f
--- /dev/null
+++ b/gcc/testsuite/g++.target/s390/pr100281-1.C
@@ -0,0 +1,10 @@
+// PR C++/100281
+// { dg-do compile }
+
+typedef void * __attribute__((mode (SI))) __ptr32_t;
+
+void foo () {
+  unsigned int b = 100;
+  __ptr32_t a;
+  a = b; /* { dg-error "invalid conversion from 'unsigned int' to '__ptr32_t'.*" } */
+}
diff --git a/gcc/testsuite/g++.target/s390/pr100281-2.C b/gcc/testsuite/g++.target/s390/pr100281-2.C
new file mode 100644
index 0000000000000..58552becd7ceb
--- /dev/null
+++ b/gcc/testsuite/g++.target/s390/pr100281-2.C
@@ -0,0 +1,9 @@
+// PR C++/100281
+// { dg-do compile }
+
+typedef int & __attribute__((mode (SI))) __ref32_t;
+
+void foo () {
+  unsigned int b = 100;
+  __ref32_t a = b; /* { dg-error "cannot bind non-const lvalue reference of type '__ref32_t'.*" } */
+}
diff --git a/gcc/tree.c b/gcc/tree.c
index e4e74ac8afc32..e0183b73e313d 100644
--- a/gcc/tree.c
+++ b/gcc/tree.c
@@ -7934,9 +7934,10 @@ operation_no_trapping_overflow (tree type, enum tree_code code)
    constructed by language-dependent code, not here.)  */
 
 /* Construct, lay out and return the type of pointers to TO_TYPE with
-   mode MODE.  If CAN_ALIAS_ALL is TRUE, indicate this type can
-   reference all of memory. If such a type has already been
-   constructed, reuse it.  */
+   mode MODE.  If MODE is VOIDmode, a pointer mode for the address
+   space of TO_TYPE will be picked.  If CAN_ALIAS_ALL is TRUE,
+   indicate this type can reference all of memory. If such a type has
+   already been constructed, reuse it.  */
 
 tree
 build_pointer_type_for_mode (tree to_type, machine_mode mode,
@@ -7948,6 +7949,12 @@ build_pointer_type_for_mode (tree to_type, machine_mode mode,
   if (to_type == error_mark_node)
     return error_mark_node;
 
+  if (mode == VOIDmode)
+    {
+      addr_space_t as = TYPE_ADDR_SPACE (to_type);
+      mode = targetm.addr_space.pointer_mode (as);
+    }
+
   /* If the pointed-to type has the may_alias attribute set, force
      a TYPE_REF_CAN_ALIAS_ALL pointer to be generated.  */
   if (lookup_attribute ("may_alias", TYPE_ATTRIBUTES (to_type)))
@@ -7999,10 +8006,7 @@ build_pointer_type_for_mode (tree to_type, machine_mode mode,
 tree
 build_pointer_type (tree to_type)
 {
-  addr_space_t as = to_type == error_mark_node? ADDR_SPACE_GENERIC
-					      : TYPE_ADDR_SPACE (to_type);
-  machine_mode pointer_mode = targetm.addr_space.pointer_mode (as);
-  return build_pointer_type_for_mode (to_type, pointer_mode, false);
+  return build_pointer_type_for_mode (to_type, VOIDmode, false);
 }
 
 /* Same as build_pointer_type_for_mode, but for REFERENCE_TYPE.  */
@@ -8017,6 +8021,12 @@ build_reference_type_for_mode (tree to_type, machine_mode mode,
   if (to_type == error_mark_node)
     return error_mark_node;
 
+  if (mode == VOIDmode)
+    {
+      addr_space_t as = TYPE_ADDR_SPACE (to_type);
+      mode = targetm.addr_space.pointer_mode (as);
+    }
+
   /* If the pointed-to type has the may_alias attribute set, force
      a TYPE_REF_CAN_ALIAS_ALL pointer to be generated.  */
   if (lookup_attribute ("may_alias", TYPE_ATTRIBUTES (to_type)))
@@ -8068,10 +8078,7 @@ build_reference_type_for_mode (tree to_type, machine_mode mode,
 tree
 build_reference_type (tree to_type)
 {
-  addr_space_t as = to_type == error_mark_node? ADDR_SPACE_GENERIC
-					      : TYPE_ADDR_SPACE (to_type);
-  machine_mode pointer_mode = targetm.addr_space.pointer_mode (as);
-  return build_reference_type_for_mode (to_type, pointer_mode, false);
+  return build_reference_type_for_mode (to_type, VOIDmode, false);
 }
 
 #define MAX_INT_CACHED_PREC \

From 0a1010428b3861464eb319c629c68cb13b9ca01e Mon Sep 17 00:00:00 2001
From: Jason Merrill <jason@redhat.com>
Date: Wed, 19 May 2021 21:12:45 -0400
Subject: [PATCH 155/164] c++: designated init with anonymous union [PR100489]

My patch for PR98463 added an assert that tripped on this testcase, because
we ended up with a U CONSTRUCTOR with an initializer for a, which is not a
member of U.  We need to wrap the a initializer in another CONSTRUCTOR for
the anonymous union.

There was already support for this in process_init_constructor_record, but
not in process_init_constructor_union.  But since this is about brace
elision, it really belongs under reshape_init rather than digest_init, so
this patch moves the handling to reshape_init_class, which also handles
unions.

	PR c++/100489

gcc/cp/ChangeLog:

	* decl.c (reshape_init_class): Handle designator for
	member of anonymous aggregate here.
	* typeck2.c (process_init_constructor_record): Not here.

gcc/testsuite/ChangeLog:

	* g++.dg/cpp2a/desig18.C: New test.
---
 gcc/cp/decl.c                        | 33 ++++++++++++++++++++++++----
 gcc/cp/typeck2.c                     | 26 ----------------------
 gcc/testsuite/g++.dg/cpp2a/desig18.C | 17 ++++++++++++++
 3 files changed, 46 insertions(+), 30 deletions(-)
 create mode 100644 gcc/testsuite/g++.dg/cpp2a/desig18.C

diff --git a/gcc/cp/decl.c b/gcc/cp/decl.c
index b81de8ef9349d..32dde5820dca1 100644
--- a/gcc/cp/decl.c
+++ b/gcc/cp/decl.c
@@ -6388,10 +6388,9 @@ reshape_init_class (tree type, reshape_iter *d, bool first_initializer_p,
 	      /* We already reshaped this.  */
 	      if (field != d->cur->index)
 		{
-		  tree id = DECL_NAME (d->cur->index);
-		  gcc_assert (id);
-		  gcc_checking_assert (d->cur->index
-				       == get_class_binding (type, id));
+		  if (tree id = DECL_NAME (d->cur->index))
+		    gcc_checking_assert (d->cur->index
+					 == get_class_binding (type, id));
 		  field = d->cur->index;
 		}
 	    }
@@ -6412,6 +6411,32 @@ reshape_init_class (tree type, reshape_iter *d, bool first_initializer_p,
 		       d->cur->index);
 	      return error_mark_node;
 	    }
+
+	  /* If the element is an anonymous union object and the initializer
+	     list is a designated-initializer-list, the anonymous union object
+	     is initialized by the designated-initializer-list { D }, where D
+	     is the designated-initializer-clause naming a member of the
+	     anonymous union object.  */
+	  tree ictx = DECL_CONTEXT (field);
+	  if (!same_type_ignoring_top_level_qualifiers_p (ictx, type))
+	    {
+	      gcc_assert (ANON_AGGR_TYPE_P (ictx));
+	      /* Find the anon aggr that is a direct member of TYPE.  */
+	      while (true)
+		{
+		  tree cctx = TYPE_CONTEXT (ictx);
+		  if (same_type_ignoring_top_level_qualifiers_p (cctx, type))
+		    break;
+		  ictx = cctx;
+		}
+	      /* And then the TYPE member with that anon aggr type.  */
+	      tree aafield = TYPE_FIELDS (type);
+	      for (; aafield; aafield = TREE_CHAIN (aafield))
+		if (TREE_TYPE (aafield) == ictx)
+		  break;
+	      gcc_assert (aafield);
+	      field = aafield;
+	    }
 	}
 
       /* If we processed all the member of the class, we are done.  */
diff --git a/gcc/cp/typeck2.c b/gcc/cp/typeck2.c
index 4e9632f6a7d42..142c6fd8e7502 100644
--- a/gcc/cp/typeck2.c
+++ b/gcc/cp/typeck2.c
@@ -1511,19 +1511,6 @@ process_init_constructor_record (tree type, tree init, int nested, int flags,
 			  || identifier_p (ce->index));
 	      if (ce->index == field || ce->index == DECL_NAME (field))
 		next = ce->value;
-	      else if (ANON_AGGR_TYPE_P (fldtype)
-		       && search_anon_aggr (fldtype,
-					    TREE_CODE (ce->index) == FIELD_DECL
-					    ? DECL_NAME (ce->index)
-					    : ce->index))
-		/* If the element is an anonymous union object and the
-		   initializer list is a designated-initializer-list, the
-		   anonymous union object is initialized by the
-		   designated-initializer-list { D }, where D is the
-		   designated-initializer-clause naming a member of the
-		   anonymous union object.  */
-		next = build_constructor_single (init_list_type_node,
-						 ce->index, ce->value);
 	      else
 		{
 		  ce = NULL;
@@ -1669,19 +1656,6 @@ process_init_constructor_record (tree type, tree init, int nested, int flags,
 
 		  if (ce->index == field || ce->index == DECL_NAME (field))
 		    break;
-		  if (ANON_AGGR_TYPE_P (TREE_TYPE (field)))
-		    {
-		      tree t
-			= search_anon_aggr (TREE_TYPE (field),
-					    TREE_CODE (ce->index) == FIELD_DECL
-					    ? DECL_NAME (ce->index)
-					    : ce->index);
-		      if (t)
-			{
-			  field = t;
-			  break;
-			}
-		    }
 		}
 	    }
 	  if (field)
diff --git a/gcc/testsuite/g++.dg/cpp2a/desig18.C b/gcc/testsuite/g++.dg/cpp2a/desig18.C
new file mode 100644
index 0000000000000..4851579b7c78f
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/desig18.C
@@ -0,0 +1,17 @@
+// PR c++/100489
+// { dg-options "" }
+
+union U
+{
+  union
+  {
+    unsigned char a;
+  };
+
+  unsigned char b[1];
+};
+
+void f(unsigned char a)
+{
+  union U u = { .a = a };
+}

From cc7fc1623b97de13c59d10d945cb845bdbd0546c Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Fri, 21 May 2021 00:18:54 +0000
Subject: [PATCH 156/164] Daily bump.

---
 gcc/ChangeLog           | 12 ++++++++++++
 gcc/DATESTAMP           |  2 +-
 gcc/cp/ChangeLog        | 33 +++++++++++++++++++++++++++++++++
 gcc/testsuite/ChangeLog | 39 +++++++++++++++++++++++++++++++++++++++
 libstdc++-v3/ChangeLog  | 11 +++++++++++
 5 files changed, 96 insertions(+), 1 deletion(-)

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index e3051116b82cf..01523448590d1 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,15 @@
+2021-05-20  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	Backported from master:
+	2021-05-18  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	PR c++/100281
+	* tree.c (build_reference_type_for_mode)
+	(build_pointer_type_for_mode): Pick pointer mode if MODE argument
+	is VOIDmode.
+	(build_reference_type, build_pointer_type): Invoke
+	build_*_type_for_mode with VOIDmode.
+
 2021-05-19  Bill Schmidt  <wschmidt@linux.ibm.com>
 
 	* config/rs6000/rs6000-c.c (rs6000_target_modify_macros): Define
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index e63f6d4142a92..6e5d5d3afec7d 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210520
+20210521
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index a18dd9a1014d3..eeb884ded4d6e 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,36 @@
+2021-05-20  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100489
+	* decl.c (reshape_init_class): Handle designator for
+	member of anonymous aggregate here.
+	* typeck2.c (process_init_constructor_record): Not here.
+
+2021-05-20  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	Backported from master:
+	2021-05-18  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	PR c++/100281
+	* cvt.c (cp_convert_to_pointer): Use the size of the target
+	pointer type.
+	* tree.c (cp_build_reference_type): Call
+	cp_build_reference_type_for_mode with VOIDmode.
+	(cp_build_reference_type_for_mode): Rename from
+	cp_build_reference_type.  Add MODE argument and invoke
+	build_reference_type_for_mode.
+	(strip_typedefs): Use build_pointer_type_for_mode and
+	cp_build_reference_type_for_mode for pointers and references.
+
+2021-05-20  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100634
+	* pt.c (invalid_nontype_parm_type_p): Return true for COMPLEX_TYPE.
+
+2021-05-20  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100659
+	* cp-tree.h (CONST_DECL_USING_P): Check for null TREE_TYPE.
+
 2021-05-19  Jason Merrill  <jason@redhat.com>
 
 	PR c++/100367
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 573d53388511e..fc9126ff274a4 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,42 @@
+2021-05-20  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100489
+	* g++.dg/cpp2a/desig18.C: New test.
+
+2021-05-20  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	Backported from master:
+	2021-05-18  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	PR c++/100281
+	* g++.target/s390/pr100281-1.C: New test.
+	* g++.target/s390/pr100281-2.C: New test.
+
+2021-05-20  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR testsuite/96488
+	* gnat.dg/unchecked_convert5.adb: Do not run on PowerPC64 LE.
+	* gnat.dg/unchecked_convert6.adb: Likewise.
+
+2021-05-20  Tobias Burnus  <tobias@codesourcery.com>
+
+	Backported from master:
+	2021-05-20  Tobias Burnus  <tobias@codesourcery.com>
+
+	PR fortran/96983
+	* gfortran.dg/pr96711.f90: Use 2**digit(x) instead of a hard-coded value;
+	add comments regarding what the code does.
+
+2021-05-20  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100634
+	* g++.dg/cpp2a/nontype-complex1.C: New test.
+
+2021-05-20  Jason Merrill  <jason@redhat.com>
+
+	PR c++/100659
+	* g++.dg/parse/access13.C: New test.
+
 2021-05-19  Bill Schmidt  <wschmidt@linux.ibm.com>
 
 	* gcc.target/powerpc/rop-1.c: New.
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index e97734abdca8a..c4cfab26da256 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,14 @@
+2021-05-20  Joern Rennecke  <joern.rennecke@riscy-ip.com>
+
+	PR libstdc++/100361
+	* include/std/charconv (to_chars): Hide the overloads for
+	floating-point types for 16 bit targets.
+	* src/c++17/floating_to_chars.cc: Don't compile for 16 bit targets.
+	* testsuite/20_util/to_chars/double.cc: Run this test only on
+	size32plus targets.
+	* testsuite/20_util/to_chars/float.cc: Likewise.
+	* testsuite/20_util/to_chars/long_double.cc: Likewise.
+
 2021-05-17  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

From 5f7834550ee1954f17ad662cf51928e0a85dc414 Mon Sep 17 00:00:00 2001
From: Eric Botcazou <ebotcazou@adacore.com>
Date: Fri, 21 May 2021 10:26:50 +0200
Subject: [PATCH 157/164] Fix incorrect SLOC on instruction

This puts the missing SLOC on a statement generated by a return.

gcc/ada/
	* gcc-interface/trans.c (gnat_to_gnu) <N_Simple_Return_Statement>:
	Put a SLOC on the assignment from the return value to the return
	object in the copy-in/copy-out case.
---
 gcc/ada/gcc-interface/trans.c | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/gcc/ada/gcc-interface/trans.c b/gcc/ada/gcc-interface/trans.c
index 5a55ca4f29ef3..8d63d03079f96 100644
--- a/gcc/ada/gcc-interface/trans.c
+++ b/gcc/ada/gcc-interface/trans.c
@@ -7525,8 +7525,10 @@ gnat_to_gnu (Node_Id gnat_node)
 	if (gnu_return_label_stack->last ())
 	  {
 	    if (gnu_ret_val)
-	      add_stmt (build_binary_op (MODIFY_EXPR, NULL_TREE, gnu_ret_obj,
-					 gnu_ret_val));
+	      add_stmt_with_node (build_binary_op (MODIFY_EXPR,
+						   NULL_TREE, gnu_ret_obj,
+						   gnu_ret_val),
+				  gnat_node);
 
 	    gnu_result = build1 (GOTO_EXPR, void_type_node,
 				 gnu_return_label_stack->last ());

From a9591c33e91b7cb1e544b4efb5987a93143a2a07 Mon Sep 17 00:00:00 2001
From: Eric Botcazou <ebotcazou@adacore.com>
Date: Fri, 21 May 2021 10:40:41 +0200
Subject: [PATCH 158/164] Fix segfault at run time on strict-alignment
 platforms

This fixes a regression present on the mainline and 11 branch by
restricting the problematic change dealing with bitfields whose
nomimal subtype is self-referential to the cases where the size
is really lower.

gcc/ada/
	* gcc-interface/trans.c (Call_to_gnu): Restrict previous change
	to bitfields whose size is not equal to the type size.
	(gnat_to_gnu): Likewise.
---
 gcc/ada/gcc-interface/trans.c | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/gcc/ada/gcc-interface/trans.c b/gcc/ada/gcc-interface/trans.c
index 8d63d03079f96..d4435eab10aec 100644
--- a/gcc/ada/gcc-interface/trans.c
+++ b/gcc/ada/gcc-interface/trans.c
@@ -4553,6 +4553,8 @@ Call_to_gnu (Node_Id gnat_node, tree *gnu_result_type_p, tree gnu_target,
 	  || (gnu_target
 	      && TREE_CODE (gnu_target) == COMPONENT_REF
 	      && DECL_BIT_FIELD (TREE_OPERAND (gnu_target, 1))
+	      && DECL_SIZE (TREE_OPERAND (gnu_target, 1))
+		 != TYPE_SIZE (TREE_TYPE (gnu_target))
 	      && type_is_padding_self_referential (gnu_result_type))))
     {
       gnu_retval = create_temporary ("R", gnu_result_type);
@@ -8271,7 +8273,9 @@ gnat_to_gnu (Node_Id gnat_node)
 	 much data.  But do not remove it if it is already too small.  */
       if (type_is_padding_self_referential (TREE_TYPE (gnu_result))
 	  && !(TREE_CODE (gnu_result) == COMPONENT_REF
-	       && DECL_BIT_FIELD (TREE_OPERAND (gnu_result, 1))))
+	       && DECL_BIT_FIELD (TREE_OPERAND (gnu_result, 1))
+	       && DECL_SIZE (TREE_OPERAND (gnu_result, 1))
+		  != TYPE_SIZE (TREE_TYPE (gnu_result))))
 	gnu_result = convert (TREE_TYPE (TYPE_FIELDS (TREE_TYPE (gnu_result))),
 			      gnu_result);
     }

From 36a70e6b64be306cf6384becbd21c65ac8bd22fa Mon Sep 17 00:00:00 2001
From: Eric Botcazou <ebotcazou@adacore.com>
Date: Fri, 21 May 2021 10:45:21 +0200
Subject: [PATCH 159/164] Always translate Is_Pure flag into pure in C sense

Gigi has historically translated the Is_Pure flag of the front-end into
the "const" attribute of GNU C.  That's correct for subprograms of pure
Ada units, but not fully exact according to the semantics of the flag.

gcc/ada/
	* gcc-interface/decl.c (gnat_to_gnu_subprog_type): Always translate
	the Is_Pure flag into the "pure" attribute of GNU C.
---
 gcc/ada/gcc-interface/decl.c | 47 ++++++++++++++++--------------------
 1 file changed, 21 insertions(+), 26 deletions(-)

diff --git a/gcc/ada/gcc-interface/decl.c b/gcc/ada/gcc-interface/decl.c
index 27ef51a9eed67..232a67ce77ba5 100644
--- a/gcc/ada/gcc-interface/decl.c
+++ b/gcc/ada/gcc-interface/decl.c
@@ -5761,16 +5761,16 @@ gnat_to_gnu_subprog_type (Entity_Id gnat_subprog, bool definition,
   tree gnu_cico_return_type = NULL_TREE;
   tree gnu_cico_field_list = NULL_TREE;
   bool gnu_cico_only_integral_type = true;
-  /* The semantics of "pure" in Ada essentially matches that of "const"
-     or "pure" in GCC.  In particular, both properties are orthogonal
-     to the "nothrow" property if the EH circuitry is explicit in the
-     internal representation of the middle-end.  If we are to completely
-     hide the EH circuitry from it, we need to declare that calls to pure
-     Ada subprograms that can throw have side effects since they can
-     trigger an "abnormal" transfer of control flow; therefore, they can
-     be neither "const" nor "pure" in the GCC sense.  */
-  bool const_flag = (Back_End_Exceptions () && Is_Pure (gnat_subprog));
-  bool pure_flag = false;
+  /* Although the semantics of "pure" units in Ada essentially match those of
+     "const" in GNU C, the semantics of the Is_Pure flag in GNAT do not say
+     anything about access to global memory, that's why it needs to be mapped
+     to "pure" instead of "const" in GNU C.  The property is orthogonal to the
+     "nothrow" property only if the EH circuitry is explicit in the internal
+     representation of the middle-end: if we are to completely hide the EH
+     circuitry from it, we need to declare that calls to pure Ada subprograms
+     that can throw have side effects, since they can trigger an "abnormal"
+     transfer of control; therefore they cannot be "pure" in the GCC sense.  */
+  bool pure_flag = Is_Pure (gnat_subprog) && Back_End_Exceptions ();
   bool return_by_direct_ref_p = false;
   bool return_by_invisi_ref_p = false;
   bool return_unconstrained_p = false;
@@ -5923,14 +5923,14 @@ gnat_to_gnu_subprog_type (Entity_Id gnat_subprog, bool definition,
     }
 
   /* A procedure (something that doesn't return anything) shouldn't be
-     considered const since there would be no reason for calling such a
+     considered pure since there would be no reason for calling such a
      subprogram.  Note that procedures with Out (or In Out) parameters
      have already been converted into a function with a return type.
      Similarly, if the function returns an unconstrained type, then the
      function will allocate the return value on the secondary stack and
      thus calls to it cannot be CSE'ed, lest the stack be reclaimed.  */
   if (VOID_TYPE_P (gnu_return_type) || return_unconstrained_p)
-    const_flag = false;
+    pure_flag = false;
 
   /* Loop over the parameters and get their associated GCC tree.  While doing
      this, build a copy-in copy-out structure if we need one.  */
@@ -6058,18 +6058,16 @@ gnat_to_gnu_subprog_type (Entity_Id gnat_subprog, bool definition,
 	  save_gnu_tree (gnat_param, gnu_param, false);
 
 	  /* A pure function in the Ada sense which takes an access parameter
-	     may modify memory through it and thus need be considered neither
-	     const nor pure in the GCC sense.  Likewise it if takes a by-ref
-	     In Out or Out parameter.  But if it takes a by-ref In parameter,
-	     then it may only read memory through it and can be considered
-	     pure in the GCC sense.  */
-	  if ((const_flag || pure_flag)
-	      && (POINTER_TYPE_P (gnu_param_type)
+	     may modify memory through it and thus cannot be considered pure
+	     in the GCC sense, unless it's access-to-function.  Likewise it if
+	     takes a by-ref In Out or Out parameter.  But if it takes a by-ref
+	     In parameter, then it may only read memory through it and can be
+	     considered pure in the GCC sense.  */
+	  if (pure_flag
+	      && ((POINTER_TYPE_P (gnu_param_type)
+		   && TREE_CODE (TREE_TYPE (gnu_param_type)) != FUNCTION_TYPE)
 		  || TYPE_IS_FAT_POINTER_P (gnu_param_type)))
-	    {
-	      const_flag = false;
-	      pure_flag = DECL_POINTS_TO_READONLY_P (gnu_param);
-	    }
+	    pure_flag = DECL_POINTS_TO_READONLY_P (gnu_param);
 	}
 
       /* If the parameter uses the copy-in copy-out mechanism, allocate a field
@@ -6269,9 +6267,6 @@ gnat_to_gnu_subprog_type (Entity_Id gnat_subprog, bool definition,
 	    }
 	}
 
-      if (const_flag)
-	gnu_type = change_qualified_type (gnu_type, TYPE_QUAL_CONST);
-
       if (pure_flag)
 	gnu_type = change_qualified_type (gnu_type, TYPE_QUAL_RESTRICT);
 

From 35382423fe1a631654708182b169ca104bba4730 Mon Sep 17 00:00:00 2001
From: Eric Botcazou <ebotcazou@adacore.com>
Date: Fri, 21 May 2021 10:57:02 +0200
Subject: [PATCH 160/164] Fix internal error on locally derived bit-packed
 array type

This is a regression present on the mainline, 11 and 10 branches,
in the form of an ICE on a locally derived bit-packed array type.

gcc/ada/
	* gcc-interface/decl.c (gnat_to_gnu_entity) <E_Array_Type>: Process
	the implementation type of a packed type implemented specially.
gcc/testsuite/
	* gnat.dg/derived_type7.adb, gnat.dg/derived_type7.ads: New test.
---
 gcc/ada/gcc-interface/decl.c            | 14 +++++++++-----
 gcc/testsuite/gnat.dg/derived_type7.adb |  9 +++++++++
 gcc/testsuite/gnat.dg/derived_type7.ads | 13 +++++++++++++
 3 files changed, 31 insertions(+), 5 deletions(-)
 create mode 100644 gcc/testsuite/gnat.dg/derived_type7.adb
 create mode 100644 gcc/testsuite/gnat.dg/derived_type7.ads

diff --git a/gcc/ada/gcc-interface/decl.c b/gcc/ada/gcc-interface/decl.c
index 232a67ce77ba5..2d64675595f37 100644
--- a/gcc/ada/gcc-interface/decl.c
+++ b/gcc/ada/gcc-interface/decl.c
@@ -2354,11 +2354,15 @@ gnat_to_gnu_entity (Entity_Id gnat_entity, tree gnu_expr, bool definition)
 	      set_nonaliased_component_on_array_type (tem);
 	  }
 
-	/* If an alignment is specified, use it if valid.  But ignore it
-	   for the original type of packed array types.  If the alignment
-	   was requested with an explicit alignment clause, state so.  */
-	if (No (Packed_Array_Impl_Type (gnat_entity))
-	    && Known_Alignment (gnat_entity))
+	/* If this is a packed type implemented specially, then process the
+	   implementation type so it is elaborated in the proper scope.  */
+	if (Present (Packed_Array_Impl_Type (gnat_entity)))
+	  gnat_to_gnu_entity (Packed_Array_Impl_Type (gnat_entity), NULL_TREE,
+			      false);
+
+	/* Otherwise, if an alignment is specified, use it if valid and, if
+	   the alignment was requested with an explicit clause, state so.  */
+	else if (Known_Alignment (gnat_entity))
 	  {
 	    SET_TYPE_ALIGN (tem,
 			    validate_alignment (Alignment (gnat_entity),
diff --git a/gcc/testsuite/gnat.dg/derived_type7.adb b/gcc/testsuite/gnat.dg/derived_type7.adb
new file mode 100644
index 0000000000000..61e7abaa1d77a
--- /dev/null
+++ b/gcc/testsuite/gnat.dg/derived_type7.adb
@@ -0,0 +1,9 @@
+package body Derived_Type7 is
+
+  procedure Proc (Size : Natural) is
+    type Sar_Six_Bit_Arr is new Six_Bit_Data_Array_Type (1 .. Size);
+  begin
+    null;
+  end;
+
+end Derived_Type7;
diff --git a/gcc/testsuite/gnat.dg/derived_type7.ads b/gcc/testsuite/gnat.dg/derived_type7.ads
new file mode 100644
index 0000000000000..2b1427af3c69f
--- /dev/null
+++ b/gcc/testsuite/gnat.dg/derived_type7.ads
@@ -0,0 +1,13 @@
+-- { dg-do compile }
+
+package Derived_Type7 is
+
+  type Six_Bit_Data_Type is range 0 .. 63;
+  for Six_Bit_Data_Type'Size use 6;
+
+  type Six_Bit_Data_Array_Type is array (Integer range <>) of Six_Bit_Data_Type;
+  for Six_Bit_Data_Array_Type'Component_Size use 6;
+
+  procedure Proc (Size : Natural);
+
+end Derived_Type7;

From 2bf34b9f4e446bf9be7f04458058dd5319fb396e Mon Sep 17 00:00:00 2001
From: Tamar Christina <tamar.christina@arm.com>
Date: Fri, 21 May 2021 10:30:59 +0100
Subject: [PATCH 161/164] libsanitizer: Remove cyclades from libsanitizer

The Linux kernel has removed the interface to cyclades from
the latest kernel headers[1] due to them being orphaned for the
past 13 years.

libsanitizer uses this header when compiling against glibc, but
glibcs itself doesn't seem to have any references to cyclades.

Further more it seems that the driver is broken in the kernel and
the firmware doesn't seem to be available anymore.

As such since this is breaking the build of libsanitizer (and so the
GCC bootstrap[2]) I propose to remove this.

[1] https://lkml.org/lkml/2021/3/2/153
[2] https://gcc.gnu.org/bugzilla/show_bug.cgi?id=100379

libsanitizer/ChangeLog:

	PR sanitizer/100379
	* sanitizer_common/sanitizer_common_interceptors_ioctl.inc: Cherry-pick
	llvm-project revision f7c5351552387bd43f6ca3631016d7f0dfe0f135.
	* sanitizer_common/sanitizer_platform_limits_posix.cpp: Likewise.
	* sanitizer_common/sanitizer_platform_limits_posix.h: Likewise.

(cherry picked from commit 745dae5923aba02982563481d75a21595df22ff8)
---
 .../sanitizer_common_interceptors_ioctl.inc           |  9 ---------
 .../sanitizer_platform_limits_posix.cpp               | 11 -----------
 .../sanitizer_platform_limits_posix.h                 | 10 ----------
 3 files changed, 30 deletions(-)

diff --git a/libsanitizer/sanitizer_common/sanitizer_common_interceptors_ioctl.inc b/libsanitizer/sanitizer_common/sanitizer_common_interceptors_ioctl.inc
index 490a04b2181b0..42e43a04441d0 100644
--- a/libsanitizer/sanitizer_common/sanitizer_common_interceptors_ioctl.inc
+++ b/libsanitizer/sanitizer_common/sanitizer_common_interceptors_ioctl.inc
@@ -366,15 +366,6 @@ static void ioctl_table_fill() {
 
 #if SANITIZER_LINUX && !SANITIZER_ANDROID
   // _(SIOCDEVPLIP, WRITE, struct_ifreq_sz); // the same as EQL_ENSLAVE
-  _(CYGETDEFTHRESH, WRITE, sizeof(int));
-  _(CYGETDEFTIMEOUT, WRITE, sizeof(int));
-  _(CYGETMON, WRITE, struct_cyclades_monitor_sz);
-  _(CYGETTHRESH, WRITE, sizeof(int));
-  _(CYGETTIMEOUT, WRITE, sizeof(int));
-  _(CYSETDEFTHRESH, NONE, 0);
-  _(CYSETDEFTIMEOUT, NONE, 0);
-  _(CYSETTHRESH, NONE, 0);
-  _(CYSETTIMEOUT, NONE, 0);
   _(EQL_EMANCIPATE, WRITE, struct_ifreq_sz);
   _(EQL_ENSLAVE, WRITE, struct_ifreq_sz);
   _(EQL_GETMASTRCFG, WRITE, struct_ifreq_sz);
diff --git a/libsanitizer/sanitizer_common/sanitizer_platform_limits_posix.cpp b/libsanitizer/sanitizer_common/sanitizer_platform_limits_posix.cpp
index 1427cec48c4a3..025e575b5bc70 100644
--- a/libsanitizer/sanitizer_common/sanitizer_platform_limits_posix.cpp
+++ b/libsanitizer/sanitizer_common/sanitizer_platform_limits_posix.cpp
@@ -131,7 +131,6 @@ typedef struct user_fpregs elf_fpregset_t;
 # include <sys/procfs.h>
 #endif
 #include <sys/user.h>
-#include <linux/cyclades.h>
 #include <linux/if_eql.h>
 #include <linux/if_plip.h>
 #include <linux/lp.h>
@@ -449,7 +448,6 @@ unsigned struct_ElfW_Phdr_sz = sizeof(Elf_Phdr);
 
 #if SANITIZER_LINUX && !SANITIZER_ANDROID
   unsigned struct_ax25_parms_struct_sz = sizeof(struct ax25_parms_struct);
-  unsigned struct_cyclades_monitor_sz = sizeof(struct cyclades_monitor);
 #if EV_VERSION > (0x010000)
   unsigned struct_input_keymap_entry_sz = sizeof(struct input_keymap_entry);
 #else
@@ -815,15 +813,6 @@ unsigned struct_ElfW_Phdr_sz = sizeof(Elf_Phdr);
 #endif // SANITIZER_LINUX
 
 #if SANITIZER_LINUX && !SANITIZER_ANDROID
-  unsigned IOCTL_CYGETDEFTHRESH = CYGETDEFTHRESH;
-  unsigned IOCTL_CYGETDEFTIMEOUT = CYGETDEFTIMEOUT;
-  unsigned IOCTL_CYGETMON = CYGETMON;
-  unsigned IOCTL_CYGETTHRESH = CYGETTHRESH;
-  unsigned IOCTL_CYGETTIMEOUT = CYGETTIMEOUT;
-  unsigned IOCTL_CYSETDEFTHRESH = CYSETDEFTHRESH;
-  unsigned IOCTL_CYSETDEFTIMEOUT = CYSETDEFTIMEOUT;
-  unsigned IOCTL_CYSETTHRESH = CYSETTHRESH;
-  unsigned IOCTL_CYSETTIMEOUT = CYSETTIMEOUT;
   unsigned IOCTL_EQL_EMANCIPATE = EQL_EMANCIPATE;
   unsigned IOCTL_EQL_ENSLAVE = EQL_ENSLAVE;
   unsigned IOCTL_EQL_GETMASTRCFG = EQL_GETMASTRCFG;
diff --git a/libsanitizer/sanitizer_common/sanitizer_platform_limits_posix.h b/libsanitizer/sanitizer_common/sanitizer_platform_limits_posix.h
index 0812039b038ff..83861105a509d 100644
--- a/libsanitizer/sanitizer_common/sanitizer_platform_limits_posix.h
+++ b/libsanitizer/sanitizer_common/sanitizer_platform_limits_posix.h
@@ -981,7 +981,6 @@ extern unsigned struct_vt_mode_sz;
 
 #if SANITIZER_LINUX && !SANITIZER_ANDROID
 extern unsigned struct_ax25_parms_struct_sz;
-extern unsigned struct_cyclades_monitor_sz;
 extern unsigned struct_input_keymap_entry_sz;
 extern unsigned struct_ipx_config_data_sz;
 extern unsigned struct_kbdiacrs_sz;
@@ -1326,15 +1325,6 @@ extern unsigned IOCTL_VT_WAITACTIVE;
 #endif  // SANITIZER_LINUX
 
 #if SANITIZER_LINUX && !SANITIZER_ANDROID
-extern unsigned IOCTL_CYGETDEFTHRESH;
-extern unsigned IOCTL_CYGETDEFTIMEOUT;
-extern unsigned IOCTL_CYGETMON;
-extern unsigned IOCTL_CYGETTHRESH;
-extern unsigned IOCTL_CYGETTIMEOUT;
-extern unsigned IOCTL_CYSETDEFTHRESH;
-extern unsigned IOCTL_CYSETDEFTIMEOUT;
-extern unsigned IOCTL_CYSETTHRESH;
-extern unsigned IOCTL_CYSETTIMEOUT;
 extern unsigned IOCTL_EQL_EMANCIPATE;
 extern unsigned IOCTL_EQL_ENSLAVE;
 extern unsigned IOCTL_EQL_GETMASTRCFG;

From 907a70be204588d9d7a282a7165048df912197de Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Sat, 22 May 2021 00:18:07 +0000
Subject: [PATCH 162/164] Daily bump.

---
 gcc/DATESTAMP           |  2 +-
 gcc/ada/ChangeLog       | 22 ++++++++++++++++++++++
 gcc/testsuite/ChangeLog |  4 ++++
 libsanitizer/ChangeLog  | 11 +++++++++++
 4 files changed, 38 insertions(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 6e5d5d3afec7d..d128d2a267a5d 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210521
+20210522
diff --git a/gcc/ada/ChangeLog b/gcc/ada/ChangeLog
index cd3d945cf9756..50201d29d9847 100644
--- a/gcc/ada/ChangeLog
+++ b/gcc/ada/ChangeLog
@@ -1,3 +1,25 @@
+2021-05-21  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/decl.c (gnat_to_gnu_entity) <E_Array_Type>: Process
+	the implementation type of a packed type implemented specially.
+
+2021-05-21  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/decl.c (gnat_to_gnu_subprog_type): Always translate
+	the Is_Pure flag into the "pure" attribute of GNU C.
+
+2021-05-21  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/trans.c (Call_to_gnu): Restrict previous change
+	to bitfields whose size is not equal to the type size.
+	(gnat_to_gnu): Likewise.
+
+2021-05-21  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/trans.c (gnat_to_gnu) <N_Simple_Return_Statement>:
+	Put a SLOC on the assignment from the return value to the return
+	object in the copy-in/copy-out case.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index fc9126ff274a4..60c48fb4c2f86 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,7 @@
+2021-05-21  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gnat.dg/derived_type7.adb, gnat.dg/derived_type7.ads: New test.
+
 2021-05-20  Jason Merrill  <jason@redhat.com>
 
 	PR c++/100489
diff --git a/libsanitizer/ChangeLog b/libsanitizer/ChangeLog
index b72d9afe4d94d..9da4130e6579c 100644
--- a/libsanitizer/ChangeLog
+++ b/libsanitizer/ChangeLog
@@ -1,3 +1,14 @@
+2021-05-21  Tamar Christina  <tamar.christina@arm.com>
+
+	Backported from master:
+	2021-05-21  Tamar Christina  <tamar.christina@arm.com>
+
+	PR sanitizer/100379
+	* sanitizer_common/sanitizer_common_interceptors_ioctl.inc: Cherry-pick
+	llvm-project revision f7c5351552387bd43f6ca3631016d7f0dfe0f135.
+	* sanitizer_common/sanitizer_platform_limits_posix.cpp: Likewise.
+	* sanitizer_common/sanitizer_platform_limits_posix.h: Likewise.
+
 2021-04-27  Release Manager
 
 	* GCC 11.1.0 released.

From 1d62f731b1c0e6d65453a44d3f2779d8221338d9 Mon Sep 17 00:00:00 2001
From: GCC Administrator <gccadmin@gcc.gnu.org>
Date: Sun, 23 May 2021 00:18:02 +0000
Subject: [PATCH 163/164] Daily bump.

---
 gcc/DATESTAMP | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index d128d2a267a5d..a0c453ec18a2c 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20210522
+20210523

From 9ee61d2b51df012c659359873637cc2162ecccf3 Mon Sep 17 00:00:00 2001
From: Tobias Burnus <tobias@codesourcery.com>
Date: Sun, 23 May 2021 11:56:39 +0200
Subject: [PATCH 164/164] fortran/intrinsic.texi: Use proper variable name

gcc/fortran/ChangeLog:

	* intrinsic.texi (ATOMIC_ADD, ATOMIC_FETCH_ADD): Use the
	proper variable name in the description.

(cherry picked from commit 5d3ef9189a7c57679b5fb06e51c90479df0548b0)
---
 gcc/fortran/intrinsic.texi | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gcc/fortran/intrinsic.texi b/gcc/fortran/intrinsic.texi
index a62508745fda5..ad16413798697 100644
--- a/gcc/fortran/intrinsic.texi
+++ b/gcc/fortran/intrinsic.texi
@@ -1870,7 +1870,7 @@ Inverse function: @gol
 
 @table @asis
 @item @emph{Description}:
-@code{ATOMIC_ADD(ATOM, VALUE)} atomically adds the value of @var{VAR} to the
+@code{ATOMIC_ADD(ATOM, VALUE)} atomically adds the value of @var{VALUE} to the
 variable @var{ATOM}. When @var{STAT} is present and the invocation was
 successful, it is assigned the value 0. If it is present and the invocation
 has failed, it is assigned a positive value; in particular, for a coindexed
@@ -2090,7 +2090,7 @@ end program atomic
 @table @asis
 @item @emph{Description}:
 @code{ATOMIC_FETCH_ADD(ATOM, VALUE, OLD)} atomically stores the value of
-@var{ATOM} in @var{OLD} and adds the value of @var{VAR} to the
+@var{ATOM} in @var{OLD} and adds the value of @var{VALUE} to the
 variable @var{ATOM}. When @var{STAT} is present and the invocation was
 successful, it is assigned the value 0. If it is present and the invocation
 has failed, it is assigned a positive value; in particular, for a coindexed
